//
// Copyright 2014 Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Created by postproc-cld2 4.0 on 2014-01-31 09:56:39
// From command line:
//  --nearby_probs=1.8 --cld2 --cc --just_read_raw --quad --standard
//  --minchars=2 --mincount=2 --max_items_per_langscript=6000 --flatmap
//  --rr_alloc --freq_alloc --boostcloseweakerpercent=00 --indirectbits=16
//  --thresh=224 --v25 --kentries=256 --tablename=QuadChrome0122_2
//  --remap=xxx-Latn=>ut-Latn tw-Latn=>ak-Latn nd-Latn=>nr-Latn
//  blu-Latn=>hmn-Latn nn-Latn=>no-Latn  --include=af-Latn ar-Arab be-Cyrl
//  bg-Cyrl bs-Latn ca-Latn cs-Latn cy-Latn    da-Latn de-Latn el-Grek
//  en-Latn es-Latn et-Latn fa-Arab fi-Latn fr-Latn    ga-Latn gd-Latn
//  hi-Deva hr-Latn hu-Latn id-Latn is-Latn it-Latn iw-Hebr    ja-Hani
//  ko-Hani lg-Latn lt-Latn lv-Latn mk-Cyrl ms-Latn nl-Latn no-Latn
//  pl-Latn pt-Latn ro-Latn ro-Cyrl ru-Cyrl rw-Latn sh-Cyrl sh-Latn sk-Latn
//  sl-Latn sr-Cyrl    sv-Latn sw-Latn th-Thai tl-Latn tr-Latn uk-Cyrl
//  vi-Latn yi-Hebr    zh-Hani zh-TW zhT-Hani    sq-Latn az-Latn eu-Latn
//  bn-Beng gl-Latn ht-Latn mt-Latn sr-Latn ur-Arab    bh-Deva mr-Deva
//  ne-Deva lg-Latn rw-Latn gd-Latn    ut-Latn ut-Deva    ceb-Latn blu-Latn
//  hmn-Latn jw-Latn    so-Latn ig-Latn ha-Latn yo-Latn zu-Latn --ko_english
//  --force_to_lang_soft --nosoft_cram2 --nomsidlevel --shapeflatprob
//  --langpriorpercent=10 --skipnuc --noshapeforcetop --noshapeeventop
//  --noshapesteep2 --langcounts --writebin --list_items=120
//  --max_langs_per_item=3 /hdb1/cld2/probs/p90_raw_quadgrams_2014.utf8
//
// CLD2_pslangs
//
// See compact_lang_det.cc for usage
//
#include "cld2tablesummary.h"
namespace CLD2 {

// For this build date, looking up 'qpdbmrmxyzptlkuuddlrlrbas' gives AZERBAIJANI
static const uint32 kQuadChrome0122_2BuildDate = 20140131;    // yyyymmdd


// Of 390154 offered items into 262144 table entries:
// 244373 filled (62%), 733 merged (0%), 145048 dropped (37%)

// Nil-grams: 19 languages
//     GREEK MALAYALAM TELUGU TAMIL GUJARATI THAI KANNADA PUNJABI
//     GEORGIAN SINHALESE ARMENIAN LAOTHIAN KHMER DHIVEHI CHEROKEE
//     SYRIAC LIMBU ORIYA INUKTITUT

// Uni-grams: 4 languages
//     Japanese Korean Chinese ChineseT

// Words/Quads: 67 languages in range ENGLISH..HMONG:
//     ENGLISH DANISH DUTCH FINNISH FRENCH GERMAN HEBREW ITALIAN
//     NORWEGIAN POLISH PORTUGUESE RUSSIAN SPANISH SWEDISH CZECH
//     ICELANDIC LATVIAN LITHUANIAN ROMANIAN HUNGARIAN ESTONIAN
//     BULGARIAN CROATIAN SERBIAN IRISH GALICIAN TAGALOG TURKISH
//     UKRAINIAN HINDI MACEDONIAN BENGALI INDONESIAN MALAY WELSH
//     NEPALI ALBANIAN BELARUSIAN JAVANESE URDU BIHARI ARABIC CATALAN
//     BASQUE SCOTS_GAELIC SWAHILI SLOVENIAN MARATHI MALTESE
//     VIETNAMESE SLOVAK AZERBAIJANI PERSIAN BOSNIAN ZULU YIDDISH
//     SOMALI MONGOLIAN AFRIKAANS YORUBA HAUSA HAITIAN_CREOLE
//     KINYARWANDA GANDA IGBO CEBUANO HMONG

// TopLanguage  TokenCount
//  ENGLISH 3592
//  DANISH 3571
//  DUTCH 3548
//  FINNISH 3676
//  FRENCH 3623
//  GERMAN 3561
//  HEBREW 3599
//  ITALIAN 2792
//  NORWEGIAN 3625
//  POLISH 3641
//  PORTUGUESE 3676
//  RUSSIAN 3614
//  SPANISH 3235
//  SWEDISH 3698
//  CZECH 7353
//  ICELANDIC 3583
//  LATVIAN 3687
//  LITHUANIAN 3594
//  ROMANIAN 7301
//  HUNGARIAN 3703
//  ESTONIAN 3575
//  BULGARIAN 3615
//  CROATIAN 3694
//  SERBIAN 6847
//  IRISH 3682
//  GALICIAN 3214
//  TAGALOG 2558
//  TURKISH 3635
//  UKRAINIAN 3624
//  HINDI 7171
//  MACEDONIAN 3608
//  BENGALI 3637
//  INDONESIAN 3892
//  MALAY 2642
//  WELSH 3586
//  NEPALI 3604
//  ALBANIAN 3614
//  BELARUSIAN 3628
//  JAVANESE 3598
//  URDU 3691
//  BIHARI 4003
//  ARABIC 3640
//  CATALAN 3576
//  BASQUE 3571
//  SCOTS_GAELIC 3632
//  SWAHILI 3617
//  SLOVENIAN 3650
//  MARATHI 3551
//  MALTESE 3642
//  VIETNAMESE 3632
//  SLOVAK 3619
//  AZERBAIJANI 3684
//  PERSIAN 3676
//  BOSNIAN 2635
//  ZULU 3517
//  YIDDISH 3573
//  SOMALI 3570
//  MONGOLIAN 15
//  AFRIKAANS 3607
//  YORUBA 3503
//  HAUSA 3008
//  HAITIAN_CREOLE 3618
//  KINYARWANDA 3479
//  GANDA 3632
//  IGBO 3170
//  CEBUANO 2298
//  HMONG 2201



// Recognized language-script combinations [69]:
static const char* const kQuadChrome0122_2RecognizedLangScripts =
  "af-Latn ar-Arab az-Latn be-Cyrl bg-Cyrl bh-Deva bn-Beng bs-Latn "
  "ca-Latn ceb-Latn cs-Latn cy-Latn da-Latn de-Latn en-Latn es-Latn "
  "et-Latn eu-Latn fa-Arab fi-Latn fr-Latn ga-Latn gd-Latn gl-Latn "
  "ha-Latn hi-Deva hmn-Latn hr-Latn ht-Latn hu-Latn id-Latn ig-Latn "
  "is-Latn it-Latn iw-Hebr jw-Latn lg-Latn lt-Latn lv-Latn mk-Cyrl "
  "mn-Latn mr-Deva ms-Latn mt-Latn ne-Deva nl-Latn no-Latn pl-Latn "
  "pt-Latn ro-Cyrl ro-Latn ru-Cyrl rw-Latn sk-Latn sl-Latn so-Latn "
  "sq-Latn sr-Cyrl sr-Latn sv-Latn sw-Latn tl-Latn tr-Latn uk-Cyrl "
  "ur-Arab vi-Latn yi-Hebr yo-Latn zu-Latn ";

static const uint32 kQuadChrome0122_2Size = 65536;    // Bucket count
static const uint32 kQuadChrome0122_2KeyMask = 0xffff0000;    // Mask hash key

static const IndirectProbBucket4 kQuadChrome0122_2[kQuadChrome0122_2Size] = {
  // hash_indirect[4], tokens[4] in UTF-8
   {{0xe9da0002,0x7c2e0003,0x65630004,0x20070005}},	// [000] вка_, ssbr, kenh, _huni_,
   {{0x20070006,0x64430007,0xbddb0008,0x63bb0009}},	//   _kuni_, kuni, stèr, hiun,
   {{0xddc4000a,0x6563000b,0x52e2000c,0x02e2000d}},	//   _križ, denh, _पर्स, _पर्न,
   {{0x6443000e,0x4916000f,0x63bb0010,0x20070011}},	//   duni, _प्रो_, jiun, _muni_,
   {{0x20070012,0x27ed0013,0x63a90014,0x63bb0015}},	//   _luni_, _dhen_, dhen, diun,
   {{0x65630016,0x64430017,0xef1f0018,0x24510019}},	//   genh, funi, tjük_, _bơm_,
   {{0x6443001a,0x24510019,0x2007001b,0x2816001c}},	//   guni, _cơm_, _nuni_, _خوزس,
   {{0x63bb001d,0xef1f0018,0x63a9001e,0xdb0d001f}},	//   giun, rjük_, ghen, riaç,
   {{0x36670020,0x65630021,0x20070022,0x21270023}},	//   _като_, benh, _auni_, _benh_,
   {{0x64430024,0x20070025,0x27ed0026,0x6f040027}},	//   buni, _buni_, _zhen_, _agic,
   {{0x2b9c0028,0x75280029,0x6aad002a,0x63bb002b}},	//   _tích_, _iedz, zzaf, biun,
   {{0x63a9002c,0x63bb002d,0x4ea7002e,0x2007002f}},	//   chen, ciun, арга, _duni_,
   {{0x69dc0030,0x75280031,0x229c0032,0xc6080033}},	//   _okre, _kedz, _dákú_, রীরা_,
   {{0x75280034,0x6e240035,0x20070036,0x71730037}},	//   _jedz, _dwib, _funi_, _وهنا,
   {{0x75280038,0xddc40039,0x212c0013,0x2007003a}},	//   _medz, _friž, madh_, _guni_,
   {{0x212c003b,0x6563003c,0x69c5003d,0x6d41003e}},	//   ladh_, zenh, wnhe, ólab,
   {{0xafb8003f,0x6b8d0040,0x64430041,0x69d70042}},	// [010] _خطوط_, rjag, zuni, toxe,
   {{0x212c003b,0x63bb002d,0x64430043,0x20070044}},	//   nadh_, ziun, yuni, _yuni_,
   {{0x69d70045,0x65630046,0x27ed0047,0x69c50048}},	//   roxe, venh, _phen_, rnhe,
   {{0x212c0049,0x69dc004a,0xa804004b,0xc7c4004c}},	//   hadh_, _ekre, ізіл, осчи,
   {{0x75280034,0x63a9004d,0x672b004e,0xd6ab0037}},	//   _bedz, vhen, ragj, خدام_,
   {{0x27ed004f,0x64430050,0x26df0051,0x672b0052}},	//   _when_, tuni, _vyuo_, sagj,
   {{0x63bb0012,0x65630053,0x27ed0054,0x212c0055}},	//   tiun, renh, _then_, dadh_,
   {{0x65630056,0x20070057,0xb3850058,0x7e6d0059}},	//   senh, _runi_, слил, _osap,
   {{0x63a9005a,0x6443005b,0x7bdd005c,0x212c0037}},	//   rhen, suni, _mksu, fadh_,
   {{0x212c003b,0x63bb005d,0x63a9005e,0x2007005f}},	//   gadh_, siun, shen, _puni_,
   {{0x63a90060,0xddc40061,0x7e6d0062,0x2ee00063}},	//   phen, _priž, _asap, _syif_,
   {{0x66010064,0xd5430065,0x6fdd002b,0x66090066}},	//   _hilk, _fẹ̀f, xéct, _kuek,
   {{0x66010067,0x7e6d0068,0x67290069,0x212c006a}},	//   _kilk, _csap, _meej, badh_,
   {{0x212c006b,0x6729006c,0x2007006d,0xb276006e}},	//   cadh_, _leej, _tuni_, _לענג_,
   {{0x1015006f,0xfce60070,0x7e6d0071,0x6fdd0072}},	//   _ابتد, сово, _esap, téct,
   {{0x69dc0073,0xee3f0074,0x260a0006,0x67290075}},	//   _skre, brý_, ादमी_, _neej,
   {{0x6d410076,0x0aea0077,0xddc40078,0x6e240079}},	// [020] ólac, удай_, _kriż, _uwib,
   {{0x46db007a,0x6601007b,0x7995007c,0x00000000}},	//   _बड़ह, _nilk, _cozw, --,
   {{0xaad8007d,0x75280029,0xdceb007e,0x7995007f}},	//   _भुरक, _redz, _ćiće, _dozw,
   {{0xbb860080,0xa3e7000f,0x06d10081,0xf7460082}},	//   _الحي, _मील_, ়েছি, седо,
   {{0x66010083,0x65940084,0x66090085,0x16340086}},	//   _bilk, жалу, _cuek, целя,
   {{0x69dc0087,0xdb160088,0x8e570089,0x5d7a006e}},	//   _ukre, ábær, מינג_, ראַק,
   {{0x6601008a,0xe644008b,0xb8960037,0x6729008c}},	//   _dilk, ğlığ, _الزع, _feej,
   {{0x5214008d,0xe644008e,0x5398008f,0xddc40090}},	//   одит, şlığ, рвия_, _ariż,
   {{0x212c0091,0x6fc80092,0x66010093,0x00000000}},	//   tadh_, rıcl, _filk, --,
   {{0xddcd0094,0x20090095,0x26f60096,0xb0340097}},	//   _krať, _čair_, ेशीर_, онош,
   {{0x212c003b,0x67290098,0xdb0d003e,0x7413001c}},	//   radh_, _yeej, knað, _فولا,
   {{0x212c0099,0x6601009a,0x7f9f0052,0xee3f0094}},	//   sadh_, _zilk, _këqi, trý_,
   {{0x4ad8007d,0x212c009b,0xeabf009c,0x27fc0031}},	//   _भुलव, padh_, _ceùl_, ívny_,
   {{0x6601008a,0xa2c5009d,0xddc4009e,0x491a009f}},	//   _xilk, ापर्, _griż, मुमो_,
   {{0x79950067,0x5ba700a0,0x71bb00a1,0x31bb00a1}},	//   _rozw, браз, _תצוג, _תזונ,
   {{0xdb0d0088,0x2d8c00a2,0x48ef00a3,0x09d100a4}},	//   gnað, öder_, _अरबो_, तक्य,
   {{0x799500a5,0x7e6d00a6,0x681500a7,0x74df00a8}},	// [030] _pozw, _usap, _işdə, _पुनः,
   {{0x5a3400a9,0x672900aa,0xaa7b0094,0x00000000}},	//   янут, _seej, _ozýv, --,
   {{0xe71900ab,0x672900ac,0x98b800ad,0x9b9500ae}},	//   ليات_, _peej, _barı_, _динц,
   {{0xe00b00af,0x00000000,0x00000000,0x00000000}},	//   _संसद_, --, --, --,
   {{0x660100b0,0xd24600b1,0x442500b2,0xbddb00b3}},	//   _pilk, _تن_, _swl_, crèc,
   {{0xcfcf0081,0x441500b4,0x00000000,0x00000000}},	//   রতিন, офит, --, --,
   {{0x660100b5,0x70d700b6,0x672900b7,0xddc4009e}},	//   _vilk, _डडेल, _teej, _rriż,
   {{0x36d500b8,0x57a400ae,0xe3b100b9,0x130900ba}},	//   _добр, _ешуа, برت_, шний_,
   {{0x660100bb,0x660900bc,0xddc400bd,0x00000000}},	//   _tilk, _uuek, _priż, --,
   {{0x11d60037,0x869800be,0x00000000,0x00000000}},	//   يوية_, _укус_, --, --,
   {{0xe2a800bf,0xfbd900c0,0x98b8008b,0x00000000}},	//   لاین_, भकाम, _yarı_, --,
   {{0x14d600c1,0x225900c2,0x63b90027,0x00000000}},	//   _וועל_, _виды_, _umwn, --,
   {{0xc8e600c3,0xddc400c4,0x00000000,0x00000000}},	//   _कर्म_, _asiš, --, --,
   {{0xa0a500c5,0x853c00c6,0x00000000,0x00000000}},	//   _малд, _alėj, --, --,
   {{0x09c400c7,0x8b9600c8,0x3b9600c9,0xdb0d003e}},	//   ্তমা, орач, ојат, tnað,
   {{0xc05200ca,0x7c3a00cb,0x00000000,0x00000000}},	//   _חזה_, štro, --, --,
   {{0x7c2900cc,0xdb0d003e,0x00000000,0x00000000}},	// [040] ćera, rnað, --, --,
   {{0x2b5800cd,0x98b8008b,0xed5a00ce,0xbc6600cf}},	//   _گیرد_, _sarı_, _тоо_, _двок,
   {{0xc8ca00d0,0xd90d00d1,0x00000000,0x00000000}},	//   جوان_, ایف_, --, --,
   {{0xddcd00d2,0x00000000,0x00000000,0x00000000}},	//   _vrať, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe5a300d3,0xddcd00d4,0x00000000,0x00000000}},	//   мичи, _trať, --, --,
   {{0x07a600d5,0x00000000,0x00000000,0x00000000}},	//   _давн, --, --, --,
   {{0x81e70081,0xd32600d6,0x68b700d7,0xaa7b00d8}},	//   _মূল_, цьки, _וללא_, _vzýv,
   {{0xdcfe00d9,0x9f4000da,0x00000000,0x00000000}},	//   _kopē, _fhiú_, --, --,
   {{0x27e600db,0x2a6200dc,0xa69700ca,0xdb230076}},	//   llon_, _mpkb_, _וכמה_, árúc,
   {{0x201800dd,0xdb060018,0x261000de,0x6ac600df}},	//   ëri_, _elké, _hào_, लपुर,
   {{0x27e600e0,0x75ed00e1,0x45220033,0x28bd00e2}},	//   nlon_, púzc, _নাটক_, ्पति,
   {{0xd25000e3,0xa2d6001c,0x201800e4,0x5f9400e5}},	//   _أنت_, _بيشت, ūri_, фият,
   {{0x27e600e6,0x2a7f00e7,0x26100023,0xdcfe00e8}},	//   hlon_, _šubo_, _mào_, _nopē,
   {{0x27e600e9,0x261000de,0x2ca500ea,0x6f1600eb}},	//   klon_, _lào_, áld_, _ffyc,
   {{0x2a6200ec,0x764200ed,0xdb1f0052,0x248e00ee}},	//   _bpkb_, kroy, miqë, ixfm_,
   {{0x261000ef,0x291c00a7,0x27e600f0,0x672200f1}},	// [050] _nào_, ıvan_, dlon_, dboj,
   {{0xceb2006e,0x3ea400f2,0x290700f3,0x764200f4}},	//   _ניי_, ømte_, øna_, droy,
   {{0x984b00e5,0x00000000,0x00000000,0x00000000}},	//   ряза_, --, --, --,
   {{0xf09300f5,0x261000de,0x27e600f0,0x201e00c6}},	//   ונע_, _bào_, glon_, ipti_,
   {{0x26100023,0xff7c006e,0x79a700f6,0x680500c6}},	//   _cào_, יטאמ, _дрве, _pėds,
   {{0x5a3400f7,0x996400f8,0xbafa00ca,0x27e600f9}},	//   _інст, _отсл, _להרש, alon_,
   {{0x27e600fa,0x00000000,0x00000000,0x00000000}},	//   blon_, --, --, --,
   {{0xd90e00fb,0x9f40009c,0x764200fc,0x00000000}},	//   _لیے_, _fhiù_, broy, --,
   {{0x764200fd,0x261000fe,0x35b500d3,0x00000000}},	//   croy, _gào_, _ебар, --,
   {{0x661b00ff,0xd6c60100,0x14190037,0x00000000}},	//   _ituk, _عملی, _هيئة_, --,
   {{0x3cdb0101,0xc8bd00b6,0x00000000,0x00000000}},	//   _खुले_, ्पिट, --, --,
   {{0x6d410102,0xe3b30103,0x00000000,0x00000000}},	//   ólan, _غرض_, --, --,
   {{0xa3ca0104,0x26100023,0xb2c70103,0x64df00a4}},	//   ोवर_, _xào_, _بغاو, _पुतळ,
   {{0xdd9200bf,0x427a0105,0x67220039,0x7c290106}},	//   روز_, _לאנג, zboj, ćern,
   {{0x27e60107,0xa0a50108,0x0c790109,0x661b010a}},	//   ylon_, _хайд, осты_, _ltuk,
   {{0x6443010b,0x661b010c,0x5f76010d,0xbebb0052}},	//   irni, _otuk, _رابر, mbën,
   {{0xeb97010e,0x6722010f,0xa9a60110,0x661b0111}},	// [060] чит_, vboj, пиад, _ntuk,
   {{0x261000de,0x7e640112,0x673b0113,0xfa490037}},	//   _rào_, _ipip, _aduj, تشفى_,
   {{0xfce60114,0x661b0115,0x261000fe,0x6d5c0116}},	//   _хоно, _atuk, _sào_, mfra,
   {{0x2d9a00a1,0x64430117,0xa2dc0096,0x76420118}},	//   _hope_, drni, _पडल्, troy,
   {{0x672200d9,0x6d5c0036,0x64430119,0xa613004d}},	//   rboj, ofra, erni, еміч,
   {{0x6d4e011a,0x2610011b,0x6d5c011c,0x27e6011d}},	//   ngba, _vào_, nfra, slon_,
   {{0x27e6011e,0x661b011f,0x29180120,0x290a0121}},	//   plon_, _etuk, _ifra_, _igba_,
   {{0x69de0122,0x7e6400cc,0x76420123,0x9734001c}},	//   lope, _opip, proy, _آکاا,
   {{0x321f0124,0x04fe0033,0x6d5c0125,0x00000000}},	//   gpuy_, ুরের_, kfra, --,
   {{0x6d4e0126,0x69de0127,0x64430128,0x5637006e}},	//   jgba, nope, brni, _מאמע_,
   {{0x290a0129,0xe8df00de,0x7ae6012a,0xf99300ca}},	//   _mgba_, _trục_, _lykt, תרת_,
   {{0xd36f012b,0x69de012c,0x644a012d,0xbddb0113}},	//   _مهم_, hope, mufi, grèn,
   {{0x6d5c012e,0x69de012f,0xe3b30130,0x2d9a0131}},	//   ffra, kope, _אױף_, _bope_,
   {{0x72eb0132,0x2d9a0133,0x00000000,0x00000000}},	//   _פֿאַ, _cope_, --, --,
   {{0xd5c800ef,0x7c290106,0xab1a0134,0x644a0135}},	//   yền_, ćero, _ọlụs, nufi,
   {{0x290a0136,0x6d4e0137,0xc1780138,0x61420139}},	//   _agba_, agba, ldė_, _fílà,
   {{0xb999013a,0x61420139,0x6d5c013b,0xdcfd013c}},	// [070] овах_, _gílà, bfra, ızıs,
   {{0x5c07013d,0x644a013e,0xc178013f,0x7ae6004d}},	//   _няма, kufi, ndė_, _dykt,
   {{0x3ea60029,0x661b0140,0x75ed00d4,0x661c0141}},	//   _ļoti_, _stuk, fúzn, _črka,
   {{0x64430087,0x290a0065,0x2d9a0062,0xdc360142}},	//   vrni, _egba_, _zope_, _קארט_,
   {{0x7bdf0143,0x4b7a00ca,0xc17800c6,0xb5fd0144}},	//   moqu, _וארו, kdė_, _apša,
   {{0x7bdf0145,0xddd60146,0x64430147,0x7bcd0148}},	//   loqu, _kryš, trni, lnau,
   {{0x64580149,0x200e0044,0x6443014a,0xbddb014b}},	//   gtvi, _nufi_, urni, yrèn,
   {{0x7bcd014c,0x2215014d,0x260a014e,0x6443014f}},	//   nnau, мфор, ादशी_, rrni,
   {{0x6d5c0150,0x661b0151,0xd24e0076,0x42540152}},	//   yfra, _utuk, لني_, нтэт,
   {{0x7bcd0153,0x23c30154,0x6d410155,0x10a50156}},	//   hnau, _bèjè_, ólal, дион,
   {{0x54550157,0x2d9a0158,0x00000000,0x00000000}},	//   _цвет, _rope_, --, --,
   {{0xd24e0159,0xe291015a,0x69de015b,0x7c3a015c}},	//   دنی_, _لذت_, zope, štrk,
   {{0x6d5c015d,0x69de0051,0x7bcd00fc,0xbddb015e}},	//   tfra, yope, dnau, rrèn,
   {{0x90c5015f,0x7ae60160,0x69de0161,0x3f890162}},	//   _обле, _rykt, xope, _enau_,
   {{0xfce30163,0x6d5c0164,0x7bdf0165,0x764b0124}},	//   воро, rfra, foqu, hugy,
   {{0x8ffa00cd,0x764b0166,0x320f0167,0x7bcd0168}},	//   _برتر_, kugy, _kugy_, gnau,
   {{0x2fc00169,0x32070079,0x00000000,0x00000000}},	// [080] _imig_, _kiny_, --, --,
   {{0x320f0113,0x7ae600c6,0x00000000,0x00000000}},	//   _mugy_, _vykt, --, --,
   {{0xeb9a016a,0x69de016b,0x8b26016c,0x7bdf016d}},	//   _дин_, rope, _одне, boqu,
   {{0xfaa600c6,0x46ea016e,0x7bdf016f,0x7ae60170}},	//   _жамо, оден_, coqu, _tykt,
   {{0x69de0171,0x764b0172,0x00000000,0x00000000}},	//   pope, gugy, --, --,
   {{0x64580173,0x290a0174,0x644a0175,0x28d90176}},	//   ttvi, _ugba_, tufi, _बुकि,
   {{0xd90d0177,0x64580120,0x799c0178,0x00000000}},	//   _ایم_, utvi, _iorw, --,
   {{0x28bd0179,0x6458017a,0x02a6017b,0x200e017c}},	//   ्परि, rtvi, дром, _rufi_,
   {{0x200e017d,0x96180081,0x6f090146,0x6aa4017e}},	//   _sufi_, _ডটকম_, žeck, nyif,
   {{0xb5aa0037,0xc17800c6,0x00000000,0x00000000}},	//   _بارك_, udė_, --, --,
   {{0x26ee017f,0x799c0178,0x61e80180,0xc17800c6}},	//   _जरुर_, _morw, rldl, rdė_,
   {{0xdce50181,0x73360182,0x33830183,0x2d9e0184}},	//   _pohľ, _آرائ, _аушв, öten_,
   {{0x799c0185,0x7bdf0186,0xa3e70187,0x69cb0103}},	//   _oorw, voqu, _मीट_, égek,
   {{0x2907013f,0x66080188,0x320700b3,0x799c0189}},	//   žnai_, _jidk, _giny_, _norw,
   {{0x7bdf00c9,0x6608008a,0xd139018a,0x00000000}},	//   toqu, _midk, _ххі_, --,
   {{0x26ee018b,0x6282018c,0x53de009d,0x6608018d}},	//   _जरूर_, _kroo, मविश, _lidk,
   {{0x7bcd018e,0x799c018f,0xdee70190,0x6f0d0191}},	// [090] rnau, _borw, _تأثي, _igac,
   {{0xaca30134,0xf9930192,0x6e2d0193,0xdb0d00fd}},	//   _arụg, خبر_, _iwab, chaî,
   {{0x20090194,0x7bdf0131,0x00000000,0x00000000}},	//   _kiai_, poqu, --, --,
   {{0x6e2d0195,0xa635004d,0x68e70146,0x764b0196}},	//   _kwab, енді, _vyjd, tugy,
   {{0x62820197,0x6e2d0167,0x799c00ca,0x68e7007f}},	//   _nroo, _jwab, _forw, _wyjd,
   {{0xba430138,0x6e2d0198,0x6b9d0199,0x799c00f0}},	//   žįst, _mwab, _hosg, _gorw,
   {{0x76590150,0x6282019a,0x6e2d019b,0x764b019c}},	//   stwy, _aroo, _lwab, sugy,
   {{0x6f0d019d,0x6282019e,0xe64b00a7,0x6e2d019f}},	//   _ngac, _broo, şdığ, _owab,
   {{0x020501a0,0x09c40033,0x62820133,0x6b9d01a1}},	//   нзин, ্তরা, _croo, _mosg,
   {{0x628201a2,0x6b9d01a3,0x6f0d0193,0x7c3a015c}},	//   _droo, _losg, _agac, štri,
   {{0x6e2d01a4,0x628201a5,0x853c0138,0x320700d4}},	//   _awab, _eroo, _plėv, _viny_,
   {{0x6e2d01a6,0x69c501a7,0xa3e700a4,0x6b9d01a8}},	//   _bwab, hihe, _मीच_, _nosg,
   {{0xee3701a9,0x628201aa,0x63a901ab,0x320700d7}},	//   ння_, _groo, mken, _tiny_,
   {{0x7c2201ac,0x236d01ad,0x4cc10033,0x69c501ae}},	//   _čorb, leej_, _শুধু, jihe,
   {{0x69c501af,0x6b9d01b0,0x61e101b1,0x6e2d01b2}},	//   dihe, _bosg, moll, _ewab,
   {{0xddcd01b3,0x63a901b4,0x20090019,0x6b9d01b5}},	//   _graž, nken, _giai_, _cosg,
   {{0x6b6301b6,0x799c01b7,0x63a901b8,0x6b9d01b9}},	// [0a0] ыкта, _porw, iken, _dosg,
   {{0x61e101ba,0x236d01bb,0x63a901bc,0x69c501bd}},	//   noll, heej_, hken, gihe,
   {{0x63a901be,0x799c01bf,0x6b9d01b5,0x7c960037}},	//   kken, _vorw, _fosg, _أشخا,
   {{0x63a901c0,0x61e101c1,0x236d01c2,0x1bba01c3}},	//   jken, holl, jeej_, _راجع_,
   {{0x61e101c4,0x63a901c5,0x9980013f,0x69c501c6}},	//   koll, dken, usių_, bihe,
   {{0x63a901c7,0x224d01c8,0x998000c6,0x00000000}},	//   eken, duek_, rsių_, --,
   {{0x186701c9,0x316c0181,0x61e101ca,0x63a901cb}},	//   _пари_, vedz_, doll, fken,
   {{0x628201cc,0x645c00bc,0x6f0900c4,0x00000000}},	//   _proo, _ärim, žeci, --,
   {{0x6d4101cd,0x224d0062,0x660801ce,0xd2570012}},	//   ólak, guek_, _tidk, нцэ_,
   {{0xbddb01cf,0x6e2d0193,0x628201d0,0x7abb00ca}},	//   trèm, _rwab, _vroo, פציו,
   {{0xddcd01d1,0x6e2d01d2,0x316c01d3,0x20090063}},	//   _praž, _swab, redz_, _piai_,
   {{0x645a01d4,0x63a901d5,0x657a01d6,0xd46900e3}},	//   _iqti, cken, _hath, _تحكم_,
   {{0x657a01d7,0x61e101d8,0xddcd01d9,0x69c501da}},	//   _kath, boll, _vraž, yihe,
   {{0x61e101db,0xd12f00bf,0x657a01dc,0x40940037}},	//   coll, _همه_, _jath, _للتر,
   {{0xddcd01dd,0x6b9d01de,0x628001df,0x657a01e0}},	//   _traž, _posg, lvmo, _math,
   {{0x657a01e1,0x6e2d01e2,0x6f0d01e3,0x25dc01e4}},	//   _lath, _twab, _ugac, मकुण,
   {{0x245a01e5,0x3df5013d,0xef64008f,0x6b9d01e6}},	// [0b0] hëm_, _изис, _също, _vosg,
   {{0x657a01e7,0xdb0d00e3,0x3eb301e8,0x63a901e9}},	//   _nath, mhaí, ıntı_, zken,
   {{0x69c501ea,0x63a901eb,0x6b9d01ec,0x00000000}},	//   rihe, yken, _tosg, --,
   {{0x69c501ed,0x657a01ee,0x00000000,0x00000000}},	//   sihe, _aath, --, --,
   {{0xe61800f3,0x8b9a00a1,0x8a1801ef,0x657a01f0}},	//   еді_, _חברת, _пояс_, _bath,
   {{0x657a01f1,0x61e101f2,0x6594004d,0x1a6801f3}},	//   _cath, xoll, лачу, _سیمی_,
   {{0x61e101f4,0x657a01f5,0x69d501c0,0x63a901f6}},	//   voll, _dath, _ijze, tken,
   {{0xc178013f,0x657a01f7,0x68e301bf,0x224d01e9}},	//   klės_, _eath, ündu, tuek_,
   {{0x61e101f8,0x853c0138,0xddcd0078,0x7d0801f9}},	//   toll, _plėt, _braż, _kérü,
   {{0x926400e3,0x236d01fa,0x777b01e9,0x657a01fb}},	//   اديم, seej_, _haux, _gath,
   {{0x63a901fc,0x224d01c8,0x00000000,0x00000000}},	//   pken, suek_, --, --,
   {{0x61e101fd,0x657a01fe,0x224d01ff,0x00000000}},	//   soll, _zath, puek_, --,
   {{0x61e10200,0x657a0201,0xddcd009e,0x00000000}},	//   poll, _yath, _fraż, --,
   {{0x61450202,0x777b00fe,0x61e10203,0x7e7600d8}},	//   _река, _laux, qoll, _vsyp,
   {{0xb02400ef,0xfce60070,0x1fb60204,0x2b3a00ae}},	//   _trườ, тово, _аспр, дязэ_,
   {{0x1e860205,0xf4130081,0x8e4a0037,0x9f420206}},	//   _алим, _সবার_, _قلبك_, blká_,
   {{0xc332004f,0x245a00dd,0xdcfe01d3,0x7eb80139}},	// [0c0] יון_, zëm_, _kopī, _dúpé,
   {{0xe9d70207,0x9f4000b3,0x2d950208,0xa923002d}},	//   вку_, _thió_, _брюс, идул,
   {{0x657a0209,0xdd05020a,0x777b020b,0x00000000}},	//   _rath, ăsăt, _baux, --,
   {{0x657a020c,0x7bda020d,0xe3b8020e,0xb09a006e}},	//   _sath, étud, _atın_, ויער,
   {{0xeb97020f,0x657a0210,0x49910103,0x00000000}},	//   _рия_, _path, _گیلر, --,
   {{0x245a01e5,0x7c3a0211,0x645c00bc,0xceb30142}},	//   tëm_, štru, _ärik, סיג_,
   {{0x629d0212,0x02ca0213,0x74140214,0x657a01fc}},	//   äson, ाप्न, دوبا, _vath,
   {{0x657a0060,0x07a30215,0x245a0216,0xc7a30217}},	//   _wath, _касн, rëm_, _киск,
   {{0xe737007e,0xa6650192,0x245a0052,0x7c290218}},	//   _шет_, _مطلو, sëm_, ćeri,
   {{0x657a00e3,0x601e00d9,0xd5fb020b,0x00000000}},	//   _uath, _līme, _trú, --,
   {{0x7f590219,0x9f35021a,0x8f35021b,0x255a0154}},	//   нанс_, лені, ленц, _vņlč_,
   {{0xdb0d00e3,0x1fa7021c,0x67f800b6,0xddcd0034}},	//   thaí, трог, bíje, _wraż,
   {{0xecdb000f,0x7c220031,0x798e0154,0xddcd009e}},	//   _मुजफ, _čora, _onbw, _traż,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d600c3,0xc17800c6,0x443c0072,0x3ead021d}},	//   _सदा_, slės_, nsv_, šet_,
   {{0x644a0037,0x7d080103,0x547b021e,0xbddb014b}},	//   irfi, _sérü, וטלו, guèr,
   {{0x62840138,0x777b021f,0x443c0095,0x443e020b}},	// [0d0] _šioj, _raux, hsv_, _lvt_,
   {{0x23b10220,0x395801b9,0x4c950221,0x70010134}},	//   _mája_, _ccrs_, _биос, _ịcha,
   {{0x29070222,0x98140037,0x4cc10033,0x443e0223}},	//   äna_, لبنا, _শুরু, _nvt_,
   {{0x9b9500d3,0x2cac0120,0xdb0d01ff,0x00000000}},	//   _симц, ødde_, piañ, --,
   {{0xadc40139,0x75ed0224,0x9f44020d,0x7bda020d}},	//   _arẹw, lúzi, ômé_, étue,
   {{0x6d550225,0x248500ec,0x2b5900e7,0xf48300cd}},	//   ngza, _prlm_, _hcsc_, لاعی,
   {{0xe8940226,0x69d80096,0x00000000,0x00000000}},	//   _карь, _मदती, --, --,
   {{0xaca30174,0x290700c6,0x443e0227,0x00000000}},	//   _abịd, žnas_, _dvt_, --,
   {{0x443e0228,0x36d5002d,0xddcf0206,0x00000000}},	//   _evt_, _соар, pucň, --,
   {{0xdb040037,0x2bc50134,0x67f80206,0x00000000}},	//   thiú, ịcha_, ríje, --,
   {{0xcea90130,0x8fa60229,0x443e0131,0x90c5022a}},	//   _צי_, гане, _gvt_, убне,
   {{0x261900fe,0xc5fb01c2,0xdb0f014b,0x3c18022b}},	//   _kèo_, ɓɓai_, _ulcè, _sčvo_,
   {{0xe1ee022c,0x2bc6022d,0x00000000,0x00000000}},	//   _гг_, रोफा, --, --,
   {{0x237d022e,0x261900de,0x5fc600aa,0x00000000}},	//   _hawj_, _mèo_, _लगवल, --,
   {{0xbb46022f,0x225f0230,0x2619020b,0x00000000}},	//   левк, ltuk_, _lèo_, --,
   {{0xc0520054,0x3a220167,0x6d5501cb,0x7c3c0231}},	//   _הזה_, _ptkp_, agza, rsrr,
   {{0x225f0232,0xdd040233,0x00000000,0x00000000}},	// [0e0] ntuk_, ırıs, --, --,
   {{0x237d01fa,0x6e2401e8,0x7c3e0234,0x44270167}},	//   _lawj_, _itib, _tvpr, kpn_,
   {{0xdca60235,0x601e00e8,0x00000000,0x00000000}},	//   _сани, _tīme, --, --,
   {{0x237d022e,0x26190023,0xfaff0052,0x6e24009e}},	//   _nawj_, _bèo_, _ibën_, _ktib,
   {{0x569400ae,0x443e0149,0xe5a60236,0xe5c60237}},	//   ралт, _svt_, лиди, лско,
   {{0x443e0238,0x281600cd,0x6e240239,0x644a0095}},	//   _pvt_, _موسس, _mtib, trfi,
   {{0xdd32013c,0x8cca023a,0x00000000,0x00000000}},	//   zəşt, _हेमो, --, --,
   {{0x7f44023b,0x9f42023c,0x644a023d,0xbebb0216}},	//   _ndiq, boké_, rrfi, mbëv,
   {{0x237d023e,0x6e24023f,0x27e60240,0x8556006f}},	//   _dawj_, _ntib, moon_, _مخاط,
   {{0xd6cf0241,0x27e60242,0x104a0243,0x237f007e}},	//   _عقل_, loon_, нями_, aduj_,
   {{0xb6030244,0x94260245,0x44a60246,0x2a6000aa}},	//   íšen, _смее, _حماق, htib_,
   {{0x27e60247,0x2a600248,0x23660141,0x00000000}},	//   noon_, ktib_, _uboj_, --,
   {{0x623400d3,0x44ce00a7,0x261900fe,0x6e2400d8}},	//   _телу, _hə_, _xèo_, _ctib,
   {{0x27e60249,0x63a2007a,0x2a790169,0x7bc6024a}},	//   hoon_, _hoon, _rssb_, _amku,
   {{0x63a2024b,0x27e6024c,0x6e240092,0x6d5501cb}},	//   _koon, koon_, _etib, rgza,
   {{0x764b0178,0x63a2024d,0x27e6024e,0x44ce00a7}},	//   yrgy, _joon, joon_, _mə_,
   {{0x27e60188,0x38c90018,0x44ce00a7,0x63a2024f}},	// [0f0] doon_, ھائی_, _lə_, _moon,
   {{0x63a20250,0x26180251,0x2bc60252,0x60d300d9}},	//   _loon, _पढ़ी_, रोबा, ņemš,
   {{0x44ce0253,0x27e60254,0x6d450255,0x26190154}},	//   _nə_, foon_, _idha, _sèo_,
   {{0x63a20256,0xbddb0257,0x27e60258,0x68ee01df}},	//   _noon, ssèd, goon_, _dybd,
   {{0x69cb0103,0x00000000,0x00000000,0x00000000}},	//   éges, --, --, --,
   {{0x9f420146,0xce3800ca,0x3a2900dc,0x7e6d012d}},	//   roké_, נאות_, mpap_, _mpap,
   {{0x63a20259,0x2905025a,0x9f42025b,0x27e60188}},	//   _boon, _àla_, soké_, boon_,
   {{0x44ce025c,0xc245025d,0x225f0103,0x261900fe}},	//   _də_, аник, ttuk_, _tèo_,
   {{0x63a2025e,0x6d45025f,0x7e6d00f9,0xa3d60096}},	//   _doon, _odha, _npap, _सदर_,
   {{0xb5fd00e9,0xaca30139,0x6d45001c,0xf4850260}},	//   _opši, _abọd, _ndha, _پائی,
   {{0x7e6d0261,0x63a20262,0x225f0263,0x237d006c}},	//   _apap, _foon, stuk_, _tawj_,
   {{0x6d450264,0x8e860265,0x63a20188,0xc49a0266}},	//   _adha, агме, _goon, _בשעת,
   {{0x7c250267,0x69c70268,0x44250095,0x20020095}},	//   _athr, _omje, _htl_, rmki_,
   {{0x63a20269,0x44ce00a7,0x291f026a,0x27e6026b}},	//   _zoon, _yə_, _şuan_, zoon_,
   {{0x63a2026c,0x417400cd,0x3079006e,0x27e6026d}},	//   _yoon, _دانس, _יאַנ, yoon_,
   {{0xaca3026e,0x63a2026f,0x23b10139,0x00000000}},	//   _gbọd, _xoon, _májo_, --,
   {{0x3f920270,0x6a8300d3,0x98b1022b,0x44250271}},	// [100] _inyu_, олта, _dezč_, _ltl_,
   {{0x27e60272,0x2a600273,0xd9460274,0x644100b6}},	//   woon_, rtib_, режи, _ovli,
   {{0xe73a0275,0x27e60276,0xb60700d9,0xa3c600c3}},	//   вее_, toon_, _mašī, _उगल_,
   {{0xd62a0277,0xc6a60131,0xb6cb0018,0xbebb0052}},	//   воде_, ирли, ھانے_, rbëv,
   {{0x27e60278,0x63a20279,0x6441027a,0x2bc6027b}},	//   roon_, _roon, _avli, रोणा,
   {{0xbebb01e5,0x27e6027c,0x4425027d,0x224d00aa}},	//   mbët, soon_, _btl_, drek_,
   {{0x4425027e,0x63a2027f,0x27e60280,0x88840281}},	//   _ctl_, _poon, poon_, _دیان,
   {{0x44ce0282,0x7bd60283,0x67f80220,0x660301fa}},	//   _və_, nnyu, bíja, amnk,
   {{0x6441008b,0xe57a0284,0x0ec50285,0xf6690286}},	//   _evli, _иза_, _लेंड, _محله_,
   {{0x63a20272,0x2bc60287,0xd5aa00aa,0x2ade007a}},	//   _woon, रोता, _कविज, _कुछु_,
   {{0x63a20288,0x09f70289,0x7e6d028a,0x00000000}},	//   _toon, שמים_, _spap, --,
   {{0xc4770054,0x224d028b,0x3f80001f,0x9f530233}},	//   _כתבו_, brek_, _caiu_, _ödül_,
   {{0x539b028c,0x4425028d,0x6d450085,0xef1f028e}},	//   _שידו, _ztl_, _pdha, rcü_,
   {{0xdb0d0161,0x4425026a,0x3f92010a,0x3f82028f}},	//   lhaç, _ytl_, _enyu_, adku_,
   {{0x8bc70290,0xab950291,0xd138007f,0x00000000}},	//   асад, бављ, ając_, --,
   {{0x69c70292,0x5b150293,0xdb0d016d,0xaca40294}},	//   _smje, смат, nhaç, chọi,
   {{0x2fc901f7,0x6d410088,0x7e6d0295,0x2bc60296}},	// [110] _imag_, ólas, _upap, रोधा,
   {{0x6d450297,0x67f80031,0x7bd6010a,0x61e80298}},	//   _udha, víja, anyu, nodl,
   {{0x4dda00ca,0x00000000,0x00000000,0x00000000}},	//   _תחתו, --, --, --,
   {{0x44250299,0x61e80074,0x93bc020a,0x224d0233}},	//   _rtl_, hodl, _stăn, yrek_,
   {{0x7bcd013f,0x2d81007a,0x2d83029a,0xbebb0052}},	//   miau, _kahe_, odje_, mbës,
   {{0x69c7029b,0x2d83029c,0x7bcd01b3,0x2d81029d}},	//   _umje, ndje_, liau, _jahe_,
   {{0xf773029e,0x2d81029f,0x58d402a0,0x776902a1}},	//   _وار_, _mahe_, _дорт, _tbex,
   {{0x224d02a2,0x7bcd013f,0x2d8100aa,0xe3b102a3}},	//   trek_, niau, _lahe_, ثرت_,
   {{0x6aad02a4,0x27ed02a5,0x27ff02a6,0x113900c6}},	//   nyaf, _iken_, _ihun_, ляны_,
   {{0x224d02a7,0x3f8002a8,0x2d830126,0x61e802a9}},	//   rrek_, _saiu_, jdje_, godl,
   {{0x600a02aa,0x7bcd02ab,0x25a5009c,0x27ed02ac}},	//   лном_, kiau, _ioll_, _kken_,
   {{0x25a502ad,0x224d02ae,0xdb0d0161,0x2d83029a}},	//   _holl_, prek_, chaç, edje_,
   {{0x216902af,0x25a50149,0x4ac702b0,0x7bcd02b1}},	//   _били_, _koll_, _रेलव, diau,
   {{0x2d830292,0x63bb02b2,0x2fc900ae,0x412602b3}},	//   gdje_, lhun, _emag_, _лошо_,
   {{0x27ff02b4,0x27ed02b5,0x2d8101c2,0x70550103}},	//   _ohun_, _oken_, _dahe_, _انعا,
   {{0x7bcd013f,0x3f9200ec,0x2d83029a,0x69d70072}},	//   giau, _unyu_, adje_, enxe,
   {{0xdb1d02b6,0xe9da02b7,0x63bb02b8,0xdb0f0131}},	// [120] _omsæ, гка_, ihun, _alcâ,
   {{0x645c02b9,0x27ff0139,0x25a502ba,0x27ed02bb}},	//   _årig, _ahun_, _noll_, _aken_,
   {{0x6c860080,0x27ff02bc,0x63bb0060,0x7bcd013f}},	//   _الجم, _bhun_, khun, biau,
   {{0x27ff02bd,0x7bcd02be,0x628b02bf,0xb73a00e3}},	//   _chun_, ciau, _orgo, اثاء_,
   {{0x63bb02c0,0x95ca02c1,0x27ff01f7,0x25a502c2}},	//   dhun, лука_, _dhun_, _boll_,
   {{0x6b8402c3,0x27ff02c4,0x27ed02c5,0x7a4102c6}},	//   ldig, _ehun_, _eken_, sátý,
   {{0x31cd00c7,0x628b02c7,0x61e802c8,0x6d5e01ff}},	//   রকাশ, _argo, vodl, _mcpa,
   {{0x63bb02c9,0xd5440139,0x2d8302ca,0x61e802cb}},	//   ghun, _bẹ̀w, zdje_, wodl,
   {{0xd13000e3,0x1a9a00c1,0x6b8402cc,0x25a502cd}},	//   ومة_, ריִע, idig, _foll_,
   {{0x361b00a1,0x2fc902ce,0x154302cf,0x25a500f0}},	//   _עובד, _smag_, _неум, _goll_,
   {{0x63bb02d0,0x2d8300e7,0x20120027,0x741602d1}},	//   bhun, vdje_, _biyi_, _اوصا,
   {{0x63bb02d2,0x753a0126,0xf8b300a1,0x61e802d3}},	//   chun, _hetz, פשר_, sodl,
   {{0x6b8402d4,0xa3e502d5,0xddc40220,0x2d810167}},	//   ddig, पकर_, _spiš, _pahe_,
   {{0x753a02d6,0x6b8402d7,0x6d5e00b3,0x0dc802d8}},	//   _jetz, edig, _ccpa, буси_,
   {{0x7bcd02d9,0x2d8302da,0x6b840188,0x753a02db}},	//   tiau, rdje_, fdig, _metz,
   {{0x753a02dc,0xddc402dd,0x5c0702de,0x2fc902df}},	//   _letz, _vpiš, сяга, _umag_,
   {{0x7bcd01b3,0x6e3602e0,0x0dcb02e1,0x6eff0139}},	// [130] riau, _gwyb, _буни_, _dàbí,
   {{0x753a02e2,0x213e01f7,0x7bcd02e3,0x6b8402e4}},	//   _netz, nath_, siau, adig,
   {{0x63bb02e5,0xddc402e6,0x6aad02e7,0x27ff00de}},	//   yhun, _upiš, syaf, _phun_,
   {{0x25a502dc,0x64c302e8,0x63bb02e9,0x00000000}},	//   _soll_, _वेगळ, xhun, --,
   {{0xb5fd02ea,0x25a502eb,0x959902ec,0x1c1f02ed}},	//   _opšt, _poll_, итку_, _मंडल_,
   {{0x7afd02ee,0x7dc902ef,0x59dd02f0,0x3c1802f1}},	//   _izst, džsk, _मदिर, _sčvi_,
   {{0x63bb0060,0x25a501bf,0x27ff02f2,0x799501bf}},	//   thun, _voll_, _thun_, _inzw,
   {{0x27ed004d,0x628b0218,0x753a01cb,0xb22502f3}},	//   _uken_, _prgo, _eetz, омил,
   {{0x25a502f4,0x7d000065,0x753a02f5,0x00000000}},	//   _toll_, _kárí, _fetz, --,
   {{0x63bb02f6,0x628b02f7,0xdb1d01cd,0x6b8400ad}},	//   shun, _vrgo, _umsæ, zdig,
   {{0xc95202f8,0x6b8402f9,0x63bb019f,0x673b02fa}},	//   ומי_, ydig, phun, _keuj,
   {{0x628b02fb,0xe3b302fc,0x661b02fd,0x644302fe}},	//   _trgo, _عرض_, _kuuk, msni,
   {{0x614502ff,0x333f025a,0x64430300,0x661b00aa}},	//   _дела, maux_, lsni, _juuk,
   {{0x6d410301,0x661b0302,0x00000000,0x00000000}},	//   ólap, _muuk, --, --,
   {{0x8fa60303,0x64430304,0xdb1d0149,0x70520037}},	//   _маке, nsni, _omsä, _قنوا,
   {{0x6b840305,0x333f0257,0xbebb023b,0x64430306}},	//   udig, naux_, rbër, isni,
   {{0x49ca0307,0x7d000065,0x37cf0033,0xba290308}},	// [140] алан_, _bárí, িকার, مسلم_,
   {{0x6b840309,0x23b801dc,0xf7830090,0x63b9030a}},	//   sdig, _méja_, _leħħ_, _llwn,
   {{0xdb06023b,0xa2cb030b,0x3e64030c,0x6443030d}},	//   _kokë, _तेस्, löt_, jsni,
   {{0x6d5c030e,0x753a030f,0xbddb0310,0x68400139}},	//   lgra, _setz, nsèn, _aádá,
   {{0x25e6007d,0x3e640311,0x2b400312,0x7c2e0313}},	//   टवली_, nöt_, maic_, lpbr,
   {{0x27380028,0x67220314,0xc7b90103,0xd639004d}},	//   ẩn_, scoj, _elő_, сяці_,
   {{0xe73a0315,0x263600a5,0x68300065,0x6d5c0316}},	//   _веб_, sło_, _dòdò, igra,
   {{0x66e60317,0x938a0318,0x2b400037,0x6d5c0319}},	//   _доба, рска_, naic_, hgra,
   {{0x386d031a,0x00000000,0x00000000,0x00000000}},	//   _ćeri_, --, --, --,
   {{0x23b800fd,0x6d5c031b,0x68300139,0x628400c6}},	//   _déja_, jgra, _gòdò, _šios,
   {{0x213e031c,0x6d5c031d,0xc486031e,0x661b0172}},	//   rath_, dgra, _флек, _zuuk,
   {{0xa2cb02e8,0x333f0257,0x442e031f,0x64580320}},	//   _तेव्, caux_, mpf_, muvi,
   {{0xdefb00c6,0x64580321,0x2294008f,0xdcfe0322}},	//   рын_, luvi, _хиля, _dapč,
   {{0x6d5c0323,0xe2a9015a,0x29180324,0xdce50325}},	//   ggra, _دامن_, _ngra_, _abhā,
   {{0x5ba70326,0xe0d400c1,0x602101d3,0x3b280294}},	//   ораз, _מײַ_, _tēma, _ọyị_,
   {{0x6d5c0080,0xc0530327,0xdb0f0328,0x2d9e0212}},	//   agra, _חזק_, _alcá, öter_,
   {{0x2bbc007d,0x201c00aa,0x64580329,0x7c2e02ac}},	// [150] _ईतरा, _huvi_, huvi, apbr,
   {{0x644302fe,0x6458032a,0x661b032b,0xdce7007f}},	//   ysni, kuvi, _ruuk, zeję,
   {{0xe7190037,0x333f00fd,0xf8b10281,0x7d7a00ca}},	//   ميات_, yaux_, رکس_, _הנתו,
   {{0x6c7a00c1,0x661b032c,0x5c7a006e,0x2cac0212}},	//   _פארפ, _puuk, _פארה, ädde_,
   {{0x333f025a,0x7afd00d9,0xcb9a00a1,0xa5f9032d}},	//   vaux_, _uzst, _הסרט, беду_,
   {{0x6443032e,0x201c001f,0xdb040042,0x3d19007f}},	//   tsni, _ouvi_, chiñ, _दलों_,
   {{0x201c02e5,0x333f0257,0x2246032f,0x64580330}},	//   _nuvi_, taux_, _avok_, guvi,
   {{0x64430331,0x3a390332,0x661b0333,0x3e64007b}},	//   rsni, _kwsp_, _tuuk, yöt_,
   {{0x64430222,0x6d5c0334,0x333f0257,0xdb060113}},	//   ssni, ygra, raux_, _cokè,
   {{0x644301b3,0x201c0172,0x2b40020a,0x23b10206}},	//   psni, _buvi_, zaic_, _máji_,
   {{0x6d5c0335,0x645c007a,0x333f00fd,0x6458020a}},	//   vgra, _ärip, paux_, cuvi,
   {{0xbebb023b,0x201c002b,0x3e6400c2,0xb4fa00ca}},	//   rcën, _duvi_, töt_, _הפעי,
   {{0x3fc9001c,0xcaea0336,0x6d5c0337,0xbddb00b3}},	//   تگوی_, _झुंड_, tgra, trèp,
   {{0xda1f0251,0x6d5c0338,0x3e640339,0x00000000}},	//   _बढ़त_, ugra, röt_, --,
   {{0x9f92033a,0xdb06023b,0x2246033b,0x3156006e}},	//   lší_, _tokë, _zvok_, _זיצן_,
   {{0x65610124,0x9f420094,0x3a2b033c,0x00000000}},	//   _lclh, boká_, _btcp_, --,
   {{0x6e4600e3,0x9f92033d,0x6d5c033e,0x2b40033f}},	// [160] _عندم, nší_, pgra, raic_,
   {{0x2b400340,0x64580027,0x00000000,0x00000000}},	//   saic_, yuvi, --, --,
   {{0x9d1b00c1,0x9f920031,0x00000000,0x00000000}},	//   _לויט, hší_, --, --,
   {{0xdc9b0341,0x6b5a00ae,0x2cbe0342,0x00000000}},	//   _היטל, _ушор_, ıydı_, --,
   {{0x9f920343,0x7f8d006e,0x656d0344,0x256f0345}},	//   jší_, ינאַ, đahn, kılı_,
   {{0x64580346,0x8afb00a1,0x9f92033d,0x00000000}},	//   tuvi, _להכי, dší_, --,
   {{0x80d000c7,0x69ce0347,0xdd57006e,0x00000000}},	//   _সুন্, _imbe, לבסט_, --,
   {{0x64580348,0xdb060036,0x7d070349,0xc8db00d7}},	//   ruvi, _pokè, léré, _הקלט,
   {{0x201c034a,0x6b86034b,0xd046013c,0x00000000}},	//   _suvi_, _makg, əmək, --,
   {{0x7d0700fd,0x9f4200d4,0x00000000,0x00000000}},	//   néré, voká_, --, --,
   {{0x69ce005c,0x2615034c,0xf99300ca,0x00000000}},	//   _mmbe, _फूटी_, גרת_, --,
   {{0x09b9034d,0x6028030b,0x78fb006e,0x57da0034}},	//   _इत्य, _něme, מפיו, _भदोह,
   {{0x69ce034e,0x9f4b034f,0x00000000,0x00000000}},	//   _ombe, nocé_, --, --,
   {{0x9f420146,0x442c0350,0x00000000,0x00000000}},	//   roká_, _ktd_, --, --,
   {{0x9f42025b,0x6b860351,0x7d070352,0x00000000}},	//   soká_, _bakg, déré, --,
   {{0x69ce0353,0x23cf0354,0x23b80139,0x00000000}},	//   _ambe, तोपद, _méjo_, --,
   {{0x3edf0129,0xdcf200d9,0x6b860355,0x442c00ca}},	// [170] _kpọọ_, īgāk, _dakg, _ltd_,
   {{0x6e2d0356,0xceb200c1,0xaca30134,0x64480357}},	//   _itab, _סיי_, _asụg, _ovdi,
   {{0xa3be0034,0xd7fb0358,0xf1b3006e,0x442c0227}},	//   ीफा_, буд_, עסע_, _ntd_,
   {{0x69ce0359,0x256f008b,0x68f50146,0x6282035a}},	//   _embe, zılı_, _vyzd, _osoo,
   {{0xd2460068,0x6448035b,0x442c035c,0x256f01e8}},	//   _جن_, _avdi, _atd_, yılı_,
   {{0xcb120054,0x9f92035d,0x68f50220,0x93b50023}},	//   _שלך_, vší_, _tyzd, _cũn,
   {{0x6282035e,0x2409035f,0xa5060360,0x00000000}},	//   _asoo, онки_, меша_, --,
   {{0x9f92030b,0x6e2d0361,0xdcfe01d3,0xc2e60033}},	//   tší_, _otab, _japā, খেছি_,
   {{0x6e2d023f,0x2a690362,0xd7660103,0x672902a1}},	//   _ntab, ntab_, _تنقی, _ifej,
   {{0x9f920363,0xab5b0364,0x442c0365,0xdcfe00e8}},	//   rší_, _flüg, _ftd_, _lapā,
   {{0xd37100e3,0x6e2d0366,0x256f0367,0xe7c402d5}},	//   _لها_, _atab, rılı_, लोकप,
   {{0x9f920368,0x2a690369,0x672902a1,0x256f0233}},	//   pší_, ktab_, _jfej, sılı_,
   {{0xee37036a,0x6e2d009c,0x63ab036b,0xa294036c}},	//   мня_, _ctab, _iogn, _паці,
   {{0x79870067,0x6e2d0037,0x6b86036d,0x00000000}},	//   _najw, _dtab, _sakg, --,
   {{0x6e2d036e,0x2c8700b6,0x98ba0325,0x7f4d0090}},	//   _etab, vídá_, kapā_, _fdaq,
   {{0xeb97036f,0x67290090,0x00000000,0x00000000}},	//   мис_, _nfej, --, --,
   {{0x63ab0370,0x63a60222,0xf1e1023a,0x6b860371}},	// [180] _mogn, ökni, _पदान, _vakg,
   {{0x63ab01ab,0x7bcf0372,0x00000000,0x00000000}},	//   _logn, _emcu, --, --,
   {{0x7649020d,0x6b860113,0x2d9a0231,0xe78602e1}},	//   _avey, _takg, _inpe_, дуло,
   {{0x442c0373,0x2a69023e,0xb7be0033,0x61aa0374}},	//   _rtd_, btab_, েক্ট, _चक्ष,
   {{0x4cd30081,0x442c0375,0x4733004d,0x7d07020d}},	//   _দুপু, _std_, тніс, péré,
   {{0x69ce0376,0x442c0332,0x63ab009c,0x56930095}},	//   _umbe, _ptd_, _aogn, ташт,
   {{0x442c016d,0x644d01d3,0x76490154,0x6282010a}},	//   _qtd_, ņain, _evey, _ssoo,
   {{0x63ab0377,0xae1e0285,0x00000000,0x00000000}},	//   _cogn, पदान_, --, --,
   {{0xe7bd0378,0x52140379,0x2d9a037a,0x63ab037b}},	//   ्फरप, ндит, _onpe_, _dogn,
   {{0x442c0167,0x602802c6,0x6e2d0090,0x2d8a0141}},	//   _ttd_, _němc, _rtab, jdbe_,
   {{0x39570054,0x63ab037c,0x195700ca,0x00000000}},	//   ושים_, _fogn, וביל_, --,
   {{0x62820197,0xe29a01b3,0x26c6023e,0x63ab0036}},	//   _tsoo, _мае_, ozoo_, _gogn,
   {{0xdde2037d,0x26c6037a,0x31c6037e,0x00000000}},	//   _šušk, nzoo_, _оскв, --,
   {{0xe0cf037f,0x63ab0380,0x69de0381,0x00000000}},	//   ازی_, _zogn, jnpe, --,
   {{0xdb060018,0x7987022b,0x00000000,0x00000000}},	//   _elkü, _rajw, --, --,
   {{0x2a690382,0x2cac0212,0x3eae0052,0x2d9a0383}},	//   ttab_, ädda_, ëjtë_, _enpe_,
   {{0x6e2d0384,0x27ef01df,0xef1f0367,0x26c601fa}},	// [190] _utab, vogn_, ndüm_, jzoo_,
   {{0x2a690385,0x67290090,0x3df4007b,0x00000000}},	//   rtab_, _sfej, _изыс, --,
   {{0x2a690006,0x917b0023,0x2251007f,0x998f01f9}},	//   stab_, _hệ_, ązki_, égű_,
   {{0x2a690383,0xaad00386,0x7bcf019f,0x00000000}},	//   ptab_, _सेवक, _umcu, --,
   {{0xcb360054,0x79870387,0x63ab0388,0x1fc10033}},	//   _ראשי_, _tajw, _rogn, _উদাস,
   {{0x63ab0389,0x6594038a,0x05790076,0x00000000}},	//   _sogn, качу, سمعة_, --,
   {{0x672902a1,0x917b020b,0x00000000,0x00000000}},	//   _tfej, _lệ_, --, --,
   {{0x26c601fa,0x7c2a0231,0x00000000,0x00000000}},	//   bzoo_, _éfre, --, --,
   {{0x645c038b,0x63ab038c,0xd24e0190,0x00000000}},	//   _årin, _vogn, مني_, --,
   {{0x63ab0381,0x00000000,0x00000000,0x00000000}},	//   _wogn, --, --, --,
   {{0x6724038d,0x63ab038e,0xddcb0233,0xe0d600ae}},	//   žije, _togn, _şişe, евэ_,
   {{0x8fa600b4,0x00000000,0x00000000,0x00000000}},	//   хаме, --, --, --,
   {{0xf1a800d1,0xe299038f,0x00000000,0x00000000}},	//   سایه_, _хал_, --, --,
   {{0x92c10390,0xdd920391,0xc0e50392,0x7bdf0393}},	//   ığın, دوس_, _полк, enqu,
   {{0xfce30394,0xddcd00d3,0x61e60103,0xeb9a0395}},	//   горо, _spaţ, ékle, пив_,
   {{0xa2d4007d,0x7a16022b,0xfaa601b6,0x00000000}},	//   _बेड्, _pņto, набо, --,
   {{0xf41200c1,0xdb060383,0x39560396,0xfbd1030b}},	// [1a0] רפן_, _alkò, ењет, _सगरम,
   {{0xac860396,0x26c6023e,0x6f040201,0xdcfe00ae}},	//   _згол, vzoo_, _izic, _capă,
   {{0xa81a0397,0x2fc001ff,0xc17200ca,0x00000000}},	//   ستار_, _klig_, רחב_, --,
   {{0xfaa60398,0xe6660399,0x00000000,0x00000000}},	//   _замо, етко, --, --,
   {{0x98ac0092,0x91b40034,0x7bd6039a,0x25ac00d8}},	//   ğlıq_, ेसमै, miyu, _podl_,
   {{0xe5a3039b,0x7bd6039c,0x98ac0092,0x2fc000ee}},	//   личи, liyu, şlıq_, _llig_,
   {{0xdbe30032,0x26c6023e,0xa3cc039d,0x3c3e02c6}},	//   _béèn, szoo_, रफल_, nův_,
   {{0x7bd6039e,0x6f04039f,0x00000000,0x00000000}},	//   niyu, _ozic, --, --,
   {{0x66e303a0,0x60c401c2,0x6aa40072,0x6f040169}},	//   _бота, _ƙimo, nxif, _nzic,
   {{0x64a603a1,0xb5ca0068,0xbbad03a2,0xef1f03a3}},	//   _паза, _عوام_, _टक्क, rdüm_,
   {{0xdb120088,0x3f8903a4,0x6f0403a5,0x7f5903a6}},	//   _ágæt, _paau_, _azic, манс_,
   {{0x64580218,0x00000000,0x00000000,0x00000000}},	//   mrvi, --, --, --,
   {{0x661a03a7,0x644a0324,0x2e2603a8,0x7bc403a9}},	//   _kitk, lsfi, _côf_, dhiu,
   {{0x661a03aa,0x9f4b030b,0x917b00fe,0x00000000}},	//   _jitk, mocí_, _vệ_, --,
   {{0x317e03ab,0x661a03ac,0xb3a400df,0x7bd60167}},	//   metz_, _mitk, _खचाख, fiyu,
   {{0x7bc403ad,0x7bdf00e5,0xd1380138,0x317e03ae}},	//   ghiu, unqu, lbą_, letz_,
   {{0x66d30068,0x9f4b0314,0x443e0085,0x6d5a0076}},	// [1b0] _műkö, nocí_, _lwt_, ótac,
   {{0x661a03af,0xd8e703b0,0x317e0364,0x644a03b1}},	//   _nitk, нцеп, netz_, ksfi,
   {{0x6d4703b2,0x20090028,0xa3c003b3,0x201b014b}},	//   maja, _khai_, ँसा_, _épis_,
   {{0x6d4703b4,0x2009023e,0x7bc403b5,0x661a03b6}},	//   laja, _jhai_, chiu, _aitk,
   {{0x661a03b7,0x6b9d03b8,0x6b8d03b9,0x46a4004d}},	//   _bitk, _insg, mdag, лаїв,
   {{0x6d4703ba,0xb90700c7,0x443e03bb,0xab5b0364}},	//   naja, _পর_, _bwt_, _flüc,
   {{0xab5b02e2,0x80d00081,0x443e03bc,0x644a03bd}},	//   _glüc, _সুস্, _cwt_, gsfi,
   {{0x6d4702dd,0x69d703be,0xe65d01e8,0xe29903bf}},	//   haja, lixe, ştığ, даи_,
   {{0xdb0f015e,0x24850063,0x6b8d02ac,0x661a00d8}},	//   _alcú, _wslm_, idag, _fitk,
   {{0x6d4703c0,0x27fd00f0,0x93bc020a,0x2fc0009c}},	//   jaja, llwn_, _stăt, _slig_,
   {{0x6d4703c1,0x2fc001bb,0xf99203c2,0x443e03c3}},	//   daja, _plig_, ברי_, _gwt_,
   {{0x200903c4,0x6b8d01c0,0xc3cb03c5,0x661a0381}},	//   _chai_, jdag, _عظام_, _zitk,
   {{0x63a9029b,0x93b60054,0x6b8d032e,0xddcd03c6}},	//   mjen, _שלנו_, ddag, _spaš,
   {{0x6d4703c7,0x7bd60193,0x65630023,0xfce603c8}},	//   gaja, wiyu, ngnh, вого,
   {{0x22510034,0x7bd60169,0x69d70072,0x2009009c}},	//   ązku_, tiyu, dixe, _fhai_,
   {{0x63a903c9,0x63bb03ca,0x6b8d03cb,0x1621030b}},	//   njen, nkun, gdag, मदार_,
   {{0x6d4703cc,0x395100e7,0x4b2300d6,0x63bb03cd}},	// [1c0] baja, _bdzs_, рмув, ikun,
   {{0x6d4703ce,0x63a903cf,0x2bc60034,0x76590150}},	//   caja, hjen, रोजा, drwy,
   {{0x63bb03d0,0x63a903d1,0x661a03d2,0x6e2403d3}},	//   kkun, kjen, _ritk, _huib,
   {{0x6e240051,0x7bd6005c,0x63a903d4,0x661a03d5}},	//   _kuib, qiyu, jjen, _sitk,
   {{0x63a903d6,0x661a02fd,0x443e03d7,0x765902ad}},	//   djen, _pitk, _swt_, grwy,
   {{0x69c503d8,0xd49a03d9,0x98660103,0x645803da}},	//   chhe, дри_, _لیئے_, trvi,
   {{0x2cb8009c,0x18a303db,0x98a30231,0x6e2403dc}},	//   nyrd_, _карм, _кире, _luib,
   {{0x63a903dd,0x63bb03de,0x6d4703df,0xef1f03e0}},	//   gjen, gkun, zaja, rdük_,
   {{0xfbd30054,0x200902ad,0x6d4703e1,0x661a03e2}},	//   יתה_, _rhai_, yaja, _titk,
   {{0xa3f5000d,0x661a0305,0x200903e3,0x8af000a7}},	//   ější_, _uitk, _shai_, lgəs,
   {{0x6d4703e4,0x63a903e5,0xd138013f,0x200900de}},	//   vaja, bjen, rbą_, _phai_,
   {{0x317e01bf,0x63bb02e2,0x6d4703e6,0x63a903e7}},	//   setz_, ckun, waja, cjen,
   {{0x6d4703e8,0x6e2403e9,0x00000000,0x00000000}},	//   taja, _cuib, --, --,
   {{0x6e2403ea,0x69d703eb,0xbf9b02ac,0x00000000}},	//   _duib, xixe, dlêe, --,
   {{0x6d4703ec,0x80a303ed,0x6b8d03ee,0x7640022e}},	//   raja, _نمون, tdag, _lwmy,
   {{0x5f7703ef,0x20090051,0x6d4703f0,0x8bc4004b}},	//   _شاعر, _uhai_, saja, асуд,
   {{0x6d4703f1,0xf96b03f2,0xfaff0216,0x6e2400fc}},	// [1d0] paja, дрей_, _ecën_, _guib,
   {{0x63bb03f3,0x6b8d032e,0x68fc03f4,0x7e6d0372}},	//   zkun, sdag, _byrd, _iqap,
   {{0x3eb903f5,0x69d703f6,0xa2d4014e,0x6b8d004d}},	//   lyst_, rixe, _बेस्, pdag,
   {{0x765902ad,0x69c50052,0xe115006e,0x7c2a0113}},	//   trwy, shhe, אַנז_, _éfra,
   {{0x6d4503f7,0xe78403f8,0x63a903f9,0x61e100f0}},	//   _keha, рухо, vjen, ynll,
   {{0x6d4503fa,0xa93403fb,0xa50903fc,0x63bb029a}},	//   _jeha, _верш, нела_, wkun,
   {{0x63a903fd,0x7afd03fe,0x63bb03ff,0x69d50090}},	//   tjen, _hyst, tkun, _imze,
   {{0x7afd0400,0x93bc00ae,0x9f420031,0x6d450401}},	//   _kyst, _stăr, sokú_, _leha,
   {{0x63a90402,0x59b70403,0x00000000,0x00000000}},	//   rjen, _आकार, --, --,
   {{0x63bb0404,0x6d450405,0x63a90406,0x004701f9}},	//   skun, _neha, sjen, نیتي_,
   {{0x7afd0407,0x04670408,0x1c1f0409,0x63a902a1}},	//   _lyst, _штам, _मंगल_, pjen,
   {{0xdb0f0396,0xc43a040a,0x442500d3,0xdb06040b}},	//   _você, _נתני, _iul_, _loká,
   {{0x4425040c,0x6d45040d,0x69d5040e,0x7afd040f}},	//   _hul_, _beha, _omze, _nyst,
   {{0x44250410,0x61450396,0x4ed5004d,0x42520411}},	//   _kul_, _сека, рюют, _انور,
   {{0x224d0412,0x44250413,0x6d450414,0x7e6d0415}},	//   lsek_, _jul_, _deha, _eqap,
   {{0x7afd0094,0x44250006,0x2d8c0416,0x7dd40092}},	//   _byst, _mul_, žde_, _müsə,
   {{0x7afd0150,0xdcfc025b,0x44250417,0xa95a00b9}},	// [1e0] _cyst, merč, _lul_, فجار_,
   {{0x6d450418,0x7afd0419,0x3f82041a,0xd5b10023}},	//   _geha, _dyst, leku_, _nó_,
   {{0xdb060074,0x7afd041b,0x31ba00c1,0x9f4b016d}},	//   _doká, _eyst, עזענ, locá_,
   {{0x6d4502a7,0x224d01e8,0x3f8200aa,0x46ea001f}},	//   _zeha, ksek_, neku_, нден_,
   {{0x7f3b00c1,0x7afd0150,0x68fc00f0,0x6441041c}},	//   גענו, _gyst, _wyrd, _awli,
   {{0x4425041d,0xd5b10019,0x6594041e,0x7434041f}},	//   _bul_, _có_, раку, анкф,
   {{0x44250420,0xe56f0214,0xd4670291,0x88840421}},	//   _cul_, سطو_, гије_, _خیان,
   {{0x44250422,0x3f8203c6,0x53980423,0x93b40424}},	//   _dul_, jeku_, твия_, рбиц,
   {{0xbebb023b,0x224d00f9,0xdb060103,0x798e0425}},	//   ncët, gsek_, _elkö, _kabw,
   {{0xc05a0426,0x602100d9,0x44250427,0xdb0f0428}},	//   нім_, _lēmu, _ful_, _docè,
   {{0x44250429,0x798e042a,0x09f70289,0x224d0062}},	//   _gul_, _mabw, רמים_, asek_,
   {{0x6d45042b,0xddc40090,0x6d5a0301,0x7c25042c}},	//   _seha, _epiż, ótan, _ruhr,
   {{0x6d45042d,0x4425042e,0x00000000,0x00000000}},	//   _peha, _zul_, --, --,
   {{0xbb1b025a,0x4425042f,0x7afd0430,0x798e0198}},	//   _maît, _yul_, _ryst, _nabw,
   {{0x6d450431,0x44250432,0x3ebf0433,0x48bf0033}},	//   _veha, _xul_, šut_, _আশ্র,
   {{0xc4c40434,0x7afd0084,0x246e0092,0x798e010a}},	//   _ہے_, _pyst, _cəmi_, _aabw,
   {{0x6d45007a,0x798e0435,0x2d85020d,0x79d5004d}},	// [1f0] _teha, _babw, ôles_, ажає,
   {{0x7afd0436,0xdcf501d3,0x2b490072,0x00000000}},	//   _vyst, udzē, saac_, --,
   {{0x7afd0067,0x2d83023f,0xd7c8001c,0xdb060437}},	//   _wyst, meje_, گونه_, _voká,
   {{0x31e10438,0x2d830439,0x7afd043a,0xe71900e3}},	//   _पद्ध, leje_, _tyst, نيات_,
   {{0x4425043b,0xa2d4000c,0x98aa01d3,0xd7c80286}},	//   _sul_, _बेल्, ējām_, دونه_,
   {{0x44250092,0x2d83043c,0xf4830260,0xa3d2030b}},	//   _pul_, neje_, ماعی, होस_,
   {{0x4425043d,0x00000000,0x00000000,0x00000000}},	//   _qul_, --, --, --,
   {{0x4425043e,0xddc4043f,0xdb1d0088,0x2d830440}},	//   _vul_, _spiż, _umsó, heje_,
   {{0x6b8f0441,0x290c00e3,0xae150442,0x2d830443}},	//   _macg, _údar_, णगान_, keje_,
   {{0x2d830444,0x44250445,0x224d0446,0x41b5008f}},	//   jeje_, _tul_, rsek_, рсит,
   {{0x2d830447,0x66ca0018,0x44250188,0x00000000}},	//   deje_, _töké, _uul_, --,
   {{0xe0d60448,0x224d0449,0xbddb03a9,0x52d9007b}},	//   рвю_, psek_, ksès, _имею_,
   {{0x2bc900b7,0x00000000,0x00000000,0x00000000}},	//   रसना, --, --, --,
   {{0x3f82044a,0x2d8302a4,0x628b0188,0xdce50154}},	//   seku_, geje_, _isgo, _echč,
   {{0xdd0e026a,0x8c46044b,0x93bc044c,0x798e0154}},	//   _dışa, ребе, _ouăl, _rabw,
   {{0xc05200a1,0x798e044d,0xb7b00033,0x00000000}},	//   _וזה_, _sabw, _কষ্ট, --,
   {{0xeab7044e,0x09c10033,0x2d83044f,0x00000000}},	// [200] айт_, োচনা, beje_, --,
   {{0xf0a90065,0xdebb021e,0x00000000,0x00000000}},	//   _gbàà_, _סמיל, --, --,
   {{0xdca60450,0x6e220451,0xc8ca0452,0x798e010a}},	//   _тани, _èobb, خوان_, _vabw,
   {{0x6e93010d,0x628b00f0,0x798e0453,0x00000000}},	//   _الیا, _osgo, _wabw, --,
   {{0xb8fd0454,0x23a90455,0x6b840456,0xe5340457}},	//   _ते_, कानद, meig, бель,
   {{0xb8660018,0x6b840458,0x00000000,0x00000000}},	//   _پاسو, leig, --, --,
   {{0x92e200c7,0x29270220,0x03c60459,0x628b01ee}},	//   _ধরে_, ávať_, исим, _asgo,
   {{0x0fc10081,0x6b84045a,0x290a045b,0x87f900ae}},	//   _উদ্ধ, neig, _izba_, _бэут_,
   {{0x27e60009,0x2d83045c,0xc1a600f6,0xa3c70409}},	//   mnon_, yeje_, ајни, _उतर_,
   {{0x6b84045d,0x2259045e,0xda16045f,0x629900eb}},	//   heig, áska_, थगित_, _drwo,
   {{0x628b0460,0x60cd03e3,0xc9530327,0x5f9500ae}},	//   _esgo, _ƙama, חמת_, бинт,
   {{0x27e60461,0xa3d20409,0x6b840462,0x2d830463}},	//   nnon_, होश_, jeig, weje_,
   {{0x63a20464,0x5f940465,0x2d830466,0x91e60467}},	//   _inon, цият, teje_, _коде,
   {{0x7bc60468,0xa3d20469,0x27e60063,0x63a20031}},	//   _alku, होर_, hnon_, _hnon,
   {{0x2d83046a,0xf2e80081,0x7054046b,0x63a20154}},	//   reje_, _পরিণ, _انبا, _knon,
   {{0x628b02e0,0xe45700c1,0x2ba4001f,0xf45700d7}},	//   _ysgo, יילט_, ојув, יילר_,
   {{0x2905046c,0x27e6019c,0x290a0154,0x2b1a02d5}},	// [210] _šla_, dnon_, _azba_, _मृदु_,
   {{0x3947046d,0x780f046e,0x2d830052,0x00000000}},	//   úns_, िष्क_, qeje_, --,
   {{0x63a2046f,0x6b8401d3,0xbef80470,0x6d5700a7}},	//   _onon, beig, _مریض_, _idxa,
   {{0x27e60471,0x20140472,0xdc9a006e,0x63a20361}},	//   gnon_, _èxit_, _עירל, _nnon,
   {{0xc987002d,0x6e220231,0x1ade0473,0x00000000}},	//   _куви, _éobt, _नेपथ, --,
   {{0x63a20474,0x27e60475,0x683302a1,0xdcfe00b6}},	//   _anon, anon_, _aħde, _napě,
   {{0x057400cd,0x97a70476,0x27e60124,0x2905034f}},	//   تاند, _крал, bnon_, _ála_,
   {{0x69c70477,0xdcfc01d3,0xc245004d,0xab5b00aa}},	//   _hlje, nerā, бник, _olüm,
   {{0xe1f90478,0xdd2c013f,0xe7300018,0x248c0479}},	//   лги_, vėži, _آصف_, _esdm_,
   {{0x6b8402dc,0x63a2047a,0xbec400c6,0x00000000}},	//   zeig, _enon, šūki, --,
   {{0x69c70268,0x7dc20220,0xf0760018,0x6e3601cb}},	//   _mlje, _dôsl, میوں_, _styb,
   {{0x7dc20181,0x6d57047b,0x9f420094,0x6299047c}},	//   _pôso, _adxa, boký_, _trwo,
   {{0x69c7047d,0x6fc60037,0xdcfc01d3,0x62990169}},	//   _olje, _cóca, derā, _urwo,
   {{0x6b84013b,0xb6da006e,0x6feb007f,0x225f047e}},	//   weig, אַלט, ręca, mruk_,
   {{0x6b84047f,0xdb1d00b3,0x7d0902c6,0xacea00ae}},	//   teig, _alsà, řesn, умва_,
   {{0xfd690134,0xdcfe0031,0x6fc60076,0x00000000}},	//   _kepụ, _topľ, _fóca, --,
   {{0x69c70480,0xfaa3044b,0x6b840481,0x7f3b006e}},	// [220] _blje, пато, reig, _געפו,
   {{0x6b840482,0x5d8600e3,0x3f920483,0xfd690129}},	//   seig, _الدل, _hayu_, _mepụ,
   {{0x3f920484,0x6d4e0485,0x291c0486,0x6fc60487}},	//   _kayu_, maba, äva_, _zóca,
   {{0x6d4e0488,0x7bc60489,0x78a302c3,0xd62a022f}},	//   laba, _ulku, ånva, годе_,
   {{0xa3ab048a,0x2b40048b,0x3f920044,0x248c0063}},	//   खान_, mbic_, _mayu_, _ssdm_,
   {{0x6d4e048c,0x225f048d,0x3f92048e,0xe1e7048f}},	//   naba, druk_, _layu_, _رس_,
   {{0x2bbf0490,0xef1f0491,0x6d4e0072,0x00000000}},	//   _एकमा, ndür_, iaba, --,
   {{0x69de0492,0x6d4e0493,0xa85700a1,0x69c700e7}},	//   lipe, haba, _לילה_, _zlje,
   {{0x6d4e0494,0x7dcb008e,0xaade0096,0xdbdc0139}},	//   kaba, _hüse, _नेमक, _báún,
   {{0x69de0495,0x6d4e0496,0x8c000081,0xfd690134}},	//   nipe, jaba, ্দিন_, _depụ,
   {{0x64a30497,0x672d00cb,0x3f920498,0x9f420146}},	//   _нафа, žaje, _bayu_, soký_,
   {{0x69de00d3,0x225f0499,0x63a2049a,0x00000000}},	//   hipe, bruk_, _unon, --,
   {{0x69de049b,0x394a049c,0x3f920085,0x2bbf049d}},	//   kipe, _oebs_, _dayu_, _एकबा,
   {{0x6d4e049e,0x30a6049f,0x3fc900cd,0xea010023}},	//   gaba, _грив, ادگی_, _đắp_,
   {{0x61fa00b3,0x69de04a0,0x3f9203e3,0xc05a04a1}},	//   motl, dipe, _fayu_, _сіл_,
   {{0x69c70292,0x61fa0342,0x224603a9,0xa3ab00bc}},	//   _slje, lotl, _kwok_, खाय_,
   {{0x6d4e04a2,0x69c704a3,0x8d8700ae,0x2a6004a4}},	// [230] baba, _plje, _лунд, grib_,
   {{0x6d4e0060,0x6f0d04a5,0x61fa04a6,0x7f4f028d}},	//   caba, _izac, notl, lacq,
   {{0x2fc904a7,0x66030094,0x6d4104a8,0x3f9200d1}},	//   _klag_, vlnk, ılad, _yayu_,
   {{0x1da704a9,0x61fa04aa,0x7f4f0036,0x6e220131}},	//   खावत, hotl, nacq, _éobr,
   {{0x7bdf04ab,0x7bcd04ac,0x61fa04ad,0x00000000}},	//   miqu, mhau, kotl, --,
   {{0x7bdf04ae,0x69de04af,0x7bcd04b0,0x99c70103}},	//   liqu, cipe, lhau, _اُسے_,
   {{0xddcc01b3,0x224600dc,0x6b5f0139,0x996502c6}},	//   _žiūr, _awok_, _gàgà, _kůži_,
   {{0x7bdf04b1,0x6d4e04b2,0xe3b904b3,0x7bcd04b4}},	//   niqu, zaba, рби_, nhau,
   {{0x66030181,0x6d4e04b5,0x27ff04b6,0x3f9204b7}},	//   plnk, yaba, _ikun_, _rayu_,
   {{0x2fc90124,0x6d4e04b8,0x3f9204b9,0x7bdf00fd}},	//   _alag_, xaba, _sayu_, hiqu,
   {{0x2fc904ba,0x6f0d04bb,0x7bdf03a9,0x3f9204bc}},	//   _blag_, _azac, kiqu, _payu_,
   {{0x6d4e04bd,0x27ff03e5,0x69de04be,0x2fc904bf}},	//   waba, _jkun_, zipe, _clag_,
   {{0x6d4e04c0,0x7bdf04c1,0xf8a6009d,0x7bcd04c2}},	//   taba, diqu, _गप्प, dhau,
   {{0xdb0f002b,0x2b4b04c3,0x3f920113,0x112b0120}},	//   _cocí, _aecc_, _wayu_, _сюди_,
   {{0x6d4e04c4,0x7bdf04c5,0x7f4f0451,0xcfaa04c6}},	//   raba, fiqu, bacq, _ناظم_,
   {{0x7bdf04c7,0x6d4104c8,0x7e660129,0x2fc901b9}},	//   giqu, ðlar, pukp, _glag_,
   {{0xe9da04c9,0x6d4e04ca,0x2b4004cb,0x2d9304cc}},	// [240] ака_, paba, rbic_, _faxe_,
   {{0x27ff04cd,0x6d4e04ce,0x27ed0063,0xdcf50367}},	//   _akun_, qaba, _ajen_, _çağr,
   {{0x69de04cf,0x7bcd04d0,0x088a00ae,0x320504d1}},	//   ripe, bhau, рбей_, illy_,
   {{0xeb9a04d2,0x394a04d3,0x7bdf04d4,0x7bcd04d5}},	//   _тим_, _webs_, ciqu, chau,
   {{0x61fa04d6,0xacf6001c,0x2bbf04d7,0xdcfc044c}},	//   yotl, _دسکت, _एकता, beră,
   {{0x69de01e5,0x27ed0332,0xfe9b0089,0x75d30037}},	//   qipe, _ejen_, יינמ, وينا,
   {{0x69dc00e3,0x6fc60072,0xab5b042c,0x602802c6}},	//   _imre, _nóco, _blüh, _těmi,
   {{0x78a104d8,0xa3ba00e3,0x27ed023b,0x7bc404d9}},	//   _álva, شاعر_, _gjen_, nkiu,
   {{0x6f0404da,0xa3db009f,0x69dc0085,0x61fa04db}},	//   _nyic, _डगर_, _kmre, totl,
   {{0x2fc904dc,0x61e801bf,0x7bdf0372,0x00000000}},	//   _slag_, undl, ziqu, --,
   {{0xeb0704dd,0x2fc904de,0x61fa00b3,0xf1d904df}},	//   _शर्त_, _plag_, rotl, योधन,
   {{0x932500bf,0x320500a1,0xea0100de,0x7bdf04e0}},	//   _فرهن, ally_, _đập_, xiqu,
   {{0x442c0429,0x69dc04e1,0x6b960150,0x2fc904e2}},	//   _hud_, _omre, ddyg, _vlag_,
   {{0x72e900c1,0x2000010a,0x6e3d04e3,0x7a410139}},	//   _פֿײַ, _ekii_, rpsb, _látò,
   {{0x7bdf04e4,0x442c00ae,0x7bcd04e5,0x3a23029a}},	//   tiqu, _jud_, thau, _rijp_,
   {{0x5a3504e6,0x69dc04e7,0x7bcd04e8,0x3a3904e9}},	//   знат, _amre, uhau, _ptsp_,
   {{0x7bdf04ea,0x442c04eb,0x7bcd04ec,0x2d9304ed}},	// [250] riqu, _lud_, rhau, _taxe_,
   {{0x7bdf04c7,0x442c04ee,0x7bcd04ef,0xaca30134}},	//   siqu, _oud_, shau, _apụg,
   {{0x6e2d01fa,0x7bdf04f0,0x20ca04f1,0x442c04f2}},	//   _huab, piqu, ानिध, _nud_,
   {{0x6e2d04f3,0x62820113,0x69dc0233,0xdb060032}},	//   _kuab, _opoo, _emre, _lokù,
   {{0xf77004f4,0x27ed00dd,0xd6db04f5,0x6282023e}},	//   ضان_, _vjen_, јте_, _npoo,
   {{0x442c04f6,0x6e2d04f7,0x644800eb,0x20ca04f8}},	//   _bud_, _muab, _bwdi, ानाध,
   {{0x27ff04f9,0xd838004b,0xddcd04fa,0x62820172}},	//   _tkun_, _мэт_, _opaž, _apoo,
   {{0x442c02a1,0x27ff04fb,0x799504fc,0xc24504fd}},	//   _dud_, _ukun_, _hazw, пник,
   {{0x64480090,0x79950201,0x442c04fe,0x672904ff}},	//   _ewdi, _kazw, _eud_, _igej,
   {{0x442c00e3,0x69c50500,0xdb060031,0x6f040169}},	//   _fud_, nkhe, _pokú, _ryic,
   {{0x442c0501,0x2a690197,0x6e2d009c,0x7bc40138}},	//   _gud_, huab_, _auab, ykiu,
   {{0x76490502,0x6033044c,0x6e2d0503,0x00000000}},	//   _kwey, _căma, _buab, --,
   {{0x6e2d00b3,0x69c50103,0xd1bb0504,0x67290350}},	//   _cuab, kkhe, _پاشا_, _mgej,
   {{0x69c50505,0x79950067,0x6e2d0167,0x442c0506}},	//   jkhe, _nazw, _duab, _yud_,
   {{0x61e10507,0xdca30508,0x76490361,0x63b90509}},	//   mill, нари, _lwey, _kown,
   {{0x61e1050a,0x6729050b,0x69dc050c,0x6724050d}},	//   lill, _ngej, _smre, žiji,
   {{0x61e1050e,0x37e10081,0x629b00c2,0x7995050f}},	// [260] oill, যকার, nvuo, _bazw,
   {{0x3ea00510,0x6d410511,0xa96a0037,0x67290512}},	//   _irit_, ılac, إمام_, _agej,
   {{0x7649008c,0x7995042c,0x61e10513,0x00000000}},	//   _awey, _dazw, iill, --,
   {{0x442c0514,0x2d980515,0x2d8a0516,0x76490517}},	//   _rud_, ldre_, lebe_, _bwey,
   {{0x61e10518,0xc61500c7,0x2a69022e,0x3f800239}},	//   kill, াদনা_, cuab_, _mbiu_,
   {{0x2d980519,0x61e1051a,0x95f6007f,0x7649030a}},	//   ndre_, jill, इवेट_, _dwey,
   {{0xf746051b,0x6282051c,0xb4c6000d,0x7c260051}},	//   _нево, _spoo, उने_, _kikr,
   {{0x7dcb051d,0x2d8a051e,0x9f590257,0x61e1007b}},	//   _müsa, hebe_, posé_, eill,
   {{0x63b9051f,0x61e10520,0x603300d3,0x2bbf0521}},	//   _down, fill, _răma, _एकसा,
   {{0x442c0522,0x61e10523,0x7c260524,0x7a290138}},	//   _tud_, gill, _likr, _užte,
   {{0x2d8a0525,0xdcf500d9,0x442c0526,0x03260231}},	//   debe_, rdzī, _uud_, _еден,
   {{0x61e10527,0x7c260090,0x00000000,0x00000000}},	//   aill, _nikr, --, --,
   {{0x71a60528,0x1ee70260,0x539b00ca,0x2b52037a}},	//   _надз, سوسی_, _ליאו, dayc_,
   {{0x61e10529,0x4426052a,0x2d8a052b,0x57b9052c}},	//   cill, _hio_, gebe_, _आव्ह,
   {{0x4426052d,0x3ea00154,0x48dc009d,0x7c26052e}},	//   _kio_, _erit_, _गेलो_, _bikr,
   {{0xcf2700e3,0x3ea0052f,0x2d980530,0x6e2d0531}},	//   _عربي, _frit_, adre_, _tuab,
   {{0x44260532,0x61eb0018,0x7c260533,0x2d8a0534}},	// [270] _mio_, _állí, _dikr, bebe_,
   {{0x2d8a0535,0x44260536,0xeb9f0537,0xdb0f00b3}},	//   cebe_, _lio_, _skød_, _vocà,
   {{0x7c260538,0x69c50539,0x2a69006c,0xc1780138}},	//   _fikr, rkhe, suab_, lnės_,
   {{0x61e1053a,0xb8d502d5,0x4426053b,0xf6f5001c}},	//   zill, _जप_, _nio_, وزشگ,
   {{0xcb9a00a1,0x63b9053c,0x61e1053d,0x920c009f}},	//   _וסרט, _rown, yill, हताज_,
   {{0xd1260080,0x06f400cd,0x00000000,0x00000000}},	//   _لم_, رسنج, --, --,
   {{0x442603ce,0xdb0602f1,0x6fc60076,0x63b901cb}},	//   _bio_, _ankè, _sócm, _pown,
   {{0x4426053e,0x3f8b053f,0x29110540,0x67290169}},	//   _cio_, jecu_, _izza_, _ugej,
   {{0x44260541,0x3f8b0542,0x2d8a0543,0x24890206}},	//   _dio_, decu_, yebe_, ňam_,
   {{0x61e10257,0x555500cd,0x3ea00052,0x63b90085}},	//   uill, _آپار, _rrit_, _wown,
   {{0x61e10544,0x7dd00084,0x4426001f,0x629b007b}},	//   rill, _jäse, _fio_, svuo,
   {{0x61e10545,0x44260546,0xdee60547,0x3ea00548}},	//   sill, _gio_, доми, _prit_,
   {{0x7dd00149,0x2d8a0549,0x7c26054a,0x6fc6002b}},	//   _läse, tebe_, _rikr, _hóck,
   {{0x7c26054b,0x61e1054c,0x4426054d,0x3e7602b6}},	//   _sikr, qill, _zio_, ræt_,
   {{0x2d98054e,0x3e76052f,0x2d8a0193,0x3b960396}},	//   rdre_, sæt_, rebe_, мјат,
   {{0x6ff6054f,0x3ea00550,0xea010019,0x2d8a0551}},	//   _تستط, _trit_, _đạp_, sebe_,
   {{0x3b07013d,0x7c260552,0x2bbf0553,0x29110554}},	// [280] дето_, _vikr, _एकरा, _azza_,
   {{0xc9860037,0x7dcb0555,0x7c2603a9,0x602802c6}},	//   بشري, _hüsn, _wikr, _těmt,
   {{0x7c260556,0x8cb50557,0xdb0f0558,0x19b9004d}},	//   _tikr, _उपयो, _vocá, чуть_,
   {{0x672d0559,0xb0b6006e,0xf0b60142,0x00000000}},	//   žajn, ופעס_, ולער_, --,
   {{0x442600c9,0x12e80033,0x2911055a,0xdb0f0143}},	//   _rio_, _পর্দ, _ezza_, _tocá,
   {{0x44260010,0xe5a300d3,0x3f8b015c,0x645e0131}},	//   _sio_, кичи, zecu_, ápio,
   {{0xd497055b,0x52b8055c,0x69ce055d,0x9f820503}},	//   дры_, ेन्स, _ilbe, _dóú_,
   {{0xc17800c6,0x2918007f,0x7c2a0231,0xddcd0090}},	//   ynės_, ągać_, _éfru, _spaż,
   {{0x8cb5055e,0x4426055f,0x24850027,0xd16600e5}},	//   _उपभो, _vio_, _eplm_, мъни,
   {{0x7c3e02e6,0x76420560,0xe29f0088,0x00000000}},	//   _otpr, mpoy, æða_, --,
   {{0x44260561,0xf99300ca,0x3f8b00e7,0x91d40034}},	//   _tio_, דרת_, tecu_, योगै,
   {{0x443e0068,0x72c60562,0xdb0d003e,0x44260563}},	//   _itt_, _обез, kkað, _uio_,
   {{0x441b0130,0x69ce02e5,0xa3ab0251,0x64580407}},	//   _וואס, _olbe, खार_, lsvi,
   {{0x443e0564,0x9f5900b3,0x6fc60503,0x00000000}},	//   _ktt_, mosí_, _lóch, --,
   {{0xc1780138,0xc04f0565,0x443e024a,0xac190566}},	//   snės_, _ші_, _jtt_, зову_,
   {{0x69ce0567,0xcbcd0081,0x5f9500e5,0xd0110568}},	//   _albe, রচ্ছ, _чиит, _حلب_,
   {{0x6feb0067,0xbbbf0569,0x9f42023b,0xda78044e}},	// [290] jęci, _एकीक, zikë_, дях_,
   {{0x443e056a,0x6458056b,0x62770327,0x00000000}},	//   _ott_, ksvi, וגמא_, --,
   {{0x443e056c,0x6d47056d,0xab5b0364,0x2907056e}},	//   _ntt_, mbja, _blüt, æna_,
   {{0x69ce056f,0x64580570,0x7dd00212,0x6d470571}},	//   _elbe, dsvi, _väse, lbja,
   {{0x443e0572,0xb906048a,0x6fc600e3,0x6b8d0573}},	//   _att_, _बे_, _dóch, meag,
   {{0x6d550574,0x9f4200dd,0x443e0575,0xdcee0138}},	//   naza, tikë_, _btt_, gebė,
   {{0x26c902e6,0x64580576,0x443e0231,0x83db007f}},	//   šao_, gsvi, _ctt_, यफलआ,
   {{0x6d550577,0x443e0036,0x9f420052,0xa3d9007f}},	//   haza, _dtt_, rikë_, डों_,
   {{0x443e0578,0x60160579,0x644e003d,0x6458057a}},	//   _ett_, náme, _ħbie, asvi,
   {{0xf1b100e3,0x765b0079,0x6b8d057b,0x00000000}},	//   اءة_, _ivuy, heag, --,
   {{0x443e03e3,0x6d55057c,0x9f42057d,0x672400b6}},	//   _gtt_, daza, liké_, žijt,
   {{0x649a0054,0x6443057e,0x14d80096,0x00000000}},	//   _מסעד, mpni, _भेटण, --,
   {{0xe1ee013d,0x6d550060,0x6d410511,0x3f9e02c6}},	//   _бг_, faza, ılan, ětu_,
   {{0x7bcf0465,0x6d55057f,0x200b0580,0x68330090}},	//   _alcu, gaza, alci_, _aħdm,
   {{0xafe60581,0xb0420019,0xdb860582,0x9f420113}},	//   _покл, _trưở, нгви, hiké_,
   {{0x6b8d0583,0x00000000,0x00000000,0x00000000}},	//   geag, --, --, --,
   {{0x6d550584,0xada602d8,0x20020585,0x7dd002c3}},	// [2a0] baza, _запл, moki_, _väsb,
   {{0xdb0d0102,0x20020586,0x673b010a,0x7bcf037a}},	//   rkað, loki_, _afuj, _elcu,
   {{0x7dcb0587,0x6b8d0588,0x765b02a4,0xdb0d01cd}},	//   _müsl, beag, _avuy, skað,
   {{0x48c30081,0x2d9a0589,0x2ca5052f,0x6016058a}},	//   ্পূর, _hape_, ælde_, lámb,
   {{0x2d9a058b,0x443e058c,0x69d100e8,0x569400c6}},	//   _kape_, _stt_, _ūdeņ, талт,
   {{0x63ab058d,0x6458058e,0xab5b01bf,0x2002058f}},	//   _angn, tsvi, _flüs, hoki_,
   {{0x20020590,0x2d9a0591,0xa3ab00bc,0xb0de0592}},	//   koki_, _mape_, खां_, _फेंग,
   {{0x6458032e,0x443e0593,0x2d9a0594,0x9f590487}},	//   rsvi, _vtt_, _lape_, tosí_,
   {{0x6d550595,0x64580596,0x20020597,0x46b70034}},	//   yaza, ssvi, doki_, _आपयह,
   {{0x27e60598,0x2d9a0599,0x6b8d01e9,0x6458059a}},	//   lion_, _nape_, zeag, psvi,
   {{0xc057059b,0x443e00d9,0x6d55059c,0x30a300e5}},	//   нія_, _utt_, vaza, гряв,
   {{0x6d55059d,0x27e6059e,0x2002059f,0x63060076}},	//   waza, nion_, goki_, _كوال,
   {{0x26c605a0,0x6d5505a1,0x2d9a05a2,0xf8ad0403}},	//   nyoo_, taza, _bape_, _टप्प,
   {{0x7d0305a3,0xbbc905a4,0x2bc905a5,0x27e600f0}},	//   _ønsk, रस्क, रस्थ, hion_,
   {{0x6d5505a6,0x26ec05a7,0x5ff5013d,0x27e605a8}},	//   raza, जपुर_, _изку, kion_,
   {{0x6d5a05a9,0x27e605aa,0x6d5505ab,0xfc300037}},	//   ótar, jion_, saza, صحف_,
   {{0x27e605ac,0x6b8d05ad,0x6d5505ae,0x497505af}},	// [2b0] dion_, reag, paza, клас,
   {{0x601605b0,0x6b8d05b1,0x644300f3,0x00000000}},	//   ráme, seag, ypni, --,
   {{0x6fc60161,0x27e60150,0x2ac70065,0x7e7d05b2}},	//   _sóci, fion_, _bíbú_, ltsp,
   {{0x27e605b3,0x765900f0,0x2d9a05b4,0xb8d900bc}},	//   gion_, tswy, _zape_, _अऊ_,
   {{0xa3b40386,0x7e7d05b5,0x2b4900ae,0x9f4b034f}},	//   ञान_, ntsp, mbac_, locó_,
   {{0xd5bb05b6,0x7e7d05b7,0xa50905b8,0xeabf00fe}},	//   ясе_, itsp, мела_, _ngùi_,
   {{0x27e60150,0x02c900d2,0x7640010a,0xa8020345}},	//   bion_, िन्न, _etmy, ğıra,
   {{0x27e605b9,0x644305ba,0x25ac002b,0x7e7d05bb}},	//   cion_, rpni, _endl_, ktsp,
   {{0x7dd00222,0x2a690069,0xa28305bc,0x765b05bd}},	//   _läsa, nrab_, ایتو, _uvuy,
   {{0x644305be,0x7e7d05bf,0x00000000,0x00000000}},	//   ppni, dtsp, --, --,
   {{0x660305c0,0x200205c1,0x7dd00212,0x7e7d05c2}},	//   monk, toki_, _näsa, etsp,
   {{0xb4bf007d,0x66030201,0x2d9a05c3,0x7e7d05c4}},	//   ुनी_, lonk, _sape_, ftsp,
   {{0x200205c5,0x3f9b0090,0x7e7d05c6,0xbddb00ee}},	//   roki_, _daqu_, gtsp, rpèn,
   {{0x008505c7,0x27e605c8,0xd65600ca,0x2a690537}},	//   _алко, zion_, כישת_, drab_,
   {{0x7e7d05c9,0x200205ca,0x1d0705cb,0x8d760504}},	//   atsp, poki_, вери_, _یادا,
   {{0x27e6025a,0x660305cc,0x225900d4,0x2d9a024a}},	//   xion_, honk, šsku_, _wape_,
   {{0x3ae800bf,0xf1b505cd,0x501b00a1,0x7e7d05ce}},	// [2c0] ربری_, _अचान, _קופו, ctsp,
   {{0xdcfc00d9,0x2616034c,0xd94605cf,0x2492007f}},	//   ndrī, _पीढी_, тежи, łymi_,
   {{0x27e605d0,0x8e3a05d1,0xdb060034,0xdcfc01d3}},	//   tion_, _عسکر_, _pokó, idrī,
   {{0x81ca0033,0x7e6905d2,0x00000000,0x00000000}},	//   রোপ_, šepe, --, --,
   {{0x27e605d3,0xa3ab05d4,0x644105d5,0xb4aa05d6}},	//   rion_, खाई_, _atli, खम्_,
   {{0x27e605d7,0xd94305d8,0xe4e3030b,0xdb060034}},	//   sion_, _вери, _केहि_, _wokó,
   {{0x27e605d9,0x09e305da,0x9f590103,0x644105db}},	//   pion_, _торн, őzés_, _ctli,
   {{0x7bd605dc,0x799c05dd,0xdb1d0113,0xdcfc00e8}},	//   nhyu, _harw, _bosè, edrī,
   {{0x644105de,0x877b00c1,0x660305df,0x76260360}},	//   _etli, _קאמי, bonk, _амаз,
   {{0x660305e0,0xf1a605e1,0x2fc001b9,0xdb1d0113}},	//   conk, трин, _aoig_, _dosè,
   {{0x799c05e2,0x7bd605e3,0x2fc0015e,0xc60e05e4}},	//   _marw, khyu, _boig_, ितीय_,
   {{0x7e7d05e5,0x9f4b05e6,0x6d41008b,0x2fc001f7}},	//   ttsp, vocó_, ılam, _coig_,
   {{0xdbdc003e,0x00000000,0x00000000,0x00000000}},	//   _ráðn, --, --, --,
   {{0xdd11025b,0x2d850146,0x799c05bd,0x644102c3}},	//   _výži, ýle_, _narw, _ytli,
   {{0x61e805e7,0xf41400c1,0x2fd205e8,0x7e7d02db}},	//   midl, ָפּ_, _flyg_, stsp,
   {{0xef67013d,0x660305e9,0x61e805ea,0xdb1d01dc}},	//   _ръко, zonk, lidl, _hosé,
   {{0x799c05eb,0x20090113,0x660305ec,0x5b1505ed}},	// [2d0] _barw, _ikai_, yonk, умат,
   {{0x799c05ee,0xdb1d05ef,0xc27b0327,0x6f0d05f0}},	//   _carw, _josé, ורמי, _iyac,
   {{0x2d910193,0x48c30081,0xd246010d,0x601605f1}},	//   meze_, ্প্র, _گن_, láma,
   {{0x2d9105f2,0x660305f3,0x61e805f4,0x6f0d010a}},	//   leze_, wonk, hidl, _kyac,
   {{0xd2460068,0x799c00f0,0x660305f5,0x6b9d01b5}},	//   _دن_, _farw, tonk, _iasg,
   {{0x2d9105f6,0x799c05f7,0x09ad0033,0x7dd005f8}},	//   neze_, _garw, _গতকা, _läsn,
   {{0x660305f9,0xfd500129,0x6b9d0124,0xb4bf05fa}},	//   ronk, _aghụ, _kasg, ुने_,
   {{0x660305fb,0x7bcd05fc,0x2d9105fd,0x799c0079}},	//   sonk, nkau, heze_, _zarw,
   {{0x66030087,0x2fc005fe,0x6b9d05ff,0x2d910600}},	//   ponk, _roig_, _masg, keze_,
   {{0x20090044,0x61e80601,0xe5730602,0x2d910603}},	//   _akai_, gidl, _خطر_, jeze_,
   {{0x7bcd02fd,0x80ad0455,0x43750604,0x64410605}},	//   kkau, टमें, _مهار, _utli,
   {{0xeb9f052f,0x52750606,0x7bcd023e,0x6f0d02a4}},	//   _skøn_, _буку, jkau, _byac,
   {{0x6f0d0193,0x61e80607,0x6033020a,0xee3700e5}},	//   _cyac, bidl, _mămi, лня_,
   {{0x63bb0608,0x40950609,0x2d91023f,0xfce60408}},	//   ljun, _брит, geze_, гого,
   {{0x6b9d060a,0x8fa6060b,0x6f0d060c,0x32050103}},	//   _basg, _байе, _eyac, moly_,
   {{0x63bb060d,0x7bcd060e,0x6b9d0150,0x799c060f}},	//   njun, gkau, _casg, _sarw,
   {{0xc33202f8,0x60160610,0x799c03a9,0xe7f700c3}},	// [2e0] מון_, cáma, _parw, ंचना_,
   {{0x7bd6023f,0xfd4a004d,0x6b9d036b,0x62990611}},	//   shyu, _язок_, _easg, _mswo,
   {{0x63bb003e,0x6b9d0612,0x07a60613,0x7d7b021e}},	//   kjun, _fasg, лажн, _אריג,
   {{0x61e80614,0x799c0615,0x6b9d00f0,0x8b9600c2}},	//   zidl, _warw, _gasg, _сроч,
   {{0x799c0616,0x63bb0617,0x00000000,0x00000000}},	//   _tarw, djun, --, --,
   {{0x7dd00031,0x9f820139,0x00000000,0x00000000}},	//   _mäso, _kóó_, --, --,
   {{0x61e80618,0x395a01af,0x629905c2,0xdb1d00fc}},	//   vidl, maps_, _aswo, _rosé,
   {{0x2d910619,0x6f090034,0x291803e3,0x63bb061a}},	//   zeze_, żeci, _izra_, gjun,
   {{0xd13000e3,0x46a3061b,0xdb1d04c1,0xdb0f020d}},	//   يمة_, _латв, _posé, _ancê,
   {{0x6f0d05bd,0x2d91044c,0x7a7b0142,0x00000000}},	//   _ryac, xeze_, עריס, --,
   {{0x63bb061c,0x2009061d,0x62990154,0x61e8061e}},	//   bjun, _pkai_, _eswo, ridl,
   {{0x09c1009d,0x2d91061f,0x61e80620,0xddcd010a}},	//   _शक्य, weze_, sidl, _twaŋ,
   {{0x61e80621,0x2d910622,0x6b9d0623,0x320505f1}},	//   pidl, teze_, _rasg, boly_,
   {{0x7dcb0006,0x23270624,0x6aa90335,0x6f0d02a4}},	//   _küsi, _сочи_, _šefo, _vyac,
   {{0x2d910625,0x6b840626,0x6b9d0627,0xd13f00a5}},	//   reze_, ffig, _pasg, łącz_,
   {{0x672d050d,0x2d910628,0x62800629,0x6b8401f9}},	//   žaji, seze_, otmo, gfig,
   {{0x9955062a,0x7bcd062b,0xf96b062c,0x2918062d}},	// [2f0] икац, rkau, ерей_, _azra_,
   {{0x7bcd062e,0x6b9d062f,0x995400ae,0x62800381}},	//   skau, _wasg, йкуц, itmo,
   {{0x6b9d0013,0x3ea90094,0x63bb0630,0x00000000}},	//   _tasg, _hrat_, yjun, --,
   {{0x3ea90631,0x6b9d0076,0xb1130294,0x6d570632}},	//   _krat_, _uasg, nụar, _hexa,
   {{0x29180633,0x248c00dc,0x6d570634,0x395a00ee}},	//   _ezra_, _apdm_, _kexa, baps_,
   {{0x4ade0635,0xb5fd00b6,0x5e58006e,0x7c2f0555}},	//   _नेटव, _ovše, ריגע_, _hicr,
   {{0x23d50636,0xdb060018,0x6d5700a7,0x63bb0637}},	//   ицир, _inká, _mexa, tjun,
   {{0xea0100ef,0x62650638,0xd26500e5,0x00000000}},	//   _đẹp_, авиа, акий, --,
   {{0xe3b604d9,0xd7f80138,0x00000000,0x00000000}},	//   рбы_, _сур_, --, --,
   {{0x6ff201d3,0x98a10555,0x7c2f0639,0xbbd2063a}},	//   māci, lahı_, _licr, _सत्क,
   {{0x7dd00222,0xf99200a1,0x6ff200d9,0x3ea9063b}},	//   _säso, חרי_, lāci, _arat_,
   {{0xf1d9063c,0x7c2f01b9,0x629901c2,0x6d57033c}},	//   योजन, _nicr, _tswo, _aexa,
   {{0x6ff200d9,0x442f01c0,0x6d57063d,0x2bbf063e}},	//   nāci, _iig_, _bexa, _एकजा,
   {{0x3ea90167,0x442f0565,0x7c2f0503,0xc5f2006e}},	//   _drat_, _hig_, _aicr, ַדן_,
   {{0x3ea9063f,0xa3cc0640,0x2d9e0220,0x442f0641}},	//   _erat_, _रकम_, ľte_, _kig_,
   {{0x6ff200d9,0x2d9e0618,0x0b460642,0x442f0643}},	//   kāci, žte_, рнан, _jig_,
   {{0x442f0644,0x7c2f0645,0x3d1c0065,0x3e7f00ae}},	// [300] _mig_, _dicr, _báwí_, cît_,
   {{0x442f0646,0xe9d70647,0x7c2f01b9,0x6ff200e8}},	//   _lig_, аку_, _eicr, dāci,
   {{0xd91000d0,0x60160072,0x6fcd020d,0x442f036b}},	//   سیر_, námo, _bûch, _oig_,
   {{0xc60e0336,0x442f0032,0x7afd0167,0x225f0009}},	//   ित्य_, _nig_, _fxst, ksuk_,
   {{0x7c240648,0x9f820649,0x7ae90559,0xeb97008f}},	//   mmir, _yóò_, _žetv, _тия_,
   {{0x6d5c064a,0x442f064b,0x7c240092,0x0466064c}},	//   nara, _aig_, lmir, атим,
   {{0x442f064d,0x601d025a,0x2bdd009d,0xdb0f03a9}},	//   _big_, léme, नोका, _ancè,
   {{0x442f064e,0x938a064f,0x60160042,0x62800650}},	//   _cig_, тска_, dámo, ttmo,
   {{0x442f0651,0x6d5c0652,0x3c3c0653,0x601d0654}},	//   _dig_, kara, _lív_, néme,
   {{0x6d5c0655,0x442f0656,0x6033020a,0x00000000}},	//   jara, _eig_, _lămu, --,
   {{0x39580657,0x62800658,0x442f00a1,0xdb0f00ee}},	//   _mers_, stmo, _fig_, _encè,
   {{0x41a6007d,0x6d570659,0x3ea9065a,0x6fc6065b}},	//   _कोरस, _sexa, _prat_, _sócr,
   {{0xdefb065c,0x6d5c065d,0x7c240559,0x7c2f00e5}},	//   тын_, fara, dmir, _ricr,
   {{0x6d5c065e,0x442f065f,0x7c2f02ad,0x3ea90660}},	//   gara, _zig_, _sicr, _vrat_,
   {{0x442f006c,0x6ff20029,0x6d570661,0x61ef00fd}},	//   _yig_, zāci, _vexa, ècle,
   {{0x7c240662,0x3ea9042c,0x6d4e01ee,0xc17800c6}},	//   gmir, _trat_, abba, lgė_,
   {{0x6d5c0663,0x8d87007e,0x69d5030b,0xba550037}},	// [310] bara, _кунд, _plze, صناع,
   {{0xe29f0102,0xc178013f,0x6ff201d3,0x39580664}},	//   æði_, ngė_, vāci, _cers_,
   {{0x3958026a,0x00000000,0x00000000,0x00000000}},	//   _ders_, --, --, --,
   {{0x39580665,0x22460666,0x6ff200d9,0x7c2400ae}},	//   _eers_, _otok_, tāci, cmir,
   {{0x9f420146,0x60160018,0x3958014b,0xdb1d00d8}},	//   niká_, zámo, _fers_, _kosí,
   {{0x442f0667,0x6ff20029,0xaca30294,0x39580668}},	//   _sig_, rāci, _ndịd, _gers_,
   {{0xe3b100e3,0x2246061d,0x60160042,0x98aa00bd}},	//   كرة_, _atok_, xámo, _rebħ_,
   {{0x442f01fa,0xb7bd020a,0x60160669,0x98aa00bd}},	//   _qig_, _piţu, vámo, _sebħ_,
   {{0xdcfe01d3,0x36d4004d,0x442f066a,0x2b5905db}},	//   _papī, _дотр, _vig_, _mesc_,
   {{0x6d5c066b,0x7c2401d3,0xdb1d0094,0x39410519}},	//   xara, zmir, _nosí, nchs_,
   {{0x2ed0007d,0x442f066c,0x1bf904dd,0x224603a9}},	//   हन्त, _tig_, ्काल_, _etok_,
   {{0x6d5c066d,0xcdc90054,0x6016066e,0xdb0f066f}},	//   wara, _אך_, rámo, _encé,
   {{0x6d5c0670,0x539a00a1,0xdb2403e0,0x6016002b}},	//   tara, _תינו, üsün, sámo,
   {{0x32b80037,0xddd40031,0x60160042,0x7dd0007b}},	//   _خدمة_, ťažo, pámo, _täsm,
   {{0xc88500a7,0x7c240671,0x8c46001f,0xdcfc00c4}},	//   naşı_, tmir, себе, terđ,
   {{0x9f820088,0x2b590672,0x7dd00673,0xa3ca02d5}},	//   _góð_, _cesc_, _käsk, रॉप_,
   {{0x2b40031a,0x09360674,0x00000000,0x00000000}},	// [320] rcic_, مراج, --, --,
   {{0x6d5c0675,0x2a600676,0x601d0677,0x2b590090}},	//   qara, rsib_, réme, _eesc_,
   {{0xfbd20678,0x39580679,0x2a60067a,0x601d00fd}},	//   _فتح_, _vers_, ssib_, séme,
   {{0xc8850491,0x9f4b0052,0x3958067b,0x00000000}},	//   daşı_, vicë_, _wers_, --,
   {{0xe5c6067c,0x39580233,0x7bc6010a,0xada90281}},	//   йско, _ters_, _ioku, _صدیق_,
   {{0x6b96026d,0x00000000,0x00000000,0x00000000}},	//   leyg, --, --, --,
   {{0x7bc6067d,0x2246067e,0xe9d7067f,0x66d101f9}},	//   _koku, _stok_, _укр_, tókö,
   {{0x6b960680,0x644a0036,0x2b5900b3,0x7bc60681}},	//   neyg, rpfi, _xesc_, _joku,
   {{0x7ae90682,0x7bc60683,0x7dcb0684,0x60290034}},	//   _þett, _moku, _küst, _uśmi,
   {{0x7bc60685,0x104a0686,0x7f440063,0x6aa900e7}},	//   _loku, лями_, _afiq, _šefk,
   {{0x7dcb0687,0xe4520688,0x442400dc,0x9f4b034f}},	//   _xüsu, _رضا_, pmm_, licé_,
   {{0x7bc6067d,0xdb1d0072,0x9f420206,0x94260689}},	//   _noku, _sosí, tiká_, _умее,
   {{0x7f5d002b,0xdb1d068a,0x2246019c,0xba3b00b3}},	//   rasq, _posí, _utok_, _trïi,
   {{0x270700ef,0x63a2068b,0xe9df0328,0xdb1100fd}},	//   ống_, _haon, _atún_, _âgée,
   {{0x7bc60201,0x7a290138,0x7f5d0036,0x63a2068c}},	//   _boku, _užti, pasq, _kaon,
   {{0x6b96008c,0xdb1d0231,0x1b020033,0x660a02ac}},	//   geyg, _rosâ, লেছে_, hofk,
   {{0x63a2068d,0x200b068e,0x394100fd,0x2b5900b3}},	// [330] _maon, moci_, tchs_, _vesc_,
   {{0x2ba904a9,0x200b068f,0x63a20690,0x394102db}},	//   _चोरा, loci_, _laon, uchs_,
   {{0x39410691,0x7dcb0692,0x998200c6,0x00000000}},	//   rchs_, _düst, _aukų_, --,
   {{0x61c50693,0x63a20051,0x39410365,0xc885020e}},	//   _लक्ष, _naon, schs_, vaşı_,
   {{0x25ed02e8,0xb5fd0146,0x961d05aa,0x7dcb01f9}},	//   _अगदी_, _avša, _opņt, _füst,
   {{0x7bc6067d,0xdcfc01d3,0x3e5c006e,0x00000000}},	//   _zoku, cerē, נדוס, --,
   {{0x7bc6067d,0x62820694,0xdb060212,0x6d45009c}},	//   _yoku, _aqoo, _enkä, _mfha,
   {{0x69c70695,0x7dcb0696,0x77d70076,0x63a20697}},	//   _hoje, _küss, _اغسط, _caon,
   {{0x69c702e6,0x644801d4,0x200b04a3,0x85b90698}},	//   _koje, _etdi, doci_, _клас_,
   {{0x7dcb02dc,0x7dd00149,0x672d02ef,0x80650699}},	//   _müss, _väsk, žajs, овож,
   {{0x69c7069a,0x645e0220,0x7e640088,0xcea90327}},	//   _moje, špir, _svip, _שי_,
   {{0x6d45069b,0x200b05fe,0x246501d3,0xd00a069c}},	//   _afha, goci_, mēm_, реме_,
   {{0xa29400f7,0xd9fb009d,0x6d45036b,0x246501d3}},	//   _наці, ्वात_, _bfha, lēm_,
   {{0x7dd0069d,0x7bc6067d,0x224d069e,0x69c70201}},	//   _käsi, _soku, mpek_, _noje,
   {{0x7bc6069f,0x63a206a0,0x7dcb06a1,0x246501d3}},	//   _poku, _yaon, _rüst, nēm_,
   {{0xb06800d0,0x7dcb007a,0x200b06a2,0x7649010a}},	//   _اصول_, _süst, coci_, _otey,
   {{0x7dcb00aa,0x19c60358,0xed360152,0x224d0095}},	// [340] _püst, обам, _мэнэ, npek_,
   {{0x7bc6067d,0x3ea006a3,0x7dcb01bf,0x69c706a4}},	//   _woku, _isit_, _düss, _coje,
   {{0x69c7011d,0x7bc606a5,0x5faf009d,0x601d06a6}},	//   _doje, _toku, _जोडल, léma,
   {{0x2d9806a7,0x510c0130,0x224d06a8,0x246501d3}},	//   lere_, נהאַ, kpek_, dēm_,
   {{0xd5ba0084,0x63a206a9,0x601d06aa,0x7a230129}},	//   иск_, _raon, néma, ọtar,
   {{0x2d9806ab,0x69c706ac,0xe4520037,0x63a206ad}},	//   nere_, _goje, وضع_, _saon,
   {{0xb4d406ae,0x2d9806af,0x63a20036,0x764906b0}},	//   हने_, iere_, _paon, _etey,
   {{0x2d9806b1,0x326606b2,0x9faf030b,0x6aa90106}},	//   here_, отов, tří_, _šefi,
   {{0x2d9806b3,0xdb1d0018,0x200b06b4,0x00000000}},	//   kere_, _kosá, voci_, --,
   {{0x2d9806b5,0x63a20051,0x601d020d,0x3f800138}},	//   jere_, _waon, déma, _aciu_,
   {{0x2d9806b6,0x63a20256,0x200b006d,0x246501d3}},	//   dere_, _taon, toci_, cēm_,
   {{0x2d980172,0x7a2900c6,0x00000000,0x00000000}},	//   eere_, _užtv, --, --,
   {{0x2d9806b7,0x200b06b8,0x00000000,0x00000000}},	//   fere_, roci_, --, --,
   {{0x2d9806b9,0xddcf00ae,0x61ea00ae,0x2b5f00c4}},	//   gere_, ducţ, _umfl, _žuc_,
   {{0xfbd30080,0xa1770054,0x69c706ba,0xc05a00f3}},	//   وتر_, _ועוד_, _roje, _тіл_,
   {{0x69c70117,0xdb1d00b3,0x7dcb00bc,0x80d70179}},	//   _soje, _posà, _püss, मनरे,
   {{0x2d9806bb,0x69c706bc,0x246501d3,0x3f9906bd}},	// [350] bere_, _poje, zēm_, mesu_,
   {{0x2d9806be,0x3f9906bf,0xdb1d0076,0xdb0f00b3}},	//   cere_, lesu_, _cosá, _socó,
   {{0xe7f7007d,0x2d8106c0,0x69c7025b,0x764906c1}},	//   ंचला_, _iche_, _voje, _stey,
   {{0x320c06c2,0x69c700a5,0x4c9a040a,0x798e0172}},	//   hody_, _woje, _פברו, _ebbw,
   {{0x320c007f,0x00000000,0x00000000,0x00000000}},	//   kody_, --, --, --,
   {{0x27ef00d7,0x246500d9,0x69de06c3,0x64a506c4}},	//   sign_, tēm_, chpe, зака,
   {{0x63600134,0x3f9903e3,0x2d81024a,0x00000000}},	//   _ịnab, kesu_, _mche_, --,
   {{0x3cfc0105,0x2d980193,0x3f990060,0x61fa06c5}},	//   ילונ, zere_, jesu_, entl,
   {{0x27ed06c6,0x2d9806c7,0x2d810129,0x37da006e}},	//   _imen_, yere_, _oche_, _פֿלע,
   {{0x2d810129,0x320c0034,0x2d9806c8,0x246500e8}},	//   _nche_, gody_, xere_, pēm_,
   {{0x2d9806c9,0x224d06ca,0x601606cb,0x2fc901ec}},	//   vere_, spek_, lámi, _boag_,
   {{0x2d9806c0,0x2fc9002b,0xd8d600ca,0x601d001c}},	//   were_, _coag_, פורט_, téma,
   {{0x2d9806cc,0x25a506cd,0x320c06ce,0xc3290037}},	//   tere_, _kall_, body_, _اكشن_,
   {{0x7dd002c3,0xd1bb06cf,0x27ff06d0,0x7bcb003e}},	//   _läsv, _خاصا_, _ljun_, ögun,
   {{0x2d9806d1,0x27ed06d2,0xdb1d06d3,0x6b8f0169}},	//   rere_, _omen_, _rosá, _bbcg,
   {{0x2d9806d4,0x4a4606d5,0x2d8100ac,0x27ed00f9}},	//   sere_, знав, _eche_, _nmen_,
   {{0x2d9806d6,0x6d4106d7,0xe9da06d8,0xdb1d0146}},	// [360] pere_, ılar, бка_, _posá,
   {{0xdb0406d9,0xddcf020a,0x8af000a7,0x25a501b5}},	//   ndié, rucţ, vbəd, _nall_,
   {{0x6d5e00d9,0x6d3b00ca,0x63760555,0xbddb015e}},	//   _iepa, _לתינ, nünü, rpèt,
   {{0xf1ba0023,0x291d01c2,0x69de0216,0x25a506da}},	//   _nhơn_, ƙwan_, shpe, _aall_,
   {{0x6d5e06db,0xb4e4009f,0x27ff009e,0x25a506dc}},	//   _kepa, _पेड़_, _djun_, _ball_,
   {{0x6d5e06dd,0x25a506de,0x7c3e06df,0x3f9901e9}},	//   _jepa, _call_, _kupr, zesu_,
   {{0x25a50465,0x320c0363,0x20000129,0x3f9906e0}},	//   _dall_, vody_, _ojii_, yesu_,
   {{0x6d5e06e1,0x7bd606e2,0x320c0034,0x7c3e06e3}},	//   _lepa, nkyu, wody_, _mupr,
   {{0x320c06e4,0x25a506e5,0xdb0400fd,0x3f9906e6}},	//   tody_, _fall_, udiè, vesu_,
   {{0x64a606e7,0x200303ce,0x6d5e06e8,0x67200292}},	//   _наза, čkim_, _nepa, _izmj,
   {{0x320c06e9,0x93160103,0x6376020e,0x9f9906ea}},	//   rody_, _کوشش, günü, овну_,
   {{0x2d8102db,0x443e020d,0x672006eb,0x27ed020b}},	//   _sche_, _iut_, _बराक_, _xmen_,
   {{0x6d5e04ee,0xe80d06ec,0xb80d06ed,0x7c3e0257}},	//   _bepa, िकता_, िकतम_, _aupr,
   {{0x6d5e06ee,0x443e06ef,0x224b0220,0x3f9900f0}},	//   _cepa, _kut_, ícke_, sesu_,
   {{0x7c3e002d,0x3f990329,0x443e06f0,0x9f4b02c6}},	//   _cupr, pesu_, _jut_, licí_,
   {{0x443e06f1,0x69dc06f2,0xd117006e,0x6d5e00f9}},	//   _mut_, _alre, _מקוה_, _eepa,
   {{0x5a35016e,0x443e06f3,0x601d06f4,0x69dc009c}},	// [370] днат, _lut_, lémo, _blre,
   {{0x443e004f,0x6d5e0418,0x2d8100ac,0x7bdf0188}},	//   _out_, _gepa, _uche_, shqu,
   {{0x7c3e03a9,0x69dc01b9,0x7ae4010a,0x443e06f5}},	//   _gupr, _dlre, azit, _nut_,
   {{0x69dc0103,0x60160072,0x00000000,0x00000000}},	//   _elre, támi, --, --,
   {{0xf77006f6,0x443e06f7,0x81bc00d9,0x7bdd06f8}},	//   طان_, _aut_, rmēj, _ilsu,
   {{0x443e004f,0x601606f9,0xf65006fa,0x6d470034}},	//   _but_, rámi, ائن_, ncja,
   {{0x25a505fe,0x98170037,0x443e00ca,0x27ed0085}},	//   _vall_, _فبرا, _cut_, _tmen_,
   {{0x7dd006fb,0x443e02a7,0x601d06fc,0x25a506fd}},	//   _häst, _dut_, démo, _wall_,
   {{0x644906fe,0x91e506ff,0x443e00fd,0x6d47007f}},	//   _žlič, допе, _eut_, kcja,
   {{0x443e0700,0x5ef1030b,0xdb040364,0x6376020e}},	//   _fut_, ँछन्_, heiß, tünü,
   {{0x65630701,0x7bdd0702,0x443e0703,0x7dd00149}},	//   manh, _olsu, _gut_, _mäst,
   {{0x7dd00704,0x637603a3,0x5ec60081,0x65630705}},	//   _läst, rünü, _লেগে, lanh,
   {{0x6d5e0706,0x7c3e0707,0x63a90708,0x6376020e}},	//   _pepa, _supr, mden, sünü,
   {{0x63a90709,0x7dd0070a,0x5187065c,0x2be000b6}},	//   lden, _näst, _худа, नसभा,
   {{0x6289070b,0x601d0042,0x6b8d070c,0x673b0361}},	//   lteo, cémo, ffag, _oguj,
   {{0x7ae401e9,0x673b070d,0x6d5e070e,0x6563070f}},	//   tzit, _nguj, _wepa, hanh,
   {{0x7dd0070a,0x6d5e0710,0x62890711,0x65630712}},	// [380] _bäst, _tepa, nteo, kanh,
   {{0x673b0487,0x63a900c2,0x22590146,0x62890037}},	//   _aguj, hden, ásky_, iteo,
   {{0xdb0f0428,0xd910001c,0x765b0713,0x59c40714}},	//   _encà, ایز_, _awuy, लॉगर,
   {{0x63a90715,0x443e0716,0x3eb20146,0xdb1d02c3}},	//   jden, _rut_, _kryt_, _bosä,
   {{0x443e02ad,0xd76500cd,0x7dd00149,0x65630131}},	//   _sut_, رنوی, _fäst, fanh,
   {{0x7dd00717,0x63a90718,0x443e0719,0x6563071a}},	//   _gäst, eden, _put_, ganh,
   {{0x7845013f,0x7dd0071b,0xf772071c,0x6feb0034}},	//   _tėva, _häss, _لاء_, ręcz,
   {{0xd7640018,0x6008071d,0x63a9071e,0x7a2900c6}},	//   _سنئی, nımd, gden, _užtr,
   {{0xa80203a3,0x2918071f,0x65630720,0x443e0721}},	//   ğıda, _hyra_, banh, _wut_,
   {{0x443e0722,0x7abb00a1,0x7dd00723,0x63a90724}},	//   _tut_, קציו, _mäss, aden,
   {{0x7dd002e2,0x443e007a,0xc0570426,0xf1a30204}},	//   _läss, _uut_, мія_, трын,
   {{0x601d0725,0x76400726,0x291801ce,0x3eb20727}},	//   rémo, _kumy, _myra_, _bryt_,
   {{0x44260728,0x62890729,0x7dd0072a,0xa3080103}},	//   _iho_, cteo, _näss, _عرصے_,
   {{0x7640072b,0xdb04042c,0x00000000,0x00000000}},	//   _mumy, weiß, --, --,
   {{0x4426072c,0x2bbb0037,0x3b4c0174,0x9e3400ae}},	//   _kho_, يارة_, _ọdịk, терч,
   {{0x2ba9072d,0xdb0601dc,0x00000000,0x00000000}},	//   _चोखा, _kakè, --, --,
   {{0x656302c9,0xa3d60378,0x6b8d072e,0x442601b9}},	// [390] yanh, _हवन_, rfag, _mho_,
   {{0x4426072f,0x63a90730,0x7e7d0329,0x49740731}},	//   _lho_, zden, musp, клус,
   {{0x7dd00222,0x63a90732,0xaca30134,0x44260733}},	//   _väst, yden, _mpịg, _oho_,
   {{0x44260734,0xdb0f0042,0xddcd0146,0x76400735}},	//   _nho_, _encá, _staň, _bumy,
   {{0x200303ce,0x7c2d0572,0x65630736,0x7dd002fd}},	//   čkih_, mmar, tanh, _täst,
   {{0x44260737,0x29180222,0x00000000,0x00000000}},	//   _aho_, _fyra_, --, --,
   {{0x44260049,0x65630738,0xd5fb0174,0xfc460220}},	//   _bho_, ranh, _asụ, žíva_,
   {{0x44260739,0x7c2d073a,0x7e7d073b,0x6563073c}},	//   _cho_, nmar, kusp, sanh,
   {{0x66f30714,0x6563073d,0x2a69073e,0x4426073f}},	//   _अधिक_, panh, nsab_, _dho_,
   {{0x60080740,0x62890741,0x7c2d0742,0x60e90743}},	//   zımd, rteo, hmar, змом_,
   {{0x62890744,0x7c2d0745,0xdb06023b,0x9f4b00ee}},	//   steo, kmar, _pakë, ficà_,
   {{0x64410012,0x6561017a,0x2a6900aa,0x78ba0103}},	//   _iuli, _helh, ksab_, _átve,
   {{0x442d0746,0x81d50747,0x64410748,0x201e00d9}},	//   mme_, _подх, _huli, ēti_,
   {{0x64410749,0x7c26074a,0x3f84003d,0x270e00de}},	//   _kuli, _shkr, żmu_, ộng_,
   {{0x65610303,0xfce6074b,0xa3b4074c,0x6441074d}},	//   _melh, хово, _छोड_, _juli,
   {{0x442d074e,0x6441074f,0x7c2d0750,0xf062008f}},	//   nme_, _muli, gmar, _скъп,
   {{0x291e03ce,0x160f0751,0xe9da0752,0x64410753}},	// [3a0] _šta_, िवार_, пка_, _luli,
   {{0x442d0754,0x7c2d0755,0xdb06030b,0x3d11009d}},	//   hme_, amar, _jaké, _दुवे_,
   {{0x64410756,0x442d0757,0xdb0603a9,0x2ca50537}},	//   _nuli, kme_, _maké, ældt_,
   {{0x442d0758,0x7dd002fd,0x3f820759,0xe85300cd}},	//   jme_, _täss, ngku_, انند,
   {{0x4426075a,0x442d075b,0x6561075c,0x9f4b0131}},	//   _rho_, dme_, _belh, nicá_,
   {{0x6441075d,0x442d075e,0xe4a6075f,0xa4f801f3}},	//   _buli, eme_, ерио, وکار_,
   {{0x64410760,0xd4970761,0xdcfc00d9,0x442d01cb}},	//   _culi, еры_, derī, fme_,
   {{0x442601bb,0x64410762,0x69ce02a7,0xdb0602f1}},	//   _qho_, _duli, _hobe, _pakè,
   {{0x65610068,0x69ce0763,0x64410764,0xf5ea00ae}},	//   _felh, _kobe, _euli, _емал_,
   {{0x44260054,0x442d0765,0x6441008a,0xef1f0766}},	//   _who_, ame_, _fuli, ngüe_,
   {{0x64410767,0x33d602ec,0x91a60174,0x44260768}},	//   _guli, _підт, _atọ_, _tho_,
   {{0x7e7d03cf,0xa2e60769,0x7c2d008a,0x442d076a}},	//   tusp, _поед, xmar, cme_,
   {{0x0cc90386,0x6441076b,0x9f4b05fe,0xa3d50006}},	//   रह्म, _zuli, ricà_, _सकत_,
   {{0x6441076c,0x7c2d076d,0x7afb0106,0x2d85076e}},	//   _yuli, wmar, _žuto, üle_,
   {{0x7e7d076f,0x64410770,0xac190771,0x00000000}},	//   susp, _xuli, дову_, --,
   {{0x7e7d0772,0x00000000,0x00000000,0x00000000}},	//   pusp, --, --, --,
   {{0x7f4d0090,0x7f49034f,0x99630206,0xda78002e}},	// [3b0] _ifaq, ñequ, ríži_, еях_,
   {{0x9f590076,0x7e6d0062,0x00000000,0x00000000}},	//   insí_, _ivap, --, --,
   {{0xd36601dc,0x69ce0773,0xaca30294,0xe3c30233}},	//   _په_, _dobe, _kpọg, ngıç_,
   {{0x7e6d0774,0x2d8300f3,0x7f4d02a1,0x656102c6}},	//   _kvap, lgje_, _jfaq, _selh,
   {{0xe7e20775,0x65610776,0x442d0777,0x85b800d1}},	//   _खतरा_, _pelh, vme_, کانس_,
   {{0x69ce0778,0x64410779,0x2d83077a,0x88820103}},	//   _gobe, _puli, ngje_, _چیلن,
   {{0x442d077b,0x6561077c,0x644100a7,0xb4db077d}},	//   tme_, _velh, _quli, डने_,
   {{0x7bcf0012,0x6441077e,0xdb0603a9,0x7f4d0090}},	//   _jocu, _vuli, _saké, _nfaq,
   {{0x130902ec,0x9f4200dd,0x6561077f,0x69d80018}},	//   ьний_, shkë_, _telh, öveg,
   {{0x7bcf0012,0x64410780,0xb6350781,0x00000000}},	//   _locu, _tuli, _شفاع, --,
   {{0xf8e10782,0xdb1d00e3,0x442d0783,0x64410784}},	//   पनिय, _cosú, pme_, _uuli,
   {{0x13a700cd,0x2d8301cb,0x9f4b0231,0x00000000}},	//   _سنتی_, egje_, ticá_, --,
   {{0x69c4046e,0x3f8c00a5,0xdb060220,0x15e500c0}},	//   रामी, ędu_, _také, _कतार_,
   {{0x827600c1,0x7e6d0106,0x63ab003e,0xd24e071c}},	//   _יענע_, _dvap, _hagn, _بنو_,
   {{0x69ce0785,0xa3d5007f,0xa0a5004d,0x228b00f3}},	//   _robe, _सका_, _райд, løk_,
   {{0x63ab0786,0xeb9700d3,0x2d8301c0,0xd00f0037}},	//   _jagn, кис_, agje_, _ولو_,
   {{0x69ce0787,0x7bcf0788,0xe7f70789,0xdb1d0139}},	// [3c0] _pobe, _docu, ूचना_, _kosù,
   {{0xdb0d003e,0x63ab078a,0x00000000,0x00000000}},	//   rjað, _lagn, --, --,
   {{0x1d0a078b,0x7bcf078c,0x69ce078d,0xddc4078e}},	//   _цени_, _focu, _vobe, _eviţ,
   {{0x69ce078f,0x63ab0790,0x78b500e7,0x27e00037}},	//   _wobe, _nagn, _drzv, óin_,
   {{0xe7f300a5,0xe7370791,0x34da00b6,0x00000000}},	//   _आगरा_, вец_, बन्द, --,
   {{0x55730792,0x6b840793,0x6aa405bd,0xa613013f}},	//   агшт, lgig, mwif, аміч,
   {{0x63ab013d,0x629906a3,0xbf000034,0x44a30076}},	//   _bagn, _apwo, ैथुन_, لموق,
   {{0x63ab0794,0x798201c2,0x00000000,0x00000000}},	//   _cagn, ɗowa, --, --,
   {{0x63ab0795,0x6f09007f,0x8c1b0796,0x00000000}},	//   _dagn, żecz, ווקי, --,
   {{0xdb1d0797,0x27e60798,0xf1ba0023,0x7d090233}},	//   _posú, lhon_, _khơi_, şesi,
   {{0x601d0799,0x25be079a,0xb97b00a1,0x7e6d028d}},	//   lémi, _intl_, וניי, _svap,
   {{0x63ab079b,0xb4c0007d,0x7ec900dd,0x27e602c9}},	//   _gagn, ुही_, _nëpë, nhon_,
   {{0xd25000e3,0xf8bf0557,0xa194079c,0x00000000}},	//   _انت_, _एप्प, _балч, --,
   {{0x63ab00f1,0x7bcf020a,0x628000e8,0x2002079d}},	//   _zagn, _socu, mumo, anki_,
   {{0xa3d603a2,0x6280079e,0x2d83079f,0x7bcf07a0}},	//   _हवा_, lumo, rgje_, _pocu,
   {{0x6008026a,0x63a000f3,0x6b8407a1,0x00000000}},	//   rımc, nemn, ggig, --,
   {{0x27e607a2,0x628001af,0x41a9074c,0x683a00d2}},	// [3d0] dhon_, numo, _कसमस, _půdn,
   {{0x601d07a3,0x3ea907a4,0x9f400428,0x3f8901b9}},	//   démi, _isat_, _aliè_, _hcau_,
   {{0xf1ba00ef,0x628007a5,0xf775036c,0x7bcf020a}},	//   _chơi_, humo, гулю, _tocu,
   {{0xf09307a6,0x628007a7,0x63a007a8,0x1a650068}},	//   ינע_, kumo, jemn, _میری_,
   {{0x63ab07a9,0x628000d9,0x600807aa,0x8af000a7}},	//   _ragn, jumo, nıma, nbəl,
   {{0x63ab07ab,0x27e607ac,0x2e24003e,0x69c407ad}},	//   _sagn, ahon_, höfn_, राणी,
   {{0x63ab07ae,0x20020034,0x7dcb01f9,0x25ac0178}},	//   _pagn, ynki_, _büsz, _dadl_,
   {{0x27e607af,0x3f8901fa,0x3d3c040a,0x2496001c}},	//   chon_, _ncau_, וגוס, انيد_,
   {{0x23c50789,0x63ab07b0,0x67d400d3,0x628007b1}},	//   वाबद, _vagn, _тоту, gumo,
   {{0x79850085,0x228b0120,0x3f8900eb,0xb0ae07b2}},	//   nghw, røk_, _acau_, टिंग,
   {{0x545507b3,0x63ab07b4,0x69c4009d,0x228b00d6}},	//   _свет, _tagn, राती, søk_,
   {{0x92b50192,0x63a00167,0x7c3d0078,0x628007b5}},	//   _محتا, cemn, _nisr, bumo,
   {{0x3ea907b6,0x62c70076,0xfeba00d1,0x00000000}},	//   _csat_, _جزاك, راحت_, --,
   {{0x7c3d009c,0xc33200ca,0x200200e7,0x27e607b7}},	//   _aisr, _הוד_, snki_, zhon_,
   {{0xfce307b8,0x3ea907b9,0xd1b80018,0x81bc01d3}},	//   боро, _esat_, _جانا_, rmēt,
   {{0xfaa607ba,0x81bc01d3,0xd0120037,0x60dc00f3}},	//   лабо, smēt, _دلع_, ørme,
   {{0xfe7200d0,0xdb060383,0x6b8407bb,0x2fc007bc}},	// [3e0] _ادب_, _ankò, rgig, _inig_,
   {{0x63a007bd,0xf1ba0023,0x7a220031,0xd6c4001c}},	//   zemn, _phơi_, rôto, یمای,
   {{0x81bc0029,0x27e607be,0x443d010a,0xcb6a07bf}},	//   slēg, thon_, _oiw_, _пане_,
   {{0x4b55008f,0xdb1d022b,0x443d0231,0x601d00fc}},	//   _върт, _onsè, _niw_, témi,
   {{0x6d5c07c0,0xcc3b00c1,0xdb0605aa,0xddc4033b}},	//   obra, _רעכט, _enkò, _zviš,
   {{0xe9df00e3,0x601d07c1,0x27e607c2,0xb8660246}},	//   _dtús_, rémi, shon_, _مارو,
   {{0xe0c707c3,0xdb1d02f1,0x63a007c4,0x601d07c5}},	//   _از_, _ansè, temn, sémi,
   {{0x02a607c6,0xb27407c7,0xc27407c8,0x6e3e07c9}},	//   гром, алиш, алиј, _lipb,
   {{0x060a07ca,0x248e01af,0x443d02f1,0x370607cb}},	//   _знак_, stfm_, _diw_, _спаг,
   {{0x63a007cc,0x628007cd,0xf1a607ce,0x6d5c01cb}},	//   semn, rumo, урин, jbra,
   {{0x438600d0,0x628007cf,0xb97b00c1,0x6d5c07d0}},	//   _ملاق, sumo, ענטי, dbra,
   {{0x273a07d1,0x9f59023b,0x752801d3,0x62800143}},	//   _günü_, misë_, _izdz, pumo,
   {{0x9f59023b,0x98b80078,0x244a00fe,0x645802ac}},	//   lisë_, _ferħ_, _hùm_, lpvi,
   {{0x2fc007d2,0x6d5c07d3,0x60080555,0xc3330142}},	//   _enig_, gbra, rıma, _פוס_,
   {{0x9f5900dd,0xfaff00dd,0xdb1d07d4,0xa2ac07d5}},	//   nisë_, _ndër_, _insé, जिक्,
   {{0x61fa07d6,0x81bc00d9,0x6d5c036b,0xdb0f0072}},	//   litl, slēd, abra, _incú,
   {{0x6d5c013d,0x3ea9015e,0x9f49026a,0xe51b0336}},	// [3f0] bbra, _usat_, _amaç_, _पुनि_,
   {{0x6d5c009c,0x61fa07d7,0x9f59023b,0xdcfc01d3}},	//   cbra, nitl, kisë_, sgrā,
   {{0xa3d50006,0x9f59023b,0xdb040143,0xf9880037}},	//   _सकल_, jisë_, rdiá, انمي_,
   {{0x9f590052,0x7e7d000b,0x61fa07d8,0xa802071d}},	//   disë_, orsp, hitl, şına,
   {{0xd90f07d9,0x61fa00ad,0x224605aa,0x645802ac}},	//   _کیا_, kitl, _nuok_, epvi,
   {{0x443d07da,0xaaa8008f,0x9f590052,0xab5b042c}},	//   _siw_, _съюз_, fisë_, _unüb,
   {{0x7aed00e5,0x244a07db,0x61fa00a7,0x8235010d}},	//   lzat, _cùm_, ditl, یرخا,
   {{0x7bcd07dc,0x22460124,0x6d5c07dd,0x244a00de}},	//   njau, _buok_, zbra, _dùm_,
   {{0x7aed07de,0x11e507df,0x6d5c07e0,0xd1b9001c}},	//   nzat, ижим, ybra, نادا_,
   {{0x437500bf,0x61fa00f9,0x8467013d,0x200907e1}},	//   _چهار, gitl, _бъде, _ajai_,
   {{0x23c507e2,0x53c50789,0x9f5900dd,0x7e7d05c9}},	//   वादद, वादश, cisë_, ersp,
   {{0x229507e3,0x6d5c07e4,0xb4b107e5,0xdb1d037a}},	//   _видя, wbra, टटी_, _ensé,
   {{0x6d5c07e6,0x61fa07e7,0xda1500a4,0xceb4013c}},	//   tbra, bitl, तकात_, _azər_,
   {{0x20090063,0xdb04016d,0x7bcd00c6,0x425207e8}},	//   _ejai_, ldiç, ejau, _بنور,
   {{0x6d5c07e9,0x6f0d07ea,0x7f7607eb,0xdca607ec}},	//   rbra, _exac, _купц, шави,
   {{0x35c7000f,0xdb0400c9,0x2fc002ad,0x78ba0220}},	//   लाड़, ndiç, _unig_, _štvo,

   {{0x896607ed,0x9f590052,0x68e100bc,0x31670383}},	// [400] икаж, zisë_, _üldj, _kenz_,
   {{0x48b6008f,0x27e4009c,0x7d1e07ee,0x00000000}},	//   ищет, _slmn_, _typs, --,
   {{0x18a607ef,0xac0a07f0,0x987402c6,0x320500ca}},	//   раем, _анна_, _týče_, inly_,
   {{0x7bdf07f1,0x244a0013,0x7e64050f,0x9f590052}},	//   ckqu, _rùm_, _kwip, visë_,
   {{0xe5c607f2,0x7e640350,0xdcfe0206,0x7aed007f}},	//   иско, _jwip, _napĺ, czat,
   {{0xd49a07f3,0x5d7a0130,0x672901d3,0x9f590052}},	//   ври_, דאַק, _dzej, tisë_,
   {{0x53e607f4,0x672907f5,0x00000000,0x00000000}},	//   ициа, _ezej, --, --,
   {{0x9f59074a,0x7afb0335,0x7f44019f,0x7a2b047e}},	//   risë_, _žuti, _ngiq, rüte,
   {{0x9f5900dd,0x66e307f6,0x67290090,0x61fa07f7}},	//   sisë_, _дота, _gzej, titl,
   {{0x9f5907f8,0x244a00fe,0xeb0400aa,0x645807f9}},	//   pisë_, _tùm_, _रखैत_, ppvi,
   {{0x7aed07fa,0x9f5907fb,0x31670174,0x61fa07fc}},	//   zzat, lisé_, _denz_, ritl,
   {{0x61fa07fd,0x656807fe,0x66180146,0x7aed07ff}},	//   sitl, _hedh, lovk, yzat,
   {{0x61fa0800,0x64480801,0x9f590802,0x656800cd}},	//   pitl, _hudi, nisé_, _kedh,
   {{0x64480803,0x656803a9,0x752d030b,0x249e0804}},	//   _kudi, _jedh, řaze, _kptm_,
   {{0x315700a1,0x40350805,0x65680806,0x7b670084}},	//   _דיון_, _лекс, _medh, итае,
   {{0x81e800c7,0x64480807,0x2cba0808,0x7aed0809}},	//   _যদি_, _mudi, _drpd_, tzat,
   {{0x6e95054f,0x7bcd02fd,0x5e9500e3,0x15f8063c}},	// [410] _الخا, rjau, _الخط, ्चार_,
   {{0x2019080a,0x7bcd080b,0xa8020367,0x6448080c}},	//   losi_, sjau, şıla, _oudi,
   {{0x6618025b,0x6d45080d,0x6008026a,0xe4fb030b}},	//   dovk, _igha, kıml, एपछि_,
   {{0x65680172,0xdce7080e,0xb8ff080f,0x00000000}},	//   _aedh, najč, _तथ_, --,
   {{0xef1f07aa,0x6568001c,0x6008013c,0x00000000}},	//   zgün_, _bedh, dıml, --,
   {{0x20190810,0xbb3a00ca,0x6568001c,0xe618004d}},	//   hosi_, _תעשי, _cedh, аді_,
   {{0x20190811,0x6d450812,0x64480813,0x656801dc}},	//   kosi_, _mgha, _cudi, _dedh,
   {{0xd7740814,0x31670451,0x20190815,0xdce705db}},	//   _واقع, _senz_, josi_, jajč,
   {{0x6568068d,0x69d50816,0x20190817,0xd7f80818}},	//   _fedh, _koze, dosi_, _тур_,
   {{0x6d450819,0x656800bf,0x69d5081a,0x6448081b}},	//   _ngha, _gedh, _joze, _fudi,
   {{0x273300ef,0x7e64081c,0x201900e5,0x6448081d}},	//   _ảnh_, _swip, fosi_, _gudi,
   {{0x6d45081e,0xdb06081f,0xfaff057a,0x20190820}},	//   _agha, _laká, _reën_, gosi_,
   {{0x6d450090,0xfaff057a,0xdb1d0103,0x6008013c}},	//   _bgha, _seën_, _mosó, sımo,
   {{0xc5f20130,0x9f590084,0x64480821,0x2be0030b}},	//   ִדן_, ensä_, _yudi, नस्थ,
   {{0x76410822,0xdcf701d4,0x64480823,0x20190824}},	//   _mily, _baxı, _xudi, bosi_,
   {{0x6618025b,0x77690825,0x20190826,0x2d8c007f}},	//   zovk, _neex, cosi_, żde_,
   {{0x69d50827,0xef1f0828,0xdd110094,0x4a430161}},	// [420] _boze, ngül_, _výši, знув,
   {{0x3ea00270,0x0d76001c,0x9f59020d,0xe9d70829}},	//   _ipit_, _دیسک_, visé_, бку_,
   {{0x6568082a,0x442f082b,0x600807aa,0xb865082c}},	//   _redh, _ohg_, yıml, قانو,
   {{0x6448082d,0x7649037a,0x9f59020d,0x263d0031}},	//   _rudi, _buey, tisé_, _dňom_,
   {{0x644800e9,0x7641082e,0x66180146,0xa6fa0037}},	//   _sudi, _bily, tovk, دعاء_,
   {{0x6448082f,0x20190129,0x9f59025a,0x2d8a0830}},	//   _pudi, zosi_, risé_, ngbe_,
   {{0xdcf701d4,0x6618025b,0x764102ad,0xd4670831}},	//   _yaxı, rovk, _dily, бије_,
   {{0xdb060074,0x656800bf,0x32540832,0x69d50833}},	//   _zaká, _wedh, овир, _zoze,
   {{0x316c0710,0x60080367,0x20190834,0xaac80835}},	//   tadz_, rıml, vosi_, रमिक,
   {{0xc05a0836,0x64480479,0x76410150,0x31c600c2}},	//   лім_, _tudi, _gily, ссив,
   {{0x64480837,0x20190838,0x3ea00533,0xe80d00a4}},	//   _uudi, tosi_, _apit_, िकचा_,
   {{0x442f00f9,0x7c29003d,0x1ac8030b,0x201900c6}},	//   _ghg_, ċerk, रमाथ, uosi_,
   {{0x20190839,0x2d98083a,0x44240063,0x8af000a7}},	//   rosi_, ffre_, mlm_, ncəd,
   {{0x6d480039,0xddcd00a5,0x10f90018,0xa158004d}},	//   ždan, _stał, ابیں_, _таку_,
   {{0x69d5083b,0xd12f083c,0x7c240090,0x3ea00154}},	//   _roze, _хх_, flir, _epit_,
   {{0x68e1007a,0xdb0f034f,0x00000000,0x00000000}},	//   _üldi, _hacé, --, --,
   {{0x69d5083d,0xdd9100e3,0x4424007a,0x3a7500d3}},	// [430] _poze, _قوة_, ilm_, юлар,
   {{0x44240212,0x77690188,0x6d450239,0x7c24083e}},	//   hlm_, _seex, _ugha, alir,
   {{0x7c24083f,0x69d50840,0xdb1d0841,0xdcf700a7}},	//   blir, _voze, _insí, _taxı,
   {{0x76410842,0x77690188,0x76490843,0xe76b001c}},	//   _sily, _qeex, _puey, احان_,
   {{0x4424005c,0xdb23001c,0xdb060844,0xdce50117}},	//   dlm_, _روسی, _taká, _mehč,
   {{0x27fd0150,0x442f0479,0x4efc0327,0xdce502c6}},	//   siwn_, _shg_, נהגו, _lehč,
   {{0x64420845,0x36230018,0x628005c2,0x00000000}},	//   _bioi, _ہورہ, ermo, --,
   {{0x84360037,0xd79400e5,0x00000000,0x00000000}},	//   يكور_, _нисъ, --, --,
   {{0x6442002b,0xf34e0174,0x00000000,0x00000000}},	//   _dioi, _rụtụ_, --, --,
   {{0xfaff057a,0xbb3c006e,0xe1f90846,0xef1f0847}},	//   _reël_, נעזי, рго_, rgül_,
   {{0x600a0848,0x3ea00849,0x628001ec,0xe5c40109}},	//   ином_, _spit_, armo, _эсто,
   {{0xd9a6084a,0x6442008f,0x7a300149,0xdb1d0143}},	//   _ऑस्ट, _gioi, mäte, _ansí,
   {{0xdb0f084b,0x8db6004d,0x11d5084c,0x51f50286}},	//   _facé, осві, _мікр, _وستر,
   {{0x2cb800c4,0x00000000,0x00000000,0x00000000}},	//   tvrd_, --, --, --,
   {{0x7a30084d,0x00000000,0x00000000,0x00000000}},	//   näte, --, --, --,
   {{0xf34e00ac,0xdb0d0037,0xfaff084e,0xec1600d1}},	//   _hụrụ_, adaí, _teël_, آورد,
   {{0x53360130,0x3ea0084f,0xf34e0134,0x2d980850}},	// [440] ַנען_, _upit_, _kụrụ_, pfre_,
   {{0xf34e0294,0xa2b10851,0xa2cc0852,0x7a300853}},	//   _jụrụ_, _अनन्, _तपस्, käte,
   {{0x7c240854,0xf34e0129,0xeb9a00d3,0xa17a006e}},	//   plir, _mụrụ_, _кин_, שטעט,
   {{0xf34e0294,0xdb040076,0x7a3000c2,0xb09a006e}},	//   _lụrụ_, idiú, däte, ייער,
   {{0x7bc60855,0xdce701d3,0x00000000,0x00000000}},	//   _inku, majā, --, --,
   {{0x78af00c2,0xf34e0294,0xdce700e8,0x00000000}},	//   äivä, _nụrụ_, lajā, --,
   {{0x37e600d6,0xa6d80033,0x00000000,0x00000000}},	//   _довг, _দেশট, --, --,
   {{0x68e30856,0x7dd000c2,0xdce701d3,0x00000000}},	//   ønde, _väsy, najā, --,
   {{0xf34e0857,0x77620858,0xc1a60859,0x62800381}},	//   _bụrụ_, mbox, ојни, urmo,
   {{0x64a6085a,0x68e900b6,0x2be10034,0x776207ee}},	//   _маза, _ředi, _नवभा, lbox,
   {{0x7bc6085b,0xc95300a1,0xdce701d3,0x3d1a0096}},	//   _onku, ומת_, kajā, _मुले_,
   {{0x645a085c,0x6831085d,0x7762085e,0x03a6085f}},	//   _itti, rådg, nbox, _фидо,
   {{0xf77300a1,0xf1a900d1,0x00000000,0x00000000}},	//   וקר_, _گانه_, --, --,
   {{0xf34e0294,0x7bc60860,0x00000000,0x00000000}},	//   _gụrụ_, _anku, --, --,
   {{0xdb6b0275,0xf1a901c3,0xc31c0033,0xdb0d0076}},	//   ирал_, _دانه_, দেশি_, rdaí,
   {{0x3eb00084,0xf34e0294,0x3d1a0096,0xdce700e8}},	//   ältä_, _zụrụ_, _मुळे_, gajā,
   {{0x161a0861,0x2aab0215,0x00000000,0x00000000}},	// [450] धवार_, штво_, --, --,
   {{0x645a0862,0x7bc60863,0x200b01c2,0x39470430}},	//   _otti, _enku, lnci_, øns_,
   {{0x6d550034,0x00000000,0x00000000,0x00000000}},	//   mcza, --, --, --,
   {{0x59c9030b,0x27e90103,0x99980138,0x6d55007f}},	//   राहर, óan_, _virš_, lcza,
   {{0x645a0864,0xf1bc007d,0x68e3052f,0xc21a00c3}},	//   _atti, ्ञान, øndb, नकाब_,
   {{0x7a3001bf,0xeabf0139,0x6b8d0865,0x00000000}},	//   täte, _irù_, lgag, --,
   {{0x69c70866,0xf34e0129,0x69cd0096,0x7d180120}},	//   _inje, _rụrụ_, साठी, _øvst,
   {{0xf7730867,0x7a300868,0x59c900a4,0x6aad024a}},	//   _زار_, räte, रावर, owaf,
   {{0x645a0869,0xdb0f0328,0xc7b20327,0x35f5086a}},	//   _etti, _incó, _אבן_, _епар,
   {{0x24840174,0x765b086b,0x200b007f,0x7a30086c}},	//   _ịmee_, _ituy, enci_, päte,
   {{0x6d5500a5,0xc617086d,0x60410134,0x69c70786}},	//   dcza, दकीय_, _ịmaa, _mnje,
   {{0xdb040076,0x2477020a,0x6d55007f,0x6aad086e}},	//   rdiú, măm_, ecza, kwaf,
   {{0x63a9086f,0xf34e0129,0xa3b4007a,0x33f406cf}},	//   meen, _tụrụ_, _छोट_, _تسلس,
   {{0x63a90313,0x225f0498,0xed570870,0x6b8d010a}},	//   leen, mpuk_, зор_, egag,
   {{0x8af00092,0xdce701d3,0x200b01c2,0xdb0f037a}},	//   hbət, tajā, bnci_, _oncó,
   {{0x24510871,0x69c70872,0x63a90873,0x60dc0874}},	//   _mám_, _anje, neen, ärme,
   {{0x765b0875,0x20020876,0xca8600d3,0xdce70877}},	// [460] _ntuy, miki_, ягай, rajā,
   {{0x14bd06e4,0x63a90878,0xe9d70879,0x4efb00ca}},	//   ्माण, heen, пку_, _להפו,
   {{0x2451087a,0x63a9087b,0x02a8087c,0x7a2b0364}},	//   _nám_, keen, _कन्न, mütl,
   {{0x2002087d,0x7bc6067d,0x63a9087e,0x3ce500f3}},	//   niki_, _unku, jeen, ølve_,
   {{0x63a9087f,0xdb060212,0xa3cf0409,0x569404e6}},	//   deen, _bakå, शान_, фалт,
   {{0xf1d00019,0x9f590146,0xdb0f0042,0x69c70880}},	//   _mạch_, visí_, _encó, _gnje,
   {{0x24510019,0x247700d3,0x18a30881,0x765b06b0}},	//   _cám_, găm_, _парм, _etuy,
   {{0x63a9008a,0x24510882,0xa6d30081,0x6d5500a5}},	//   geen, _dám_, _দেওয়, zcza,
   {{0x20020883,0x36670884,0x6d5500a5,0xdce501d3}},	//   diki_, _нато_, ycza, _mehā,
   {{0x683102fe,0x2b460206,0xdce7044c,0x2477044c}},	//   råde, ľoch_, najă, băm_,
   {{0x20020885,0x80df00c7,0x63a90886,0xf1af0037}},	//   fiki_, _ফেব্, been, اءً_,
   {{0xf1d00019,0x27e60887,0x6d550034,0x63a90888}},	//   _bạch_, nkon_, wcza, ceen,
   {{0x27e60889,0xf19400c2,0xf1d0020b,0x00000000}},	//   ikon_, _жиль, _cạch_, --,
   {{0xdb0f00b3,0x7a2b0233,0x27e6088a,0x752402c6}},	//   _oncò, gütl, hkon_, řizu,
   {{0x2002088b,0x6d550034,0x24510023,0x1b5a0174}},	//   biki_, rcza, _xám_, _ọnụm,
   {{0x69c70268,0x1bd4088c,0xe50d0179,0x394a042c}},	//   _snje, нося, िपति_, _agbs_,
   {{0xf1d000de,0x2477020a,0x00000000,0x00000000}},	// [470] _gạch_, zăm_, --, --,
   {{0x2fc901fa,0x8af00092,0x20b0088d,0xceb40327}},	//   _hnag_, vbət, _जनाध, _טיפ_,
   {{0x63a9088e,0x67d5088f,0x4ddc00ca,0x765b0381}},	//   yeen, можу, _לחזו, _stuy,
   {{0xdb0f0890,0x321e0891,0x2a60023e,0x27e60892}},	//   _hací, hoty_, bpib_, gkon_,
   {{0x2451025b,0x63a90893,0x9f4b034f,0xa26300fe}},	//   _sám_, veen, licó_, _chố,
   {{0x20020894,0x63a9008a,0x27e602b1,0x247700ae}},	//   ziki_, ween, akon_, tăm_,
   {{0x58840895,0x63a90896,0xd5fb0174,0xdb0f0143}},	//   _пыта, teen, _apụ, _mací,
   {{0x24510897,0x7a300898,0x247700ae,0xf8b200ca}},	//   _vám_, mäta, răm_, _בשל_,
   {{0x27ff0899,0x63a9089a,0x765b0193,0x2002089b}},	//   _imun_, reen, _utuy, viki_,
   {{0x130602fd,0x81bc00d9,0x24510019,0x68e1007a}},	//   ьный_, blēm, _tám_, _ülds,
   {{0x2002089c,0x6603089d,0xf1d00019,0x2fc901ec}},	//   tiki_, mink, _sạch_, _bnag_,
   {{0x9f4b058a,0x2fc9089e,0x351a006e,0x00000000}},	//   dicó_, _cnag_, _ווענ, --,
   {{0x2002089f,0x628908a0,0xddcd084f,0x8af001d4}},	//   riki_, queo, _svaš, hbər,
   {{0x660308a1,0x200208a2,0xc33200a1,0x9f4b058a}},	//   nink, siki_, _סוג_, ficó_,
   {{0x27ed08a3,0x801608a4,0x81bc00d9,0x200208a5}},	//   _olen_, _офиц, klēj, piki_,
   {{0x2d8401e8,0x660308a6,0xbf9b0131,0x00000000}},	//   şme_, hink, liên, --,
   {{0x660308a7,0xdb0f08a8,0x78a908a9,0x224708aa}},	// [480] kink, _fací, _ćeva, _kink_,
   {{0xceb40253,0x660308ab,0x27ed0559,0x27ff01c2}},	//   _isə_, jink, _alen_, _amun_,
   {{0x660308ac,0x2fc9005c,0xe4f4030b,0x27e608ad}},	//   dink, _ynag_, ेपछि_, tkon_,
   {{0xbf9b0023,0xfbdf0023,0x9f4b028d,0xeabf0139}},	//   hiên, _hiên_, licò_, _iyùn_,
   {{0x27e608ae,0x660308af,0x224708b0,0xfbdf00de}},	//   rkon_, fink, _oink_, _kiên_,
   {{0x27e608b1,0x27ed08b2,0x27ff01c8,0x7ae40169}},	//   skon_, _elen_, _emun_, myit,
   {{0xdcfe01e8,0xbf9b001f,0xfbdf0023,0x321e0094}},	//   _kapı, diên, _miên_, voty_,
   {{0xfbdf00ef,0x69dc08b3,0xbf9b00fd,0x21e9037a}},	//   _liên_, _hore, nnêt, _búho_,
   {{0x518608b4,0x12be0033,0x7ae408b5,0x23270291}},	//   муна, েন্দ, nyit, моћи_,
   {{0xfbdf0019,0x660308b6,0x70c90179,0xbf9b016d}},	//   _niên_, cink, िमूल, giên,
   {{0x69dc08b7,0x22470665,0x9f4b028d,0x27ed00c2}},	//   _more, _dink_, dicò_, _ylen_,
   {{0xe36308b8,0x69dc08b9,0xd01108ba,0xdce7007f}},	//   _акци, _lore, الح_, nają,
   {{0xe81f000c,0x3f8508bb,0x224708bc,0xfbdf0019}},	//   यकता_, ğlu_, _fink_, _biên_,
   {{0xbf9b001f,0x69dc00f3,0x06e10081,0x9f4b034f}},	//   ciên, _nore, _মেডি, ticó_,
   {{0x628608bd,0xdb0f0890,0x764808be,0xdce70034}},	//   škod, _vací, _midy, kają,
   {{0x660308bf,0xdb0d001f,0x1bb80037,0xe80008c0}},	//   zink, ndaç, واقع_, लोमा_,
   {{0x660308c1,0x63a208c2,0xdce700a5,0x5a3508c3}},	// [490] yink, _mbon, dają, енат,
   {{0x69dc08c4,0x7e6d0051,0xddc408c5,0x27ff0113}},	//   _core, _iwap, _zviž, _smun_,
   {{0x660308c6,0x69dc08c7,0x27ed06a3,0x3d100096}},	//   vink, _dore, _plen_, णपणे_,
   {{0xdd0d00a5,0x660308c8,0xdce70034,0x7e6d08c9}},	//   półp, wink, gają, _kwap,
   {{0x69dc08ca,0x660301b3,0x366908cb,0xf7700602}},	//   _fore, tink, чало_, شان_,
   {{0x7e6d08cc,0xfbdf00fe,0x04b500e5,0x00000000}},	//   _mwap, _xiên_, есия, --,
   {{0xdcfe074e,0xa3e3007a,0x7bdd08cd,0xb7d50065}},	//   _yapı, _नकद_, _kosu, _aṣeh,
   {{0x660308ce,0x7f4d08cf,0x69dc08d0,0xdb060220}},	//   sink, _ngaq, _zore, _rakú,
   {{0x69c40336,0x3d0604a9,0x7bdd02c9,0xc24508d1}},	//   राची, _हेने_, _mosu, нник,
   {{0xdb1d0149,0x69dc0188,0x7bdd08d2,0xddc400d4}},	//   _insä, _xore, _losu, _sviž,
   {{0xbf9b0396,0x67290085,0x80c902d5,0x91d00081}},	//   riên, _hyej, िमें, িসংখ,
   {{0x6e2508d3,0x34bd08d4,0x60dc0212,0x7e6d08d5}},	//   _akhb, ्मीद, ärma, _bwap,
   {{0x63bb08d6,0xdb060032,0x6264004d,0xbf9b0231}},	//   mdun, _fakù, _авіа, piên,
   {{0x63bb08d7,0xf1d00019,0x409508d8,0x63b9003d}},	//   ldun, _hạnh_, _зрит, _hawn,
   {{0xdca308d9,0xfbdf00ef,0x320508da,0xa3e3009d}},	//   лари, _viên_, mily_, _नका_,
   {{0x63bb08db,0xc4d20130,0x7bdd00d3,0x6724003d}},	//   ndun, נגן_, _cosu, żiji,
   {{0x69dc00e9,0x629b0895,0xfbdf0028,0xf1d00028}},	// [4a0] _pore, ntuo, _tiên_, _mạnh_,
   {{0xf1d00028,0x81e10081,0x7ae40079,0xdce70034}},	//   _lạnh_, নোর_, ryit, wają,
   {{0x69dc08dc,0xdcfe0740,0xdce70034,0x672908dd}},	//   _vore, _tapı, tają, _ayej,
   {{0x76480124,0x629b0138,0x67290172,0xdbcd0139}},	//   _sidy, ktuo, _byej, _dóós,
   {{0x69dc08de,0xdce70034,0x7c2600bd,0x63bb08df}},	//   _tore, rają, _ikkr, ddun,
   {{0xb90600c7,0x629b0124,0x63bb08e0,0x7bdd08e1}},	//   _বই_, dtuo, edun, _zosu,
   {{0x7bdd08e2,0x06d80081,0x68e100aa,0x764808e3}},	//   _yosu, _দেখি, _üldp, _vidy,
   {{0xf1d00019,0x764808e4,0x63bb0009,0x326608e5}},	//   _cạnh_, _widy, gdun, нтов,
   {{0x63b908e6,0x32050146,0x76480154,0x629b02c9}},	//   _dawn, fily_, _tidy, gtuo,
   {{0xa2b108e7,0x75280034,0x26c40062,0x7e6d0027}},	//   _अनर्, _tydz, _irmo_, _rwap,
   {{0x681500a5,0x63b908e8,0xdb1d0212,0xdb0f0076}},	//   ląda, _fawn, _inså, _macá,
   {{0x63a208e9,0x20d500c6,0x26c40141,0x7e6d0154}},	//   _ubon, džią_, _krmo_, _pwap,
   {{0x91e608ea,0x442608eb,0x2d8508ec,0x3205025b}},	//   _поде, _iko_, óleo_, bily_,
   {{0x92f203a3,0x7bdd08ed,0x00000000,0x00000000}},	//   ığım, _sosu, --, --,
   {{0xe57100c1,0x23c40179,0x442608ee,0x31bb00ca}},	//   יַן_, _वफाद, _kko_, _מזגנ,
   {{0x442605db,0x7e6d08ef,0x7f4d039f,0x00000000}},	//   _jko_, _twap, _ugaq, --,
   {{0xbbe10557,0x7e6d08f0,0x442608f1,0xafdb02b6}},	// [4b0] _नवीक, _uwap, _mko_, rmød,
   {{0x99990138,0xafdb02b6,0x3ea90113,0xd6d100d1}},	//   _rusų_, smød, _ipat_, یقا_,
   {{0x78ba0181,0xa77508f2,0x7bdd08f3,0xef200034}},	//   _štvr, влеч, _tosu, ążek_,
   {{0x442608f4,0x6b6700fd,0xfbdf0023,0xdb1d0212}},	//   _nko_, _dégâ, _kiêm_, _anså,
   {{0x7c2d08f5,0x212b00de,0x69c108f6,0x8af000a7}},	//   mlar, ́ch_, _óleo, ncəl,
   {{0x442608f7,0x7c2d08f8,0xeb9f02ec,0xe5a508f9}},	//   _ako_, llar, _gjør_, тики,
   {{0x34bd08fa,0x320508fb,0xfbdf0023,0x7c2d08fc}},	//   ्मेद, vily_, _liêm_, olar,
   {{0x7c2d08fd,0x629b08fe,0xd6d80081,0xe7950018}},	//   nlar, ttuo, _দেওয, _جاسک,
   {{0x63bb08ff,0x44260900,0x7c2d01e9,0xfbdf0023}},	//   rdun, _dko_, ilar, _niêm_,
   {{0x3d1a0067,0x7c2d07aa,0x44260901,0x229200bf}},	//   _मुझे_, hlar, _eko_, گلیس,
   {{0x7c2d0902,0x629b0903,0x23e700d6,0xc952040a}},	//   klar, stuo, _підв, ימי_,
   {{0x7c2d0587,0x2d810113,0x32050904,0xdee60905}},	//   jlar, _adhe_, sily_, воми,
   {{0x443f0906,0x7c2d0907,0x442d0908,0x644b00f9}},	//   mmu_, dlar, mle_, _iigi,
   {{0x644b0909,0x3ea9090a,0x7c2d090b,0x600b00c2}},	//   _higi, _dpat_, elar, tömä,
   {{0x442d090c,0x644b090d,0x7c2d090e,0xed57090f}},	//   ole_, _kigi, flar, тос_,
   {{0x2d810910,0x442d0911,0x7c2d0912,0x443f0913}},	//   _edhe_, nle_, glar, nmu_,
   {{0x442d03ea,0x443f0914,0xdb0f00e3,0x8c430915}},	// [4c0] ile_, imu_, _pacá, рете,
   {{0x644b0916,0x442d0917,0x443f0918,0xfaa302f3}},	//   _ligi, hle_, hmu_, рафо,
   {{0x7c2d0919,0x443f0706,0x442d091a,0x81c30033}},	//   blar, kmu_, kle_, _একা_,
   {{0x443f023c,0x442d091b,0x644b05bd,0x1867091c}},	//   jmu_, jle_, _nigi, таци_,
   {{0x442d091d,0x443f091e,0x9696013d,0x6d5c009c}},	//   dle_, dmu_, треш, ocra,
   {{0x442d091f,0x442600bb,0x443f0920,0x7c240921}},	//   ele_, _sko_, emu_, loir,
   {{0x69ce0922,0x644b0193,0xeb9f00d6,0x44260923}},	//   _inbe, _bigi, _kjøp_, _pko_,
   {{0x68e30924,0x644b0925,0xe4e300d6,0x26c405db}},	//   ände, _cigi, рішн, _trmo_,
   {{0x644b0926,0xf7430927,0x44260928,0x26c400bc}},	//   _digi, _вето, _vko_, _urmo_,
   {{0x442d0929,0x7c2d08bb,0x644b092a,0x443f092b}},	//   ale_, zlar, _eigi, amu_,
   {{0x442d092c,0x4426092d,0x7c2d092e,0xf99300a1}},	//   ble_, _tko_, ylar, ברת_,
   {{0x4426092f,0x442d0930,0x644b0931,0x62890932}},	//   _uko_, cle_, _gigi, breo,
   {{0x7c240933,0x69ce0934,0x7c2d0935,0x68380072}},	//   doir, _onbe, vlar, cíde,
   {{0x44240936,0x82770130,0x644b0937,0xfbdf0019}},	//   lom_, _יעדע_, _zigi, _viêm_,
   {{0x7c2d06d7,0x644b02a4,0x2d580938,0x7c2400e3}},	//   tlar, _yigi, тись_, foir,
   {{0x69ce0939,0xfbdf00de,0x0a6b07ed,0x6c6a0018}},	//   _anbe, _tiêm_, држи_, علقہ_,
   {{0x7c2d093a,0x3b5400d3,0x644000c2,0x3ea902c9}},	// [4d0] rlar, ркур, immi, _upat_,
   {{0x4424093b,0x7c2d093c,0x442d093d,0x7e7d093e}},	//   hom_, slar, zle_, mssp,
   {{0x442d093f,0x7c2d03a3,0x443f0940,0xa3e3009f}},	//   yle_, plar, ymu_, _नकल_,
   {{0x7c2d0253,0x44240941,0xb8db0942,0x69ce0943}},	//   qlar, jom_, _अन_, _enbe,
   {{0x442d032e,0xc1780138,0x644b0944,0x6d4800c4}},	//   vle_, nkės_, _rigi, ždat,
   {{0x68380945,0x69d80018,0xdb0600b6,0x1a6800cd}},	//   víde, övet, _jaký, _شیمی_,
   {{0x442d0946,0x18b80084,0x443f0947,0x644b0948}},	//   tle_, _игры_, tmu_, _pigi,
   {{0x442402e6,0x442d0949,0x6289094a,0x443f094b}},	//   gom_, ule_, treo, umu_,
   {{0x442d094c,0x644b094d,0x11d900e3,0x395105db}},	//   rle_, _vigi, فوظة_, _kgzs_,
   {{0x442d094e,0x443f094f,0xe0d90950,0x62890951}},	//   sle_, smu_, ево_, rreo,
   {{0x442d0952,0x443f0498,0x644b0953,0x33950018}},	//   ple_, pmu_, _tigi, _ملاز,
   {{0x44240954,0x644b0955,0x68380956,0x7c2401ff}},	//   com_, _uigi, píde, xoir,
   {{0x7c240257,0x7e7d0957,0x3f9e0034,0x00000000}},	//   voir, gssp, ętu_, --,
   {{0x7bcf0958,0x645c016d,0xdb040959,0x8635006e}},	//   _ancu, _éric, leiç, טאָג_,
   {{0x7c24025a,0x0c79055b,0x2019095a,0x6d5c095b}},	//   toir, ксты_, éric_, rcra,
   {{0x6d5c095c,0xf09200ca,0x00000000,0x00000000}},	//   scra, _הנה_, --, --,
   {{0x7c24095d,0x00000000,0x00000000,0x00000000}},	// [4e0] roir, --, --, --,
   {{0x7bcf095e,0x7c24095f,0x7a2b00bc,0x00000000}},	//   _encu, soir, kütu, --,
   {{0x2fd700bf,0xdb040960,0x7c24020d,0x6fd80096}},	//   _شوید_, rdiñ, poir, यापू,
   {{0x78800074,0x27e00102,0x61e00961,0x44240962}},	//   _návš, ðin_, _पक्ष, xom_,
   {{0x4a750963,0x44240964,0x2bd10965,0xfbd10966}},	//   _выст, vom_, हारा, हारम,
   {{0x69ce02e2,0x442402c9,0x00000000,0x00000000}},	//   _unbe, wom_, --, --,
   {{0xdb040161,0xa3cf0285,0xb4ce00b7,0x54a60076}},	//   feiç, शां_, शमे_, احتف,
   {{0xd90d00bf,0x644000e7,0x3a2a0967,0x7e640968}},	//   _تیم_, ummi, _hkbp_, _otip,
   {{0x81bc0029,0x64400969,0x6596096a,0x00000000}},	//   klēt, rmmi, _مجار, --,
   {{0x683800b6,0x2458096b,0xdd1f0206,0x7a30007b}},	//   bídc, _tém_, _líši, dätk,
   {{0x7e64096c,0x4424096d,0xf99300a1,0xddcd096e}},	//   _atip, pom_, זרת_, _ataş,
   {{0x4424096f,0x7e7d0970,0x1e1d0971,0x660a0972}},	//   qom_, tssp, पक्ष_, lifk,
   {{0xbb1b044c,0x81e30033,0x00000000,0x00000000}},	//   _adîn, _নগর_, --, --,
   {{0xdb070018,0xdb060103,0x7e7d0973,0x52830037}},	//   ámít, _lakó, rssp, _الوك,
   {{0x40350974,0x9f520154,0x70940975,0x00000000}},	//   _кекс, _olyè_, _тайф, --,
   {{0xf1d20976,0x7a300220,0x3a2a0085,0xdb06008b}},	//   तावन, bätk, _akbp_, _fakü,
   {{0x200b0977,0x49750978,0xdb060220,0x7a570037}},	// [4f0] mici_, илас, _taký, اضرا,
   {{0xdd910979,0xd91b00c2,0x2c51007f,0x00000000}},	//   _بود_, нье_, _sądu_, --,
   {{0x87e70927,0xd7e7097a,0x00000000,0x00000000}},	//   люде, лідо, --, --,
   {{0x200b08a9,0x69d8097b,0x3dcd03e3,0xf3f100fe}},	//   nici_, över, ɓewa_, _mục_,
   {{0x7c3a00fd,0xb5fd0138,0xdb1d0052,0x6fa7097c}},	//   ître, _atša, _masë, ट्यू,
   {{0x4877097d,0xdb0e0088,0x7bd70138,0x200b097e}},	//   _مدرس, _þjál, šbuč, hici_,
   {{0x200b097f,0xdb1d052f,0x25b60037,0x00000000}},	//   kici_, _ansø, شهيد_, --,
   {{0x73e508d8,0x69c90980,0x28e200bc,0xe4c80981}},	//   роиз, _होती, पहरि, ابون_,
   {{0x200b0982,0x22150983,0x45d500ae,0x62860984}},	//   dici_, ифор, _коас, škon,
   {{0xe1250508,0x9f59028d,0x7a3000c2,0xdb060154}},	//   импи, misù_, vätk, _kakò,
   {{0x200b0985,0x7e640986,0xdb0602f1,0x26e30294}},	//   fici_, _stip, _jakò, ̣rọ_,
   {{0x200b0987,0x764300a4,0xf3f100fe,0xdb060383}},	//   gici_, lmny, _dục_, _makò,
   {{0x32630018,0xdb0602f1,0x32670202,0xd343001c}},	//   _انتہ, _lakò, _стев, _افشی,
   {{0x61450231,0x7e64025b,0x3f8c00a7,0x00000000}},	//   _кела, _vtip, şdu_, --,
   {{0x443d006c,0x76430167,0x61e30988,0x00000000}},	//   _khw_, imny, _ionl, --,
   {{0x200b0989,0x61e30018,0xab66098a,0x784500c6}},	//   cici_, _honl, рвал, _tėvy,
   {{0x395600c9,0x61e3098b,0x7a2b0018,0xda650037}},	// [500] ањет, _konl, yütt, مالي,
   {{0x61e30113,0x2fc000ee,0xdb060154,0xdb1d098c}},	//   _jonl, _haig_, _bakò, _masè,
   {{0x61e3098d,0xdb1d022b,0x443d0381,0xd826098e}},	//   _monl, _lasè, _ohw_, аджи,
   {{0xb8ce05d4,0xe666098f,0x443d02ad,0xb8fe074c}},	//   _कह_, атко, _nhw_, _तप_,
   {{0x2fc00990,0xddd6025b,0xb8660103,0x660a0991}},	//   _maig_, _zvyš, _چارو, tifk,
   {{0x2d980992,0x200b030b,0x2fc00993,0x645e0161}},	//   ngre_, zici_, _laig_, ípio,
   {{0x443d005c,0x200b0367,0x9f4200c2,0x3ea00090}},	//   _bhw_, yici_, lkkä_, _lqit_,
   {{0xe8d700a1,0x25a90106,0x76430994,0x25a000b6}},	//   _דולר_, đala_, amny, řil_,
   {{0x9f4902a5,0x78af0995,0x61e300c4,0x68380072}},	//   _ilaç_, čivš, _bonl, cída,
   {{0x61e30996,0xc05a01b3,0x00000000,0x00000000}},	//   _conl, кім_, --, --,
   {{0x61e30997,0x3a3700a1,0x2fc00998,0x39570327}},	//   _donl, שרים_, _baig_, ישים_,
   {{0x2fc0023e,0xdb1d0154,0xf42700ae,0x00000000}},	//   _caig_, _fasè, _кохл_, --,
   {{0x200b0999,0x2fc0099a,0x00000000,0x00000000}},	//   rici_, _daig_, --, --,
   {{0x6282099b,0x9f49099c,0x2d85020d,0xf3f100fe}},	//   _ivoo, _llaç_, ûle_, _tục_,
   {{0x52b6099d,0x6e27099e,0x200b099f,0x02b607d5}},	//   _अनुस, rojb, pici_, _अनुन,
   {{0x3b55083c,0xd0f700ca,0x2fc000b3,0x61e3029a}},	//   скар, _כמות_, _gaig_, _zonl,
   {{0xa3a809a0,0xdb1d00d1,0x61fa09a1,0x00000000}},	// [510] ख्य_, _kasé, ohtl, --,
   {{0xf9930602,0x6838030b,0x98c709a2,0x8af000a7}},	//   تبر_, vída, исел, nbəy,
   {{0x2fc001fa,0xdb1d0763,0xb9c40037,0x00000000}},	//   _yaig_, _masé, تقلي, --,
   {{0x200901c2,0x628009a3,0x2a6909a1,0x00000000}},	//   _jmai_, ksmo, ppab_, --,
   {{0x6fd8009d,0x27e4020a,0xf9930037,0x00000000}},	//   यातू, _domn_, _وبس_, --,
   {{0x7aed010a,0x764309a4,0x96210285,0x00000000}},	//   myat, umny, यवेट_, --,
   {{0xfc3f0028,0x7aed09a5,0x76430085,0x00000000}},	//   _khí_, lyat, rmny, --,
   {{0x248909a6,0x81c30081,0x61e309a7,0x1d1800ca}},	//   čam_, _একই_, _sonl, יקור_,
   {{0xfc3f00e3,0x645c0018,0xf1d2009d,0x628009a8}},	//   _mhí_, _érin, तांन, gsmo,
   {{0x201909a9,0x200909aa,0x7a3009ab,0x673b09ac}},	//   érin_, _amai_, täti, _izuj,
   {{0x7aed0167,0x62800313,0x61e309ad,0x443d02db}},	//   hyat, asmo, _vonl, _thw_,
   {{0xfc3f00de,0xfbdf0023,0x7a3009ae,0xafdb09af}},	//   _nhí_, _kiêu_, räti, smøn,
   {{0x2fc00472,0x7a300084,0x0cd009b0,0x61e30847}},	//   _vaig_, säti, हम्म, _tonl,
   {{0x61fa09b1,0x7aed09b2,0xfc3f09b3,0x3edf0294}},	//   chtl, dyat, _ahí_, _gwọọ_,
   {{0x4095054f,0xfc3f054f,0x2fc001fa,0xfbdf0023}},	//   _العر, _bhí_, _taig_, _liêu_,
   {{0xfc3f0028,0x7ff609b4,0x3ce50222,0x79870383}},	//   _chí_, _دستا, älva_, _adjw,
   {{0x68e309b5,0x44c700fe,0x7aed01f9,0x27e4009c}},	// [520] ändn, _lđ_, gyat, _romn_,
   {{0xc3320054,0x200e00a5,0x27e400ae,0xddcd0146}},	//   לון_, ślić_, _somn_, _zvaž,
   {{0x224b0220,0x44c70023,0xe93a07ed,0x9f4900ee}},	//   ícky_, _nđ_, учај_, _plaç_,
   {{0x628009b6,0x8b96004d,0x7aed09b7,0x60dc02c3}},	//   ysmo, _уроч, byat, ärmi,
   {{0x673b0034,0x7aed0079,0x683800b6,0x661a0167}},	//   _czuj, cyat, bídn, _pjtk,
   {{0x99d60241,0x600f05aa,0xd49a09b8,0xfbdf00fe}},	//   _اتحا, _kòmè, гри_, _diêu_,
   {{0x320c022b,0x44c700de,0x7589004d,0xdb1d020d}},	//   vidy_, _cđ_, рсів_, _rasé,
   {{0xc7a309b9,0x628609ba,0x628009bb,0x07a300f3}},	//   _ниск, škom, tsmo, _насн,
   {{0x6aa409bc,0x6d430146,0x200900dc,0xdb1d09bd}},	//   ntif, _únav, _rmai_, _pasé,
   {{0x60ca0085,0x20090063,0x628009be,0xaac900b6}},	//   _prfm, _smai_, rsmo, रितक,
   {{0x2019001f,0x320c0094,0x44c700fe,0xe7bc0179}},	//   ério_, ridy_, _gđ_, _ईसाप,
   {{0x7aed09bf,0x6aa4048e,0xf53700a1,0x91a70174}},	//   yyat, ktif, _פנאי_, _piṇ_,
   {{0x733600cd,0x657a001c,0x645a09c0,0xfbdf00fe}},	//   _ارائ, _keth, _huti, _xiêu_,
   {{0x329b09c1,0x7aed09c2,0xe7cf09c3,0xa2b709c4}},	//   _עבוד, vyat, _सोनप, ्टर्,
   {{0xf1a900bf,0xfc3f0028,0x657a09c5,0x317e00e7}},	//   _خانه_, _phí_, _meth, matz_,
   {{0x645a09c6,0x657a09c7,0x317e01bf,0x20090063}},	//   _muti, _leth, latz_, _umai_,
   {{0x645a09c8,0x1a5b00e3,0xed4e0103,0x7c3a014b}},	// [530] _luti, اشرة_, ٹھی_, îtra,
   {{0x645a025a,0x7aed09c9,0xa3a80557,0x9f4b02c6}},	//   _outi, ryat, ख्त_, nkcí_,
   {{0xe8e0011b,0x2bc409ca,0xfbdf0023,0x317800a5}},	//   ười_, _लोका, _siêu_, órzy_,
   {{0x317e09cb,0x657a0178,0x4735001f,0x00000000}},	//   hatz_, _aeth, онес, --,
   {{0x657a09cc,0x6aa409cd,0xe70b00cd,0x3f890239}},	//   _beth, ctif, دتان_, _mdau_,
   {{0x645a09ce,0x25a90106,0x657a001c,0x63ab0063}},	//   _buti, đalo_, _ceth, _sbgn,
   {{0x69d509cf,0x645a002d,0x8ccc09d0,0x44290019}},	//   _inze, _cuti, हियो, _ưa_,
   {{0xfbdf0028,0x69c509d1,0x657a01cb,0x61f801cb}},	//   _tiêu_, ldhe, _eeth, _alvl,
   {{0x6fdd009d,0x657a09d2,0xdb1d09d3,0xb5a70002}},	//   यानं, _feth, _insó, _грей,
   {{0x69c509d4,0x657a09d5,0x645a09d6,0x317e09d7}},	//   ndhe, _geth, _futi, gatz_,
   {{0xf99209c1,0x69c50049,0x645a09d8,0x7a300084}},	//   ורי_, idhe, _guti, mätt,
   {{0x7a3009d9,0x777b0257,0x81bc00d9,0x657a0201}},	//   lätt, _jeux, slēp, _zeth,
   {{0x3f890150,0x69d509da,0x657a0060,0x645a0827}},	//   _ddau_, _onze, _yeth, _zuti,
   {{0x317e0350,0x201909db,0x2d9e09dc,0x3f8900eb}},	//   catz_, ansi_, üte_, _edau_,
   {{0x69c503a8,0x68e30364,0xb147001c,0x271509dd}},	//   ddhe, ändl, _دیدم_, तपुर_,
   {{0x69d502dc,0x7bc402e5,0x6aa409de,0x7a3009df}},	//   _anze, udiu, ttif, hätt,
   {{0xb4b6033a,0xfaa309e0,0x7bc409e1,0x6aa409e2}},	// [540] _छन्_, мато, rdiu, utif,
   {{0x69c509e3,0xe9d709e4,0x8eb30018,0x99630094}},	//   gdhe, оку_, _کمیش, _píšu_,
   {{0x02b6022d,0xd91009e5,0x657a09e6,0x20dc0220}},	//   _अन्न, ریر_, _reth, pšiť_,
   {{0x657a09e7,0x5fdd009d,0x26cd0072,0x69d509e8}},	//   _seth, यायल, _breo_, _enze,
   {{0x26cd09e9,0x645a09ea,0x777b0257,0x657a09eb}},	//   _creo_, _suti, _deux, _peth,
   {{0x7c36003e,0x63a909ec,0x76410178,0x7aeb042c}},	//   llyr, efen, _chly, ägte,
   {{0x63a909ed,0x5fca0976,0x6fca0296,0x788002c6}},	//   ffen, ियाल, ियां, _dává,
   {{0x657a09ee,0x63a90150,0x26cd002b,0x442f0063}},	//   _weth, gfen, _freo_, _ckg_,
   {{0x26cd0124,0x442f09ef,0x645a09f0,0x7a3007ee}},	//   _greo_, _dkg_, _wuti, bätt,
   {{0x645a09f1,0x914a09f2,0x238c0138,0x1546002d}},	//   _tuti, ична_, dėjų_, _дезм,
   {{0x645a02fd,0x425400cd,0x96c20789,0x69db009d}},	//   _uuti, _کنتر, लिकॉ, नाती,
   {{0x317e01bf,0x765b010a,0x00000000,0x00000000}},	//   satz_, _yuuy, --, --,
   {{0x238c00c6,0x531600d1,0x69c509f3,0x386a033c}},	//   gėjų_, _بذار, ydhe, _ltbr_,
   {{0x81f809f4,0xc693021e,0x69c50188,0x3f8401cd}},	//   _دفتر_, ואש_, xdhe, ómur_,
   {{0x644209f5,0x271c0028,0x71260037,0x1bd500e5}},	//   _khoi, ỉnh_, _برشل, повя,
   {{0x60240291,0xdfd10037,0x929d007f,0x00000000}},	//   _одја, _أية_, szłe, --,
   {{0x34b709f6,0x644209f7,0xdb1d022b,0x8af000a7}},	// [550] _आन्द, _mhoi, _ansò, dcəs,
   {{0x78a50102,0x69c501cb,0x59d204d7,0x00000000}},	//   tthv, udhe, सागर, --,
   {{0x69c509f8,0x26cd08a9,0x62860094,0xd75909f9}},	//   rdhe, _sreo_, škoh, ملات_,
   {{0x76410052,0x69c50052,0x78a501ab,0x00000000}},	//   _shly, sdhe, rthv, --,
   {{0x2bc4007d,0x7c2d09fa,0x7bda00a1,0x7a3009ab}},	//   _लोटा, moar, _הקרו, tätt,
   {{0x7c2d09fb,0x26cd00d3,0x1dcb0438,0x29070037}},	//   loar, _vreo_, ायित, únas_,
   {{0x7a3009fc,0x644202bc,0x6ab90092,0xdb1d09fd}},	//   rätt, _bhoi, şafı, _masí,
   {{0x7a3009fc,0x57b409fe,0x644209ff,0x7c2d0a00}},	//   sätt, _обст, _choi, noar,
   {{0xd5bb0a01,0x64420a02,0x63a90a03,0x7c2d01c8}},	//   _все_, _dhoi, rfen, ioar,
   {{0x63a90a04,0x7c2d0a05,0xdb0d0a06,0x1306007b}},	//   sfen, hoar, ndañ, яный_,
   {{0xf99207a6,0x64420514,0x7c2d02a7,0x3eb20a07}},	//   ערט_, _fhoi, koar, _spyt_,
   {{0xb4d70a08,0xa3bb0a09,0x644209f7,0x442f0a0a}},	//   ामी_, _خاطر_, _ghoi, _ukg_,
   {{0x7c2d0a0b,0x64490a0c,0x317c05db,0x00000000}},	//   doar, mmei, _fevz_, --,
   {{0x64490a0d,0xfce60a0e,0x238c00c6,0x8b08007f}},	//   lmei, пого, rėjų_, nięż,
   {{0x1fb6036f,0xe6b804f8,0x7c2d0a0f,0x238c00c6}},	//   _еспр, _इन्ज, foar, sėjų_,
   {{0x644901b5,0x7c2d0a10,0x1e860a11,0xb91a0129}},	//   nmei, goar, _елим, anyị_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [560] --, --, --, --,
   {{0x3f82042b,0x64490a12,0xdcfc0a13,0x2d9c00f2}},	//   laku_, hmei, larč, _øve_,
   {{0x23bd034d,0x6e2e0a14,0x53bd0592,0x9f590314}},	//   ्याद, mobb, ्याश, cisó_,
   {{0x3f820a15,0x7a3001bf,0xdb1d00b6,0x7c2d020a}},	//   naku_, täts, _zasí, coar,
   {{0x5fdd009d,0x442d0a16,0x644900aa,0xfbb900b6}},	//   यातल, doe_, dmei, उजरम,
   {{0x7bc60a17,0x64420a02,0xe5340a18,0x3f820a19}},	//   _haku, _shoi, мель, haku_,
   {{0x7bc60a1a,0x64420a1b,0x3f82023b,0x75fd05aa}},	//   _kaku, _phoi, kaku_, _bèzb,
   {{0x293700c1,0x7bc601ce,0x00000000,0x00000000}},	//   _זאלן_, _jaku, --, --,
   {{0x7bc60a1c,0x3f820a1d,0xdb0d003e,0x64a000c4}},	//   _maku, daku_, ndað, dšiš,
   {{0x7bc6048e,0x7c2d0a1e,0x6e2e0a1f,0x64420a20}},	//   _laku, zoar, jobb, _whoi,
   {{0x64420a21,0x5f950a22,0x6e2e0a23,0x3f820a24}},	//   _thoi, минт, dobb, faku_,
   {{0x3f820a25,0x04db00a1,0x7c2d0a00,0xdcfc007e}},	//   gaku_, _לקבל, xoar, garč,
   {{0x7c2d00d3,0x63a20133,0xdb0d016d,0xdb1d0a26}},	//   voar, _icon, meaç, _pasí,
   {{0x91e30a27,0x61140a28,0x7bc60270,0x9f590076}},	//   _поче, _одлу, _aaku, mhsí_,
   {{0x7c2d0a29,0x7bc60a2a,0x6fa50096,0x00000000}},	//   toar, _baku, _कापू, --,
   {{0x7bc60a2b,0x2c0d009d,0x61ea0a2c,0x00000000}},	//   _caku, _सगळं_, _hofl, --,
   {{0x7c2d0a00,0x4a550a2d,0x7bc60a2e,0x645c0036}},	// [570] roar, дкас, _daku, _èrif,
   {{0x7c2d0a2f,0x6838000d,0xa2bf0a30,0x7e6d0a31}},	//   soar, bídk, _वनस्, _itap,
   {{0x7bc60a32,0x2d830a33,0x7c2d0a34,0x41ae0a35}},	//   _faku, maje_, poar, ज्यस,
   {{0x2d9c070a,0x27e90682,0x2d830a36,0x7bc60a37}},	//   _över_, ðan_, laje_, _gaku,
   {{0x6fa50a38,0x7e6900d3,0x442d0a39,0x76ab0a3a}},	//   _कानू, _împă, voe_, стев_,
   {{0x7bc60a3b,0x2d830a3c,0xdcfc033b,0x7e6d0a3d}},	//   _zaku, naje_, zarč, _mtap,
   {{0x7bc60a3e,0xb4d7074c,0x442d0a3f,0x3f820a40}},	//   _yaku, ामे_, toe_, yaku_,
   {{0x683101df,0x3cfc0a41,0x2d830a42,0x1ae40a43}},	//   råds, מלונ, haje_, _নেয়া,
   {{0x69c70a44,0x64490a45,0x442d0996,0x26cb06aa}},	//   _kaje, rmei, roe_, _éco_,
   {{0x63a20a46,0x64490a47,0x442d00b7,0xa879006e}},	//   _econ, smei, soe_, ֿאָר,
   {{0x3f820a48,0x7e6d0a49,0x61ea0a4a,0x93270018}},	//   taku_, _atap, _dofl, _کران,
   {{0x69c700bf,0x63a20037,0x683802c6,0x00000000}},	//   _laje, _gcon, vídk, --,
   {{0x63bb0a4b,0xb5fd00e4,0xcb0c0285,0x00000000}},	//   meun, _atši, _सेंड_, --,
   {{0x69c70a4c,0x2d830a4d,0x3f820a4e,0x63bb0a4f}},	//   _naje, gaje_, saku_, leun,
   {{0x7bc60a50,0xed570a51,0x62860146,0xdca30a52}},	//   _paku, дор_, ákov, кари,
   {{0xaac90789,0x6e2e0a53,0x8c430a54,0x60c30139}},	//   रिंक, sobb, весе, _isnm,
   {{0x69c70a55,0x7bc60a56,0xf41200a1,0x2d830a57}},	// [580] _baje, _vaku, דפן_, baje_,
   {{0x7c2903ce,0x7bc60a58,0x69c70a59,0x68380a5a}},	//   čera, _waku, _caje, mídi,
   {{0xb4d700b7,0x1c460307,0x00000000,0x00000000}},	//   ामो_, _оном, --, --,
   {{0x63bb0a5b,0x00000000,0x00000000,0x00000000}},	//   jeun, --, --, --,
   {{0xa3e105cd,0x6b840a5c,0x56940095,0x69c70a5d}},	//   दान_, maig, халт, _faje,
   {{0x6b840a1b,0x69c70a5e,0x63a20a5f,0x00000000}},	//   laig, _gaje, _scon, --,
   {{0xe9a303a6,0x61ea0a60,0xdb0f00fc,0x628f0a61}},	//   _шарп, _rofl, _abcè, ácon,
   {{0x69c703ce,0x6b840a62,0x2d830a63,0xd9430a64}},	//   _zaje, naig, zaje_, _реси,
   {{0x27e60113,0x752d0511,0x83fc09ac,0x69c70350}},	//   mjon_, ğaza, _nuđe, _yaje,
   {{0x27e60a65,0x6b840a66,0x24f60a67,0x68380072}},	//   ljon_, haig, _очер, dídi,
   {{0xdb1d025b,0x2d830a68,0x6b840a69,0xdbcd0139}},	//   _masá, vaje_, kaig, _bóìs,
   {{0x68e30a6a,0x63bb0072,0x83fc0106,0x2d830a6b}},	//   ändi, ceun, _buđe, waje_,
   {{0x6b840a6c,0xfe6e0103,0xe46a01cd,0x00000000}},	//   daig, یگی_, blöð_, --,
   {{0x61ac0081,0xdb1d0094,0x26c40131,0x00000000}},	//   _কোরআ, _nasá, _msmo_, --,
   {{0x2d830a6d,0x69c70a6e,0x6b840037,0x7c8400d3}},	//   raje_, _raje, faig, куте,
   {{0x2d830a6f,0x69c70a70,0x25a90335,0xa00800e3}},	//   saje_, _saje, đali_, _يقول_,
   {{0x79a70a71,0x7e6d0a72,0x68380161,0xdb1d034f}},	// [590] дрее, _utap, cídi, _basá,
   {{0x2fc90a73,0x1e1400d3,0xdb1d03a8,0x00000000}},	//   _haag_, _амья, _casá, --,
   {{0x6b84013f,0x61e70149,0x69c70a74,0x26c40634}},	//   baig, öjli, _vaje, _asmo_,
   {{0x69c70a75,0x6b840a76,0x2fc90313,0x27e60a77}},	//   _waje, caig, _jaag_, gjon_,
   {{0xb4d70a78,0xdb1d0a79,0x2fc90a7a,0x69c70a7b}},	//   ाम्_, _ansö, _maag_, _taje,
   {{0x2fc903ee,0x7a2b02e2,0xa594008f,0x69c70a4b}},	//   _laag_, hütz, връщ, _uaje,
   {{0x63bb04ee,0x97a70a7c,0x6fa5009d,0xdb0f0a7d}},	//   teun, _орал, _काढू, _tacó,
   {{0xee3f0220,0x2d810a7e,0x75fd022b,0x321e0a7f}},	//   dtým_, _lehe_, _dèza, enty_,
   {{0xc6a40a80,0x63bb0a81,0xb06500c2,0x17f80037}},	//   _архи, reun, kyää, _غرفة_,
   {{0xddc400e9,0xdb040a82,0x63bb0a83,0x2d810134}},	//   _otiš, nfiá, seun, _nehe_,
   {{0x83fc00e9,0xdcfc0a84,0x27ff05db,0x93240a85}},	//   _suđe, karā, _klun_, فرین,
   {{0x2fc90a86,0xb5fd0a87,0xaad200b6,0x79850169}},	//   _caag_, _duše, सिमक, hahw,
   {{0x2fc90a88,0x7985061d,0x2d810634,0x27ed00f3}},	//   _daag_, kahw, _behe_, _moen_,
   {{0x27ff0150,0x20020a89,0x11d90037,0x27ed0a8a}},	//   _llun_, shki_, _روعة_, _loen_,
   {{0x62860a8b,0xb5fd0995,0x6b840a8c,0x7c29037d}},	//   škot, _guše, taig, čern,
   {{0x27ed0a8d,0x8b950a8e,0x83fc00cc,0x64590113}},	//   _noen_, круч, _tuđe, _jiwi,
   {{0x64590a8f,0xdb1d0a90,0x499600ae,0x6b840a91}},	// [5a0] _miwi, _pasá, ешет, raig,
   {{0x6b840099,0x27ff0a92,0x2d8102e2,0x62890a93}},	//   saig, _alun_, _gehe_, iseo,
   {{0x7d7b00a1,0xdb1d0018,0x6d5e02c9,0x6b840a94}},	//   _מניו, _vasá, _igpa, paig,
   {{0xc6a60a95,0x64590a96,0x25a500eb,0x27ff00eb}},	//   ерки, _niwi, _acll_, _clun_,
   {{0x27ed01aa,0x79850193,0x27e60a97,0x75fd022b}},	//   _doen_, bahw, rjon_, _sèza,
   {{0x27e60a8d,0x6d5e0131,0x2d810062,0x3e6600fe}},	//   sjon_, _jgpa, _xehe_, _môt_,
   {{0x69dc0a98,0xd9430a99,0x8cd308fa,0xb4bc00c3}},	//   _inre, _бери, डियो, ेटे_,
   {{0xb4b0007a,0x27ff0a9a,0x64590a9b,0x7f440372}},	//   _ओही_, _glun_, _ciwi, _oziq,
   {{0x7ae408a8,0x64590a9c,0xaac9030b,0xf1db0096}},	//   nxit, _diwi, रिएक, बांन,
   {{0xb5fd042d,0x44ce00a5,0x645901c0,0x2fc90a9d}},	//   _puše, _tę_, _eiwi, _saag_,
   {{0x7a2b02e2,0x98b30a9e,0x200001ec,0x7f440372}},	//   tütz, čeće_, _blii_, _aziq,
   {{0x2d8101bf,0x6d5e00f9,0x200001b9,0x7af6007b}},	//   _sehe_, _agpa, _clii_, kyyt,
   {{0x2d810139,0x69dc0a9f,0xee3f0146,0xddc40995}},	//   _pehe_, _onre, stým_, _stiš,
   {{0x84e402d5,0xb5fd0aa0,0x2ee10aa1,0x2fc90a88}},	//   _कपाट_, _tuše, _पपीत, _waag_,
   {{0x765a0aa2,0x7f44019f,0x2fc90aa3,0x27470139}},	//   _mity, _eziq, _taag_, _kìní_,
   {{0x69dc0aa4,0x765a0aa5,0xd7cf0aa6,0xc1780138}},	//   _anre, _lity, _सोंच, lbė_,
   {{0x5a35016e,0x27ed0aa7,0x3b550aa8,0x2d810aa9}},	// [5b0] внат, _roen_, ткар, _tehe_,
   {{0x27ed0aaa,0x61fa0aab,0xb4b000aa,0xfe700076}},	//   _soen_, nktl, _ओहू_, _ادي_,
   {{0xdcfc01d3,0x27ed0aac,0xe6110103,0x2e360537}},	//   parā, _poen_, یشت_, ræft_,
   {{0x69dc04c7,0x87e40aad,0xe71900e3,0x6d450aae}},	//   _enre, люче, ويات_, _izha,
   {{0xf7700391,0xe5a50aaf,0x7bdd0ab0,0x765a0ab1}},	//   صان_, вили, _insu, _bity,
   {{0x0c7400bf,0x6aad0239,0xdb04003e,0x27e001d3}},	//   _جدید, mtaf, meið, ķina_,
   {{0xdb040088,0x27ed0ab2,0x765a00d1,0x00000000}},	//   leið, _toen_, _dity, --,
   {{0x19580ab3,0xc4470018,0x765a00c6,0x00000000}},	//   _часы_, ریشن_, _eity, --,
   {{0x248003ce,0x7c3a0257,0x64590239,0x7bcd0ab4}},	//   ćima_, îtri, _viwi, idau,
   {{0x62890ab5,0x645900bf,0x765a0ab6,0x7bdd0124}},	//   rseo, _wiwi, _gity, _lnsu,
   {{0x7bdd0ab7,0x62890ab8,0x3494065c,0x67290090}},	//   _onsu, sseo, _бахр, _hxej,
   {{0xdb04003e,0x765a0ab9,0xbbe0023a,0xb4bd00aa}},	//   keið, _zity, _पचेक, इबी_,
   {{0x6d450aba,0x76480084,0x7bcd0abb,0x67290090}},	//   _azha, _yhdy, ddau, _jxej,
   {{0x7bdd0abc,0x645c028d,0x51870396,0x7af6007b}},	//   _ansu, _èric, _чуда, vyyt,
   {{0x6e3c0abd,0x15f40abe,0x75fd022b,0x6aad0abf}},	//   rlrb, _अवसर_, _lèzo, etaf,
   {{0x3e660ac0,0x7ae401e9,0x7bcd019c,0x6aad01ab}},	//   _tôt_, txit, gdau, ftaf,
   {{0xdfd20068,0xafdb00f3,0x6aad0ac1,0x00000000}},	// [5c0] _ميں_, rmøt, gtaf, --,
   {{0xfe9b040a,0x6d5e0124,0x7bdd0ac2,0xafdb004d}},	//   _קיימ, _ugpa, _ensu, smøt,
   {{0x7e640084,0x7af600c2,0x83fc0ac3,0xeb9f02b6}},	//   _huip, syyt, _luđa, _blød_,
   {{0xdb0401cd,0x59e0000d,0x7e640ac4,0x765a02f1}},	//   beið, नाहर, _kuip, _sity,
   {{0x779100d0,0x765a0ac5,0xc178013f,0xc7a30ac6}},	//   صیلا, _pity, ybė_, ричк,
   {{0x68380161,0x7d0203e3,0x69dc0ac7,0x07120134}},	//   vídu, _ƙosh, _unre, tụbọ,
   {{0x38630113,0x7e640a88,0x765a0ac8,0x00000000}},	//   _gujr_, _luip, _vity, --,
   {{0x83fc0a39,0x765a05aa,0xeb9f0ac9,0xb0d500aa}},	//   _buđa, _wity, _glød_, धिनग,
   {{0x2a660076,0x765a0172,0xd4030aca,0xfe13023a}},	//   íobh_, _tity, рящи, _डगलस_,
   {{0x320500ca,0x2cba02a1,0x765a05aa,0x7bcd004b}},	//   ghly_, _oppd_, _uity, zdau,
   {{0x68380161,0xa99b00c1,0xbb1b00ae,0x61fa0acb}},	//   sídu, וביר, _neîn, rktl,
   {{0xc05801b3,0x80a30acc,0xeb9f00f2,0x66180a87}},	//   кія_, _कमरे, _kløe_, livk,
   {{0x44260acd,0x7e640113,0x66010216,0x00000000}},	//   _ijo_, _cuip, _yllk, --,
   {{0x27310028,0xb5fd037d,0xdb04003e,0x32050ace}},	//   ỡng_, _kuša, veið, chly_,
   {{0x4426074a,0xab950acf,0x5e5800d3,0xe6bf077d}},	//   _kjo_, ливі, тиря_, _एन्ज,
   {{0x6aad0ad0,0x44260361,0xa4b700ca,0xb5fd0ad1}},	//   ttaf, _jjo_, כללה_, _muša,
   {{0x20190ad2,0xab840ad3,0x7e640a06,0x7bcd0ad4}},	// [5d0] misi_, руск, _guip, rdau,
   {{0x20190ad5,0xdb040088,0x7bcd0ad6,0x66180117}},	//   lisi_, reið, sdau, jivk,
   {{0x44260ad7,0x99640ad8,0x7e6401cb,0x661800d4}},	//   _ojo_, ртул, _zuip, divk,
   {{0x20190ad9,0x44260ada,0x6e35031a,0xba770adb}},	//   nisi_, _njo_, lozb, _لاست,
   {{0x4b7a09c1,0xa3e102d5,0x3a840109,0x7cfc00ce}},	//   _ראשו, दास_, _высв, pärö,
   {{0xd1260adc,0x44260add,0xa2b800c0,0x20190ade}},	//   _هم_, _ajo_, ्बन्, hisi_,
   {{0x20190adf,0x2baa00d2,0x44260ae0,0xb4bd00aa}},	//   kisi_, ङ्का, _bjo_, इबे_,
   {{0x20190ae1,0x6e350062,0x00000000,0x00000000}},	//   jisi_, hozb, --, --,
   {{0x20190ae2,0x4426022b,0xe3b60ae3,0x55a50103}},	//   disi_, _djo_, убы_, _مجاہ,
   {{0x44260ae4,0x6e35042d,0xb5fd05db,0xb7d60065}},	//   _ejo_, jozb, _fuša, _iṣay,
   {{0x201906a3,0x7c290087,0x7e64036b,0x00000000}},	//   fisi_, čerj, _suip, --,
   {{0xc50c006e,0xbb1b00ae,0x20190ae5,0x7e640503}},	//   _קלאָ, _reîn, gisi_, _puip,
   {{0x443f0ae6,0xd24e00cd,0x00000000,0x00000000}},	//   mlu_, تنی_, --, --,
   {{0x443f0ae7,0xdca60a0e,0x831a00c1,0x229200e3}},	//   llu_, лаги, _אונז, _الوس,
   {{0x443f0ae8,0xafdb00f2,0x00000000,0x00000000}},	//   olu_, rmør, --, --,
   {{0xeb9f038c,0x443f008b,0x20190ae9,0x6618042d}},	//   _smør_, nlu_, cisi_, zivk,
   {{0x443f0aea,0x9e5a0aeb,0x2baa00b6,0x8c430aec}},	// [5e0] ilu_, _проф_, ङ्गा, сете,
   {{0x443f0aed,0xd8390154,0x7a300364,0x00000000}},	//   hlu_, _akō_, lätz, --,
   {{0x443f0aee,0x3ea20aef,0xb7d60af0,0x3ce502c3}},	//   klu_, lukt_, _aṣay, älvt_,
   {{0x2bab0af1,0x2d8a0283,0xdc9b0327,0x2a69023e}},	//   _छाया, labe_, _איטל, bqab_,
   {{0xa3d70336,0x443f0af2,0x60060af3,0x68e30212}},	//   ायन_, dlu_, _góme, ändr,
   {{0x7c2400d3,0x7a3001bf,0xb5fd0106,0x443f0af4}},	//   lnir, hätz, _puša, elu_,
   {{0x20190af5,0x5faa009d,0x2955013d,0x443f0af6}},	//   yisi_, _काढल, _вътр, flu_,
   {{0x69ce0af7,0x2d8a0af8,0x68e3085d,0x7c240af9}},	//   _habe, habe_, ånde, nnir,
   {{0x69ce0afa,0x6b86007e,0xf74300d3,0x629b00c6}},	//   _kabe, _mekg, _гето, gruo,
   {{0x69ce0a00,0x32b700e3,0x6b86039f,0x20190afb}},	//   _jabe, ادية_, _lekg, wisi_,
   {{0x69ce0afc,0x443f0afd,0x2d8a0afe,0xaca30134}},	//   _mabe, blu_, dabe_, _kwụg,
   {{0x44260aff,0x7c240039,0x443f0b00,0x69ce0b01}},	//   _ujo_, jnir, clu_, _labe,
   {{0xa3e10693,0x26c60085,0x4ea700d3,0x00000000}},	//   दार_, nwoo_, ырна, --,
   {{0x2d8a0b02,0x20190b03,0x69ce0b04,0xd2500b05}},	//   gabe_, sisi_, _nabe, _بنت_,
   {{0x021700a1,0xafdb02b6,0x2a690b06,0x6b860313}},	//   _תחום_, rløb, wqab_, _bekg,
   {{0xfbdf00ef,0x69a70006,0x62820b07,0x6b860063}},	//   _thêm_, _चाही, _kwoo, _cekg,
   {{0x3f8b0b08,0x2d8a0b09,0x7a3000c2,0x3d950b0a}},	// [5f0] macu_, babe_, läty, _кипр,
   {{0x69ce0b0b,0x3b540b0c,0x443f0b0d,0xd9990182}},	//   _cabe, скур, zlu_, ئنات_,
   {{0x69ce0b0e,0x443f0b0f,0x7a3000c2,0xf7730286}},	//   _dabe, ylu_, näty, ماش_,
   {{0x8d7400cd,0x3f8b0b10,0x6006037a,0x443f00a7}},	//   _پایا, nacu_, _tóme, xlu_,
   {{0x66e50b11,0x443f0b12,0x68e30ac9,0x00000000}},	//   рола, vlu_, åndb, --,
   {{0x69ce0b13,0x3f8b0b14,0x7bcf0169,0x00000000}},	//   _gabe, hacu_, _hacu, --,
   {{0x62820694,0x7bcf0b15,0x3dd70081,0x2aaf0092}},	//   _awoo, _kacu, _সকাল, lüb_,
   {{0x69ce0b16,0x629b0b17,0xaca30174,0x3f8b0b18}},	//   _zabe, truo, _gwụg, jacu_,
   {{0x443f0b19,0x4919009d,0x69ce0b1a,0x02050b1b}},	//   rlu_, _येतो_, _yabe, изин,
   {{0x443f01cd,0xd24e00ab,0x7bcf0b1c,0x91f500d3}},	//   slu_, وني_, _lacu, рчич,
   {{0x443f0b1d,0x61450b1e,0x6faa0096,0x62820b1f}},	//   plu_, рена, _कादं, _ewoo,
   {{0x20040b20,0xdcfe01d3,0x7bcf0027,0x8fa60b21}},	//   ómi_, _nepā, _nacu, шаме,
   {{0x91e50b22,0xf38c006e,0x2d8a0b23,0x62820b24}},	//   _воле, _טראָ, tabe_, _gwoo,
   {{0x44d50b25,0x7a3002e2,0xee370b26,0x2166007e}},	//   _kā_, sätz, иня_, _киши_,
   {{0x2d8a0b27,0x7bcf0b28,0x44d500d9,0x69ce0b29}},	//   rabe_, _bacu, _jā_, _rabe,
   {{0x44d50a84,0x2d8a0b2a,0x31c50b2b,0x3f8b0231}},	//   _mā_, sabe_, _वसुध, cacu_,
   {{0xfaa60b2c,0x69ce0b2d,0xcb0000a5,0x25db00aa}},	// [600] разо, _pabe, लैंड_, _गोभी_,
   {{0x69ce03e5,0x2d960b2e,0x0b590b2f,0x7e76039f}},	//   _qabe, _трис, урсы_, _ityp,
   {{0x44d50325,0x44c70018,0x7bcf0b30,0xfce60b31}},	//   _nā_, _nő_, _facu, _тоно,
   {{0x69ce0b32,0x7bcf0b33,0xfaa60b34,0xb5fd0995}},	//   _wabe, _gacu, _камо, _bušo,
   {{0x7bc400ae,0x41a602d5,0x671601e4,0x00000000}},	//   meiu, _खालस, _देशक_, --,
   {{0xa61300d6,0x28880260,0x7bc40b35,0x00000000}},	//   оміч, _مصری_, leiu, --,
   {{0x291e0222,0x7bcf0079,0x64aa00a7,0xb5fd0357}},	//   _äta_, _yacu, _rəis, _tušn,
   {{0x3edf0134,0x07a30b36,0x68220174,0x75f400ee}},	//   _stọọ_, _масн, ọdba, _vàzq,
   {{0xe5a60b37,0xb5fd00e7,0x521400c2,0x3f8b042d}},	//   _визи, _kušl, йдит, vacu_,
   {{0x44c70018,0x7c290b38,0x216600d3,0x83fc0995}},	//   _fő_, čeri, штиг, _tuđo,
   {{0x7e760b39,0x6aa401c0,0xf99300ca,0x69d9006e}},	//   _atyp, huif, חרת_, אַרו,
   {{0xa3d7074c,0xb5fc00bd,0xdb1d0103,0xa2b80b3a}},	//   ायण_, _diġe, _vasú, ्बद्,
   {{0xc7b30054,0x69a7018b,0x3f8b0a39,0x7bc40b3b}},	//   חבר_, _चाली, racu_, deiu,
   {{0x27230019,0x7bcf0b3c,0x3f8b0b18,0x00000000}},	//   ằng_, _sacu, sacu_, --,
   {{0x40940b3d,0x7bcf0b3e,0x3f8b005c,0x6adf00a3}},	//   _البر, _pacu, pacu_, नम्र,
   {{0x3ced0039,0x41a60b3f,0x95fe0033,0x27230031}},	//   ćev_, _खाँस, ্চিম_, nčnú_,
   {{0x99670b40,0x7bcf0b41,0x798700ec,0xa3d70b42}},	// [610] ател, _vacu, _pejw, ायत_,
   {{0x2aaf00a7,0x7bcf0b43,0x2b8500fe,0xd357021e}},	//   rüb_, _wacu, ặc_, שימי_,
   {{0x7bcf0b44,0xdcfc0234,0x60060b45,0x00000000}},	//   _tacu, varć, _hóma, --,
   {{0x44d50325,0x7bc400ae,0xf7f4001c,0x3ddf01c2}},	//   _rā_, ceiu, يسند, ɓuwa_,
   {{0xa3ea0b2b,0xd6d900a5,0x6b8d0b46,0x09cf0081}},	//   मान_, _była_, maag, রাবা,
   {{0x44d50325,0x6b8d0b47,0x80af0081,0x3f890027}},	//   _pā_, laag, য়িত্, _leau_,
   {{0x69c50b48,0xcd9800ca,0x00000000,0x00000000}},	//   mehe, בדות_, --, --,
   {{0x6b8d0b49,0x69c50b4a,0x53c902aa,0x44d50a84}},	//   naag, lehe, угим_, _vā_,
   {{0x659500ae,0x60060328,0xe5c70002,0x00000000}},	//   _газу, _nóma, _всео, --,
   {{0x44d50b4b,0xa2050b4c,0x26cd028d,0x69c50b4d}},	//   _tā_, спод, _iseo_, nehe,
   {{0x3f890b4e,0x6b8d0b4f,0x629d0146,0x7e76007f}},	//   _beau_, kaag, ásob, _styp,
   {{0x69c50b50,0x76430b51,0x6b8d0b52,0xdb040076}},	//   hehe, llny, jaag, rfiú,
   {{0x69c50b53,0xaac60251,0x6b8d0b54,0x60060072}},	//   kehe, _रैंक, daag, _cóma,
   {{0x63a90b55,0x6006003e,0x3f9e01e8,0x69c5023b}},	//   lgen, _dóma, ştu_, jehe,
   {{0x61e30b56,0xeb9a0b57,0x63a90b58,0x61fc0b59}},	//   _innl, лив_, ogen, örle,
   {{0x63a90b5a,0x6b8d0b5b,0x60dc01df,0x78a503d6}},	//   ngen, gaag, ærme, duhv,
   {{0x63a90b5c,0xfe720037,0x60060b5d,0xb5fd05db}},	// [620] igen, _عدة_, _góma, _pušl,
   {{0x69c50b5e,0xb5fd00e7,0x443d0364,0x2002007b}},	//   gehe, _bušm, _lkw_, lkki_,
   {{0xa3d70b5f,0x395c0149,0x26cd05e6,0xdcfe00ae}},	//   ाया_, ävs_, _aseo_, _depă,
   {{0x6b8d008c,0x20020084,0x63a90b60,0xb5fd0880}},	//   caag, nkki_, jgen, _dušm,
   {{0xadec0b61,0xa3e105d4,0x69c50b62,0xb4e00285}},	//   ञापन_, दाई_, behe, दम्_,
   {{0x443d0294,0x63a90b63,0x25db07e5,0x78a50a39}},	//   _akw_, egen, _गोदी_, buhv,
   {{0x63a90b64,0x7c290146,0x7d7b006e,0x18a30138}},	//   fgen, červ, אנצו, _нарм,
   {{0x68150067,0x63a90b65,0x83fc005f,0x3a3a0149}},	//   ządz, ggen, _tuđm, lopp_,
   {{0x645c028d,0xfbd300d7,0x00000000,0x00000000}},	//   _èrim, לתה_, --, --,
   {{0x60060b66,0xd9cf0081,0x3a3a0b67,0xddcd007e}},	//   _róma, রাথম, nopp_, _otaš,
   {{0x3f890257,0xb5fc009e,0x45460076,0x00000000}},	//   _peau_, _tiġb, _اناق, --,
   {{0x82a605e1,0x3a3a05e8,0x63a90b68,0xc4d300d7}},	//   _гадж, hopp_, cgen, _מגע_,
   {{0x3f89020d,0x69c50b69,0x3a3a0b6a,0x00000000}},	//   _veau_, yehe, kopp_, --,
   {{0xddcd00a5,0x6b8d0b6b,0x3878009c,0x00000000}},	//   _uważ, waag, _otrr_, --,
   {{0x6b8d0b6c,0x69c501f9,0x00000000,0x00000000}},	//   taag, vehe, --, --,
   {{0x321e0b6d,0x69c50113,0x27e400f9,0x6006003e}},	//   lity_, wehe, _nnmn_, _tóma,
   {{0x69c502e2,0x6b8d0b6e,0xfaff023b,0x15fa00b6}},	// [630] tehe, raag, _afër_, ्सार_,
   {{0x321e0b6f,0xddab0b70,0x6b8d0b71,0x7e7d0b72}},	//   nity_, _стил_, saag, mpsp,
   {{0x094b0b73,0x6b8d0b74,0x69c50b75,0x237f007f}},	//   учаи_, paag, rehe, ybuj_,
   {{0x69c502dc,0xb8f10b76,0xad1a00a1,0x8cc60096}},	//   sehe, _वन_, _כותר, ाबरो,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20090150,0xb5fd0117,0x443d084e,0x00000000}},	//   _llai_, _tušm, _skw_, --,
   {{0x63a90b77,0xb5fd00cc,0x443d0b78,0x2002003e}},	//   tgen, _hušk, _pkw_, ykki_,
   {{0x5fd90b79,0x66830068,0xdb0d0a43,0x07350b7a}},	//   _बोलल, _فیصل, leañ, _дебю,
   {{0x23290b7b,0x66f400d3,0x320700d4,0x00000000}},	//   ропи_, _епту, _plny_, --,
   {{0xb5fd00e9,0x63a90b7c,0x312500c2,0x20090b7d}},	//   _mušk, sgen, ждог, _alai_,
   {{0x443d0479,0x32070146,0xafdb00f2,0x20090b7e}},	//   _tkw_, _vlny_, rløn, _blai_,
   {{0xa3ea00d2,0xb4d50b7f,0x443d0b80,0xafdb0b81}},	//   माण_, िटी_, _ukw_, sløn,
   {{0x20020084,0xe2da0018,0xb5fd05db,0x00000000}},	//   rkki_, _پانچ_, _nušk, --,
   {{0x27380028,0x321e0b82,0x27e001d3,0x20090b83}},	//   ứng_, city_, ķini_, _elai_,
   {{0xed5a0b40,0xdbc70088,0x7f4d0372,0x00000000}},	//   ров_, töðu, _ezaq, --,
   {{0xb5fd0b14,0xc4d20327,0x200400e8,0x2009030a}},	//   _bušk, וגל_, ījis_, _glai_,
   {{0xa3ea009d,0x3a3a0b84,0x00000000,0x00000000}},	// [640] मात_, topp_, --, --,
   {{0xb5fd031a,0xc18c006e,0x7f440372,0x00000000}},	//   _dušk, ָטאָ, _iyiq, --,
   {{0xd6d90067,0x3a3a0b85,0x00000000,0x00000000}},	//   _było_, ropp_, --, --,
   {{0x8c46002d,0x321e0094,0x386d00d4,0x3a3a00f3}},	//   _феме, zity_, _čert_, sopp_,
   {{0x628600b6,0xa3cd00aa,0x00000000,0x00000000}},	//   škoz, शजन_, --, --,
   {{0xd49a08c3,0x2ba80b86,0x321e0b87,0x00000000}},	//   ари_, गलवा, xity_, --,
   {{0x25a00b88,0x1db20b89,0x321e0b8a,0xd5ad0018}},	//   ğil_, _जानत, vity_, اہم_,
   {{0x25a0026a,0xaa7b00b6,0x321e007f,0x18670161}},	//   şil_, _frýd, wity_, _фати_,
   {{0x2489084f,0x6ab60034,0x6e3c0b8b,0x1dca00a4}},	//   ćama_, ntyf, korb, ाजात,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3b5007d,0x321e0054,0x600604d8,0x104b0084}},	//   _चॉक_, rity_, _cómo, иями_,
   {{0xdb210146,0xf1ae00b7,0x320c0b8c,0x7d0300a7}},	//   _štíh, ज्जन, shdy_, _ünsi,
   {{0x6e3c0b8d,0xa3d70386,0x185b0142,0x00000000}},	//   forb, ायर_, יכטע, --,
   {{0x60060072,0xf2870018,0x7e7d0b8e,0x6e3c0062}},	//   _fómo, _بھٹو_, rpsp, gorb,
   {{0x48c500c7,0x3f82005c,0x7f440372,0x00000000}},	//   _এপ্র, bbku_, _eyiq, --,
   {{0x7aed0b8f,0x7bd60124,0x7e7d0b90,0x83fc007e}},	//   txat, gdyu, ppsp, _buđi,
   {{0xf96b0b91,0x7f4d00a7,0x09cf0033,0x671f00a3}},	// [650] арей_, _uzaq, রাসা, _मेढक_,
   {{0x527b0130,0x600d014b,0x7aed00b3,0x00000000}},	//   ינמא, _dûme, rxat, --,
   {{0x2d910b92,0x2d83023b,0x81bc01d3,0x603201d3}},	//   maze_, mbje_, tnēj, sāme,
   {{0x2d910106,0x61f801df,0x7c290146,0x80c40033}},	//   laze_, _lovl, čers, ষিপ্,
   {{0xeb7600c1,0x76c701c3,0xb5fc0078,0x00000000}},	//   _מערץ_, تغال, _siġa, --,
   {{0xe61800d6,0x2d910b93,0xb5fc0090,0x00000000}},	//   оді_, naze_, _piġa, --,
   {{0xa3d70b94,0x7e6d0085,0xb5fd00c4,0xf505013f}},	//   ायल_, _luap, _juši, язко,
   {{0xb5fd050d,0x25db0b95,0xfbdf00de,0x60060031}},	//   _muši, _गोरी_, _thêu_, _rómo,
   {{0x2d910b96,0x26d90143,0x38b50b97,0x29ff007f}},	//   kaze_, _éso_, lår_, ałań_,
   {{0xddc400e9,0x69d50b98,0x11d50037,0x10a50b99}},	//   _stiž, _jaze, ستخد, пион,
   {{0x6d450b9a,0x61f80b9b,0xb5fd0b9c,0x29010103}},	//   _nyha, _dovl, _nuši, nyha_,
   {{0x69d50b9d,0x6e3c0364,0x00000000,0x00000000}},	//   _laze, worb, --, --,
   {{0x63bb05e7,0xa2e50b9e,0xdb1d0143,0x93270b9f}},	//   mfun, _холд, _masó, _بران,
   {{0x2d8c0ba0,0x63bb0ba1,0x2d910ba2,0x7e6d0167}},	//   úde_, lfun, gaze_, _duap,
   {{0xe16600bf,0x61420ba3,0x59df00c3,0x63bb0175}},	//   _عضوی, _пеша, _नफ़र, ofun,
   {{0xc4d207a6,0xbc630ba4,0x6e3c0ba5,0x80b10081}},	//   עגן_, евск, sorb, _জনপ্,
   {{0x2fc00256,0x7e6d0ba6,0x2d910ba7,0x63bb0ba8}},	// [660] _ibig_, _guap, baze_, ifun,
   {{0xa3e200e2,0x25db099d,0x4a430ba9,0x2d910baa}},	//   _फोन_, _गोली_, енув, caze_,
   {{0x38b50bab,0x26df0174,0xdb1d0bac,0x63bb0bad}},	//   går_, _aruo_, _basó, kfun,
   {{0xdb1d0bae,0xde6d0019,0x83fc08a9,0x69d50036}},	//   _obsè, _hươn, _tuđi, _eaze,
   {{0x69d50303,0x6b840baf,0x63bb0090,0x6d40008b}},	//   _faze, mbig, dfun, şmad,
   {{0x69d50bb0,0x6b840bb1,0x281605bc,0x7c3b0b18}},	//   _gaze, lbig, _کورس, čure,
   {{0xdb0f025a,0x63bb0bb2,0xdb1d0bb3,0x2d850103}},	//   _accè, ffun, _absè, űleg_,
   {{0xde6d0019,0x320502b6,0x69d5063d,0x02a60bb4}},	//   _lươn, ekly_, _zaze, пром,
   {{0xa3e10bb5,0x6b840bb6,0x81d50033,0x798e0172}},	//   दाज_, ibig, হান_, _kebw,
   {{0xdb0d001f,0xde6d00de,0x8afb0266,0x6faa097c}},	//   sfaç, _nươn, צהיי, _काउं,
   {{0x6aa40bb7,0x7e6d08d3,0x403505c7,0xd2500018}},	//   hrif, _suap, денс, ٹنگ_,
   {{0x6aa40bb8,0xe45a0bb9,0xa3d70bba,0x2ee00150}},	//   krif, _уже_, ायः_, _brif_,
   {{0xf2060020,0x7e6d0381,0xeb9f0537,0xe2da0103}},	//   _няко, _quap, _fløj_, _دباؤ_,
   {{0x6aa402ec,0xde6d00de,0x9c830220,0x32050bbb}},	//   drif, _cươn, účov, ckly_,
   {{0xde6d0028,0x69d50bbc,0xc1bb00a1,0x38a000ae}},	//   _dươn, _raze, _המוש, nără_,
   {{0x6aa402ad,0x6b8400a6,0x2d910bbd,0x6d450094}},	//   frif, gbig, saze_, _vyha,
   {{0x6aa40bbe,0x2ee00bbf,0xb0380341,0x8f9c00a1}},	// [670] grif, _grif_, _מנהג_, _היחי,
   {{0x38b509ce,0xde6d0019,0x3ea40206,0x6b840bc0}},	//   tår_, _gươn, ámte_, abig,
   {{0x29070bc1,0x6b840bc2,0xee78010d,0x798e05aa}},	//   ána_, bbig, _وصیت_, _debw,
   {{0x290703e5,0x6aa40bc3,0x69d50bc4,0x76410138}},	//   ġna_, brif, _waze, _skly,
   {{0xdb1d0921,0x7c2d0bc5,0x38b50bc6,0x603201d3}},	//   _obsé, mnar, sår_, nāma,
   {{0xde6d0019,0x68e10103,0x7c2d0bc7,0x38b50212}},	//   _xươn, _áldo, lnar, pår_,
   {{0x2489005f,0x442f005c,0xd7fb00ae,0x29070120}},	//   ćamo_, _pjg_, _луа_, ønad_,
   {{0x7c2d0bc8,0xdb0f0bc9,0x67d40070,0x130900a9}},	//   nnar, _accé, _посу, жний_,
   {{0x63bb0bca,0x7c2d0bcb,0x98b800c6,0x25f50285}},	//   rfun, inar, _vyrą_, _एचपी_,
   {{0x3eab0bcc,0x644201e9,0xb5fd0aa8,0x7c2d0bcd}},	//   duct_, _ekoi, _aušv, hnar,
   {{0x63bb0bce,0x7c2d0088,0x32050849,0xc6090521}},	//   pfun, knar, rkly_, वसीय_,
   {{0x2ee002ad,0x81b50081,0xe3b00037,0xde6d00de}},	//   _prif_, _চোখ_, _مره_, _sươn,
   {{0xa3ea0751,0x7c2d02dd,0x443f0bcf,0xe28e0bd0}},	//   मार_, dnar, mou_, _ша_,
   {{0x64490bd1,0x7c2d0bd2,0x645b0bd3,0x3f82007f}},	//   llei, enar, lmui, dłuż_,
   {{0x442d0020,0xe1f00bd4,0x3eb90505,0x9d430bd5}},	//   one_, _حسن_, atst_, верд,
   {{0x443f0bd6,0x7c2d0bd7,0x64490bd8,0xa3b10bd9}},	//   nou_, gnar, nlei, ञ्च_,
   {{0x442d0bda,0xde6d0028,0x644901f7,0x7c290146}},	// [680] ine_, _tươn, ilei, čerp,
   {{0x6aa40bdb,0x443f0bdc,0x2b8c0028,0x6b840694}},	//   rrif, hou_, ếc_, sbig,
   {{0x443f0bdd,0x442d01ce,0x851c0251,0x64490bde}},	//   kou_, kne_, _भेंट_, klei,
   {{0x442d0bdf,0x798e01a2,0x443f0be0,0xc3140081}},	//   jne_, _webw, jou_, াপতি_,
   {{0x442d0031,0x443f0be1,0xb865015a,0x64490be2}},	//   dne_, dou_, رامو, dlei,
   {{0x64490b7c,0x44ce02c6,0x3e7402c3,0xafdb00f3}},	//   elei, _př_, _mät_, tløk,
   {{0x443f0be3,0xa3ea0be4,0x3e740212,0x1dc00be5}},	//   fou_, माल_, _lät_, श्यत,
   {{0x442d0be6,0x443f0ba0,0x68e301c5,0x64490be7}},	//   gne_, gou_, ænde, glei,
   {{0x3e740212,0x9ad30134,0x00000000,0x00000000}},	//   _nät_, tịim, --, --,
   {{0x442d0be8,0x7c240be9,0x6449007b,0x00000000}},	//   ane_, hiir, alei, --,
   {{0x443f0bea,0x850603ed,0x442d0beb,0x25eb04f8}},	//   bou_, _توان, bne_, चारी_,
   {{0x443f0bec,0x62800bed,0x603200e8,0x64490bee}},	//   cou_, ppmo, tāma, clei,
   {{0x64400bef,0x2bdf0789,0x6b9d009c,0x7c240bf0}},	//   momi, _पोषा, _rdsg, diir,
   {{0x64400bf1,0x603201d3,0xddc400e8,0x14c20096}},	//   lomi, rāma, _puiš, _शहाण,
   {{0x7c240bf2,0x6233007e,0x7c2d0bf3,0xb5fc009e}},	//   fiir, _шешу, tnar, _riġl,
   {{0xfc300bf4,0x80c40033,0x2bdf0bf5,0x7c240bf6}},	//   لحق_, ষিদ্, _पोशा, giir,
   {{0xa3b604dd,0xcd0400b6,0x645c028d,0xb5fd0433}},	// [690] _जान_, vněž_, _èriu, _kušt,
   {{0x442d0bf7,0x443f0bf8,0x64400bf9,0x7c2d0bfa}},	//   zne_, zou_, homi, snar,
   {{0x442d0bfb,0x6440019f,0x7c240bfc,0xdb040103}},	//   yne_, komi, biir, rgiá,
   {{0x442403ce,0x27e90bfd,0x443f0bfe,0x64400bff}},	//   jim_, ñan_, xou_, jomi,
   {{0x442d0c00,0x443f0c01,0x6449057a,0x7bcd0c02}},	//   vne_, vou_, vlei, meau,
   {{0x442d0067,0x443f0383,0x7bcd014b,0x6aad0063}},	//   wne_, wou_, leau, muaf,
   {{0x443f0c03,0x442d0c00,0x60060080,0x44240c04}},	//   tou_, tne_, _fómh, fim_,
   {{0x442d0012,0x61ea0c05,0x64400c06,0x7bcd0c07}},	//   une_, _anfl, gomi, neau,
   {{0x442d0c08,0x64490c09,0x63a60c0a,0x9635075f}},	//   rne_, rlei, ókna, _знац,
   {{0x442d0c0b,0x443f0042,0xe1f10080,0x7c240c0c}},	//   sne_, sou_, اسة_, ziir,
   {{0x60260c0d,0x64490c0e,0x443f0c0f,0x65940c10}},	//   една, plei, pou_, _раху,
   {{0x64400c11,0x61ea0c12,0xa3b60c13,0x44240c0b}},	//   comi, _enfl, _जाय_, cim_,
   {{0x7bcd0c14,0x7c240c15,0x2ac301d3,0x00000000}},	//   deau, viir, nībā_, --,
   {{0xa3d70c16,0xb5fd0480,0x2d9e00fd,0x2c75052f}},	//   ायक_, _gušt, ûte_, _båd_,
   {{0x1b1d0081,0xd00a0291,0xa3b60c17,0x7c240c18}},	//   _ভুলে_, _неке_, _जाम_, tiir,
   {{0x7bcd0113,0x3e740c19,0xb5fc00bd,0x00000000}},	//   geau, _tät_, _riġm, --,
   {{0x7c240c1a,0xf41200c1,0x60060c1b,0x1f66004d}},	// [6a0] riir, אפן_, _nómi, _яким,
   {{0x44240c1c,0xe9d70c1d,0x7c240694,0x7c3b0307}},	//   zim_, нку_, siir, čura,
   {{0x7c240c1e,0x44240c1f,0x1bea02b3,0x7bcd0c20}},	//   piir, yim_, _едни_, beau,
   {{0x44240c21,0x95fa0c22,0x7bcd00fc,0x929d007f}},	//   xim_, ्स्ट_, ceau, zyła,
   {{0xa3b604a9,0x6440065c,0x600604d8,0x6b960c23}},	//   _जाब_, vomi, _cómi, mayg,
   {{0x44240c24,0x6b960c25,0x600604c8,0x64400c26}},	//   wim_, layg, _dómi, womi,
   {{0x046608d9,0x7c2f00e3,0x39e70219,0xb5fd0094}},	//   нтим, _áirí, _ядро_, _rušt,
   {{0xb5fd0c27,0xccf3040a,0xd9430c28,0xd4670831}},	//   _sušt, רכה_, _сеси, није_,
   {{0x44240c29,0xb5fd02e6,0x64400c2a,0x2ac300d9}},	//   rim_, _pušt, romi, cībā_,
   {{0x64400c2b,0x6b96008c,0x00000000,0x00000000}},	//   somi, hayg, --, --,
   {{0x64400c2c,0x64a30c2d,0x2a6a0036,0x91f1034c}},	//   pomi, _баха, _mibb_, _अचरज_,
   {{0x2c750c2e,0x929d0034,0x44240c2f,0x64400415}},	//   _råd_, syła, qim_, qomi,
   {{0x7bcd0c30,0x93fb00ca,0x6b96008c,0xb5fd00c6}},	//   veau, _מלאי, dayg, _tušt,
   {{0x61ea0154,0x81bc00e8,0xa3b600a4,0x00000000}},	//   _unfl, gnēt, _जाड_, --,
   {{0x7bcd0c31,0x645c028d,0x71f70103,0xa4a50139}},	//   teau, _èris, _سروس_, _ibòí,
   {{0x59c60789,0x6b960188,0x2c750537,0x00000000}},	//   _रॉबर, gayg, _våd_, --,
   {{0x7bcd0c32,0x7b7400e3,0xb5fd0b14,0xab380c33}},	// [6b0] reau, اطفا, _mušr, епту_,
   {{0x7bcd0c34,0x2bcf0034,0x13d90033,0x49d800ba}},	//   seau, हजहा, থায়, ндую_,
   {{0x6b960188,0x7bcd0c35,0x48ab0c36,0x5d550c37}},	//   bayg, peau, ятам_, _шкот,
   {{0xfbab0084,0x629d0103,0x9f490113,0x200b00b6}},	//   _этой_, ások, _anaé_, nkci_,
   {{0x6aad028d,0x79a70859,0xc66b00c2,0xa3ea02f0}},	//   quaf, _прве, чшее_, माई_,
   {{0x60060165,0x2ac301d3,0xd54900ae,0xb5fd00c6}},	//   _vómi, rībā_, мпле_, _aušr,
   {{0xda34055b,0x2d93016d,0x2ac301d3,0x70af049d}},	//   _серы, _mexe_, sībā_, _झमेल,
   {{0xa3b600a4,0x00000000,0x00000000,0x00000000}},	//   _जाण_, --, --, --,
   {{0x69c10c38,0x961d00e8,0x42550231,0x00000000}},	//   र्थी, _atņe, ктот, --,
   {{0x85b80c39,0x27ff022b,0x2d9300ee,0x00000000}},	//   _плус_, _houn_, _nexe_, --,
   {{0x76430c3a,0x3f9200b3,0x27ff0c3b,0x00000000}},	//   mony, _peyu_, _koun_, --,
   {{0x27ff0154,0x69c10c3c,0xe1f10504,0x7d07007f}},	//   _joun_, र्ती, اسک_, dyjs,
   {{0xa3b60c3d,0x27ff0c3e,0x20190052,0x76430a4b}},	//   _जात_, _moun_, ëria_, oony,
   {{0xed5a0c3f,0xaae000b6,0x76430c40,0x00000000}},	//   дог_, निसक, nony, --,
   {{0x7997025e,0xdcfc00d9,0x27ed0c41,0x629b0138}},	//   daxw, varē, _onen_, lsuo,
   {{0x7ae9005f,0x76430c42,0x20d3044c,0x2a6a009c}},	//   _šeta, hony, _iţi_, _sibb_,
   {{0xee3a0c43,0xab2702af,0x76430c44,0xe9da05af}},	// [6c0] _они_, вота_, kony, мка_,
   {{0x20000113,0x27ed0052,0x7d01042c,0x00000000}},	//   _hoii_, _anen_, älsc, --,
   {{0x76430c45,0x27ff0154,0x940c00a7,0x00000000}},	//   dony, _boun_, _evdə_, --,
   {{0x2d980c46,0x629b0138,0x09cf0033,0x661d0138}},	//   lare_, ksuo, রাগা, _įska,
   {{0x76430c47,0x2a6a00a7,0x27ff01ff,0x2d98044c}},	//   fony, _tibb_, _doun_, oare_,
   {{0x2d980c48,0x76430c49,0xe5340c4a,0xe4b801b6}},	//   nare_, gony, лель, елкі_,
   {{0x69dc0062,0xb5fc003d,0x00000000,0x00000000}},	//   _iare, _jiġi, --, --,
   {{0x64590c4b,0x2d980c4c,0x69dc0c4d,0x34c2000f}},	//   _chwi, hare_, _hare, _शहीद,
   {{0x2d980c4e,0x69dc0c4f,0x51860077,0x76430c50}},	//   kare_, _kare, куна, bony,
   {{0x69dc0c51,0x2d980c52,0x69de0c53,0xa3e20c54}},	//   _jare, jare_, ndpe, _फोर_,
   {{0x69dc0c55,0x25db007d,0x2d980b6a,0x27ff0c56}},	//   _mare, _गोटी_, dare_, _youn_,
   {{0x2d930c57,0x03260c58,0xaa7b00b6,0x03a30c59}},	//   _sexe_, _иден, _brýl, _вицо,
   {{0x2d98028d,0x63a20c5a,0xdcf500d9,0x40340c5b}},	//   fare_, _idon, pazī, реяс,
   {{0x69dc0c5c,0x2d980572,0x62820c5d,0xc0aa037f}},	//   _nare, gare_, _itoo, _قابل_,
   {{0x6d40090e,0x20d30c5e,0xdd940c5f,0x6e2701cb}},	//   şman, _نتيج, расы, rijb,
   {{0x76430c60,0xec3403f8,0xaca30129,0xb5fc0078}},	//   zony, ансь, _ntụg, _diġi,
   {{0x2d980c61,0x81d500c7,0x76430c62,0x5a350c63}},	// [6d0] bare_, হার_, yony, гнат,
   {{0x2d980c64,0xaca30129,0x69dc0c65,0x25e2000d}},	//   care_, _atụg, _care, _टोली_,
   {{0x69dc0c66,0x99670450,0x27ff0383,0x76430027}},	//   _dare, ттал, _poun_, vony,
   {{0x63a20c67,0x3f990c68,0xac1900d6,0x76430c69}},	//   _ndon, nasu_, _чому_, wony,
   {{0x501c0c6a,0xf7700602,0x1dc00789,0x6282006c}},	//   וואו, زان_, श्वत, _ntoo,
   {{0x69dc0c6b,0x63a20c6c,0x627200a5,0x7bdd0c6d}},	//   _gare, _adon, _młod, _hasu,
   {{0x7bdd0c6e,0x27ff0139,0x25a903a3,0x5e5800c1}},	//   _kasu, _toun_, ğal_, דיגע_,
   {{0x2d980012,0x69dc0c6f,0xa3ea000f,0x27ed0c70}},	//   zare_, _zare, माग_, _unen_,
   {{0x7bdd0c71,0x69dc0c72,0x76430c73,0x611300a7}},	//   _masu, _yare, pony, mələ,
   {{0x386d0c74,0x611301d4,0x63a20c75,0x2d980c76}},	//   _hier_, lələ, _edon, xare_,
   {{0x2d980c77,0x62820c78,0x629b0c79,0x7f4d0c7a}},	//   vare_, _etoo, ssuo, _ayaq,
   {{0x7bdd0c7b,0x660100b6,0x3f990218,0x645c0036}},	//   _nasu, _holk, gasu_, _èrip,
   {{0x66010c7c,0x7ae9005f,0x386d0c7d,0x765a007b}},	//   _kolk, _šetn, _mier_, _yhty,
   {{0x61130092,0xddcd0c7e,0xee3f0146,0x386d0c7f}},	//   hələ, _etaž, brým_, _lier_,
   {{0x2d980c48,0x611301d4,0x69dc0c80,0x3f990c81}},	//   rare_, kələ, _rare, basu_,
   {{0x69dc0c82,0x2d980c83,0x44e30b88,0x66010c84}},	//   _sare, sare_, _mı_, _lolk,
   {{0x79950c85,0x2d980c86,0x7bdd0c87,0x61130092}},	// [6e0] _bezw, pare_, _dasu, dələ,
   {{0x7bdd033c,0x2d980052,0x69dc0c88,0xafdb0c89}},	//   _easu, qare_, _qare, bløs,
   {{0x69dc0c8a,0x386d0c8b,0x61130092,0x3ea0004d}},	//   _vare, _bier_, fələ, _hvit_,
   {{0xe73a02fd,0x765a00dd,0xb8dc0c8c,0x69dc0c8d}},	//   нее_, _shty, _आम_, _ware,
   {{0x69dc0c8e,0x386d0c8f,0xc7a30a7c,0xb5fd0141}},	//   _tare, _dier_, сичк, _pušp,
   {{0x38bc0c90,0x3f990c91,0x386d0c92,0x7ae401df}},	//   pír_, zasu_, _eier_, mvit,
   {{0x386d0c93,0x7bdd0198,0x7ae40c94,0x44e30092}},	//   _fier_, _yasu, lvit, _cı_,
   {{0x79950c95,0x611301d4,0x7bdd008a,0x386d0034}},	//   _zezw, cələ, _xasu, _gier_,
   {{0x66010c96,0x7ae40c97,0x52140a71,0xe7370036}},	//   _folk, nvit, идит, _бет_,
   {{0xddcd0c98,0xa3b60006,0x66010c99,0x40860c9a}},	//   _staž, _जाव_, _golk, лумб,
   {{0x7c260c9b,0x59c60c9c,0x7f4d005c,0x3f9900aa}},	//   _omkr, र्यर, _syaq, tasu_,
   {{0x63a20c9d,0x66010063,0x7e7602ac,0x628206b0}},	//   _udon, _zolk, _buyp, _ttoo,
   {{0x44260c9e,0x7bdd0c9f,0x6d4003a3,0x3ea000c4}},	//   _imo_, _rasu, şmal, _cvit_,
   {{0x44260197,0x7bdd0ca0,0x27310019,0x3f9902a4}},	//   _hmo_, _sasu, ạng_, sasu_,
   {{0x7bdd0ca1,0x3f990ca2,0x317b00f5,0x3ea00ca3}},	//   _pasu, pasu_, _ארומ, _evit_,
   {{0x6006003e,0xafdb01df,0x4426024a,0x79950415}},	//   _dóms, rløs, _jmo_, _sezw,
   {{0x59c60557,0xafdb01df,0x7bdf0ca4,0x7bdd0ca5}},	// [6f0] र्भर, sløs, rdqu, _vasu,
   {{0x386d02ec,0x7bdd0ca6,0xafdb09af,0xe29f003e}},	//   _sier_, _wasu, pløs, áði_,
   {{0x44260649,0x7bdd0006,0xc7950077,0x61130092}},	//   _omo_, _tasu, арлы, tələ,
   {{0x79950c95,0x20da0ca7,0x2ee90332,0x66010ca8}},	//   _wezw, mšić_, _kraf_, _solk,
   {{0x6b8d0ca9,0x386d0418,0x2d940181,0x66010caa}},	//   mbag, _vier_, ždeň_, _polk,
   {{0x6b8d0cab,0x611301d4,0x69c70477,0x386d01cb}},	//   lbag, sələ, _ubje, _wier_,
   {{0x66010b7c,0xb605026e,0x22450313,0xf8c90336}},	//   _volk, _aláì, volk_, _रहिय,
   {{0x66010cac,0x61130092,0x22450cad,0x6b8d0cae}},	//   _wolk, qələ, wolk_, nbag,
   {{0x2bc7009d,0xa3b60caf,0x21f5004d,0x95d90cb0}},	//   ऱ्या, _जार_, аїнс, _идат_,
   {{0x20da0106,0x20c5004d,0x69c50076,0x42250cb1}},	//   kšić_, айом, nfhe, рдов,
   {{0x3ea00cb2,0x2ee90178,0x6aad0503,0x00000000}},	//   _svit_, _araf_, hraf, --,
   {{0x44260cb3,0xa4fa00c1,0x6aad0cb4,0x2ee900f0}},	//   _gmo_, _בלעט, kraf, _braf_,
   {{0x636b03a3,0x1f56055b,0xc7d600ca,0x7d010212}},	//   _dönü, ртнё, בורי_, älsn,
   {{0x91fc0b4b,0x6aad0cb5,0x62890cb6,0x2ee90cb7}},	//   rmāc, draf, mpeo, _draf_,
   {{0x3b960cb8,0x2ee90cb9,0x8b960cba,0x6aad05c2}},	//   ијат, _eraf_, ирач, eraf,
   {{0x6b8d0cbb,0xafdb038c,0xe8e00019,0x636b026a}},	//   gbag, slør, _hiệp_, _gönü,
   {{0xa3d606ed,0xada6061b,0x3a2601b6,0x6da60b36}},	// [700] ाजत_, _капл, амаг, _кипа,
   {{0x7ae40cbc,0xac76001c,0x6b8d083e,0x600601cd}},	//   rvit, _پادش, abag, _tóms,
   {{0xdb0d0146,0x7ae40cbd,0x68460cbe,0x636b008b}},	//   čkác, svit, анжа, _yönü,
   {{0x7c260cbf,0xbc7b00a1,0xdb200103,0xebe60cc0}},	//   _umkr, _שנכת, ítóg, _томп,
   {{0x2bdf0096,0xdcfc00c6,0x9f40033c,0x68e5009c}},	//   _पोटा, tarė, _aniú_, avhd,
   {{0x7aeb052f,0xe4a60cc1,0x25a5030a,0x69c50cc2}},	//   ægte, арио, _cdll_, cfhe,
   {{0xd49701b3,0x18a30cc3,0x44260cc4,0x2f380174}},	//   ары_, _марм, _pmo_, ọgh_,
   {{0xa6860cc5,0x7c360150,0xddcd007f,0xf2c60cc6}},	//   _влад, nnyr, _staż, асон,
   {{0x20190052,0x75fd0154,0xb5fc0090,0x00000000}},	//   ërim_, _lèzy, _siġu, --,
   {{0x1db2009d,0x3878023b,0x4426029a,0x64a60cc7}},	//   _जागत, _kurr_, _wmo_, _важа,
   {{0xe3ba0476,0xe8e00023,0x80270cc8,0x2ee9007e}},	//   _абе_, _diệp_, لرحم, _sraf_,
   {{0x7c3b0cc9,0x2ee900d3,0x6f1d0cca,0x20da00cc}},	//   čurk, _praf_, tzsc, všić_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3b60ccb,0x6aad028d,0x6f1d042c,0x9f490231}},	//   _जाँ_, vraf, rzsc, _unaí_,
   {{0x6b8d0ccc,0x61fc02c3,0x245100fe,0xdde101f9}},	//   tbag, örlu, _sơmi_, ítői,
   {{0x6aad0ccd,0xa3b60cce,0x2ee90ccf,0x20da0357}},	//   traf, जलि_, _traf_, ršić_,
   {{0x6b8d0cd0,0xf9930037,0xda780cd1,0x00000000}},	// [710] rbag, قبض_, аях_, --,
   {{0xd9990cd2,0x6aad0cd3,0x80da08fa,0x3da70058}},	//   انات_, rraf, _बनाइ, _триб,
   {{0x290700ae,0xa3d602d5,0x69c50076,0xa3b60965}},	//   âna_, ाजा_, rfhe, जला_,
   {{0x6aad002d,0x628901af,0x24850875,0x7d0802c3}},	//   praf, ypeo, _rtlm_, ädse,
   {{0x7c2d0cd4,0xadc40065,0x66e50077,0x6aad00a7}},	//   miar, _atẹw, сола, qraf,
   {{0x929d00a5,0x4aac0cd5,0xb0b602d5,0x59c60285}},	//   syłk, _चितव, _अमंग, र्दर,
   {{0x610a013c,0x7c2d0062,0x00000000,0x00000000}},	//   nəld, oiar, --, --,
   {{0xf77f08bb,0xa954004d,0x7c2d0cd6,0x2a71066a}},	//   _üç_, _єкті, niar, _hizb_,
   {{0x26cd0239,0xa3d60cce,0xaae000b6,0xa3c800aa}},	//   _upeo_, ाज़_, निएक, _लउर_,
   {{0xe1f90cd7,0x7c2d0cd8,0xe613006f,0x00000000}},	//   уго_, hiar, _بشر_, --,
   {{0x7c2d0a00,0xd24e00cd,0x7c360cd9,0x6272007f}},	//   kiar, رچه_, ynyr, _płoc,
   {{0x60060cda,0x9f060037,0x6d40026a,0xc50c006e}},	//   _cómp, موجو, şmak, _שלאָ,
   {{0x91e507f3,0x7c2d0cdb,0x201e01b3,0x528500e3}},	//   _голе, diar, ėti_, _التك,
   {{0x442d0cdc,0x64490cdd,0xe29f003e,0x62720034}},	//   lie_, loei, áðu_, _włoc,
   {{0x442d0a88,0x7c2d0cde,0x0c7900c2,0x00000000}},	//   oie_, fiar, исты_, --,
   {{0x442d0cdf,0x7c2d0ce0,0xb5fc0078,0x75fd0154}},	//   nie_, giar, _jiġr, _vèzy,
   {{0x63a60ce1,0x7c360138,0x442d0ce2,0xb5fc0090}},	// [720] ókni, rnyr, iie_, _miġr,
   {{0x442d06c0,0xc3010081,0x3ea20ce3,0x644901cb}},	//   hie_, এনপি_, mskt_, hoei,
   {{0x442d0ce4,0x8c460ce5,0x7c2d0ce6,0x3ea20ce7}},	//   kie_, _гене, biar, lskt_,
   {{0x442d0ce8,0x2d9a0ce9,0x6e2e0cea,0x6449016d}},	//   jie_, _hepe_, libb, joei,
   {{0x442d0ceb,0x3ea20cec,0xdcfc00d9,0xddc401d3}},	//   die_, nskt_, karī, _muiž,
   {{0x6e2e03e5,0x27e00ced,0x9e7b006e,0x2d9a0cee}},	//   nibb, žin_, אנספ, _jepe_,
   {{0xdcfc00d9,0x291e004d,0x344a0b21,0x2d9a03a9}},	//   darī, _åta_, лчин_, _mepe_,
   {{0x442d0cef,0x2d9a0cf0,0x6449002b,0x6e2e0cf1}},	//   gie_, _lepe_, goei, hibb,
   {{0x38660149,0x610a00a7,0xe73a001f,0x6e2e010a}},	//   mmor_, zəld, _сеа_, kibb,
   {{0x7c2d0cf2,0x442d0cf3,0x2d9a0383,0x3f82007f}},	//   ziar, aie_, _nepe_, ecku_,
   {{0x442d0cf4,0xa1580cf5,0xa3b60cf6,0xf99300ca}},	//   bie_, рану_, _जाऊ_, הרת_,
   {{0x442d0cf7,0x395700a1,0x7c2d0cf8,0x15f00285}},	//   cie_, משים_, xiar, चाकर_,
   {{0x7c2d0cf9,0x799e0cfa,0x6e2e0036,0xa2b200a4}},	//   viar, kapw, fibb, _आमट्,
   {{0xdb0d001f,0x6e2e0172,0x7c2d007f,0x2d9a044c}},	//   lgaç, gibb, wiar, _cepe_,
   {{0x7c2d0cfb,0x2d9a0085,0x6c850037,0x6a690138}},	//   tiar, _depe_, تلزم, _užfi,
   {{0x388101b3,0x2d9a0139,0xc5f401c2,0x7bd60113}},	//   _nėra_, _eepe_, ɓɓe_, geyu,
   {{0x7c2d02a7,0xa3b605a7,0x99990cfc,0x6e2e0cfd}},	// [730] riar, _जाई_, икат_, bibb,
   {{0x442d0cfe,0x6fb5037f,0x7c2d0cff,0xff1800ca}},	//   zie_, _امکا, siar, _לקחת_,
   {{0x9f520383,0x3c5900d3,0x7bd60027,0x00000000}},	//   _anyè_, _винэ_, beyu, --,
   {{0x28ba0336,0x38660d00,0x64490072,0x00000000}},	//   _उमरि, gmor_, xoei, --,
   {{0x442d0d01,0xc9870d02,0xb6c70ae3,0x64490131}},	//   vie_, _губи, ссей, voei,
   {{0x442d0d03,0xd9fd04dd,0xa3b60d04,0x853c013f}},	//   wie_, _उचित_, _जाउ_, _idėj,
   {{0x442d0d05,0x69d7002b,0x64490231,0x00000000}},	//   tie_, mexe, toei, --,
   {{0x52a90d06,0x3ea20324,0x69d70d07,0x00000000}},	//   авим_, yskt_, lexe, --,
   {{0x28e1007d,0x2d8300a5,0x644904e2,0x59c60c38}},	//   फिकि, kcje_, roei, र्वर,
   {{0x442d0d08,0x69d7014b,0x7d080b81,0x00000000}},	//   sie_, nexe, ødsk, --,
   {{0x442d0d09,0x7bd60d0a,0xdbc600bc,0xb5fc009e}},	//   pie_, yeyu, mööd, _tiġr,
   {{0xa3b60d0b,0xa2b202e8,0x62860031,0x245800ae}},	//   _जाए_, _आमच्, íkoc, _лахь_,
   {{0xe299007e,0xb7da00ca,0x6d5802c6,0xbb1b020a}},	//   _тал_, בקרי, _úvaz, _sfîn,
   {{0x63bb0d0c,0x5fdc0d0d,0x3ea20d0e,0xdcf5007f}},	//   lgun, _बसवल, rskt_, zczą,
   {{0xc5f200a1,0xfce30d0f,0x7c3a0d10,0x38660178}},	//   ודם_, моро, étro, ymor_,
   {{0x63bb0d11,0x3ead0d12,0x6e2e0d13,0x26df007e}},	//   ngun, šeta_, sibb, _osuo_,
   {{0x61e30d14,0x81dc0081,0x32070d15,0x799e0d16}},	// [740] _kanl, ডার_, _kony_, tapw,
   {{0x63bb0d17,0x00000000,0x00000000,0x00000000}},	//   hgun, --, --, --,
   {{0x61e30d18,0x63bb0d19,0x5fc10d1a,0x00000000}},	//   _manl, kgun, ष्कल, --,
   {{0xb8f20d1b,0x61e30d1c,0x46ea0d1d,0x6d5e0d1e}},	//   _वह_, _lanl, иден_, _izpa,
   {{0x38660bc6,0x4e0e0b42,0x66da00c2,0x63bb02ac}},	//   rmor_, _हवाई_, рьер_, dgun,
   {{0xb0a90455,0x61e30d1f,0x63bb0d20,0x6aa40239}},	//   _किंग, _nanl, egun, msif,
   {{0xa3d6009f,0x69ce0d21,0x9f4500b6,0xf8b00103}},	//   ाजल_, _ibbe, ělé_, _سکا_,
   {{0x61e301a2,0x2fc00197,0x63bb0d22,0x799c0d23}},	//   _aanl, _ncig_, ggun, _herw,
   {{0x61e30d24,0x2d830034,0x69c10966,0x6272007f}},	//   _banl, ycje_, र्की, _dłon,
   {{0x61e30d25,0x32180067,0x799c01c2,0x320700ee}},	//   _canl, óry_, _jerw, _cony_,
   {{0x61e30d26,0x63bb0a00,0x2ee00d27,0xb97b040a}},	//   _danl, bgun, _asif_, יניי,
   {{0x68e301c5,0x27e60d28,0x69ca0d29,0x61ed0d2a}},	//   ændi, ndon_, स्ती, _ɗali,
   {{0x91e608a4,0x26c60d2b,0x73360018,0x2ee00072}},	//   _моде, ntoo_, _برائ, _csif_,
   {{0xd34400bf,0x63a00d2c,0x61e30150,0x32070072}},	//   _ویژه_, lamn, _ganl, _gony_,
   {{0x27e60124,0x64b802d5,0x0b270033,0x2cb80d2d}},	//   kdon_, _इमोश, _মডেল_, gurd_,
   {{0x27e40572,0xe3ac0081,0x228002f1,0x799c03a8}},	//   _namn_, ক্রব, _kòk_, _aerw,
   {{0x799c0d2e,0xa3cc022d,0x61e303a3,0x69d703be}},	// [750] _berw, श्य_, _yanl, texe,
   {{0x3eb90d2f,0x63bb0d30,0xaaac0442,0x63a00d31}},	//   must_, zgun, _चिरक, hamn,
   {{0x3eb9007a,0x799c0d32,0x69d703eb,0x63a00d33}},	//   lust_, _derw, rexe, kamn,
   {{0x69d70d34,0x69ce0d35,0x6b84028d,0x661a0d36}},	//   sexe, _ebbe, ccig, _altk,
   {{0xd6db0205,0x799c0d37,0x69d70d38,0x3eb900aa}},	//   рте_, _ferw, pexe, nust_,
   {{0x6608008a,0x62720034,0x20090023,0xd5b10037}},	//   _codk, _słon, _loai_, رفع_,
   {{0x1c0f0d39,0x32070154,0x91fc00d9,0x27e40d3a}},	//   _सवाल_, _rony_, rmāl, _famn_,
   {{0xd7c900cd,0x61e30d3b,0x3eb9007a,0x6d3c00ca}},	//   _دوره_, _sanl, kust_, יתונ,
   {{0x63bb0d3c,0x61e30d3d,0x799c0172,0x00000000}},	//   rgun, _panl, _yerw, --,
   {{0x2ea806ed,0x66080d3e,0x3eb90d2f,0x63bb0d3f}},	//   _कटौत, _godk, dust_, sgun,
   {{0x61e30d40,0xa3bb010d,0x610a00a7,0x7985042c}},	//   _vanl, _ناشر_, vəlc, ichw,
   {{0xb4e70455,0x22800c56,0x5437010d,0x63a00d41}},	//   यटी_, _fòk_, _برطر, camn,
   {{0x61e30d42,0xe8030d43,0x3eb90d44,0x2f560d45}},	//   _tanl, _रचना_, gust_, ятос,
   {{0x321e0d46,0xfc3f034f,0x273800fe,0xc4bf00b6}},	//   chty_, _ají_, ẩng_, _एमाओ,
   {{0xed5a0d47,0x27e60d48,0xdbd90088,0xa06a0b99}},	//   сов_, ydon_, tæðu, _лака_,
   {{0x799c0d1b,0x6b9d0d49,0x6aa40d4a,0x3eb90d4b}},	//   _serw, _cesg, tsif, bust_,
   {{0x799c0d4c,0xdbd90088,0x6b84008a,0x3eb90d4d}},	// [760] _perw, ræðu, rcig, cust_,
   {{0x6aa4005a,0x6b840d4e,0x09e30d4f,0x63a0013c}},	//   rsif, scig, ноун, zamn,
   {{0x799c0d50,0x1b040081,0x6b9d002b,0x6aa40d51}},	//   _verw, _রেখে_, _fesg, ssif,
   {{0xdcf500a5,0x79850d52,0x799c0d53,0x26c60d54}},	//   jczę, achw, _werw, ttoo_,
   {{0x799c0d55,0x66080c6f,0x27e60d56,0xe3c30033}},	//   _terw, _podk, rdon_, ্যাব,
   {{0x26c60084,0xd49a08c3,0x98a60d57,0x27e4010a}},	//   rtoo_, бри_, _ниге, _wamn_,
   {{0x26c6008a,0x628b00f0,0x27e60d58,0x80da0034}},	//   stoo_, _atgo, pdon_, _बनें,
   {{0xb60300d9,0xa3b60101,0x04630204,0x22800154}},	//   īšan, _जाओ_, нтым, _pòk_,
   {{0x27f7000d,0x2bce009d,0xd70700ae,0x85760d59}},	//   šení_, ह्या, _енте_, _فدائ,
   {{0x59cf009d,0xe8e000de,0x3eb9007a,0x63a00088}},	//   स्पर, _nhịp_, vust_, samn,
   {{0x69c10c38,0x3eb90126,0x00000000,0x00000000}},	//   र्टी, wust_, --, --,
   {{0x3eb90006,0x5ed60033,0x8fa40c37,0xa3b606eb}},	//   tust_, দিনে, наџе, _जाट_,
   {{0x6b9d0d5a,0x798500f0,0x24490d5b,0x00000000}},	//   _resg, ychw, _بجلي_, --,
   {{0x99ce00c7,0x6b9d0143,0x3eb90d5c,0x00000000}},	//   রযুক, _sesg, rust_, --,
   {{0x61f80305,0x3eb9007a,0x248c0036,0xddde0103}},	//   _invl, sust_, _jtdm_, _cipő,
   {{0x3eb90d5d,0x5c740d5e,0x315700ca,0x25fe055c}},	//   pust_, елст, _מיון_, लाडी_,
   {{0x3eb90d5f,0x3a7502a0,0x00000000,0x00000000}},	// [770] qust_, длар, --, --,
   {{0xdce701e8,0xa3cc0251,0xdcf50034,0x996700d3}},	//   sajı, श्त_, zczę, птел,
   {{0x02d9033a,0x79850d60,0x52d900b6,0x201900c6}},	//   _भन्न, rchw, _भन्स, ūriu_,
   {{0x798502e2,0x69c8026a,0x69c10d61,0x6d45063d}},	//   schw, _öden, र्जी, _ixha,
   {{0x601f00dd,0x61f802ac,0x00000000,0x00000000}},	//   _këmb, _onvl, --, --,
   {{0x7bcd0d62,0x8afa00ca,0x7e770090,0xafdb0537}},	//   lfau, _והשי, _jixp, lnød,
   {{0x20f0077e,0x7aed0d63,0x7e7700d8,0xd90f05bc}},	//   nđić_, lvat, _mixp, _حیا_,
   {{0x3ea90d64,0xfcaa07a6,0x61f805aa,0x3e640212}},	//   _ovat_, קיפּ, _anvl, möte_,
   {{0x7aed0d65,0x661201f9,0x00000000,0x00000000}},	//   nvat, ükkö, --, --,
   {{0xbebb023b,0xf0a90d66,0x7aed0d67,0x6d450d68}},	//   tzën, окол_, ivat, _oxha,
   {{0x7aed08a9,0x6d45023e,0xa3c80789,0xa06a0d69}},	//   hvat, _nxha, _लॉक_, жана_,
   {{0x7aed00cc,0xead20649,0xe4d40018,0x00000000}},	//   kvat, fẹ́_, _ستمب, --,
   {{0x6d49020a,0x7aed09ac,0x6d450d6a,0x00000000}},	//   şeal, jvat, _axha, --,
   {{0x7a200018,0x59cf0be4,0x7aed0d6b,0x00000000}},	//   _köte, स्मर, dvat, --,
   {{0x442f008a,0x42520018,0x7bcd0d6c,0x7aed0d6d}},	//   _kmg_, _جنور, ffau, evat,
   {{0xc17200a1,0x7a200149,0x2019023b,0x442f0d6e}},	//   _בחו_, _möte, ërit_, _jmg_,
   {{0xfaa30d6f,0x442f0d70,0x2eff0364,0x6d450d71}},	// [780] като, _mmg_, äuft_, _exha,
   {{0xe9d70d72,0x601f023b,0x00000000,0x00000000}},	//   мку_, _vëme, --, --,
   {{0xb4ac009f,0xd7e6004d,0x6d4007e7,0x3dfb00ca}},	//   _कटे_, діло, ğmas, _וליד,
   {{0x9f400d73,0x6d4008bb,0xafdb09af,0x00000000}},	//   _unió_, şmas, rnøg, --,
   {{0xa3c800a5,0xc7a30a28,0xd6d00d74,0x7aed00ae}},	//   _लॉग_, тичк, اقت_, cvat,
   {{0x7a200212,0x3eaf02b6,0x6b960429,0xe8df0023}},	//   _böte, _ægte_, lbyg, _luộc_,
   {{0x68e302b6,0xf8d20d75,0xa5c4007f,0x00000000}},	//   ændt, _सहिय, _राठौ, --,
   {{0x6b9600d6,0xd4670284,0x00000000,0x00000000}},	//   nbyg, мије_, --, --,
   {{0x42740d76,0x00000000,0x00000000,0x00000000}},	//   нгис, --, --, --,
   {{0x61e80abd,0xf8d20d77,0xdb1500fd,0x00000000}},	//   uddl, _सहाय, ébéc, --,
   {{0xd130054f,0x7a200222,0x7aed084f,0xe8df0019}},	//   امج_, _göte, zvat, _buộc_,
   {{0xe8df0028,0x7aed025b,0x442f0036,0x4de7074c}},	//   _cuộc_, yvat, _gmg_, _छोड़े_,
   {{0xd6d900a5,0x6b960d78,0x2ef200f0,0x00000000}},	//   _były_, dbyg, _cryf_, --,
   {{0xead20d79,0x7aed0565,0x2ef20313,0x6ab60313}},	//   rẹ́_, vvat, _dryf_, dryf,
   {{0x1bd5013d,0x645c01d3,0xfe2400c2,0x00000000}},	//   новя, _īrij, тьян, --,
   {{0x5fc602d5,0x91ca0d7a,0x6b960a1f,0xec68036c}},	//   _वायल, त्रै, gbyg, друк_,
   {{0x2ef20d7b,0x20190d7c,0xafdb0c89,0x7e7702a1}},	// [790] _gryf_, ūris_, rnød, _tixp,
   {{0x6d450d7d,0xe9d30037,0x69ca0d7e,0x9e670d7f}},	//   _txha, ضغط_, स्ली, _تابن,
   {{0x7aed0d80,0x5884055b,0x5c750d81,0x47c70033}},	//   svat, выча, _плот, _রোগী,
   {{0x20190d82,0x39580ac9,0x00000000,0x00000000}},	//   nksi_, _dyrs_, --, --,
   {{0x201900c2,0x59c70c8c,0x97350d83,0x00000000}},	//   iksi_, _लापर, رکرا, --,
   {{0x68e3052f,0x644200c2,0x2ba70096,0xafdb0120}},	//   ænds, _ajoi, गणका, rløy,
   {{0xafdb0120,0x00000000,0x00000000,0x00000000}},	//   sløy, --, --, --,
   {{0xe73900f0,0x1309004d,0x58d4021a,0xafdb00f3}},	//   _ddŵr_, зний_, _шост, pløy,
   {{0x7c3a0396,0x9f9d0088,0xf6b50018,0x95cb0d84}},	//   étri, væði_, _سماج, _мужа_,
   {{0x20190084,0x56940d85,0x41050d86,0x7a200364}},	//   eksi_, _рафт, езов, _töte,
   {{0x6e3504a3,0x442f0d87,0x69c2007f,0xf8df00b7}},	//   dizb, _tmg_, _लासी, नबिय,
   {{0xcdc90054,0x80a000a5,0x59cf0d88,0x3cf900c3}},	//   _לך_, _खबरे, स्तर, _उपजे_,
   {{0xef170d89,0x9f9d0088,0x6e3503ab,0x00000000}},	//   емя_, ræði_, fizb, --,
   {{0xfce60848,0x645b0d8a,0xc692006e,0x201900c2}},	//   ного, llui, ראם_, aksi_,
   {{0x443f0d8b,0xa3cc0851,0x81c80081,0x6b960727}},	//   onu_, श्व_, _লোক_, tbyg,
   {{0x443f0d8c,0x645b0d8d,0x0eaa00ae,0xfbdf084e}},	//   nnu_, nlui, _екий_, _skêr_,
   {{0x34dc039d,0x6b960d8e,0x7ae90146,0x443f0d8f}},	// [7a0] _मन्द, rbyg, _šetr, inu_,
   {{0x6b960d90,0x8e9700ca,0x443f0d91,0x6d40013c}},	//   sbyg, _רדיו_, hnu_, şmaq,
   {{0x2d980d92,0xf1c20d93,0x69c801e8,0x6b9604c8}},	//   mbre_, _शासन, _ödem, pbyg,
   {{0x443f0d94,0x7afb09ac,0xcfb20033,0x41cf00a4}},	//   jnu_, _šute, ট্রন, त्तस,
   {{0x443f0d95,0xc8790367,0x68e30537,0x2caa00b3}},	//   dnu_, _diş_, ændr, lsbd_,
   {{0x443f0d96,0xa3c802d5,0x45d40d97,0x9f4000b3}},	//   enu_, _लॉज_, токс, _maià_,
   {{0x443f0d98,0x5fc6009d,0x69de0239,0x1dd20bf5}},	//   fnu_, _वाढल, mepe, द्यत,
   {{0x66e60d99,0x6b7b00c1,0x25fe009d,0x645b0d9a}},	//   _поба, ּרינ, लाही_, glui,
   {{0xe7d503a3,0x3edf0294,0xf7430d9b,0x00000000}},	//   lığı, _kwụọ_, _бето, --,
   {{0x443f0d9c,0x9fd00081,0x69de0d9d,0xe8df020b}},	//   anu_, িযোগ, nepe, _nuớc_,
   {{0x7c240d9e,0x443f0d94,0x3a3700ca,0x610a00a7}},	//   khir, bnu_, תרים_, cəll,
   {{0x645b0d9f,0x69de0da0,0x351b00a1,0x2d98037a}},	//   clui, hepe, _מובנ, ebre_,
   {{0x69de0da1,0x20190da2,0x6e35042c,0x442400b3}},	//   kepe, rksi_, tizb, mhm_,
   {{0xa3cc0336,0x93250103,0x3edf0134,0x63a20d6e}},	//   श्र_, _جرمن, _nwụọ_, _heon,
   {{0x63a20da3,0x69de0da4,0x62820113,0xc0e30da5}},	//   _keon, depe, _huoo, _бојк,
   {{0xe7d50702,0x7c240da6,0x63a20da7,0x61ea0da8}},	//   dığı, ghir, _jeon, _hafl,
   {{0xf1a40da9,0x63a20167,0x61ea0ce1,0x610a00a7}},	// [7b0] _खजान, _meon, _kafl, zəll,
   {{0x63a20daa,0x443f0dab,0x69de0dac,0x7c240239}},	//   _leon, znu_, gepe, ahir,
   {{0x443f0dad,0x7c240dae,0x47bc0033,0xdb1601f9}},	//   ynu_, bhir, োজনী, rgyá,
   {{0x7c240daf,0x61ea0db0,0x610a00a7,0xf77301c3}},	//   chir, _lafl, vəll, هاش_,
   {{0x443f02e6,0x44240080,0x69de0db1,0x66e50db2}},	//   vnu_, dhm_, bepe, тола,
   {{0x27e900e9,0xe6180120,0x69de0db3,0x7bdf0db4}},	//   žan_, нді_, cepe, lequ,
   {{0x443f0106,0x645b0db5,0x6e200052,0x3eb9042c}},	//   tnu_, tlui, ëmbi, hrst_,
   {{0x7bdf016d,0x00000000,0x00000000,0x00000000}},	//   nequ, --, --, --,
   {{0x63a20db6,0x645b0db7,0x045600e3,0x1db10bb5}},	//   _deon, rlui, خلية_, _जयंत,
   {{0x443f08a9,0x645b0db8,0xd24e00ab,0x7bdf0db9}},	//   snu_, slui, يني_, hequ,
   {{0x25fe0dba,0x61ea00f0,0x645b0dbb,0x3eb90dbc}},	//   लारी_, _dafl, plui, erst_,
   {{0x69de0dbd,0x7a2002c3,0x6d5a09a1,0x00000000}},	//   zepe, _möta, ütam, --,
   {{0x69c70292,0x69de0dbe,0xdb060094,0x69c200b6}},	//   _ocje, yepe, _odká, _लाली,
   {{0xdd92003f,0x61ea0dbf,0x69de01ff,0x00000000}},	//   شور_, _gafl, xepe, --,
   {{0xed57064f,0xada30dc0,0x7c240dc1,0x63a20dc2}},	//   вор_, расл, thir, _yeon,
   {{0x1c430dc3,0x60d60796,0x63a20042,0x8c43001f}},	//   ансм, _יוצא_, _xeon, аесе,
   {{0xeab10068,0x7c2403a8,0xc1e50dc4,0x32cb0120}},	// [7c0] یعے_, rhir, _कसाब_, nøy_,
   {{0x7c240dc5,0xceb9000d,0x68f5025b,0x61ea008a}},	//   shir, áře_, _brzd, _xafl,
   {{0x291c0c01,0x69de0dc6,0x7bdf0dc7,0x00000000}},	//   áva_, repe, bequ, --,
   {{0x7bc600e7,0x7ae600f9,0xe73a0204,0x3ea002f1}},	//   _ucku, _tskt, мее_, _kwit_,
   {{0x63a200e7,0x627200a5,0xa6fa00e3,0x69de0dc8}},	//   _reon, _głow, بعاء_, pepe,
   {{0xaa460dc9,0x4a750084,0x63a20dca,0x7ae40384}},	//   _регл, _быст, _seon, mwit,
   {{0x63a20dcb,0x98a30dcc,0x7a200212,0x7ae40313}},	//   _peon, _висе, _göta, lwit,
   {{0x61ea02ad,0x7bc40dcd,0xa78500e3,0xaca40134}},	//   _safl, ngiu, _مشكو, _nhọt,
   {{0x7c23002d,0x59cf000c,0x7ae402a1,0xa6ca0dce}},	//   _înre, स्वर, nwit, _زوال_,
   {{0xaca40134,0x610a0092,0x05c90034,0x7aeb02b6}},	//   _ahọt, səlm, _रायब, ægti,
   {{0x859b028c,0x9f4e025b,0x3ea00dcf,0x85060dd0}},	//   _חשבו, čným_, _awit_, _جوان,
   {{0xc9530054,0xaca40129,0x7ae40dd1,0xe7b400aa}},	//   ימת_, _chọt, kwit, ुलिप,
   {{0xd5c9007a,0x05c90bd9,0x61ea0dd2,0x81d40161}},	//   _रामज, _रामब, _tafl, _болх,
   {{0x6e940084,0x7bc400bc,0x00000000,0x00000000}},	//   риру, egiu, --, --,
   {{0x62720067,0x7bdf0dd3,0x1dd205a5,0xc27b0341}},	//   _słow, tequ, द्धत, _קרוי,
   {{0xd10f0336,0x7bc4013d,0xaca40129,0xa17700ca}},	//   ाहरण_, ggiu, _ghọt, _בעוד_,
   {{0xdb1d05aa,0x41cf0213,0x94bf0285,0x7a2002c3}},	// [7d0] _absò, त्वस, _एम्आ, _söta,
   {{0xf7f400bf,0x200b042d,0x2ee90dd4,0x4d99004d}},	//   یسند, ljci_, _isaf_, _якою_,
   {{0x2d810dd5,0xac190566,0x3ea0022b,0x6d410dd6}},	//   _ighe_, _зону_, _zwit_, úlad,
   {{0x787a030b,0x7ae40dd7,0xc8640dd8,0x3ea00154}},	//   _důvo, bwit, атчи, _ywit_,
   {{0xdb0d00bc,0x601f0216,0x00000000,0x00000000}},	//   ngaü, _lëmo, --, --,
   {{0x69c70dd9,0x6b8d0dda,0x26360034,0x6aad0ddb}},	//   _ucje, lcag, słon_, msaf,
   {{0x6aad0ddc,0x00000000,0x00000000,0x00000000}},	//   lsaf, --, --, --,
   {{0x2fc9023e,0x69c50ddd,0x32cb00d6,0xd4660dde}},	//   _ncag_, lghe, tøy_, лище_,
   {{0x2bd50ddf,0x2d810134,0x69ca07ad,0x27ff0139}},	//   ड्या, _oghe_, स्की, _inun_,
   {{0x2d810028,0x27ed0de0,0x32cb004d,0x95d8007b}},	//   _nghe_, _haen_, røy_, _идут_,
   {{0xe4cb0de1,0x69c50091,0x1acf0081,0x2ee90de2}},	//   _زبان_, ighe, রিয়া, _asaf_,
   {{0x27ed0de3,0xf3f00037,0x24850036,0x76430167}},	//   _jaen_, _وأن_, _iulm_, lnny,
   {{0x25a50de4,0x27ed0de5,0x63a90de6,0xdcee0491}},	//   _kell_, _maen_, maen, vabı,
   {{0x27ed0de7,0x63a90de8,0x3d28001c,0x6aad0de9}},	//   _laen_, laen, نتزی_, dsaf,
   {{0x27ff0dea,0x03e600c7,0xdcee07aa,0x2ee90134}},	//   _onun_, কারী_, tabı, _esaf_,
   {{0x6b8d063d,0x61e10deb,0x63a90dec,0xf1cf0ded}},	//   gcag, lell, naen, त्रन,
   {{0xab660dee,0x7643005c,0x6aad0def,0x3ea003a9}},	// [7e0] увал, knny, gsaf, _uwit_,
   {{0x25a50465,0xdcee07aa,0x787a030b,0x7ae40df0}},	//   _nell_, sabı, _půvo, rwit,
   {{0x7ae40df1,0x61e1008f,0x610a0092,0x20120044}},	//   swit, iell, vəlk, _koyi_,
   {{0x61e10df2,0x6b8d0df3,0x27ed0df4,0x63a90df5}},	//   hell, ccag, _caen_, jaen,
   {{0x61e10df6,0x7e7e0df7,0x63a90df8,0x25a500d7}},	//   kell, _kipp, daen, _bell_,
   {{0x7e7e03e5,0x61e10df9,0x25a50dfa,0x645902a4}},	//   _jipp, jell, _cell_, _akwi,
   {{0x61e10dfb,0x25a50dfc,0x83fd0018,0x63a900b3}},	//   dell, _dell_, klőd, faen,
   {{0x764306ee,0x6d5e0dfd,0x44220018,0x3a3a0dfe}},	//   anny, _mypa, ók_, lipp_,
   {{0x61e10dff,0x57460d86,0x610a0092,0xe3af0e00}},	//   fell, _снаб, məli, سري_,
   {{0x61e10e01,0x64590e02,0xf1c6030b,0x200000d3}},	//   gell, _ekwi, _část_, _anii_,
   {{0x63a90bb6,0x20120b58,0x2bd50285,0xca570142}},	//   baen, _boyi_, ड्डा, רייז_,
   {{0x0eeb0084,0x25a50e03,0x69c5044c,0x00000000}},	//   ньги_, _zell_, zghe, --,
   {{0xe2960396,0x69c502b6,0x6fc60714,0x6272007f}},	//   _среќ, yghe, _वारं, _błot,
   {{0x61e10e04,0x7e7e028d,0x25a500b3,0x60c10113}},	//   cell, _cipp, _xell_, bulm,
   {{0x23b800aa,0x224b0206,0x00000000,0x00000000}},	//   _इयाद, écke_, --, --,
   {{0x60df0068,0x20120d2a,0x2ee903e3,0x7c840e05}},	//   őzmé, _goyi_, _tsaf_, суре,
   {{0x5a350e06,0x765a0092,0x76430e07,0xc88000a7}},	// [7f0] анат, _okty, ynny, əşir_,
   {{0x27ed03be,0x321e00a5,0x6b8d0e08,0x6aad0e09}},	//   _saen_, nkty_, scag, rsaf,
   {{0xa3e50251,0x69c50e0a,0x6aad0e0b,0x99670d86}},	//   _फसल_, rghe, ssaf, утал,
   {{0x61e10e0c,0x765a0e0d,0x627200a5,0x67d50e0e}},	//   zell, _akty, _złot, роду,
   {{0x25a50e0f,0x60c10e10,0x76430167,0x24850052}},	//   _pell_, zulm, tnny, _sulm_,
   {{0xf7700e11,0x64590e12,0x61e109cd,0x7643005c}},	//   سان_, _skwi, xell, unny,
   {{0x61e10e13,0x25a50e14,0x63a90e15,0x76430167}},	//   vell, _vell_, taen, rnny,
   {{0x25a50054,0x61e10e16,0x76430167,0xb6c90103}},	//   _well_, well, snny, _لائے_,
   {{0x61e10e17,0xcb1200c1,0x25a500a1,0xd347001c}},	//   tell, ַלט_, _tell_, دیشه_,
   {{0x63a90479,0x60c10511,0x22150e18,0x7769039f}},	//   saen, tulm, рфир, _izex,
   {{0xc5fa00c1,0xb5fa00c1,0x63a90131,0x69ca0e19}},	//   _שפעט, _שלעכ, paen, स्टी,
   {{0x61e10e1a,0x43750e1b,0x60c108bb,0x64590193}},	//   sell, _култ, rulm, _ukwi,
   {{0x60c10e1c,0x7e7e0e1d,0x6d5e0e1e,0xe7d70e1f}},	//   sulm, _pipp, _sypa, ण्यप,
   {{0x51870e20,0x387f0808,0x6da30e21,0x60c10e22}},	//   _суда, _liur_, жира, pulm,
   {{0xed5a0e23,0xe816007d,0x6286025b,0xdca6036f}},	//   тов_, _थकला_, íkov, раби,
   {{0x1e860114,0x200007cc,0x6d5e0363,0x387f009c}},	//   _клим, _unii_, _vypa, _niur_,

   {{0x7e7e0e24,0x627200a5,0x6d5e00a5,0xb0690e25}},	// [800] _tipp, _głos, _wypa, _حصول_,
   {{0x6d4100e3,0x3c3f00c2,0x386d0167,0x3ead003d}},	//   úlac, tävä_, _aher_, ġett_,
   {{0x78a200e7,0x6e3c0e26,0x6fd30287,0x387f007f}},	//   ćovo, mirb, ध्वं, _biur_,
   {{0x386d025a,0xe8df00fe,0xd90d0e27,0x6fc60e28}},	//   _cher_, _cuốc_, ریق_, वलिं,
   {{0x66f40e29,0x386d0e2a,0x387f0e2b,0x7bd60022}},	//   сплу, _dher_, _diur_, mfyu,
   {{0x386d02e2,0xfaa300e5,0xdb060052,0xc8960e2c}},	//   _eher_, _фаро, _lekë, _врањ,
   {{0x29070212,0xd9430e2d,0x7589004d,0x00000000}},	//   änat_, _дери, усів_, --,
   {{0x6a6b0364,0x247e0174,0x68e2007f,0x986a00ae}},	//   rüfe, _ọmba_, łods, _рибб_,
   {{0xf5ea0476,0xdb0d003e,0x63bd0e2e,0x53340e2f}},	//   _имал_, ngað, ósna, септ,
   {{0x387f0634,0xe80400a4,0xd4d601b3,0x00000000}},	//   _ziur_, ळावा_, _відэ, --,
   {{0x6e3c0e30,0x7416001c,0x92d60033,0x60190138}},	//   dirb, _پوشا, াটে_, гоня_,
   {{0x76580e31,0x7d1c0e32,0x91fc00e8,0xdb060216}},	//   lovy, dyrs, flāc, _cekë,
   {{0x22940e33,0x44260e34,0x329400e3,0xd0420092}},	//   _التس, _ilo_, _التأ, ntlə,
   {{0x4426006c,0x7c260172,0x63560065,0x765800d4}},	//   _hlo_, _alkr, _e̟nì, novy,
   {{0x44260e35,0xda05000f,0x627200a5,0x2ba70a28}},	//   _klo_, रासत_, _włos, ијав,
   {{0xf21c0251,0x5bb80084,0x717b00a1,0xd04200a7}},	//   _पकड़_, ился_, _בנוס, ktlə,
   {{0xb06600aa,0x32d00023,0x44260239,0x3cfa00b3}},	// [810] svää, này_, _mlo_, _erpv_,
   {{0x44260e36,0xeb9f0537,0x7c260e37,0x00000000}},	//   _llo_, _snød_, _elkr, --,
   {{0xda780e38,0x4f5809b4,0x6f1d0154,0x44260e39}},	//   рят_, _مجید_, lysc, _olo_,
   {{0xe8df00ef,0xd12600fb,0x44260af0,0xa7750e3a}},	//   _quốc_, _ہم_, _nlo_, блеч,
   {{0x6eaa0cce,0x6f1d0e3b,0x610a013c,0x8b670568}},	//   जीपु, nysc, məlu, _خادم,
   {{0xe5a20e3c,0xcb120327,0x2d910e3d,0x00000000}},	//   пиши, _צלם_, ncze_, --,
   {{0x44260087,0x29070e3e,0xb4e10096,0x00000000}},	//   _blo_, ånad_, धबे_, --,
   {{0x43690e3f,0x44260e40,0xd5c902d5,0xd4e40120}},	//   лайн_, _clo_, _रावज, юючи,
   {{0x44260c56,0x00000000,0x00000000,0x00000000}},	//   _dlo_, --, --, --,
   {{0x44260e41,0xaac80285,0x786a00d4,0x00000000}},	//   _elo_, िंतक, mýva, --,
   {{0x44260e42,0x6d4003e0,0x1b1b0033,0x786a0e43}},	//   _flo_, şmaz, _নেমে_, lýva,
   {{0x44260e44,0xdee60e45,0x92d60033,0x6e3c042c}},	//   _glo_, боми, ায়ে_, wirb,
   {{0x28c902d5,0x2bcb0e46,0x00000000,0x00000000}},	//   ांडि, िलना, --, --,
   {{0xe29c00c1,0x7d1c0052,0x51950037,0x23740206}},	//   _ישׂר, tyrs, _الغذ, ňajú_,
   {{0x82340e47,0x1d1902ec,0x6fc10096,0x50db08c0}},	//   _برنا, ають_, _वाचू, _बहिष,
   {{0x61b7009d,0xc5f403e3,0x3b860e48,0x6f1d0e49}},	//   _आयुष, ɓɓu_, слаг, bysc,
   {{0xe9da0e4a,0xc05300a1,0x3b0702b3,0x6272007f}},	// [820] лка_, _מזה_, бето_, _kłop,
   {{0xdb0d01cd,0x7dea007b,0xf9c40d7f,0x00000000}},	//   rgað, _смог_, تحری, --,
   {{0xe8040096,0xd23a006e,0x76580e4b,0x00000000}},	//   ळाला_, נגעל, vovy, --,
   {{0xa96700e5,0xa2aa0e4c,0x00000000,0x00000000}},	//   щиха_, _फ़िल्, --, --,
   {{0x29070149,0x628f0e4d,0x442600c4,0x765800d4}},	//   änar_, ícol, _rlo_, tovy,
   {{0x44260e4e,0xd0420092,0xe4a60e4f,0x644b00b3}},	//   _slo_, rtlə, брио, _ajgi,
   {{0x26190e50,0xd0420092,0x6f1d0034,0xd497013f}},	//   _बकरी_, stlə, zysc, бры_,
   {{0x290500cb,0x786a0e51,0x941800c2,0x3c2700bc}},	//   _šlag_, býva, ржит_, _kõva_,
   {{0x59cf0e52,0x6a700212,0x69c80e53,0x7a2002c3}},	//   स्कर, räff, _ödes, _nötk,
   {{0x6d4003a3,0x20f700ae,0x09e60033,0x00000000}},	//   şmay, _băi_, নাকা, --,
   {{0x69dc0e54,0x44260106,0x69ce0154,0x20f7020a}},	//   _mbre, _tlo_, _mcbe, _căi_,
   {{0x44260e55,0x438600e3,0x2d9100a5,0x442000de}},	//   _ulo_, _الإق, wcze_, _ôi_,
   {{0x69dc0e56,0x00000000,0x00000000,0x00000000}},	//   _obre, --, --, --,
   {{0x44f800de,0x2d850120,0x25fe0285,0x13ad0033}},	//   _kĩ_, øle_, लाटी_, _গায়,
   {{0x786a035d,0x2d910034,0xb425007f,0xceb400a7}},	//   zýva, rcze_, łżeń, _evə_,
   {{0xa3cc0e57,0x44f80023,0x649502a1,0x00000000}},	//   श्च_, _mĩ_, _wġig, --,
   {{0x7b670e58,0x69dc0090,0x649502a1,0x00000000}},	// [830] стве, _bbre, _iġie, --,
   {{0x69dc009c,0x64950078,0x00000000,0x00000000}},	//   _cbre, _uġig, --, --,
   {{0xf96b00c6,0xdd920421,0x7c23020a,0xa3e800b7}},	//   урай_, _توپ_, _înro, मजा_,
   {{0x69dc0e59,0x7c670e5a,0x7aee00c2,0x7d1a0e5b}},	//   _ebre, _داخل, äntä, ätse,
   {{0x7c2d0e5c,0xdcf503e0,0x649500bd,0x00000000}},	//   mhar, mazı, _mġie, --,
   {{0x7c2d0e5d,0x69d80e5e,0x786a0146,0x7afd0450}},	//   lhar, न्दी, rýva, _irst,
   {{0x2409014d,0xafdb052f,0x25fe0e5f,0x27e60e60}},	//   инки_, rnøj, लाजी_, beon_,
   {{0x7c2d0e61,0x7afd0542,0x601f01e5,0x44f800de}},	//   nhar, _krst, _fëmi, _dĩ_,
   {{0xc7b90018,0x20f700ae,0x7afb04e9,0x20d1037a}},	//   _idő_, _săi_, _šutj, wái_,
   {{0xaca30e62,0x1ddb07d5,0xdcf50e63,0x82350e00}},	//   _atọg, म्मत, hazı, تربا,
   {{0x7c2d0e64,0x21690e65,0x7bcf0e66,0x629b007b}},	//   khar, рини_, _occu, spuo,
   {{0xe8e000fe,0x20d10e67,0x7afd0e68,0x00000000}},	//   _chộp_, rái_, _orst, --,
   {{0x7c2d0e69,0x442d006b,0x6d410e6a,0xc7d600ca}},	//   dhar, mhe_, úlan, חורי_,
   {{0x443f0e6b,0x442d0396,0x7bcf0e6c,0x628b0e6d}},	//   liu_, lhe_, _accu, _iugo,
   {{0x27e605dc,0x7afd0e6e,0x62830d16,0x64950090}},	//   yeon_, _arst, _iino, _fġie,
   {{0x443f0e6f,0x7c2d0e70,0x64490e71,0x442d0396}},	//   niu_, ghar, nnei, nhe_,
   {{0xda050e72,0x63ab0018,0x64490e73,0x6a700e74}},	// [840] रांत_, _megn, inei, häfe,
   {{0x63ab0e75,0x442d0e76,0x64490e77,0x628b01e2}},	//   _legn, hhe_, hnei, _mugo,
   {{0x7afd0e78,0x7c2d0e79,0x442d0e7a,0x443f013f}},	//   _erst, bhar, khe_, kiu_,
   {{0x62830e7b,0x7c2d0e7c,0x62990034,0x645b00fd}},	//   _lino, char, _otwo, joui,
   {{0x442d0e7d,0x443f0e7e,0x44f80028,0x27e60e7f}},	//   dhe_, diu_, _sĩ_, reon_,
   {{0x8c1f00c7,0x7c24007a,0x27e60e80,0xdb040072}},	//   নোদন_, lkir, seon_, caiá,
   {{0x7a2001bf,0x291c00aa,0x443f0e81,0x628b01d3}},	//   _nöti, ävad_, fiu_, _augo,
   {{0x442d0e82,0x443f0e83,0x62830084,0x628b0e84}},	//   ghe_, giu_, _aino, _bugo,
   {{0x63ab0e85,0x628b00c4,0x63b9030a,0x6495009e}},	//   _degn, _cugo, _ddwn, _rġie,
   {{0x38660e86,0x628b02e6,0x63b703e3,0x64490e87}},	//   llor_, _dugo, _ɗanɗ, anei,
   {{0xf9930054,0x443f0e88,0x69fb00f5,0x7c240a15}},	//   ורת_, biu_, בליק, kkir,
   {{0x443f0e89,0x63ab0e8a,0xe3b2010d,0x64490e8b}},	//   ciu_, _gegn, _آرا_, cnei,
   {{0xe1ef0e8c,0xc7b30054,0x386600d3,0x62830e8d}},	//   رسی_, ובר_, ilor_, _fino,
   {{0x7c2d0e8e,0x62830e8f,0x64400e90,0x7c240e91}},	//   whar, _gino, limi, ekir,
   {{0x7c2d0e92,0x61e80bc6,0x7c24009e,0xfe6e015a}},	//   thar, medl, fkir, دگي_,
   {{0x62830e93,0x60c80270,0x38660e94,0x69d80d7e}},	//   _zino, mudm, jlor_, न्सी,
   {{0x7c2d0e95,0xdceb03a3,0x8d870e96,0x628b0072}},	// [850] rhar, ınız, _мунд, _xugo,
   {{0x7c2d0e97,0x61e802ad,0x64400e98,0x443f0e99}},	//   shar, nedl, himi, ziu_,
   {{0x64400e9a,0x7c2d0e9b,0xf8b10260,0xa5c40034}},	//   kimi, phar, عکس_, _राजौ,
   {{0xdce50028,0x443f0e9c,0x64400e9d,0x7afd0e9e}},	//   _nghĩ, xiu_, jimi, _trst,
   {{0x63ab0e9f,0x66050ea0,0x443f0ea1,0xe8e000de}},	//   _regn, зпла, viu_, _khớp_,
   {{0x63ab0465,0x628b0ea2,0x61e80ea3,0x7aed0ea4}},	//   _segn, _rugo, jedl, mwat,
   {{0x442d0ea5,0x443f0ea6,0x64400ea7,0x628b0ea8}},	//   the_, tiu_, fimi, _sugo,
   {{0x64400ea9,0x3f890eaa,0x7bcd0eab,0x628b0eac}},	//   gimi, _ngau_, ngau, _pugo,
   {{0x443f0ead,0x63ab0102,0x62830eae,0x442d0eaf}},	//   riu_, _vegn, _pino, rhe_,
   {{0x442d0eb0,0x443f0eb1,0x7c240eb2,0x63ab0eb3}},	//   she_, siu_, zkir, _wegn,
   {{0x442d0eb4,0x63ab0eb5,0x64400eb6,0x443f0eb7}},	//   phe_, _tegn, bimi, piu_,
   {{0x64400eb8,0x7aed0a15,0xe8df06c0,0x628b0eb9}},	//   cimi, kwat, _ahịa_, _tugo,
   {{0x62830eba,0x62990034,0xd5d200b7,0x78a2007e}},	//   _tino, _utwo, _सामज, ćovi,
   {{0x7aed0ebb,0xe8df0134,0x3ea906a3,0xe802009f}},	//   dwat, _chịa_, _dwat_, _रोना_,
   {{0x32070034,0x7c240ebc,0x00000000,0x00000000}},	//   _inny_, tkir, --, --,
   {{0x5fc602e8,0x7bcd0044,0xdddc0146,0x3ebf0ebd}},	//   _वाटल, ggau, zorň, šuta_,
   {{0x7c240ebe,0x6e460ebf,0x6fa2055e,0x7aed0ec0}},	// [860] rkir, _неиз, _क्यू, gwat,
   {{0x7c240903,0x64400ec1,0x4efb006e,0x1efb006e}},	//   skir, zimi, _פליג, _פליע,
   {{0x64400ec2,0xae1b00c1,0x7aed0167,0xa3ae0ec3}},	//   yimi, _הויכ, awat, करम_,
   {{0x7aed083e,0x61e80ec4,0x00000000,0x00000000}},	//   bwat, zedl, --, --,
   {{0x64400ec5,0xa2bd034d,0x38660ec6,0x9f520065}},	//   vimi, _शिष्, rlor_, _bayé_,
   {{0x1603009f,0x442400dc,0x64400027,0x00000000}},	//   लागर_, wkm_, wimi, --,
   {{0xf8e0007d,0x443d0ec7,0x61e80ec8,0x64400bb0}},	//   _नहिय, _bmw_, vedl, timi,
   {{0x7afb01ac,0x60c80ec9,0x61e80eca,0x3298001f}},	//   _šuti, vudm, wedl, овиќ_,
   {{0x6ab60ecb,0x5fc60096,0x61e80158,0x00000000}},	//   nsyf, _वाजल, tedl, --,
   {{0x80c00abe,0xa2bd0d88,0x248c00dc,0xf8e00336}},	//   _विदे, _शिर्, _tudm_, _नहाय,
   {{0x660801c5,0x64a30ecc,0x859b00a1,0xb38600ae}},	//   _indk, _заха, _השבו, _елел,
   {{0x7aed0067,0x35d20251,0x61e80ecd,0x32070ece}},	//   ywat, _साड़, sedl, _enny_,
   {{0x82fa010d,0x661a0ecf,0xd5b1020b,0x00000000}},	//   _دراز_, _kotk, _món_, --,
   {{0x661a02fd,0xe3b00470,0xf2c501ce,0x00000000}},	//   _jotk, _سرچ_, _ісін, --,
   {{0x601f00dd,0x61db028c,0x5fc6009d,0x7aed030a}},	//   _sëmu, _הקוד, _वाचल, wwat,
   {{0x7aed0ed0,0x7bcd00c6,0x00000000,0x00000000}},	//   twat, ugau, --, --,
   {{0x3b540ed1,0xa3de022d,0x7bcd0ed2,0x35d20ed3}},	// [870] ектр, द्य_, rgau, _साढ़,
   {{0x24860080,0x91fc0029,0x661a0088,0x7c870012}},	//   _liom_, klām, _notk, _нуме,
   {{0xf9880037,0x3e64003e,0x9f52014b,0xac190ed4}},	//   أنمي_, götu_, _rayé_, _дону_,
   {{0xa2bd0ed5,0x3e830139,0x660800bc,0x6fad02d5}},	//   _शिल्, _fétì_, _andk, चरिं,
   {{0xd6db0ed6,0x2366023e,0x9f5200fd,0xfc3f0065}},	//   сте_, _nyoj_, _payé_, _imí_,
   {{0x443d0167,0x992b0ed7,0x59c700c3,0x95cb0ed8}},	//   _smw_, _люба_, _लाटर, суда_,
   {{0x661a0ed9,0xf8ae00d1,0x80db00a3,0xcd980eda}},	//   _dotk, _نکن_, _बहें, הדות_,
   {{0x3e6401f9,0x00000000,0x00000000,0x00000000}},	//   lött_, --, --, --,
   {{0x661a0edb,0xe1f20103,0x00000000,0x00000000}},	//   _fotk, چسپ_, --, --,
   {{0x20090edc,0x80d9004d,0x7a2001cd,0x00000000}},	//   _anai_, оєму_, _fötu, --,
   {{0x76430edd,0x2486028d,0xb7bd00ae,0x7a20003e}},	//   miny, _fiom_, _alţi, _götu,
   {{0xa3ae0861,0x76430ede,0x59dd0edf,0xeb0d0ee0}},	//   करण_, liny, न्तर, _सपूत_,
   {{0xd09201d4,0x7a200ee1,0xdb060328,0x3e640ee2}},	//   _müəy, _kött, _pekí, kött_,
   {{0xfce600d6,0x3e640103,0x7a2001f9,0x00000000}},	//   мого, jött_, _jött, --,
   {{0x91fc00d9,0x7a200ee3,0x3e640103,0x00000000}},	//   klāj, _mött, dött_, --,
   {{0x601f023b,0x00000000,0x00000000,0x00000000}},	//   _dëms, --, --, --,
   {{0x76430ee4,0xcb670ee5,0xdd8f0068,0xbb430ee6}},	// [880] kiny, дате_, اوہ_, ветк,
   {{0x76430ee7,0x67220239,0x3e640103,0x6ab60ee8}},	//   jiny, vyoj, gött_, rsyf,
   {{0x76430ee9,0x6ab60324,0x00000000,0x00000000}},	//   diny, ssyf, --, --,
   {{0x3209006d,0x3b0a0eea,0x27e001ab,0x50c50eeb}},	//   _ɗaya_, _демо_, ýin_, _विनष,
   {{0x76430201,0x248606ad,0x00000000,0x00000000}},	//   finy, _riom_, --, --,
   {{0xd49a0eec,0x59dd09dd,0x9d450018,0xceb902c6}},	//   ори_, न्दर, _آئین, áři_,
   {{0xf9830eed,0xa96700c2,0x7a2002c3,0x00000000}},	//   _агро, _жира_, _dött, --,
   {{0xa803013d,0xb7fb030b,0x00000000,0x00000000}},	//   _изсл, _एफएम_, --, --,
   {{0x76430eee,0x7a200149,0x02a300ae,0x00000000}},	//   biny, _fött, крэм, --,
   {{0x7a200eef,0x764304ff,0x20090ef0,0x00000000}},	//   _gött, ciny, _snai_, --,
   {{0x248601b9,0x00000000,0x00000000,0x00000000}},	//   _tiom_, --, --, --,
   {{0x3e640068,0x534608d8,0xdb0f0231,0x03260ef1}},	//   zött_, _охла, _decê, _оден,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb04014b,0x00000000,0x00000000,0x00000000}},	//   mbiè, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x76430ef2,0x61f80ef3,0x20090ef4,0x2d9800b3}},	//   ziny, _havl, _unai_, acre_,
   {{0x76430ef5,0x61f80ef6,0x3a750ef7,0x0c84004b}},	// [890] yiny, _kavl, елар, тырм,
   {{0x61f803ce,0x61fa00f2,0x998700d2,0x4a540e4f}},	//   _javl, ndtl, ónů_, вкус,
   {{0xa3ae0006,0x64dd0ef8,0x76430201,0x7a20071b}},	//   करा_, _महेश, viny, _rött,
   {{0x2c2702ec,0xfc3f00b6,0x6d5702a1,0x76430ef9}},	//   _цьог, _umí_, _ixxa, winy,
   {{0x76430efa,0x6b9a00ca,0x787102c3,0x6568041c}},	//   tiny, _משרד, gåva, _aydh,
   {{0xf770037f,0x321c0146,0x60da010a,0x00000000}},	//   جام_, _novy_, kttm, --,
   {{0x76430808,0x80c00efb,0x9f4e02c6,0x69d5039f}},	//   riny, _विषे, čném_, _icze,
   {{0x76430efc,0xc7c400ae,0x9f4b0231,0x00000000}},	//   siny, _асфи, recê_, --,
   {{0xa3de0efd,0x76430efe,0x61f80eff,0xe8df00de}},	//   द्ध_, piny, _bavl, _khỏa_,
   {{0x80c00961,0x3eb9004d,0xf52700ae,0x00000000}},	//   _विशे, dsst_, _офен, --,
   {{0x61f8062d,0xe0460f00,0x9046001c,0x64450f01}},	//   _davl, енни, فنده, éhis,
   {{0x44f108a1,0xdb060181,0xb4fa00ca,0xa3de0f02}},	//   _iš_, _leká, _מפעי, द्द_,
   {{0xc2c80241,0x9327046b,0x442f0042,0xd12e0f03}},	//   _قبول_, _تران, _ilg_, لمی_,
   {{0x2d8c0f04,0x61f80f05,0x29030f06,0x00000000}},	//   øde_, _gavl, _orja_, --,
   {{0xdb040f07,0x1d070f08,0xb4ad0006,0x32d906a3}},	//   mbié, нери_, _कबो_, lèy_,
   {{0x44f10146,0x3c2e0031,0xdb0f0113,0x59dd00a8}},	//   _mš_, _býva_, _kecè, न्सर,
   {{0x2903003d,0x442f0f09,0x44f10d62,0x6d5702ac}},	// [8a0] _arja_, _mlg_, _lš_, _exxa,
   {{0x4a430f0a,0xdb0f0113,0x6f040f0b,0x2d9a0231}},	//   гнув, _mecè, _iric, _ufpe_,
   {{0x4c860f0c,0xd8260f0d,0x7769063d,0xdb060437}},	//   _плов, нджи, _ayex, _deká,
   {{0x6f040f0e,0xa01b0f0f,0x69d50f10,0xdc9b006e}},	//   _kric, rmög, _ecze, _מיטל,
   {{0xdcfc01d4,0x44f101b3,0x45d40f11,0xa01b0364}},	//   marı, _aš_, волс, smög,
   {{0xdcfc08fd,0xceb30341,0x6f0401dc,0x26c601ee}},	//   ları, ריג_, _mric, rroo_,
   {{0x442f0f12,0xdb1d0154,0x6e200052,0x00000000}},	//   _blg_, _adsè, ëmby, --,
   {{0x6f040012,0x61f80f13,0xdcfc071d,0x442f0076}},	//   _oric, _savl, narı, _clg_,
   {{0x44f102ef,0x533400d3,0x996100e8,0xe7370c58}},	//   _eš_, тепт, _cīņa_, _зет_,
   {{0x2d8c035d,0xdb0f00b3,0x442f0f14,0x44f105db}},	//   ždej_, _decè, _elg_, _fš_,
   {{0xdcfc01e8,0x6f040f15,0x40350f16,0x3a3700a1}},	//   karı, _aric, венс, גרים_,
   {{0x6f040b87,0x32d9022b,0x00000000,0x00000000}},	//   _bric, bèy_, --, --,
   {{0x44f10146,0x61f80f17,0x6d480610,0xdcfc008b}},	//   _zš_, _tavl, údan, darı,
   {{0x6f040149,0xbe8800c2,0x00000000,0x00000000}},	//   _dric, ессе_, --, --,
   {{0xf1b30054,0xcfb00033,0x2d850f18,0xd12f004d}},	//   _עסק_, _কারন, äle_, _сх_,
   {{0x6f040f19,0x3ea003e5,0xbbcb030b,0xac180284}},	//   _fric, _ftit_, िलेक, носу_,
   {{0x06e80081,0xf9c70f1a,0xdb060146,0x649502a1}},	// [8b0] পিডি, ещен, _peká, _aġil,
   {{0xddde007e,0x8b0800d2,0x00000000,0x00000000}},	//   _tipš, _spřá, --, --,
   {{0xe802007d,0x628a0f1b,0xdcfc03e0,0x23c70139}},	//   _रोहा_, _mifo, barı, _jìjà_,
   {{0x69d500a5,0x996400d3,0xdcfc00a7,0x628a0178}},	//   _wcze, утул, carı, _lifo,
   {{0xe8df0019,0x799c0150,0x44f10f1c,0x8038006e}},	//   _thỏa_, _ffrw, _sš_, ענדע_,
   {{0x628a0f1d,0x69d500a5,0xb5c20f1e,0x442f002b}},	//   _nifo, _ucze, айшл, _slg_,
   {{0x442f0f1f,0x2245033b,0xaa540b36,0x00000000}},	//   _plg_, vilk_, _сврш, --,
   {{0x130908d1,0xd13800a5,0x628a0f20,0x44f10094}},	//   дний_, dzą_, _aifo, _vš_,
   {{0x628a0149,0x5695008f,0x95d9001f,0x35f50f21}},	//   _bifo, _разт, _одат_, _ипар,
   {{0xdcfc008e,0x32d906a3,0x644201e9,0x27ef01c2}},	//   zarı, rèy_, _emoi, legn_,
   {{0xa2bd06e4,0x442f0f22,0xf99200a1,0x26cf0f23}},	//   _शिक्, _tlg_, ירי_, lugo_,
   {{0x6f040f24,0xdcfc0092,0x23c70139,0x3ea00f25}},	//   _pric, xarı, _dìjà_, _ptit_,
   {{0xe1ee0870,0x539a028c,0x628a0065,0xdcfc008b}},	//   _кг_, _חינו, _fifo, varı,
   {{0x63a90f26,0x6fa209c4,0x23c70139,0x628a0f27}},	//   lben, _क्रू, _fìjà_, _gifo,
   {{0xdcfc0f28,0xd1380034,0x2ee900b3,0xd7b30e5f}},	//   tarı, czą_, _epaf_, ुणाच,
   {{0x5184013a,0x21880130,0x63a90f29,0x26cf0f2a}},	//   _суча, _אָפּ, nben, kugo_,
   {{0x787800c9,0x27fd02ad,0x3b86004b,0xa3c4009f}},	// [8c0] níve, ddwn_, тлаг, ौलत_,
   {{0xdcfc01e8,0x00000000,0x00000000,0x00000000}},	//   sarı, --, --, --,
   {{0x63a90f2b,0xd7fa0f2c,0x28c90b94,0xdcfc071d}},	//   kben, дул_, ांगि, parı,
   {{0x26cf0051,0x63a90dd9,0x3ead020a,0xb6a6016d}},	//   fugo_, jben, ţete_, видл,
   {{0x63a9011d,0xfaa600f6,0x00000000,0x00000000}},	//   dben, _јаго, --, --,
   {{0x63a90f2d,0x787800b6,0xaca40129,0xa4d80f2e}},	//   eben, díve, _nkịt, едку_,
   {{0x628a0f2f,0xd9460f30,0xdb0f0f31,0x49910103}},	//   _rifo, _реви, _recé, _ایمر,
   {{0xd7060f32,0xaca40174,0x7c3602ad,0x63a90f33}},	//   _изби, _akịt, nhyr, gben,
   {{0x26dd00a5,0x97ea0092,0xa6860f34,0x9f4b0487}},	//   ctwo_, ışdı, _алад, pecé_,
   {{0x6206004d,0x00000000,0x00000000,0x00000000}},	//   тчиз, --, --, --,
   {{0xc4c50adb,0x1be20f35,0x64570143,0x00000000}},	//   _متنو, खभाल_, éxic, --,
   {{0x23ba0f36,0x9f520139,0x14d70327,0x7878016d}},	//   _آداب_, _bayà_, _יובל_, bíve,
   {{0xd13800a5,0x628a0f37,0x78780131,0x00000000}},	//   szą_, _tifo, cíve, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c80233,0x00000000,0x00000000,0x00000000}},	//   _ödey, --, --, --,
   {{0xc61f0f38,0xdb0f020a,0x00000000,0x00000000}},	//   _भव्य_, _decî, --, --,
   {{0x06d70033,0xeb0d00b6,0x26cf0956,0x00000000}},	// [8d0] _দৈনি, समेत_, xugo_, --,
   {{0x63a90f39,0x394b00cd,0x26cf0193,0x6abd0120}},	//   zben, وشاپ_, vugo_, _vvsf,
   {{0x27ef01df,0x656d03e3,0x98480847,0x00000000}},	//   tegn_, ƙahi, _ağı_, --,
   {{0xdb060f3a,0xdcb1020b,0x26cf0027,0x00000000}},	//   _bekä, ẩu_, tugo_, --,
   {{0x7c2d0f3b,0x78780161,0x27ef0f3c,0x63a907ee}},	//   mkar, xíve, regn_, vben,
   {{0xd77400e3,0x26cf0f3d,0x78780161,0xbb3a006e}},	//   جامع, rugo_, víve, _טערי,
   {{0xd4690f3e,0x26dd0034,0x5edf0033,0x245a01d3}},	//   нике_, stwo_, মিটে, zīme_,
   {{0x78780f3f,0x63a90f40,0xa3e302d5,0xc6a700d3}},	//   tíve, uben, _पॉश_, _аржи,
   {{0xc7b200a1,0x7c2d0f41,0x069b0470,0x1dd30f42}},	//   _לבן_, ikar, _آخرت_, _तांत,
   {{0x96f80f43,0x63a90f44,0x7c2d0f45,0x78780db4}},	//   _جعفر_, sben, hkar, ríve,
   {{0x7c2d0f46,0x78780161,0x9f4e030b,0x9f5b0052}},	//   kkar, síve, čním_, _faqë_,
   {{0xddd5030b,0xdb0a0146,0x7c2d0f47,0x2ba5088d}},	//   mozř, šnéh, jkar, गुमा,
   {{0x91e50f48,0x442d0f49,0x7c2d0f4a,0x9f520065}},	//   _боле, mke_, dkar, _bayá_,
   {{0x442d0f4b,0xdd920cd2,0xf776006e,0x7c2d0dd8}},	//   lke_, صور_, טערי_, ekar,
   {{0x442d0f4c,0x7c360f4d,0x09b20081,0xed570c2d}},	//   oke_, thyr, _চালা, гор_,
   {{0x442d0f4e,0x7c2d0f4f,0x8c430f50,0x09cc0096}},	//   nke_, gkar, бесе, ाल्य,
   {{0x442d0f51,0x9b9300e3,0x7c360f52,0x69da0233}},	// [8e0] ike_, إلكت, rhyr, _ötek,
   {{0xe9d70303,0x05d20f53,0x3b830f54,0x442d0f55}},	//   лку_, _साइब, слуг, hke_,
   {{0x442d0f56,0x7c2d00a7,0xf4be0033,0x8c460f57}},	//   kke_, bkar, _আহ্ব, _бене,
   {{0x442d0f58,0x7c2d0f59,0xdbd70364,0x3eb20f5a}},	//   jke_, ckar, mäßi, _kwyt_,
   {{0x442d0f5b,0x6449030a,0xd707007b,0x00000000}},	//   dke_, diei, лнце_, --,
   {{0x442d0934,0x9f5b0052,0x00000000,0x00000000}},	//   eke_, _saqë_, --, --,
   {{0x442d006d,0x04660ac6,0x64490150,0x7af600f0}},	//   fke_, лтим, fiei, lwyt,
   {{0x25f000a5,0x7bd60f5c,0x442d0f5d,0xaca40174}},	//   _इसकी_, ngyu, gke_, _nkọt,
   {{0xa6ca0814,0x91fc00d9,0xd5d60018,0x3866084e}},	//   _سوال_, klāt, _متاث, moor_,
   {{0xd6cf0cd2,0xe29f0102,0x7c2d02a7,0xdb160c56}},	//   _رقم_, íða_, zkar, rayè,
   {{0xf5930080,0xa1580f5e,0x05560f5f,0x7af6007f}},	//   _المج, тану_, _стая, hwyt,
   {{0x764a0f60,0x557700c1,0x38660185,0x64490f61}},	//   lify, _געבן_, noor_, ciei,
   {{0x09cc00c7,0x80c00f62,0xe80b09c3,0x7c2d0f63}},	//   র্যা, _विके, _सोफा_, vkar,
   {{0xe80b000f,0x38660185,0x7c2d0f64,0xb80b0f65}},	//   _सोना_, hoor_, wkar, _सोनम_,
   {{0x16d10f66,0x7c2d0f67,0x38660f68,0x00000000}},	//   _सम्ब, tkar, koor_, --,
   {{0x09cc00c7,0x386601d0,0xa3e709c4,0x00000000}},	//   র্মা, joor_, म्प_, --,
   {{0x38660f69,0x5b150f6a,0xead50f6b,0x00000000}},	// [8f0] door_, шмат, розь, --,
   {{0x7c2d03f3,0x442d0f6c,0x7f3c006e,0x6d410f6d}},	//   skar, zke_, _רעזו, úlas,
   {{0x764a0f6e,0x442d0f6f,0x1c000d88,0x2abb0d79}},	//   dify, yke_, _लोकल_, _bàbá_,
   {{0x38660313,0x9c130129,0x00000000,0x00000000}},	//   goor_, bọal, --, --,
   {{0x64490f70,0x6f1b0364,0x76ab0291,0x00000000}},	//   viei, äuch, хтев_, --,
   {{0x09cc0f71,0x80aa0f71,0xa3e70976,0x1994004d}},	//   র্বা, _কিন্, म्न_, _гаря,
   {{0x442d0f72,0x3d080f73,0x64490072,0x38660f74}},	//   tke_, हिये_, tiei, boor_,
   {{0x442d0f75,0x6a6b0364,0x14250f76,0x5fd40f77}},	//   uke_, rüfu, рдим, _थाइल,
   {{0x7cec0103,0xe80b0f78,0x00000000,0x00000000}},	//   _körö, _सोया_, --, --,
   {{0x442d0f79,0x69d70201,0xdb0f0094,0x9f400131}},	//   ske_, ngxe, _necí, _maiô_,
   {{0x69dd0782,0xc32300c7,0x78780314,0x62810f7a}},	//   _पानी, _বেশি_, líva, rmlo,
   {{0xdb0f001f,0xd71c0081,0x27ff0f7b,0x660d0022}},	//   _mecâ, _দেয়া_, _jaun_, ɓaka,
   {{0x92b70080,0x93940867,0x27ff0dd8,0x38bc0032}},	//   _إحصا, _اجما, _maun_, _kárá_,
   {{0x63bb0f7c,0xdb0f0f7d,0xed5a0831,0xd35600ca}},	//   laun, _cecí, вог_, _דיני_,
   {{0x61420f7e,0xdb0f04d8,0xa01b007b,0x32f6007f}},	//   _меша, _decí, mmön, _zły_,
   {{0x63bb0f7f,0x27ff01ff,0xbb7600e5,0x3ead020a}},	//   naun, _naun_, аузъ, ţeta_,
   {{0xe9da0f80,0x38660126,0x6d410032,0xeb97002d}},	// [900] кка_, voor_, úlar, риу_,
   {{0x63bb019c,0x7af60150,0x787800b6,0xab5b0f81}},	//   haun, rwyt, díva, _idül,
   {{0xf1dd0557,0x41dd0f82,0x63bb0f83,0x261908fa}},	//   _मानन, _मानस, kaun, पानी_,
   {{0xa3e7000d,0xdb0f002d,0x63bb00d9,0xc6a60f84}},	//   म्म_, _decâ, jaun, арки,
   {{0x27ff048e,0x764a0f85,0x46f60f86,0x38660f87}},	//   _daun_, tify, рчет, roor_,
   {{0x69dd007d,0x20c502d5,0x7cec0103,0xb8dc0033}},	//   _पायी, _विंध, _görö, _আম_,
   {{0x01bb0f71,0x764a0f88,0x38660f89,0x26df0f8a}},	//   ংলাদ, rify, poor_, _equo_,
   {{0x27ff0f8b,0x63bb0f8c,0x290a0113,0x00000000}},	//   _gaun_, gaun, _irba_, --,
   {{0xd3770f8d,0x38bc0032,0x38ac0139,0x09cc0033}},	//   ичь_, _fárá_, _fòrò_, র্ণা,
   {{0x201200ac,0x27e60f8e,0xa3e70f8f,0x27ff042c}},	//   _anyi_, lfon_, म्ब_, _zaun_,
   {{0x7bc60f90,0x9f4b037a,0x64a30f91,0x27ff01ff}},	//   _odku, recí_, _даха, _yaun_,
   {{0x78a10103,0x920201d3,0x27e600f0,0x2000020a}},	//   _élve, _šāda, nfon_, _caii_,
   {{0x63a20f92,0xdb0f0072,0x200500b6,0xdb060065}},	//   _ifon, _pecí, ěli_, _eekú,
   {{0x20050067,0x20120f93,0x7a32052f,0xdb060139}},	//   śli_, _enyi_, _sætn, _fekú,
   {{0x9c47065c,0x00000000,0x00000000,0x00000000}},	//   ахал, --, --, --,
   {{0x8f470f94,0x705500cd,0x1dd30251,0x44f800de}},	//   _вход, _دنبا, _ताकत, _mũ_,
   {{0x290a01b3,0xaa7b0220,0xfb870b91,0x44f800de}},	// [910] _arba_, _opýt, рывн, _lũ_,
   {{0x63bb006d,0x39a70f95,0x27ff0f96,0x7a380f97}},	//   zaun, ршав, _saun_, апур_,
   {{0x27ff08c4,0x7cec0103,0x69dd0096,0xa3e702d5}},	//   _paun_, _vörö, _पाठी, म्ड_,
   {{0xdd1c00b6,0x765a023b,0x63a200b3,0xd7c80f98}},	//   _nářa, _ajty, _nfon, لومه_,
   {{0xe5a50f99,0x290a0f9a,0xd6db0275,0x8c1a00a1}},	//   били, _erba_, тте_, _עושי,
   {{0x63a20f9b,0x63bb0239,0x69dc0076,0xd6ce00da}},	//   _afon, waun, _gcre, رقى_,
   {{0x27ff0979,0x44f80028,0x63bb0f9c,0x69c70113}},	//   _taun_, _cũ_, taun, _idje,
   {{0xed5800a1,0x80c00f82,0x6d480037,0x61ea042c}},	//   יבור_, _विजे, údai, _abfl,
   {{0x86980c0d,0x63bb0f9d,0x386d0f9e,0xdb060f9f}},	//   _вкус_, raun, _iker_, _sekú,
   {{0x629b025a,0xe4e702ec,0xdb0f0428,0xb06300c2}},	//   rquo, _відн, _mecà, äänt,
   {{0x92d700c7,0x9f5e000d,0x26190d39,0x63bb0fa0}},	//   াবে_, ětí_, पाठी_, paun,
   {{0x66010fa1,0x44e10fa2,0xaac70be4,0x6e25009c}},	//   _halk, mó_, _लिंक, _aohb,
   {{0x69c70fa3,0x44e10fa4,0x539a00a1,0x43850037}},	//   _odje, ló_, _עיסו, _الشق,
   {{0x69c701e5,0x6da30fa5,0x66010084,0x7bdd0072}},	//   _ndje, зира, _jalk, _acsu,
   {{0x44e10fa6,0x2d8c0212,0x386d0634,0xdca600d3}},	//   nó_, äde_, _oker_, саби,
   {{0x69dc0fa7,0x62990fa8,0x7aef0fa9,0x20120134}},	//   _scre, _kuwo, _bpct, _unyi_,
   {{0x290a00e9,0xa3df0251,0x63b90150,0x69c70357}},	// [920] _srba_, _तान_, _mewn, _bdje,
   {{0xbf9b0396,0xdb0f015e,0xa2cf00b6,0x387f01ff}},	//   ndên, _decà, _दिन्, _ahur_,
   {{0x44e10faa,0x31ba0130,0x93f9009d,0x387f03dc}},	//   jó_, רזענ, ्याच_, _bhur_,
   {{0x387f0fab,0x44e10fac,0xe73a02fd,0x44f800de}},	//   _chur_, dó_, лее_, _rũ_,
   {{0x27e60fad,0x44e10072,0x629903a9,0x387f0fae}},	//   rfon_, eó_, _nuwo, _dhur_,
   {{0x63a20faf,0xceb30341,0xfaa30fb0,0x290a007e}},	//   _sfon, ליד_, _харо, _trba_,
   {{0x6601025e,0x44e10fb1,0x96c40034,0x7c260fb2}},	//   _dalk, gó_, _रिकॉ, _kokr,
   {{0x44f80028,0x62990fb3,0x69c70fb4,0x7c260090}},	//   _vũ_, _buwo, _zdje, _jokr,
   {{0x8c1b004f,0x66010fb5,0x32660448,0x85060281}},	//   רופי, _falk, йтов, _گوان,
   {{0x41dd02e8,0x8afb00c1,0x66010188,0x11d800e3}},	//   _माणस, נהיי, _galk, جودة_,
   {{0x04960080,0x44e10890,0xdb0f0fb6,0xdfd10fb7}},	//   _الصح, có_, _mecá, ويد_,
   {{0x6e2501e8,0x7ae40fb8,0x7c2600f3,0x78780220}},	//   _sohb, ktit, _nokr, zívn,
   {{0x447b0130,0xdb1d0146,0x62990361,0xbf9b0231}},	//   _ענדע, _odsá, _guwo, bdên,
   {{0x7ae40fb9,0x63b900a5,0x6601008c,0xdb0f015e}},	//   dtit, _zewn, _xalk, _recà,
   {{0x90a60fba,0x7ae4084e,0x8bc700ae,0x00000000}},	//   _احتم, etit, йсад, --,
   {{0x44260fbb,0x7c260449,0x62990167,0x318e013c}},	//   _joo_, _cokr, _yuwo, məz_,
   {{0x2fc90fbc,0x44260197,0x44e10068,0x78780038}},	// [930] _idag_, _moo_, zó_, tívn,
   {{0x4426025e,0x386d02b9,0x6f0d0fbd,0x98b808bb}},	//   _loo_, _sker_, _irac, _ayrı_,
   {{0xda780fbe,0x6f0d025b,0x7d080fbf,0xdb0f0328}},	//   сят_, _hrac, ådst, _decá,
   {{0x6f0d0fc0,0x44260fc1,0x44e10fc2,0x66010fc3}},	//   _krac, _noo_, vó_, _salk,
   {{0x66010fc4,0xe6100260,0x7d030fc5,0xfaff01d3}},	//   _palk, کشن_, bírá, šību_,
   {{0x44e100fb,0xd126012b,0x2ba500b6,0x442601ee}},	//   tó_, _قم_, गुरा, _aoo_,
   {{0x63b90067,0xe3b10080,0x66010fc6,0x62990fc7}},	//   _pewn, ورة_, _valk, _suwo,
   {{0x44e10fc8,0x386d00d6,0x66010fc9,0x6f0d0fca}},	//   ró_, _uker_, _walk, _orac,
   {{0x44e10fcb,0xe816009d,0x27ed0800,0x6f0d0174}},	//   só_, णारा_, _iben_, _nrac,
   {{0x2fc90fcc,0x44e10fcd,0x63b900a5,0x317c037d}},	//   _adag_, pó_, _wewn, _bzvz_,
   {{0x3ea9002d,0x6f0d0fce,0x7a3b00fd,0x27ed0fcf}},	//   _atat_, _arac, _gîte, _kben_,
   {{0x44c501d3,0x68e500f0,0x62990fd0,0x44260fd1}},	//   mē_, ithd, _tuwo, _goo_,
   {{0x44c500d9,0x6f0d0fd2,0x64950078,0x644b02a1}},	//   lē_, _crac, _eġit, _imgi,
   {{0x7ae40e37,0x5bb2009f,0x64a300c4,0x44260fd3}},	//   vtit, जर्व, _gđic, _zoo_,
   {{0x44260649,0x27ed02dc,0x8c0100c7,0x3ea90fd4}},	//   _yoo_, _oben_, _একজন_, _etat_,
   {{0x6a7002e2,0x4426023e,0x5baa0fd5,0xeb970fd6}},	//   häft, _xoo_, ркам_, жит_,
   {{0x3b07016e,0x6f0d0fd7,0x7ae4034f,0x3a260fd8}},	// [940] оето_, _grac, utit, омаг,
   {{0x7ae40d63,0x78780fd9,0x320500d7,0x2b40078e}},	//   rtit, tívo, ndly_, rzic_,
   {{0x7ae40fda,0x644b02fe,0xe816009d,0x7c260087}},	//   stit, _omgi, णाला_, _tokr,
   {{0x7ae40fdb,0x44c501d3,0x6bd60246,0xdb240103}},	//   ptit, dē_, _بتدر, _فوجی,
   {{0xaac7030b,0xdb0f037a,0x6f0d0231,0xdb0401ff}},	//   _लिएक, _tecá, _xrac, paiñ,
   {{0x2d4e01e9,0x44260fdc,0xa3e70fdd,0x27ed0fde}},	//   _eнee_, _soo_, म्स_, _eben_,
   {{0xd4970fdf,0x44260fe0,0xd0b100a7,0xd5b907bf}},	//   оры_, _poo_, _təəs, ссі_,
   {{0x68e30428,0x44260085,0xa3df00a4,0x46d2023a}},	//   ànde, _qoo_, _ताण_, _सिपह,
   {{0x44260fe1,0x69da0233,0x00000000,0x00000000}},	//   _voo_, _ötes, --, --,
   {{0x81d200c7,0x26c000c6,0x6f0d0052,0x00000000}},	//   হ্ন_, šios_, _rrac, --,
   {{0x4a7b0130,0x442600a1,0x649500b6,0xa3e70d75}},	//   שריב, _too_, _všic, म्ह_,
   {{0x6f0d0ed9,0x35e000c3,0x4034007b,0x00000000}},	//   _prac, _नाड़, деюс, --,
   {{0xa3e302d5,0x649505db,0xe67b020b,0x00000000}},	//   _पॉट_, _išia, _hưở, --,
   {{0xafdb0537,0xa2f80285,0xdef801b3,0x00000000}},	//   tiøs, ्टीज_, цыю_, --,
   {{0xdd9400c6,0x6f0d0fe2,0x6ce4004d,0x40350fe3}},	//   дары, _wrac, міте, _некс,
   {{0x6f0d0fe4,0xafdb038c,0x261100a5,0x69dd0096}},	//   _trac, riøs, _धोनी_, _पाही,
   {{0x6f0d0fe5,0x44c501d3,0x97ea0367,0x5a350fe6}},	// [950] _urac, zē_, ışlı, пнат,
   {{0x78a301f9,0x00000000,0x00000000,0x00000000}},	//   ínvo, --, --, --,
   {{0xa3da00bc,0x00000000,0x00000000,0x00000000}},	//   ़ला_, --, --, --,
   {{0xdb1f023b,0xae190034,0xa8020233,0x68e50fe7}},	//   naqë, दावन_, _çılg, rthd,
   {{0x8c1a00a1,0x00000000,0x00000000,0x00000000}},	//   _הורי, --, --, --,
   {{0xafdb00d6,0x59e20096,0x3866007e,0x44c500e8}},	//   rnøy, _पायर, čora_, tē_,
   {{0x6a700fe8,0x19580fe9,0x7af90342,0x25ec00aa}},	//   räft, _дары_, şatı, _आउरी_,
   {{0x44390fea,0x44c501d3,0x57f400f6,0xa01b02c3}},	//   ós_, rē_, _опст, smöj,
   {{0xf7490080,0x44c501d3,0x051b0033,0x45d5002d}},	//   _الذي_, sē_, তনের_, _ноас,
   {{0x363700bf,0xc2420879,0x2905037a,0xd5b1020b}},	//   _بررس, еньк, _álas_, _góp_,
   {{0x21690feb,0xdb1d02b6,0xd00a0fec,0x86220281}},	//   сини_, _udsæ, бене_, _سکول,
   {{0x293600c1,0x644b0fed,0xc2f30033,0x3e7601cd}},	//   פארן_, _umgi, জিবি_, mæti_,
   {{0x20040038,0x443f01c2,0x3e7601cd,0x00000000}},	//   ľmi_, mhu_, læti_, --,
   {{0x443f006d,0x3d080cf6,0xf3f9044c,0x20040fee}},	//   lhu_, हिले_, leţ_, žmi_,
   {{0xc69200a1,0x91ba00ca,0xafdb09af,0xed520103}},	//   תאם_, _המצי, riør, رپر_,
   {{0xaac700a5,0x4ac70fef,0x645b0ff0,0x00000000}},	//   _लिखक, _लिखव, nnui, --,
   {{0x6b630ff1,0x443f0ff2,0xf09300d7,0x00000000}},	// [960] екта, ihu_, _אנה_, --,
   {{0x499a0b2f,0xd042013c,0x00000000,0x00000000}},	//   стая_, vrlə, --, --,
   {{0x443f067d,0xa96a0037,0x290e003e,0xd88a0103}},	//   khu_, حمام_, ífa_, مپئن_,
   {{0xfc3200e3,0xdb040126,0x2611074c,0x7a32003e}},	//   _أحد_, ncië, _धोबी_, _mæti,
   {{0xfbd30054,0xf3f900ae,0x4cb10033,0x7c360b85}},	//   _אתר_, deţ_, _জয়পু, mkyr,
   {{0xe8df0028,0x4b7b00ca,0xdb0f016d,0xd6a9001c}},	//   _giữa_, _לאכו, _secç, زدهم_,
   {{0xb5090096,0x5fbe00b6,0x645b0ff3,0x9f590f5a}},	//   विषय_, ्णाल, fnui, gesê_,
   {{0x7c240ff4,0x443f003d,0x43940ff5,0xb3c60971}},	//   njir, ghu_, майс, रृंख,
   {{0xdb060103,0x6fd600a4,0x7a33047e,0x261900a4}},	//   _nekü, _भाजू, _fıtı, पाशी_,
   {{0x628303ea,0x443f0ff6,0x7a32003e,0x31340ff7}},	//   _chno, ahu_, _bæti, деор,
   {{0x443f019f,0xf1dd08d4,0x6495007e,0x00000000}},	//   bhu_, _मारन, _išin, --,
   {{0xc4860ff8,0x395700a1,0x7c24083e,0xdb060103}},	//   _элек, לשים_, jjir, _bekü,
   {{0xee8700c2,0x26c60ff9,0x4ea7065c,0x00000000}},	//   зыво, nsoo_, ярна, --,
   {{0xd2500470,0x62830441,0x6ca70927,0xdb06007f}},	//   _جنت_, _ghno, зраж, _lekó,
   {{0xa1570ffa,0xe9ff00de,0x61fa0ffb,0xc27b00ca}},	//   _нашу_, _ngạc_, metl, _הרגי,
   {{0x31c6030b,0x61fa0ffc,0x415b00ca,0x249e01c2}},	//   bízí_, letl, _לדוג, _mutm_,
   {{0xdb040257,0x60da005c,0xa3df009d,0xdb060364}},	// [970] nciè, lutm, _तास_, _gekü,
   {{0x61fa0ffd,0x7c240a4b,0xe29f003e,0x02d400c0}},	//   netl, ajir, íði_, _दिनभ,
   {{0x6ca40ffe,0x24890031,0x7c380328,0xa3bc00aa}},	//   _пряж, ňami_, ñará, अरा_,
   {{0xf77000cd,0x61fa0fff,0xdb0d0143,0x9f590052}},	//   گام_, hetl, lbaí, jesë_,
   {{0x26191000,0x61fa1001,0x644000e3,0x7c3a020d}},	//   पाली_, ketl, dhmi, être,
   {{0xf7700602,0x61fa0292,0xa3df009f,0xf3f9020a}},	//   دام_, jetl, _ताह_, inţe_,
   {{0x443f1002,0x26c60188,0x00000000,0x00000000}},	//   thu_, asoo_, --, --,
   {{0xc9520054,0x7bdf1003,0xdb1d023b,0x9f59023b}},	//   _סמן_, ngqu, _nesë, gesë_,
   {{0x13060084,0x645b1004,0x61fa026a,0xf3f9020a}},	//   дный_, rnui, fetl, reţ_,
   {{0x443f1005,0xa3df1006,0x645b00d3,0x68e10212}},	//   shu_, _ताव_, snui, _älds,
   {{0x443f1007,0xa2cf0e19,0x3de30033,0xdb1d0052}},	//   phu_, _दिव्, য়াল, _besë,
   {{0xcdc90054,0x6440078f,0x78a91008,0x291100e7}},	//   _כך_, chmi, _čevl, _mrza_,
   {{0xdb060c56,0xdb0401c0,0x09d50081,0x43741009}},	//   _lekò, rcië, স্যা, _пушт,
   {{0x2911100a,0x443d00bd,0xa2940120,0x999800d8}},	//   _orza_, _hlw_, _зачі, _smrž_,
   {{0x1d0709f2,0x443d100b,0x6da30307,0xfce3100c}},	//   мери_, _klw_, тиса, коро,
   {{0x6e21003e,0xdb1d100d,0x00000000,0x00000000}},	//   ölbr, _kesè, --, --,
   {{0x2903100e,0xfaff00d9,0x1a06100f,0x32070027}},	// [980] _asja_, šīnu_, мпам, _kany_,
   {{0x29111010,0x6f040201,0x7c36013f,0x64850037}},	//   _brza_, _isic, skyr, lóid,
   {{0xeb9a1011,0x32070054,0xae1b00c1,0x8c461012}},	//   _мин_, _many_, _וויכ, _жене,
   {{0x3ea01013,0x61fa1014,0x9f5906a3,0x64851015}},	//   _kuit_, zetl, fesè_, nóid,
   {{0x61fa1016,0x41dd034d,0x78780231,0x00000000}},	//   yetl, _मांस, nívi, --,
   {{0x28db0557,0x6f040051,0x09d50033,0x443d00f0}},	//   मूहि, _msic, স্বা, _alw_,
   {{0x61fa1017,0x5e570130,0x64401018,0x9f59023b}},	//   vetl, ויסע_, thmi, tesë_,
   {{0x7bc41019,0xdb1d0113,0x672d0052,0x61fa0313}},	//   naiu, _besè, ënjë, wetl,
   {{0xa3df07e5,0x68e10222,0x3ea0025a,0x61fa101a}},	//   _तार_, _äldr, _nuit_, tetl,
   {{0x6440023b,0xa683101b,0x2fc000b3,0xdb1d101c}},	//   shmi, _алуд, _aeig_, _desè,
   {{0x61fa101d,0x6f04101e,0xae220fef,0x443d0131}},	//   retl, _asic, मानन_, _flw_,
   {{0x68e10222,0x61fa101f,0xf99300a1,0x3ea01020}},	//   _ålde, setl, כרת_, _buit_,
   {{0x69ce0181,0x32070da7,0x27e40063,0x3ead0313}},	//   _odbe, _fany_, _mcmn_, ëet_,
   {{0x3ea01021,0x32070154,0x683a00b3,0x00000000}},	//   _duit_, _gany_, _oïdo, --,
   {{0xd30800ef,0x2486022e,0x2bd00006,0x6e940127}},	//   _hệ_, _khom_, तृभा, тиру,
   {{0x3ea01022,0x69ce0a69,0xdb0606a3,0xd30800de}},	//   _fuit_, _adbe, _rekò, _kệ_,
   {{0x661a0a9f,0x62981023,0xae0c0c22,0xb4bb00c3}},	// [990] _ontk, _kivo, िएशन_, _अब्_,
   {{0x20090a88,0x24860090,0xdb060154,0x2fc0042c}},	//   _haai_, _lhom_, _pekò, _zeig_,
   {{0xd3080019,0xa3df0c9c,0xdb1d0103,0x7a32003e}},	//   _lệ_, _ताल_, _mesé, _nætu,
   {{0xa2cf1024,0xec350130,0x62981025,0x315700c1}},	//   _दिल्, _נאָר_, _livo, ויבן_,
   {{0x66081026,0x2ee90063,0x20090f5a,0x99580206}},	//   _badk, _jqaf_, _maai_, háňa_,
   {{0x62981027,0x2009057a,0xdb1d1028,0xfb16006e}},	//   _nivo, _laai_, _odsú, _אַלט_,
   {{0x6608025e,0x6d4703e5,0x69c51029,0x9f5906a3}},	//   _dadk, nzja, mahe, sesè_,
   {{0xcd9809c1,0x2486102a,0x69c5102b,0x588702e3}},	//   ודות_, _chom_, lahe, _цыга,
   {{0x6298102c,0x443d0161,0xfe0f102d,0x320700ee}},	//   _bivo, _vlw_, ायास_, _pany_,
   {{0x6608102e,0x69c5102f,0x3ea01030,0x649500c6}},	//   _gadk, nahe, _ruit_, _išim,
   {{0x09d500c7,0xd00a1031,0xdb1d002b,0xdb041032}},	//   স্থা, пене_, _desé, rcié,
   {{0x7a320102,0x7878025b,0x23600146,0x7643005c}},	//   _hætt, tívi, _žije_, lhny,
   {{0x69c5101e,0x20090185,0x64851033,0x2fc005fe}},	//   kahe, _daai_, róid, _veig_,
   {{0x09d50f71,0xfc3f0933,0x63a91034,0x3ea005fe}},	//   স্তা, _alí_, lcen, _vuit_,
   {{0x75f3008e,0x7a320088,0x69c51035,0x6aa40188}},	//   mızı, _mætt, dahe, wqif,
   {{0x3ea007e4,0x98a700b6,0x200902ac,0xfc3f033c}},	//   _tuit_, šně_, _gaai_, _clí_,
   {{0x1e960097,0xfc3f00e3,0xab661036,0x2be1030b}},	// [9a0] _прор, _dlí_, хвал, _फारा,
   {{0x75f30587,0xd9461037,0x69c51038,0x7a320537}},	//   nızı, нези, gahe, _nætt,
   {{0xa3df1039,0xba3b0428,0x6608103a,0x7dbb0327}},	//   तला_, _suïc, _radk, _מציצ,
   {{0x63a9103b,0xc18c00c1,0xe786004d,0x248d103c}},	//   jcen, קטאָ, нуло, jmem_,
   {{0xe737103d,0x69c5103e,0x2ca100e7,0x26dd0449}},	//   нец_, bahe, _zuhd_, guwo_,
   {{0x63a9103f,0x69ce052f,0x69c50167,0x200b0094}},	//   ecen, _udbe, cahe, zdci_,
   {{0x62981040,0x2486006c,0xdb1d1041,0x64950218}},	//   _rivo, _phom_, _resé, _išij,
   {{0xdb0f0072,0x764302fa,0x63a91042,0x0463022a}},	//   _recú, ahny, gcen, лтым,
   {{0xa01b0088,0x6d47003d,0xdb08020d,0x20090313}},	//   llög, zzja, élèv, _raai_,
   {{0xd3080028,0x63a91043,0x20091044,0xddc7033b}},	//   _vệ_, acen, _saai_, kojš,
   {{0xa3e8018b,0x63a91045,0xb7bd00d3,0x2009084e}},	//   _बाप_, bcen, _soţi, _paai_,
   {{0x23660d7d,0x63a91046,0x44cc030b,0xd30800de}},	//   _txoj_, ccen, mě_, _tệ_,
   {{0x69c51047,0x00000000,0x00000000,0x00000000}},	//   yahe, --, --, --,
   {{0x61460257,0x2009057a,0xfc3f0037,0x28d100b7}},	//   _célé, _waai_, _slí_, _हिलि,
   {{0x69c50006,0x44cc030b,0xbd681048,0x614600fd}},	//   vahe, ně_, ерте_, _délé,
   {{0x9f520a43,0x69c51049,0xb7bd020a,0x657a0632}},	//   _cayó_, wahe, _toţi, _myth,
   {{0x69c50bd9,0x3a750231,0x657a0178,0x6146104a}},	// [9b0] tahe, влар, _lyth, _félé,
   {{0xddc7104b,0xbbeb00cd,0x9967104c,0x6146104d}},	//   bojš, _کردم_, нтел, _gélé,
   {{0x7a3201ab,0xe61f0019,0x657a104e,0x63a9104f}},	//   _rætt, _đô_, _nyth, ycen,
   {{0x7a321050,0x44cc000d,0x69c51051,0xd75908ba}},	//   _sætt, dě_, sahe, ولات_,
   {{0xd90f00fb,0x7643005c,0xab841052,0x00000000}},	//   _گیا_, thny, _бурк, --,
   {{0x7aed0018,0x657a1053,0x64951054,0x46d200b6}},	//   mtat, _byth, _všim, _सिरह,
   {{0xd90f00fb,0xd4691055,0x657a0178,0xf3f9020a}},	//   _دیا_, мике_, _cyth, enţa_,
   {{0x7aed028d,0x6d581056,0x76430085,0x00000000}},	//   otat, _žvak, shny, --,
   {{0xc8641057,0x248d1058,0x7a3202b6,0x4864008f}},	//   _стри, rmem_, _tætt, _сърб,
   {{0x63a91059,0x7aed105a,0x7c2f028d,0x44cc02c6}},	//   scen, itat, _locr, bě_,
   {{0xa06a105b,0x7aed023b,0xe8160096,0x63a907ee}},	//   дана_, htat, णाचा_, pcen,
   {{0x7c2f03a9,0xa3e80714,0x6146014b,0x00000000}},	//   _nocr, _बाय_, _sélé, --,
   {{0xe28e105c,0x09cc0081,0x442f041c,0x00000000}},	//   _ва_, র্টা, _iog_, --,
   {{0xc0a80979,0xda11007d,0x7aed105d,0x2d9e004d}},	//   بایل_, _डोलत_, dtat, øte_,
   {{0x1fb6105e,0x442f0d62,0x7aed105f,0x217500c1}},	//   _испр, _kog_, etat, _בײַם_,
   {{0x442f1060,0xe8df00de,0xbc631061,0x9f520139}},	//   _jog_, _nhựa_, авск, _dayò_,
   {{0x614604ea,0x442f01fa,0x7aed0256,0x649500e7}},	// [9c0] _télé, _mog_, gtat, _ašik,
   {{0x4a431062,0x442f00a1,0xd5e00557,0xa01b0212}},	//   анув, _log_, _नाइज, smöt,
   {{0x442f0305,0x2dd900c1,0x4dd900c1,0x77690072}},	//   _oog_, _אַרב, _אַרױ, _axex,
   {{0x44cc000d,0x442f1063,0x76411064,0x657a0257}},	//   vě_, _nog_, _ally, _ryth,
   {{0x7aed1065,0xb8650dce,0x657a1066,0x4af900ae}},	//   ctat, دالو, _syth, _пэря_,
   {{0x09cc00c7,0x649500cc,0x44cc030b,0x98a700d3}},	//   র্জা, _ušij, tě_, ână_,
   {{0xe97600cd,0x77690072,0xa2bf0034,0x04661067}},	//   _شهرد, _exex, लीस्, ктим,
   {{0x442f0197,0x00000000,0x00000000,0x00000000}},	//   _cog_, --, --, --,
   {{0x657a02ad,0x65c61068,0x442f00ca,0x4274016d}},	//   _wyth, _абза, _dog_, лгис,
   {{0x44cc02c6,0x442f030a,0xb355001c,0x00000000}},	//   pě_, _eog_, دیها_, --,
   {{0x7aed1069,0x442f106a,0xd48f106b,0xd3e400cd}},	//   ztat, _fog_, _вр_, _مقای,
   {{0x320a0897,0x76580010,0xe53700c1,0x6f16106c}},	//   žby_, livy, _שטאט_, _bryc,
   {{0x6442106d,0xdb0d0131,0x6f16106e,0xdd3b078e}},	//   _iloi, mbaç, _cryc, _băşt,
   {{0x442f01bb,0x7c2f106f,0x6f161070,0xa3e800bc}},	//   _zog_, _socr, _dryc, _बाड_,
   {{0x442f1071,0x16df099d,0x2d8501df,0xe29b00ca}},	//   _yog_, _नम्ब, åle_, _קשור,
   {{0x7aed1072,0x3d0802e8,0x46d21073,0x09cb009d}},	//   ttat, हिजे_, _सिंह, ाण्य,
   {{0x7aed1074,0x5b15065c,0x4c9400c2,0xc4c40103}},	// [9d0] utat, ымат, ритс, _ڈے_,
   {{0x7aed1075,0x5fb60034,0x9f590143,0x850200b6}},	//   rtat, ूरथल, nesí_, लबाट_,
   {{0x7aed1076,0xda780e38,0x26cd015c,0x6f161077}},	//   stat, тят_, _sveo_, _zryc,
   {{0x7aed1078,0xdb1d0072,0x00000000,0x00000000}},	//   ptat, _hesí, --, --,
   {{0x442f1079,0x44210019,0x64850131,0xf6e7107a}},	//   _rog_, _đh_, jóia, тцен,
   {{0x644202fd,0x6d58013f,0x69dd009d,0x442f107b}},	//   _aloi, _žvai, _पाटी, _sog_,
   {{0x442f107c,0x6442107d,0xb7bd00ae,0xdb1d0143}},	//   _pog_, _bloi, _soţu, _mesí,
   {{0x442f022e,0x1309107e,0x6442107f,0x845800c2}},	//   _qog_, ений_, _cloi, крыт_,
   {{0x628a0080,0x442f1080,0x97ea0b88,0x26cd0335}},	//   _bhfo, _vog_, ıştı, _uveo_,
   {{0x42250ff7,0x64421081,0x442f1082,0x478800ae}},	//   удов, _eloi, _wog_, _рссм_,
   {{0xa2cf05cd,0x56940131,0xe4e4004d,0x6442033c}},	//   _दिक्, _тафт, _вічн, _floi,
   {{0x64421083,0x00000000,0x00000000,0x00000000}},	//   _gloi, --, --, --,
   {{0x63bb1084,0xa3e81085,0xba3b1086,0x60da029a}},	//   mbun, _बात_, _ruïn, artm,
   {{0xa2d8097c,0xfce61087,0x63bb0c19,0x7e750634}},	//   _मित्, лого, lbun, gozp,
   {{0xdb1d00b6,0x2720007f,0x63bb0350,0xa01b1088}},	//   _desí, _मप्र_, obun, rmör,
   {{0x6f161089,0x6e3c108a,0x2a78108b,0x63bb108c}},	//   _tryc, skrb, _skrb_, nbun,
   {{0x63bb02e2,0xc05300ca,0x200207f5,0x3a3100d4}},	// [9e0] ibun, _לזה_, meki_, _bozp_,
   {{0x200209e7,0x01d50033,0xd9ae0285,0x00000000}},	//   leki_, ত্রদ, टडेट, --,
   {{0x291e0e94,0x38cb010d,0x46c602d5,0x9c66001c}},	//   _štab_, فانی_, रीनह, _مهدو,
   {{0x6495009e,0xdb1d108d,0xa3df0d75,0x81760142}},	//   _eġiz, _desâ, _ताग_, אגעס_,
   {{0xa2cf0e19,0x601b007b,0x63bb108e,0xa01b042c}},	//   _दिग्, _hämä, dbun, llöc,
   {{0x64420527,0x7bc6023b,0xa5f8108f,0x63bb1090}},	//   _sloi, _heku, теку_, ebun,
   {{0xa3e81091,0x7bc60496,0x644200d3,0x765802f1}},	//   _बाद_, _keku, _ploi, rivy,
   {{0x20020510,0x63bb1092,0x76581093,0x7bc60350}},	//   jeki_, gbun, sivy, _jeku,
   {{0x38550465,0x200201e8,0x05240081,0xdb041094}},	//   _търс, deki_, বনের_, mbió,
   {{0x7bc61095,0x27e61096,0x64a600d6,0x00000000}},	//   _leku, lgon_, _бажа, --,
   {{0xdb1d1097,0x63bb01c2,0x601b007b,0x00000000}},	//   _resí, bbun, _nämä, --,
   {{0x27e61098,0x7bc61099,0x64850674,0x71f70068}},	//   ngon_, _neku, lóin, پریس_,
   {{0xa85700ca,0x27e600fe,0x00000000,0x00000000}},	//   ריכה_, igon_, --, --,
   {{0x539b0105,0x291801b5,0xdb1d016d,0xc694006e}},	//   _ניגו, _orra_, _lesã, יאָ_,
   {{0x7bc6109a,0xdb1d002b,0x7e75109b,0x2002109c}},	//   _beku, _vesí, rozp, beki_,
   {{0x200201e8,0x63a20231,0xade900b6,0x00000000}},	//   ceki_, _jgon, ञ्जन_, --,
   {{0x29180018,0x63a20051,0x320e01c2,0xba550215}},	// [9f0] _arra_, _mgon, _kafy_, авај,
   {{0x63bb00ae,0x00000000,0x00000000,0x00000000}},	//   zbun, --, --, --,
   {{0x6485109d,0x3eb900e8,0x63bb007f,0x00000000}},	//   dóin, lpst_, ybun, --,
   {{0x63a2109e,0x7bc6109f,0xf8c90139,0x64b101d3}},	//   _ngon, _geku, _aréè_, _jāie,
   {{0x291810a0,0x61f8033b,0x65c50131,0x7c2d10a1}},	//   _erra_, _obvl, абла, mjar,
   {{0xe6180565,0x63a210a2,0x200210a3,0x27e910a4}},	//   лді_, _agon, zeki_, żan_,
   {{0xce3800a1,0x7bc60092,0x290500e5,0x63bb0a2c}},	//   ראות_, _yeku, _èla_, tbun,
   {{0x7afd0124,0xa3df0179,0xafdb0537,0x00000000}},	//   _kpst, _ताओ_, shøj, --,
   {{0x63bb10a5,0xc24510a6,0xa3b40336,0xf9a90032}},	//   rbun, иник, झड़_, _gbèè_,
   {{0x69c710a7,0xdb0410a8,0x63a20a00,0x63bb10a9}},	//   _jeje, nciá, _egon, sbun,
   {{0x69c710aa,0x216910ab,0x7c2d10ac,0xafdb052f}},	//   _meje, тини_, kjar, dkøb,
   {{0x7afd10ad,0x69c710ae,0x20560a71,0xdd2f00b6}},	//   _opst, _leje, ртор, _běže,
   {{0x387e10af,0x7c2d10b0,0x200210b1,0x442d10b2}},	//   _être_, djar, reki_, mje_,
   {{0x7bc610b3,0x443f10b4,0x644910b5,0x69c7030b}},	//   _seku, lku_, lhei, _neje,
   {{0x7afd0029,0x442d013f,0x7c2d0088,0xdd920e25}},	//   _apst, oje_, fjar, زور_,
   {{0x644910b6,0x660310b7,0x44f10019,0xef1a10b8}},	//   nhei, henk, _mơ_, _ами_,
   {{0x69c70068,0x207b00c1,0x443f10b9,0x644910ba}},	// [a00] _beje, _באקא, iku_, ihei,
   {{0xba2310bb,0x601b02fd,0x442d10bc,0x7bc610bd}},	//   одук, _tämä, hje_, _weku,
   {{0x443f0329,0x442d00f3,0x64490665,0x69c710be}},	//   kku_, kje_, khei, _deje,
   {{0x1ae60d64,0x443f00e9,0x64490126,0x442d10bf}},	//   _комм, jku_, jhei, jje_,
   {{0x442d10c0,0x27e610c1,0x644910c2,0x69c710c3}},	//   dje_, rgon_, dhei, _feje,
   {{0x443f0029,0x660304aa,0x442d00a5,0x69c70d12}},	//   eku_, genk, eje_, _geje,
   {{0x44f100ef,0x7ae410c4,0x644900e3,0xdb1d001f}},	//   _cơ_, luit, fhei, _tesã,
   {{0x644910c5,0x442d10c6,0x628110c7,0x443f00dc}},	//   ghei, gje_, ello, gku_,
   {{0x660310c8,0x32660cf5,0x23380084,0x779400cd}},	//   benk, итов, уппы_, _ایشا,
   {{0x442d10c9,0x443f10ca,0x7c2d10cb,0xe5a300d3}},	//   aje_, aku_, zjar, _дифи,
   {{0x850603ed,0x443f10cc,0x442d02dd,0x64490441}},	//   _خوان, bku_, bje_, bhei,
   {{0x644910cd,0x442d0d1b,0x443f068e,0x386610ce}},	//   chei, cje_, cku_, nnor_,
   {{0xfe2210cf,0x7c2d10d0,0xfe7f0428,0xd372001c}},	//   मांस_, vjar, juïc_, _بهش_,
   {{0x7ae410d1,0x30a60ce5,0x6e950aec,0x78a0039f}},	//   duit, _крив, сигу, _limv,
   {{0x69c710d2,0x0ed30096,0x44f10023,0xfda70285}},	//   _reje, _तिकड, _xơ_, _खलीफ,
   {{0xe51704dd,0x69c710d3,0x660310d4,0x644010d5}},	//   थिति_, _seje, zenk, nkmi,
   {{0x7ae410d6,0x7c2d10d7,0x66fa00d9,0xdb0f10d8}},	// [a10] guit, rjar, nākā, _recó,
   {{0x443f0618,0xdb1d10d9,0x442d10da,0x656d0092}},	//   zku_, _cesá, zje_, şahi,
   {{0x442d10db,0x69c710dc,0x64490185,0x3ea900dc}},	//   yje_, _veje, yhei, _huat_,
   {{0x3ea910dd,0x7ae410de,0x38660451,0x660310df}},	//   _kuat_, buit, gnor_, wenk,
   {{0x660310e0,0x443f10e1,0x44f10028,0x442d10e2}},	//   tenk, vku_, _sơ_, vje_,
   {{0x3ea910e3,0x2fc910e4,0x6f0d0350,0xba450103}},	//   _muat_, _leag_, _msac, _انسٹ,
   {{0x442d10e5,0x3ea910e6,0x644910e7,0x58d410e8}},	//   tje_, _luat_, thei, _морт,
   {{0xa2d810e9,0x442d01b3,0x660310ea,0x443f10eb}},	//   _मिश्, uje_, senk, uku_,
   {{0x644910ec,0xa3e810ed,0x660308ac,0x6f0d0174}},	//   rhei, _बार_, penk, _nsac,
   {{0x442d10ee,0x644910ef,0xa2d809b0,0x44f10023}},	//   sje_, shei, _मिर्, _tơ_,
   {{0x2fc910f0,0x442d10f1,0x6f0d10f2,0x8467013d}},	//   _beag_, pje_, _asac, _къде,
   {{0x3ea910f3,0x644010f4,0x442d023b,0x66fa00e8}},	//   _buat_, ckmi, qje_, bākā,
   {{0x02a70a8e,0x147400e3,0x6f630109,0x9e660037}},	//   _трем, _بالج, звяз, ماسن,
   {{0xed5a10f5,0x6d4e0364,0x7ae410f6,0x00000000}},	//   гог_, tzba, vuit, --,
   {{0x50b510f7,0x386610f8,0x27ed10f9,0x6efd0212}},	//   _услу, ynor_, _ocen_, _påbö,
   {{0x7ae410fa,0xb6030618,0x68e50124,0x27ed01dc}},	//   tuit, _hráč, duhd, _ncen_,
   {{0xab2710fb,0x9ce80033,0xb6030094,0x7ae40131}},	// [a20] бота_, খবেন_, _kráč, uuit,
   {{0x78a90b14,0x78a010fc,0x239b0138,0x20120415}},	//   _čevr, _simv, mąjį_, _hayi_,
   {{0xa3e80b7f,0x7ae410fd,0x20120d2a,0x6459029a}},	//   _बाल_, suit, _kayi_, _omwi,
   {{0xa2d8000c,0x32050103,0x201210fe,0x69c60ff9}},	//   _मिल्, hely_, _jayi_, िरही,
   {{0x386610ff,0x78bb1100,0x6ecb1101,0x66e31102}},	//   rnor_, _čuve, तीपु, зоча,
   {{0x20120044,0xdb1d02b6,0x64591103,0x91fc00e8}},	//   _layi_, _besæ, _amwi, gnāl,
   {{0x48e31104,0x78a01105,0x32051106,0x186a0284}},	//   _норв, _timv, dely_, _бави_,
   {{0xe8e00019,0xa2b41107,0x66fa01d3,0xa3e80096}},	//   _chụp_, обич, tākā, _बाळ_,
   {{0x64400088,0x661100c2,0x2fc90036,0x239b00c6}},	//   rkmi, ökkä, _reag_, jąjį_,
   {{0x6440007a,0x66fa01d3,0xc50a1108,0x60cd007f}},	//   skmi, rākā, _متصل_, _łama,
   {{0x20121109,0x5316110a,0x09d50033,0x3ea9110b}},	//   _bayi_, _گذار, স্কা, _suat_,
   {{0x9f99110c,0x6f0d0354,0x3ea90113,0xfe7f00ee}},	//   ивну_, _psac, _puat_, duïa_,
   {{0x32050a7f,0x3ea900fe,0x28af110d,0x6495110e}},	//   bely_, _quat_, _जूनि, _všit,
   {{0x6d14110f,0xfbdf03a8,0x32050d54,0x00000000}},	//   डिंग_, _clên_, cely_, --,
   {{0x40351110,0x64a3015c,0x20120027,0x2fc901b9}},	//   _мекс, _uđit, _fayi_, _teag_,
   {{0x0ca81111,0x201201c2,0x649500d4,0x00000000}},	//   стри_, _gayi_, _ušit, --,
   {{0x5a351112,0xe7cc0034,0x6f0d039f,0x6a350291}},	// [a30] онат, ारनप, _usac, онађ,
   {{0x27ed1113,0x6aad0052,0xfe7f00b3,0xfbdf03a8}},	//   _scen_, rqaf, buïa_, _glên_,
   {{0x20121114,0xa3e81115,0x27ed00f3,0x00000000}},	//   _yayi_, बला_, _pcen_, --,
   {{0xac191116,0xb901034d,0xc0b20023,0x765a063d}},	//   _тому_, _दि_, _sưởi_, _amty,
   {{0xd6db0cfc,0x6675001c,0xb06600c2,0x1dbf1117}},	//   уте_, يدتر, ltää, ्रपत,
   {{0xf7700a09,0x00000000,0x00000000,0x00000000}},	//   ران_, --, --, --,
   {{0xb0660084,0x32051118,0x91fc00d9,0x27ed0036}},	//   ntää, vely_, rnāl, _tcen_,
   {{0x99540fe9,0x00000000,0x00000000,0x00000000}},	//   _эксц, --, --, --,
   {{0x52a61119,0x32050b82,0xe7330dd0,0x2012111a}},	//   овым_, tely_, _عصر_, _rayi_,
   {{0x2012111b,0x5f1d05d6,0xe4e70120,0x00000000}},	//   _sayi_, मिन्_, _гідн, --,
   {{0x386d0b27,0x69d80396,0xe3b30602,0x320500ca}},	//   _kjer_, óvei, _فرش_, rely_,
   {{0xdb1d02fd,0x7643038c,0x64590193,0x60dc111c}},	//   _kesä, lkny, _umwi, árma,
   {{0x32050146,0x44f3016d,0x76430167,0x2d85111d}},	//   pely_, lã_, okny, ülen_,
   {{0x7643111e,0x2012111f,0xe8df00fe,0xa01b1120}},	//   nkny, _wayi_, _chừa_, llöl,
   {{0x2d8c02fe,0x6da31121,0xf3f900d3,0x20121122}},	//   åde_, дира, enţi_, _tayi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7ff08fa,0x7643005c,0xd0420092,0xa09b0266}},	// [a40] ोजना_, kkny, xslə, _דיקט,
   {{0x25fb099d,0x386d1123,0x387f1124,0x5e570037}},	//   ल्मी_, _ajer_, _akur_, _وليس_,
   {{0xda1b0251,0x291c1125,0xafdb0565,0x7e7c1126}},	//   _नफरत_, íva_, rhøv, morp,
   {{0x6b830174,0xdb1d0c19,0xfe7f00ee,0x77861127}},	//   ọgas, _besä, nuïn_, олез,
   {{0x7c261128,0x386d03a9,0x00000000,0x00000000}},	//   _inkr, _djer_, --, --,
   {{0x386d01c5,0xd04200a7,0x1dbf0213,0x6b8b1129}},	//   _ejer_, rslə, ्रयत, ügge,
   {{0x344a00a9,0x3af40324,0xd04200a7,0xdb07003e}},	//   ичин_, läp_, sslə, élög,
   {{0x386d00f3,0x7e7c112a,0x76430167,0x9cd700ca}},	//   _gjer_, horp, akny, קופה_,
   {{0x7e7c112b,0x1666013d,0x213e0150,0x3a380078}},	//   korp, _двам, wyth_, _korp_,
   {{0x7af601b3,0x7643112c,0xb06600c2,0x00000000}},	//   ityt, ckny, ytää, --,
   {{0x7c26112d,0x6e37112e,0x7e7c112f,0x3a380063}},	//   _onkr, _roxb, dorp, _morp_,
   {{0x8cb100a4,0x00000000,0x00000000,0x00000000}},	//   _आंबो, --, --, --,
   {{0x09d50081,0x44261130,0xdefb00c6,0x289b006e}},	//   স্টা, _ino_, шын_, ייטא,
   {{0x44261131,0x3f850029,0x7c261132,0xb06600c2}},	//   _hno_, ālu_, _ankr, ttää,
   {{0x25b900a7,0xf3f9044c,0x91bb00d7,0x00000000}},	//   _əsl_, liţa_, _דמוי, --,
   {{0x8cdc0f35,0x44260167,0x1bbb0037,0xb06600ce}},	//   _फिरो, _jno_, شارع_, rtää,
   {{0xa3e81133,0xb0660084,0x44261134,0xe8df0019}},	// [a50] _बाई_, stää, _mno_, _thừa_,
   {{0x7c2602dd,0x09e30081,0x387f1135,0x9f5902b6}},	//   _enkr, ন্না, _skur_, geså_,
   {{0x3a380305,0x999102c6,0x386d1136,0x00000000}},	//   _dorp_, _vozů_, _pjer_, --,
   {{0x44260517,0x67000134,0x3a3801b9,0xdb1d007b}},	//   _nno_, _ịkag, _eorp_, _pesä,
   {{0x8707001c,0x2b52007f,0x6d5a1137,0xaae200c3}},	//   تبال, czyc_, útav, _पियक,
   {{0x44261138,0xd12600e3,0x58d500c2,0xc1780138}},	//   _ano_, _كم_, _ногт, ngės_,
   {{0xe5a20b21,0x76431139,0x0445083c,0x386d0216}},	//   ниши, rkny, зейн, _tjer_,
   {{0x387f113a,0x442601b9,0x76430167,0x44f30231}},	//   _ukur_, _cno_, skny, rã_,
   {{0x27ff0124,0xa01b02c3,0x28af00a3,0x44f30231}},	//   _ibun_, glöm, _जूति, sã_,
   {{0x4426113b,0x00000000,0x00000000,0x00000000}},	//   _eno_, --, --, --,
   {{0xf8cb009f,0x05190076,0x44260565,0xfe7f00b3}},	//   ाठिय, _دياب_, _fno_, tuïn_,
   {{0x44d7002d,0xe8df0019,0xbbaa06eb,0xafdb09af}},	//   mă_, _chứa_, _कलेक, skøn,
   {{0x7d1e113c,0x644b113d,0x44d7002d,0x09e30081}},	//   _srps, _ilgi, lă_, ন্যা,
   {{0x629d030b,0x00000000,0x00000000,0x00000000}},	//   ůsob, --, --, --,
   {{0x44d70012,0x44260150,0x00000000,0x00000000}},	//   nă_, _yno_, --, --,
   {{0x09e30081,0x5baa113e,0x7af601ce,0x00000000}},	//   ন্মা, скам_, ttyt, --,
   {{0x78bb00e9,0xe9da0e4a,0xaca40134,0xeb97113f}},	// [a60] _čuva, йка_, _nhụt, зит_,
   {{0x27ff0044,0x3af402c3,0x6f04039f,0x6a8300d3}},	//   _abun_, räp_, _ipic, елуа,
   {{0xe8fa0f48,0x7af61140,0xaca40294,0x44d700d3}},	//   сле_, styt, _ahụt, jă_,
   {{0xa3ea000c,0xafdb0856,0x44d700d3,0xfaa61141}},	//   _टाइप_, lhør, dă_, _намо,
   {{0x7bc41142,0x442605db,0xf7431143,0x3a38032e}},	//   mbiu, _rno_, нецо, _torp_,
   {{0x644b0138,0x27ff0af0,0x44260973,0x7ae41144}},	//   _algi, _ebun_, _sno_, mrit,
   {{0x44d700d3,0x69dc00d6,0x290c028d,0xf8e00034}},	//   gă_, _idre, _èda_, _पटिय,
   {{0xb6030029,0x68e30fb6,0x69ce1145,0x6f040f1c}},	//   ēšan, ánde, _hebe, _opic,
   {{0x69ce03b4,0x7ae401ab,0x66e31146,0x22861147}},	//   _kebe, nrit, _пота, зунг,
   {{0x64aa000d,0x69ce0880,0x25fb0789,0xf3f900ae}},	//   _přid, _jebe, ल्दी_, riţa_,
   {{0x69ce1148,0x44d70012,0x7ae402e2,0x55bb00ca}},	//   _mebe, că_, hrit, _המבו,
   {{0x44261149,0x69ce114a,0x6f0400da,0x00000000}},	//   _uno_, _lebe, _bpic, --,
   {{0x69dc03ce,0xa8570327,0x69ce0113,0x00000000}},	//   _odre, ליטה_, _oebe, --,
   {{0x8cb10e72,0x69ce114b,0x6266114c,0xbeed114d}},	//   _आंदो, _nebe, _عاشق, _जमीन_,
   {{0x7ae4007a,0xd7cc009d,0x09e30081,0x01fb00ca}},	//   erit, ाराच, ন্ডা, _הפול,
   {{0x69dc114e,0x7ae4114f,0x69ce01e9,0xdb0d1150}},	//   _adre, frit, _aebe, scaí,
   {{0x69ce1151,0x44d70012,0x6fc31152,0x91fc01d3}},	// [a70] _bebe, ză_, _व्यं, ciāc,
   {{0x19ab001f,0x6d590022,0x200b1153,0x69ce1154}},	//   стап_, _ƙwad, leci_, _cebe,
   {{0x69ce1155,0x39471156,0x7ae4028d,0x5eed00c3}},	//   _debe, áns_, arit, _जमुई_,
   {{0x44d700d3,0x9cd600ca,0xf9900037,0x200b1157}},	//   vă_, _קורה_, ابك_, neci_,
   {{0xa2d80285,0x00000000,0x00000000,0x00000000}},	//   _मिग्, --, --, --,
   {{0x69ce1158,0x44d70012,0x1dbf0c9c,0x3cf80504}},	//   _gebe, tă_, ्रित, _بعید_,
   {{0x7bcf0496,0x78a2025b,0x200b0220,0xdb1d0220}},	//   _kecu, ňova, keci_, _nesú,
   {{0x44d70012,0x200b0ea3,0x27ff02e7,0xa01b0149}},	//   ră_, jeci_, _ubun_, slöj,
   {{0x44d7002d,0x1dbf009d,0x7bcf1159,0xd5b100de}},	//   să_, ्रात, _mecu, _các_,
   {{0xe0d9115a,0x44d700d3,0x69ce00a7,0x6ed7115b}},	//   ово_, pă_, _xebe, _बिजु,
   {{0x69c501b5,0x7ae40181,0x7bcf0381,0x741200d1}},	//   ibhe, zrit, _oecu, رویا,
   {{0xb92200ac,0x7bcf00d3,0x7ae400c2,0x6aa7029a}},	//   _akpọ_, _necu, yrit, _lijf,
   {{0x998300c6,0x00000000,0x00000000,0x00000000}},	//   _kojų_, --, --, --,
   {{0x09e30081,0x7ae4115c,0x3d0a0179,0xfe7f00ee}},	//   ন্তা, vrit, ाबले_, buïm_,
   {{0x7bcf115d,0xbea3115e,0xafdb00f2,0x200b115f}},	//   _becu, тарк, rhør, beci_,
   {{0x69ce1160,0xd9f01161,0xdd8f0c5e,0xb5fc02a1}},	//   _sebe, _चाहत_, شوق_, _imġe,
   {{0x78ae1162,0x7bcf1163,0xd910110a,0x69ce052f}},	// [a80] _subv, _decu, گیز_, _pebe,
   {{0x7ae41164,0x1cba003f,0xe8df0019,0x6aa70126}},	//   rrit, _واجب_, _chữa_, _cijf,
   {{0xfbc61165,0xdb1d03be,0x7bcf04c3,0x2d961166}},	//   _обно, _xesú, _fecu, _юрис,
   {{0xab2a1167,0x31360130,0x7bcf1168,0x6d620d2a}},	//   _дома_, ונעם_, _gecu, _ƙwaƙ,
   {{0x69ce1169,0x09e30081,0x394601d3,0xe737116a}},	//   _tebe, ন্ধা, ņos_, мец_,
   {{0x69dc116b,0x659400ae,0x69ce0364,0x200b116c}},	//   _udre, налу, _uebe, zeci_,
   {{0x693502c6,0xdb060537,0x00000000,0x00000000}},	//   _přeš, _afkø, --, --,
   {{0x64aa030b,0xdb1d0610,0x09e30033,0xd7060e2c}},	//   _přib, _resú, ন্দা, _озби,
   {{0x41e6116d,0x25fb116e,0x200b116f,0x64aa02c6}},	//   міна, ल्ही_, veci_, _břic,
   {{0xd2501170,0xd6260190,0x51f8004d,0xf5e700d3}},	//   اند_, _تعري, чною_, _омул_,
   {{0xa01b00c2,0x62830350,0x693502c6,0x63b900eb}},	//   llöi, _dkno, _třeš, _ffwn,
   {{0xa3e8000d,0xc32a00e3,0xd5b100fe,0x00000000}},	//   _बाट_, _وكان_, _tác_, --,
   {{0xa2d80251,0x7bcf1171,0x200b1172,0x67000285}},	//   _मिट्, _recu, reci_, ोबिक_,
   {{0x200b03ce,0x7bcf1173,0x00000000,0x00000000}},	//   seci_, _secu, --, --,
   {{0x38b704f9,0x6d550036,0x320c1174,0x200b1175}},	//   _oħra_, uzza, medy_, peci_,
   {{0xfc150077,0x28d81176,0x320c1177,0xa3c31178}},	//   эмбэ, _डिजि, ledy_, ्रय_,
   {{0x7bcf00d9,0x7b670b1b,0xfe1a1179,0x00000000}},	// [a90] _vecu, фтве, _फोकस_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3c30961,0x1bd5117a,0x69c5117b,0x6aa70126}},	//   ्रम_, _поня, rbhe, _vijf,
   {{0x3f89006d,0x78a20031,0x6aa701cb,0x00000000}},	//   _kyau_, ňovn, _wijf, --,
   {{0x320c0181,0xa3e80caf,0x7d020542,0x7c3d033f}},	//   kedy_, _बाज_, _ćosi, _iosr,
   {{0x24510618,0x7aed0332,0x46e000aa,0xf1c70e43}},	//   _máme_, muat, _निरह, ďáky_,
   {{0x7aed09bc,0x82b80134,0xc984117c,0x7c3d02ac}},	//   luat, _rịịl_, _аути, _kosr,
   {{0xe7f9000d,0xdb1d0939,0xe8cb0096,0x00000000}},	//   _एउटा_, _besø, ाठीच, --,
   {{0x25a900cd,0x64aa00b6,0x3f890350,0x7c3d0216}},	//   _فضای_, _přic, _nyau_, _mosr,
   {{0x291e0138,0x4ae200b7,0x00000000,0x00000000}},	//   _štai_, _पिसव, --, --,
   {{0x7aed117d,0x3f890022,0x7c3d084e,0x00000000}},	//   huat, _ayau_, _oosr, --,
   {{0x7aed117e,0xdee6117f,0x1b060033,0x00000000}},	//   kuat, номи, রিতে_, --,
   {{0xe80102e8,0x7aed1180,0x64490364,0xd9f00096}},	//   ळ्या_, juat, mkei, _चालत_,
   {{0x443d0054,0x78a91181,0x644900c2,0x24510146}},	//   _how_, _liev, lkei, _dáme_,
   {{0x62811182,0xda020efb,0x7c3d1183,0x443d1184}},	//   molo, र्फत_, _bosr, _kow_,
   {{0x7aed068d,0x62811185,0x78a91186,0x64491187}},	//   fuat, lolo, _niev, nkei,
   {{0x3b070465,0xfe720068,0x7aed1188,0xadee009d}},	// [aa0] нето_, _مدد_, guat, _जाऊन_,
   {{0x9b9300e3,0x443d00a1,0x7c360120,0x09e30033}},	//   الكت, _low_, sjyr, ন্সা,
   {{0x64491189,0xd943004c,0xeabf01b9,0xef1800e8}},	//   kkei, лефи, _crùb_, āļu_,
   {{0x443d0054,0x7aed0808,0x78a90031,0x3eb204d6}},	//   _now_, buat, _ciev, _kuyt_,
   {{0x78a9118a,0x91fc00d9,0x7bd6118b,0x7aed118c}},	//   _diev, onāt, mayu, cuat,
   {{0x25fb0d0b,0x6281118d,0x7bd6118e,0x443d118f}},	//   ल्ली_, jolo, layu, _aow_,
   {{0x291e01cd,0x7c3d061d,0x3eb20f5a,0x443d1190}},	//   _éta_, _yosr, _luyt_, _bow_,
   {{0x644902dc,0x98a31191,0x78a91192,0x7bd61193}},	//   gkei, _бисе, _giev, nayu,
   {{0x0edc0ed3,0x57cc030b,0xa3b70037,0x68e10212}},	//   _बिगड, ारीह, راير_, _åldr,
   {{0x62811194,0x7bd61195,0xa68305da,0x00000000}},	//   golo, hayu, _блуд, --,
   {{0xa3b3030b,0x320c0206,0x75d30076,0x00000000}},	//   जुङ_, redy_, _إيما, --,
   {{0x44fa074a,0x661a00e7,0xa3c30efb,0x38661196}},	//   më_, _hatk, ्रण_, nior_,
   {{0x62811197,0xff041198,0x44fa00dd,0x661a1199}},	//   bolo, лярн, lë_, _katk,
   {{0x661a02fd,0x7c3d0479,0x386605bd,0x7bc2002b}},	//   _jatk, _sosr, hior_, ñoun,
   {{0x44fa074a,0x661a119a,0x7c3d011d,0x5ce403a0}},	//   në_, _matk, _posr, люта,
   {{0x7aed119b,0x7bd6119c,0x661a119d,0x6485119e}},	//   tuat, gayu, _latk, lóir,
   {{0x44fa00dd,0x78a9119f,0xeab30037,0x4ea711a0}},	// [ab0] hë_, _riev, اعر_, _проа,
   {{0x78a90029,0x44fa00dd,0xda7811a1,0x83fd0018}},	//   _siev, kë_, нях_, lnőt,
   {{0xdd9111a2,0x78a90029,0x7aed06ee,0x44fa01e5}},	//   _خود_, _piev, suat, jë_,
   {{0x648500e3,0x7aed11a3,0x44fa0052,0x7d01020a}},	//   hóir, puat, dë_, gârţ,
   {{0x628111a4,0x661a02ef,0xdb070084,0x44fa0185}},	//   yolo, _batk, ämäs, eë_,
   {{0x628111a5,0x99d4012b,0x443d11a6,0xa50900c9}},	//   xolo, _متفا, _sow_, дека_,
   {{0x628111a7,0x648500e3,0x44fa00dd,0x443d11a8}},	//   volo, dóir, gë_, _pow_,
   {{0x628111a9,0x386600d3,0xed640094,0x00000000}},	//   wolo, cior_, loží_, --,
   {{0x644911aa,0x661a023b,0x248603a9,0xf7730037}},	//   rkei, _fatk, _dkom_, _صار_,
   {{0x644911ab,0x69d708a8,0x648500e3,0x7bd60051}},	//   skei, naxe, góir, zayu,
   {{0xa3c300c3,0x7bd601af,0x44fa0052,0x03e30033}},	//   ्रद_, yayu, cë_, ক্ষী_,
   {{0x20040871,0xa3d20be4,0x628111ac,0xd5640528}},	//   ými_, वरण_, solo, _ступ,
   {{0x628111ad,0x249f11ae,0x6e3e007e,0x60c4033b}},	//   polo, mmum_, _popb, _čime,
   {{0x248d11af,0x63bb013d,0xfce611b0,0x9f610103}},	//   llem_, lcun, кого, ását_,
   {{0x7bd611b1,0xfc3f11b2,0x6d4711b3,0x8d6311b4}},	//   tayu, _boí_, gyja, авре,
   {{0xa3c311b5,0x00000000,0x00000000,0x00000000}},	//   ्रि_, --, --, --,
   {{0xdca311b6,0xcb6711b7,0x0b431102,0x7bd611b8}},	// [ac0] рати, вате_, антн, rayu,
   {{0x7bd611b9,0xbea611ba,0x6fa711bb,0x248d11bc}},	//   sayu, _шапк, _गणतं, hlem_,
   {{0x661a0084,0xfe3700a1,0xa3c305cd,0x7bd611bd}},	//   _ratk, _סרטי_, ्रा_, payu,
   {{0x44fa023b,0x076a0dce,0x5ee900c3,0xd5b10023}},	//   vë_, وماً_, _जिम्_, _báo_,
   {{0x248d11be,0x69ca003e,0x386611bf,0xd5b10023}},	//   dlem_, ðfes, rior_, _cáo_,
   {{0x44fa074a,0x629d1030,0x2ca000aa,0x00000000}},	//   të_, ïsol, lmid_, --,
   {{0x81d70081,0x38660212,0x661a00ce,0x00000000}},	//   িলা_, pior_, _vatk, --,
   {{0x44fa074a,0x29181114,0x439411c0,0xe4e30557}},	//   rë_, _isra_, лайс, _गिरि_,
   {{0x44fa074a,0x661a02e7,0x6d4700a5,0x648500e3}},	//   së_, _tatk, zyja, tóir,
   {{0x91fc0029,0x44fa023b,0x60c411c1,0xd05d0092}},	//   ciāl, pë_, _čimb, əyəc,
   {{0x672211c2,0x248d11c3,0x648500e3,0xb6a300ae}},	//   lvoj, blem_, róir, _тифл,
   {{0xdb0411c4,0x64850037,0x60da11c5,0x6d4708ac}},	//   nció, sóir, rstm, vyja,
   {{0x73360391,0xf09f0428,0xdb040328,0x657a009c}},	//   _جرائ, rmà_, ició, _hxth,
   {{0x52d700a1,0x201b005c,0x2ca000aa,0xc694006e}},	//   _יודע_, _waqi_, emid_, טאָ_,
   {{0x4fc70752,0x201b0161,0xdb040018,0x7e67029a}},	//   _испа, _taqi_, kció, rijp,
   {{0x57cc11c6,0x09cb11c7,0x5c740e3a,0x3f8500a7}},	//   ारोह, िर्य, алст, ğlub_,
   {{0x3a7500ae,0x6e450076,0x00000000,0x00000000}},	// [ad0] глар, _منظم, --, --,
   {{0x672202e6,0x68e30fb6,0x99d50dce,0x2ca011c8}},	//   dvoj, ándo, اقات, amid_,
   {{0xa3d2007d,0x248d055c,0x69d711c9,0x8af000a7}},	//   वरा_, ylem_, raxe, lzəl,
   {{0x69d711ca,0x69ca0088,0xa01b00a2,0x00000000}},	//   saxe, ðfer, mlös, --,
   {{0x7c2f11cb,0x64aa030b,0xd6db11cc,0xa01b11cd}},	//   _incr, _přin, фте_, llös,
   {{0xe29a00ef,0xdb0411ce,0xf3f900ae,0x45190927}},	//   _như_, ació, miţi_, еция_,
   {{0x91fc0029,0x58d411cf,0xa01b11d0,0xf3f9020a}},	//   riāl, _вост, nlös, liţi_,
   {{0xdb0411d1,0x69d511d2,0x332611d3,0xafdb00f2}},	//   cció, _heze, _brox_, ljøf,
   {{0x69d50068,0x248d11d4,0xa3e4030b,0xf3f900ae}},	//   _keze, rlem_, _भएर_, niţi_,
   {{0x69d511d5,0x63bb11d6,0xa3c311d7,0x248d11d8}},	//   _jeze, scun, ्रह_, slem_,
   {{0x10a611d9,0x69d511da,0xa06a11db,0x248d11dc}},	//   лион, _meze, еана_, plem_,
   {{0xcea907a6,0x69d511dd,0xf992040a,0x6d5903e3}},	//   _זי_, _leze, מרי_, _ƙwan,
   {{0x442f07c3,0xe28e11de,0x643a00ca,0xdb1d0143}},	//   _ing_, _га_, _רעננ, _mesó,
   {{0x69d511df,0xa01b01bf,0x7c2f11e0,0x764102ac}},	//   _neze, flös, _ancr, _joly,
   {{0x2d8c01c5,0xed5a0b99,0x442f1193,0x1d0702d8}},	//   æde_, хов_, _kng_, лери_,
   {{0x442f11e1,0xfe7f0428,0x09cd0033,0x61f1020a}},	//   _jng_, duïu_, _লাগা, şelă,
   {{0x69d511e2,0x2ca000aa,0x442f11e3,0x705301c3}},	// [ae0] _beze, rmid_, _mng_, _دنيا,
   {{0x442f0bb6,0x2ca011e4,0x00000000,0x00000000}},	//   _lng_, smid_, --, --,
   {{0x442f11e5,0x69d511e6,0x9d4611e7,0x499611e8}},	//   _ong_, _deze, _сенд, ушат,
   {{0x442f010a,0xf3f9020a,0xd7f7007e,0x00000000}},	//   _nng_, biţi_, гуш_, --,
   {{0xdb0409e9,0x69d511e9,0xdb1d037a,0x764111ea}},	//   rció, _feze, _desó, _boly,
   {{0x442f11eb,0x69d511ec,0x20d1031a,0x672211ed}},	//   _ang_, _geze, kši_, rvoj,
   {{0xdb0411ce,0x442f0933,0x20d10b27,0x672211ee}},	//   pció, _bng_, jši_, svoj,
   {{0x332611ef,0x44de003d,0x69d511f0,0x26c611f1}},	//   _prox_, rċ_, _zeze, ppoo_,
   {{0x76410068,0x442f11f2,0x3254002d,0x78a20036}},	//   _foly, _dng_, ивир, mmov,
   {{0x764102ad,0x78a211f3,0xdb040042,0xda14007f}},	//   _goly, lmov, nciñ, ड़ित_,
   {{0xd48f11f4,0x2d8c00a5,0x741300cd,0x6244009c}},	//   _гр_, żdej_, _گونا, _bòor,
   {{0xd0e5000c,0x78a20328,0x442f00f9,0x4254001c}},	//   _किरण_, nmov, _gng_, انگر,
   {{0xe29a0028,0xdd2500d9,0x78a2016d,0x9f59037a}},	//   _thư_, dīša, imov, vesó_,
   {{0x98bc030b,0x64421183,0x20d1033b,0xdddc020a}},	//   ávě_, _hooi, bši_, vorţ,
   {{0x442f02e0,0x78a202dd,0xfe7f05fe,0x6442029a}},	//   _yng_, kmov, duït_, _kooi,
   {{0x78a200cb,0xf3f900ae,0x69d511f5,0xda02009f}},	//   jmov, tiţi_, _seze, र्सत_,
   {{0x64420272,0x90980a09,0xa01b0f3a,0x69d501e9}},	// [af0] _mooi, _حضور_, slös, _peze,
   {{0xf3f900d3,0xdb1d015e,0xa01b0212,0x9f400364}},	//   riţi_, _besò, plös, _heiß_,
   {{0x69d511f6,0x391511f7,0x985100a5,0x57b511f8}},	//   _veze, рмер, nąć_, абет,
   {{0x64420db8,0x69d511f9,0x6f0d0294,0xdddc00ae}},	//   _nooi, _weze, _kpac, porţ,
   {{0x7bda03c2,0xfe7f0428,0x2d9c0031,0xf6e70aec}},	//   _בקרו, buït_, _úver_, уцен,
   {{0x7aed11fa,0xf62511fb,0x7bcd11fc,0xc8d700b9}},	//   mrat, рдко, lbau, _مزرع,
   {{0xe3b1054f,0x7a4100b6,0x764111fd,0x98510034}},	//   يرة_, _vítě, _voly, jąć_,
   {{0x20d100e9,0x130902ec,0x7bcd11fe,0x7aed11ff}},	//   vši_, вний_, nbau, orat,
   {{0x64421200,0x442f1201,0x7aed1202,0x2bb81203}},	//   _dooi, _vng_, nrat, _अलसा,
   {{0x248000e9,0x7aed1204,0x6aae01fa,0x212709a4}},	//   čima_, irat, _xibf, _prnh_,
   {{0x27e0003e,0x29011205,0xdddc0542,0x7aed1206}},	//   ðing_, ntha_, jorš, hrat,
   {{0x442f1207,0x20d11208,0x67291209,0x644201c0}},	//   _ung_, rši_, _krej, _gooi,
   {{0x7aed00e7,0x99980117,0xe3ae120a,0x00000000}},	//   jrat, _morš_, _фб_, --,
   {{0x8cb10034,0x78a20094,0x6729120b,0x644201cb}},	//   _आंखो, zmov, _mrej, _zooi,
   {{0xada6120c,0xdb120682,0x6da610ab,0xdd2500d9}},	//   равл, _ágús, рива, tīša,
   {{0x3b000078,0x6729120d,0x7bcd120e,0xdb1d022b}},	//   ttiq_, _orej, gbau, _resò,
   {{0xfe7f05fe,0x7aed120f,0xdd2500d9,0x2d851210}},	// [b00] tuït_, grat, rīša, üler_,
   {{0x2bb8007d,0x09e61211,0xdd2501d3,0x99580206}},	//   _अलवा, рожн, sīša, ráža_,
   {{0x290100e3,0x7aed1212,0xaa7b00b6,0x78a21213}},	//   gtha_, arat, _svýc, tmov,
   {{0x67291214,0x64aa02c6,0xafdb0537,0x00000000}},	//   _brej, _přim, lkør, --,
   {{0x2bd3110f,0x78a2025b,0x29010091,0x64421215}},	//   तररा, rmov, atha_, _rooi,
   {{0x6729074a,0x29011216,0x64421217,0x2458014b}},	//   _drej, btha_, _sooi, _méme_,
   {{0x25080177,0xafdb038c,0x29010037,0xa3c300ec}},	//   ارتی_, ljøe, ctha_, ्रं_,
   {{0x67291135,0x249d030a,0x916800fe,0x68e3044c}},	//   _frej, _chwm_, _lực_, ânde,
   {{0x67291218,0xa2b300c2,0xd1ca1219,0x00000000}},	//   _grej, обыч, кунд_, --,
   {{0x1663121a,0x32540a3a,0x6f0d01b9,0x26c0044c}},	//   _двум, свор, _rpac, ţios_,
   {{0x6f0d121b,0x67290220,0x91a900de,0x7bcd0138}},	//   _spac, _zrej, _đã_, ybau,
   {{0xa3c30be5,0x7aed0077,0x5067121c,0x00000000}},	//   ्रः_, yrat, ртоа, --,
   {{0xfe7f015e,0x00000000,0x00000000,0x00000000}},	//   duïr_, --, --, --,
   {{0x7aed02c8,0x9f4002e2,0x2d8401e8,0x69d80088}},	//   vrat, _weiß_, ğmen_, ðvel,
   {{0x25fb121d,0x7aed00bd,0xa3bd06ec,0x7bcd042c}},	//   ल्टी_, wrat, _आलम_, tbau,
   {{0x7aed121e,0x20090063,0x228b0120,0x00000000}},	//   trat, _ubai_, søkt_, --,
   {{0x7bcd121f,0x6f0d1084,0x64aa030b,0x451c0081}},	// [b10] rbau, _upac, _přij, থমিক_,
   {{0x62880150,0xe9ab0688,0x29010063,0xab841220}},	//   nodo, ندان_, ttha_, цуск,
   {{0x6729007e,0x3947020a,0x00000000,0x00000000}},	//   _srej, âns_, --, --,
   {{0x67291221,0x62881222,0x7aed1223,0x29011224}},	//   _prej, hodo, prat, rtha_,
   {{0x29011225,0xdc360266,0x32051226,0xdd2800e8}},	//   stha_, _הארט_, yfly_, mēša,
   {{0xb6071227,0xdd2800d9,0x62880167,0x29010037}},	//   рядк, lēša, jodo, ptha_,
   {{0x62881228,0xd4691229,0x48ab01b6,0x67290090}},	//   dodo, лике_, _атам_, _wrej,
   {{0x6729122a,0xfd550134,0xdd2801d3,0x00000000}},	//   _trej, _slaị, nēša, --,
   {{0x672902dd,0x9f4407aa,0x62880150,0x3205122b}},	//   _urej, ümü_, fodo, tfly_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf5950080,0x00000000,0x00000000,0x00000000}},	//   _الاج, --, --, --,
   {{0x20560109,0x237d022e,0xb7bd078e,0x00000000}},	//   стор, _txwj_, _faţe, --,
   {{0x6288122c,0x443f122d,0x645b0527,0xdd2801d3}},	//   bodo, mju_, mhui, dēša,
   {{0xb6cc03e0,0x645b122e,0x00000000,0x00000000}},	//   _şükü, lhui, --, --,
   {{0xc6920341,0x443f0138,0xdd920602,0xafdb00f2}},	//   פאל_, oju_, سور_, rkør,
   {{0x645b122f,0x78a30a9f,0xd5b10023,0x24580031}},	//   nhui, ïnvl, _cái_, _téme_,
   {{0xbbb8009d,0x8c431230,0x09e600d3,0x645b084e}},	// [b20] _अलीक, чете, йоан, ihui,
   {{0x443f007a,0x3f920d2a,0x64aa00b6,0xe9d71231}},	//   hju_, _iyyu_, _přik, йку_,
   {{0x645b0371,0x09060d86,0x395f01c2,0x499a0109}},	//   khui, спен, _ƙusa_, утая_,
   {{0x443f1232,0xdd2801d3,0xb8eb0018,0xd5b100fe}},	//   jju_, cēša, ابلے_, _gái_,
   {{0x443f1233,0xf3ff0081,0x645b1234,0xb9210294}},	//   dju_, ্যার_, dhui, _kasị_,
   {{0x7c241235,0x443f1236,0x645b1237,0x64aa00d2}},	//   ldir, eju_, ehui, _třik,
   {{0x62880941,0xb9210134,0x69de1238,0x645b1239}},	//   vodo, _masị_, mape, fhui,
   {{0x7c241151,0xa3a900c0,0x628800a5,0x24800128}},	//   ndir, _गृह_, wodo, čimo_,
   {{0x35fa0391,0x98a300ae,0x938a065c,0x55e6123a}},	//   _مراد_, _хите, ыска_, _гозб,
   {{0x443f0af0,0x69de123b,0xdd2801d3,0x05070033}},	//   aju_, nape, zēša, লয়ের_,
   {{0x443f123c,0x7c240345,0x81b00033,0x00000000}},	//   bju_, kdir, টুন_, --,
   {{0x443f0580,0x645b123d,0x69de123e,0x320200b6}},	//   cju_, chui, hape, řky_,
   {{0x6288123f,0x69de1240,0x7c241241,0x09e30081}},	//   podo, kape, ddir, ন্টা,
   {{0x3dd900c7,0xdce50220,0x69de1242,0x5eb80033}},	//   _তাহল, _vzhľ, jape, _অবশে,
   {{0x69de1243,0x64aa000d,0x26001244,0xd12f11cf}},	//   dape, _přih, _रानी_, _эх_,
   {{0x7c241245,0x60c700b6,0x67ef0139,0x00000000}},	//   gdir, íjme, _mòjà, --,
   {{0xdd2800d9,0x7d1e0124,0xeabf00de,0xf3fa0033}},	// [b30] rēša, _esps, _trùm_, _আসার_,
   {{0x443f03e5,0x7b7400e3,0xb92100ac,0x69de1246}},	//   zju_, أطفا, _gasị_, gape,
   {{0x7c241247,0x984b1248,0xdd2800e8,0x6d4e0027}},	//   bdir, ляда_, pēša, cyba,
   {{0x19a81249,0x987c02c6,0x00000000,0x00000000}},	//   ступ_, bíč_, --, --,
   {{0x443f124a,0x69de124b,0xe739124c,0x00000000}},	//   vju_, bape, рел_, --,
   {{0xdb1d070a,0x7bdf124d,0xd629124e,0x1b060033}},	//   _besö, laqu, роке_, রিখে_,
   {{0x443f124f,0xf53200c9,0x845900d3,0x3eb31250}},	//   tju_, дејќ, ирит_, _mixt_,
   {{0x7bdf1251,0x443f0d7c,0x94790284,0x00000000}},	//   naqu, uju_, јску_, --,
   {{0x443f1252,0x645b03ee,0xa5f90291,0x727900ae}},	//   rju_, rhui, _везу_, исос_,
   {{0x443f1253,0x645b1254,0xdd1c0146,0x7c241255}},	//   sju_, shui, váže, zdir,
   {{0x443f1256,0x9327015a,0x614510f5,0x7c240342}},	//   pju_, _گران, цена, ydir,
   {{0x69de1257,0x1faa04e6,0x60cd02ef,0x80b80033}},	//   zape, икни_, _čamd, _আবশ্,
   {{0x7bdf1258,0x93270281,0x645902a1,0x69de024a}},	//   daqu, _دران, _ilwi, yape,
   {{0xda0b0251,0x6d4e1259,0xdd1c1054,0x02a700d3}},	//   स्मत_, tyba, ráže, _урем,
   {{0xa3bd02e8,0x7bdf023b,0x69de125a,0x7c240abd}},	//   _आला_, faqu, vape, tdir,
   {{0x69de125b,0xdb1d016d,0x7c240036,0x6d4e00c6}},	//   wape, _lesõ, udir, ryba,
   {{0xe9da125c,0x7c24125d,0x200501d4,0xf412028c}},	// [b40] ика_, rdir, əli_, ופן_,
   {{0x22470313,0x7c24125e,0x4996125f,0xee0a00ae}},	//   _jonk_, sdir, ошет, _теол_,
   {{0x69de1260,0x6da6123a,0x8c461261,0xdd0f01e8}},	//   rape, _фина, _дене, mışt,
   {{0xdd0f01e8,0x7c2400a7,0x9f4800de,0x7bdf0db4}},	//   lışt, qdir, _điêu_, caqu,
   {{0xcfbc0081,0x64aa02c6,0xfaa61262,0xd5b1020b}},	//   _অজান, _křiv, _мамо, _máu_,
   {{0x7ae40037,0x645902a1,0x2bb80174,0xdd0f0233}},	//   msit, _alwi, _ọch_, nışt,
   {{0xd90d0177,0x7ae400e3,0x81cf0081,0x261b030b}},	//   _میل_, lsit, ষণা_, _यसरी_,
   {{0x7bc41263,0xfd530af0,0x7ae41264,0xdb1d00b7}},	//   nciu, _aifọ, osit, _eesõ,
   {{0x69dc0281,0x7ae41265,0x22471266,0xdd0f0233}},	//   _kere, nsit, _bonk_, kışt,
   {{0x24510037,0x2000009c,0x7ae41267,0x64590178}},	//   _lámh_, _acii_, isit, _elwi,
   {{0x69dc1268,0x22471269,0x7bdf126a,0xd25708a1}},	//   _mere, _donk_, yaqu, іць_,
   {{0x69dc126b,0x7ae4126c,0xe0cf0688,0x6618126d}},	//   _lere, ksit, کزی_, levk,
   {{0x76480167,0xfd530065,0x2005007f,0xf4870a85}},	//   _kody, _fifọ, ęli_, _بالی,
   {{0x24890220,0x7bc6126e,0x76480383,0x00000000}},	//   čame_, _afku, _jody, --,
   {{0x7bdf0257,0x2bc80294,0x7648126f,0x7ae41270}},	//   taqu, _ọjị_, _mody, esit,
   {{0x69dc008f,0x3ced1271,0x67200fa3,0x6ca41272}},	//   _aere, čev_, _osmj, друж,
   {{0x69dc1273,0x20191274,0x7ae407ac,0x7bdf1275}},	// [b50] _bere, mesi_, gsit, raqu,
   {{0x20191276,0x69dc1173,0x66180ebd,0x7bc40451}},	//   lesi_, _cere, jevk, aciu,
   {{0x69dc0170,0x7bdf1277,0x48151278,0x78bc1279}},	//   _dere, paqu, змес, _curv,
   {{0x765a127a,0x2019127b,0x78bc127c,0x7ae4127d}},	//   _alty, nesi_, _durv, bsit,
   {{0x2ca9127e,0x27e00088,0x69dc127f,0x7bdd01ff}},	//   mmad_, ðina_, _fere, _iesu,
   {{0x69dc1280,0x7bdd1281,0x2ca91282,0xc9870408}},	//   _gere, _hesu, lmad_, _дуби,
   {{0x69c51283,0x7bdd06e1,0x6e2502a1,0x20191284}},	//   mche, _kesu, _mahb, kesi_,
   {{0x69c51285,0x7bdd1286,0x7d7c00c1,0x69dc1287}},	//   lche, _jesu, ינוו, _zere,
   {{0x2bdc007d,0x7bdd1288,0x69dc1289,0x76d500e3}},	//   बरता, _mesu, _yere, _رياض,
   {{0x69dc128a,0x69c5128b,0x7bdd128c,0x09af0081}},	//   _xere, nche, _lesu, _চ্যা,
   {{0x69c5128d,0x2019128e,0x224701d0,0x386d0113}},	//   iche, fesi_, _vonk_, _kmer_,
   {{0x2458128f,0x7bdd01b3,0x20191290,0x69c51291}},	//   _téma_, _nesu, gesi_, hche,
   {{0x24511292,0x64aa00b6,0x69c51293,0x271d0154}},	//   _námi_, _přiv, kche, _jňn_,
   {{0x6e251294,0x69c51295,0x248d0629,0x68e70344}},	//   _cahb, jche, loem_, _ovjd,
   {{0x61e102fd,0x20191296,0x7bdd1297,0xdca603fc}},	//   mall, besi_, _besu, зави,
   {{0x7ae41298,0x20191299,0x61e1129a,0x248d0185}},	//   tsit, cesi_, lall, noem_,
   {{0x69dc129b,0x7bdd052f,0x7bc40018,0x2d9e025b}},	// [b60] _pere, _desu, rciu, ťte_,
   {{0x7bc4013d,0xba23129c,0x78bc129d,0xada6129e}},	//   sciu, ндук, _purv, _напл,
   {{0x7ae4129f,0x7648013f,0xda020be4,0x7bc412a0}},	//   ssit, _rody, र्गत_, pciu,
   {{0x69dc12a1,0x61e112a2,0x7bdd12a3,0x7ae412a4}},	//   _were, hall, _gesu, psit,
   {{0x61e10e1d,0x387f0149,0x69c512a5,0x764812a6}},	//   kall, _djur_, bche, _pody,
   {{0x69c5013d,0x78bc0d80,0x61e112a7,0x7bdd07f5}},	//   cche, _turv, jall, _zesu,
   {{0x201912a8,0x20c100ef,0x7bdd12a9,0x7c2612aa}},	//   yesi_, _nói_, _yesu, _kakr,
   {{0xadc30065,0x7bdd0042,0x6d4100c2,0x066601f3}},	//   _diẹd, _xesu, älai, _کارپ,
   {{0x66180038,0x61e112ab,0x201912ac,0x67200ea3}},	//   pevk, fall, vesi_, _usmj,
   {{0x201912ad,0x61e112ae,0x20c10023,0x3f850233}},	//   wesi_, gall, _bói_, şluk_,
   {{0x201912af,0x60cd08a9,0x6e2512b0,0x69c30087}},	//   tesi_, _čamc, _rahb, žneg,
   {{0x7c2612b1,0xe3a70018,0xb6060146,0x20c1016d}},	//   _nakr, _کشمی, _dráž, _dói_,
   {{0x61e112b2,0x201912b3,0xaa7b00b6,0x6d4802c3}},	//   ball, resi_, _svým, ädan,
   {{0x7bdd03b4,0x442612b4,0x61e112b5,0x8ca20034}},	//   _sesu, _hao_, call, _कीबो,
   {{0x442602e6,0x20c10019,0x7bdd0fc4,0x201912b6}},	//   _kao_, _gói_, _pesu, pesi_,
   {{0x7c2612b7,0x6e250063,0x6abd12b8,0x201912b9}},	//   _cakr, _wahb, _pusf, qesi_,
   {{0xd6d70f71,0x442612ba,0x69c512bb,0x2ca912bc}},	// [b70] _সম্প, _mao_, tche, rmad_,
   {{0x442612bd,0x27e00102,0x69c512be,0x386d12bf}},	//   _lao_, ðinn_, uche, _smer_,
   {{0x69c505d7,0x7bdd12c0,0x29190397,0xfaa80037}},	//   rche, _tesu, تقاد_, أهلي_,
   {{0x69c512c1,0x442612c2,0xd75900e3,0x61e112c3}},	//   sche, _nao_, يلات_, zall,
   {{0x69c512c4,0x61e100ad,0x68e50063,0x79950034}},	//   pche, yall, sshd, _wyzw,
   {{0x7c2612c5,0x61e112c6,0xf1ba0023,0x660d015c}},	//   _zakr, xall, _ngơ_, đako,
   {{0x44260028,0x7c3a0076,0x387f12c7,0x00000000}},	//   _bao_, _úcrá, _tjur_, --,
   {{0x442600ef,0x61e112c8,0x2458020d,0x45180120}},	//   _cao_, wall, _démo_, яція_,
   {{0x61e112c9,0x27ed12ca,0x20c10023,0x248d12cb}},	//   tall, _iden_, _sói_, roem_,
   {{0x81bc01d3,0x25a002c6,0x442612cc,0x7ea012cd}},	//   ldēj, řila_, _eao_, köpa,
   {{0x26cd0284,0x61e112ce,0x355506fa,0x64aa00b6}},	//   _hteo_, rall, _تناز, _přit,
   {{0x61e112cf,0xd36e00bf,0x81bc00e8,0x20e70559}},	//   sall, اهی_, ndēj, rđi_,
   {{0x61e112d0,0xe28e12d1,0x7c2612d2,0x00000000}},	//   pall, _аа_, _rakr, --,
   {{0x4426068d,0x6da612d3,0xafdb00f2,0x61e112d4}},	//   _zao_, дига, ljøl, qall,
   {{0x4426068d,0x7c26013f,0x644b0044,0xb6060094}},	//   _yao_, _pakr, _kogi, _uráž,
   {{0x26cd0542,0x442600de,0x8af000a7,0x27ed0233}},	//   _oteo_, _xao_, yyəd, _nden_,
   {{0x1e860508,0x644b12d5,0xeb9712d6,0x7c26004d}},	// [b80] _олим, _mogi, дит_, _vakr,
   {{0x7c260051,0x27ed12d7,0x2480033b,0x6d590022}},	//   _wakr, _aden_, čimi_, _ƙwat,
   {{0x7c2612d8,0xa3bd009d,0xafdb0120,0xf3e80033}},	//   _takr, _आलं_, kjøl, ক্টর_,
   {{0x644b12d9,0xd7ef0037,0xdb0d00d4,0x00000000}},	//   _nogi, لكم_, škán, --,
   {{0x44260028,0xdd8f001c,0xdb1d02b6,0x47360037}},	//   _rao_, _موی_, _afsæ, براز,
   {{0x442612da,0x27ed12db,0xdd1d033d,0x644b009c}},	//   _sao_, _eden_, lášt, _aogi,
   {{0x7af612dc,0x22990113,0x00000000,0x00000000}},	//   lryt, mèkh_, --, --,
   {{0xe9a312dd,0x644b12de,0x7af60034,0xfc3f00fe}},	//   _расп, _cogi, oryt, _khía_,
   {{0x442612df,0x60cd0335,0x84ea0abe,0x644b05bd}},	//   _vao_, _čama, _टिकट_, _dogi,
   {{0x4426068d,0x2489005f,0x64aa030b,0x65790037}},	//   _wao_, čama_, _přis, ábhá,
   {{0x442612e0,0x09f70054,0xd48f0012,0x9f4203a9}},	//   _tao_, ומים_, _ар_, lakè_,
   {{0xdbd603cf,0x644b00eb,0x00000000,0x00000000}},	//   _jääd, _gogi, --, --,
   {{0xfe73012b,0x00000000,0x00000000,0x00000000}},	//   ندس_, --, --, --,
   {{0x63a212e1,0x7af612e2,0x245100d4,0x00000000}},	//   _izon, dryt, _dámu_, --,
   {{0xdd9401b3,0xafdb01df,0xdc14020e,0x00000000}},	//   вары, ljøm, _ağız, --,
   {{0xaa7b025b,0x7af6023b,0x7bd6084e,0x9f4201dc}},	//   _zvýh, fryt, gbyu, kakè_,
   {{0xf09400a1,0x5a35008f,0x78c40129,0xfc3f034f}},	// [b90] _בנק_, ннат, _ịkpọ_, _chía_,
   {{0x3b090090,0x00000000,0x00000000,0x00000000}},	//   rtaq_, --, --, --,
   {{0x80e00081,0xdb0d0143,0x0fe3007f,0x3b0912e3}},	//   পূর্, rcañ, परपढ, staq_,
   {{0x7af612e4,0xc19b00ca,0xdb0d037a,0x00000000}},	//   bryt, חשבי, scañ, --,
   {{0x6d550103,0xa3c212e5,0x81bc00e8,0x63a212e6}},	//   lyza, ंशन_, rdēj, _nzon,
   {{0xe5a512e7,0x00000000,0x00000000,0x00000000}},	//   нили, --, --, --,
   {{0x63a20068,0x629a12e8,0x00000000,0x00000000}},	//   _azon, dlto, --, --,
   {{0x032512e9,0x27ed0021,0x63a20078,0x629a12ea}},	//   един, _uden_, _bzon, elto,
   {{0xe61012eb,0x64aa00b6,0x59b90034,0x200c0103}},	//   _چشم_, _přir, ेडकर, ődik_,
   {{0x63a212ec,0x60c70220,0x64b101d3,0x24510094}},	//   _dzon, íjmo, _jāiz, _rámu_,
   {{0x9f42001c,0x644b0172,0x63a212ed,0x00000000}},	//   maké_, _togi, _ezon, --,
   {{0xe7300068,0x644b00c6,0x2cb901b9,0x200412ee}},	//   _حصہ_, _uogi, _nisd_, ümi_,
   {{0x63880052,0x00000000,0x00000000,0x00000000}},	//   rënë, --, --, --,
   {{0x2cb901b9,0x60c40117,0x22990113,0x00000000}},	//   _aisd_, _čimv, kèki_, --,
   {{0x40960562,0xdd92046b,0x9f4203a9,0x00000000}},	//   _прит, اوز_, iaké_, --,
   {{0xfc3f0019,0x9f4200bf,0x6d590044,0x7af612ef}},	//   _phía_, haké_, _ƙwar, tryt,
   {{0x9f420979,0x7bd600f9,0x63a212f0,0x00000000}},	// [ba0] kaké_, rbyu, _xzon, --,
   {{0x9f42025b,0xdbd600c2,0xcfb700ca,0x2cb901ec}},	//   jaké_, _sääd, _אלפי_, _eisd_,
   {{0xdbd612f1,0x9f4200d1,0x69a512f2,0x00000000}},	//   _pääd, daké_, _करणी, --,
   {{0x27e012f3,0x20020991,0xe3a70391,0xfc3f00fe}},	//   úin_, ngki_, _مر_, _thía_,
   {{0x81d60033,0xb9070285,0x9f4200d1,0x00000000}},	//   িণত_, _मौ_, faké_, --,
   {{0xae040096,0x9f42001c,0x00000000,0x00000000}},	//   श्चन_, gaké_, --, --,
   {{0xa9a3007e,0x245101cd,0x22990113,0xfc3f00da}},	//   _бирд, _náms_, cèki_, _mhín_,
   {{0x25a000b6,0x2bd3030b,0x69a512f4,0x2ba709a1}},	//   řilo_, धुपा, _करती, _खरमा,
   {{0x087700c1,0xb5fc009e,0x27e612f5,0x68fe01b6}},	//   _נעמט_, _alġe, maon_, lupd,
   {{0x27e612f6,0x3eba12f7,0x9f4203a9,0x00000000}},	//   laon_, _nipt_, caké_, --,
   {{0xd5a40b94,0x64a612f8,0x00000000,0x00000000}},	//   _ओरिज, _зажа, --, --,
   {{0x27e612f9,0x25a1042c,0x63a20350,0x8386007b}},	//   naon_, ühle_, _tzon, _пыле,
   {{0x3ce30096,0xf1d100b6,0x2cb90027,0xafdb00f2}},	//   टीने_, _द्वन, _risd_, ljøk,
   {{0xfc3f00de,0x6d550034,0x27e6019c,0x291800bd}},	//   _chín_, tyza, haon_, _opra_,
   {{0x321e109b,0x27e6019c,0x7e7512fa,0x00000000}},	//   mety_, kaon_, rizp, --,
   {{0x6d5500a5,0x321e12fb,0xfc3f0032,0x2d9a00f3}},	//   ryza, lety_, _ehín_, _dype_,
   {{0x200c01d4,0x29180036,0x00000000,0x00000000}},	// [bb0] ədi_, _apra_, --, --,
   {{0x9e670037,0x321e12fc,0xafdb00f3,0x6d4100ce}},	//   _ساخن, nety_, kjøk, älas,
   {{0xa3e00ccb,0xa3c2046e,0x23c70065,0xfe7f00b3}},	//   थरा_, ्डा_, _jíjó_, duïx_,
   {{0x29180167,0xab5b0956,0x69d801cd,0x00000000}},	//   _dpra_, _agüe, ðver, --,
   {{0x321e025b,0x7c2d12fd,0x58b80037,0xe758004d}},	//   kety_, mdar, رامج_, ниці_,
   {{0x7c2d12fe,0xf6d400d1,0x00000000,0x00000000}},	//   ldar, ازند, --, --,
   {{0x64aa000d,0xc9840752,0x27e612ff,0x9f4200cd}},	//   _přip, _бути, baon_, raké_,
   {{0x248906b8,0x3d19007f,0x00000000,0x00000000}},	//   čamo_, _पहने_, --, --,
   {{0x9f4200cd,0x130600c2,0xfd620139,0x321e00a1}},	//   paké_, вный_, _buwọ, fety_,
   {{0xa7741300,0x7c2d1301,0x64aa0022,0x68e102b6}},	//   _случ, hdar, _aƙid, _ælds,
   {{0x320b00a5,0x7c2d1302,0x00000000,0x00000000}},	//   ęcy_, kdar, --, --,
   {{0x7c2d1303,0x26df0129,0x00000000,0x00000000}},	//   jdar, _kwuo_, --, --,
   {{0x7c2d1304,0x442d0902,0xf8b20130,0xe813009d}},	//   ddar, mde_, ישט_, ण्या_,
   {{0x64491305,0x2d9a0f5a,0x443d0381,0x00000000}},	//   ljei, _pype_, _hnw_, --,
   {{0x1d070b1e,0xfc3f0072,0x2d9a1306,0x67220034}},	//   кери_, _chío_, _qype_, zwoj,
   {{0x7c2d0bb6,0x61e31307,0x645b00c2,0x644911e9}},	//   gdar, _henl, nkui, njei,
   {{0xc05300a1,0x62810449,0x3eba01cb,0x61e30227}},	// [bc0] _כזה_, onlo, _tipt_, _kenl,
   {{0x442d02fd,0x60c31308,0x7c2d1309,0x6281130a}},	//   hde_, _kunm, adar, nnlo,
   {{0x27e60d3d,0x442d130b,0x7c2d130c,0xbf9b016d}},	//   taon_, kde_, bdar, ngên,
   {{0x442d130d,0x38600080,0x68fe0085,0x61e3130e}},	//   jde_, óir_, rupd, _lenl,
   {{0x442d130f,0xe1e703ed,0x27e61310,0xf11e00c0}},	//   dde_, _پس_, raon_, _बन्द_,
   {{0x442d1311,0x27e6019c,0x443d0381,0x645b084e}},	//   ede_, saon_, _anw_, ekui,
   {{0x442d0db8,0xa8061312,0x60c30364,0x321e00d4}},	//   fde_, _извл, _nunm, vety_,
   {{0x78bb078e,0x6abb0072,0x24580139,0x443d00fc}},	//   _giuv, _éufr, _kémi_, _cnw_,
   {{0x68e101c5,0x26df0174,0xd70700d3,0x799c0150}},	//   _ældr, _gwuo_, _инте_, _hyrw,
   {{0x386600c9,0x7c2d1313,0x443d02ad,0x61e31314}},	//   lhor_, zdar, _enw_, _cenl,
   {{0x26c41315,0x442d01df,0x7c2d1316,0xa5d81317}},	//   _humo_, bde_, ydar, _न्यौ,
   {{0xf9930054,0x3866001f,0x68e312c0,0x78a90052}},	//   ירת_, nhor_, ândi, _xhev,
   {{0x26090789,0x321e12fb,0x61e31318,0x69ce003e}},	//   _सामी_, pety_, _fenl, _ofbe,
   {{0xdce50038,0x27e4002d,0x61e31319,0x60c30139}},	//   _vyhľ, _lemn_, _genl, _funm,
   {{0x61e8131a,0xac19131b,0xa3e6009f,0x40350f80}},	//   madl, нову_, _बजा_, _бейс,
   {{0xfbd303ed,0x69ce0ab2,0x7c2d10d3,0x24580139}},	//   شتر_, _afbe, udar, _bémi_,
   {{0x3866131c,0x6d4a01b9,0x00000000,0x00000000}},	// [bd0] dhor_, _àfan, --, --,
   {{0x442d131d,0xf09f0472,0xa2c30179,0x78bb0138}},	//   zde_, llà_, रदत्, _siuv,
   {{0x442d131e,0x9f4e0018,0x6abc131f,0x7c2d0325}},	//   yde_, önöm_, _dirf, pdar,
   {{0x61e81320,0x2486084f,0x7c2d1321,0x26c40344}},	//   hadl, _njom_, qdar, _bumo_,
   {{0x442d1322,0x61e81323,0xdbd100aa,0x3707004c}},	//   vde_, kadl, _müüd, тчев,
   {{0x442d1324,0x6abc0090,0x26c401ee,0x6a6001cd}},	//   wde_, _girf, _dumo_, _höfn,
   {{0x2609009d,0x61e81325,0x442d1326,0x26c400b3}},	//   _साठी_, dadl, tde_, _eumo_,
   {{0x6281051f,0x61e31327,0x29011328,0x26c41329}},	//   wnlo, _senl, muha_, _fumo_,
   {{0x442d132a,0x60c3132b,0x7aed0e78,0x645b132c}},	//   rde_, _sunm, nsat, rkui,
   {{0x442d132d,0xb7bd002d,0x6729132e,0x645b132f}},	//   sde_, _naţi, _isej, skui,
   {{0x61e31330,0x29011331,0x442d1332,0x26c41333}},	//   _venl, nuha_, pde_, _zumo_,
   {{0x44e101b3,0xbf9b0396,0x83350fba,0x26c40a4b}},	//   mų_, rgên, _مرتض, _yumo_,
   {{0x44e1013f,0x27e001ab,0x61e81334,0x6b9d01df}},	//   lų_, ðini_, badl, _nysg,
   {{0x249f1335,0x29011336,0x7aed1337,0x3f9e00d9}},	//   llum_, kuha_, dsat, ātu_,
   {{0x44e101b3,0x7aed01ee,0x00000000,0x00000000}},	//   nų_, esat, --, --,
   {{0xa3e60251,0x29011338,0xc0061339,0xf09f00b3}},	//   _बड़ा_, duha_, _спик, clà_,
   {{0xfc3f0074,0x7aed133a,0xcb67133b,0x06d80033}},	// [be0] _dní_, gsat, гате_, _সিভি,
   {{0x44e101b3,0xfeba0241,0x6b9d02ad,0x27e400ae}},	//   kų_, _ثابت_, _dysg, _semn_,
   {{0x44e101b3,0x249f133c,0x3e660257,0x386600a1}},	//   jų_, klum_, _côte_, thor_,
   {{0x8c46133d,0x44e1013f,0x6abc133e,0x7aed0188}},	//   _семе, dų_, _wirf, bsat,
   {{0x09e80081,0x7aed0fcc,0x6b9d0178,0x81bc01d3}},	//   _পাঠা, csat, _gysg, ldēt,
   {{0x2ca0133f,0x29011340,0xfc3f02c6,0x38661341}},	//   llid_, buha_, _zní_, shor_,
   {{0x38661342,0x61e81343,0x44e1013f,0x2ca000bc}},	//   phor_, vadl, gų_, olid_,
   {{0x26091344,0x26c41345,0x54541346,0x955300e3}},	//   _साथी_, _tumo_, рвит, إخوا,
   {{0x61e81347,0x41e60426,0x18670284,0x2ca009a1}},	//   tadl, ліна, _сати_, ilid_,
   {{0x471b00c1,0xdbd1007a,0x44e10138,0x171b006e}},	//   _אומג, _süüd, bų_, _אומע,
   {{0x3de21348,0x26091349,0x2ca0007a,0x249f134a}},	//   _বাংল, _साती_, klid_, blum_,
   {{0x7aed0694,0xfc3f0019,0x61e8134b,0xc0ab0452}},	//   ysat, _phím_, sadl, عادل_,
   {{0x543b0130,0x61e8134c,0xd9e40789,0x087700c1}},	//   _רעדא, padl, गरात_, רעכט_,
   {{0x6a60003e,0x29010169,0x00000000,0x00000000}},	//   _söfn, yuha_, --, --,
   {{0x6d4a0231,0xf09f015e,0x00000000,0x00000000}},	//   _àfal, plà_, --, --,
   {{0x7aed134d,0x2ca000aa,0xfc3f0023,0x6b9d00f0}},	//   tsat, glid_, _thím_, _pysg,
   {{0x3a750cc0,0x0ca800c2,0x998c0a39,0x7aed00b7}},	// [bf0] алар, утри_, _ćoše_, usat,
   {{0x7ed40080,0x7bcd134e,0x2901134f,0x2ca01350}},	//   _ازيا, scau, tuha_, alid_,
   {{0x7aed1351,0x667500bf,0xc9841352,0x2ca01353}},	//   ssat, یدتر, буци, blid_,
   {{0x29011354,0x2c2702ec,0x2ca01355,0x7aed1356}},	//   ruha_, _сьог, clid_, psat,
   {{0xf7451357,0x26001358,0x29011359,0xd6db008f}},	//   рело, _राखी_, suha_, хте_,
   {{0x44e101b3,0x09df0081,0xa2c303a2,0x29010169}},	//   tų_, _ঢাকা, रदस्, puha_,
   {{0x58d41167,0x249f135a,0x7c2f0483,0xafdb09af}},	//   _гост, tlum_, _kacr, ljøu,
   {{0x99840080,0x44e1013f,0x60c4135b,0x68e3135c}},	//   _الفو, rų_, _čimp, ându,
   {{0x09e80081,0xc864135d,0x6729135e,0x44e10138}},	//   _পাতা, _утри, _usej, sų_,
   {{0x7c2f0f99,0xaa7b135f,0x81ae0081,0x42551360}},	//   _lacr, _zvýr, কশন_, ртит,
   {{0xa06a1361,0xc4f800ab,0x249f0b12,0xe046008d}},	//   вана_, _معنا_, plum_, анни,
   {{0xb4c11362,0x54a71363,0x7c2f005f,0xcea9040a}},	//   ंदी_, _صحاف, _nacr, _חי_,
   {{0x2ca01364,0x00000000,0x00000000,0x00000000}},	//   vlid_, --, --, --,
   {{0x442f1365,0x3ebe081f,0x2ca01366,0x00000000}},	//   _hag_, ött_, wlid_, --,
   {{0x442f1367,0xfce600ba,0x7c2f041c,0x00000000}},	//   _kag_, робо, _bacr, --,
   {{0x442f1368,0xbc631369,0xa3ac03a2,0x2fdf01cd}},	//   _jag_, овск, _गरम_, ðugt_,

   {{0x91fc00d9,0x6b850037,0x2ca0136a,0xb4c1136b}},	// [c00] bkād, مشكل, rlid_, ंदु_,
   {{0xe9d7136c,0x442f136d,0x7ea00149,0xd0e60470}},	//   ику_, _lag_, köpi, _حکیم_,
   {{0xa926136e,0x7e7c02ef,0x7c2f009c,0x442f0027}},	//   рдел, mirp, _facr, _oag_,
   {{0x442f136f,0x7e7c0063,0x4907007a,0x6d5c1370}},	//   _nag_, lirp, _हमरो_, myra,
   {{0x7c241371,0xd7071372,0x6d5c1373,0x28131374}},	//   meir, инце_, lyra, تونس,
   {{0x7c241375,0xb4c11376,0x7c2f0106,0x80db0033}},	//   leir, ंदू_, _zacr, _ভিন্,
   {{0x39470222,0x6d5c1377,0x442f1378,0x2bd30336}},	//   änst_, nyra, _bag_, धुवा,
   {{0x7c241379,0x442f137a,0x8af00092,0x7791001c}},	//   neir, _cag_, yyəl, _کیها,
   {{0x27e00088,0xd5b100de,0x6d5c00f0,0x7e7c0109}},	//   ðinu_, _máy_, hyra, kirp,
   {{0x80ca03a2,0x7d1e02ec,0x7c24137b,0x442f036b}},	//   _संदे, _opps, heir, _eag_,
   {{0x3a370054,0x442f137c,0xd57500d6,0x5186137d}},	//   ברים_, _fag_, _луць, рупа,
   {{0x442f137e,0x7c24137f,0x1b1d0033,0x78a21380}},	//   _gag_, jeir, নিতে_, nlov,
   {{0x7c241381,0x44241382,0x236d00a5,0x78a2025b}},	//   deir, mem_, czej_, ilov,
   {{0xa2c3009f,0x442f1383,0x78a20146,0xbe88007b}},	//   रदर्, _zag_, hlov, ассе_,
   {{0x7c2402ad,0x78a20146,0x6d5c1384,0xd08700c2}},	//   feir, klov, gyra, _выпи,
   {{0x44241385,0x78a21386,0x7c241387,0x26161388}},	//   nem_, jlov, geir, प्ती_,
   {{0x78a21389,0x4424138a,0xf9c7117a,0x80ca00b7}},	// [c10] dlov, iem_, ащен, _सूते,
   {{0x4424138b,0x2489138c,0x753a0634,0xae1600aa}},	//   hem_, čami_, _ortz, द्दन_,
   {{0x4424138d,0x7c24138e,0x78a200d4,0x7c2f138f}},	//   kem_, beir, flov, _tacr,
   {{0x7c241390,0x00000000,0x00000000,0x00000000}},	//   ceir, --, --, --,
   {{0x44241391,0x442f1392,0x2b470077,0x753a01e9}},	//   dem_, _rag_, _тэнг, _artz,
   {{0x6442054f,0x442f1393,0x78a21394,0x00000000}},	//   _anoi, _sag_, alov, --,
   {{0x442f1395,0x78a20e94,0xb4c10980,0x5bb702d5}},	//   _pag_, blov, ंदे_, _अणुव,
   {{0x44241396,0x442f01fa,0x628a0e94,0x644200da}},	//   gem_, _qag_, _ajfo, _cnoi,
   {{0x442f1397,0x753a0a00,0xe2990231,0xd8b60018}},	//   _vag_, _ertz, лаи_, _اگلا_,
   {{0x442f1398,0x7c24001f,0x9f421054,0x236d007f}},	//   _wag_, zeir, jaká_, rzej_,
   {{0x236d0067,0x442f1399,0x4424139a,0x291301e9}},	//   szej_, _tag_, bem_, ntxa_,
   {{0x4424139b,0x7c241390,0x442f023e,0x673b0052}},	//   cem_, xeir, _uag_, _kruj,
   {{0x7c240bfe,0x4374139c,0x6d41057e,0x6d5c00f0}},	//   veir, _мушт, ålan, wyra,
   {{0xda0304a9,0x6d5c139d,0x1d0a139e,0x539a00ca}},	//   _लागत_, tyra, леги_, _גינו,
   {{0x7c24139f,0x78a213a0,0x98a702c6,0x3ce300b6}},	//   teir, ylov, íně_, टीले_,
   {{0x3fe607ed,0x673b13a1,0xeb9a007b,0xab2a13a2}},	//   _ужив, _oruj, гиб_, лоба_,
   {{0x7c2413a3,0x387d0150,0x64aa00b6,0x5baa13a4}},	// [c20] reir, diwr_, _přiz, укам_,
   {{0x7c2413a5,0x09e80081,0x0f3700ca,0x00000000}},	//   seir, _পাহা, _פריט_, --,
   {{0x7d1e13a6,0xed5a13a7,0xe8fa13a8,0x7c2413a9}},	//   _upps, _сон_, уле_, peir,
   {{0x442413aa,0x673b0a59,0x16050006,0xafdb00f2}},	//   xem_, _bruj, _राउर_, ljør,
   {{0x442413ab,0x78a213ac,0x7bc60124,0x673b034f}},	//   vem_, rlov, _igku, _cruj,
   {{0x78a213ad,0x442400a5,0x13e002d5,0xd9460d86}},	//   slov, wem_, नर्भ, _леги,
   {{0x260913ae,0x7bc60124,0x9ac3003d,0xe3e800d1}},	//   _सारी_, _kgku, ċċes, لکشن_,
   {{0x6d5903e3,0xafdb00f2,0x442413af,0x00000000}},	//   _ƙwaz, hjør, uem_, --,
   {{0xe73702fd,0x533413b0,0x673b13b1,0x66e313b2}},	//   _лет_, цепт, _gruj, _нота,
   {{0x442413b3,0x3d190d1b,0x6f0604f8,0x00000000}},	//   sem_, _पहले_, dukc, --,
   {{0x442406f7,0x3a3700a1,0x1a9b00c1,0xe6930781}},	//   pem_, זרים_, רייע, _علمد,
   {{0x5edd0033,0xc95300ca,0x9f4b020d,0x20050138}},	//   _বিবে, למת_, lacé_, ėlio_,
   {{0xa3bc13b4,0xa3ac00b6,0xafdb00f3,0xa01b01f9}},	//   _आणि_, _गरि_, fjør, lnök,
   {{0x63a213b5,0xafdb00d6,0x9f4000ee,0x161b0ff9}},	//   _iyon, gjør, _deià_, प्पर_,
   {{0x865b13b6,0x63a20167,0xdd3a00ae,0x00000000}},	//   נדלי, _hyon, văţa, --,
   {{0x63a20283,0x4fc700d3,0x00000000,0x00000000}},	//   _kyon, _уска, --, --,
   {{0x628813b7,0x260913b8,0x61ea003e,0xafdb13b9}},	// [c30] ondo, _साली_, _kefl, bjør,
   {{0x628813ba,0x80db0081,0xe9ab00d1,0x00000000}},	//   nndo, _ভিত্, هدان_, --,
   {{0x63a213bb,0x628805c2,0x09e80033,0xc98400d3}},	//   _lyon, indo, _পাশা, пуци,
   {{0x629a13bc,0xf77000d0,0x6e2713bd,0x27e906cb}},	//   hoto, کام_, lejb, úan_,
   {{0x61f813be,0x65c511a0,0x387d00f0,0x9f4b014b}},	//   _odvl, обла, riwr_, facé_,
   {{0xe6180565,0x34b30f35,0x673b007e,0xddc502c6}},	//   йді_, ुद्द, _vruj, _pohř,
   {{0x69c702ec,0x63a213bf,0x6d590d2a,0xa01b02c3}},	//   _igje, _ayon, _ƙway, rnöj,
   {{0x06d80081,0x63a20a15,0xe45913c0,0x6e2700d8}},	//   _সিরি, _byon, ржи_, hejb,
   {{0x60ca01bf,0x63a202a4,0x27ef01cd,0x6e2700d4}},	//   _aufm, _cyon, magn_, kejb,
   {{0x629a13c1,0x63a205aa,0x60d800b3,0xbbc60285}},	//   goto, _dyon, _btvm, _वल्क,
   {{0x602604d9,0x63a213c2,0xdddc0138,0x63f913c3}},	//   одна, _eyon, sirū, _نفاس_,
   {{0x27ef005c,0x628813c4,0x99580220,0xe45f00aa}},	//   nagn_, ando, náša_, ööd_,
   {{0x63a20517,0x62351146,0xe1ee0221,0x69c30206}},	//   _gyon, _меду, _ог_, žneh,
   {{0x61ea13c5,0x629a13c6,0x68f50094,0x69c70052}},	//   _gefl, coto, _ovzd, _ngje,
   {{0xdd920867,0x8c7a008f,0x2c6700bc,0xbea30d85}},	//   ذور_, ащат_, _sõda_, фарк,
   {{0x69c700dd,0x69d501c0,0x9f4000ee,0x8c4313c7}},	//   _agje, _afze, _teià_, месе,
   {{0x20e70103,0xfc3f00fe,0x2ea70103,0x00000000}},	// [c40] lői_, _nhíu_, _ڈپٹی_, --,
   {{0xafdb13c8,0xa01b01f9,0x00000000,0x00000000}},	//   ljøp, ynök, --, --,
   {{0x38cb00d0,0xc7c613c9,0x60c413ca,0xc92a00e5}},	//   لانی_, осли, _kiim, роеж_,
   {{0xdca613cb,0x69da13cc,0x629a0051,0x09aa0096}},	//   _фами, _प्री, zoto, _करीय,
   {{0x41c9000c,0x629a0010,0x3ced0039,0xc5f30081}},	//   रशास, yoto, ćeve_, চ্ছা_,
   {{0x473302ec,0xa3dc0096,0x7c3613cd,0x60c413ce}},	//   ьніс, तुन_, ldyr, _liim,
   {{0x629a13cf,0x63a213d0,0xafdb0120,0x00000000}},	//   voto, _syon, kjøp, --,
   {{0x69c701e5,0x7c3613d1,0x629a13d2,0x60c413d3}},	//   _zgje, ndyr, woto, _niim,
   {{0x629a0256,0x00000000,0x00000000,0x00000000}},	//   toto, --, --, --,
   {{0xd25a11d9,0x62880131,0x63a20169,0x7ae9047e}},	//   рци_, undo, _vyon, _çete,
   {{0xaca40134,0x62880429,0x403513d4,0xfc3f00fe}},	//   _alọt, rndo, пенс, _khít_,
   {{0x63a213d5,0x7ea00212,0x629a13d6,0x60c4041c}},	//   _tyon, köps, soto, _ciim,
   {{0x629a0a4b,0x60c413d7,0x628f020d,0x06cc0033}},	//   poto, _diim, écoc, রীরি,
   {{0x5edd0081,0xf8ca00b7,0x69da087c,0x00000000}},	//   _বিদে, िदाय, _प्ली, --,
   {{0x60c413d8,0xa6e900fe,0x00000000,0x00000000}},	//   _fiim, _giươ, --, --,
   {{0x60c413d9,0x3f8c0233,0x00000000,0x00000000}},	//   _giim, ğdur_, --, --,
   {{0x3f8c0092,0x27ef13da,0x69c7037a,0x00000000}},	// [c50] şdur_, vagn_, _pgje, --,
   {{0xe80d04a9,0x0b8800d6,0x24510146,0xea0000fe}},	//   _हाहा_, істи_, _dámy_, _đản_,
   {{0xf7d80294,0x47d80134,0x00000000,0x00000000}},	//   _ịrụp, _ịzụk, --, --,
   {{0xb8f313db,0x2ee903e3,0xfc3f0023,0x245100d8}},	//   _हं_, _kwaf_, _chít_, _fámy_,
   {{0xe73913dc,0x87270037,0x209b0134,0x490706eb}},	//   сел_, تعام, ụkwụ_, _हमको_,
   {{0x27ef00f2,0xb9010033,0x9605023a,0xd62913dd}},	//   sagn_, _দি_, रलेट_, соке_,
   {{0x224913de,0x2fc900f9,0xb06600c2,0x3b090063}},	//   _đak_, _ogag_, nsää, luaq_,
   {{0x2fc90009,0x20e70103,0xd7f00076,0x929d007f}},	//   _ngag_, vői_, _لكِ_, tuło,
   {{0xeda8030b,0x66f413df,0x00000000,0x00000000}},	//   _गर्छ, _опту, --, --,
   {{0x27ed03ee,0xcb1203c2,0x2fc913e0,0x20e70103}},	//   _heen_, עלי_, _agag_, tői_,
   {{0x60c413e1,0xa0a6028d,0x2d840233,0x27ed13e2}},	//   _piim, занд, şmez_, _keen_,
   {{0x26c5068d,0xc4d200a1,0x60c4008a,0x2489037a}},	//   _hilo_, _נגד_, _qiim, _ñam_,
   {{0x60c413e3,0x27ed13e4,0x7c360b81,0x25a513e5}},	//   _viim, _meen_, vdyr, _hyll_,
   {{0xd356040a,0x27ed13e6,0x645913e7,0xdbf602d5}},	//   _מיני_, _leen_, _howi, ेल्ड_,
   {{0x2fcd13e8,0x60c413e9,0x7c3613ea,0x00000000}},	//   žega_, _tiim, tdyr, --,
   {{0x26c5026e,0x628113eb,0x27ed029a,0x3eb809ac}},	//   _lilo_, lilo, _neen_, smrt_,
   {{0x2ee903e3,0x201205bd,0x2d85020d,0x26c50062}},	// [c60] _gwaf_, _icyi_, ûler_, _oilo_,
   {{0x628113ec,0x26c50d79,0xee3700ae,0x6a6002c3}},	//   nilo, _nilo_, _ень_, _löfv,
   {{0x27ed13ed,0x2f1601c5,0x7c3601ce,0x7c2a0077}},	//   _been_, læg_, pdyr, _лонг_,
   {{0xc18c00c1,0x628113ee,0x645913ef,0xa3ac074c}},	//   סטאָ, hilo, _nowi, _गरल_,
   {{0x628113f0,0x16340423,0xb8f31024,0xd7ef0037}},	//   kilo, деля, _हू_, اكه_,
   {{0x6b890682,0x98ac07aa,0x26c500c4,0xfe1f11c6}},	//   _þega, ılır_, _cilo_, म्पस_,
   {{0x628113f1,0x26c513f2,0x645913f3,0x1fb90852}},	//   dilo, _dilo_, _bowi, _इण्ड,
   {{0x27ed13f4,0x18a313f5,0x7bd60027,0x00000000}},	//   _geen_, _засм, ncyu, --,
   {{0x645900a5,0x26c513f6,0x00000000,0x00000000}},	//   _dowi, _filo_, --, --,
   {{0x628113f7,0x25a513f8,0x26c503a9,0xa3dc097c}},	//   gilo, _fyll_, _gilo_, _त्र_,
   {{0x764813f9,0xfc3f0037,0xa15800ae,0x2ee90383}},	//   _indy, _mhír_, цану_, _swaf_,
   {{0xa3e6000f,0x386613fa,0x7af600c2,0x764401c2}},	//   _बजट_, nkor_, ksyt, ɓiya,
   {{0x6a600102,0x765a13fb,0x533402b3,0xe29a13fc}},	//   _höfu, _koty, _целт, _лад_,
   {{0x628113fd,0x644701d3,0x645913fe,0x4b120033}},	//   cilo, ējie, _zowi, হবাগ_,
   {{0x765a13ff,0x6e940231,0x38661400,0x9f4b02c6}},	//   _moty, хиру, kkor_, mací_,
   {{0xea0000de,0x9f4b033d,0x765a1401,0x4fc71402}},	//   _đạn_, lací_, _loty, _эска,
   {{0x5a351403,0xb0660084,0xfbd000e3,0x27ed0313}},	// [c70] мнат, ssää, اتف_, _reen_,
   {{0x32d20019,0x765a1404,0x27ed00a1,0x9f4b02c6}},	//   _mây_, _noty, _seen_, nací_,
   {{0x80a403ed,0x26c50124,0x32d20023,0x6dc30090}},	//   _زمین, _rilo_, _lây_, _qċaċ,
   {{0x2c0900bf,0x9f4b1405,0x00000000,0x00000000}},	//   _بعدی_, hací_, --, --,
   {{0x2ca91406,0xcc5603c2,0x9f4b00b6,0x27ed0629}},	//   mlad_, _חברי_, kací_, _veen_,
   {{0xe5a51407,0x64591408,0x2ca91409,0x62810a00}},	//   мили, _sowi, llad_, xilo,
   {{0x64590d1b,0x765a140a,0x27ed140b,0x6281140c}},	//   _powi, _doty, _teen_, vilo,
   {{0x38660222,0x61e40291,0x32d20019,0x7648140d}},	//   ckor_, _đila, _bây_, _endy,
   {{0x6281140e,0x32d20028,0x26c503e3,0x2ca90150}},	//   tilo, _cây_, _tilo_, ilad_,
   {{0x32d20019,0x2ca9140f,0x2f161410,0x00000000}},	//   _dây_, hlad_, væg_, --,
   {{0x62810a29,0x2ca91411,0x356b1412,0x386d0120}},	//   rilo, klad_, _уран_, _kler_,
   {{0x1de60f8f,0x62790146,0x23720034,0x6a6013da}},	//   कर्ष_, jňov, _żyje_, _höft,
   {{0x32d20028,0x2ca91413,0x62790146,0xd3d80037}},	//   _gây_, dlad_, dňov, _ربنا_,
   {{0x5edd00c7,0x248d1414,0x7cd5013f,0x38661415}},	//   _বিশে, lnem_, _sąra, zkor_,
   {{0x248d1416,0x6da30cd7,0x2ca90188,0xdca60a99}},	//   onem_, вира, flad_, дави,
   {{0x248d1417,0x4e1f0c8c,0x2ca91418,0xae1f09dd}},	//   nnem_, म्बई_, glad_, म्बन_,
   {{0xa5a404dd,0x32d20028,0x3ced1419,0xdca3141a}},	// [c80] _चुनौ, _xây_, ćeva_, тати,
   {{0x386d00b3,0x1e83141b,0x2ca9019a,0x7af6141c}},	//   _aler_, _альм, alad_, rsyt,
   {{0x2ca9141d,0x9f420031,0x386d141e,0x249f014b}},	//   blad_, jakú_, _bler_, koum_,
   {{0x20d30028,0x248d141f,0x9f4b00b6,0x315600c1}},	//   _mãi_, jnem_, zací_, ויען_,
   {{0x248d1420,0x20d300de,0x38661421,0xfc3f0076}},	//   dnem_, _lãi_, rkor_, _thír_,
   {{0x38661422,0x2ca01423,0xa3c106eb,0xd04200a7}},	//   skor_, loid_, ंधन_, rqlə,
   {{0x386d1424,0x9f4b0343,0xceb30130,0x656300f0}},	//   _fler_, vací_, דיג_, gynh,
   {{0x38b50bab,0x60cd00e7,0x628f00fd,0x684311cc}},	//   gård_, _čamp, écon, _инса,
   {{0x27e61425,0xd62600e3,0x765a1426,0x41c90abe}},	//   mbon_, _يعطي, _toty, रशंस,
   {{0x20d300de,0x27e601e9,0x518601ef,0x32d20023}},	//   _bãi_, lbon_, дума, _vây_,
   {{0x248d1427,0x9f4b033d,0x20d300de,0x1bee0285}},	//   bnem_, rací_, _cãi_, जराल_,
   {{0x32d20028,0x27e61428,0x20d300fe,0x9f4b00d4}},	//   _tây_, nbon_, _dãi_, sací_,
   {{0x80ca0693,0x2ca91429,0x44fa01d3,0x62791054}},	//   _संके, vlad_, lī_, vňov,
   {{0x2ca9142a,0x20050511,0x8d6b001f,0x91f2074c}},	//   wlad_, şli_, ојба_, _आजिज_,
   {{0x62790146,0x44fa01d3,0x20d300fe,0x00000000}},	//   tňov, nī_, _gãi_, --,
   {{0x8af00253,0x6e370694,0x2ca000f9,0xa3b500c3}},	//   yyət, _waxb, goid_, छेक_,
   {{0x7b1800c2,0x2918003d,0x2d9e142b,0x62790094}},	// [c90] мотр_, _aqra_, üter_, rňov,
   {{0xd5a400fb,0x248d142c,0x62790094,0x249f01c2}},	//   _نہ_, znem_, sňov, zoum_,
   {{0x6279025b,0x25a903e3,0x386d0113,0xfbd00103}},	//   pňov, ƙali_, _pler_, اتہ_,
   {{0x2ca0142d,0x59df142e,0x765e007b,0x00000000}},	//   coid_, _प्रर, öpyn, --,
   {{0xf625142f,0x248d02dd,0x7c2d1430,0x38b50149}},	//   едло, vnem_, mear, vård_,
   {{0x7c2d1431,0x8cb91432,0xb0cf0be4,0xe61000a7}},	//   lear, ्दको, _संलग, rüşə,
   {{0x248d02dd,0xe5a200d6,0x79a40097,0x64a51433}},	//   tnem_, лиши, _арте, нака,
   {{0x7c2d1434,0x387f1084,0x20d300de,0x386d1435}},	//   near, _umur_, _rãi_, _uler_,
   {{0x248d1436,0x6d43007e,0x00000000,0x00000000}},	//   rnem_, _šnal, --, --,
   {{0x7c2d0099,0x248d0660,0x00000000,0x00000000}},	//   hear, snem_, --, --,
   {{0x7c2d0634,0x00860237,0x248d1437,0x2c0f00b7}},	//   kear, елно, pnem_, िलां_,
   {{0x20d30023,0x7c2d1438,0x00000000,0x00000000}},	//   _vãi_, jear, --, --,
   {{0xe28e1439,0x442d143a,0x7c2d143b,0x270d009d}},	//   _ба_, mee_, dear, _समोर_,
   {{0x442d143c,0x877a0796,0x82350281,0xed5a0b0a}},	//   lee_, לארי, _سرتا, пог_,
   {{0x6fa0143d,0x27ff0d79,0x26170f53,0x8af00092}},	//   _गुरू, _odun_, _नानी_, yyəs,
   {{0x442d143e,0x7c2d143f,0xdca607b3,0xdca31440}},	//   nee_, gear, хаби, гаси,
   {{0x644b005c,0xdb1c00a7,0xab271441,0x20000af0}},	// [ca0] _mngi, _özüm, нота_, _idii_,
   {{0x442d1442,0x27ff049e,0x7f441443,0x00000000}},	//   hee_, _adun_, _iriq, --,
   {{0x442d1444,0x7c2d1445,0x644b11f0,0x26df0231}},	//   kee_, bear, _ongi, _atuo_,
   {{0x7c2d1446,0x442d1447,0x27e6029a,0xb05b058f}},	//   cear, jee_, ubon_, rmäg,
   {{0x442d1448,0x3a38013f,0x7d0e1449,0x27e6144a}},	//   dee_, _tarp_, lubs, rbon_,
   {{0x644b144b,0x27ff144c,0x27e6144d,0x6e2e144e}},	//   _angi, _edun_, sbon_, nebb,
   {{0x442d0129,0x7ae4144f,0x69ce0d79,0x69dc1450}},	//   fee_, lpit, _igbe, _ifre,
   {{0x442d1451,0x7ae40051,0x6e2e1452,0x44fa0877}},	//   gee_, opit, hebb, rī_,
   {{0x7ae41453,0x96ba1454,0x760a00ae,0xb05b007b}},	//   npit, _فائز_, _неаг_, nmäe,
   {{0x644b1455,0x7c2d0a00,0xda100d77,0x75d60037}},	//   _engi, zear, ालित_, _أيضا,
   {{0xd48f1456,0x69ce0294,0x06d80033,0x7c2d1457}},	//   _бр_, _mgbe, _সিটি, year,
   {{0x7ae41458,0x442d1459,0x7f44145a,0x7c2d0634}},	//   kpit, cee_, _briq, xear,
   {{0x69dc11ce,0x7c2d145b,0xbfab1402,0x7f44145c}},	//   _ofre, vear, ятое_, _criq,
   {{0x2b400117,0x6e2e0103,0x78a200bc,0x9f4b00ee}},	//   dvic_, gebb, hoov, racà_,
   {{0x7c2d145d,0x3ced0335,0xdd9400c6,0xac1907bf}},	//   tear, ćevo_, гары, мову_,
   {{0x69dc145e,0x69ce0d79,0xa01b0212,0x7f4400b3}},	//   _afre, _agbe, rnös, _friq,
   {{0x7c2d145f,0xddc50220,0x7ae40d1f,0x9f53007f}},	// [cb0] rear, _dlhš, gpit, ędów_,
   {{0x7c2d1460,0x442d1461,0x6f0f028d,0x1dd51462}},	//   sear, zee_, mucc, _दलित,
   {{0x442d1463,0x6f0f1464,0x7c2d1465,0x6f1d0364}},	//   yee_, lucc, pear, ltsc,
   {{0x69ce0af0,0xdddc013f,0x6f1d01c0,0x69dc1466}},	//   _egbe, mirš, otsc, _efre,
   {{0xd3661467,0x6f1d1468,0xb8d80251,0xab871469}},	//   _ئه_, ntsc, _घी_, _чунк,
   {{0x442d146a,0x6d4a00e3,0x6f1d0364,0x70030294}},	//   wee_, _áfac, itsc, ọchi,
   {{0x442d146b,0x78a200e7,0x6f1d11c5,0x628f014b}},	//   tee_, boov, htsc, écom,
   {{0xa8a4146c,0x442d00f9,0x69ce00c4,0xc3250033}},	//   _брук, uee_, _zgbe, বিসি_,
   {{0x2ba704dd,0x36d502ec,0x442d0054,0x9f4b146d}},	//   _कुमा, _розр, ree_, yacá_,
   {{0x6f0f146e,0x442d146f,0xcb1400c1,0x20001470}},	//   ducc, see_, אלץ_, _sdii_,
   {{0x442d1471,0x35550241,0x6d4501fa,0xd00a1472}},	//   pee_, _جناز, _nrha, мене_,
   {{0x644b1473,0x6e2e0361,0x6f1d02db,0x60dc002b}},	//   _ungi, webb, ftsc, írma,
   {{0xa3a8009d,0x6e2e1474,0x547a00ca,0x6f0f0036}},	//   _खुप_, tebb, _קטנו, gucc,
   {{0x6d45005c,0xdee30058,0x8cd60285,0x3b09010a}},	//   _brha, рори, _मंदो, draq_,
   {{0x6e2e0465,0x7afd1475,0x6da60097,0xada61476}},	//   rebb, _avst, тива, тавл,
   {{0x7f441477,0x6e2e1478,0x69dc1479,0x6f0f147a}},	//   _triq, sebb, _sfre, bucc,
   {{0x7d0e147b,0x6d4502e2,0x7d1c02dd,0x6b63147c}},	// [cc0] subs, _erha, strs, акта,
   {{0x63ab00f9,0x7ae4147d,0x2b4005db,0x7bcf0372}},	//   _mygn, rpit, rvic_, _egcu,
   {{0x2ba7007d,0x7ae4147e,0x6729026e,0xa3a8147f}},	//   _कुठा, spit, _apej, _खुन_,
   {{0x66e61480,0xe78600d3,0x7ae41481,0xe3a71482}},	//   вода, куло, ppit, _نر_,
   {{0x62830031,0x78a2058f,0x00000000,0x00000000}},	//   _omno, roov, --, --,
   {{0xb7d20081,0x20ee00b6,0x78a200aa,0x69dc1483}},	//   ারেট, yři_, soov, _ufre,
   {{0x6f0f0036,0xd3e90033,0x91fc01d3,0x00000000}},	//   zucc, _গাড়ি_, skāk, --,
   {{0x63ab1484,0x394702b6,0x62831485,0x00000000}},	//   _bygn, ænse_, _amno, --,
   {{0x63ab02e5,0xa7a71486,0x87251487,0x7eb200f3}},	//   _cygn, _акта_, _معلم, væpn,
   {{0x63ab0149,0x20ee00d2,0x00000000,0x00000000}},	//   _dygn, tři_, --, --,
   {{0x26171488,0x7c26103b,0x26cc008c,0x2b460206}},	//   _नाती_, _obkr, _iido_, ťoch_,
   {{0x6f0f0451,0xdddc0138,0x6f1d1489,0x62830372}},	//   tucc, virš, ttsc, _emno,
   {{0x4426148a,0x6f1d0364,0xd36f1374,0x2d9a01ff}},	//   _ibo_, utsc, _وهم_, _axpe_,
   {{0x6f1d148b,0x6f0f04d3,0x2c7501c5,0x6d450117}},	//   rtsc, rucc, _måde_, _prha,
   {{0x26cc148c,0x6f1d148d,0x2bc5148e,0x7c260062}},	//   _mido_, stsc, लेना, _bbkr,
   {{0x200500c6,0x6f1d042c,0x91f200aa,0x6d4500d4}},	//   ėlis_, ptsc, _आजुओ_, _vrha,
   {{0x201e0253,0x4426148f,0x09bd0966,0x9cc801b6}},	// [cd0] əti_, _mbo_, ्ख्य, тыра_,
   {{0x62881490,0x99671491,0x160e1492,0x2ba71493}},	//   nido, ктел, _सागर_, _कुणा,
   {{0x44261494,0x60cd1495,0x67291496,0x7ac41497}},	//   _obo_, _kiam, _spej, рсте,
   {{0x2c750c2e,0x24580181,0x44261498,0x60cd1499}},	//   _både_, _témy_, _nbo_, _jiam,
   {{0x60cd149a,0x26cc0129,0x160e009d,0xb8fa149b}},	//   _miam, _bido_, _साखर_, _डू_,
   {{0x4426149c,0x98b308bb,0x7c3d149d,0xa3e509c3}},	//   _abo_, ıdır_, _hasr, बुन_,
   {{0x62880b0b,0x6ed506ed,0x63ab149e,0x4426083e}},	//   dido, _यूसु, _sygn, _bbo_,
   {{0x60cd149f,0x26cc03be,0x7c3d0063,0x9f52022b}},	//   _niam, _eido_, _jasr, _feyè_,
   {{0x7c3d14a0,0x78a9039f,0x42c9007e,0x00000000}},	//   _masr, _ikev, нгин_, --,
   {{0x628814a1,0x442614a2,0x78a214a3,0xe3b6004b}},	//   gido, _ebo_, čove, ыбы_,
   {{0x78bb023e,0x60cd0154,0x64150037,0x00000000}},	//   _khuv, _biam, _مواط, --,
   {{0x60cd01b5,0x44260d79,0xdee614a4,0x205600d3}},	//   _ciam, _gbo_, ломи, утор,
   {{0x60cd14a5,0xb4c10d77,0x00000000,0x00000000}},	//   _diam, ूदी_, --, --,
   {{0x6288132d,0x443f14a6,0x443d14a7,0x628314a8}},	//   cido, ldu_, _haw_, _umno,
   {{0x443d14a9,0x443f14aa,0xff140081,0x60cd14ab}},	//   _kaw_, odu_, িবেশ_, _fiam,
   {{0x60cd14ac,0x7c3d0188,0x645b14ad,0x00000000}},	//   _giam, _casr, njui, --,
   {{0x4bd914ae,0x443d0150,0x3b070476,0x443f14af}},	// [ce0] ться_, _maw_, лето_, idu_,
   {{0x443d00a1,0xfaaa001c,0x443f14b0,0x2c7500f2}},	//   _law_, رهاي_, hdu_, _råde_,
   {{0x9f5214b1,0x09060f2e,0x26cc14b2,0xae1b006e}},	//   _seyè_, упен, _rido_, _אויכ,
   {{0x26cc14b3,0x38600102,0x78bb0bfe,0x443f0146}},	//   _sido_, ðir_, _chuv, jdu_,
   {{0x443f14b4,0x26cc14b5,0x5fc700b6,0x4b5500e5}},	//   ddu_, _pido_, रेपल, _кърт,
   {{0x0f370054,0x62880042,0x443f14b6,0xda720018}},	//   טרנט_, xido, edu_, _اُس_,
   {{0x443d14b7,0xaad80096,0x00000000,0x00000000}},	//   _baw_, _भूतक, --, --,
   {{0xdd0401b3,0x443d006c,0x7c2414b8,0x26cb0036}},	//   ūrėt, _caw_, nfir, _ècon_,
   {{0x6288132d,0x443d14b9,0xf7430f7e,0xb2740396}},	//   tido, _daw_, _лето, илиш,
   {{0x60cd14ba,0x59b80b94,0x443f14bb,0x7c2402e5}},	//   _siam, _अरार, adu_, hfir,
   {{0x7c2414bc,0x443f009e,0x1da40f78,0x443d14bd}},	//   kfir, bdu_, _खुलत, _faw_,
   {{0xf5370054,0x628814be,0x443d14bf,0x60cd061d}},	//   _תנאי_, sido, _gaw_, _qiam,
   {{0x7c3d14c0,0x44240063,0x9f590216,0x00000000}},	//   _rasr, mfm_, masë_, --,
   {{0x35a9009f,0x644014c1,0x6e3e14c2,0x7c3d03a9}},	//   _चुड़, ldmi, _capb, _sasr,
   {{0x60cd006c,0x61fa01d4,0x7c2414c3,0x7c3d14c4}},	//   _tiam, matl, ffir, _pasr,
   {{0x61fa14c5,0x644014c6,0x443d01ad,0x7c3d026d}},	//   latl, ndmi, _xaw_, _qasr,
   {{0x50b8006f,0x6e9500d6,0x99900335,0x3b550284}},	// [cf0] _حدود_, _випу, _čaša_, шкар,
   {{0x61fa14c7,0x443f14c8,0xda780457,0xdb2401f9}},	//   natl, zdu_, лях_, ásán,
   {{0x394714c9,0x443f14ca,0x7c3d14cb,0x628f00fd}},	//   íns_, ydu_, _tasr, écoi,
   {{0x261713b4,0x61fa04a8,0x443f1321,0x9f590216}},	//   _नाही_, hatl, xdu_, jasë_,
   {{0xe73914cc,0x443f14cd,0x61fa14ce,0x07a507c8}},	//   тел_, vdu_, katl, јалн,
   {{0xa5091402,0x61fa14cf,0x443d00ca,0x00000000}},	//   века_, jatl, _saw_, --,
   {{0x443d14d0,0x61fa14d1,0x3e7400aa,0x443f00a7}},	//   _paw_, datl, _jäta_, tdu_,
   {{0x443f14d2,0xc6060081,0x3e7414d3,0x7cdc05db}},	//   udu_, ল্লা_, _mäta_, _očrn,
   {{0xa3a805d4,0x443f14d4,0xfc3f0682,0xe456004b}},	//   _खुद_, rdu_, _maí_, ржы_,
   {{0xc6a714d5,0x61fa14d6,0x161c0789,0x2ef200f0}},	//   _срби, gatl, _नायर_, _rwyf_,
   {{0x443d14d7,0x7c24003e,0x6e3e0085,0xf8c90139}},	//   _taw_, yfir, _rapb, _gbéé_,
   {{0x443f14d8,0x44f300ae,0x239e0134,0x3f6a0284}},	//   qdu_, mţ_, ịja_, вимо_,
   {{0x61fa07e7,0x6e3e14d9,0xa3c100a4,0x3cdb00aa}},	//   batl, _papb, ंधळ_, _खूबे_,
   {{0x200c0092,0x614514da,0x673b0350,0x00000000}},	//   şdi_, _века, _msuj, --,
   {{0x44f300d3,0x8d630508,0xa3dc14db,0xb05b007b}},	//   nţ_, овре, तुक_, mmän,
   {{0xb05b14dc,0x673b09ac,0xfc3f0850,0xebe600d3}},	//   lmän, _osuj, _caí_, роап,
   {{0x7c2414dd,0xfc3f0161,0x638801d3,0x673b06b0}},	// [d00] rfir, _daí_, cīnī, _nsuj,
   {{0xab2714de,0x7bdf0451,0x00000000,0x00000000}},	//   рофа_, acqu, --, --,
   {{0xd00f14df,0x7c2402a4,0x19b901b3,0x6d4305db}},	//   _علی_, pfir, гуць_, _šnav,
   {{0x8c4614e0,0xa01b007b,0x61fa14e1,0x07ba0076}},	//   _теме, tiöi, zatl, نهضة_,
   {{0x61fa03a3,0x27e914e2,0xbb4300d6,0xeb97020f}},	//   yatl, ñana_, _деяк, _вия_,
   {{0xa01b00c2,0x2913002b,0xbb43001f,0x248602ac}},	//   riöi, buxa_, _ќерк, _smom_,
   {{0x61fa14e3,0xd49a14e4,0x261714e5,0x442414e6}},	//   vatl, кри_, _नारी_, tfm_,
   {{0x61fa005c,0x98a314e7,0x493b00d7,0x00000000}},	//   watl, _дисе, _בגלו, --,
   {{0xc178013f,0x61fa101a,0x3ced0a9e,0x66e314e8}},	//   ybės_, tatl, ćevi_, _мота,
   {{0x09ca0081,0x672214e9,0xdd1c0031,0xa6ca14ea}},	//   _ল্যা, mtoj, _záťa, _شوال_,
   {{0x61fa14eb,0x272002f1,0x672214ec,0xd25702e3}},	//   ratl, lòn_, ltoj, рцы_,
   {{0x6722013f,0x61fa14ed,0x224903e3,0x44320023}},	//   otoj, satl, _ɗaki_, _úy_,
   {{0x672211c2,0x61fa14ee,0x2cb214ef,0xfc3f0231}},	//   ntoj, patl, dlyd_, _raí_,
   {{0xea0000ef,0x61fa00a7,0xfc3f016d,0x67220109}},	//   _đến_, qatl, _saí_, itoj,
   {{0xb2bb0054,0xbd680012,0x672214f0,0xfc3f037a}},	//   _שמור, арте_, htoj, _paí_,
   {{0x2c750222,0x672214f1,0xdb0f0143,0x5c7414f2}},	//   _båda_, ktoj, _azcá, олст,
   {{0x3a750095,0x6722023b,0xa9e70037,0x9f590113}},	// [d10] блар, jtoj, لثان, kasé_,
   {{0x29130072,0x6d4314f3,0xdbd81405,0x3e7402c3}},	//   tuxa_, _šnau, rťák, _täta_,
   {{0x2ba7000d,0xdd9114f4,0x61f814f5,0x672214f6}},	//   _कुरा, _روح_, _mevl, etoj,
   {{0x31570130,0x201914f7,0x272006a3,0x6722023b}},	//   ייבן_, ngsi_, fòn_, ftoj,
   {{0xf74514f8,0x272014f9,0x60d800b3,0x9f5903a9}},	//   село, gòn_, _luvm, fasé_,
   {{0x2ca9051f,0x78a20074,0xbb3a00c1,0x29130072}},	//   load_, čova, _געשי, puxa_,
   {{0xfbdb007d,0x28f814fa,0x199414fb,0x499300d1}},	//   _भलाम, _весь_, _даря, _بیار,
   {{0x29010051,0x6722023e,0x4adb14fc,0xe7870686}},	//   msha_, btoj, _बढाव, _кузо,
   {{0x290114fd,0x61f814fe,0x4e1700b6,0x9f5903a9}},	//   lsha_, _bevl, तलाई_, basé_,
   {{0x38bc14ff,0x29010255,0x61f81500,0x6e350357}},	//   ríre_, osha_, _cevl, jezb,
   {{0x61f81501,0xa06a1502,0x29011503,0xb05b1504}},	//   _devl, гана_, nsha_, rmän,
   {{0xf99200a1,0xb1130294,0x76410188,0x29011505}},	//   לרי_, _kụzu, _haly, isha_,
   {{0x248d0b4b,0x76411506,0x720500cd,0x889a0341}},	//   miem_, _kaly, _هوشم, רברי,
   {{0x248d00d9,0x61f81507,0xb05b00c2,0x27fd00f0}},	//   liem_, _gevl, lmäl, hawn_,
   {{0x76430167,0x01c50033,0xfce61508,0x628f020d}},	//   idny, _শ্রদ, собо, écou,
   {{0x248d1509,0x672201b3,0xb05b0149,0x6d4a0072}},	//   niem_, ytoj, nmäl, _áfam,
   {{0xf1bf00b6,0xd5b10023,0x6e350095,0x61f8013c}},	// [d20] řád_, _lý_, bezb, _yevl,
   {{0x6f04150a,0x248d150b,0x764106b0,0x2901150c}},	//   _ivic, hiem_, _naly, fsha_,
   {{0xfe370054,0x248d150d,0x2b4b01c2,0x00000000}},	//   _פרטי_, kiem_, _ercc_, --,
   {{0x248d0b4b,0x91fc00d9,0x17fa00e3,0x672200c2}},	//   jiem_, nkār, اراة_, ttoj,
   {{0x248d0029,0x501b09c1,0x7641150e,0x672202e3}},	//   diem_, רונו, _baly, utoj,
   {{0x6722150f,0x1ae31510,0xe8140179,0xa01b007b}},	//   rtoj, _хорм, _डाका_, liöt,
   {{0x672206bc,0x764101b3,0x394a00b3,0x490f00c3}},	//   stoj, _daly, _urbs_, _डियो_,
   {{0x248d1511,0x7c361512,0x6722023b,0xb1760019}},	//   giem_, neyr, ptoj, _ngượ,
   {{0xa3a80101,0x00000000,0x00000000,0x00000000}},	//   _खुश_, --, --, --,
   {{0x066500cd,0x76411513,0xda7b006e,0x7d150350}},	//   _والپ, _galy, ָנטר, yuzs,
   {{0xd0110604,0x248d00e8,0x959a00d3,0xa3a800b7}},	//   ولد_, biem_, _стау_, _खुर_,
   {{0x248d1514,0x7641010a,0x00000000,0x00000000}},	//   ciem_, _zaly, --, --,
   {{0x5f94008f,0x3e970037,0x9f4001ff,0x6f041515}},	//   зият, مؤسس, _beiñ_, _cvic,
   {{0x6f0402ef,0x6442033f,0x2901008c,0x539b00ca}},	//   _dvic, _haoi, ysha_, _גידו,
   {{0x90e61516,0x7c36003e,0xb5fc0090,0x2ca91517}},	//   _استن, feyr, _loġo, toad_,
   {{0x81df0033,0x76431518,0x00000000,0x00000000}},	//   তরণ_, zdny, --, --,
   {{0x64421519,0x5eb80081,0x29010188,0xd9f90183}},	// [d30] _maoi, _ইংরে, wsha_, инац_,
   {{0x7f4d151a,0x29010060,0x64420a02,0x248d151b}},	//   _iraq, tsha_, _laoi, ziem_,
   {{0x6f04023b,0xb05b00c2,0x20090063,0xd9990037}},	//   _zvic, ymäl, _kdai_, جنات_,
   {{0x6d400029,0xdb0f0257,0x2901151c,0x6442151d}},	//   āmat, _lycé, rsha_, _naoi,
   {{0x248d151e,0x3ced08a9,0xa3a80251,0x7641013f}},	//   viem_, ćevu_, _खुल_, _paly,
   {{0xf1c8099d,0x248d0034,0x00000000,0x00000000}},	//   रधान, wiem_, --, --,
   {{0x248d0029,0x9f400088,0x7641151f,0x7aed1520}},	//   tiem_, _leið_, _valy, lpat,
   {{0x13091521,0x644202bc,0x7b080088,0x76430167}},	//   аний_, _caoi, _ástæ, sdny,
   {{0x6442003b,0x248d151e,0x7aed1522,0xb7bd00d3}},	//   _daoi, riem_, npat, _obţi,
   {{0x248d0029,0x20090051,0x38bc0094,0x2f10003e}},	//   siem_, _adai_, míra_, _lögð_,
   {{0x6442006b,0x6f041523,0x7f4d1524,0x645d01bf}},	//   _faoi, _svic, _araq, ösis,
   {{0x43751525,0x644209f7,0x2bbe02d5,0x9fca02b3}},	//   _мулт, _gaoi, ्धमा, игна_,
   {{0x99980335,0xe28e1526,0x7f4d1527,0x200903a9}},	//   _marš_, _жа_, _craq, _ddai_,
   {{0x7aed055c,0xa3e500bc,0x91fc00e8,0xc5f90142}},	//   dpat, बुर_, skār, יפֿט,
   {{0xa3c10455,0x7aed1528,0xa01b0e74,0x00000000}},	//   ंधक_, epat, giös, --,
   {{0x7f4d1529,0x6f04022b,0x00000000,0x00000000}},	//   _fraq, _tvic, --, --,
   {{0x7aed152a,0x7c360088,0x68e9033b,0x8eba00d3}},	// [d40] gpat, reyr, _čeda, _вынт_,
   {{0xf221009f,0x63b6004d,0x6d5a007b,0x7c36152b}},	//   _माफ़_, _øyne, ätas, seyr,
   {{0x649700d9,0xed5a0605,0x6ee5015a,0x05a9152c}},	//   rģij, _тон_, _وسیل, _चुलब,
   {{0xd7ef0037,0x78a20094,0x6ef70294,0xcfad0033}},	//   نكم_, čovo, ụbeg, _গণতন,
   {{0xa6ca007e,0x64420441,0xa01b152d,0x8af0013c}},	//   алда_, _raoi, shög, yyəy,
   {{0x64420099,0x2c7c0139,0x00000000,0x00000000}},	//   _saoi, _díde_, --, --,
   {{0x385a0bd5,0x69230cb0,0xd8390154,0x00000000}},	//   _краю_, _омра, _djōb_, --,
   {{0xe8140c54,0xa3e51073,0x00000000,0x00000000}},	//   _डाटा_, बुल_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x026a00d6,0x3f82152e,0xa50a0f6b,0x00000000}},	//   рший_, dzku_, _вежа_, --,
   {{0x3a3703c2,0x6442152f,0x8cd60469,0x7aed007f}},	//   חרים_, _taoi, _मंगो, zpat,
   {{0xb05b007b,0x00000000,0x00000000,0x00000000}},	//   mmäk, --, --, --,
   {{0xe29a0831,0xb05b007b,0x00000000,0x00000000}},	//   _кад_, lmäk, --, --,
   {{0x29070018,0x628a0201,0x63a201ff,0x9f5b0216}},	//   ának_, _umfo, _ixon, _heqë_,
   {{0xb05b007b,0xafdb0565,0x00000000,0x00000000}},	//   nmäk, ldøm, --, --,
   {{0xa01b1530,0xe57100c1,0x9b890037,0x69d80138}},	//   riös, ײַל_, منزل_, žvel,
   {{0x3a750095,0x6d5a1531,0x629a026d,0x9f5b0052}},	// [d50] плар, ätar, onto, _meqë_,
   {{0x68e303be,0x00000000,0x00000000,0x00000000}},	//   índo, --, --, --,
   {{0x05a90455,0x629a00c2,0xa3ca0096,0x7aed1532}},	//   _चुंब, into, ळेत_, spat,
   {{0x7aed1533,0x63a20167,0x7c590037,0x6d5800d4}},	//   ppat, _oxon, _الحر_, _švag,
   {{0x78ab1534,0xfc5a00d7,0x8cba007f,0x00000000}},	//   rogv, _הכרמ, ्षरो, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d830034,0x00000000,0x00000000,0x00000000}},	//   nzje_, --, --, --,
   {{0x629a1535,0x00000000,0x00000000,0x00000000}},	//   ento, --, --, --,
   {{0x38341536,0x00000000,0x00000000,0x00000000}},	//   _інфр, --, --, --,
   {{0x629a0b81,0xb05b1537,0xaabd0d7e,0x00000000}},	//   gnto, lmäh, ्गिक, --,
   {{0x27e003f1,0x850500d0,0x91fc00d9,0xe45f00bc}},	//   žine_, _روشن, rkāp, öös_,
   {{0x629a14a7,0x8fa61538,0x55ba00ca,0x61ee00a7}},	//   anto, заме, _המעו, ıbla,
   {{0xc31900c7,0xe80c0096,0x442f1539,0xaabd00a8}},	//   _তৈরি_, हणता_, _ibg_, ्गाक,
   {{0x68e9153a,0x00000000,0x00000000,0x00000000}},	//   _čedn, --, --, --,
   {{0xdd92153b,0xbea3147c,0x3f82153c,0x00000000}},	//   رور_, харк, szku_, --,
   {{0x442f0ca7,0xda1e0096,0xaf06153d,0x00000000}},	//   _jbg_, _पाहत_, _епил, --,
   {{0x2002153e,0x3aeb0018,0x60c4153f,0x207b006e}},	// [d60] maki_, مبلی_, _ihim, _לאקא,
   {{0x20021540,0xdb060034,0xa6e90023,0x2fc0039f}},	//   laki_, _szkó, _khươ, _izig_,
   {{0xceb31541,0x4ddb00ca,0xe853001c,0x442f0131}},	//   _איז_, _לחיו, کنند, _obg_,
   {{0x20021542,0x38cb037f,0xc6040455,0xdca61543}},	//   naki_, مانی_, रण्य_, _хами,
   {{0x629a1544,0x60c40a1c,0x00000000,0x00000000}},	//   ynto, _mhim, --, --,
   {{0x442f063f,0x20021545,0xd6d900d6,0x00000000}},	//   _abg_, haki_, іті_, --,
   {{0x20020044,0xe9a31546,0x442f1547,0x00000000}},	//   kaki_, _зарп, _bbg_, --,
   {{0x20021548,0x399b00a1,0x2bc300c3,0x291a0270}},	//   jaki_, _הילד, _शरमा, mupa_,
   {{0x20020b88,0x6b841549,0x98a300d3,0x2fc0010a}},	//   daki_, nzig, _чите, _nzig_,
   {{0x2a6a154a,0xb05b02fd,0x27e6154b,0x877b0327}},	//   _jobb_, mmäi, lcon_, _האמי,
   {{0x2bb906ae,0xa6e90028,0x249700bf,0xbbb9143d}},	//   _आर्थ, _chươ, _کنند_, _आर्क,
   {{0x60c4154c,0x442f02c3,0x2a6a02a1,0x63a201c8}},	//   _chim, _gbg_, _lobb_, _txon,
   {{0x60c4154d,0x6b840ab2,0x291a0270,0x60d6030a}},	//   _dhim, jzig, hupa_, _diym,
   {{0x291a154e,0x60c40154,0xd35700ca,0xf8dc0285}},	//   kupa_, _ehim, _מידי_, यदाय,
   {{0x2002154f,0x68e90095,0x60c400bd,0x3a3a1550}},	//   baki_, _čedo, _fhim, depp_,
   {{0x60c400ae,0x30a401b3,0x60d60233,0x2002007f}},	//   _ghim, _прыв, _giym, caki_,
   {{0x3f9e01e8,0xcb3400e5,0x7c2f1551,0x27e60565}},	// [d70] ştur_, нетъ, _vbcr, dcon_,
   {{0x291a0239,0x6d41003e,0x60c401c2,0x1ab400d3}},	//   fupa_, ælas, _zhim, ебуя,
   {{0x2907030b,0x291a003a,0x6b840172,0xf8b101f3}},	//   éna_, gupa_, azig, نکر_,
   {{0x38690682,0x6a730367,0x9f0400d1,0x00000000}},	//   ðar_, _sıfı, _تویو, --,
   {{0x7c2d1552,0x649700ae,0x36691553,0x00000000}},	//   mfar, nţie, жало_, --,
   {{0x442f1554,0x20021555,0x7c2d1556,0x00000000}},	//   _sbg_, zaki_, lfar, --,
   {{0xa9341557,0x20021558,0x291a1559,0xa3ca0096}},	//   _перш, yaki_, cupa_, ळेस_,
   {{0x7c2d155a,0x2002155b,0x00000000,0x00000000}},	//   nfar, xaki_, --, --,
   {{0x2002155c,0x7c2d0ba1,0x00000000,0x00000000}},	//   vaki_, ifar, --, --,
   {{0x60c4155d,0xa6e90028,0x2002155e,0x00000000}},	//   _shim, _phươ, waki_, --,
   {{0x2002155f,0x66031560,0xa0a6007e,0x60c400de}},	//   taki_, mank, данд, _phim,
   {{0x60d601d4,0x27ff1561,0x3943037a,0xf4b600d1}},	//   _qiym, _jeun_, _msjs_, _قشنگ,
   {{0x20021562,0x644902ad,0x442d1563,0x7c2d1564}},	//   raki_, mdei, mfe_, dfar,
   {{0x442d02dc,0xa6e900ef,0x20021565,0xa2da0096}},	//   lfe_, _thươ, saki_, नदर्,
   {{0x20021566,0x6d58015c,0x2a6a1567,0x60c41568}},	//   paki_, _švab, _robb_, _thim,
   {{0x64491569,0x6b84156a,0x442d156b,0x7c2d156c}},	//   ndei, tzig, nfe_, gfar,
   {{0x6603156d,0xfc3f0139,0x649700d3,0x3e7400aa}},	// [d80] kank, _akís_, cţie, _läti_,
   {{0x62810060,0x291a156e,0x7f440201,0xfbd1071c}},	//   nhlo, tupa_, _isiq, اتِ_,
   {{0x6603156f,0x224702f1,0x6e3c01cb,0x64591570}},	//   dank, _mank_, merb, _onwi,
   {{0x291a1571,0x22471572,0x7d1c1573,0xccf30327}},	//   rupa_, _lank_, murs, _שכר_,
   {{0x073a1574,0xc6f70426,0x44e3037a,0x6603041c}},	//   تساب_, дніх_, _añ_, fank,
   {{0x26c50a9a,0x66031575,0x44fa0a84,0xea000023}},	//   _chlo_, gank, tū_, _đặn_,
   {{0x442d1576,0x69dc0bfe,0x7d1c1577,0x644901cd}},	//   ffe_, _igre, nurs, fdei,
   {{0x3ae40222,0x6e3c1578,0x27ff1579,0x442201f9}},	//   _köp_, herb, _geun_, ük_,
   {{0x2247157a,0x7ae20076,0xb5fc009e,0x68fc03a8}},	//   _bank_, íoth, _loġi, _hwrd,
   {{0x6603157b,0x64490fe1,0x22470027,0x290a084e}},	//   cank, adei, _cank_, _kvba_,
   {{0x2247157c,0x765a157d,0x7c2d0150,0x018a00c2}},	//   _dank_, _inty, yfar, ющий_,
   {{0x7d1c157e,0x1c1d04f8,0x386600d1,0x7648041c}},	//   durs, _फाइल_, njor_, _hady,
   {{0x69dc157f,0x6e3c1580,0x76481581,0x2247007e}},	//   _ogre, ferb, _kady, _fank_,
   {{0x62811582,0x69dc1583,0x7e7e0154,0x2ee01570}},	//   chlo, _ngre, _clpp, _duif_,
   {{0xf1aa00cd,0x76481584,0x7d1c1585,0xc34800de}},	//   _باشه_, _mady, gurs, _hổ_,
   {{0x66031586,0x69dc1587,0x6e3c028d,0x6497020a}},	//   zank, _agre, aerb, pţie,
   {{0x3ec71588,0x7ae40372,0x7c2d1556,0x765a084e}},	// [d90] _особ, gqit, rfar, _onty,
   {{0x27ff0185,0x76480ece,0x68fc0150,0xc34800de}},	//   _seun_, _nady, _bwrd, _mổ_,
   {{0x6f1d002b,0x48151589,0x644900f0,0x6e25158a}},	//   lusc, емес, ydei, _ichb,
   {{0x6d4508f0,0x6603158b,0x765a158c,0x38660052}},	//   _isha, wank, _anty, gjor_,
   {{0x764812ff,0xc34800de,0x7bdd02c9,0x785e00ae}},	//   _bady, _nổ_, _igsu, _săvâ,
   {{0x68fc00f0,0x6459009c,0x7648041c,0x00000000}},	//   _fwrd, _snwi, _cady, --,
   {{0x7648008c,0x27ff01cb,0x224700ca,0x644909ad}},	//   _dady, _teun_, _rank_, tdei,
   {{0x9345158d,0xc3480019,0x61ea158e,0x6d45158f}},	//   ение, _bổ_, _affl, _msha,
   {{0x442d1590,0xc3480028,0xa3ca009d,0x7d1c1591}},	//   rfe_, _cổ_, ळेल_, zurs,
   {{0x27290fb6,0x764802f1,0x6603008a,0xda0f1592}},	//   mún_, _gady, qank, ाणित_,
   {{0x6d451593,0x27290037,0x386d00aa,0x442d1594}},	//   _nsha, lún_, _koer_, pfe_,
   {{0x6e3c02e2,0x386d034f,0xf09f00b3,0x6f1d0036}},	//   werb, _joer_, gnà_, fusc,
   {{0x66011595,0x6d451596,0xda0f009d,0x386d0abf}},	//   _kelk, _asha, ाणात_, _moer_,
   {{0x7d1c01ab,0x386d057a,0x249f003e,0x6e3c1597}},	//   turs, _loer_, lnum_, uerb,
   {{0x387f0702,0x66011598,0x7afd1599,0xed57159a}},	//   _olur_, _melk, _awst, нор_,
   {{0x249f0102,0x6e3c159b,0x66010018,0x7f44005c}},	//   nnum_, serb, _lelk, _tsiq,
   {{0x6d45159c,0xc34800de,0x249f003e,0xb09b0796}},	// [da0] _esha, _xổ_, inum_, _מיקר,
   {{0x6d4500dd,0x387f159d,0x32051177,0x2d8c037a}},	//   _fsha, _alur_, naly_, údes_,
   {{0x387f02e5,0x7648159e,0x386d159f,0x249f0088}},	//   _blur_, _rady, _boer_, knum_,
   {{0xd7060636,0x76480bb6,0x3ae40653,0xa2c10285}},	//   езди, _sady, _töp_, _रीस्,
   {{0x272915a0,0x61360068,0x660115a1,0x386d15a2}},	//   gún_, _külö, _belk, _doer_,
   {{0x66010871,0xc3480023,0x69dc15a3,0x387f15a4}},	//   _celk, _rổ_, _ugre, _elur_,
   {{0xc3480019,0x2ca015a5,0x249f0088,0xfaa315a6}},	//   _sổ_, onid_, fnum_, _саро,
   {{0x249f0088,0x545415a7,0x660100aa,0x95530adb}},	//   gnum_, твит, _eelk, اخوا,
   {{0x660115a8,0xc7a315a9,0xb05b0149,0x764807ac}},	//   _felk, _битк, lläg, _tady,
   {{0x2c7c0610,0x2ca00076,0x386d0381,0x717806e7}},	//   _oído_, hnid_, _zoer_, дбор_,
   {{0xb05b0222,0x2b910220,0xbbbe0eeb,0x5a17006e}},	//   nläg, môcť_, ्धुक, עקטן_,
   {{0xc3480028,0xbebb023b,0x6f1d15aa,0x69c30034}},	//   _tổ_, ntëv, tusc, żneg,
   {{0x442615ab,0xb05b01bf,0xfebb0037,0x320515ac}},	//   _ico_, hläg, كاست_, baly_,
   {{0x6f1d15ad,0xa01b0364,0xb05b02c3,0xddde00d2}},	//   rusc, chön, kläg, _kopř,
   {{0xac9500ba,0x8d7715ae,0x00000000,0x00000000}},	//   вавш, راسا, --, --,
   {{0xdcb80465,0x6f1d1163,0xb05b02c3,0x6d450381}},	//   ещу_, pusc, dläg, _vsha,
   {{0x649700d3,0x386d000b,0xfaf015af,0x00d80103}},	// [db0] nţia, _roer_, مثل_, _ثبوت_,
   {{0x6d450d7d,0x3b0915b0,0x6f0d15b1,0xdb26001c}},	//   _tsha, rsaq_, _ivac, ئولی,
   {{0x3b09009e,0x6d4515b2,0x44260042,0x98b3033b}},	//   ssaq_, _usha, _oco_, žeča_,
   {{0x442601bb,0x6f0d015c,0x66010084,0xb06600c2}},	//   _nco_, _kvac, _selk, mpää,
   {{0xf74515b3,0x66010084,0x386d0305,0xb05b15b4}},	//   тело, _pelk, _voer_, lmäs,
   {{0x272915b5,0xe9d30421,0x386d02ac,0x2a7a0231}},	//   rún_, _مغز_, _woer_, ckpb_,
   {{0x660115b6,0x320515b7,0x386d057a,0x272915b8}},	//   _velk, valy_, _toer_, sún_,
   {{0x660115b9,0x6f0d042d,0x3e74042c,0x387f023b}},	//   _welk, _ovac, _hätt_, _ulur_,
   {{0x249f0088,0x320515ba,0xd84202c6,0x69c80094}},	//   rnum_, taly_, áčů_, _úder,
   {{0xdeab0022,0x249f15bb,0xb05b02c3,0x442615bc}},	//   ƙiƙa, snum_, kmäs, _eco_,
   {{0xb05b15bd,0x6f0d15be,0x320515bf,0x3e740212}},	//   kläd, _avac, raly_, _mätt_,
   {{0x3e740222,0x320515c0,0xdee60613,0x649700e8}},	//   _lätt_, saly_, коми, rģis,
   {{0x443f15c1,0xab5b0103,0x10a315c2,0x320500d4}},	//   meu_, _szün, риян, paly_,
   {{0x6da615c3,0x443f15c4,0x644b15c5,0xaca40129}},	//   вига, leu_, _hagi, _mmụt,
   {{0x644b15c6,0x6f0d15c7,0x27ed042c,0x2907020a}},	//   _kagi, _evac, _ofen_, ânal_,
   {{0x443f0472,0x7f8600e3,0x7cdc009c,0x6f960037}},	//   neu_, _للبن, _cōra, _للعض,
   {{0x644b15c8,0x443f15c9,0x7c2b0013,0xeb9715ca}},	// [dc0] _magi, ieu_, ògra, вит_,
   {{0x644b15cb,0xaa7b003e,0x443f15cc,0xb05b15cd}},	//   _lagi, _stýr, heu_, smät,
   {{0xaca40129,0x6f0d028a,0xb05b00ce,0x00000000}},	//   _amụt, _zvac, mmär, --,
   {{0x644b15ce,0x63a40088,0xb05b15cf,0x7f56023b}},	//   _nagi, _þing, rläg, _kryq,
   {{0x443f15d0,0x27e015d1,0xb05b0212,0xbebb0052}},	//   deu_, žino_, släg, rtëv,
   {{0x7bc60b27,0x7c24013f,0xbebb023b,0xca760109}},	//   _izku, lgir, stëv, _румы,
   {{0x644b15d2,0x92de00c7,0xc5d500c7,0x443f15d3}},	//   _bagi, _তবে_, _স্বপ, feu_,
   {{0x7c24149c,0x38c803ed,0x443f0472,0x00000000}},	//   ngir, _سازی_, geu_, --,
   {{0x442615d4,0xb05b15d5,0xf2c615d6,0x225c01c8}},	//   _vco_, kmär, ксон, _pnvk_,
   {{0x78a215d7,0x649700ae,0x644b15d8,0x6f0d0344}},	//   lnov, rţia, _eagi, _rvac,
   {{0x443f15d9,0x644b15da,0x518615db,0x44260324}},	//   beu_, _fagi, тупа, _tco_,
   {{0x443f15dc,0x78a215dd,0x044615de,0x61f5008b}},	//   ceu_, nnov, _једн, ızla,
   {{0x6440026a,0x623415df,0x9f5902c3,0xadc40139}},	//   memi, _белу, kaså_, _ijẹu,
   {{0x644015e0,0x644b15e1,0x6497002d,0x7c240062}},	//   lemi, _zagi, nţin, egir,
   {{0x3e74070a,0x644b0ab1,0x7bc60634,0x7c3f013c}},	//   _rätt_, _yagi, _azku, teqr,
   {{0x644015e2,0x3e74070a,0x7c2415e3,0x6abd15e4}},	//   nemi, _sätt_, ggir, ्ग्र,
   {{0x4ea715e5,0x5a350fa5,0xb05b15e6,0xbebb023b}},	// [dd0] _арна, лнат, smäs, ftët,
   {{0x443f15e7,0x644015e8,0xdce70034,0x9b440018}},	//   zeu_, hemi, zyję, ؤنلو,
   {{0x391515e9,0x7bc601e9,0x83fd0103,0x443f15ea}},	//   умер, _ezku, rkőz, yeu_,
   {{0x2bae0f53,0x443f0428,0x78a215eb,0x28f8002d}},	//   _झुका, xeu_, gnov, тець_,
   {{0x644b15ec,0x443f15ed,0x291a028d,0x3e740212}},	//   _ragi, veu_, arpa_, _tätt_,
   {{0x644b15ee,0xe5a515ef,0x00000000,0x00000000}},	//   _sagi, лили, --, --,
   {{0x644b15f0,0x443f15f1,0x78a215f2,0x27ee02c6}},	//   _pagi, teu_, bnov, émní_,
   {{0x644015f3,0x69c715f4,0x332d03e5,0xfd5e0294}},	//   gemi, _izje, ttex_, _anyị,
   {{0x443f15f5,0xbebb023b,0x2cb90167,0x67d4002d}},	//   reu_, ntës, _mksd_, _воту,
   {{0x443f15f6,0x644b15f7,0xb63415f8,0x6d5700a7}},	//   seu_, _wagi, _نعمت, _orxa,
   {{0xab5b0068,0x644b15f9,0xe4e702ec,0x443f15fa}},	//   _szül, _tagi, _різн, peu_,
   {{0xa3550f43,0xc87900ae,0xbebb0052,0xa3ea0285}},	//   _مختص, _fişe_, ktës, _मलय_,
   {{0xbebb00dd,0x6d5715fb,0x6d41026a,0x9975007f}},	//   jtës, _arxa, çlan, nęła_,
   {{0x78a21271,0x539a0341,0xdee30b3b,0x00000000}},	//   znov, _אינו, сори, --,
   {{0x78a215fc,0x649700d3,0x7c2415fd,0x25eb00aa}},	//   ynov, nţio, tgir, _चलनी_,
   {{0xb05b007a,0xdd8f0037,0xb5fc009e,0xbebb0052}},	//   smär, سوق_, _inġe, ftës,
   {{0x78a215fe,0xb05b0149,0x69c700bd,0x5f46001c}},	// [de0] vnov, pmär, _azje, _صندل,
   {{0xddb60190,0x644015ff,0x7c241600,0x78a200d4}},	//   _محجب, zemi, sgir, wnov,
   {{0x64401601,0x7c24015e,0xdce801d3,0xaf36001c}},	//   yemi, pgir, ēlēt, _شرکت,
   {{0xe3a700bf,0x644001ff,0xd70a1602,0x66e61603}},	//   _هر_, xemi, енде_, года,
   {{0x78a2110e,0xb8eb048a,0x2bba00e3,0x7bc61604}},	//   rnov, _री_, _ساحة_, _uzku,
   {{0x09e30752,0xbebb0216,0x00000000,0x00000000}},	//   _горн, ltër, --, --,
   {{0x64400b88,0xafdb038c,0x3a2a02ef,0x649700ae}},	//   temi, ndør, _icbp_, rţin,
   {{0x649700d3,0x78a20146,0x00000000,0x00000000}},	//   sţin, čovs, --, --,
   {{0xb5fc0090,0xf2061605,0x6d580b18,0x88b300d1}},	//   _anġe, ляно, _šval, _اینچ,
   {{0x7ae61606,0x86c60037,0x67220138,0x64401607}},	//   _mukt, _صيان, muoj, semi,
   {{0x27e902dd,0x64401608,0x3cf80220,0x649700d3}},	//   žane_, pemi, jprv_, cţio,
   {{0xf993040a,0x649700d3,0x1fdf02d5,0x44ea01ec}},	//   מרת_, nţil, नखेड, _iù_,
   {{0x44ea1609,0x6722013f,0xf4870068,0x26de160a}},	//   _hù_, nuoj, _حالی, _kito_,
   {{0xc7b3028c,0x81d4160b,0xb05b160c,0x660a13d7}},	//   מבר_, _колх, fläc, nafk,
   {{0x629a160d,0x7ae6160e,0x44ea0649,0x6ca7160f}},	//   mito, _aukt, _jù_, граж,
   {{0x44ea1610,0x7ae6113a,0x26de1611,0x1f751612}},	//   _mù_, _bukt, _lito_, _влия,
   {{0x44ea0af0,0x26de0bfe,0x3a381613,0x60cd1614}},	// [df0] _lù_, _oito_, _bbrp_, _iham,
   {{0x44ea04ea,0x26de13b5,0x19591119,0x7ae61615}},	//   _où_, _nito_, казы_, _dukt,
   {{0x60cd1616,0x81b60081,0xbebb0052,0x660a008c}},	//   _kham, চের_, stës, dafk,
   {{0x26de1617,0x89340080,0xa56500cd,0x200b1618}},	//   _aito_, إعلا, یگان, naci_,
   {{0x629a1619,0xe758004d,0x67220138,0x26de0512}},	//   kito, лиці_, guoj, _bito_,
   {{0x44ea1610,0x629a161a,0x87040084,0x26de161b}},	//   _bù_, jito, сяце, _cito_,
   {{0x26de0256,0x200b161c,0x44ea161d,0x6f1d01bf}},	//   _dito_, kaci_, _cù_, hrsc,
   {{0x44ea161e,0x200b161f,0x7ae60113,0x26de0072}},	//   _dù_, jaci_, _yukt, _eito_,
   {{0x200b00e9,0x26de1114,0x6b8d1620,0x6283025b}},	//   daci_, _fito_, nzag, _plno,
   {{0x68e700dd,0x60cd1621,0x65950f2c,0x44ea1622}},	//   _kujd, _aham, _казу, _fù_,
   {{0x76431623,0x60cd009c,0x6f1d1624,0x649700ae}},	//   meny, _bham, ersc, lţim,
   {{0x60cd1625,0x200b1626,0x229b0139,0x236002ef}},	//   _cham, gaci_, _bákè_, _šije_,
   {{0x60cd1627,0xdee61628,0x6b8d015c,0xe3b31629}},	//   _dham, роги, jzag, _ارض_,
   {{0x76430517,0x78a90480,0x6288162a,0xe299162b}},	//   neny, _ljev, chdo, _шал_,
   {{0x7c96162c,0x7523162d,0x78bb0a15,0x6722013f}},	//   арац, nunz, _okuv, zuoj,
   {{0x7643162e,0x200b162f,0x60cd1630,0x32070167}},	//   heny, caci_, _gham, _heny_,
   {{0x76431631,0x4e1a0084,0x60d70341,0xbebb023b}},	// [e00] keny, _июня_, _דוקא_, rtër,
   {{0x75231632,0xef1f0103,0x61e300dc,0xda79004d}},	//   kunz, zzük_, _jgnl, ляє_,
   {{0x2bb80251,0x26de00a6,0xfe3700c1,0x76431633}},	//   _आडवा, _rito_, _דריי_, deny,
   {{0x26de0465,0x60cd1634,0x628801e5,0x629a1635}},	//   _sito_, _xham, zhdo, zito,
   {{0x78a90292,0x26de1636,0x44ea1637,0x629a1638}},	//   _djev, _pito_, _sù_, yito,
   {{0x75231639,0x7643163a,0x6722013f,0x629a0072}},	//   funz, geny, ruoj, xito,
   {{0x6d58163b,0x629a163c,0x321800a5,0x6722163d}},	//   _švaj, vito, órym_, suoj,
   {{0x7c360653,0x26de0051,0x629a163e,0x98a60a54}},	//   nfyr, _wito_, wito, _тибе,
   {{0x629a163f,0x76431640,0x26de1641,0x32071642}},	//   tito, beny, _tito_, _beny_,
   {{0x32071643,0x60cd1644,0xab5b0068,0x3eb802fe}},	//   _ceny_, _sham, _szük, jort_,
   {{0x60cd0060,0x68e0008e,0x6b8d1645,0x200b1646}},	//   _pham, _kimd, zzag, taci_,
   {{0x629a1647,0x66080044,0x859b00ca,0x6f0402a4}},	//   sito, _hedk, _בשבו, _bwic,
   {{0x3eb81648,0x2d9e1649,0x4fc70077,0x6f1d01cb}},	//   fort_, úten_, рсна, ursc,
   {{0x6f1d164a,0x61e3010a,0x660805db,0x92b30076}},	//   rrsc, _ggnl, _jedk, _وحوا,
   {{0xa3ea0454,0x60cd164b,0x200b164c,0xbc07164d}},	//   _मला_, _tham, paci_, ичай,
   {{0x60cd164e,0x320c06c2,0x3d180ccb,0x6b8d01e9}},	//   _uham, lady_, _फिरे_, tzag,
   {{0x2486022e,0xa3ca009d,0x7643164f,0x6f041650}},	// [e10] _mlom_, ळेच_, yeny, _gwic,
   {{0x78a90ea3,0x78bb12e8,0x6286023b,0x76430201}},	//   _sjev, _skuv, ëkoh, xeny,
   {{0x78a903c6,0xbebb00dd,0x27e40085,0x99670d69}},	//   _pjev, rrëd, _bgmn_, штал,
   {{0x76431651,0x320c0094,0x660801ff,0x254701f9}},	//   weny, hady_, _aedk, _ről_,
   {{0x62981030,0xa01b0364,0x78a904e9,0x7f4d02a1}},	//   _omvo, rhöh, _vjev, _jsaq,
   {{0x75231652,0x7bda00a1,0x24861653,0xa01b042c}},	//   tunz, _תקשו, _alom_, shöh,
   {{0x24861654,0x3207022b,0x76431655,0x66081656}},	//   _blom_, _reny_, reny, _dedk,
   {{0x76431657,0x68e0013f,0x78bb1658,0x75230875}},	//   seny, _gimd, _ukuv, runz,
   {{0x75231659,0x7643165a,0xb3d200c3,0x3207165b}},	//   sunz, peny, देलख, _peny_,
   {{0xf67400e3,0x75230193,0x25470103,0x6f040169}},	//   _والخ, punz, _től_, _rwic,
   {{0x3eb8165c,0xd00a165d,0x7f4d039f,0xb80b00aa}},	//   vort_, лене_, _asaq, _हजाम_,
   {{0x3eb802e2,0xb7bd002d,0x200900ae,0xb5fc00bd}},	//   wort_, _acţi, _ceai_, _inġa,
   {{0xd12e03ed,0x42d500d6,0x32070d5b,0x3eb8165e}},	//   ومی_, _ліку, _teny_, tort_,
   {{0x201e165f,0x2009009c,0x24861660,0x00000000}},	//   şti_, _eeai_, _zlom_, --,
   {{0x22451661,0x62811662,0x80f50037,0x3eb81663}},	//   melk_, mklo, _استض, rort_,
   {{0x27e00660,0xb05b1664,0x3eb81665,0x6f041666}},	//   žini_, llän, sort_, _twic,
   {{0x3eb81667,0x7c361668,0xcb671669,0x6f040079}},	// [e20] port_, rfyr, бате_, _uwic,
   {{0x34d300a5,0xb05b00a2,0xa96a166a,0x68e0166b}},	//   दगुद, nlän, лиза_, _simd,
   {{0x66080087,0x2b490188,0xb05b11d0,0x6281166c}},	//   _redk, awac_, ilän, iklo,
   {{0x0aea0037,0x00000000,0x00000000,0x00000000}},	//   _مرسي_, --, --, --,
   {{0x68fb166d,0xb05b02c3,0x628100f3,0x00000000}},	//   _čude, klän, kklo, --,
   {{0xfd650028,0x24860995,0x6281007e,0x00000000}},	//   _nguồ, _slom_, jklo, --,
   {{0x9986054f,0x27e902e6,0x5d7a00c1,0x660801df}},	//   _الأو, žana_, טאַק, _vedk,
   {{0x6608166e,0xa2f4166f,0x00000000,0x00000000}},	//   _wedk, опич, --, --,
   {{0xc44500cd,0xf3ef0037,0xd20a01b6,0x77860284}},	//   زیون_, رأي_, лэнд_, _улаз,
   {{0x273200d3,0xbae50033,0x9f52034f,0xcfce0033}},	//   mân_, _পৌঁছ, _leyó_, রখান,
   {{0x273200eb,0x320c1670,0x3abb0341,0xaabb006e}},	//   lân_, rady_, רמינ, רזיכ,
   {{0x320c1671,0x629d00fd,0x628105c2,0x00000000}},	//   sady_, ésor, aklo, --,
   {{0x320c1672,0x937a1673,0xdb0f0131,0x00000000}},	//   pady_, _حصار_, _excê, --,
   {{0x62811674,0xacf91675,0xddde022b,0x00000000}},	//   cklo, ингу_, _enpō, --,
   {{0x40350d47,0x273200f0,0x00000000,0x00000000}},	//   _дейс, hân_, --, --,
   {{0xce3300bf,0xa0a400c9,0xd0110068,0x7f4d005c}},	//   _کودک, _најд, _کلک_, _tsaq,
   {{0x3a75117c,0xf09f0428,0x00000000,0x00000000}},	// [e30] олар, mià_, --, --,
   {{0x9e071676,0xf09f05fe,0x2eb4007a,0x7aed01ee}},	//   _учил, lià_, ंकृत, rqat,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x50c91677,0xb0c91678,0x17fb0037,0xf09f015e}},	//   रतिष, रतिग, ارضة_, nià_,
   {{0x7aed0090,0x2ca91679,0x6281167a,0x00000000}},	//   qqat, mnad_, yklo, --,
   {{0x4519167b,0xf09f0036,0x2ca9167c,0x00000000}},	//   ация_, hià_, lnad_, --,
   {{0x20c9009d,0x224500e8,0x00000000,0x00000000}},	//   रताध, velk_, --, --,
   {{0x2ca9167d,0x236002ef,0x8339001f,0xf1c302c6}},	//   nnad_, _šija_, ачот_, _liší_,
   {{0xf09f0428,0x2d8c167e,0x649700ae,0xfdfb167f}},	//   dià_, údez_, nţii, ्रास_,
   {{0x2ca90150,0xe2990291,0x00000000,0x00000000}},	//   hnad_, рао_, --, --,
   {{0xb05b1680,0xe0461681,0x62811682,0xc66800c9}},	//   rlän, онни, rklo, _уште_,
   {{0x61fc07aa,0xb05b1683,0x7e65020b,0x00000000}},	//   ırla, slän, _anhp, --,
   {{0x3f841684,0x443d010a,0xb05b1489,0x2ca90b85}},	//   ámu_, _ibw_, plän, dnad_,
   {{0x7c2f1685,0x3f8c0034,0x248d1686,0x2eb41687}},	//   _accr, ądu_, lhem_, ंकेत,
   {{0xe7fc030b,0x3f840031,0xf09f00b3,0x1d0a0da5}},	//   उँमा_, šmu_, bià_, реби_,
   {{0x90c30d47,0x248d1688,0x9f5206a3,0xf09f0428}},	//   _обще, nhem_, _deyò_, cià_,
   {{0xdca303bf,0x8af70092,0xab2a1689,0x2d910036}},	// [e40] фати, _şəra, роза_, azze_,
   {{0xa01b168a,0x443d168b,0x4a430161,0x00000000}},	//   nkön, _lbw_, мнув, --,
   {{0x443d0283,0xdb060212,0x249f0063,0x3dcd03e3}},	//   _obw_, _nykö, kium_, ƙewa_,
   {{0x442f0042,0xab2a168c,0xd7f00076,0xa01b00ce}},	//   _ncg_, _кома_, ركت_, hkön,
   {{0x05260081,0x249f168d,0x649700ae,0xa01b168e}},	//   _মনের_, dium_, cţii, kkön,
   {{0x05760391,0x63a401b3,0x442f01b9,0x6d5e166d}},	//   قاعد, _žino, _acg_, _krpa,
   {{0x443d168f,0x442f0172,0x2907020a,0x38cb00d1}},	//   _bbw_, _bcg_, ânat_, _چاقی_,
   {{0x69ce1690,0x442f1691,0x7d7b006e,0x443d1692}},	//   _izbe, _ccg_, ינצו, _cbw_,
   {{0x926a1693,0xd7ef0037,0xb6a61694,0xe3af0018}},	//   арна_, _شكل_, _диал, ہری_,
   {{0xa5f70291,0x2ca00188,0xb5fc0090,0xdeb403e3}},	//   _међу_, hiid_, _inġo, ƙaƙa,
   {{0x2b420063,0xe3af015a,0xdb0f1695,0xf09f00b3}},	//   _lpkc_, فری_, _excè, tià_,
   {{0x248d1696,0x27e0005f,0x6e3e0063,0x442f0167}},	//   chem_, žinu_, _abpb, _gcg_,
   {{0x98b30995,0xf09f05fe,0x2ca00188,0x2ca905e8}},	//   žeća_, rià_, diid_, vnad_,
   {{0x69ce01c2,0x6d5e0167,0x626313c7,0x9f52022b}},	//   _ozbe, _brpa, _овча, _peyò_,
   {{0x2d850618,0x66cd0181,0xb05b09df,0x628a00ae}},	//   ále_, núka, lläm, _ilfo,
   {{0xbca50037,0x6d5e00c4,0x67221697,0x9f61020a}},	//   أمري, _drpa, kroj, ăpân_,
   {{0x2d850335,0x7de704a1,0x6d5e0270,0x2a781698}},	// [e50] šle_, _мінд, _erpa, _borb_,
   {{0x249f1699,0x6722169a,0x2a78169b,0x248d0a39}},	//   zium_, droj, _corb_, zhem_,
   {{0xdcef01d3,0x37f80134,0x5f74001c,0x2ca9169c}},	//   ēdēt, _ịkụz, _فایر, pnad_,
   {{0x2ca0008a,0x63ad003e,0x6497044c,0x22890206}},	//   ciid_, _þang, pţii, _múka_,
   {{0x69ce169d,0xae1f0abe,0xfc3f0032,0x648e01ec}},	//   _ezbe, _बयान_, _ibí_, _mùid,
   {{0x7bda00a1,0x442f169e,0x5b7a00d7,0x00000000}},	//   _לקרו, _scg_, _הרשא, --,
   {{0x442f0072,0xa8a7169f,0x20020034,0xb5fc0090}},	//   _pcg_, _драк, ybki_, _inġl,
   {{0x672203ce,0xddc70031,0x00000000,0x00000000}},	//   broj, rejň, --, --,
   {{0x248d0e53,0xf5590281,0xec7900fe,0x7c2d16a0}},	//   rhem_, _گلاب_, _độc_, igar,
   {{0x248d00dd,0x7c2d0150,0xc879026a,0x8af000a7}},	//   shem_, hgar, _hoş_, dvəl,
   {{0x63ad16a1,0x648e009c,0x7c2d0381,0x6b89007f}},	//   _žand, _bùid, kgar, _żegl,
   {{0x2eb60af1,0x628a0018,0xdb0f054e,0x443d02a4}},	//   ृत्त, _elfo, _excé, _ubw_,
   {{0xe28e08c3,0x44f100c9,0xb4b7009d,0x6d5e16a2}},	//   _за_, _há_, चकी_, _srpa,
   {{0x442d13c8,0x44f10d79,0x7c2d16a3,0xfc3f0065}},	//   lge_, _ká_, egar, _abí_,
   {{0x44f116a4,0x2ca001ff,0x648e01b9,0x442d041c}},	//   _já_, tiid_, _fùid, oge_,
   {{0x7c2d16a5,0x768f004d,0xb5fc0078,0x672216a6}},	//   ggar, _høyd, _anġl, yroj,
   {{0x44f116a7,0x442d16a8,0x20d200e3,0x2ca016a9}},	// [e60] _lá_, ige_, ráid_, riid_,
   {{0x7c2d01b5,0x39430085,0x20d20037,0x6d5e16aa}},	//   agar, _bpjs_, sáid_, _trpa,
   {{0x44f116ab,0xd7fa044b,0xc8790511,0x8e7b00ca}},	//   _ná_, бул_, _boş_, _הניה,
   {{0x672216ac,0xc87916ad,0x9f59037a,0x26c705db}},	//   troj, _coş_, casó_, elno_,
   {{0x27e00084,0x442d00a1,0x44f116ae,0x6d5c16af}},	//   äin_, dge_, _aá_, lvra,
   {{0x44f102b4,0x672216b0,0xa96a0114,0x442d16b1}},	//   _bá_, rroj, _лига_, ege_,
   {{0xd94316b2,0x44f116b3,0x6d5c16b4,0x9c831271}},	//   _пери, _cá_, nvra, ščev,
   {{0x44f116b5,0x442d16b6,0x7bc6010a,0xb4c806eb}},	//   _dá_, gge_, _kyku, ोगे_,
   {{0x68ee01ee,0x00000000,0x00000000,0x00000000}},	//   _hubd, --, --, --,
   {{0xaabe16b7,0x44f116b8,0x442d16b9,0x7c2d16ba}},	//   ्तिक, _fá_, age_, zgar,
   {{0x44f116bb,0x7c2d16bc,0x044616bd,0x442d0d2a}},	//   _gá_, ygar, _нежн, bge_,
   {{0x66cd0220,0x7c2d0188,0xc87900a7,0x78a200d4}},	//   núkn, xgar, _xoş_, niov,
   {{0xaabe11c6,0xb05b00c2,0xa01b042c,0x623416be}},	//   ्ताक, lläk, fhör, _желу,
   {{0x68fc00d9,0x1df80109,0x2ee50364,0xddc502c6}},	//   _otrd, зеры_, ölf_, _zahř,
   {{0x291c0068,0xd23b00a1,0xdb1d00b6,0x44f10023}},	//   ával_, _הגול, _vysí, _xá_,
   {{0x7c2d16bf,0xd13800c6,0xb4fb0266,0x5d5416c0}},	//   ugar, mtą_, מפלי, экст,
   {{0x7c2d16c1,0x649700ae,0x768f00d6,0x2918028d}},	// [e70] rgar, cţiu, _høye, _avra_,
   {{0x7c2d16c2,0x6ce700d6,0x1eea001c,0xd13816c3}},	//   sgar, _німе, _گویی_, otą_,
   {{0xd138013f,0x442d00f2,0xa01b00ce,0x00000000}},	//   ntą_, yge_, hköm, --,
   {{0x44f116c4,0x78a2028d,0xd1380138,0x6d450201}},	//   _rá_, giov, itą_, _ipha,
   {{0x29180831,0x2d8301b3,0xb8f4009f,0x44f116c5}},	//   _evra_, lyje_, _सी_, _sá_,
   {{0x44f116c6,0xd138013f,0x61ea0113,0xb05b16c7}},	//   _pá_, ktą_, _ngfl, rmäy,
   {{0x442d16c8,0x2d83013f,0xe61000b9,0x3f8216c9}},	//   tge_, nyje_, اشه_, zyku_,
   {{0x44f116ca,0x442d16cb,0x78a20244,0xb4b7058f}},	//   _vá_, uge_, ciov, चके_,
   {{0x44f10649,0x26c70146,0x68ee03e3,0xe78400ae}},	//   _wá_, plno_, _zubd, _пуфо,
   {{0x44f116cc,0x6d4516cd,0x442d01b5,0x7d1a0220}},	//   _tá_, _opha, sge_, átsk,
   {{0x6d45022e,0xbebb0052,0x7ae716ce,0x442d02c3}},	//   _npha, trën, _mijt, pge_,
   {{0xbe250081,0x6724015c,0x8fa600ae,0x7afd00bc}},	//   ম্মদ_, šije, даме, _otst,
   {{0x6d45019f,0x3ea312f7,0x7afd16cf,0x00000000}},	//   _apha, fijt_, _ntst, --,
   {{0xdd92015a,0xafdb00f2,0x6497020a,0x6d5c01fc}},	//   پور_, dfød, rţiu, tvra,
   {{0xdee316d0,0x7afd16d1,0xe810000d,0xed570636}},	//   тори, _atst, ारमा_, мор_,
   {{0x69da0396,0x68ee01c2,0x291c0031,0x25fd0096}},	//   _útei, _rubd, ávam_, रुती_,
   {{0x60c416d2,0x7ae716d3,0x6d450201,0xab5b0103}},	// [e80] _ikim, _bijt, _epha, _szür,
   {{0x7bc616d4,0xab5b0018,0x68ee16d5,0x00000000}},	//   _vyku, _gyüm, _pubd, --,
   {{0xceb30130,0xbebb023b,0x994a08ba,0x6abe042c}},	//   _ביז_, ytëz, تلال_, ropf,
   {{0x7aef020a,0x672b150c,0xb4b700b6,0xcb6a02e1}},	//   _fuct, fugj, चको_, _даме_,
   {{0x78a216d6,0x3b040139,0x7bc6026a,0x60c40a4b}},	//   riov, _dépò_, _uyku, _mkim,
   {{0xd13816d7,0xa92616d8,0x6b840027,0x6eeb02a1}},	//   ytą_, _одгл, myig, _użbe,
   {{0x98a616d9,0x25070103,0x68fc0117,0x60c40361}},	//   _живе, ورٹی_, _utrd, _okim,
   {{0x3d110336,0x60c416da,0x399b00ca,0xb05b02c3}},	//   _तबसे_, _nkim, _וילד, rläk,
   {{0x6b8416db,0x752a01c2,0xa2ac0285,0xb05b02c3}},	//   nyig, sufz, ीकल्, släk,
   {{0x60c416dc,0x325416dd,0xa01b042c,0x32050f5a}},	//   _akim, хвор, rköm, gbly_,
   {{0xaca40174,0x60f8097a,0xb05b007b,0x403516de}},	//   _anọt, яння_, lläi, ненс,
   {{0xd13816df,0x60d602ad,0x2d8300c6,0xeb9f00f3}},	//   rtą_, _chym, vyje_, _edøy_,
   {{0xd13816e0,0x6497044c,0x00000000,0x00000000}},	//   stą_, rţit, --, --,
   {{0x60c416e1,0x2bd516e2,0x2d83013f,0xd1380138}},	//   _ekim, _दरबा, tyje_, ptą_,
   {{0x7aef16e3,0x68fb15f4,0x6d5816e4,0x7ae701c0}},	//   _suct, _čudo, _švar, _rijt,
   {{0x96140081,0x2d83013f,0xbf35004d,0x8f3500d3}},	//   সলিম_, ryje_, _знищ, _зеиц,
   {{0x3f4f03e5,0x7ebf00b6,0x3ea3029a,0x92c20033}},	// [e90] _użu_, tápě, pijt_, ্দী_,
   {{0xdddc00cc,0x2d830138,0x6f0d0193,0x2fc900f9}},	//   skrš, pyje_, _iwac, _iyag_,
   {{0x6d450201,0x6b8406b0,0xb05b007b,0x00000000}},	//   _upha, ayig, eläi, --,
   {{0xc8790702,0x386911ce,0x6f0d16e5,0x80d10081}},	//   _kişi_, ñar_, _kwac, _সূত্,
   {{0x59d41349,0x7afd0578,0xfc3f0103,0x366916e6}},	//   _थरथर, _utst, _amíg_, зало_,
   {{0x644216e7,0xaa450084,0x6288029a,0x6f0d08cc}},	//   _aboi, ävää_, jkdo, _mwac,
   {{0xaabe15e4,0xa2c200aa,0xafdb0120,0x00000000}},	//   ्तरक, रकन्, rdøy, --,
   {{0xa3ba09d0,0x3ea100fe,0xf9920327,0x6f0d16e8}},	//   _आँख_, _lmht_, _ערן_, _owac,
   {{0x27ed16e9,0x6f0d01c2,0x6442009c,0x60d616ea}},	//   _igen_, _nwac, _dboi, _rhym,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68e90067,0x21690636,0x320516eb,0x6442009c}},	//   _kied, чини_, rbly_, _fboi,
   {{0x2280022b,0x6f0d02a4,0x64420139,0xc8790233}},	//   _bòks_, _bwac, _gboi, _bişi_,
   {{0x68e916ec,0x6f0d010a,0x443f16ed,0x6497020a}},	//   _mied, _cwac, mfu_, bţir,
   {{0x52390130,0x443f16ee,0x68e916ef,0x6459008a}},	//   _זײַנ, lfu_, _lied, _hawi,
   {{0xfaff01e5,0x645916f0,0x27ed0126,0x7bcb01bf}},	//   _atë_, _kawi, _ogen_, ügun,
   {{0x68e916f1,0x63a4013f,0x60c40010,0xfa090033}},	//   _nied, _žini, _ukim, _লাগল_,
   {{0x6d410b88,0x64590010,0xfc3f0065,0x443f0051}},	// [ea0] çlar, _mawi, _ajís_, ifu_,
   {{0x27ed048e,0x6b840169,0x248f030a,0x00000000}},	//   _agen_, ryig, _llgm_, --,
   {{0x68e916f2,0x35c4009f,0xdb1d0146,0xd7fa002d}},	//   _bied, _लुढ़, _vysá, пул_,
   {{0x7e7e057e,0x645900a5,0xb5fc0078,0x645b044c}},	//   _hopp, _nawi, _inġi, jdui,
   {{0x7e7e16f3,0x175400c2,0xe7c00033,0xd7071102}},	//   _kopp, твля, েশ্য, енче_,
   {{0x20120065,0x27ed16f4,0x443f061f,0x7e7e16f5}},	//   _leyi_, _egen_, efu_, _jopp,
   {{0x80d100c7,0x443f16f6,0x7e7e16f7,0x6abe16f8}},	//   _সংস্, ffu_, _mopp, ्तीर,
   {{0x7e7e16f9,0xd49716fa,0x63ad16fb,0x68e916fc}},	//   _lopp, ерь_, _žana, _gied,
   {{0x645916fd,0x82a60ae3,0x7e7e16fe,0x2b52020b}},	//   _dawi, ешне, _oopp, nwyc_,
   {{0x68e900d9,0x20120139,0x443f16ff,0x07a30d9b}},	//   _zied, _aeyi_, afu_, _саун,
   {{0x7d0900e7,0x13ea00ae,0x3ce10096,0x644201b9}},	//   ćesk, _емей_, _कळले_, _tboi,
   {{0x64590256,0x765a0063,0x6abe0d7e,0x6f0d0154}},	//   _gawi, _haty, ्तुर, _pwac,
   {{0x765a1700,0x6d58007e,0x768f004d,0x00000000}},	//   _katy, _švap, _høya, --,
   {{0x64590067,0xa6e700de,0x7e7e0dfc,0xdc030e43}},	//   _zawi, _nhữ, _copp, rčík,
   {{0xb810110f,0x7e7e1701,0x765a1702,0x20d20037}},	//   ाराम_, _dopp, _maty, máin_,
   {{0x765a0ee8,0x20d20037,0x6ca41703,0x6f0d0079}},	//   _laty, láin_, груж, _twac,
   {{0x68e91704,0xfaf30018,0x7e7e1705,0x5a350e3a}},	// [eb0] _ried, اثر_, _fopp, кнат,
   {{0x765a1706,0x68e91707,0x645b00ae,0x20d20037}},	//   _naty, _sied, zdui, náin_,
   {{0x68e91708,0x394705fe,0x48151612,0x5e9c00ca}},	//   _pied, ïns_, вмес, _מבזק,
   {{0x20d2054f,0x26c5025b,0xe0df1709,0x7e7e028d}},	//   háin_, _sklo_, nmò_, _zopp,
   {{0x6459170a,0x68e9170b,0x765a170c,0x20d90037}},	//   _rawi, _vied, _baty, méid_,
   {{0x68e9170d,0x6459170e,0x945d00a5,0x20d90037}},	//   _wied, _sawi, końc, léid_,
   {{0x68e902fd,0x6459170f,0x443f1710,0x20d20037}},	//   _tied, _pawi, tfu_, dáin_,
   {{0x67241711,0x27ed052f,0x20d90076,0x929d007f}},	//   šija, _ugen_, néid_, dpła,
   {{0x645b1712,0xe2990aa8,0x443f1713,0x23db00c3}},	//   rdui, дап_, rfu_, मेंद,
   {{0x64590010,0x09e50081,0x765a1714,0x645b1715}},	//   _wawi, _প্যা, _gaty, sdui,
   {{0x81c90f71,0x20120c3e,0x64591716,0x443f0193}},	//   লেন_, _peyi_, _tawi, pfu_,
   {{0x387f04ea,0x7e0a007d,0x7e7e1717,0xa3ba152c}},	//   _jour_, वर्ग_, _sopp, _आँच_,
   {{0xa4d402ec,0x80d10081,0x087600c1,0x6d570188}},	//   _соці, _সংশ্, דערט_, _asxa,
   {{0x9f9e0396,0x20d2109d,0xe0df028d,0x387f022b}},	//   _ação_, cáin_, amò_, _lour_,
   {{0x2d8c1718,0x71640037,0x00000000,0x00000000}},	//   áde_, _مايك, --, --,
   {{0x09b00081,0xeaed055c,0x6495033c,0x00000000}},	//   _করলা, जदूत_, _dáig, --,
   {{0x7e7e0b97,0xf4120130,0xfce31719,0x69d5171a}},	// [ec0] _topp, יפן_, рото, _azze,
   {{0x386d01df,0xdee6171b,0x3ceb0027,0x8a03171c}},	//   _aner_, _шопи, _eicv_, изуе,
   {{0x386d171d,0xceb902c6,0x64950e43,0x00000000}},	//   _bner_, éře_, _káid, --,
   {{0x387f0257,0x765a171e,0x20d90076,0xb05b02db}},	//   _cour_, _saty, céid_, bläu,
   {{0x765a013f,0x69d50018,0x387f171f,0x929d0034}},	//   _paty, _ezze, _dour_, zpła,
   {{0x6f020b88,0x649500e3,0x648e01b9,0x96341720}},	//   _çocu, _láid, _cùin, ункц,
   {{0x64b300d3,0xc60b0081,0x387f1721,0xfaa31722}},	//   răin, _রাখা_, _four_, _таро,
   {{0xb4cc009d,0x00000000,0x00000000,0x00000000}},	//   ळते_, --, --, --,
   {{0x20d20037,0xd2500037,0x00000000,0x00000000}},	//   táin_, منة_, --, --,
   {{0x7c2900d9,0x38bc00d4,0x69da00d4,0x42740c3f}},	//   _ķerm, víry_, _útes, угос,
   {{0x387f1723,0x63ad0102,0x20d20037,0xe13400c6}},	//   _your_, _þann, ráin_, ынны,
   {{0x20d20080,0x63a401b3,0x2ebd0f62,0x66181724}},	//   sáin_, _žinu, ोत्त, lavk,
   {{0xe0df0451,0x20d20076,0x909800e5,0x6495033c}},	//   rmò_, máil_, твят_, _dáid,
   {{0x44f80d79,0x395802ef,0x6fe901d3,0x20d20076}},	//   _ké_, _osrs_, _rīcī, láil_,
   {{0x44f80649,0x395800e7,0x9c830094,0x3ead00c4}},	//   _jé_, _nsrs_, áčov, đet_,
   {{0x44f81725,0x273b00ef,0x80d10033,0x23661726}},	//   _mé_, yên_, _সূর্, _kroj_,
   {{0x44f802b4,0x20191727,0x1af41728,0x661800d8}},	// [ed0] _lé_, masi_, иптя, kavk,
   {{0x20d20080,0x7e5500d6,0x44f80037,0xb05b0364}},	//   háil_, _своє, _oé_, rläu,
   {{0x387f1729,0x6618025b,0x20d900e3,0x69c80856}},	//   _pour_, davk, péid_, _ødel,
   {{0xdb1d00c2,0xb4cc0096,0x5c0400e5,0x00000000}},	//   _pysä, ळतो_, _вяра, --,
   {{0xfeb8172a,0x9cd60c6a,0x20d200e3,0x2366022e}},	//   _سایت_, _תורה_, dáil_, _nroj_,
   {{0x44f8172b,0x2ca902ad,0x2019172c,0x25570092}},	//   _bé_, liad_, hasi_, _hələ_,
   {{0x2019172d,0x44f80080,0x888300bf,0x387f172e}},	//   kasi_, _cé_, _پیشن, _tour_,
   {{0x236600e9,0x44f8172f,0x20d20080,0x2ca902ad}},	//   _broj_, _dé_, gáil_, niad_,
   {{0x66181100,0x69da00b6,0xb5fc02a1,0x44f80af0}},	//   bavk, _úter, _anġu, _eé_,
   {{0x44f80649,0x2019002d,0x2ca900f0,0x6f1d1730}},	//   _fé_, easi_, hiad_, dssc,
   {{0x2019068d,0x44f80649,0xa29f0006,0x23660078}},	//   fasi_, _gé_, गोष्, _eroj_,
   {{0x20191731,0x20d200e3,0x68f51732,0x27e909ac}},	//   gasi_, cáil_, _muzd, žanu_,
   {{0x32450636,0x2ca902e0,0x44f80161,0x23661733}},	//   _белг, diad_, _zé_, _groj_,
   {{0xed5a15de,0x248d030b,0x44f8026e,0xf2070686}},	//   ног_, lkem_, _yé_, _рядо,
   {{0x2ca902ad,0x20191734,0x68f500cc,0x2b4b00b3}},	//   fiad_, basi_, _nuzd, _apcc_,
   {{0x6abe0c38,0x2ca902ad,0x7d1c0161,0x20191735}},	//   ्त्र, giad_, rsrs, casi_,
   {{0xab661736,0xab270818,0xb05b0212,0xceb60dce}},	// [ee0] ывал, лота_, rlät, _محدث,
   {{0x248d0006,0x68f51737,0xed5a11cc,0xb8650d7f}},	//   hkem_, _buzd, _зоо_, یانو,
   {{0xb05b01bf,0x248d1738,0x648e009c,0xdca6079c}},	//   plät, kkem_, _bùil, _бани,
   {{0x44f81739,0xb05b173a,0x648e01b9,0x3958033b}},	//   _ré_, llär, _cùil, _vsrs_,
   {{0x44f8173b,0x248d00b6,0x76430167,0x648e01ec}},	//   _sé_, dkem_, ffny, _dùil,
   {{0x44f802b4,0x4ab8000c,0x248d01c0,0x2019173c}},	//   _pé_, _आदिव, ekem_, zasi_,
   {{0x20190f28,0x20d20080,0x2b40173d,0x60c603a9}},	//   yasi_, táil_, ltic_, kokm,
   {{0x6f040ca7,0x44f80019,0x2366173e,0x768f00f3}},	//   _otic, _vé_, _proj_, _høyl,
   {{0x36360241,0x20190498,0xe80a02e8,0x20d20080}},	//   _مراس, vasi_, _ह्या_, ráil_,
   {{0x44f8173f,0x20191740,0xfaff023b,0x20d200e3}},	//   _té_, wasi_, _orën_, sáil_,
   {{0xe3af09e5,0x6f041741,0x44f8016d,0x32630138}},	//   قری_, _atic, _ué_, стыв,
   {{0x68e21742,0x6f1d1743,0x6f040036,0x248d1744}},	//   nmod, tssc, _btic, ckem_,
   {{0xb4c005d4,0xb4c202e8,0x2366023b,0x6f1d042c}},	//   ंकी_, ृती_, _uroj_, ussc,
   {{0x20191745,0x25630b88,0x2ca9053c,0x3eaa0364}},	//   sasi_, _yıl_, wiad_, gibt_,
   {{0x6f040977,0x20190da3,0xdd940077,0x69ce0073}},	//   _etic, pasi_, бары, _nybe,
   {{0xb05b160c,0x2b4000e7,0x201911bc,0x2b4b015e}},	//   rläs, ftic_, qasi_, _ppcc_,
   {{0x2ca91746,0x68f51747,0xddde0154,0xb05b03bd}},	// [ef0] riad_, _suzd, _lapň, släs,
   {{0x69ce0665,0x2ca90150,0x8f9c00c1,0x68f50031}},	//   _bybe, siad_, _ריזי, _puzd,
   {{0x81e60033,0xb9b50cc8,0x2ca91748,0x7aee01ee}},	//   যুর_, جماع, piad_, _dibt,
   {{0x69ce02b6,0x2137006e,0x76481749,0x00000000}},	//   _dybe, רטאל_, _abdy, --,
   {{0x6568174a,0x2b40174b,0xdc360130,0x648e009c}},	//   _ardh, ctic_, _דארט_, _cùim,
   {{0x7aee01bf,0x83fd0018,0x68f5174c,0xab6601d3}},	//   _gibt, zdőd, _tuzd, _daļē,
   {{0x248d174d,0xd6180037,0x291c00b6,0x68e20131}},	//   tkem_, اتها_, ávat_, bmod,
   {{0x032508c3,0x06b102c6,0x693400d3,0xc485174e}},	//   адин, _řídí_, _ынсу, рлик,
   {{0x656800dd,0xc6140081,0x67d4004d,0x248d174f}},	//   _erdh, _সারা_, _готу, rkem_,
   {{0x78ab038c,0x248d1750,0x64870314,0x2d9c01f9}},	//   ligv, skem_, _añit, _üveg_,
   {{0xe0da1751,0x26c71752,0x39411753,0x6f041754}},	//   кво_, mono_, nths_, _stic,
   {{0xaca30134,0x6e250013,0x26c71755,0x78ab1570}},	//   _brọd, _adhb, lono_, nigv,
   {{0xe28e1756,0xa3e91757,0x7d050037,0xa85600ca}},	//   _да_, _मणि_, _aths, בירה_,
   {{0x91e51758,0x26c70517,0x539a00a1,0x11670103}},	//   _коле, nono_, _בינו, _ملتی_,
   {{0xb05b07ee,0x26c700e5,0x5fd80096,0x68e200eb}},	//   rlär, iono_, _ठरवल, ymod,
   {{0xdd8f0bf4,0x62831759,0x26c7019f,0x69ce0ecb}},	//   ذوق_, _hono, hono_, _rybe,
   {{0x26c7175a,0x6f04175b,0x78ab02b6,0x68e2175c}},	// [f00] kono_, _utic, digv, vmod,
   {{0x26c7013f,0x2b40175d,0xa01b175e,0x6283175f}},	//   jono_, rtic_, sköt, _jono,
   {{0x2b401760,0x6283028d,0xd83a01b6,0x26c7008f}},	//   stic_, _mono, вэл_, dono_,
   {{0x2b401761,0x69ce0074,0x7e030174,0xa01b1762}},	//   ptic_, _vybe, ọstu, lkör,
   {{0x26c71763,0xbebb00dd,0x76940139,0x62830167}},	//   fono_, rrëv, _aàya, _oono,
   {{0x62831764,0x68e20429,0x69ce1765,0xafdb01df}},	//   _nono, smod, _tybe, dføl,
   {{0xa3e302d5,0x68e21766,0xa01b0212,0x768f00f3}},	//   फेस_, pmod, ljöe, _gøym,
   {{0xd7061612,0x260604f1,0x776901ff,0x6283033c}},	//   _взаи, _स्री_, _frex, _aono,
   {{0xf74900cd,0xa2c2009d,0x26c70201,0x389b0796}},	//   _مجله_, रकल्, bono_, _סימנ,
   {{0x62831767,0x26c71768,0x20d90231,0x00000000}},	//   _cono, cono_, déia_, --,
   {{0x62831769,0x7c26176a,0xd48f176b,0x99f70054}},	//   _dono, _odkr, _др_, יזיה_,
   {{0xdcee013f,0x75d3001c,0xb97b00ca,0xdb1d0206}},	//   mybė, _بيما, דנטי, _vysú,
   {{0x4426176c,0x6283176d,0xe3b20241,0xbfa8176e}},	//   _ido_, _fono, _برا_, атре_,
   {{0x6283176f,0x00000000,0x00000000,0x00000000}},	//   _gono, --, --, --,
   {{0x44261770,0xdcee0138,0x57d30085,0xb5fc00bd}},	//   _kdo_, nybė, _तर्ह, _gaġe,
   {{0x30150161,0x26c71771,0x80d10081,0x27e00146}},	//   _удир, zono_, _সংক্, žiny_,
   {{0x60cd1772,0x26c70510,0x44260a4b,0x6d480233}},	// [f10] _ikam, yono_, _mdo_, çdar,
   {{0x99671773,0xdcee0138,0x3b0900a7,0x44260231}},	//   ител, kybė, rpaq_, _ldo_,
   {{0xd366172a,0x44261774,0x161a0067,0x26c7013d}},	//   _که_, _odo_, _नज़र_, vono_,
   {{0x776908a8,0xa3cc0179,0x44261775,0xb4c0030b}},	//   _prex, _शुभ_, _ndo_, ंको_,
   {{0x26c71776,0x60cd0239,0xc7b901f9,0xcc761777}},	//   tono_, _mkam, _idők_, _הערה_,
   {{0xc9871778,0x6b8d1779,0x2bb40176,0x00000000}},	//   _куби, myag, ंपरा, --,
   {{0x09e50f71,0x99850080,0x1a6800bf,0x60cd025b}},	//   _প্রা, _الزو, _خیلی_, _okam,
   {{0x442600dd,0xa8a4013a,0xe570177a,0x26c7177b}},	//   _cdo_, _друк, بطه_, sono_,
   {{0x6b8d177c,0x26c7177d,0x4426177e,0x78a9177f}},	//   nyag, pono_, _ddo_, _imev,
   {{0x60cd1652,0x44261780,0x81c200c7,0xafdb038c}},	//   _akam, _edo_, ্ধন_, rføl,
   {{0x62831781,0xb5a71782,0xa01b02c3,0x00000000}},	//   _vono, _трай, vkör, --,
   {{0x656e054f,0x62831783,0x160b1784,0xafdb004d}},	//   _ábha, _wono, _स्तर_, pføl,
   {{0xafdb01c5,0x80d10081,0x23291785,0x443d0167}},	//   lføj, _সংখ্, _соли_, _icw_,
   {{0x629a1786,0xb05b0212,0xe3b000b9,0x60cd019f}},	//   chto, släp, _ترم_, _ekam,
   {{0x7c961787,0x753c01bf,0x69a700af,0xa01b1788}},	//   брац, _ärzt, _टेली, rkör,
   {{0xa9240220,0x20d91789,0xa01b178a,0xa5c3007f}},	//   _úžit, péia_, skör, ciół,
   {{0xc9f600e3,0x09e50081,0xa01b0ee2,0x6b8d178b}},	// [f20] مساع, _প্লা, pkör, gyag,
   {{0xe810178c,0x2bac0096,0x78a90a58,0x7810178d}},	//   ार्थ_, _घेणा, _amev, ार्क_,
   {{0x81c90f71,0x443d178e,0x997c00e8,0x6b8d06b0}},	//   লের_, _ocw_, sāža_, ayag,
   {{0xa01b0149,0x443d178f,0xdcee0138,0xe81a1790}},	//   nköp, _ncw_, vybė, ازات_,
   {{0x20020d62,0x649c0076,0xb8650452,0x442605db}},	//   icki_, _héig, تالو, _rdo_,
   {{0xa01b02fd,0xdcee013f,0xb4c200aa,0x44261791}},	//   hköp, tybė, ृत्_, _sdo_,
   {{0x2bac0096,0xeae40c8c,0x25e31792,0xdcfc00c6}},	//   _घेता, कगीत_, टेली_, tyrę,
   {{0x69dc1793,0x44261794,0xdcee0138,0x836607e8}},	//   _izre, _qdo_, rybė, مدخل,
   {{0x442604de,0x57fb00f5,0x649c00e3,0xa01b0212}},	//   _vdo_, _תלמו, _léig, dköp,
   {{0x60cd1795,0x6d5e1796,0x32180181,0xe810030b}},	//   _skam, _ospa, úry_, ारका_,
   {{0x44261797,0x672201d3,0xa055004d,0x38cb0103}},	//   _tdo_, lsoj, овні, _شاہی_,
   {{0x55770130,0x44261798,0x661a0d80,0x629a00dd}},	//   _לעבן_, _udo_, _hetk, shto,
   {{0x2d8c0430,0x661a007b,0x09c50096,0x7cef0065}},	//   øden_, _ketk, _वड्य, _lòrì,
   {{0x2486022e,0x69dc015c,0x2002052f,0x768f004d}},	//   _hoom_, _ozre, acki_, _røyk,
   {{0x248601bb,0x321e1799,0xdd94004b,0x64950076}},	//   _koom_, maty_, пары, _máin,
   {{0x60cd179a,0x6b8d179b,0x6722179c,0x661a179d}},	//   _ukam, tyag, ksoj, _letk,
   {{0x6d5e179e,0xfbd3012b,0x69dc00dc,0x6f1600f0}},	// [f30] _espa, ستر_, _azre, _gwyc,
   {{0x661a179f,0xbebb023b,0x6b8d0079,0x321e007f}},	//   _netk, rrës, ryag, naty_,
   {{0x6f160034,0x2bd50fef,0x2907023b,0x625e02a1}},	//   _zwyc, _दरका, ëna_, _għoż,
   {{0x2486022e,0x290701d3,0x7cef0139,0x66cd04c8}},	//   _noom_, īna_, _dòrì, júkr,
   {{0xf1cf0251,0x41cf030b,0x201b0167,0x321e0034}},	//   _सुनन, _सुनस, _meqi_, katy_,
   {{0x661a00cc,0x443d008a,0x57a90096,0x7bdd17a0}},	//   _cetk, _scw_, _कधीह, _izsu,
   {{0x78bb05e8,0x7d020031,0xe8100096,0x24860d63}},	//   _tjuv, _čosk, ारखा_, _boom_,
   {{0x6298038c,0x6722023e,0x661a1030,0x649c033c}},	//   _alvo, bsoj, _eetk, _néid,
   {{0x254e00a7,0x64950037,0x20d917a1,0x248617a2}},	//   _cəlb_, _fáin, téin_, _doom_,
   {{0x52a900c2,0x81bd0033,0x31250095,0x321e17a3}},	//   рвом_, _আরব_, одог, gaty_,
   {{0x2486006c,0x649c033c,0x00000000,0x00000000}},	//   _foom_, _béid, --, --,
   {{0x649c0076,0xa9110789,0x7de00065,0x248600fc}},	//   _réig, डीएफ_, _lásí, _goom_,
   {{0x661a0587,0x321e17a4,0x649c036b,0x2d8517a5}},	//   _yetk, baty_, _déid, älen_,
   {{0x216917a6,0x644917a7,0xfc3f0428,0xddde00ae}},	//   _вики_, lfei, _ací_, _nopţ,
   {{0x649c054f,0x6724003d,0xed5a17a8,0xf8c90c22}},	//   _féid, ġiji, шов_, िकाय,
   {{0x248617a9,0x2fc001fa,0x644910f4,0x672400cc}},	//   _xoom_, _txig_, nfei, šiji,
   {{0x6d5e00a5,0xbb4317aa,0x4aaa169f,0xbbb400a4}},	// [f40] _wspa, метк, акан_, ंपेक,
   {{0x649c00e3,0x1ae317ab,0x00000000,0x00000000}},	//   _téig, доум, --, --,
   {{0x661a17ac,0x7de00065,0xa01b0212,0xa96700e5}},	//   _retk, _dásí, ljöa, жиха_,
   {{0x50ca00a5,0x661a17ad,0x20ca030b,0x672200c2}},	//   रविष, _setk, रविध, tsoj,
   {{0x661a03f1,0x248600a1,0xe8e00023,0x6756046b}},	//   _petk, _room_, hiệt_, تخار,
   {{0x248617ae,0x2a6302ef,0x6d5c01ee,0x6b8b0212}},	//   _soom_, _gajb_, owra, ägge,
   {{0xd49a11d9,0x248617af,0x661a17b0,0x69dc01d3}},	//   ири_, _poom_, _vetk, _uzre,
   {{0xb19800de,0x734a00d3,0x672d17b1,0xe9d7004d}},	//   _ngưỡ, ачов_, šaja, _єкт_,
   {{0x68fc17b2,0x61ef0092,0x649c0037,0x160b09c4}},	//   _hurd, əklə, _réid, _स्वर_,
   {{0x68fc17b3,0x386617b4,0x649500da,0x00000000}},	//   _kurd, ldor_, _háil, --,
   {{0xe45a02ec,0x2486022e,0x321e17b5,0x7f4417b6}},	//   _вже_, _toom_, raty_, _aqiq,
   {{0x68fc17b7,0x92ca0081,0x765817b8,0x290a02ef}},	//   _murd, লগে_, levy, _mtba_,
   {{0x610100d9,0x91ca02d5,0x270c0033,0x321e12b1}},	//   _vēla, _सुरै, _হয়তো_, paty_,
   {{0x81c90081,0x76580051,0x809f0034,0xbbb40096}},	//   লেই_, nevy, खोजे, ंपैक,
   {{0xbd6817b9,0x009500ae,0x00000000,0x00000000}},	//   орте_, _никэ, --, --,
   {{0x90c407c8,0x90e7001c,0x64950231,0x76580027}},	//   _обје, _بستن, _náil, hevy,
   {{0x1eab00e3,0x7bc10034,0x386617ba,0xe0d00d7f}},	// [f50] _نادي_, _ślub, ddor_, _جزو_,
   {{0x1b040033,0x68fc17bb,0x291803a8,0x00000000}},	//   _লিখে_, _burd, _bwra_, --,
   {{0xad2700cd,0xa907015a,0x68fc17bc,0xe9f8004d}},	//   _برخو, زبان, _curd, інці_,
   {{0xe8f8059b,0x649500e3,0x68fc17bd,0x6d45019f}},	//   ілі_, _cáil, _durd, _iqha,
   {{0xb902007d,0xcb4400c9,0x6d4717be,0x7d0200e7}},	//   _नी_, _охри, ltja, _čosi,
   {{0x7afd17bf,0x8afa00ca,0x24670023,0x68fc17c0}},	//   _iust, _להשי, _ốm_, _furd,
   {{0xceb40130,0x6d4717c1,0x855700d0,0x649500e3}},	//   ויס_, ntja, تیار_, _fáil,
   {{0x7af50a00,0x81c20033,0x00000000,0x00000000}},	//   _hizt, ্ধা_, --, --,
   {{0x644917c2,0xe3b100e3,0x68fc1186,0x26060285}},	//   rfei, عرب_, _zurd, _स्की_,
   {{0x644917c3,0x68fc03e0,0x6d5c17c4,0xe2990291}},	//   sfei, _yurd, ywra, сао_,
   {{0x68fc08a8,0xa06a17c5,0x76b20034,0xc692021e}},	//   _xurd, бана_, słyc, _ראב_,
   {{0x7b090031,0x7af501c8,0x69d50216,0x00000000}},	//   _kľud, _lizt, _myze, --,
   {{0x7afd01b3,0xb4c9009d,0x3f8f003d,0xbf9b016d}},	//   _nust, ोती_, _żgur_, scên,
   {{0x91fc01d3,0x649c0503,0x00000000,0x00000000}},	//   ndāl, _géib, --, --,
   {{0x7c96013a,0x649500e3,0xfce60f94,0xe7eb09c4}},	//   прац, _láim, зово, जेता_,
   {{0x249f00c9,0x7afd17c6,0xa3e2007a,0x7af500d9}},	//   nhum_, _bust, _धरम_, _aizt,
   {{0x7af517c7,0x7afd17c8,0x649c033c,0x7d1b02ef}},	// [f60] _bizt, _cust, _héic, ćusa,
   {{0x7afd17c9,0x5cf600ae,0x00000000,0x00000000}},	//   _dust, _няму, --, --,
   {{0x7afd01e9,0x68fc00a7,0x7af501ff,0x3ddf01c2}},	//   _eust, _qurd, _dizt, ƙuwa_,
   {{0x7afd17ca,0x68fc13c8,0x20d217cb,0x69d517cc}},	//   _fust, _vurd, máis_, _dyze,
   {{0x7afd17cd,0x68fc02d6,0x672d0106,0x386617ce}},	//   _gust, _wurd, šajn, rdor_,
   {{0x68fc17cf,0x648e009c,0x2d87015e,0x442017d0}},	//   _turd, _lùit, _ànec_, _ži_,
   {{0x7afd17d1,0x64950037,0x321c17d2,0xddc7007f}},	//   _zust, _táil, _revy_, dejś,
   {{0x2ca006a8,0x7de70018,0xf7461602,0x957c0034}},	//   nhid_, lésé, _небо, _rząd,
   {{0x7afd0933,0xa78607e8,0x00000000,0x00000000}},	//   _xust, _عشرو, --, --,
   {{0xcb1300ca,0x610100e8,0x7de701f9,0x649c0503}},	//   עלת_, _cēlo, nésé, _béic,
   {{0xa3cc007d,0x40350606,0xfbc40081,0x59be17d3}},	//   _शुर_, менс, ্ধিত, ्थिर,
   {{0x7bc300ae,0x249f17d4,0x92ac0033,0x20d217d5}},	//   şnui, chum_, ককে_, dáis_,
   {{0xcb1b02d5,0x8143001c,0xbd020134,0x00000000}},	//   _पौंड_, ونین, _ọkpọ, --,
   {{0x7afd17d6,0x6d4717d7,0x6f0f0313,0x7afb0131}},	//   _rust, ttja, rpcc, _éuti,
   {{0x71f7012b,0x7de70018,0x7afd17d8,0x20d2034f}},	//   _عروس_, désé, _sust, gáis_,
   {{0x6d4717d9,0x768f004d,0x9f400062,0x628a07ee}},	//   rtja, _høyt, _egiñ_, _hofo,
   {{0x6d4703d0,0x628a17da,0xc6220081,0x7af501e9}},	// [f70] stja, _kofo, _নানা_, _pizt,
   {{0x6f0d17db,0x8f9c00ca,0xbd02037a,0x628a01f9}},	//   _itac, _ליחי, ñéca, _jofo,
   {{0xb5fc03e5,0xe80a0294,0x68220134,0x20d217dc}},	//   _paġn, _ịbịa, _ọdab, cáis_,
   {{0xddde175b,0x69d50181,0x2ca017dd,0x20d20037}},	//   _uopš, _vyze, chid_, láir_,
   {{0xf74517de,0x7afd09a1,0x26ce0350,0x00000000}},	//   фело, _uust, fofo_, --,
   {{0x628a01d3,0x20d200e3,0x6442002b,0x768f0120}},	//   _nofo, náir_, _acoi, _nøyt,
   {{0x249f030a,0x24e90208,0x00000000,0x00000000}},	//   thum_, омки_, --, --,
   {{0x649500e3,0x9f650220,0xc21f009f,0x130917df}},	//   _táim, _štýl_, _मजहब_, оний_,
   {{0x6f0d17e0,0x80c90081,0x320517e1,0x20d2002b}},	//   _ntac, রগঞ্, tcly_, záis_,
   {{0xd0480092,0x20d2034f,0xaabf08c0,0xe3b610e0}},	//   əməy, yáis_, ्विक, ьбы_,
   {{0x648e01b5,0x610101d3,0x249f039f,0x5bba00a8}},	//   _cùis, _vēlo, phum_, _इश्व,
   {{0x644200e3,0x7de70018,0xf485010d,0x648e01ec}},	//   _gcoi, zésé, _تائی, _dùis,
   {{0x628a17e2,0x10a317e3,0xe3ae07ef,0x4abf087c}},	//   _fofo, тиян, _рб_, ्वाव,
   {{0x12fa00a1,0x443f17e4,0xa3e217e5,0x20d205e6}},	//   _והסב, lgu_, _धरत_, táis_,
   {{0x2ca00013,0x768f004d,0x2c0b0129,0x443f17e6}},	//   thid_, _høys, _ụjọ_, ogu_,
   {{0x443f17e7,0x20d200e3,0x2ca0005c,0x67290487}},	//   ngu_, ráis_, uhid_, _ovej,
   {{0x7de70018,0x236d052f,0x9f440084,0xaec617ab}},	// [f80] tésé, nvej_, ämä_, _обил,
   {{0x2ca017e8,0xed5a17e9,0x6b8b0212,0x629d0052}},	//   shid_, _доо_, ägga, ësoh,
   {{0x443f08d3,0xfe14030b,0x610800b6,0x768f00f3}},	//   kgu_, _त्यस_, _těle, _løys,
   {{0x648e01ec,0x00000000,0x00000000,0x00000000}},	//   _lùir, --, --, --,
   {{0x7c2417ea,0x2b4917eb,0xaca40134,0x6729007e}},	//   mair, ctac_, _laịt, _cvej,
   {{0x7c2417ec,0x64420080,0x443f17ed,0x24580019}},	//   lair, _scoi, egu_, _ẩm_,
   {{0x26ce17ee,0xa01b0088,0x3d12009d,0xaca40134}},	//   rofo_, fjöl, धीचे_, _naịt,
   {{0x7c2417ef,0x628a02e2,0x443f17f0,0xa01b003e}},	//   nair, _sofo, ggu_, gjöl,
   {{0x648e01f7,0x63ad17f1,0x644200fe,0x00000000}},	//   _bùir, _žanr, _vcoi, --,
   {{0x7c2417f2,0x648e0441,0x443f17f3,0x628a17f4}},	//   hair, _cùir, agu_, _qofo,
   {{0x3a3717f5,0x7c2417f6,0x60cf00d3,0x6f0d17f7}},	//   ורים_, kair, tocm, _stac,
   {{0x78a217f8,0x645b17f9,0x249d03a8,0x6f0d055c}},	//   nhov, ceui, _glwm_, _ptac,
   {{0x7c2417fa,0x23e2116e,0x628a0f20,0xb4ca0efb}},	//   dair, _परिद, _tofo, लकी_,
   {{0x442417fb,0x768f02ec,0x78a2019f,0x00000000}},	//   lam_, _høyr, hhov, --,
   {{0xa2cb06ed,0x20c709b9,0x7c2417fc,0x78a2039f}},	//   सकर्, _осиг, fair, khov,
   {{0x442417fd,0x644017fe,0x7c240a1b,0xa3e217ff}},	//   nam_, ngmi, gair, _धरा_,
   {{0x44241800,0x7b090031,0x6f0d1801,0xfbd00076}},	// [f90] iam_, _sľub, _utac, لتك_,
   {{0x44241802,0x5a341803,0x81c90081,0x2b491804}},	//   ham_, кнут, লেও_, rtac_,
   {{0x44240ad4,0x67290995,0x443f1805,0x38350d0f}},	//   kam_, _svej, ygu_, енер,
   {{0x7c241806,0xdbd9003e,0xd0f9006e,0xe8c90096}},	//   cair, _fæði, פּער, िकेच,
   {{0xfe700103,0x00000000,0x00000000,0x00000000}},	//   _صدی_, --, --, --,
   {{0x81c90081,0x45191807,0xa01b0103,0xb4c90285}},	//   লেট_, пция_, gköz, ोत्_,
   {{0x44241808,0xddde0034,0x645b1809,0x7ae701c2}},	//   fam_, _zapł, teui, _ihjt,
   {{0x78a20897,0xfdf800a1,0x443f129d,0x69c70090}},	//   chov, וצות_, ugu_, _ixje,
   {{0x610100d9,0x254e0092,0xaca400ac,0x645b180a}},	//   _vēlm, _həll_, _saịt, reui,
   {{0x443f02ad,0x236d052f,0xf1bf0031,0xf3f9020a}},	//   sgu_, rvej_, ášok_, deţe_,
   {{0x236d052f,0xa06a180b,0x00000000,0x00000000}},	//   svej_, пана_, --, --,
   {{0x20050034,0x236d02b6,0xd11b0285,0xf3f9044c}},	//   ślin_, pvej_, भीषण_, feţe_,
   {{0x9f4c07aa,0x442f180c,0x7c2400d9,0x47d10033}},	//   _ölüm_, _idg_, vair, _তৃতী,
   {{0x78a2025b,0x7c24180d,0xade400bc,0xa3b80037}},	//   zhov, wair, _गरदन_, _تامر_,
   {{0x7c24180e,0xc69200f5,0x649c033c,0x69c700dd}},	//   tair, נאל_, _méin, _nxje,
   {{0x23ce000d,0x649c00e3,0xa01b0018,0x442f180f}},	//   _हुँद, _léin, zköz, _jdg_,
   {{0x7c241810,0xfa360781,0x69cb026a,0x60c40090}},	// [fa0] rair, فراد, şgel, _ijim,
   {{0x7c241811,0x4a430832,0xd00f001c,0x00000000}},	//   sair, лнув, _پلی_, --,
   {{0x44241812,0x442f1813,0xf296006e,0x7c241814}},	//   yam_, _odg_, עכער_, pair,
   {{0xafdb1484,0x44241815,0xb05b0364,0x60c4010a}},	//   mfør, xam_, mnäc, _jjim,
   {{0xa01b0018,0x78a21816,0xafdb0856,0x69c7037a}},	//   tköz, rhov, lfør, _exje,
   {{0x78a21817,0x60c4007e,0x44241818,0xfaff0216}},	//   shov, _ljim, wam_, _erës_,
   {{0xb7bd002d,0x78a20149,0x442f1819,0xafdb181a}},	//   _reţe, phov, _bdg_, nfør,
   {{0x442f04d4,0xb4ca048a,0x2a6a0090,0x00000000}},	//   _cdg_, लके_, _habb_, --,
   {{0x64400006,0xe737064f,0x649c0037,0x98a3001f}},	//   rgmi, _пет_, _féin, _сите,
   {{0x4424181b,0x649c00da,0x92940291,0xafdb00f3}},	//   sam_, _géin, таоц, kfør,
   {{0xa2a609c4,0x648e009c,0xf3f9020a,0x00000000}},	//   टोग्, _fùip, veţe_, --,
   {{0x4424181c,0xafdb0939,0x39580483,0x442f03a8}},	//   qam_, dfør, _mprs_, _gdg_,
   {{0x6108030b,0x60c4181d,0x2d8c0e74,0xa01b02c3}},	//   _děla, _djim, äden_, ljök,
   {{0x60c4181e,0x6234002d,0xd36f001c,0xd491020b}},	//   _ejim, _реку, _دهه_, _rùi_,
   {{0xafdb181f,0x7c2f0027,0x6ee002c3,0xf3f9020a}},	//   gfør, _pdcr, möbl, reţe_,
   {{0x11db0054,0x629a1820,0x768f004d,0x225e0124}},	//   _מחוב, lkto, _løyp, letk_,
   {{0x213e1821,0x6fb9004d,0x00000000,0x00000000}},	// [fb0] luth_, _ігор_, --, --,
   {{0x629a1822,0x60dd0973,0xa9c70a11,0x2efa02ac}},	//   nkto, llsm, нсек, _gipf_,
   {{0x649c00fd,0xb8120033,0x2bd100b7,0x69c10147}},	//   _réin, _হয়ত_, _थुरा, _žleb,
   {{0xb4ca033a,0x89341823,0x4c951824,0x00000000}},	//   लको_, اعلا, _римс, --,
   {{0x3669090f,0x649c0037,0x442f1825,0x00000000}},	//   дало_, _péin, _rdg_, --,
   {{0x442f1826,0x6e2704e9,0xd1380138,0x629a0381}},	//   _sdg_, najb, krą_, jkto,
   {{0x6abf1827,0x56920b1b,0x64a51828,0x442f1829}},	//   ्वीर, рајт, кака, _pdg_,
   {{0x629a182a,0x29110062,0x25ba182b,0xd138182c}},	//   ekto, _itza_, úpla_, drą_,
   {{0x290301ae,0x27ff0032,0x200502c6,0x032200c6}},	//   _huja_, _igun_, ělil_, адын,
   {{0x29030010,0x442f0174,0x60d602c3,0x649c0076}},	//   _kuja_, _wdg_, _skym, _héil,
   {{0x10a600d6,0x29030216,0xbbde00a8,0x68fb09a1}},	//   винн, _juja_, _मर्क, _kiud,
   {{0x92c300c7,0x442f182d,0x2efa00e7,0x4096182e}},	//   ্ষে_, _udg_, _sipf_, трот,
   {{0x68fb13a9,0x68e9182f,0x6f63013f,0x00000000}},	//   _miud, _mhed, авяз, --,
   {{0x764303b4,0xed5a1830,0x68fb0138,0x200b028d}},	//   ngny, мог_, _liud, acci_,
   {{0x2a6a1831,0x27ff0d79,0xdc0f00ac,0x63a91832}},	//   _rabb_, _ogun_, _ụmụa, lzen,
   {{0xafdb0856,0x6fb60037,0x39580169,0xe7f600b6}},	//   rfør, _لمعا, _rprs_, ेशमा_,
   {{0x63a91833,0xafdb13c8,0xab271834,0x2a6a0090}},	// [fc0] nzen, sfør, кота_, _pabb_,
   {{0x68e91835,0x63a901c0,0xafdb004d,0x27ff0113}},	//   _ahed, izen, pfør, _agun_,
   {{0x68e9009c,0x29030161,0x68fb0138,0x649c0076}},	//   _bhed, _cuja_, _biud, _béil,
   {{0x68fb1836,0x779400cd,0x649c0037,0x6f040239}},	//   _ciud, هیزا, _céil, _kuic,
   {{0x63a901c0,0x649c0037,0x2d980103,0x68e91837}},	//   jzen, _déil, lyre_, _dhed,
   {{0x63a91838,0x27ff03f3,0x6d4e02ac,0x29030131}},	//   dzen, _egun_, otba, _fuja_,
   {{0xd9e604a9,0x68461839,0x649c00e3,0x2d98183a}},	//   _करित_, _инва, _féil, nyre_,
   {{0x68fb013d,0x68e9183b,0x7afc183c,0x3eb80076}},	//   _giud, _ghed, _hirt, hirt_,
   {{0x69dc0149,0x7afc183d,0xbebb0052,0x6d4e0dbc}},	//   _hyre, _kirt, rrëz, htba,
   {{0x7afc0694,0xd1380138,0xd9e609c3,0x6d4e183e}},	//   _jirt, trą_, _करात_, ktba,
   {{0x2d980052,0x63a901ff,0x7afc183f,0x00000000}},	//   jyre_, azen, _mirt, --,
   {{0x6f0400e3,0x213e1840,0x23661841,0x69dc1842}},	//   _buic, ruth_, _tsoj_, _myre,
   {{0x63a90d1b,0x7afc0a02,0xb4be1843,0x6d4e0629}},	//   czen, _oirt, ँची_, etba,
   {{0x6f041844,0x717400d1,0xf77300d7,0x00000000}},	//   _duic, _مهتا, בקש_, --,
   {{0x5c071845,0x69dc0073,0xb5fc003d,0xddde0154}},	//   вяза, _nyre, _baġi, _lapņ,
   {{0x7afc0080,0x3eb80091,0x672d00d9,0x2fc9023e}},	//   _airt, airt_, šaji, _txag_,
   {{0x649c00e3,0x68e90150,0x7afc1846,0x68fb0428}},	// [fd0] _réil, _rhed, _birt, _riud,
   {{0x68e91847,0x29031848,0x1a5b0037,0x64950037}},	//   _shed, _puja_, بشرة_, _háit,
   {{0x2d8c01df,0x69dc1849,0x68e90178,0x3f9900f0}},	//   ødet_, _cyre, _phed, lysu_,
   {{0x69dc184a,0xf8d100c7,0x7afc184b,0x20d9184c}},	//   _dyre, িষ্ঠ, _eirt, méis_,
   {{0xab84184d,0x3a23184e,0x649c0037,0x68fb184f}},	//   _курк, _tejp_, _céim, _viud,
   {{0xf7701850,0x64950080,0x4aa71317,0x69dc038c}},	//   غان_, _láit, _गतिव, _fyre,
   {{0x68e91851,0x20d91852,0x6fd502d5,0xb8120033}},	//   _thed, néis_, _युसू, _হযরত_,
   {{0x63a91853,0x200500a5,0x7d051854,0x7bdd0031}},	//   tzen, ślij_, _muhs, _kysu,
   {{0xe8941855,0x610802c6,0x659302c6,0x69dc0216}},	//   _тать, _bělo, _běhá, _zyre,
   {{0x63a91856,0x45451857,0x7afc0188,0x69080103}},	//   rzen, _منطق, _xirt, _ördö,
   {{0x63a91858,0xaca30139,0x7f4d0036,0x20d9037a}},	//   szen, _asọd, _aqaq, jéis_,
   {{0x20d91859,0x2375071c,0x7f4d0090,0x386d02ac}},	//   déis_, _ماتح, _bqaq, _jaer_,
   {{0x6f0400a1,0x386d185a,0x7d050231,0x649500da}},	//   _quic, _maer_, _auhs, _dáit,
   {{0x2d9800dd,0x66e3009d,0x386d057a,0x6d4e185b}},	//   tyre_, गतिक_, _laer_, ttba,
   {{0x09be00c7,0xada30231,0x6da3185c,0x2d9e185d}},	//   _অর্থ, барл, бира, áte_,
   {{0x7afc185e,0x09e20033,0x7d0503a9,0x6f04185f}},	//   _sirt, _বললা, _duhs, _tuic,
   {{0x2d9e0206,0x09be1860,0x7afc1861,0x3eb8023b}},	// [fe0] šte_, ्थ्य, _pirt, pirt_,
   {{0x649c00e3,0x0e661862,0x20d91863,0x9a6a0308}},	//   _réim, _скон, béis_, عمال_,
   {{0x386d02e5,0x7afc1864,0x20d90a43,0xddde01d3}},	//   _baer_, _virt, céis_, _sapņ,
   {{0x7afc1865,0x386d1866,0x20d90037,0x69dc1867}},	//   _wirt, _caer_, léir_, _vyre,
   {{0x386d1868,0x7afc1869,0x3ce0004d,0x7c2600e8}},	//   _daer_, _tirt, mliv_, _iekr,
   {{0x7afc0037,0x20d90037,0xe9440d7f,0x3ce0186a}},	//   _uirt, néir_, _پرسی, lliv_,
   {{0x2aa40068,0x64950080,0x7c260449,0x7769063d}},	//   _több_, _náis, _kekr, _esex,
   {{0xa01b186b,0x386d0178,0xb4de0096,0xb97b1777}},	//   ljöv, _gaer_, णते_, _אנלי,
   {{0x649500e3,0x7c26186c,0x5c37006e,0x00000000}},	//   _ráit, _mekr, ארפן_, --,
   {{0x4154186d,0x59b80b42,0x326610e8,0xa5da0037}},	//   авос, _आधार, утив, _كبار_,
   {{0x6e2501e8,0xdd1200a7,0x7c261044,0xba57006e}},	//   _rehb, _rüşv, _oekr, נסטו_,
   {{0x7c2602e6,0x629d023b,0x7d05026a,0x764403e3}},	//   _nekr, ësor, _ruhs, ɗiya,
   {{0xe29a01b3,0xe0df028d,0x91fc01d3,0x610802c6}},	//   _пад_, rlò_, edāt, _tělo,
   {{0x20d9186e,0x442600de,0x4ea7186f,0x7bdd0034}},	//   téis_, _heo_, урма, _rysu,
   {{0x44261870,0x254e00a7,0x6e251871,0x00000000}},	//   _keo_, _bəli_, _vehb, --,
   {{0x442608a9,0x649500e3,0x20d91872,0x2fc60117}},	//   _jeo_, _háir, réis_, _žoge_,
   {{0x7c261873,0x2d8c052f,0x442600fe,0x20d91874}},	// [ff0] _dekr, øder_, _meo_, séis_,
   {{0x44261875,0x20d91876,0x7bdd0094,0x39a7002d}},	//   _leo_, péis_, _vysu, лшев,
   {{0x64950037,0x386d00b3,0xb5fc02a1,0xca480286}},	//   _máir, _paer_, _kaġu, المه_,
   {{0x44260049,0x7c2601a2,0xb4c0000d,0xddde030b}},	//   _neo_, _gekr, ूको_, _např,
   {{0xd36607c3,0xddd701d4,0x2ca900e3,0x00000000}},	//   _به_, _yaxş, mhad_, --,
   {{0xca4900cd,0xd1260190,0x64950076,0x9a8707bf}},	//   _جلسه_, _وم_, _náir, _сумл,
   {{0x44261877,0x1ddb0789,0x00000000,0x00000000}},	//   _beo_, _मुमत, --, --,
   {{0x44260158,0xa4230033,0xf1cf1878,0x387f009e}},	//   _ceo_, ফল্য_, _सुगन, _unur_,
   {{0x44261879,0xd05d0092,0x64950076,0x73050c37}},	//   _deo_, _üzər, _báir, јпоз,
   {{0x649500da,0x81b901c2,0xe2990284,0x7eab042c}},	//   _páis, _haɓɗ, тао_, _hüpf,
   {{0x00860ac6,0x44260487,0x332d187a,0x91e50a18}},	//   ално, _feo_, ssex_, роне,
   {{0x672d1197,0x4426187b,0x64950072,0x2c150176}},	//   šaju, _geo_, _váis, _फ्लू_,
   {{0x81bd00c7,0x249f01af,0x20d90076,0x64590079}},	//   _আরও_, mkum_, téir_, _ibwi,
   {{0xe296187c,0x64950037,0x249f187d,0x3cde0285}},	//   _ваш_, _gáir, lkum_, _कीजे_,
   {{0x20d900e3,0x3ce01842,0xb60600d4,0x7c2605db}},	//   réir_, tliv_, _uváž, _pekr,
   {{0x4426187e,0x64ba03e5,0x2ca9187f,0x249f003e}},	//   _xeo_, nċip, ghad_, nkum_,

   {{0x3b071880,0x644b1881,0x3b86100f,0x3d1c0139}},	// [1000] ието_, _mcgi, шлаг, _bàwò_,
   {{0x3ce01882,0x248d01df,0x249f07e7,0x7c26084e}},	//   sliv_, hjem_, hkum_, _wekr,
   {{0x249f003e,0x64591883,0x7c2601e8,0x186a0114}},	//   kkum_, _obwi, _tekr, кажи_,
   {{0x315600c1,0x6d5e003d,0x2ca90013,0x248d03e5}},	//   ייען_, _ippa, chad_, jjem_,
   {{0x91fc00d9,0x3d1c0139,0x00000000,0x00000000}},	//   ndār, _fàwò_, --, --,
   {{0x44261884,0x64591885,0xfaa61121,0x1dbc02d5}},	//   _seo_, _abwi, _таго, ोपपत,
   {{0x442600b7,0xfc3f0206,0x26c00357,0x00000000}},	//   _peo_, _ulíc_, đio_, --,
   {{0xd7660068,0x2ca01886,0x291a007b,0x248d0216}},	//   _پارٹ, nkid_, mppa_, gjem_,
   {{0x64950080,0x44261887,0xb5fc003d,0x2ca000f9}},	//   _páir, _veo_, _raġu, ikid_,
   {{0x6d5e1888,0x68e21889,0xd2570120,0x00000000}},	//   _oppa, llod, ацю_, --,
   {{0x4426188a,0x64a6188b,0x6913009e,0x248d0117}},	//   _teo_, _кажа, _għed, bjem_,
   {{0xd83f033d,0x644b0124,0xd1300103,0x00000000}},	//   _účtu_, _gcgi, _ہمت_, --,
   {{0x6d5e188c,0x64950080,0xb05b007b,0x58f70142}},	//   _appa, _táir, snäo, ימטע_,
   {{0xd0650092,0x291a0167,0x539b00ca,0x3ea50103}},	//   _əsər, kppa_, _בידו, ólt_,
   {{0x3cf3009d,0x2ca901b5,0x611300ae,0xfc3f037a}},	//   ंगले_, thad_, _căld, _alía_,
   {{0x76b2007f,0x20d20072,0xbd440076,0x0ca8188d}},	//   pływ, záiz_, تنفي, атуи_,
   {{0x2ca9188e,0x5a35008f,0x90a70018,0xb6030146}},	// [1010] rhad_, йнат, _محکم, áško,
   {{0xda780084,0x2ca9188f,0x657a1890,0x249f02c6}},	//   иях_, shad_, _orth, zkum_,
   {{0xceb20132,0x83fd0018,0x249f1891,0xfc3f037a}},	//   _זיי_, ndőr, ykum_, _elía_,
   {{0x68e21892,0x00000000,0x00000000,0x00000000}},	//   glod, --, --, --,
   {{0x7c2d1893,0x69ce0113,0x291a1894,0x7aee009c}},	//   maar, _exbe, appa_, _fhbt,
   {{0x7c2d1895,0x7b3d078e,0x00000000,0x00000000}},	//   laar, _căuş, --, --,
   {{0x248d0087,0xd57501ef,0x6d9e0078,0x637211bc}},	//   tjem_, суль, _għaġ, yınç,
   {{0x58d41896,0x7c2d1897,0xc4850b36,0x64950076}},	//   _дост, naar, слик, _cáip,
   {{0xf77303ed,0x248d1898,0x657a02ad,0x249f003e}},	//   _باز_, rjem_, _erth, rkum_,
   {{0x249f1899,0x7c2d189a,0xd5bb00ae,0x777b01ff}},	//   skum_, haar, _исе_, _irux,
   {{0x6f16189b,0x00000000,0x00000000,0x00000000}},	//   _styc, --, --, --,
   {{0x7c2d189c,0x6459023f,0x6f1601ff,0x00000000}},	//   jaar, _ubwi, _ptyc, --,
   {{0x442d189d,0x7c2d189e,0xe28e002d,0x83fd0103}},	//   mae_, daar, _еа_, rdős,
   {{0x442d189f,0x644918a0,0xc7d60089,0xd8390154}},	//   lae_, lgei, מורי_, _blōk_,
   {{0xf1cf063c,0x628318a1,0x7c2d0188,0xada318a2}},	//   _सुचन, _inno, faar, парл,
   {{0x7c2d18a3,0x644918a4,0xdd8f1363,0x442d0239}},	//   gaar, ngei, روق_, nae_,
   {{0x09b500c7,0xbebb00dd,0x7e9a03ef,0x2ca000dc}},	// [1020] _জুলা, rsër, _منظر_, rkid_,
   {{0x442d18a5,0xe3a70068,0x2ca018a6,0xe7db00a3}},	//   hae_, _ہر_, skid_, _बड़प,
   {{0x7c2d18a7,0x9e7b00c1,0x6e2e18a8,0x442d0749}},	//   baar, _ענטפ, mabb, kae_,
   {{0x6c8618a9,0x6e2e18aa,0x777b18ab,0x7c2d008a}},	//   _الحم, labb, _brux, caar,
   {{0x442d18ac,0x628304e2,0xddd502c6,0xb8d0049d}},	//   dae_, _onno, dezř, _ओत_,
   {{0xcd290814,0x6e2e18ad,0x56931469,0xa01b0212}},	//   _حسین_, nabb, зашт, njör,
   {{0x64950037,0x2b4018ae,0xb9960037,0x00000000}},	//   _páip, lric_, _الزب, --,
   {{0x628318af,0x6e2e18b0,0x5fc8030b,0x290a0124}},	//   _anno, habb, रपाल, _iuba_,
   {{0xdc9b0130,0x213e02ad,0x78a20146,0x657a0150}},	//   טיקל, wrth_, mkov, _wrth,
   {{0x290a18b1,0x78a218b2,0x6e2e18b3,0x2d7818b4}},	//   _kuba_, lkov, jabb, _oče_,
   {{0x7c2d0694,0x290a18b5,0xd48f18b6,0x442d0256}},	//   yaar, _juba_, _ер_, bae_,
   {{0x7d1c0146,0x6283083e,0x290a18b7,0x232a0a7c}},	//   dprs, _enno, _muba_, _боди_,
   {{0x7c2d18b8,0x2bd80e50,0x439418b9,0x6e2e18ba}},	//   vaar, _भुला, _фалс, fabb,
   {{0x291818bb,0x7c2d0254,0xae1404f1,0x6e2e18bc}},	//   _otra_, waar, तुलन_, gabb,
   {{0x7c2d18bd,0x8af001d4,0x6ca718be,0xb05b0084}},	//   taar, ktəb, браж, nnäk,
   {{0xfc3f01cd,0x00000000,0x00000000,0x00000000}},	//   _elín_, --, --, --,
   {{0x7c2d18bf,0x78a2025b,0x6e2e18c0,0x60cd023f}},	// [1030] raar, dkov, babb, _ijam,
   {{0x7c2d18c1,0xff500037,0x442d18c2,0x290a18c3}},	//   saar, _أخي_, zae_, _buba_,
   {{0x290a18c4,0x78a218c5,0x291805b4,0x6d41109d}},	//   _cuba_, fkov, _ctra_, álad,
   {{0x290a1114,0x6d471124,0xec6b1612,0xfc3f02c6}},	//   _duba_, muja, _срок_, _zlín_,
   {{0x6d47026e,0x6d5503f3,0x442d024a,0x660518c6}},	//   luja, ltza, vae_, опла,
   {{0x442d18c7,0x290718c8,0x2bc6030b,0x6d5518c9}},	//   wae_, ínas_, लपरा, otza,
   {{0x6d5503f3,0x290a18ca,0x6d470087,0x78a20146}},	//   ntza, _guba_, nuja, bkov,
   {{0x6e2e18cb,0x78a218cc,0x6d550a00,0x60cd18cd}},	//   zabb, ckov, itza, _njam,
   {{0x442d18ce,0x290a18cf,0x98680068,0x6d4718d0}},	//   rae_, _zuba_, _دینے_, huja,
   {{0xadf9000f,0x6d4718d1,0x27ed0a00,0x644918d2}},	//   ंधान_, kuja, _izen_, sgei,
   {{0x6e2e18d3,0x208a008f,0x6113020a,0x71b5007b}},	//   vabb, айни_, _sălb, ющих,
   {{0x25d607a6,0x6d470181,0x3eba0167,0x349418d4}},	//   _ווען_, duja, _smpt_, _нахр,
   {{0x6e2e18d5,0x78a918d6,0x60cd18d7,0xa85600ca}},	//   tabb, _mlev, _djam, חירה_,
   {{0x78a918d8,0x78a2025b,0x9c130129,0x6113020a}},	//   _llev, zkov, _kọwa, _călc,
   {{0x6e2e18d9,0x78a9069d,0xde0302ec,0xfc3f0072}},	//   rabb, _olev, дпри, _clío_,
   {{0x290a18da,0x8b260c79,0x6e2e18db,0x2b4018dc}},	//   _ruba_, ждае, sabb, tric_,
   {{0x78a218dd,0x290a18de,0x3eba0808,0x7eab01e8}},	// [1040] vkov, _suba_, _tmpt_, _süpe,
   {{0x78a918df,0x61e3003e,0x78bb18e0,0xa01b0212}},	//   _alev, _kynl, _amuv, ljöp,
   {{0x78a210e1,0x78a90021,0x386618e1,0x656101fa}},	//   tkov, _blev, teor_, _nplh,
   {{0x290a0193,0x7a400af0,0x8037006e,0x6f000139}},	//   _vuba_, _bátà, ַנצע_, _fábì,
   {{0x78a210e1,0x61e302b6,0x8af000a7,0x236f0350}},	//   rkov, _lynl, rtəb, _nsgj_,
   {{0x290a18e2,0x649c00e3,0x7b0903da,0x78bb0201}},	//   _tuba_, _léit, _džud, _emuv,
   {{0x78a204ad,0x27ed18e3,0x98a618e4,0x78a918e5}},	//   pkov, _ezen_, _диве, _flev,
   {{0x78a900ee,0xd91b0327,0x00000000,0x00000000}},	//   _glev, _כולל, --, --,
   {{0xccf3028c,0xf366004d,0x2904026d,0x00000000}},	//   וכה_, ітин, _iima_, --,
   {{0x29040350,0x60cd18e6,0x78a902c6,0xc17800c6}},	//   _hima_, _sjam, _zlev, tvė_,
   {{0x61e302e0,0x290418e7,0x649c0076,0x52aa074c}},	//   _cynl, _kima_, _béit, _छतीस,
   {{0x290418e8,0x649c033c,0x61e303a8,0x00000000}},	//   _jima_, _céit, _dynl, --,
   {{0x248618e9,0x290418ea,0x9c130294,0x78fb0266}},	//   _inom_, _mima_, _kọva, יפטו,
   {{0x26dc0335,0x6d4718eb,0x6f1d01cb,0x00000000}},	//   novo_, tuja, rpsc, --,
   {{0xdcbb18ec,0x61e30150,0x361b006e,0x7afb0036}},	//   аща_, _gynl, שולד, _èuti,
   {{0x290402dd,0x629818ed,0x5b1518ee,0x6d5502a7}},	//   _nima_, _hovo, змат, rtza,
   {{0x629816d4,0x2486005f,0x63a00e43,0x6d5518ef}},	// [1050] _kovo, _mnom_, nymn, stza,
   {{0x78a9000d,0x29040139,0x60dd18f0,0x78bb0095}},	//   _slev, _aima_, losm, _smuv,
   {{0x248604a3,0x290418f1,0x89d900e3,0x26dc18f2}},	//   _onom_, _bima_, حوار_, dovo_,
   {{0xf771054f,0x29040e3a,0x6f0d0010,0x629818f3}},	//   فات_, _cima_, _kuac, _lovo,
   {{0x7c2204d8,0xf21b0034,0x78a902c6,0x62980090}},	//   ñore, पुड़_, _vlev, _oovo,
   {{0xd6db18f4,0x248618f5,0x6f0d00de,0x290401ff}},	//   ште_, _anom_, _muac, _eima_,
   {{0x6f0d0099,0x290403e3,0x78a900e7,0xa954004d}},	//   _luac, _fima_, _tlev, _окрі,
   {{0x78bb0193,0x290418f6,0x78a918f7,0x27ed0634}},	//   _umuv, _gima_, _ulev, _tzen_,
   {{0x6f0d0080,0x649c00e3,0x61e302fe,0xf7700182}},	//   _nuac, _réit, _synl, _لال_,
   {{0xd2a90084,0x629818f8,0xf3f900d3,0x649c0a7d}},	//   ское_, _covo, neţi_, _béis,
   {{0x629818f9,0x216918fa,0x672900bd,0x6113020a}},	//   _dovo, щини_, _hwej, _băla,
   {{0x2009002b,0x6f0d152f,0x92cb0081,0x672918fb}},	//   _cgai_, _buac, লতে_, _kwej,
   {{0x61fe0074,0x7ea20257,0x09b80bf5,0x2d850b97}},	//   _úpln, _hôpi, _आध्य, ålen_,
   {{0xe3b009b4,0x523900c1,0x6f0d0332,0x59bd00df}},	//   _جرم_, _הײַנ, _duac, ्पार,
   {{0xb7bd00d3,0xf3f900d3,0x10a60a54,0x6729063d}},	//   _deţi, deţi_, _никн, _lwej,
   {{0x649c00e3,0x6ab4009f,0x5f7602a3,0x2cb20065}},	//   _héir, ंफ्र, _فاخر, _bímọ_,
   {{0x6b630805,0x69c3002b,0x62980154,0x00000000}},	// [1060] нкта, únen, _yovo, --,
   {{0x6d410080,0x0f7b021e,0x2cab01dc,0x290418fc}},	//   álac, _פריל, _elcd_, _sima_,
   {{0xfe9b00c1,0x290418fd,0x5e9b00ca,0x7e9b00ca}},	//   _היימ, _pima_, _הביק, _הסיו,
   {{0x649c0080,0x672918fe,0x2904009e,0xa2bb18ff}},	//   _léir, _bwej, _qima_, षोत्,
   {{0x7c241900,0x66e61901,0xc7a3037e,0x7eab09a1}},	//   mbir, пода, ницк, _hüpa,
   {{0xb6030146,0x7c2401af,0xf3f900d3,0x672900bd}},	//   _otáč, lbir, ceţi_, _dwej,
   {{0x2904042d,0x6298015c,0x7d061902,0x00000000}},	//   _tima_, _rovo, _kiks, --,
   {{0x26dc0542,0x7c241903,0x649c036b,0x62980141}},	//   sovo_, nbir, _réis, _sovo,
   {{0x62981904,0x7d061905,0xe6461906,0xf7431907}},	//   _povo, _miks, _неап, _пето,
   {{0x2cfa04f1,0x7d061908,0x9c130174,0x649c1909}},	//   ्दुल_, _liks, _họta, _céir,
   {{0xb7bd00d3,0x9c130174,0x62980231,0x649c00da}},	//   _reţi, _kọta, _vovo, _déir,
   {{0x7d06190a,0x2486019c,0x75d30037,0x6298042c}},	//   _niks, _unom_, _ثيما, _wovo,
   {{0x7c24190b,0x62980087,0xdfdb008f,0x6f0d142d}},	//   dbir, _tovo, сън_, _quac,
   {{0xd24f00ab,0x7c24190c,0x9c130174,0xdb230018}},	//   _منه_, ebir, _lọta, ہوری,
   {{0x7d0600e8,0xa2d906e4,0x51860131,0xf3f9044c}},	//   _biks, नकर्, _хула, veţi_,
   {{0x7c24190d,0x6f0d190e,0x2a7f0233,0x2b4901ff}},	//   gbir, _tuac, _şub_, tuac_,
   {{0x2d8c190f,0x7d061910,0xf3f9002d,0xddde00a7}},	// [1070] äder_, _diks, teţi_, _tapş,
   {{0x7c24083e,0x0dcb1911,0xa5771912,0x67291913}},	//   abir, _гуми_, ščić, _rwej,
   {{0x7c241914,0xa9071915,0xf3f9020a,0xa3de00a4}},	//   bbir, سبان, reţi_, _दुस_,
   {{0xe9f8004d,0x6ef202b6,0x00000000,0x00000000}},	//   їнці_, ræbe, --, --,
   {{0x3b640020,0x9c130134,0x6913009e,0x2d571916}},	//   _първ, _dọta, _għen, lçe_,
   {{0x6447013f,0x4519098e,0x00000000,0x00000000}},	//   ėjim, оция_, --, --,
   {{0x672400d9,0x2d571917,0x7c2f01dc,0x00000000}},	//   ģija, nçe_, _kecr, --,
   {{0xc95200a1,0x67290172,0x8af0013c,0x00000000}},	//   _שמן_, _twej, ntən, --,
   {{0x2d5701e8,0x649c0076,0x7eb0007b,0xb60300d4}},	//   hçe_, _péir, _häpe, _stáč,
   {{0x2d57026a,0x999105db,0x957c007f,0x00000000}},	//   kçe_, _zdzš_, _cząs, --,
   {{0x3ce902f1,0x904600cd,0xa06a00ae,0x00000000}},	//   klav_, ونده, оана_, --,
   {{0xcea91541,0x7c24013c,0x764d03e3,0xb6030206}},	//   _די_, xbir, ɗaya, _vtáč,
   {{0x7d061918,0x00000000,0x00000000,0x00000000}},	//   _riks, --, --, --,
   {{0x7d061919,0xc3320266,0x442f191a,0x1d0a0e06}},	//   _siks, _יוד_, _heg_, жеви_,
   {{0xfce6191b,0x7d0600bf,0x8af0013c,0x00000000}},	//   дово, _piks, ftən, --,
   {{0x442f191c,0x3ce9191d,0x7c2f191e,0x2cfa074c}},	//   _jeg_, glav_, _cecr, ्देल_,
   {{0x442f191f,0x7c241920,0x7c2f1921,0x46dd167f}},	// [1080] _meg_, rbir, _decr, यवाह,
   {{0x7c2410f8,0x7d060383,0x4a430396,0xda660037}},	//   sbir, _wiks, кнув, باري,
   {{0xa96a0391,0x7d061922,0xd910001c,0x00000000}},	//   تمام_, _tiks, ایر_, --,
   {{0x442f06a3,0x53ad0557,0x7c2f1923,0x3ce91924}},	//   _neg_, टनाश, _gecr, clav_,
   {{0x69d51925,0xafdb0537,0x291c004b,0x00000000}},	//   _exze, lgør, ūva_, --,
   {{0x442f0006,0x9c130134,0x7c2f010a,0x64d61926}},	//   _aeg_, _wọta, _zecr, डक्श,
   {{0x442f1927,0xafdb0c08,0x443d0090,0x9856007e}},	//   _beg_, ngør, _bdw_, _оташ,
   {{0x442f006c,0xb05b007b,0x00000000,0x00000000}},	//   _ceg_, nnät, --, --,
   {{0x442f1928,0x9c130174,0xfc3f003e,0x443d030a}},	//   _deg_, _kọra, _slík_, _ddw_,
   {{0x3958023e,0x672201b6,0x00000000,0x00000000}},	//   _kqrs_, mpoj, --, --,
   {{0x67220029,0x44241929,0x691302a1,0x442f0324}},	//   lpoj, pbm_, _nħel, _feg_,
   {{0x3cfa0034,0x3f86192a,0x442f192b,0x2a780113}},	//   ्दों_, _šoua_, _geg_, _larb_,
   {{0xceeb16c4,0x7c2f192c,0x26ce0451,0x5f94008f}},	//   قرآن_, _recr, onfo_, вият,
   {{0x442f0126,0x7c2f192d,0x2d570233,0x2d8105db}},	//   _zeg_, _secr, tçe_, _prhe_,
   {{0x26ce192e,0xafdb052f,0x9d18192f,0x443d00f0}},	//   info_, ggør, дост_, _ydw_,
   {{0x9f5500d6,0x2cb20150,0x2d571930,0x00000000}},	//   _звич, ghyd_, rçe_, --,
   {{0x7c220610,0x7c2f01d3,0xd13800c6,0x7e770158}},	// [1090] ñora, _vecr, lsą_, _taxp,
   {{0x8af0013c,0xe9ab0076,0x48be0033,0x201901f9}},	//   stən, يدان_, ইকোর, lcsi_,
   {{0x7c2f01e8,0x2a781931,0x3d250154,0x69130078}},	//   _tecr, _darb_, _dèwò_, _għel,
   {{0x2cb202ad,0x628a0124,0x20190103,0x2d1b0174}},	//   chyd_, _lnfo, ncsi_, _ụgwụ_,
   {{0x442f1932,0xb8d70251,0x2366022e,0xe76b006f}},	//   _reg_, _छत_, _npoj_, تحان_,
   {{0x442f0a8d,0x9c130174,0x99670927,0xd13800c6}},	//   _seg_, _tọsa, _отбл, ksą_,
   {{0x26c901ac,0xb05b16f9,0x00000000,0x00000000}},	//   đao_, nnäs, --, --,
   {{0x628a1933,0x2ca902c3,0x00000000,0x00000000}},	//   _anfo, nkad_, --, --,
   {{0x442f1934,0xe3b10037,0x29111935,0xd13800c6}},	//   _veg_, طرة_, _huza_, esą_,
   {{0x442f1936,0x29111937,0x3125007e,0x00000000}},	//   _weg_, _kuza_, ндог, --,
   {{0x442f1938,0x2a630063,0x2f140212,0xc87903e0}},	//   _teg_, _mbjb_, _säg_, _kaş_,
   {{0x8cc100a3,0x6e3e00e7,0x628a1939,0x442f00b3}},	//   रोमो, _sdpb, _enfo, _ueg_,
   {{0xc00000c7,0xe3ae0457,0x6d41193a,0x2ca907ac}},	//   ূর্ণ_, _сб_, álan, dkad_,
   {{0x539a193b,0x2f140222,0xafdb02b6,0x2911022b}},	//   _מינו, _väg_, tgør, _ouza_,
   {{0x98a700b6,0x29110169,0x9f6302c6,0xd24e0076}},	//   éně_, _nuza_, ěvák_, _انى_,
   {{0xfce3007e,0xfce60450,0xfe7800c6,0xafdb0537}},	//   госо, хобо, žį_, rgør,
   {{0x60c6193c,0xcb67193d,0xca860077,0x60d700ca}},	// [10a0] mikm, нате_, нгай, _רופא_,
   {{0x2911193e,0x60c6193f,0x691300bd,0xafdb0537}},	//   _buza_, likm, _iħej, pgør,
   {{0xc8790253,0xdca61940,0xc8661941,0x98a61942}},	//   _baş_, _зани, етли, ниже,
   {{0x60c606ee,0x2ca90149,0x6d4e1943,0x48be0033}},	//   nikm, ckad_, muba, ইক্র,
   {{0x6d4e1944,0xb05b1945,0x7c3601af,0xc87900a7}},	//   luba, onär, mayr, _daş_,
   {{0x26ce1946,0x7e7c02ef,0xb05b1947,0x691300bd}},	//   unfo_, ndrp, nnär, _mħej,
   {{0x23660559,0x29110995,0x550600ae,0x00000000}},	//   _spoj_, _guza_, нчиа, --,
   {{0x6d5c1948,0x672200c2,0x39470072,0xb05b042c}},	//   itra, ppoj, ánse_, hnär,
   {{0x6d4e1949,0x68e2194a,0x29110ec4,0x60c60167}},	//   huba, mood, _zuza_, dikm,
   {{0x6d4e194b,0x8af00092,0x6d4701cd,0x2911010a}},	//   kuba, xtəl, yrja, _yuza_,
   {{0xe3af03ed,0x6d5c042d,0xc87903a3,0xd46a194c}},	//   لری_, jtra, _yaş_, _ниже_,
   {{0xe61f0028,0x6d4e194d,0x6d5c194e,0xd1380138}},	//   _đôi_, duba, dtra, rsą_,
   {{0xb4be194f,0xdefb0084,0x6d5c0bd3,0xd4370a41}},	//   ुची_, зыв_, etra, _טראק_,
   {{0x68e2008a,0x6d5c1950,0x628a00ca,0xb8160033}},	//   hood, ftra, _unfo, ারিত_,
   {{0x6d5c1951,0x68e20be9,0x6e3507c0,0xc27b00a1}},	//   gtra, kood, razb, _מרגי,
   {{0xdef803e5,0x8af00092,0x29111952,0x68e21953}},	//   ċċa_, stəl, _ruza_, jood,
   {{0x68e20694,0x6d5c1954,0x2911005f,0x2ca91955}},	// [10b0] dood, atra, _suza_, rkad_,
   {{0x6d4e1956,0x2ca91957,0x6f070065,0x9b44001c}},	//   buba, skad_, _débì, انلو,
   {{0x7c361958,0xc98407c7,0x67200113,0x6d4e1959}},	//   bayr, луци, _atmj, cuba,
   {{0x68e2008a,0xcd9600ca,0x61ea0154,0x7afe0f5a}},	//   good, _סדרת_, _myfl, ampt,
   {{0x4c9a040a,0xd763001c,0x00000000,0x00000000}},	//   _חברו, انتی, --, --,
   {{0x07a21787,0x6446195a,0xc6680291,0x2911195b}},	//   рашн, ókin, ешће_, _tuza_,
   {{0xc879026a,0x68e2195c,0x20e1097c,0x00000000}},	//   _taş_, bood, नवाध, --,
   {{0xc485007e,0x68e20188,0x00000000,0x00000000}},	//   тлик, cood, --, --,
   {{0xa3de0251,0x6d4e195d,0x77550c79,0x6d5c195e}},	//   _दुआ_, zuba, _шкаф, ztra,
   {{0x6d4e195f,0x6d5c1960,0x8cc1007f,0x00000000}},	//   yuba, ytra, रोतो, --,
   {{0x26c71961,0x61ea02e0,0x60c61962,0x7c3600f9}},	//   mino_, _cyfl, tikm, yayr,
   {{0xf4850068,0x6d5c1963,0x3cf902ac,0x2b491964}},	//   _جائی, vtra, _nhsv_, krac_,
   {{0x7fd60565,0x3f84030b,0x6d5c182f,0xb05b0212}},	//   тіні, ímu_, wtra, tnär,
   {{0x6d5c1965,0x26c71966,0x2b491967,0x6d4e1968}},	//   ttra, nino_, drac_, tuba,
   {{0xed571969,0x61ea02ad,0x68e2008a,0xb05b02c3}},	//   кор_, _gyfl, yood, rnär,
   {{0x6d4e196a,0x26c7196b,0x6d5c196c,0xf8db0285}},	//   ruba, hino_, rtra, यकोप,
   {{0x26c7196d,0x6d4e196e,0x387d00f0,0x8af000a7}},	// [10c0] kino_, suba, ddwr_, stəm,
   {{0x68e2196f,0x26c71970,0x7c360e8e,0x0f37006e}},	//   wood, jino_, sayr, _שריט_,
   {{0xa3de000d,0x68e21971,0xda650037,0x80c600c0}},	//   _दुई_, tood, طالي, _लगाइ,
   {{0xd3080023,0xdca60ef1,0x2b491972,0x00000000}},	//   _hệt_, _рами, brac_, --,
   {{0x68e21973,0x60c40350,0x00000000,0x00000000}},	//   rood, _mmim, --, --,
   {{0x26c71974,0x65680063,0x68e21975,0xb05b09ab}},	//   gino_, _ppdh, sood, hnäp,
   {{0xceb30054,0xd30800de,0x60c40129,0xd5af0190}},	//   שיו_, _mệt_, _omim, يفه_,
   {{0x98a31121,0xb4be1006,0x68e2008c,0x00000000}},	//   _кисе, ुचे_, qood, --,
   {{0x26c71976,0x6ef202b6,0x98a31977,0x00000000}},	//   bino_, væbn, _тите, --,
   {{0x26c71978,0x00000000,0x00000000,0x00000000}},	//   cino_, --, --, --,
   {{0x40351979,0xa3e702d5,0x3a3700ca,0xaa37006e}},	//   ленс, _मुठ_, כרים_, כטיק_,
   {{0x30a7197a,0x9346197b,0x6abf0557,0x60c4023b}},	//   тров, _анде, _एग्र, _cmim,
   {{0x2d8c0bab,0x644201c8,0x2d9e197c,0xd30800fe}},	//   åden_, _idoi, äten_, _bệt_,
   {{0x41dd1362,0x60c4083e,0x78a0197d,0x00000000}},	//   _नुकस, _emim, _lomv, --,
   {{0x7b09197e,0xd3080023,0x2d850a93,0xeda4197f}},	//   _džul, _dệt_, íle_, ашто,
   {{0x629a0542,0xf0470152,0x60d60052,0x28c41980}},	//   ljto, _рэко, _gjym, लोमि,
   {{0x09bd05a5,0x1be300a3,0x59d51981,0x0bf51982}},	// [10d0] ्प्य, _कुशल_, _दशहर, упаю,
   {{0xdd03008b,0x6d481983,0x26c71984,0x629a0216}},	//   ırıc, ádac, xino_, njto,
   {{0x26c71985,0x81e40081,0x78a01986,0x6cd50e5a}},	//   vino_, পের_, _bomv, _مقدا,
   {{0x26c71987,0x64420076,0x3cf600a4,0x00000000}},	//   wino_, _ndoi, ्षणे_, --,
   {{0x3ea1007a,0x78a0080e,0x7b090138,0x386f00c4}},	//   _koht_, _domv, _užuo, regr_,
   {{0x644208a8,0x00000000,0x00000000,0x00000000}},	//   _adoi, --, --, --,
   {{0x26c71988,0xfc3f033c,0x00000000,0x00000000}},	//   rino_, _flít_, --, --,
   {{0xf77301f9,0xe6f2020b,0x00000000,0x00000000}},	//   _پار_, _vườ, --, --,
   {{0x26c71989,0x68e90032,0x13090938,0xdce500d9}},	//   pino_, _iked, нний_, _arhī,
   {{0xd7f8198a,0x6b6701d3,0x68fb0172,0x27ed0032}},	//   _рус_, mīgā, _hhud, _iyen_,
   {{0x2455006f,0x27fa00a5,0xa0a6198b,0x68fb0188}},	//   _مناس, ępne_, ганд, _khud,
   {{0x5fc500aa,0xd30800fe,0x00000000,0x00000000}},	//   _लेहल, _sệt_, --, --,
   {{0x7ae5198c,0x27ed0154,0x68fb0a4b,0x6b6700e8}},	//   koht, _jyen_, _mhud, nīgā,
   {{0x7ae500c2,0x63bb198d,0x63a9198e,0x68fb009e}},	//   joht, mzun, myen, _lhud,
   {{0x27ed14b1,0x270f00c0,0xc87901e8,0x8af00092}},	//   _lyen_, ादुर_, _ekşi_, stək,
   {{0x60c4198f,0x7b091528,0x27ed037a,0x63bb024a}},	//   _umim, _džum, _oyen_, ozun,
   {{0x63a91990,0x63bb1991,0x27ed0027,0xf412006e}},	// [10e0] nyen, nzun, _nyen_, מפן_,
   {{0xfeba00bf,0x290d0d2a,0x68e91992,0x63bb1993}},	//   _ساخت_, _aiea_, _aked, izun,
   {{0x6da61994,0x27ed05aa,0x09f61278,0x8cc1023a}},	//   _сина, _ayen_, учая, रोहो,
   {{0x270f007d,0xd7fa1995,0x68fb1996,0x7e7e1997}},	//   ादूर_, нул_, _chud, _happ,
   {{0x7e7e1998,0x96ea0bd5,0xddc71515,0x3d1a0caf}},	//   _kapp, нька_, mejš, _मंडे_,
   {{0x7e7e03e5,0xddc71999,0x68e90134,0x68fb039f}},	//   _japp, lejš, _eked, _ehud,
   {{0x7e7e199a,0x7b0916a2,0x9f45199b,0xd639004d}},	//   _mapp, _ožuj, ́là_, тячі_,
   {{0xddc7199c,0x3a3a199d,0x63bb042c,0x6b8409a1}},	//   nejš, lapp_, fzun, ovig,
   {{0xa3de04dd,0x63a9199e,0x6b6701d3,0x6b84059a}},	//   _दुख_, gyen, cīgā, nvig,
   {{0x7e7e199f,0xf12619a0,0x22580342,0xe3130037}},	//   _napp, льмо, ürk_, حبيب,
   {{0x23ba0032,0xc6100179,0x6b8400bc,0x63a902ac}},	//   _bàjé_, ाशीय_, hvig, ayen,
   {{0x657a0113,0x7e7e19a1,0x63a919a2,0x6f16033c}},	//   _isth, _aapp, byen, _buyc,
   {{0xdb0419a3,0x7e7e0085,0x3a3a19a4,0x4fc719a5}},	//   nzió, _bapp, kapp_, усна,
   {{0x7e7e19a6,0x00000000,0x00000000,0x00000000}},	//   _capp, --, --, --,
   {{0x7e7e19a7,0xccfb0831,0x291c0094,0x7eb000bc}},	//   _dapp, ећа_, íval_, _täpn,
   {{0x61f519a8,0x00000000,0x00000000,0x00000000}},	//   üzle, --, --, --,
   {{0x5a3519a9,0x7afc009c,0x00000000,0x00000000}},	// [10f0] инат, _bhrt, --, --,
   {{0x68fb0022,0x68e919aa,0x6113020a,0x6b6700e8}},	//   _shud, _sked, _săli, vīgā,
   {{0x657a01fa,0x7ae519ab,0x2d9e004d,0x7dd20103}},	//   _nsth, roht, øtet_, rűsé,
   {{0xf77104f4,0x7e7e19ac,0xddc719ad,0x6b6700e8}},	//   قات_, _zapp, cejš, tīgā,
   {{0x7c2d19ae,0x69dc05b4,0x2ab60537,0x4e1919af}},	//   mbar, _exre, _sæbe_, _दलाई_,
   {{0x6b6700d9,0xe4630555,0x89370281,0x63bb013c}},	//   rīgā, şmüş, _معرا, vzun,
   {{0x7d0f0068,0x5e5800c1,0x68fb19b0,0x00000000}},	//   _kics, טיגע_, _thud, --,
   {{0x63bb19b1,0x58d500d6,0x68fb00e7,0x3f8900f0}},	//   tzun, _тобт, _uhud, _orau_,
   {{0x3f89023e,0x7c2d19b2,0x27ed00fe,0x63bb19b3}},	//   _nrau_, ibar, _uyen_, uzun,
   {{0x52a919b4,0x63a919b5,0x7c2d19b6,0x387f0a00}},	//   твом_, ryen, hbar, _haur_,
   {{0x63a919b7,0x7c2d19b8,0x7e7e19b9,0x3f8901e9}},	//   syen, kbar, _rapp, _arau_,
   {{0x7e7e19ba,0x7c2d00a5,0x3f8919bb,0xf8b50336}},	//   _sapp, jbar, _brau_, ंसिय,
   {{0x442d19bc,0x7e7e19bd,0xddc719be,0x387f19bf}},	//   mbe_, _papp, vejš, _maur_,
   {{0x442d19c0,0x6b840451,0x7b09007e,0x387f19c1}},	//   lbe_, vvig, _džuk, _laur_,
   {{0x3f89002d,0x3c420018,0xddc70211,0x7c2d19c2}},	//   _erau_, _lévő_, tejš, fbar,
   {{0x0c2619c3,0x7c2d19c4,0x442d19c5,0x3f89030f}},	//   рман, gbar, nbe_, _frau_,
   {{0x442d19c6,0x3f8919c7,0x7e7e19c8,0xddc702dd}},	// [1100] ibe_, _grau_, _tapp, rejš,
   {{0x6b8419c9,0x628119ca,0xaa4619cb,0x7d1701ee}},	//   rvig, ndlo, режл, _fuxs,
   {{0x6e3c02fe,0x7c2d19cc,0x2d850c2e,0x7d0f0527}},	//   marb, bbar, ålet_, _fics,
   {{0x442d19cd,0x6e3c19ce,0x9c1400ac,0x387f01d3}},	//   jbe_, larb, _kọmp, _caur_,
   {{0x7d0419cf,0x442d19d0,0xdddc0018,0x387f0194}},	//   mmis, dbe_, merő, _daur_,
   {{0x7d0419d1,0x6b8b01c5,0x442d19d2,0x6e3c19d3}},	//   lmis, ægge, ebe_, narb,
   {{0x3856008f,0xd94319d4,0x387f078e,0x00000000}},	//   _възс, _мери, _faur_, --,
   {{0x442d0649,0x387f02a7,0xa3e70251,0x6e3c19d5}},	//   gbe_, _gaur_, _मुह_, harb,
   {{0x7d0419d6,0x291819d7,0x386619d8,0x649c0072}},	//   imis, _hura_, mfor_, _méix,
   {{0x291819d9,0x6d4117b1,0x442d0361,0x7d0419da}},	//   _kura_, šlai, abe_, hmis,
   {{0x6e3c19db,0x442d19dc,0x7b0900e7,0x657a063d}},	//   darb, bbe_, _džuh, _usth,
   {{0x386619dd,0x291819de,0x7c2d008a,0xd57700a1}},	//   nfor_, _mura_, xbar, _כתבה_,
   {{0x291819df,0x7d04007a,0x4ea719e0,0x6e3c19e1}},	//   _lura_, dmis, арва, farb,
   {{0x6e3c19e2,0xa15805b6,0x7d0419e3,0x3f890052}},	//   garb, _баку_, emis, _vrau_,
   {{0x291819e4,0x7d0f19e5,0x02fb0796,0x7d040ac1}},	//   _nura_, _pics, _שלומ, fmis,
   {{0x7d0419e6,0x7c2d19e7,0xb03519e8,0xdddc0103}},	//   gmis, ubar, _униш, gerő,
   {{0x7c2d19e9,0x291819ea,0x5c07013d,0x2fcf0149}},	// [1110] rbar, _aura_, рява, _ägg_,
   {{0x7c2d19eb,0x442d19ec,0x7d040084,0x291819ed}},	//   sbar, zbe_, amis, _bura_,
   {{0x291819ee,0x442d19ef,0x3a3819f0,0x7d0419f1}},	//   _cura_, ybe_, _derp_, bmis,
   {{0x38690653,0x7c9500e3,0x6d5519f2,0x620500a7}},	//   ýar_, _الحص, muza, ürlə,
   {{0x3cf404a9,0x29180fa3,0x7bd801e8,0x442d19f3}},	//   ंतरे_, _eura_, şvur, vbe_,
   {{0x291819f4,0x1fd90033,0x69c3002b,0x00000000}},	//   _fura_, _সরাস, únes, --,
   {{0x20d20038,0x291819f5,0x27fa00a5,0x6a220068}},	//   lšie_, _gura_, ępna_, _رہنم,
   {{0x442d01bf,0x9dd800ca,0x6e3c19f6,0x3a3800c4}},	//   ube_, יווק_, zarb, _zerp_,
   {{0x6d5519f7,0x291819f8,0x7c220610,0x6e3c026a}},	//   huza, _zura_, ñori, yarb,
   {{0x442d19f9,0x29180085,0x6d5519fa,0x628100f9}},	//   sbe_, _yura_, kuza, udlo,
   {{0x628119fb,0x7d0419fc,0x20d20220,0xe5f50037}},	//   rdlo, ymis, hšie_, _اكاد,
   {{0x9c140174,0x6d5519fd,0x00000000,0x00000000}},	//   _pọmp, duza, --, --,
   {{0x20d20038,0x6e3c19fe,0xfbc70179,0xdfd20190}},	//   jšie_, tarb, _रेलम, سيس_,
   {{0xed5a19ff,0x249f1a00,0x6d551a01,0xd5430139}},	//   лог_, ljum_, fuza, _gẹ̀g,
   {{0x7d040006,0x6e3c1a02,0x6d551a03,0xa0a60db2}},	//   tmis, rarb, guza, _гайд,
   {{0x6e3c1a04,0x3a38061c,0xceb400a7,0x998305db}},	//   sarb, _serp_, _atət_, _bejž_,
   {{0x7e751643,0x29180b8c,0x6a160b05,0x2247061d}},	// [1120] bezp, _sura_, مبار, _kdnk_,
   {{0x3f8f0396,0x6d551a05,0x7d041a06,0x2b40044c}},	//   _água_, buza, smis, rsic_,
   {{0x8fc500cd,0x5d8600e3,0x249f003e,0xd23a006e}},	//   _هزین, _الجل, kjum_, רגעל,
   {{0x3a380a88,0xb4c6074c,0x29181a07,0x20d20206}},	//   _werp_, _उगे_, _vura_, bšie_,
   {{0x38661a08,0xdd8f0421,0x6da50022,0xa3e71a09}},	//   rfor_, _قوی_, nɗan, _मुल_,
   {{0x29181114,0x6da503e3,0xe9440281,0x00000000}},	//   _tura_, iɗan, _ورزی, --,
   {{0x058600d3,0xaadd009d,0x237d00dc,0x249f01cd}},	//   сулм, _मदतक, _aswj_, fjum_,
   {{0x249f01cd,0x00000000,0x00000000,0x00000000}},	//   gjum_, --, --, --,
   {{0x6d551a0a,0x644f1a0b,0x00000000,0x00000000}},	//   zuza, ócia, --, --,
   {{0x25610068,0xe6431a0c,0x224701ff,0x29060062}},	//   ból_, _неуп, _cdnk_, lmoa_,
   {{0xf09f0472,0x764802ad,0xd6cf13c3,0x6a9b006e}},	//   tjà_, _iddy, _ثقل_, אשינ,
   {{0x9c140174,0x2ca01a0d,0x26ce1314,0x64a31a0e}},	//   _dọkp, jjid_, lifo_, _наха,
   {{0x33f60fba,0x2ca0042f,0xc7b4006e,0x6d551a0f}},	//   _اساس, djid_, קבֿ_, wuza,
   {{0x20d20181,0x6d551a10,0x3d1100c3,0x3d9500c2}},	//   všie_, tuza, _दूजे_, оигр,
   {{0x3b110090,0x00000000,0x00000000,0x00000000}},	//   _rizq_, --, --, --,
   {{0x6d551a11,0x26ce1a12,0x8cf50c10,0x853b00c1}},	//   ruza, hifo_, ізац, טגלי,
   {{0xab87013d,0x764817a4,0x7b141940,0xa4b700ca}},	// [1130] щувк, _oddy, здух, צלמה_,
   {{0x20d20220,0x705504c6,0x6d5505bd,0x249f0034}},	//   ršie_, _انکا, puza, zjum_,
   {{0xceb20796,0x69c80559,0x2d870381,0x249f01cd}},	//   _חיי_, _žder, _éne_, yjum_,
   {{0x764802ad,0x20d20181,0x515b0341,0x8af0013c}},	//   _addy, pšie_, רכאו, ftəs,
   {{0xf74500d3,0x291e0072,0x752800e8,0x656103a9}},	//   цело, _étan_, _atdz, _sqlh,
   {{0x25610068,0x79820034,0xf7701a13,0x7f3c006e}},	//   tól_, łowa, عان_, נעוו,
   {{0x04590037,0x00000000,0x00000000,0x00000000}},	//   للغة_, --, --, --,
   {{0xc3251a14,0x25610068,0x03251a15,0x7eab00aa}},	//   омик, ról_, один, _küps,
   {{0x249f0088,0x7b0900e7,0x386d00b3,0xd299004d}},	//   rjum_, _džuv, _iber_, атні_,
   {{0x02c502ec,0x68eb1a16,0x69130078,0xb1451a17}},	//   ійно, logd, _għer, онол,
   {{0xe0da1a18,0xd4e702ec,0x2bd004f8,0x21691a19}},	//   иво_, _люди, _सेना, шини_,
   {{0x237d0197,0xd00a060b,0x60cf014b,0x672900bd}},	//   _tswj_, иене_, gicm, _ktej,
   {{0x443f1a1a,0x03a50848,0x6d45169c,0xe2991a1b}},	//   mau_, _фило, _avha, _вал_,
   {{0x443f1a1c,0x645b1a1d,0x67291a1e,0x99830090}},	//   lau_, lgui, _mtej, _bejż_,
   {{0x2d8c1a1f,0x386d1a20,0xa0a61a21,0x6283078e}},	//   íde_, _ober_, _макд, _iano,
   {{0x443f1a22,0x645b1a23,0x3f86007e,0xe29a020b}},	//   nau_, ngui, _šouu_, _thưc_,
   {{0x62831a24,0x5aca055b,0x67291a25,0xeab20018}},	// [1140] _kano, алам_, _ntej, وٹر_,
   {{0x386d02d6,0x443f1a26,0x2ca01a27,0x63a60120}},	//   _aber_, hau_, sjid_, økni,
   {{0x443f1a28,0xdca61a29,0x67291a2a,0x6d410018}},	//   kau_, _дани, _atej, álat,
   {{0x186a1a2b,0x443f1a2c,0x62831a2d,0xd7240139}},	//   ради_, jau_, _lano, _aṣọg,
   {{0x443f1a2e,0x27e01a2f,0xd70a1942,0x4733004d}},	//   dau_, çin_, анде_, дніс,
   {{0x29060a00,0x9f610018,0x27e0003d,0xddde022b}},	//   smoa_, ését_, ħin_, _japů,
   {{0x68eb1a30,0x443f0150,0x67290134,0xe1e71850}},	//   bogd, fau_, _etej, _آس_,
   {{0x7c241a31,0x443f02ad,0x20050092,0x26ce019f}},	//   ncir, gau_, əlif_, sifo_,
   {{0x62831a32,0x69130090,0x8af000a7,0x7c2400c4}},	//   _bano, _għeq, qtəs, icir,
   {{0x6283030a,0x78a2049c,0x645b0d5a,0x386d0031}},	//   _cano, ljov, agui, _zber_,
   {{0x443f1a33,0xe29a00ef,0x60cf008a,0x69c11a34}},	//   bau_, _chưa_, ticm, _žlez,
   {{0x78a2007e,0x00000000,0x00000000,0x00000000}},	//   njov, --, --, --,
   {{0x442600ac,0x64401a35,0x62831a36,0xe3b21a37}},	//   _ifo_, mami, _fano, _ترا_,
   {{0x62831a38,0x7c261a39,0xfbdf030a,0x00000000}},	//   _gano, _afkr, _ddêl_, --,
   {{0xeca707ed,0x9c8300b6,0x64400239,0x4426010a}},	//   ојан, íčov, oami, _kfo_,
   {{0x6aaa01bf,0x4c9400c2,0x00000000,0x00000000}},	//   öffn, мисс, --, --,
   {{0x628310b1,0xdfd102fc,0x26cc1a3a,0x4426063d}},	// [1150] _yano, _سيد_, _omdo_, _mfo_,
   {{0x64401a3b,0x44240019,0x443f1a3c,0x6d411a3d}},	//   hami, hcm_, zau_, álas,
   {{0xceb207a6,0x6440005e,0x6729000d,0xe2a60102}},	//   _ניט_, kami, _stej, _áður_,
   {{0x5d7a00c1,0x2d811a3e,0x443f022e,0x7c2418f6}},	//   _פארק, _ishe_, xau_, ccir,
   {{0x64401a3f,0x443f013f,0x7b640c79,0x60cd06b0}},	//   dami, vau_, _отре, _mmam,
   {{0x8af001d4,0x44261a40,0x443f1a41,0xcf5800a1}},	//   stər, _afo_, wau_, קבות_,
   {{0x443f1a42,0x60cd1a43,0x7c3d1a44,0x20d20031}},	//   tau_, _omam, _kesr, hšia_,
   {{0x64401a45,0x628302fd,0x44261a46,0x16190034}},	//   gami, _sano, _cfo_, दशहर_,
   {{0x443f02e0,0x7c3d1a47,0x20d20220,0x4426039f}},	//   rau_, _mesr, jšia_, _dfo_,
   {{0x60cd1a48,0x443f1a49,0x78a904ee,0x62831a4a}},	//   _amam, sau_, _hoev, _qano,
   {{0x62831a4b,0x443f1a4c,0x64401a4d,0x78a91a4e}},	//   _vano, pau_, bami, _koev,
   {{0x62831a4f,0x44240239,0x00000000,0x00000000}},	//   _wano, ccm_, --, --,
   {{0x62830256,0x2d811a50,0xa29500d6,0x78bb030b}},	//   _tano, _ashe_, _наді, _mluv,
   {{0x78bb0890,0xe29a00de,0x2bef00aa,0x78a90bd3}},	//   _lluv, _thưa_, _आड़ू_, _loev,
   {{0xde031a51,0x6da61a52,0x443d02f1,0x78bb0283}},	//   епри, чива, _kew_, _oluv,
   {{0xdca31a53,0x61fc01e8,0x8b261855,0xc5f200ca}},	//   наси, ürle, здае, גדל_,
   {{0xeb971a54,0x6d4101cd,0x945d007f,0x5f461454}},	// [1160] пит_, álar, lińs, _عندل,
   {{0x09e61121,0x7c241a55,0x443d14b7,0x7c3d09a1}},	//   позн, scir, _lew_, _eesr,
   {{0x6440149c,0x78a2037a,0x78a901cb,0x00000000}},	//   yami, tjov, _boev, --,
   {{0x443d004f,0x7eab00aa,0x64401a56,0xfce61a57}},	//   _new_, _hüpp, xami, _хомо,
   {{0x64401a58,0x8af00092,0x7d1e1a59,0x6b8900c4}},	//   vami, stəq, _hups, _šegv,
   {{0xab270465,0xd9460c37,0x64401a5a,0x442613b9}},	//   _хора_, _неги, wami, _sfo_,
   {{0x64401a5b,0x78a20138,0x44240072,0x09e31a5c}},	//   tami, pjov, tcm_, _зорн,
   {{0x443d0167,0x78bb1a5d,0x89db00ca,0x00000000}},	//   _cew_, _gluv, _החלי, --,
   {{0x64401a5e,0xe73702fd,0x68e30328,0x00000000}},	//   rami, _нет_, énde, --,
   {{0x64401a5f,0xbebb0052,0x6e3e0381,0x78a90381}},	//   sami, hpër, _nepb, _zoev,
   {{0x443d00a1,0x705500b9,0x2000039f,0x7d1e09a1}},	//   _few_, وندا, _azii_, _nups,
   {{0x443d1a60,0x64400372,0x69c100bc,0xdfd5013f}},	//   _gew_, qami, _ülee, домы,
   {{0x2d8c02b6,0xdcb10023,0x00000000,0x00000000}},	//   æden_, ểm_, --, --,
   {{0x7bc416d7,0x20d21a61,0x7c3d1a62,0x00000000}},	//   dziu, ršia_, _sesr, --,
   {{0x443d1a63,0xdd940138,0x7eb000aa,0x290400c4}},	//   _yew_, нары, _näpu, _ohma_,
   {{0x60cd1a64,0x20d20031,0x62881a65,0x7d1e1a66}},	//   _umam, pšia_, lddo, _dups,
   {{0x2bc70a30,0x5b151a67,0xfbd30452,0x00000000}},	// [1170] _रेखा, дмат, رتر_, --,
   {{0x7b090542,0x62881a68,0x2d81022e,0x6da501c2}},	//   _ažur, nddo, _tshe_, nɗak,
   {{0x2d8c0501,0x2d811a69,0x60dd1a6a,0x7bc4078e}},	//   ådet_, _ushe_, onsm, aziu,
   {{0x6d550a9e,0xcfd20af0,0x2904009c,0x3157006e}},	//   mrza, _apẹẹ, _chma_, ליבן_,
   {{0x629803ee,0x7b0900e7,0x2bc819c3,0x9be4004d}},	//   _onvo, _džur, _еуро_, _зірк,
   {{0x443d003d,0x6b8d02a4,0x6d551a6b,0x00000000}},	//   _sew_, mvag, orza, --,
   {{0x78a9043e,0x58d502ec,0x6f17037a,0x6d471a6c}},	//   _toev, _жовт, _mixc, nsja,
   {{0xe3b91a6d,0x6add02d5,0x62881a6e,0x6d480076}},	//   жби_, _मदुर, eddo, ádai,
   {{0xa3e70782,0xf770003f,0x27ff08bb,0x62881a6f}},	//   _मुख_, _مال_, _uzun_, fddo,
   {{0x25e802b0,0xfc3f1a70,0x04fd0033,0x6d4700bc}},	//   _चुकी_, _leí_, ঁদের_, ksja,
   {{0x76431a71,0x6d550034,0x41b4083c,0xc0e6001f}},	//   many, jrza, есят, донк,
   {{0x62981a72,0x6d551197,0x644b01c5,0x76431a73}},	//   _envo, drza, _udgi, lany,
   {{0x7d1e0039,0x6d55007f,0x945d007f,0x00000000}},	//   _sups, erza, sińs, --,
   {{0x76431a74,0xe299002d,0x7bc40052,0xa3d3058f}},	//   nany, _фак_, vziu, _हेय_,
   {{0x9fa00629,0x76430172,0x00000000,0x00000000}},	//   _méér_, iany, --, --,
   {{0x76431a75,0xc10600e3,0x7bc401ff,0x00000000}},	//   hany, _توبي, tziu, --,
   {{0x76431a76,0xcb671a77,0xbebb023b,0x6d4700aa}},	// [1180] kany, мате_, rpër, asja,
   {{0x76431a78,0x0f5700ca,0xae220179,0xbebb0216}},	//   jany, _קיים_, _मलिन_, spër,
   {{0x76431a79,0x7e7c1a7a,0x673b1a7b,0x5e9b00ca}},	//   dany, merp, _awuj, _וביק,
   {{0x6d5c1a7c,0x673b0169,0x395a1a7d,0xbebb0216}},	//   mura, _bwuj, rups_, qpër,
   {{0x76431a7e,0x6d5c0706,0x628802e0,0xb9060971}},	//   fany, lura, yddo, _पद_,
   {{0x395a1a7f,0x76431a80,0x3ced042d,0x7c360727}},	//   pups_, gany, čeve_, lbyr,
   {{0x6d5c1a81,0xf9831a82,0x673b039f,0x7e7c02ac}},	//   nura, _игро, _ewuj, ierp,
   {{0x2ebb0714,0x7e7c1a83,0x7b0914f3,0x7643010a}},	//   _उत्त, herp, _užur, aany,
   {{0x76431a84,0x00000000,0x00000000,0x00000000}},	//   bany, --, --, --,
   {{0xd25000bf,0x7643023f,0xeb9100c1,0x7e7c0120}},	//   دند_, cany, אָט_, jerp,
   {{0x628802ad,0x7e7c1a85,0x20d20344,0xf1aa001c}},	//   rddo, derp, ršin_, زاده_,
   {{0x6d5c1a86,0x67201a87,0x04930037,0x9fa001cb}},	//   dura, _kumj, _للمح, _zéér_,
   {{0x6f170167,0xfc3f037a,0x60dd1a88,0x20d2007e}},	//   _pixc, _reí_, rnsm, pšin_,
   {{0x6d5c0010,0x7e7c1a89,0x62980364,0x6d471a8a}},	//   fura, gerp, _unvo, tsja,
   {{0xf1a202d5,0x9f9902ac,0x6d5501cb,0x00000000}},	//   _ओपिन, _dáár_, urza, --,
   {{0x76431a8b,0x6d471a8c,0x20c20037,0x7c361a8d}},	//   zany, rsja, _cóid_, gbyr,
   {{0x76431a8e,0x2d9e02e2,0x2d8c038c,0x6d471a8f}},	// [1190] yany, äter_, åder_, ssja,
   {{0x6d5c1a8e,0x9af500e3,0x32c00139,0xf38800fe}},	//   bura, ركات, _fòye_, _mợ_,
   {{0x76431a90,0x6d5c1a91,0x6b8d1a92,0xc98400d3}},	//   vany, cura, svag, куци,
   {{0x76431a93,0x2bd01a94,0xe0df0451,0x69c502db}},	//   wany, _सेवा, nnò_, rzhe,
   {{0x76431a95,0x7d0d1a96,0xf3880019,0xd62905da}},	//   tany, mmas, _nợ_, поле_,
   {{0x7d0d1a97,0xddde1a98,0x00000000,0x00000000}},	//   lmas, _hapš, --, --,
   {{0x76431a99,0x00000000,0x00000000,0x00000000}},	//   rany, --, --, --,
   {{0x7d0d1a9a,0x76431a9b,0xb3851a9c,0x9fa001cb}},	//   nmas, sany, елил, _wéér_,
   {{0x76431a9d,0x7d0d1a9e,0x3755001c,0x76751a9f}},	//   pany, imas, _سپاس, _плаф,
   {{0x130602fd,0x6d5c1aa0,0x7d0d1aa1,0x261902d5}},	//   нный_, yura, hmas, _पलटी_,
   {{0xd12e0159,0xe4a7002d,0x7d0d026a,0x6d5c01e9}},	//   یمی_, _ордо, kmas, xura,
   {{0x764100fb,0xf9920130,0x2ec81244,0x3cfb0034}},	//   _hely, ארט_, रफ्त, ्षों_,
   {{0xe8df00ac,0x42cd0081,0x6d5c1aa2,0x76410138}},	//   _abịa_, রকৌশ, wura, _kely,
   {{0x91e50e58,0x6d5c1aa3,0xe0df0036,0x7521010a}},	//   _поле, tura, anò_, _kulz,
   {{0x76411aa4,0xa3d302d5,0xc5f2006e,0x41b200d1}},	//   _mely, _हेत_, ָדן_, _ممور,
   {{0x7d0d1aa5,0x76411aa6,0x7af5010a,0x7f5d00fc}},	//   gmas, _lely, _akzt, busq,
   {{0x245a026a,0x75210052,0x6b8914f3,0x7c361aa7}},	// [11a0] lümü_, _lulz, _šegr, rbyr,
   {{0x6d5c1aa8,0x160f07d5,0xb05b160c,0x7d0d1aa9}},	//   pura, ाधार_, nhän, amas,
   {{0x8c460c28,0x6d5c13d7,0x245a03e0,0xcee91aaa}},	//   _пене, qura, nümü_, _ترين_,
   {{0x7eb0007a,0x22451aab,0x20d2042d,0x00000000}},	//   _täps, halk_, kšim_, --,
   {{0x20d20087,0xa2b4030b,0x2b49020a,0x22451aac}},	//   jšim_, ेसम्, csac_, kalk_,
   {{0x09bf0033,0x7641030a,0x0cc30033,0xf388020b}},	//   _আশরা, _cely, ্কৃত, _rợ_,
   {{0xf3880019,0xceb300ca,0x76410178,0x00000000}},	//   _sợ_, ריו_, _dely, --,
   {{0x752100e1,0xd3a61aad,0x69c100bc,0x67200350}},	//   _dulz, ероп, _ülea, _tumj,
   {{0x22450524,0xb05b042c,0x76411aae,0x00000000}},	//   falk_, fhän, _fely, --,
   {{0xf3880028,0x76411aaf,0x6aae02b6,0x7d0d071d}},	//   _vợ_, _gely, _jobf, zmas,
   {{0x1dcf0251,0x6d1f0378,0x7d0d1ab0,0x3ce0032e}},	//   _हेंत, _मूंग_, ymas, kniv_,
   {{0x254c00b6,0x7d0d00a7,0x6add1ab1,0x61f80e43}},	//   měl_, xmas, _मद्र, _vyvl,
   {{0xe29a1ab2,0xb05b01bf,0xe0df0451,0x22451ab3}},	//   _над_, bhän, rnò_, balk_,
   {{0x6442036b,0x245a0233,0xb60600d8,0x00000000}},	//   _heoi, bümü_, _etáž, --,
   {{0x7d0d1ab4,0x20c2033c,0x00000000,0x00000000}},	//   tmas, _dóib_, --, --,
   {{0xdc88002d,0xccf80291,0x628a0178,0x00000000}},	//   нсул_, ећу_, _hafo, --,
   {{0x7d0d06e1,0x628a1ab5,0xddde00c4,0x64421909}},	// [11b0] rmas, _kafo, _vapš, _meoi,
   {{0x64421ab6,0x00000000,0x00000000,0x00000000}},	//   _leoi, --, --, --,
   {{0x76411ab7,0xd99900e3,0x628a1ab8,0x7d0d1ab9}},	//   _rely, بنات_, _mafo, pmas,
   {{0x76411aba,0x6442036b,0x628a1abb,0x254c00b6}},	//   _sely, _neoi, _lafo, děl_,
   {{0x81bc01d3,0x245a020e,0x7eb01abc,0x752102db}},	//   ucēj, zümü_, _käpp, _sulz,
   {{0x75211abd,0x69d5009d,0x20d2042d,0xf6530068}},	//   _pulz, _येथी, všim_, ائش_,
   {{0x644200e3,0x764100c6,0x22451abe,0xb5c2004d}},	//   _beoi, _vely, valk_, ийшл,
   {{0xe7d21abf,0x64420037,0x7eb005f8,0x69cc0031}},	//   _देवप, _ceoi, _läpp, ôlež,
   {{0xe3b100e3,0x628a1ac0,0x13091aad,0x69d50096}},	//   شرة_, _bafo, мний_, _येती,
   {{0x628a0150,0x7eb0032c,0xb6060094,0x2ca91ac1}},	//   _cafo, _näpp, _stáž, hjad_,
   {{0x628a1ac2,0xb05b0e74,0x64421ac3,0x2258007f}},	//   _dafo, rhän, _feoi, órka_,
   {{0x64420cc2,0xe3b0110a,0xe5080037,0x20d20995}},	//   _geoi, _گرم_, _كيلو_, pšim_,
   {{0xb05b0222,0x2ca91ac4,0x22451ac5,0x999302c6}},	//   mhäl, djad_, palk_, čeře_,
   {{0x798200a5,0x628a0150,0x00000000,0x00000000}},	//   łowi, _gafo, --, --,
   {{0x20040220,0xbea307ed,0x8af000a7,0x20c2033c}},	//   ťmi_, шарк, frən, _cóic_,
   {{0x248d1ac6,0xa3e51073,0x1fb61ac7,0x1d071ac8}},	//   ndem_, _नशा_, _асор, веси_,
   {{0x2c070285,0x236d006c,0x248d04f8,0x628a04ff}},	// [11c0] _शरणं_, ntej_, idem_, _yafo,
   {{0x3ce0023e,0x63a60212,0xa2d40179,0x628a00ee}},	//   sniv_, äkni, योप्, _xafo,
   {{0xae5700ca,0xc96605b6,0x41c10285,0x00000000}},	//   _בסיס_, твей, शनिस, --,
   {{0x799500a5,0x38cb1ac9,0x290f0124,0x248d1aca}},	//   _drzw, وانی_, gmga_, jdem_,
   {{0x6d5a013f,0xf0930089,0xe7d20096,0x23d00034}},	//   štad, ינא_, _देशप, _तेंद,
   {{0x248d003d,0x254c00b6,0x64420076,0x7ccc013c}},	//   edem_, těl_, _seoi, rşru,
   {{0xe9a31acb,0x628a003e,0x64421acc,0xa01b01f9}},	//   _карп, _rafo, _peoi, ldöt,
   {{0xb86609b4,0x628a02ad,0x00000000,0x00000000}},	//   _جاسو, _safo, --, --,
   {{0x2c6d0018,0xaa82003e,0x69e7020a,0xd62a02a0}},	//   lódó_, _þýsk, ăreţ, _жозе_,
   {{0x68e21acd,0x00000000,0x00000000,0x00000000}},	//   lnod, --, --, --,
   {{0x9f4f0088,0x64421ace,0xe3af0281,0xc8b600aa}},	//   _ágú_, _teoi, مری_, _अकाट,
   {{0x9f351acf,0xe3ba032d,0x68e200f0,0x6b8402a4}},	//   лемі, _обе_, nnod, kwig,
   {{0x35a8000f,0x628a0178,0x2ca9033b,0x68e20072}},	//   _कपड़, _tafo, vjad_, inod,
   {{0x6b841ad0,0x7a4801d3,0x00000000,0x00000000}},	//   dwig, nūtē, --, --,
   {{0x1df81ad1,0x2ca900aa,0x51f3001c,0x20d209ac}},	//   веры_, tjad_, _پسور, kših_,
   {{0x20d202dd,0x2d1b0134,0xa3d609a1,0x2d9c00d8}},	//   jših_, _ụgbụ_, _सधा_, _švec_,
   {{0x68e20074,0x3a751ad2,0x2ca91ad3,0x7eb01ad4}},	// [11d0] dnod, ллар, rjad_, _täpp,
   {{0x5a341ad5,0x3f8900e7,0x68e2033c,0x248d1ad6}},	//   инут, _isau_, enod, zdem_,
   {{0x68e30fb6,0x68e202ad,0xceb2040a,0xe7030023}},	//   éndo, fnod, _היי_, _nướ,
   {{0x68e20178,0x6b840079,0x00000000,0x00000000}},	//   gnod, bwig, --, --,
   {{0xe9ff00de,0x20c2016d,0xdcb10023,0x27e91ad7}},	//   _trắc_, _jóia_, ểu_, çan_,
   {{0x7d1d0dea,0x7c2d1ad8,0xfbdf03a8,0xe70300fe}},	//   _hiss, lcar, _ddêt_, _bướ,
   {{0x68e21ad9,0xc9841ada,0x45191adb,0xb05b01bf}},	//   bnod, _кути, нция_, thäl,
   {{0x7c2d1adc,0x7d1d003d,0xdb1e0146,0xc48500ae}},	//   ncar, _jiss, _švéd, улик,
   {{0x7d1d1add,0x248d1ade,0xb05b160c,0x38930065}},	//   _miss, rdem_, rhäl, _e̟rú_,
   {{0x248d0479,0x236d1adf,0x27e00037,0x66150094}},	//   sdem_, rtej_, úine_, _úzko,
   {{0x291e025a,0x236d1ae0,0x3f8900eb,0x50460077}},	//   _état_, stej_, _asau_, ленб,
   {{0x7c2d1ae1,0xd5ba00c1,0x6b840313,0x20c20131}},	//   jcar, _אזעל, ywig, _bóia_,
   {{0xe28e1ae2,0x7c2d1ae3,0xb05b042c,0x00000000}},	//   _ла_, dcar, chäm, --,
   {{0x442d1ae4,0x7d1d1ae5,0x35d8009f,0x66f51ae6}},	//   lce_, _aiss, _भेड़, ेतिक_,
   {{0x62811ae7,0x7d1d1ae8,0x3f891ae9,0x68e20150}},	//   melo, _biss, _esau_, ynod,
   {{0x442d1aea,0x62811aeb,0x7d1d1aec,0x777b002b}},	//   nce_, lelo, _ciss, _opux,
   {{0x68e20995,0x60c41aed,0x20d2042d,0x442f1aee}},	// [11e0] vnod, _ilim, vših_, _mfg_,
   {{0xc3320054,0x62811aef,0x7bc001d4,0xdd040491}},	//   צוב_, nelo, _ümum, ırır,
   {{0x442d000d,0x2d9614d5,0x7d1d1af0,0x68e21af1}},	//   kce_, _српс, _fiss, tnod,
   {{0xdca61af2,0x7c2d1af3,0x68461491,0x442d1af4}},	//   _сами, ccar, унда, jce_,
   {{0x442d1af5,0x62811af6,0x6d4e1af7,0x60c40051}},	//   dce_, kelo, lsba, _mlim,
   {{0x56941af8,0x62811af9,0x6d5c1afa,0x60c41afb}},	//   ракт, jelo, orra, _llim,
   {{0x62811afc,0xf1a70037,0x6da501c2,0x7aeb01f9}},	//   delo, _اء_, lɗar, égte,
   {{0x442f1afd,0x6f1e00a5,0x6d4e0b77,0x6d5c026d}},	//   _cfg_, _lipc, isba, irra,
   {{0xb4e405cd,0x62811afe,0x6d5c01bf,0x8af000a7}},	//   _नदी_, felo, hrra, hrəm,
   {{0x62811aff,0x442d1b00,0x26c7030b,0x38660150}},	//   gelo, ace_, chno_, lgor_,
   {{0x60c41a3a,0x442d030b,0xb9090294,0x645d0143}},	//   _blim, bce_, _nchọ_, ósic,
   {{0x442d1b01,0x38661b02,0x2bef0081,0x6d5c0052}},	//   cce_, ngor_, চেয়ে_, drra,
   {{0xb90900ac,0xb4c00490,0x2d9e0ec9,0x6d5c1b03}},	//   _achọ_, ँसी_, åten_, erra,
   {{0x7d1d0006,0x62341b04,0x38660178,0x2f04003e}},	//   _siss, _теку, hgor_, sögn_,
   {{0x60c403e5,0x7c2d1b05,0x403503a0,0xd12f0fe9}},	//   _flim, tcar, _кейс, _ых_,
   {{0x60c41b06,0x3f89022e,0xd13816d7,0x3ced07c0}},	//   _glim, _tsau_, mpą_, čevo_,
   {{0x7d1d1b07,0x6d5c1b08,0x6d4e1b09,0xafdb02b6}},	// [11f0] _viss, arra, asba, dbøg,
   {{0x7d1d1b0a,0x442d1b0b,0x7c2d0fca,0xdea10d7f}},	//   _wiss, zce_, scar, _بیسی,
   {{0x7d1d1b0c,0x442d1b0d,0x60c400c2,0x7c2d1b0e}},	//   _tiss, yce_, _ylim, pcar,
   {{0x62811b0f,0x69c1007a,0x6d5a0095,0x60c4028d}},	//   zelo, _ülem, štac, _xlim,
   {{0x442d01d9,0x07a51b10,0x36690b22,0xa3d31b11}},	//   vce_, ралн, вало_, _हें_,
   {{0x38691b12,0x0555008f,0x442d0034,0x62811b13}},	//   żar_, атия, wce_, xelo,
   {{0x62811b14,0x442d045f,0x49930d83,0x3eb30090}},	//   velo, tce_, _دیار, _moxt_,
   {{0xed64025b,0x473518fa,0x442d1b15,0x62811b16}},	//   leží_, _внас, uce_, welo,
   {{0x628100ae,0x442d1b17,0xe730046b,0x64491b18}},	//   telo, rce_, _فصل_, raei,
   {{0x442d1b19,0x60c41b1a,0x27ff1b1b,0xd7f8002d}},	//   sce_, _slim, _iyun_, _сус_,
   {{0x62811b1c,0x442d0d95,0x60c41b1d,0x68e9004d}},	//   relo, pce_, _plim, _kjed,
   {{0x6281004c,0x65630161,0x272b052f,0x8af000a7}},	//   selo, munh, _køn_, stəx,
   {{0x7bcd1b1e,0x68e9023b,0x20c20076,0x5f0611db}},	//   jzau, _mjed, _fóin_, изма,
   {{0xed5a15de,0x6d4e1b1f,0x59b510e9,0x272b0537}},	//   ког_, tsba, ंहार, _møn_,
   {{0x68fb1b20,0x63bb1b21,0x272b0c08,0x6d5c1b22}},	//   _okud, lyun, _løn_, urra,
   {{0xdcfc03ce,0x27ff1b23,0x60c41b24,0x22470629}},	//   tvrđ, _oyun_, _ulim, _henk_,
   {{0x63bb1b25,0x63a91b26,0x26c503be,0x9c130294}},	// [1200] nyun, nxen, _ollo_, _fọma,
   {{0xc87901d4,0xed4614fa,0x63a91b27,0x68e90314}},	//   _abş_, _кноп, ixen, _ajed,
   {{0x27ff1b28,0x63bb0479,0x212700b3,0x290d00c4}},	//   _ayun_, hyun, _junh_, _bhea_,
   {{0x290d03be,0x26c5013d,0xe73a1b29,0x63bb1b2a}},	//   _chea_, _allo_, вед_, kyun,
   {{0x1634013d,0x68e90268,0x38661b2b,0x290d0503}},	//   беля, _djed, rgor_, _dhea_,
   {{0x68e91b2c,0x68fb019f,0x22470113,0xd707075f}},	//   _ejed, _ekud, _nenk_, анче_,
   {{0x65630933,0x09e30231,0x20d20031,0x27ff0065}},	//   gunh, _дорн, lšiu_, _eyun_,
   {{0x26c514e2,0x5fa6009d,0xd4971b2d,0xb4c0121d}},	//   _ello_, खमाल, арь_, ँसे_,
   {{0x63bb0018,0x63a90201,0x22471b2e,0x20d20206}},	//   gyun, gxen, _benk_, nšiu_,
   {{0x291f002d,0xb273055b,0x23bc0af0,0x9f4f020d}},	//   _ziua_, ольш, _aájú_, _âgé_,
   {{0x22471b2f,0x26dc1b30,0xfd530174,0x2ef801bf}},	//   _denk_, mivo_, _dofọ, dorf_,
   {{0x64a31b31,0x26dc1b32,0xddc500b6,0x63bb0079}},	//   _маха, livo_, _schů, byun,
   {{0x7528005c,0x76481b33,0x20d20220,0xdc2e0092}},	//   _hudz, _kedy, jšiu_, _sığo,
   {{0x764800a5,0x22471b34,0x24841b35,0x7b100364}},	//   _jedy, _genk_, lemm_, läuf,
   {{0xe3e80f71,0x75281b36,0x20000139,0xec6b016d}},	//   _পরিব, _judz, _eyii_, крак_,
   {{0x752802ef,0xc05b02ec,0x7bcd1b37,0x26dc1b38}},	//   _mudz, _рік_, tzau, hivo_,
   {{0x75280067,0x2bba0034,0x2d9a0381,0x7f44039f}},	// [1210] _ludz, jącą_, _erpe_, _gwiq,
   {{0x68e91b39,0x68fb1b3a,0x69c100aa,0x764800d1}},	//   _sjed, _skud, _ülek, _nedy,
   {{0x272b038c,0x2484003d,0xc8ab013d,0x63a4002b}},	//   _søn_, kemm_, къде_, _áinf,
   {{0xf77116cc,0x9c130174,0x00000000,0x00000000}},	//   كات_, _jọka, --, --,
   {{0x2bde1000,0x752800d9,0x68e900dd,0x76480178}},	//   _नेपा, _audz, _vjed, _bedy,
   {{0x65631b3b,0x75281b3c,0xdc3c02a1,0x20d2007e}},	//   tunh, _budz, _iġġo, lšit_,
   {{0x68e90292,0xa8a71b3d,0x785712eb,0x75281b3e}},	//   _tjed, _крак, _نیاز_, _cudz,
   {{0x68e903ce,0x65631b3f,0x224706a3,0x68fb0060}},	//   _ujed, runh, _senk_, _ukud,
   {{0x764800eb,0x00000000,0x00000000,0x00000000}},	//   _fedy, --, --, --,
   {{0x63a908a8,0x65631b40,0x26c503e3,0x68f91b41}},	//   rxen, punh, _ullo_, lowd,
   {{0x63bb1281,0x386d0357,0x95c81b42,0x2247022b}},	//   syun, _kcer_, _куца_, _venk_,
   {{0x297a0105,0x67211b43,0x397a00a1,0x60dd1b44}},	//   נטרא, _hilj, נטרנ, gism,
   {{0x443f1b45,0x6d450124,0x20050092,0x22471b46}},	//   mbu_, _awha, əlik_, _tenk_,
   {{0x443f1b47,0x6d4500f9,0x7d1801f9,0x6601007b}},	//   lbu_, _bwha, _évsz, _kylk,
   {{0xdca61b48,0x2d950ce5,0x01351b49,0x719600cd}},	//   бави, ортс, _اعتد, _هنوز_,
   {{0x443f1b4a,0x67211088,0x0c261b4b,0xfc260033}},	//   nbu_, _lilj, сман, বর্ষ_,
   {{0x443f1b4c,0x1d071b4d,0x63a41b4e,0x2d840094}},	// [1220] ibu_, сети_, _àint, ňme_,
   {{0x443f0090,0x2d9a1197,0x8e860037,0x9e661b4f}},	//   hbu_, _trpe_, _الده, _увод,
   {{0x499a1ad1,0x76481b50,0xef17002d,0x6d4503a8}},	//   ытая_, _redy, _ымь_, _gwha,
   {{0x443f0078,0x76481b51,0x75281b52,0x20d21a61}},	//   jbu_, _sedy, _rudz, pšiu_,
   {{0x7d041b53,0x75281b54,0x4b55008f,0xc053006e}},	//   mlis, _sudz, _мърт, לזא_,
   {{0x7d041b55,0xf1ca000d,0x60dd1b56,0x386d005c}},	//   llis, ानमन, zism, _ecer_,
   {{0x26dc1b57,0x67211b58,0x2d981b59,0x60dd1b5a}},	//   rivo_, _dilj, nvre_, yism,
   {{0x7d041b5b,0x60dd1b5c,0x76480150,0x2d9800fd}},	//   nlis, xism, _wedy, ivre_,
   {{0x47c600c9,0x7d041b5d,0x26dc1b5e,0xf7430a7c}},	//   _убав, ilis, pivo_, _нето,
   {{0x7d041b5f,0x660102ec,0x41541b60,0x60dd0167}},	//   hlis, _fylk, овос, wism,
   {{0x443f1b61,0x8afb00c1,0x63a41b62,0x8af000a7}},	//   bbu_, רהיי, _šind, msəd,
   {{0x7d041b63,0x00000000,0x00000000,0x00000000}},	//   jlis, --, --, --,
   {{0xe6c40102,0x44261b64,0x7d040181,0x9e4b002d}},	//   _þjóð, _igo_, dlis, ţămâ,
   {{0x7d160220,0xf1a6159a,0x60dd01ce,0x7d041b65}},	//   emys, _грин, sism, elis,
   {{0x6d5a00e9,0x7d041b66,0x91fc01d3,0xb6bb006e}},	//   štan, flis, zgāj, נצלי,
   {{0xd9041b67,0x7d041b68,0xa2d408c0,0x00000000}},	//   _سی_, glis, योर्, --,
   {{0x2d8c01c5,0x88bd0034,0x63a40072,0x4426020b}},	// [1230] æder_, _liśc, _áind, _mgo_,
   {{0x7d041b69,0x443f1b6a,0x2d98014b,0x61ff01f9}},	//   alis, zbu_, bvre_, _ízlé,
   {{0x7d041b6b,0x44261b6c,0x443f1b6d,0x6ab500de}},	//   blis, _ogo_, ybu_, _vozf,
   {{0x44261b6e,0x67211b6f,0x77991b70,0x20d20095}},	//   _ngo_, _silj, икер_, lšir_,
   {{0xd3661b71,0x67290890,0x443f025b,0xdbe30072}},	//   _ته_, _quej, vbu_, _téño,
   {{0x3ce900ae,0x91fc01d3,0xa3be0b3f,0xe80f0034}},	//   lnav_, rgāj, ीनन_, ़ेगा_,
   {{0x67211b72,0x442600f9,0x5fe002d5,0x0319001c}},	//   _vilj, _bgo_, _पेनल, یتخت_,
   {{0x4426033c,0x443f1b73,0x00000000,0x00000000}},	//   _cgo_, ubu_, --, --,
   {{0x443f1b74,0x7b1001bf,0xb05b0364,0x75220634}},	//   rbu_, bäud, nhäu, _dioz,
   {{0x44260857,0x66010d1b,0x443f1b75,0x7d161b76}},	//   _ego_, _tylk, sbu_, zmys,
   {{0x00861b77,0x7d041b78,0xd04f00a7,0x00000000}},	//   олно, ylis, licə, --,
   {{0x2eb41b79,0xc9520089,0x9c130134,0x7d0401ee}},	//   ुस्त, ומט_, _tọha, xlis,
   {{0xfc460181,0xbebb023b,0x7d040233,0x2d81039f}},	//   šíka_, jqës, vlis, _aphe_,
   {{0x61451b7a,0x7d041b7b,0x644b05bd,0x75220062}},	//   _дека, wlis, _hegi, _zioz,
   {{0x644b1b7c,0x7d040973,0xdddc09ac,0x2d980668}},	//   _kegi, tlis, ferš, uvre_,
   {{0x0ce80081,0xdca31543,0xb05b1531,0x7d041b7d}},	//   পত্ত, маси, lkän, ulis,
   {{0x7d041b7e,0xeb970084,0x644b1b7f,0x8b2600d6}},	// [1240] rlis, оит_, _megi, ідже,
   {{0xda6600e3,0x7d1602c6,0xda650037,0xb05b1b80}},	//   تاري, smys, كامي, nkän,
   {{0x7d041b81,0x645900a5,0x1d0a1b82,0xdddc1726}},	//   plis, _odwi, _вени_, berš,
   {{0xb17a006e,0xe8fa0b36,0xa8a30215,0xa17a006e}},	//   יטער, шле_, дршк, יטעט,
   {{0xb05b02c3,0x442600fc,0x00000000,0x00000000}},	//   phäv, _rgo_, --, --,
   {{0x8f9b1b83,0xe0df0451,0xd946007e,0xbf9b0142}},	//   ייני, ziò_, _меги, יינש,
   {{0x2bde06ec,0xb05b0149,0xe5a30284,0x91fc00e8}},	//   _नेता, dkän, дији, rgāk,
   {{0x644b1765,0x18671a19,0x8af0013c,0x00000000}},	//   _cegi, _маси_, ssəd, --,
   {{0x644b1b84,0xe0df0036,0xfd4e0294,0x00000000}},	//   _degi, viò_, takị, --,
   {{0x64591b85,0x3ce0007a,0x8af00092,0x64570022}},	//   _edwi, hiiv_, qsəd, _ɗaiɗ,
   {{0x27301b86,0x644b1b87,0x75220131,0x75d60076}},	//   _hàn_, _fegi, _tioz, _بيضا,
   {{0x6ab70bd9,0x44261b88,0xbebb023b,0x644b1b89}},	//   _आक्र, _ugo_, yqës, _gegi,
   {{0x6d5a0941,0x69c1007a,0x3ce9033b,0x290601ff}},	//   štal, _ülev, vnav_, iloa_,
   {{0x20050029,0x27300028,0xdefb0ab3,0x2bd5030b}},	//   āli_, _màn_, рым_, _ठेगा,
   {{0x27301b8a,0x62881b8b,0xc8bc152c,0x853c0138}},	//   _làn_, medo, ्घाट, _drėg,
   {{0x62881b8c,0x5ce70120,0x00000000,0x00000000}},	//   ledo, іюва, --, --,
   {{0x60c01b8d,0x27300023,0x3ce91b8e,0x00000000}},	// [1250] ömme, _nàn_, rnav_, --,
   {{0x62881b8f,0xb4c706eb,0x7f84015a,0x77621b90}},	//   nedo, _उत्_, _کلین, drox,
   {{0xdc3f025b,0xb05b02db,0x00000000,0x00000000}},	//   líčk, shäu, --, --,
   {{0xd04f01d4,0x27301b91,0x62880134,0x26f51b92}},	//   ticə, _bàn_, hedo, ेत्र_,
   {{0xf7451339,0xdc3f0579,0x6d550103,0x23d90104}},	//   чело, níčk, lsza, _बेंद,
   {{0x27301b93,0x644b1b94,0x62880fa3,0x6b8d1b95}},	//   _dàn_, _segi, jedo, mwag,
   {{0x62881b96,0x6b8d0ab2,0xb05b02c3,0x00000000}},	//   dedo, lwag, vkän, --,
   {{0x28f8004d,0x00000000,0x00000000,0x00000000}},	//   _десь_, --, --, --,
   {{0x6b8d1b97,0x644b003e,0xf41f0084,0xdc3f0146}},	//   nwag, _vegi, ää_, jíčk,
   {{0x62881b98,0x644b1b99,0x04fd0081,0x2cb9009c}},	//   gedo, _wegi, ুদের_, _losd_,
   {{0x644b1b9a,0x6b8d1b9b,0xb05b1531,0x68eb00fe}},	//   _tegi, hwag, rkän, ongd,
   {{0x6b8d1651,0xb05b02c3,0x69c109a1,0x00000000}},	//   kwag, skän, _üleu, --,
   {{0xa3d3009d,0x62881b9c,0xe2991b9d,0x20040088}},	//   _हेच_, bedo, _гал_, æmi_,
   {{0x6d5a077e,0x2cb901b9,0x62881b9e,0xb05b1b9f}},	//   štam, _aosd_, cedo, lkäl,
   {{0x2d9e0074,0x6da31b4d,0x7643005c,0x6d550018}},	//   íte_, нира, ibny, gsza,
   {{0xd7bd0096,0x2cb901b9,0xb05b16f9,0xdc3f0094}},	//   ्नाच, _cosd_, nkäl, bíčk,
   {{0x673b022e,0x6b8d1ba0,0xab660f5f,0x00000000}},	// [1260] _ntuj, gwag, явал, --,
   {{0x0e660084,0x3f921ba1,0xcff700ca,0x80aa0e1f}},	//   _экон, _isyu_, _מצפה_, टावे,
   {{0x27301ba2,0x3ebb00a1,0x98b00335,0xdebb00a1}},	//   _sàn_, _הציב, šači_, _המיל,
   {{0x77621ba3,0x6b8d1ba4,0xeb9f01df,0x186a1ba5}},	//   trox, bwag, _frø_, сади_,
   {{0xfc3f1ba6,0x65630364,0x47331ba7,0x6b8d05bd}},	//   _unía_, ernh, еніс, cwag,
   {{0x62881ba8,0x996400b6,0x2b401ba9,0x273000fe}},	//   xedo, může_, mpic_, _vàn_,
   {{0xb0cc0bf5,0x38a50174,0x673b007b,0xdc3f00d4}},	//   ासाग, ịram_, _etuj, zíčk,
   {{0x628802ad,0x27301baa,0x77621bab,0x6f020076}},	//   wedo, _tàn_, prox, _íocf,
   {{0x764301f9,0x6563009c,0x00000000,0x00000000}},	//   bbny, arnh, --, --,
   {{0xb6c80068,0x7afe1bac,0x68e21bad,0x86ea0037}},	//   _بارے_, nopt, liod, _اعرف_,
   {{0x6d5a00e9,0x6b8d1bae,0x69c100aa,0xe3af0421}},	//   štaj, zwag, _ület, نری_,
   {{0xeafa055e,0x68e21baf,0x2347001c,0xdc3f0094}},	//   ्तुत_, niod, _کلوپ_, tíčk,
   {{0x62881bb0,0x98a70106,0xa4b700ca,0x3eba00b3}},	//   pedo, šići_, _מלאה_, _bopt_,
   {{0x628800dd,0x6d551bb1,0x3eba00ae,0xddeb0076}},	//   qedo, tsza, _copt_, مرأه_,
   {{0xf29703c2,0x3ebe13da,0x200c00a7,0x6b8d1bb2}},	//   _זכור_, ötta_, ədim_, wwag,
   {{0x6d551bb3,0x6b8d1bb4,0xfbde009d,0x1cbb0037}},	//   rsza, twag, _नेहम, حاسب_,
   {{0x6d550068,0x68e21bb5,0xa3be00b7,0xaca30174}},	// [1270] ssza, diod, ीनि_, _nsụd,
   {{0x6b8d1bb6,0x60cd1bb7,0x88bd0034,0xb05b0364}},	//   rwag, _hlam, _ciśn, chär,
   {{0xc178013f,0x673b005c,0x2cb901b9,0xceb20142}},	//   ntė_, _stuj, _tosd_, _סיט_,
   {{0xa3be05d4,0xc178013f,0x2ee30126,0xec6b1bb8}},	//   ीना_, itė_, lijf_, _урок_,
   {{0x3a380169,0x60cd001c,0x66cf00f3,0x69d81bb9}},	//   _ffrp_, _mlam, _løke, úver,
   {{0x60cd1bba,0x25de000d,0x7afe1bbb,0x255700ae}},	//   _llam, _केही_, copt, tăl_,
   {{0xf650012b,0x68e20139,0x60cd026a,0xb05b00c2}},	//   ائه_, biod, _olam, tkäl,
   {{0x68e2002d,0x2ee301c0,0x387f0194,0x26cc1bbc}},	//   ciod, hijf_, _ubur_, _eldo_,
   {{0xc1780138,0x673b1bbd,0x78a91bbe,0x00000000}},	//   etė_, _utuj, _inev, --,
   {{0x78bb1bbf,0x69c1007a,0x66cf00d6,0x130600c2}},	//   _houv, _üles, _bøke, мный_,
   {{0x78bb1bc0,0x208a1bc1,0x60cd1bc2,0x78a901cb}},	//   _kouv, ойни_, _blam, _knev,
   {{0xafe602ec,0x15e31bc3,0xd00a001f,0x78bb1022}},	//   домл, _केयर_, жеме_, _jouv,
   {{0x78bb1bc4,0x60cd1bc5,0x92b50037,0x00000000}},	//   _mouv, _dlam, _يحتا, --,
   {{0x78bb1bc6,0x60cd1bc7,0xafdb0170,0x00000000}},	//   _louv, _elam, mbøl, --,
   {{0x60cd1bc8,0x9998007e,0x78a918ef,0x00000000}},	//   _flam, _serž_, _onev, --,
   {{0x78bb1bc9,0x7afe022b,0x68e2002b,0xb05b1bca}},	//   _nouv, wopt, xiod, shär,
   {{0xb05b01bf,0x3207030a,0xa2d40635,0x00000000}},	// [1280] phär, _hyny_, योक्, --,
   {{0x273b00ae,0x78a9078e,0x2b401a4a,0x00000000}},	//   _mână_, _anev, rpic_, --,
   {{0x2d9c0018,0xdce9026a,0x78bb1bcb,0x2b400141}},	//   _éve_, _çoğu, _bouv, spic_,
   {{0x78bb025a,0x5883055b,0x60cd0063,0x88bd007f}},	//   _couv, выша, _xlam, _wiśn,
   {{0x78bb02f1,0xd5af001c,0x711b006e,0xba56008f}},	//   _douv, یفه_, קונפ, _отвъ,
   {{0x68e21bcc,0xc1780138,0x78a91bcd,0x46a31bce}},	//   siod, ytė_, _enev, качв,
   {{0x06c20033,0xdddc00d4,0x26190d75,0x00000000}},	//   ্চলি, berť, येली_, --,
   {{0x78bb1bcf,0x6abc0088,0x23c90096,0x78a9049c}},	//   _gouv, _horf, िनंद, _gnev,
   {{0x66cf00d6,0x69c100bc,0x60cd01f7,0x00000000}},	//   _søke, _üler, _rlam, --,
   {{0x60cd1bd0,0xf7431bd1,0xf7d70089,0xc17a004d}},	//   _slam, _рефо, _חומש_, оїм_,
   {{0xa50a00d3,0xb05b17a5,0xa2d41bd2,0x00000000}},	//   _дежа_, skäm, योग्, --,
   {{0xc178013f,0x2249077e,0x30a70a01,0xd4c60037}},	//   rtė_, _đake_, фров, _تغطي,
   {{0x351b00c1,0xc178013f,0x60cd04e2,0x60c00212}},	//   _וואנ, stė_, _vlam, ömma,
   {{0x32070150,0x63a21bd3,0x213c0023,0x00000000}},	//   _fyny_, _iron, _ttvh_, --,
   {{0x63a21bd4,0x67281bd5,0x27fa00a5,0x2ee3029a}},	//   _hron, _midj, ępny_, rijf_,
   {{0x60cd1bd6,0x629a1bd7,0x6ee900cb,0x66080113}},	//   _ulam, ldto, džbe, _mydk,
   {{0x5b151bd8,0x63a200bf,0x62981bd9,0x6abc1bda}},	// [1290] емат, _jron, _kavo, _borf,
   {{0x78bb1bdb,0x6abc0150,0x29041bdc,0x672802ef}},	//   _souv, _corf, _akma_, _nidj,
   {{0x78bb1bdd,0x25de02e8,0x78a90087,0xae1b0034}},	//   _pouv, _केली_, _pnev, फेशन_,
   {{0x62980020,0x63a21bde,0x7d0903e5,0x20091bdf}},	//   _lavo, _oron, ċess, _kyai_,
   {{0x6abc1be0,0x21290063,0x672802f1,0x7f4d009e}},	//   _forf, _miah_, _bidj, _jwaq,
   {{0x6abc02ad,0x7f4d009e,0xda7e0206,0x2d87014b}},	//   _gorf, _mwaq, íďte_, _ânes_,
   {{0x63a21be1,0xd5b11b49,0x7f4d0372,0x2d910169}},	//   _aron, افع_, _lwaq, nwze_,
   {{0x273b002d,0x21290063,0x629a0ed0,0xe3b905cb}},	//   _până_, _niah_, edto, зби_,
   {{0x65930092,0x2009060f,0x03251be2,0xf7701a37}},	//   _məhə, _nyai_, ндин, _نال_,
   {{0x7dee0018,0x629800e5,0x3f4d1be3,0x672800bd}},	//   nősé, _cavo, džu_, _gidj,
   {{0x62981be4,0x69c50a1f,0x21290063,0x7f4d063d}},	//   _davo, nyhe, _biah_, _awaq,
   {{0x0ef80455,0xf9da00c1,0x629a1be5,0x6593013c}},	//   ंक्स_, פֿיל, adto, _nəhə,
   {{0x63a21be6,0x212902e7,0xafdb0537,0xe81700c3}},	//   _gron, _diah_, lbøj, _तरफा_,
   {{0x248d04de,0xe3b000d0,0x62981be7,0x6d42007e}},	//   leem_, _خرم_, _gavo, _čoab,
   {{0x57bd033a,0xdd921be8,0x7f4d039f,0x00000000}},	//   ्नुह, دوز_, _ewaq, --,
   {{0x248d0665,0x91fc01d3,0x659300a7,0xeafa00aa}},	//   neem_, rgāt, _cəhə, ्त्त_,
   {{0xc4d200c1,0x6abc1be9,0x2cab037a,0x62980027}},	// [12a0] אגן_, _porf, _dncd_, _yavo,
   {{0x248d006c,0x00000000,0x00000000,0x00000000}},	//   heem_, --, --, --,
   {{0xa84a0037,0x67280580,0x6abc1bea,0x2cab022b}},	//   كلام_, _ridj, _vorf, _fncd_,
   {{0x67281beb,0x00000000,0x00000000,0x00000000}},	//   _sidj, --, --, --,
   {{0x66e61bec,0x1c1c1bed,0x6abc1bee,0x248d1bef}},	//   нода, पेशल_, _torf, deem_,
   {{0x69c51bf0,0x659300a7,0x6d411bf1,0xb05b007b}},	//   byhe, _zəhə, ílag, tkäk,
   {{0x67281bf2,0x248d023e,0xa2c30d77,0x691102c3}},	//   _vidj, feem_, ाउन्, måen,
   {{0x62981bf3,0x67281bf4,0x692c020a,0x62831bf5}},	//   _savo, _widj, _eşec, _abno,
   {{0x62981bf6,0xe3b20190,0x60430294,0x21290f5a}},	//   _pavo, ارع_, ọmkw, _riah_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2009005c,0x21290063,0x63a200ca,0x20c21bf7}},	//   _syai_, _piah_, _wron, _nóis_,
   {{0x63a2011b,0x3cfa0034,0x00000000,0x00000000}},	//   _tron, ंवों_, --, --,
   {{0x09dd0961,0xbfa81995,0x62981bf8,0xd8db00ca}},	//   _मध्य, нтре_, _tavo, לקטר,
   {{0x61eb0018,0x63ad031a,0xb3e90037,0x659300a7}},	//   állá, _šang, _تعمل_, _səhə,
   {{0xe29b00c1,0x7ae50117,0xe297125f,0x00000000}},	//   _זשור, viht, _чај_, --,
   {{0xb05b00c2,0x2f1602b6,0xfd1307e8,0x7f4d003d}},	//   kkäi, væge_, اجس_, _twaq,
   {{0x3a751bf9,0x7dee0068,0xe7e00ed3,0x2d9e0e3e}},	// [12b0] клар, tősé, _खेला_, åter_,
   {{0x69111bfa,0x63bd038c,0x257a0052,0x248d1bfb}},	//   gåen, øsni, kël_, zeem_,
   {{0x1df90084,0x7ae51bfc,0x291d0027,0xb05b00ce}},	//   _цены_, riht, tmwa_, tkäh,
   {{0xf7711a13,0xa90703ef,0x248d01fa,0x69c50313}},	//   لات_, ربان, xeem_, ryhe,
   {{0x7d0d1bfd,0x57bd00b6,0xadfc0034,0x257a0313}},	//   mlas, ्नेह, _एडऑन_, eël_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5a03ce,0x257a00dd,0x1af41bfe,0x8aa4008f}},	//   štav, gël_, _спря, _сряд,
   {{0x7d0d1bff,0x262501c2,0xa3be00a4,0x00000000}},	//   nlas, rɓo_, ीनं_, --,
   {{0x3f890197,0x07351c00,0x248d1c01,0x8af000a7}},	//   _npau_, _резю, reem_, ksəl,
   {{0x7d0d0614,0x248d1c02,0xc3c800e3,0x257a0052}},	//   hlas, seem_, عظيم_, bël_,
   {{0x3de100c7,0xa06a1c03,0x7d0d1c04,0x860200cd}},	//   _মুসল, мана_, klas, _پژوه,
   {{0xa2a11c05,0x34950da5,0xf99200ca,0x00000000}},	//   _कोर्, _јадр, ברט_, --,
   {{0xe28e1c06,0x64491c07,0x7d0d1c08,0x2d8c003d}},	//   _ка_, mbei, dlas, ħdem_,
   {{0x64491c09,0xa3da1c0a,0x200c01d3,0x20c20037}},	//   lbei, _डेट_, ādi_, _cóir_,
   {{0xfc3f0031,0x64490062,0x443d1c0b,0x628101ab}},	//   _kníh_, obei, _kfw_, mflo,
   {{0x64491c0c,0x753c0018,0x443d0167,0x98b801d3}},	//   nbei, _érze, _jfw_, _otrā_,
   {{0x69111c0d,0x1d071c0e,0x442f0167,0x0c261c0f}},	// [12c0] tåen, тети_, _mgg_, тман,
   {{0x62810078,0x4a43135d,0x7d0d00aa,0x692c044c}},	//   nflo, инув, alas, _aşea,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf7461312,0x2d3e00ac,0x442f0483,0x8af0013c}},	//   ведо, _ọgwụ_, _ngg_, msəm,
   {{0xd7ef0080,0x7d041c10,0x09290037,0xb8650018}},	//   يكم_, mois, رسمي_, طانو,
   {{0x7d041c11,0xa2a11c12,0x6d5a0181,0x442f0626}},	//   lois, _कोल्, štau, _agg_,
   {{0x6d5c03bd,0x1ae30c79,0xb05b00bc,0x09e61c13}},	//   nsra, _торм, skäi, _ровн,
   {{0x7d041c14,0x6d5c1c15,0x69c300c2,0x2249077e}},	//   nois, isra, änee, _đaka_,
   {{0x613e00d9,0x628107ee,0x62341c16,0x00000000}},	//   _mīle, fflo, лепу, --,
   {{0x02a61c17,0x7d0d1c18,0x7d041c19,0x442f1c1a}},	//   трим, zlas, hois, _egg_,
   {{0xf48400bf,0x7d0402fd,0xd48f1c1b,0x7d0d1c1c}},	//   _ماشی, kois, _кр_, ylas,
   {{0x6d5c1c1d,0x63ad007e,0x7d04007b,0x6ee90357}},	//   dsra, _šane, jois, džba,
   {{0x248603e3,0x7d041c1e,0xb4c00ded,0xfbdf02ac}},	//   _ibom_, dois, ुसी_, _leêr_,
   {{0x752b002b,0x76580010,0x69c10231,0x00000000}},	//   _zigz, navy, _àleg, --,
   {{0x2fcd00e9,0x7d0d1c1f,0x3cff1c20,0x6d5c0324}},	//   šeg_, tlas, लवले_, gsra,
   {{0x656a0037,0x48bd0081,0x8c3b0364,0x9d181c21}},	//   irfh, _আগ্র, _maßg, вост_,
   {{0x7d0d1c22,0xe7bd0081,0x20c200e3,0x5c07013d}},	// [12d0] rlas, _অধ্য, _tóir_, тява,
   {{0x7d0d1c23,0x76581c24,0xf09f015e,0x00000000}},	//   slas, javy, ldà_, --,
   {{0x7d0d1c25,0x7d041c26,0x6f0200e3,0x7658004b}},	//   plas, bois, _íoca, davy,
   {{0xf09f1c27,0x7d0d1a4a,0x48e10081,0x658a00a7}},	//   ndà_, qlas, যক্র, _məhd,
   {{0x973500d0,0x62811c28,0xfc3f0139,0xf0940142}},	//   اکرا, yflo, _ifí_, ינף_,
   {{0xfc3f02c6,0x00000000,0x00000000,0x00000000}},	//   _sníh_, --, --, --,
   {{0xceb4193b,0x940d00a7,0x24860131,0x00000000}},	//   ייס_, ənən_, _bbom_, --,
   {{0x26190e4c,0x3946007e,0x00000000,0x00000000}},	//   येगी_, ćost_, --, --,
   {{0x64491c29,0x27e000e3,0x57f51c2a,0x76580051}},	//   rbei, úint_, _спат, bavy,
   {{0x3ce901bb,0xf09f0428,0x64491c2b,0x7d04024a}},	//   hiav_, edà_, sbei, zois,
   {{0x62811c2c,0x7d040239,0xfad60327,0x693700c4}},	//   rflo, yois, רותך_, _oćem,
   {{0x6281003e,0x20c20037,0x27391c2d,0xe7b70096}},	//   sflo, _cóip_, _kèn_, _आपाप,
   {{0x7d041c1e,0x273906a3,0x6e290092,0xa2c302d5}},	//   vois, _jèn_, əmbə, ाउद्,
   {{0x249f1c2e,0xe29607c8,0x249d0197,0xfc3f00ee}},	//   ldum_, _баш_, _hawm_, _afí_,
   {{0xa0a6067f,0x7d040084,0x249d01bb,0x691102fe}},	//   _байд, tois, _kawm_, tåel,
   {{0x249f0102,0x7b1001bf,0x6d5c1c2f,0x72420018}},	//   ndum_, räum, rsra, _پھیل,
   {{0xcb671c30,0x237f1c31,0x8fa61c32,0x6d5c0116}},	// [12e0] лате_, ntuj_, _сапе, ssra,
   {{0xda650080,0x249d0d7d,0x8f9b00a1,0x6d5a08a8}},	//   لامي, _lawm_, _טיפי, átas,
   {{0x7d041c33,0xbebb0052,0x15e30285,0x00000000}},	//   pois, yqëz, _केलर_, --,
   {{0x249d023e,0x237f1799,0x27391c34,0x7658024a}},	//   _nawm_, ktuj_, _bèn_, wavy,
   {{0x76581c35,0x249f1c36,0x4b5500e5,0x00000000}},	//   tavy, ddum_, _въст, --,
   {{0xb8cb1c37,0x2ca0007a,0x3b0a0084,0x4e7a00c1}},	//   _को_, ldid_, _чего_, גאַצ,
   {{0x2ca000bc,0x45d40110,0xa2d700a4,0x76581c38}},	//   odid_, ройс, यसन्, ravy,
   {{0x2ca01c39,0x249d006c,0x76581c3a,0x2ed11c3b}},	//   ndid_, _cawm_, savy, _हत्त,
   {{0xc6760e25,0xe6461c3c,0x667600b1,0x249d01fa}},	//   _مطاب, _безп, _مدار, _dawm_,
   {{0x63ad025b,0x4b7b006e,0x5b7b006e,0x2d9a01c8}},	//   _šanc, עטיג, עריא, _ospe_,
   {{0x249d023e,0x7f441c3d,0xf0b51c3e,0xdb060216}},	//   _fawm_, _atiq, айнь, _arkë,
   {{0x249d023e,0x273900bf,0x2ca000dc,0x00000000}},	//   _gawm_, _yèn_, jdid_, --,
   {{0xf09f0472,0x2d9a0154,0x9f350120,0x2ca01c3f}},	//   rdà_, _aspe_, регі, ddid_,
   {{0x11d6003f,0x539b040a,0x249d023e,0x8c3b042c}},	//   _متعد, _ניוו, _zawm_, _maße,
   {{0x7f441c40,0x249d006c,0x02b10096,0x5637006e}},	//   _etiq, _yawm_, जारभ, ראלע_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4a551a6d,0x6d471c41,0xba5500f6,0x2d9a0565}},	// [12f0] икас, spja, ивај, _espe_,
   {{0xb05b01bf,0x3ce9023e,0x27391c42,0x2ca000aa}},	//   rkäu, siav_, _rèn_, adid_,
   {{0x6d5a1c43,0x249f020e,0x273902f1,0x66cf0537}},	//   štar, ydum_, _sèn_, _søko,
   {{0x6d451c44,0x237f0034,0x5c0700e5,0x27391c45}},	//   _itha, ytuj_, _бяга, _pèn_,
   {{0x249d01fa,0xb05b00c2,0x0a6b1c46,0xa2d700b6}},	//   _rawm_, lkäs, _први_, यसम्,
   {{0x249d022e,0xb6a5037e,0xe7361c47,0x00000000}},	//   _sawm_, рикл, шеш_, --,
   {{0xa56400e3,0xb05b00c2,0x249f00a7,0xb9250076}},	//   مدين, nkäs, tdum_, _نفسي,
   {{0x386000e3,0xdb060113,0xe7950421,0x6d451c48}},	//   óirt_, _arkè, _پارک, _mtha,
   {{0x249f0587,0x6d450124,0x7d1d0113,0xb05b1c49}},	//   rdum_, _ltha, _mhss, hkäs,
   {{0x237f00a5,0x6d451c4a,0x68eb1c4b,0xdddc00c6}},	//   rtuj_, _otha, ligd, verž,
   {{0x249d01bb,0x6d4501fa,0x2a7600a1,0x25b90604}},	//   _tawm_, _ntha, בעתך_, _جهاد_,
   {{0x68eb0a9f,0x25de00b6,0x60261c4c,0xa01b09a8}},	//   nigd, _केटी_, идна, rfön,
   {{0x6d451c4d,0x60dd023b,0x443f1c4e,0x00000000}},	//   _atha, ërma, mcu_, --,
   {{0x443f1c4f,0x7d1d01b9,0x68eb0009,0x995402c6}},	//   lcu_, _ahss, higd, _rýže_,
   {{0xa01b0018,0x50460036,0xddc31c50,0x68eb0009}},	//   lföl, _кейб, обри, kigd,
   {{0x1c460204,0x6d4501b9,0x645b042c,0x00000000}},	//   рнам, _dtha, naui, --,
   {{0x6d451c51,0x6f07015c,0x68eb1c52,0x2ca0007a}},	// [1300] _etha, bojc, digd, rdid_,
   {{0x60c41c53,0x645b0231,0xc3320327,0xb05b09a1}},	//   _hoim, haui, קוב_, skät,
   {{0x2d9a1c54,0xf0aa0032,0x29060350,0x00000000}},	//   _uspe_, _gbàá_, tooa_, --,
   {{0x270e0a30,0xa9670293,0x200c0092,0xdca60c3f}},	//   ित्र_, рица_, ədir_, _тами,
   {{0x443f1c55,0x02b500c3,0x3f8200d4,0x613e00e8}},	//   dcu_, _अचंभ, ntku_, _mīla,
   {{0x658a01d4,0x236d1c56,0x66d40139,0x3f8200dc}},	//   _rəhb, drej_, _bàka, itku_,
   {{0x6d4501b9,0x29060350,0x00000000,0x00000000}},	//   _xtha, pooa_, --, --,
   {{0x399b0105,0x798e0113,0x386400ae,0x63ad1c57}},	//   _בילד, _ipbw, _udmr_, _šana,
   {{0xf7431c58,0xdb0603a9,0x236d1c59,0x764100eb}},	//   _мето, _arké, grej_, _ffly,
   {{0x78a21c5a,0xdce7007f,0x443f1206,0xb05b007b}},	//   ldov, mują, acu_, ykäs,
   {{0x3a370054,0x6f070039,0x60c41c5b,0x443f0a32}},	//   ירים_, vojc, _boim, bcu_,
   {{0x60c40a21,0x69de01e9,0x236d1c5c,0x60d60178}},	//   _coim, izpe, brej_, _clym,
   {{0x77f41926,0x60c41c5d,0x6d450090,0xdce70034}},	//   _अशोक_, _doim, _stha, nują,
   {{0x0eeb00a9,0x28dd00aa,0xb05b007b,0x6ee900d4}},	//   тьми_, _मतभि, tkäs, ržbo,
   {{0x3f821c5e,0xeda400d6,0xd2f80018,0xdef801b3}},	//   atku_, ошто, _لکھا_, рыя_,
   {{0xdce700a5,0x78a21c5f,0x60d61c60,0xb05b1c61}},	//   kują, jdov, _glym, rkäs,
   {{0x78a20451,0xab38110c,0x68eb1c62,0x69de01ff}},	// [1310] ddov, ипту_, vigd, ezpe,
   {{0x6e950080,0x443f1c63,0xdce70034,0x00000000}},	//   _الدا, zcu_, dują, --,
   {{0x6d450060,0x68eb1030,0x2b49020d,0x78a01c64}},	//   _utha, tigd, spac_, _bamv,
   {{0xa3c71c65,0x271f00df,0xcd3405bc,0x00000000}},	//   _उथल_, यग्र_, _گریب, --,
   {{0x443f0335,0x2d830126,0x07a51c66,0xdce7007f}},	//   vcu_, ltje_, салн, gują,
   {{0x6b9d002b,0x98bc01d3,0x2d83029a,0x3ea11c67}},	//   _issg, īvā_, otje_, _jaht_,
   {{0x2d831c68,0x443f1c69,0x645b0b6a,0x3ea100bc}},	//   ntje_, tcu_, taui, _maht_,
   {{0xfdf800a1,0x66cf01c5,0x2d83029a,0x9479018a}},	//   ימוש_, _køkk, itje_, уску_,
   {{0x60c4006b,0x68e91c6a,0x443f1c6b,0xe3e900cd}},	//   _roim, _imed, rcu_, دکان_,
   {{0x443f0012,0x236d1c6c,0xa01b1c6d,0x60d61849}},	//   scu_, rrej_, rföl, _slym,
   {{0x66cf01c5,0x60d61c6e,0x2d831c6f,0x60c41c70}},	//   _løkk, _plym, jtje_, _poim,
   {{0x236d02dd,0xfd1f0023,0xa01b0212,0x2d830381}},	//   prej_, _nhì_, pföl, dtje_,
   {{0x60c40084,0x66cf00d6,0x6f1e0072,0x2d83029a}},	//   _voim, _nøkk, _phpc, etje_,
   {{0x78a21b32,0x291f023e,0x3f821c71,0x64591c72}},	//   zdov, _lhua_, rtku_, _hewi,
   {{0x60c41c73,0x64590da3,0x3f821c74,0x68e90212}},	//   _toim, _kewi, stku_, _omed,
   {{0xeb9a0565,0x26c51c75,0xb05b097b,0xcd2a1c76}},	//   либ_, _lolo_, skär, ужбе_,
   {{0x63bb0933,0x2d830126,0x2120028d,0xfc3f0575}},	// [1320] nxun, atje_, _ihih_, _anís_,
   {{0x68fb1c77,0x64591c78,0xf412193b,0x78a004c8}},	//   _ajud, _lewi, לפן_, _samv,
   {{0x68fb0149,0x27220019,0xdb041c79,0xfe9b00ca}},	//   _bjud, _hưng_, nvié, _גיימ,
   {{0x645902ad,0x291f1c7a,0xd7fa0a29,0xdce7007f}},	//   _newi, _chua_, лул_, tują,
   {{0x26c50038,0x96ea1068,0x68fb03a9,0x00000000}},	//   _bolo_, лька_, _djud, --,
   {{0xdce70034,0x68fb1c7b,0x8f9b0289,0x96f80161}},	//   rują, _ejud, טיני, јект_,
   {{0x6b841c7c,0x64591c7d,0x27220019,0xdce70034}},	//   ltig, _bewi, _lưng_, sują,
   {{0x63ab0085,0xdce70034,0xd4971b2d,0x26c50036}},	//   _brgn, pują, брь_, _eolo_,
   {{0x68e300dd,0xd2500080,0x645902ad,0xdddd007f}},	//   ënde, ونة_, _dewi, _łyże,
   {{0x6b841c7e,0x68e9033b,0x63ab1c7f,0x00000000}},	//   itig, _zmed, _drgn, --,
   {{0x201201c2,0x6b841c80,0xd9fa00b6,0xd3d700d1}},	//   _ayyi_, htig, ्थित_, لبیا_,
   {{0x64591c81,0x6b841c82,0x2ed109c3,0x63bb002b}},	//   _gewi, ktig, हस्त, bxun,
   {{0xdfd8013d,0x765a023b,0x272200de,0x6b840381}},	//   бър_, _kety, _cưng_, jtig,
   {{0xd9fa1c83,0x27220023,0x66cf01ce,0x8c000033}},	//   ्थात_, _dưng_, _røkk, ্ধান_,
   {{0x765a1c84,0x6b8404e2,0x69180487,0xfd1f0023}},	//   _mety, etig, víen, _phì_,
   {{0x2d830ab2,0x628801d0,0x753a0027,0xd05d00a7}},	//   rtje_, lfdo, _mutz, yisə,
   {{0x6b841c85,0x2d831c86,0x3ea11c87,0x753a1c88}},	// [1330] gtig, stje_, _taht_, _lutz,
   {{0x68e91c89,0x765a1c8a,0xf41a0033,0x433b006e}},	//   _smed, _nety, _ডলার_, טעמב,
   {{0xfd1f00ef,0x753a02dc,0x6b841c8b,0x291f01fa}},	//   _thì_, _nutz, atig, _phua_,
   {{0x26c51c8c,0x291f006c,0x481515e5,0xa3b800b6}},	//   _solo_, _qhua_, омес, ङमा_,
   {{0x660407d1,0x765a0d3e,0x6c7a00c1,0x26c51c8d}},	//   şikl, _bety, _דארפ, _polo_,
   {{0x26c50188,0x35c9022f,0x321c00d8,0x64591c8e}},	//   _qolo_, игло_, _ozvy_, _sewi,
   {{0x765a01e5,0x26c51c8f,0x291f1c90,0xd05d0092}},	//   _dety, _volo_, _thua_, sisə,
   {{0x93451c91,0xf9920796,0x68e91c92,0x68fb1c93}},	//   оние, _קרן_, _umed, _ujud,
   {{0xdcfc00d9,0x03a51c94,0x76b900d3,0x26c51c95}},	//   ntrā, ципо, _клар_, _tolo_,
   {{0xdddc0018,0x21201c96,0x765a01d0,0x272200fe}},	//   zerű, _shih_, _gety, _rưng_,
   {{0x27220023,0x63bb0072,0x00000000,0x00000000}},	//   _sưng_, sxun, --, --,
   {{0x297a00c1,0x79850150,0x7b100364,0x673b0a4b}},	//   סטרא, ithw, läut, _kuuj,
   {{0xa3bb110a,0x9405001c,0x63ab0036,0x79500154}},	//   _حاضر_, _بوشه, _urgn, _kòwò,
   {{0x673b008a,0x63a91c97,0x161d178d,0x217500ae}},	//   _muuj, mven, _फरार_, _дуир,
   {{0x63a91c98,0x6da31c99,0xed5a0e2f,0x00000000}},	//   lven, мира, роб_, --,
   {{0x63a91c9a,0x161e00c3,0x272200de,0xb4c702d5}},	//   oven, येटर_, _tưng_, _ईको_,
   {{0x0aea1c9b,0xab6600d6,0x6b841c9c,0x63a41c9d}},	// [1340] адай_, ювал, utig, _áint,
   {{0x6b841c9e,0x63a91c9f,0xaca40065,0x00000000}},	//   rtig, iven, _idọt, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x765a1ca0,0xac760018,0x6d4e13ea,0x274a0c37}},	//   _sety, _بادش, mpba, ачко_,
   {{0x765a1ca1,0x63a90126,0x6b84008a,0x7cf3003d}},	//   _pety, jven, qtig, għru,
   {{0x63a91ca2,0x645d0088,0x356a1a67,0x2d8505fe}},	//   dven, ðsin, арин_, àleg_,
   {{0xd54700c9,0xa9671ca3,0xe6da0251,0x63a91ca4}},	//   опје_, _мира_, _भतीज, even,
   {{0x387f0037,0x7d1600f2,0x94aa05af,0xf3661ca5}},	//   _gcur_, nlys, ртка_, отон,
   {{0xaca40134,0xdb0400b3,0x63a91ca6,0x00000000}},	//   _ndọt, nviï, gven, --,
   {{0x63a41ca7,0x7d1600f0,0x6f020076,0xd56400d3}},	//   _šins, hlys, _íoch, _еӂип,
   {{0xaca40294,0xdb040072,0x7d161ca8,0x6d4e01cb}},	//   _adọt, nxiñ, klys, jpba,
   {{0x63a91162,0x4035022a,0x00000000,0x00000000}},	//   bven, яемс, --, --,
   {{0x63a9002d,0x4ea71ca9,0x75220079,0x66cf00f3}},	//   cven, орва, _ihoz, _søki,
   {{0xe2971caa,0xe7f200c3,0x7d1616cf,0x00000000}},	//   _мач_, _आइना_, elys, --,
   {{0x78170bd9,0x7b1001bf,0xddc50233,0x75221c48}},	//   _तर्क_, häus, _dehş, _khoz,
   {{0xd5a407d9,0xdcee01d3,0x69c300aa,0x63a40072}},	//   _یہ_, tubā, änem, _áins,
   {{0x28ab152c,0x6d4e1cab,0x00000000,0x00000000}},	// [1350] _घोषि, apba, --, --,
   {{0x7e990018,0x387f1cac,0x395803a8,0x00000000}},	//   _اندر_, _scur_, _bwrs_, --,
   {{0xdcfc0029,0x39580150,0x0e9a00ca,0x658a00a7}},	//   strā, _cwrs_, _השתל, _səhn,
   {{0x236603ce,0x79851cad,0x6ee91cae,0x63a91caf}},	//   _ovoj_, rthw, džbi, yven,
   {{0x7d0d002d,0xba7700e3,0x66dd1cb0,0xf68000d2}},	//   moas, _واست, _lèke, ěžně_,
   {{0x7d0d1cb1,0x60dd023b,0x63a91cb2,0x752201e9}},	//   loas, ërmj, vven, _ahoz,
   {{0x39580150,0x00000000,0x00000000,0x00000000}},	//   _gwrs_, --, --, --,
   {{0x7d0d16fa,0x2ec81117,0xb4d500bc,0x75221cb3}},	//   noas, _रक्त, हसे_, _choz,
   {{0x63a90257,0xf3f900ae,0x225c05db,0x7d0d044c}},	//   uven, faţa_, _bevk_, ioas,
   {{0x67211cb4,0x225c05db,0x23660e4b,0x2b4b020b}},	//   _uhlj, _cevk_, _dvoj_, _mtcc_,
   {{0xa0a6007e,0x66dd0113,0x7d0d007b,0x00000000}},	//   панд, _cèke, koas, --,
   {{0x21060a30,0x75221cb5,0x2b4b0124,0x7d0d00ae}},	//   रवेश_, _ghoz, _otcc_, joas,
   {{0x087600c1,0xe45600c1,0xdfd20190,0x2d9c002b}},	//   הערט_, _זינט_, ريس_, _ávez_,
   {{0x75291cb6,0x00000000,0x00000000,0x00000000}},	//   lmez, --, --, --,
   {{0x2cf917ff,0x7d0d020a,0x412a00e5,0x7d1601ce}},	//   ्कूल_, foas, _локо_, tlys,
   {{0x0b460467,0x201e01d4,0x2b5902a1,0x225c0233}},	//   знан, ətin_, _bwsc_, _zevk_,
   {{0x7d160429,0xfc030360,0x2b5903a8,0x00000000}},	// [1360] rlys, епто, _cwsc_, --,
   {{0x7d161cb7,0x6d4e0aab,0xdb0401ff,0x00000000}},	//   slys, ppba, txiñ, --,
   {{0x7d160f3c,0x2d930072,0xbe3b00ca,0xdb040072}},	//   plys, _gpxe_, _לעית, uxiñ,
   {{0x7d0d1cb8,0x6f0e0094,0x684311c0,0xc18c006e}},	//   coas, lobc, енца, שטאָ,
   {{0xdc370130,0x68e31cb9,0x00000000,0x00000000}},	//   _מאכט_, ënda, --, --,
   {{0x7b100364,0x66e3097a,0x658a013c,0x75221cba}},	//   räus, ноча, _fəhl, _shoz,
   {{0x23660c0b,0x8af00092,0xceb300ca,0x39e700e5}},	//   _svoj_, ssəs, תיו_, _едро_,
   {{0x68130034,0x63610134,0x18a30219,0x225c0233}},	//   _będą, _ịnar, _пасм, _sevk_,
   {{0x6f0e01c2,0x66dd03a9,0x225c05db,0x20050233}},	//   kobc, _sèke, _pevk_, ğlik_,
   {{0xfc3f0072,0x2005020e,0x66dd0113,0xe5a61cbb}},	//   _maía_, şlik_, _pèke, _низи,
   {{0x741601f3,0xb4e20174,0x7d0d024a,0x00000000}},	//   _کوشا, áàsh, yoas, --,
   {{0x23661cbc,0x693703c6,0x09f700ca,0x55bb00ca}},	//   _tvoj_, _kćer, למים_, _למבו,
   {{0xa3cd13ae,0x7d0d1cbd,0xdfd800e5,0xbff803a0}},	//   रहण_, voas, пър_, зеях_,
   {{0x63a21cbe,0xdefb0450,0x9f4e01ab,0x00000000}},	//   _ison, сым_, ðnám_, --,
   {{0x7d0d1cbf,0x629a1cc0,0xbbc50213,0x00000000}},	//   toas, meto, लङ्क, --,
   {{0x7aee01c0,0xc8ab009f,0xfc3f0558,0x51fb00ca}},	//   _ambt, _घोंट, _baía_, _להוצ,
   {{0x7d0d002d,0xfc3f0165,0x3f9d01dc,0x00000000}},	// [1370] roas, _caía_, _èwu_, --,
   {{0x7f4d1cc1,0x63a20239,0x752902c6,0x7d0d1cc2}},	//   _itaq, _mson, zmez, soas,
   {{0x63a20085,0x7d0d1cc3,0x75290216,0x69da09a1}},	//   _lson, poas, ymez, _ütel,
   {{0x3ce01cc4,0x63a21cc5,0x629a1cc6,0x00000000}},	//   chiv_, _oson, heto, --,
   {{0x6d4a00dd,0xdcfc00d3,0x63a21cc7,0xd3661cc8}},	//   _çfar, stră, _nson, _جه_,
   {{0x629a1cc9,0x658a01d4,0x2ca91cca,0x7b10042c}},	//   jeto, _təhl, ldad_, säur,
   {{0x63a21ccb,0x7f4d009e,0x75290233,0x20ef02c6}},	//   _ason, _ltaq, tmez, třil_,
   {{0x2ca91ccc,0x7f4d0092,0xddde0154,0x00000000}},	//   ndad_, _otaq, _depň, --,
   {{0x290f06ee,0x752903e5,0xb05b0222,0x2ca90487}},	//   moga_, rmez, tjän, idad_,
   {{0x2bdf030b,0x658a00a7,0xe3ca037a,0x69c80231}},	//   पैया, _zəhm, _soñó_, _àdec,
   {{0x7f4d0b0b,0x63a21ccd,0x2ca901c2,0x93ca0103}},	//   _ataq, _eson, kdad_, مایہ_,
   {{0x290f1cce,0x386d0113,0xb40e0174,0x6aa705db}},	//   noga_, _jder_, ịpịa_, _lajf,
   {{0x2ca91ccf,0xb9150139,0x290f00b3,0x03a500d3}},	//   ddad_, _bibẹ_, ioga_, _цило,
   {{0x2ca9037a,0x629a1cd0,0x290f1cd1,0x853c0138}},	//   edad_, ceto, hoga_, _grės,
   {{0x386d02d6,0x6f0e0074,0x290f0106,0x3ce0023e}},	//   _oder_, robc, koga_, thiv_,
   {{0x386d023b,0x7f4d0090,0x290f01c2,0xb05b007b}},	//   _nder_, _ftaq, joga_, njäl,
   {{0x6aa7007e,0x394d033b,0x658a00a7,0xdb0600d4}},	// [1380] _bajf, _česa_, _rəhm, _arká,
   {{0x386d00dc,0x63a61cd2,0x7d09033b,0xb05b173a}},	//   _ader_, ækni, česa, hjäl,
   {{0xe820007d,0x88860848,0x290f1cd3,0x6283037a}},	//   _बरहा_, длеж, foga_, _mcno,
   {{0xa3bf009f,0xa3cd1cd4,0x61ee0072,0xddde022b}},	//   ीहा_, रहा_, úbli, _repň,
   {{0x8cdb0789,0x629a1cd5,0x60dd0052,0x98a402c6}},	//   नसरो, yeto, ërmi, _zimě_,
   {{0x386d1cd6,0x473300d6,0x629a0072,0xb5fc02a1}},	//   _eder_, вніс, xeto, _leġe,
   {{0xe820007d,0x290f1cd7,0x69d8181f,0x63a206b0}},	//   _बरवा_, boga_, øved, _sson,
   {{0x629a1cd8,0x3eba0063,0x66cf0120,0x290f0027}},	//   weto, _lnpt_, _søkt, coga_,
   {{0xd90d172a,0x629a1cd9,0xa6861cda,0x22490233}},	//   _این_, teto, _олад, _şaka_,
   {{0xb6cb00fb,0x68e200d4,0xd62a1cdb,0x00000000}},	//   _والے_, lhod, _дозе_, --,
   {{0x629a1cdc,0x658a01d4,0xe3af001c,0xfa7700ca}},	//   reto, _məhk, هری_, ועית_,
   {{0x75490018,0x386d00dc,0x68e20131,0x3d08007f}},	//   őszö, _xder_, nhod, वकों_,
   {{0x27e6006d,0x63a21cdd,0x9f590649,0x26cc1cde}},	//   nzon_, _uson, ìyàn_, _kodo_,
   {{0xe1ef11a2,0x7ce30006,0x3eba0072,0x2cb91cdf}},	//   اسی_, _kõrg, _cnpt_, _snsd_,
   {{0x9f3402ec,0xdc3a0b88,0xc32700e3,0x290f1ce0}},	//   тері, _açık, _تكون_, yoga_,
   {{0x26cc0032,0xe7ab0220,0x66dd0113,0x68e200d4}},	//   _lodo_, _ďaľš, _mèka, jhod,
   {{0x2ca91ce1,0x68e203f1,0x290f0880,0x7f4d01ee}},	// [1390] rdad_, dhod, voga_, _utaq,
   {{0x26cc1ce2,0xcf270190,0x60cd020b,0x00000000}},	//   _nodo_, _تربي, _hoam, --,
   {{0x290f1ce3,0x2ca900f9,0x7ce300aa,0xb05b007b}},	//   toga_, pdad_, _nõrg, yjäl,
   {{0xf8690037,0x2fe4026a,0x00000000,0x00000000}},	//   سمتي_, _örgü_, --, --,
   {{0x26cc0b27,0x6aa71ce4,0x60cd1ce5,0xf7f401f3}},	//   _bodo_, _tajf, _moam, پسند,
   {{0x290f1ce6,0x26cc0328,0x6f020076,0xdb0602b6}},	//   soga_, _codo_, _íoct, _arkæ,
   {{0x26cc1ce7,0x04451ce8,0x68e2019f,0x6283022b}},	//   _dodo_, нейн, bhod, _rcno,
   {{0x68e21643,0x27e6026a,0x2f16003e,0xce381777}},	//   chod, bzon_, lægt_, ואות_,
   {{0xe3b10c5e,0x248d0559,0x7d03002b,0x5884004b}},	//   ارب_, rfem_, _ínsu, _шыра,
   {{0x26cc1ce9,0xb05b1cea,0x248d09c2,0x56270103}},	//   _godo_, själ, sfem_, _قرآ,
   {{0x78a900aa,0xcb120327,0x67380206,0x80a90a43}},	//   _kaev, רלי_, žajú, গান্,
   {{0x26c702e6,0x98b800d9,0xfc3f002b,0x6adc00d2}},	//   ljno_, _kurā_, _saín_, _यत्र,
   {{0x952200fb,0x60cd002d,0xb05b00c2,0x26cc1ceb}},	//   _حکوم, _doam, nkäy, _yodo_,
   {{0x68e20871,0x78a91cec,0xd36e1ced,0x00000000}},	//   zhod, _laev, _اهو_, --,
   {{0x7d0908a9,0x60cd1cee,0x3eba0023,0x27e60103}},	//   česn, _foam, _vnpt_, zzon_,
   {{0xdca31cef,0x76930511,0x64491cf0,0x62811cf1}},	//   ласи, lıyı, ncei, lglo,
   {{0xac071cf2,0x68e21cf3,0xeb970205,0x683601e8}},	// [13a0] ента_, vhod, нит_, _müdü,
   {{0x62811cf4,0x4e1100b6,0x76930555,0x09e602f3}},	//   nglo, _दुवै_, nıyı, нозн,
   {{0xae5b0054,0xd9100068,0x68e21cf5,0x26cc1cf6}},	//   _מכיר, لیس_, thod, _rodo_,
   {{0x38600080,0xa01b0222,0x26cc1cf7,0x443d1cf8}},	//   úir_, mför, _sodo_, _ngw_,
   {{0x26cc1cf9,0xa01b0149,0xfd650134,0x68e20563}},	//   _podo_, lför, kasị, rhod,
   {{0x27e61cfa,0x644b052f,0x56941cfb,0x7ce300bc}},	//   rzon_, _afgi, такт, _põrg,
   {{0x68e20c27,0x26cc02dd,0xa01b1cfc,0xb9060033}},	//   phod, _vodo_, nför, _পদ_,
   {{0x7ce300aa,0x69340e27,0x7cfb007b,0x6281004b}},	//   _võrg, _شکار, märä, eglo,
   {{0x26cc0d9f,0x29041cfd,0x7bd601c2,0x00000000}},	//   _todo_, _ijma_, nyyu, --,
   {{0x60cd11ca,0x026a0084,0xa01b0149,0x443d010a}},	//   _soam, чший_, kför, _egw_,
   {{0xb5fc02a1,0x00000000,0x00000000,0x00000000}},	//   _weġb, --, --, --,
   {{0x73e61cfe,0xa01b0149,0xfbe0009f,0x6449015e}},	//   _поез, dför, फनाम, ccei,
   {{0x6d5e0139,0xddcc00b6,0x4e161cff,0xb4dc0096}},	//   _awpa, _čišt, _दुबई_, डसी_,
   {{0x661a1d00,0x673a00bd,0x00000000,0x00000000}},	//   _kytk, _jitj, --, --,
   {{0xdd94004b,0x673a0990,0x60cd002d,0xa01b0212}},	//   лары, _mitj, _toam, gför,
   {{0x51830f97,0x673a039f,0x00000000,0x00000000}},	//   _суша, _litj, --, --,
   {{0x2f1602b6,0x317e01c2,0xb05b007b,0x00000000}},	// [13b0] tægt_, lutz_, hjäk, --,
   {{0xff500037,0x78a900b7,0x673a1d01,0x00000000}},	//   _اخي_, _saev, _nitj, --,
   {{0x317e1d02,0x661a007b,0x78a91d03,0x6d5e00eb}},	//   nutz_, _nytk, _paev, _gwpa,
   {{0x6ee20220,0x00000000,0x00000000,0x00000000}},	//   _vôbe, --, --, --,
   {{0x07a50cd7,0x317e01bf,0x7ce3007a,0x78a900aa}},	//   талн, hutz_, _võrd, _vaev,
   {{0xcf9400c1,0x7e6704e9,0x6b8d1d04,0x212903a9}},	//   רטס_, najp, mtag, _lhah_,
   {{0x6b8d04f6,0xceb4040a,0x24861d05,0x673a1d06}},	//   ltag, טיס_, _bcom_, _ditj,
   {{0xdb060704,0x62811d07,0x248601b9,0x673a029a}},	//   _erkä, wglo, _ccom_, _eitj,
   {{0x6b8d120f,0x4794110a,0x644917c8,0x47351d08}},	//   ntag, _مجلس, rcei, _анас,
   {{0x64491d09,0xd90d0103,0x6b8d1d0a,0x57f41d0b}},	//   scei, _ایچ_, itag, _спут,
   {{0x05740100,0x69c50052,0xc0e6022a,0x76930345}},	//   _ماند, nxhe, вонк, rıyı,
   {{0x63ad0b14,0xa01b0212,0x6b8d1d0c,0x6281030a}},	//   _šanu, vför, ktag, sglo,
   {{0xa85600a1,0x66040587,0x332701cb,0x21291d0d}},	//   כירה_, şikt, _thnx_, _dhah_,
   {{0xe1f10979,0x6b8d1d0e,0x658a01d4,0x249f1a85}},	//   _پست_, dtag, _səhi, leum_,
   {{0x213b1d0f,0x8d630831,0x92580037,0x6b8d0172}},	//   _fiqh_, ивре, _أشهر_, etag,
   {{0xa01b1d10,0x00000000,0x00000000,0x00000000}},	//   rför, --, --, --,
   {{0x6b8d1d11,0xa01b0222,0xcb671d12,0xaa46061b}},	// [13c0] gtag, sför, кате_, везл,
   {{0x249f1d13,0xd0f20065,0xa01b0212,0x00000000}},	//   heum_, _faṣẹ, pför, --,
   {{0xfaa31440,0xef1f0103,0x673a1d14,0xa01b003e}},	//   рахо, ztük_, _ritj, ngön,
   {{0x673a1d15,0x080a001c,0x00000000,0x00000000}},	//   _sitj, وزشي_, --, --,
   {{0x673a1d16,0x2ca0007a,0x27290220,0x249f0113}},	//   _pitj, meid_, kúnd_, deum_,
   {{0x2ca01d17,0x98b80113,0x66dd0154,0xc1780138}},	//   leid_, _bură_, _dèko, yrė_,
   {{0x5fa9000f,0x888412eb,0x4420013f,0xb0e20789}},	//   _चैनल, _میان, _ši_, _पतंग,
   {{0x44200019,0x2ca000aa,0xef1f0103,0x661a00d4}},	//   _ơi_, neid_, ttük_, _vytk,
   {{0xccf30054,0x2b4600e3,0xf7461d18,0x673a003d}},	//   יכה_, íoch_, _резо, _titj,
   {{0x2ca01d19,0x21291d1a,0x2d9a038c,0x673a1183}},	//   heid_, _shah_, _oppe_, _uitj,
   {{0x60f91d1b,0xc4861d1c,0x2ca01d1d,0x6b8d0634}},	//   ення_, _алек, keid_, ztag,
   {{0x6b8d1d1e,0xdb0400c2,0x249f1d1f,0x85f700ca}},	//   ytag, lviä, ceum_, _בצבע_,
   {{0x442000de,0x2ca000aa,0x996200b6,0xddde0154}},	//   _ái_, deid_, _níže_, _depō,
   {{0x4426023f,0x2d471d20,0x6b8d1d21,0x6d4303a9}},	//   _izo_, _põe_, vtag, _énak,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b8d1d22,0x2009023e,0x2ca000b7,0x00000000}},	//   ttag, _txai_, geid_, --,
   {{0xbab90265,0x6b8d1d23,0x00000000,0x00000000}},	// [13d0] нгах_, utag, --, --,
   {{0x6b8d1d24,0x7a40025b,0xbb1900e3,0x249f1d25}},	//   rtag, vští, رياض_, zeum_,
   {{0x6b8d1d26,0x2ca01d27,0x249f0167,0x00000000}},	//   stag, beid_, yeum_, --,
   {{0xf7711d28,0x442600ac,0x2ca0009c,0x98ad00a5}},	//   مات_, _ozo_, ceid_, _mieć_,
   {{0x6d451d29,0xb05b1537,0x44260b58,0xb5fc0090}},	//   _huha, rjäh, _nzo_, _reġa,
   {{0x6d451d2a,0x6f151d2b,0xd6db0686,0x0684004d}},	//   _kuha, nozc, ьте_, игін,
   {{0x44261d2c,0x6d451d2d,0x29881d2e,0xa8a71d2f}},	//   _azo_, _juha, _исто_, _ирак,
   {{0xf3f900d3,0x60dd029a,0xd92800ae,0x66dd05aa}},	//   laţi_, jksm, _ацул_, _zèkl,
   {{0xe796010d,0xf4950421,0xddde022b,0x00000000}},	//   _مالک, نشکد, _repō, --,
   {{0xdb0400c9,0x63ad00e9,0x2fd902ad,0xf3f900ae}},	//   rviç, _šans, dysg_, naţi_,
   {{0x44261d30,0xe8df0134,0x658a00a7,0xf8c70442}},	//   _ezo_, _ndịa_, _səhv, _रचाय,
   {{0xcea909c1,0x455a00ca,0xf48719e8,0x61fc0076}},	//   _מי_, _נכנס, _јужн, úrla,
   {{0x645b1d31,0x7f441d32,0x7760023e,0xe2a8001c}},	//   mbui, _quiq, _xwmx, راین_,
   {{0x6d451d33,0x201e00d9,0xf3f900ae,0x645b0f10}},	//   _buha, āti_, jaţi_, lbui,
   {{0xfce6192f,0x2ca0007a,0xe296013d,0xf3f900ae}},	//   гово, teid_, _сащ_, daţi_,
   {{0x6d451d34,0xee3700d3,0x645b1d35,0x61d61777}},	//   _duha, унс_, nbui, _תוקף_,
   {{0x2ca01d36,0x0c261cdb,0x6d451d37,0xa3e309a1}},	// [13e0] reid_, уман, _euha, ननि_,
   {{0x2ca00006,0xf3f900ae,0xb6020131,0x7c260206}},	//   seid_, gaţi_, _àágu, _vzkr,
   {{0x3f821d38,0x6d45023f,0x2ca01d39,0x2d9a0149}},	//   luku_, _guha, peid_, _uppe_,
   {{0x7d7b0105,0xa3e300a5,0x645b0381,0x00000000}},	//   _אנטו, नना_, jbui, --,
   {{0x7d041d3a,0x6d451d3b,0x3f821d3c,0x7c2601d3}},	//   mnis, _zuha, nuku_, _uzkr,
   {{0xf3f9002d,0x7d041d3d,0x236d0031,0x645b02ac}},	//   caţi_, lnis, dsej_, ebui,
   {{0x3f821d3e,0x224e01ff,0xe510023a,0xb9240065}},	//   huku_, _rffk_, ावलि_, _musẹ_,
   {{0x33741d3f,0x7d040fda,0x3f821d40,0x44260357}},	//   агир, nnis, kuku_, _pzo_,
   {{0x7d041d41,0xd70a01c9,0x3f821d42,0x78a21d43}},	//   inis, _знае_, juku_, meov,
   {{0x7d041d44,0x3f821d45,0x78a20357,0x92b60037}},	//   hnis, duku_, leov, احظا,
   {{0x7d041d46,0x6f150094,0xe3b20281,0x645b010a}},	//   knis, vozc, _گرا_, bbui,
   {{0x3386188d,0x6d451d47,0x2ba51d48,0x3f821c35}},	//   _букв, _ruha, _ऑनला, fuku_,
   {{0x442600ac,0x6d451d49,0x60dd1d4a,0x644202c9}},	//   _uzo_, _suha, rksm, _igoi,
   {{0x6d451d4b,0x7d041d4c,0x02a300e5,0xf1a61d4d}},	//   _puha, enis, _гръм, _брин,
   {{0x59a40067,0x7d041d4e,0xf3f9020a,0x6f151d4f}},	//   _गैलर, fnis, vaţi_, rozc,
   {{0x3f82077e,0xd9041ac9,0x6d451d50,0x7d160188}},	//   buku_, _ری_, _vuha, goys,
   {{0xf3f900d3,0x6d451d51,0x78a21d52,0xdbc601bf}},	// [13f0] taţi_, _wuha, deov, röße,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0402e2,0x658a0092,0xad270260,0xf3f900d3}},	//   bnis, _məhs, _مرحو, raţi_,
   {{0x3ea31abd,0x64421d53,0xe82000aa,0xf3f900ae}},	//   lejt_, _ngoi, _बरखा_, saţi_,
   {{0x6298134c,0x2d910a00,0xd5b80325,0x96651d54}},	//   _obvo, ltze_, _arā_, акле,
   {{0x4b7a006e,0x64421d55,0x2d910062,0x00000000}},	//   _באשו, _agoi, otze_, --,
   {{0x2d8312fb,0x2d9101e9,0x645b18f0,0x3f821d56}},	//   nuje_, ntze_, tbui, zuku_,
   {{0x09e11827,0x67d51d57,0x2d9101c8,0x3f8218fe}},	//   पनीय, _кобу, itze_, yuku_,
   {{0x2d8309cf,0xb4d509d0,0xe7871d58,0x645b1d59}},	//   huje_, _सकी_, _љубо, rbui,
   {{0x3ae40222,0x64421d5a,0x3f820335,0x645b1d5b}},	//   _köpa_, _egoi, vuku_, sbui,
   {{0x41061d5c,0x7d041d5d,0x00000000,0x00000000}},	//   изов, ynis, --, --,
   {{0x3f821d5e,0xf5300037,0xdddc05db,0x00000000}},	//   tuku_, _فإن_, jgrš, --,
   {{0x7d040ca7,0x8c3b042c,0x00000000,0x00000000}},	//   vnis, _maßs, --, --,
   {{0x3f8202e6,0x2d830dd1,0xc8e20034,0xef1700d3}},	//   ruku_, fuje_, _खत्म_, имя_,
   {{0x7d041d5f,0x3f821d60,0x6da614fa,0xacf619e8}},	//   tnis, suku_, шива, ачај,
   {{0x3f821d61,0x7ce300aa,0xdb0f00b3,0x26f2049d}},	//   puku_, _põra, _arcà, _अग्र_,

   {{0x7d040e13,0x2d9101ff,0x8fa61d62,0x60cb0154}},	// [1400] rnis, atze_, _тапе, _ògma,
   {{0x2d831d63,0x658a00a7,0xf1c90032,0xeb971272}},	//   buje_, _məhr, _gbáà_, риф_,
   {{0x7e7b00a1,0xc8661d64,0xed5a0231,0xb5fc0090}},	//   _באיז, атли, _шон_, _reġo,
   {{0xd7fa0086,0x7c9601b6,0x256c0065,0x00000000}},	//   кул_, _троц, _lólá_, --,
   {{0x27e0054f,0xc60e0179,0x78a200d7,0xb8ce05cd}},	//   áin_, िथ्य_, reov, _कस_,
   {{0x78a21d65,0x64420049,0x6b841d66,0x00000000}},	//   seov, _sgoi, muig, --,
   {{0x3567004b,0x5f090789,0x6b84009c,0x27e01d67}},	//   арын_, _सदस्_, luig, šin_,
   {{0xd9431d68,0x63b9030a,0x658a00a7,0x00000000}},	//   _фети, _brwn, _bəhr, --,
   {{0x667600bf,0xb4d6009d,0x256c0065,0x26161ab1}},	//   _ندار, _हवी_, _bólá_, _पुरी_,
   {{0x4ac91d69,0x2d830169,0x00000000,0x00000000}},	//   रायव, yuje_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d830074,0xd5fb00ca,0x63b903a8,0x6b840350}},	//   vuje_, _בפבר, _frwn, kuig,
   {{0x658a01d4,0x893700c1,0x61ff0092,0x2d830034}},	//   _təhs, ירטע_, _əylə, wuje_,
   {{0xdefb01b3,0x539b0327,0x6b841d6a,0x00000000}},	//   тым_, _סיוו, duig, --,
   {{0x27290037,0x3ea3023b,0x69d801df,0xcf8e001c}},	//   núna_, rejt_, øvel, وژی_,
   {{0x3ea31d6b,0x2d9101e9,0x00000000,0x00000000}},	//   sejt_, rtze_, --, --,
   {{0x3ea300dd,0x6f950037,0x6b84014b,0xdb0f1d6c}},	// [1410] pejt_, _الخض, guig, _arcá,
   {{0x3ce9006c,0x62881d6d,0xdd8700d3,0xed4e0103}},	//   shav_, ngdo, _кымп, بھی_,
   {{0xf9f90037,0x3ce9004d,0x00000000,0x00000000}},	//   دفاع_, phav_, --, --,
   {{0xb4d50971,0x6d5701e9,0x3ebf03e3,0x6b8401d0}},	//   _सके_, _itxa, ɓuta_, buig,
   {{0x395a00f9,0x6d480146,0xb05b007b,0x00000000}},	//   apps_, ídav, ljäs, --,
   {{0x9a8419e8,0x290601ff,0x00000000,0x00000000}},	//   _мусл, anoa_, --, --,
   {{0x7ae70063,0x25ac00fe,0x00000000,0x00000000}},	//   _iljt, _csdl_, --, --,
   {{0xe91900d6,0x79850b58,0x00000000,0x00000000}},	//   _собі_, muhw, --, --,
   {{0x658a00a7,0xa8250421,0xdd0204e9,0xdb0f02c6}},	//   _qəhr, _اکان, šuću, _zrcá,
   {{0x6d570634,0x00000000,0x00000000,0x00000000}},	//   _otxa, --, --, --,
   {{0xa06a1d6e,0x6d570197,0x6b8401c0,0xd9f91073}},	//   лана_, _ntxa, zuig, ्पित_,
   {{0x628801d0,0x658a013c,0x00000000,0x00000000}},	//   agdo, _təhr, --, --,
   {{0x6d570634,0xe2991d6f,0x5eb10033,0x63b90169}},	//   _atxa, _бал_, ঞানে, _urwn,
   {{0x63a91d70,0xd9f91926,0x00000000,0x00000000}},	//   mwen, ्पात_, --, --,
   {{0x63a90060,0x8db5004d,0x80b00033,0x00000000}},	//   lwen, ості, টাব্, --,
   {{0x6b841d71,0xb4d51d72,0x307a0037,0x79850027}},	//   tuig, _सको_, _صحبة_, duhw,
   {{0x60c41d73,0x63a91d74,0x3ce0017a,0x6d5701e9}},	// [1420] _inim, nwen, rkiv_, _etxa,
   {{0xfd690294,0x20ef01c2,0xff260012,0x4bd9007b}},	//   _jupụ, nƙin_, _ымпо, шься_,
   {{0x63a91d75,0xbed700c1,0x60d6026a,0x00000000}},	//   hwen, _הויז_, _koym, --,
   {{0xb4d60b79,0x6d5c0a82,0x63a91d76,0xe89400d6}},	//   _हवे_, mpra, kwen, іаль,
   {{0x29061d77,0xbcb700ca,0x628802b6,0xa77307bf}},	//   rnoa_, _הפכו_, ygdo, зліч,
   {{0x6ffc00d9,0xef1f01e8,0x63a91d78,0xfd690134}},	//   mācī, ltür_, dwen, _nupụ,
   {{0x6d5c0c56,0x6d430231,0xc7af0103,0x63a91d79}},	//   npra, _énat, وڑے_, ewen,
   {{0xdbdd0220,0x98bc01d3,0x63a91d7a,0x60c4083e}},	//   zšír, īvē_, fwen, _nnim,
   {{0x96961d7b,0xfd690174,0x63a91d7c,0x7e6e01d3}},	//   _греш, _bupụ, gwen, kabp,
   {{0x68e20018,0x59dc1d7d,0x6eeb1d7e,0x69c10072}},	//   lkod, _यथार, _kübe, _álec,
   {{0xba9b006e,0x658a00a7,0x5a9b006e,0x62881d7f}},	//   נסטי, _təhq, נשטא, rgdo,
   {{0x6d5c1d80,0x63a91d81,0x68e21d82,0x7afe026a}},	//   dpra, bwen, nkod, hipt,
   {{0x7afe0102,0x5f94060b,0x53a30f2e,0x6eeb1d83}},	//   kipt, пият, _нацб, _lübe,
   {{0xb5fc03e5,0x60c41d84,0x7afe023b,0x39581d85}},	//   _reġj, _enim, jipt, _otrs_,
   {{0x6d5c19e6,0x68e21d86,0xab5b1d87,0x8af0013c}},	//   gpra, kkod, _krüg, rpəl,
   {{0x99860067,0x657c13c8,0x2d730b18,0x25e00336}},	//   łoś_, _århu, rće_, _कथनी_,
   {{0x8b580037,0x09e10096,0x2d73007e,0x2a6a030a}},	// [1430] مجلس_, पन्य, sće_, _bebb_,
   {{0x2d731d88,0x7afe0076,0x2efa02ac,0x00000000}},	//   pće_, gipt, _gmpf_, --,
   {{0x7f3c00c1,0x69de0d5b,0x63a90201,0x6d481d89}},	//   _געזו, gype, zwen, ídat,
   {{0xad27037f,0x38690102,0x9bc7022c,0xfc3f03be}},	//   _درخو, úar_, _лёгк, _saíu_,
   {{0x395800b3,0x00000000,0x00000000,0x00000000}},	//   _etrs_, --, --, --,
   {{0x7afe0496,0xab5b02e2,0xe7391d8a,0xb5791b60}},	//   cipt, _prüf, шел_, ащих_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a91d8b,0x68e21d8c,0x280400b6,0x00000000}},	//   twen, ckod, ásná_, --,
   {{0x68e91d8d,0x63a90ab2,0x25a0020a,0x68fb0af0}},	//   _iled, uwen, ăila_, _imud,
   {{0x60c400e9,0x81d400c7,0x68e9000d,0x63a91d8e}},	//   _snim, _সেই_, _hled, rwen,
   {{0x68e91d8f,0x63a90060,0x545502b3,0x68fb0085}},	//   _kled, swen, _двет, _kmud,
   {{0x6d5c0087,0x60d60092,0x68e90113,0x00000000}},	//   vpra, _qoym, _jled, --,
   {{0xb05b0149,0xfc3f1d90,0x2b591d91,0x7afe0103}},	//   tjär, _maís_, _ntsc_, yipt,
   {{0x6d5c1d92,0x68e21d93,0x539a0327,0x68e900f0}},	//   tpra, zkod, _כינו, _lled,
   {{0x823709b4,0x290d002b,0x98a40138,0xe3b90103}},	//   _ارشا, _ojea_, _gimė_, lvű_,
   {{0xb05b1d94,0x39581d95,0x2a6a00dc,0x6eeb0364}},	//   sjär, _rtrs_, _sebb_, _rübe,
   {{0xa11300e3,0x2a780167,0xa2cd1d96,0x394a1d97}},	// [1440] _تويت, _pdrb_, ताप्, _subs_,
   {{0x6d5c1d98,0x68fb1d99,0x68e90143,0x290d01ff}},	//   ppra, _amud, _aled, _ajea_,
   {{0x7afe1d9a,0x8c460457,0x6f1c1d9b,0xdcfc00ae}},	//   ript, _мене, morc, gură,
   {{0x69de1d9c,0x319a006e,0xc7c600c2,0xab5b0364}},	//   rype, יבענ, жски, _brüd,
   {{0x7d090559,0x68e90113,0x69de0094,0x26c50503}},	//   čest, _dled, sype, _bnlo_,
   {{0x7afe074a,0x68e21d9d,0x68e91d9e,0x6f1c1d9f}},	//   qipt, skod, _eled, norc,
   {{0xbb4308d1,0xc4480177,0xa2cd0d7a,0xab5b00aa}},	//   _церк, میان_, तान्, _prüg,
   {{0xd4970012,0x151700e3,0xd250001c,0x00000000}},	//   орь_, يزية_, کند_, --,
   {{0x394400ec,0x6b961da0,0x00000000,0x00000000}},	//   _iims_, ntyg, --, --,
   {{0xb5fc003d,0xa314007f,0x00000000,0x00000000}},	//   _leġi, डवेज_, --, --,
   {{0x7ce300aa,0x3f821da1,0x610401f9,0xdcfc00e8}},	//   _sõrm, erku_, zőle, ntrē,
   {{0x69c8014b,0x00000000,0x00000000,0x00000000}},	//   _àdeu, --, --, --,
   {{0x6f1c1da2,0x7afc05db,0x00000000,0x00000000}},	//   forc, _omrt, --, --,
   {{0x6f1c0039,0x63a20139,0x3cfd0285,0x00000000}},	//   gorc, _ipon, रोने_, --,
   {{0x3eb30092,0x2b4b0451,0x273200ae,0xdb0d016d}},	//   _vaxt_, _succ_, mând_, lvaç,
   {{0x1fa71da3,0x8b670037,0x9f6b0291,0x201600fd}},	//   _дрог, قائم, _кроз_, écié_,
   {{0x200c01d4,0x6f1c1da4,0x2d68044c,0x00000000}},	// [1450] şdir_, borc, aşe_, --,
   {{0x68fb1da5,0x6f1c1da6,0xf43b00a1,0x273200d3}},	//   _smud, corc, שתמש, nând_,
   {{0xaca30134,0xdcf50034,0xa2b200b6,0x7f45039f}},	//   _ahụb, erzą, _असन्, _iihq,
   {{0x63a21da7,0x3944015e,0xaac91da8,0xc23700ca}},	//   _opon, _cims_, राहक, קראו_,
   {{0x995400b6,0x37ab1da9,0xdcfc044c,0x6568041c}},	//   _výše_, ртен_, sură, _awdh,
   {{0x2ca91daa,0x26e30081,0xb345016d,0x68e900f0}},	//   lead_, কোনো_, _liçã, _wled,
   {{0x63a21dab,0x68e90449,0x3944022b,0xfc3f0131}},	//   _apon, _tled, _fims_, _taís_,
   {{0x68fb1dac,0x2ca91dad,0xaac91dae,0x3f82166e}},	//   _umud, nead_, रावक, yrku_,
   {{0x291d1daf,0x629a010a,0x39951842,0x6f1c037a}},	//   mowa_, ffto, lås_, yorc,
   {{0x2ca91db0,0x386d09e3,0x291d1db1,0x273200ae}},	//   head_, _heer_, lowa_, gând_,
   {{0x386d1db2,0x63a21db3,0xaca30134,0x7d080146}},	//   _keer_, _epon, _awọd, édsk,
   {{0x386d008a,0x23751a37,0x7cf10073,0x291d1db4}},	//   _jeer_, _فاتح, _hårf, nowa_,
   {{0x386d1db5,0xb5fc03e5,0x7ce300bc,0x2d831db6}},	//   _meer_, _reġi, _tõrj, erje_,
   {{0x386d1db7,0x273200d3,0x248d1db8,0x442f1db9}},	//   _leer_, când_, lgem_, _izg_,
   {{0xa928025b,0x291d1dba,0x63bb003e,0x2ca90037}},	//   ližš, kowa_, lvun, fead_,
   {{0x2ca901b9,0x7afc00d2,0x386d0305,0x273200d3}},	//   gead_, _smrt, _neer_, mâne_,
   {{0xfc3f08a8,0x291d1dbb,0x2d831dbc,0x3b8600c6}},	// [1460] _saír_, dowa_, arje_, ялаг,
   {{0xe81f0b89,0x6b960149,0x8b2300c2,0x7cea003e}},	//   _बड़ा_, rtyg, едуе, _dýra,
   {{0x3995040f,0x6edb00ca,0x66dd0113,0x386d1dbd}},	//   gås_, _החיפ, _lèks, _beer_,
   {{0x2fc0017a,0x3eaa0364,0x273200ae,0x3e5700b6}},	//   _krig_, lebt_, zând_, pětí_,
   {{0x4cbb0054,0xdcfc0029,0x2d981dbe,0x2d8a1dbf}},	//   _הזכו, strē, ltre_, lube_,
   {{0x6d461dc0,0xb4b40251,0x6b841dc1,0x7997023e}},	//   _hika, _छोड़_, mrig, btxw,
   {{0x2d981dc2,0x6d461dc3,0x291d1dc4,0x2d8a1dc5}},	//   ntre_, _kika, bowa_, nube_,
   {{0x6eeb01d4,0x94aa1dc6,0x6d46127e,0x2d981dc7}},	//   _müba, стка_, _jika, itre_,
   {{0x6d461dc8,0x6b841dc9,0x2fc0006c,0x273200ae}},	//   _mika, nrig, _nrig_, tând_,
   {{0x6d461dca,0x386d0ab2,0x61e11dcb,0x248d001f}},	//   _lika, _zeer_, fyll, agem_,
   {{0x6b8402e2,0x273200d3,0x64a61dcc,0x9f4e0031}},	//   hrig, rând_, _нажа, ľným_,
   {{0xc05807bf,0x2fc002ad,0x6b840bc6,0x9f4e0146}},	//   зір_, _brig_, krig, žným_,
   {{0x613f0029,0x3869003e,0x273200d3,0x63a21dcd}},	//   _jūli, ðari_, pând_, _upon,
   {{0x44261dce,0x6d461dcf,0x6136003e,0x61e11175}},	//   _iyo_, _aika, jálf, byll,
   {{0x6d461dd0,0x44261dd1,0x06fd030b,0x6b841dd2}},	//   _bika, _hyo_, _říká_, erig,
   {{0x6d461dd3,0x44260517,0x2d8300dd,0x2fc01dd4}},	//   _cika, _kyo_, rrje_, _frig_,
   {{0x2d9c1424,0x6d460496,0x386d0694,0x57c6009d}},	// [1470] _även_, _dika, _reer_, लमोह,
   {{0x7cea0074,0x291d1dd5,0x39950fbc,0x386d057a}},	//   _výra, wowa_, tås_, _seer_,
   {{0x291d1dd6,0x75221dd7,0x6d461dd8,0xab5b0364}},	//   towa_, _okoz, _fika, _brüc,
   {{0xf77104f4,0xddde030b,0x39950222,0x44261dd9}},	//   نات_, _nepř, rås_, _oyo_,
   {{0x44261dda,0x611200d9,0x3f8b01e8,0xab5b01bf}},	//   _nyo_, nāla, nucu_, _drüc,
   {{0x386d01aa,0x291d1ddb,0x6d461ddc,0xd24600e3}},	//   _weer_, sowa_, _zika, _لن_,
   {{0x44261ddd,0xc9841dde,0x672102dd,0x752200e7}},	//   _ayo_, _пути, _vklj, _bkoz,
   {{0x7d0d1ddf,0x44260b92,0x611200e8,0x61e1007b}},	//   nnas, _byo_, kāla, vyll,
   {{0x248d1de0,0x4426023f,0x61e10150,0xdb1d1de1}},	//   rgem_, _cyo_, wyll, _arsé,
   {{0x672100e9,0x7cf11de2,0x7d0d02ad,0x61e11de3}},	//   _uklj, _hård, hnas, tyll,
   {{0x3dc1023e,0x44261dd9,0x7d0d1de4,0x614703a9}},	//   _nrhw_, _eyo_, knas, dèlè,
   {{0x61e11de5,0x7d0d00e7,0x63a4020a,0x6b8401ee}},	//   ryll, jnas, _ţine, yrig,
   {{0x61e102e0,0x6d461de6,0xdb0f1de7,0x4426083e}},	//   syll, _rika, _escé, _gyo_,
   {{0x2d981de8,0x75291de9,0x6d4610b3,0x2d8a1dea}},	//   ttre_, llez, _sika, tube_,
   {{0x31161612,0x6b841deb,0x7d0d003e,0x7c370022}},	//   _офис, wrig, fnas, ɓarɓ,
   {{0xd1321dec,0x2d981ded,0x7d0d0088,0x2d8a02a4}},	//   _جمع_, rtre_, gnas, rube_,
   {{0xeb971dee,0xddc71def,0x4426023e,0x0b4600d6}},	// [1480] мит_, rajš, _xyo_, днан,
   {{0x6d4600a6,0xa01b1df0,0x7c260146,0x7d0d01b9}},	//   _wika, rgöt, _vykr, anas,
   {{0x6d460b4b,0x644b0451,0x8102009f,0x7c260034}},	//   _tika, _oggi, _लगाओ_, _wykr,
   {{0x6b841df1,0xa3bf030b,0x644b00cd,0x18670291}},	//   prig, ुमा_, _nggi, даци_,
   {{0x7d041df2,0x75290b18,0xa01b02c3,0x753b01cb}},	//   miis, dlez, lgör, dmuz,
   {{0x644b0465,0x7d041df3,0x752202dd,0x75290010}},	//   _aggi, liis, _skoz, elez,
   {{0x7ae30084,0xa01b1df4,0x44260270,0xdcf50034}},	//   önte, ngör, _syo_, erzę,
   {{0x75291df5,0x29020149,0x7cf11bfa,0x44261df6}},	//   glez, _öka_, _gård, _pyo_,
   {{0x38661df7,0xddde02c6,0xdb04002b,0x60cb009c}},	//   mbor_, _vepř, lviñ, _ògmi,
   {{0x6d5e02e6,0x7d04008a,0x65c6013d,0x644b1df8}},	//   _otpa, hiis, _обза, _eggi,
   {{0x7d041df9,0x7cf10d3e,0xe8df00de,0x75291dfa}},	//   kiis, _håre, _hiền_, blez,
   {{0x44261dfb,0x7cf10f3c,0xf503008f,0x75290036}},	//   _tyo_, _kåre, _изхо, clez,
   {{0x7d040694,0x6d5e1dfc,0x7ce3007a,0x44261dfd}},	//   diis, _atpa, _kõrv, _uyo_,
   {{0xe8df0019,0x3f991dfe,0x3f8b0367,0x611201d3}},	//   _miền_, rtsu_, rucu_, rāla,
   {{0xc3480028,0xe8df0019,0x7d0d1dff,0x7d04008a}},	//   _nổi_, _liền_, tnas, fiis,
   {{0x7d040784,0x30a70a28,0x40351e00,0x201e00ae}},	//   giis, _цркв, _пейс, ştia_,
   {{0xfd44013f,0x00000000,0x00000000,0x00000000}},	// [1490] тэрн, --, --, --,
   {{0x7d0d1e01,0x4ac9000f,0x0dcb013d,0x19eb0037}},	//   snas, राइव, _думи_, يراً_,
   {{0x7d041e02,0xceb200c1,0x61ed0022,0x212b00f0}},	//   biis, _גיי_, _ƙali, olch_,
   {{0x7d040188,0xa81500ae,0x7aee1e03,0x7cf100f2}},	//   ciis, ндеш, _elbt, _båre,
   {{0x7cf10222,0xc7ab15f8,0x78ab0313,0x14bf0d7e}},	//   _vård, تدال_, regv, _शोषण,
   {{0x6d5800fd,0x6b8d0239,0x6d4a028d,0x7e750062}},	//   _évac, muag, _èfac, nazp,
   {{0x752901cb,0x260200c3,0x69d800f2,0xa2cd1e04}},	//   tlez, _वेदी_, øvet, तास्,
   {{0x7cf10f05,0x7e7501ff,0x672a18f0,0x00000000}},	//   _hårb, hazp, alfj, --,
   {{0x61360146,0x7529029a,0x68e400c2,0x387f00bd}},	//   nále, rlez, öide, _idur_,
   {{0x752902c6,0xaad21e05,0xdbdb0139,0x00000000}},	//   slez, सायक, _mààm, --,
   {{0x290f0027,0x753b1e06,0x00000000,0x00000000}},	//   onga_, pmuz, --, --,
   {{0x290f01af,0x387f00bd,0x68f9020e,0x2732020a}},	//   nnga_, _jdur_, _çadı, mâna_,
   {{0x7d041e07,0x13a700cd,0x290f004d,0x6b8d034f}},	//   viis, _آنتی_, inga_, juag,
   {{0x6136025b,0x7e750634,0x7d040188,0x386600d4}},	//   dále, gazp, wiis, zbor_,
   {{0x7d041e08,0x6da311b7,0x290f0124,0x387f07e7}},	//   tiis, лира, knga_, _odur_,
   {{0x7cea0871,0xe05800cd,0xdbdb0139,0xa2cd1792}},	//   _výro, _زیست_, _bààm, ताव्,
   {{0x7d041e09,0x61361e0a,0x6b8d028d,0xbb4a0260}},	// [14a0] riis, ráld, guag, سلان_,
   {{0x7d041e0b,0x2cb90072,0xdbdb0032,0x387f1e0c}},	//   siis, _easd_, _dààm, _adur_,
   {{0x7cf11e0d,0x88861e0e,0x7d040302,0x6d5e0565}},	//   _såre, ележ, piis, _utpa,
   {{0xdd2f030b,0x395100c4,0x2cb901ec,0xdb04002b}},	//   pěšn, _duzs_, _gasd_, rviñ,
   {{0x3c7700ca,0x387f182f,0x3eba0313,0x5fc30442}},	//   _אתכם_, _ddur_, _kapt_, शियल,
   {{0x290f1e0f,0x7cf113f8,0xa82400cd,0xe8df0023}},	//   anga_, _våre, _یکشن, _viền_,
   {{0x212b0150,0x77620072,0x940a00a7,0x290f1e10}},	//   ylch_, spox, əbə_, bnga_,
   {{0xe8df00ef,0x7cf101df,0xd9431e11,0xf3660c3f}},	//   _tiền_, _tåre, _беси, нтон,
   {{0x7ce300bc,0x290601c8,0x00000000,0x00000000}},	//   _tõrv, mioa_, --, --,
   {{0x13f300c2,0xdb9700c1,0x290601e9,0x877b0327}},	//   узья, עדיט_, lioa_, _מאמי,
   {{0x61360146,0xb05b02c3,0x6d5a0174,0xc17800c6}},	//   zále, ndäg, ̣tar, usė_,
   {{0x26de0044,0x6b8d0167,0x29061e12,0x00000000}},	//   _hoto_, yuag, nioa_, --,
   {{0xa30b00fb,0xa2e61e13,0xe8df0019,0x6d5a1e14}},	//   _کرنے_, _подд, _hiển_, ítan,
   {{0x26de0051,0x9f35004d,0x61361e15,0x29060062}},	//   _joto_, тегі, vále, hioa_,
   {{0x3eba1e16,0x7e751e17,0xf1a300d3,0xa2cd1e18}},	//   _dapt_, razp, _брын, तार्,
   {{0x6b8d1e19,0x0ccf0081,0x7cf10073,0x61360094}},	//   tuag, রস্ত, _sårb, tále,
   {{0x60cd023f,0x3eba002d,0x26cc1e1a,0x27e606a3}},	// [14b0] _inam, _fapt_, _ondo_, jyon_,
   {{0x26de1e1b,0x6b8d1e1c,0x3ce90117,0x28c6023a}},	//   _noto_, ruag, skav_, _रोबि,
   {{0xab5b02e2,0x290f019c,0x7b0b01d3,0x6b8d1e1d}},	//   _grün, tnga_, kļuv, suag,
   {{0xa95400d6,0x6c7900c1,0x290f0239,0x61360146}},	//   укці, _קאָפ, unga_, pále,
   {{0x27e60068,0x60cd0051,0x26de1e1e,0x69d813b9}},	//   gyon_, _mnam, _boto_, øver,
   {{0xe8df0028,0x8698008f,0x26de0328,0xd6db1e1f}},	//   _biển_, етът_, _coto_, яте_,
   {{0xa8a71e20,0x60cd019f,0x5b1407c8,0x27e606a8}},	//   _прак, _onam, _смрт, ayon_,
   {{0x81c80033,0x27e603e3,0x60cd0517,0x387f1e21}},	//   োনা_, byon_, _nnam, _udur_,
   {{0x249f1e22,0xf6990831,0x1fcb0096,0xe7841e23}},	//   rfum_, _овај_, ामोड, _бухо,
   {{0x60cd1e24,0x78bb1e25,0xa2e50231,0x26de0133}},	//   _anam, _hauv, тоод, _goto_,
   {{0x67230078,0xe4e7004d,0x60cd037a,0x9f4402c6}},	//   monj, _підн, _bnam, ámí_,
   {{0x67231e26,0x60cd009c,0xd00a001f,0x3eba020a}},	//   lonj, _cnam, деме_, _sapt_,
   {{0x78bb0257,0x3ae40149,0xe299001f,0x60df01ee}},	//   _mauv, _köpt_, _жал_, _doqm,
   {{0x290603f3,0x60cd1e27,0x67231e28,0x78bb1e29}},	//   zioa_, _enam, nonj, _lauv,
   {{0x27e61e2a,0x7c961031,0xc6920089,0x61ed0d2a}},	//   zyon_, крац, יאם_, _ƙalu,
   {{0xfbe700de,0x645b1e2b,0x67231e2c,0x78bb1e2d}},	//   _thể_, ncui, honj, _nauv,
   {{0x3eba1e2e,0x1c461e2f,0x00000000,0x00000000}},	// [14c0] _tapt_, тнам, --, --,
   {{0x67230dd7,0x00000000,0x00000000,0x00000000}},	//   jonj, --, --, --,
   {{0x26de1e30,0x67231e31,0xd9460582,0x78bb042c}},	//   _roto_, donj, вежи, _bauv,
   {{0x26de1e32,0xa9671e33,0x27e602f1,0xe78601b3}},	//   _soto_, тица_, tyon_, вуко,
   {{0xa2b202e8,0x26de1e34,0x29060a00,0x27e60009}},	//   _असल्, _poto_, rioa_, uyon_,
   {{0x67231e35,0x7bc60078,0x29060a00,0x27e61e36}},	//   gonj, _irku, sioa_, ryon_,
   {{0x27e61e37,0x66e30396,0x290601e9,0x78bb014b}},	//   syon_, роја, pioa_, _fauv,
   {{0x399c05fe,0x6abc1e38,0x7539022b,0x44b40c37}},	//   mís_, _harf, _chwz, убис,
   {{0x26de0074,0x6abc1114,0x290403e5,0x78a2031a}},	//   _toto_, _karf, _imma_, mfov,
   {{0x78bb005f,0x60cd1e39,0x78a21e3a,0x672300ae}},	//   _zauv, _snam, lfov, conj,
   {{0x399c1e3b,0x6abc1e3c,0x68e01e3d,0x6d5a003e}},	//   nís_, _marf, _komd, ítal,
   {{0x7bc61e3e,0x645b1e3f,0xab5b1e40,0x6abc03a8}},	//   _orku, ccui, _brül, _larf,
   {{0x399c00e3,0x7bd6023e,0x53b61462,0x23b60179}},	//   hís_, jxyu, _अनिश, _अनिद,
   {{0x3d951cbd,0x28a402d5,0x68e00372,0xdb1d00d4}},	//   лигр, _गॉसि, _lomd, _prsí,
   {{0x5e5802ec,0x7bc61e41,0x29041e42,0x2c580e62}},	//   тися_, _arku, _omma_, _ọda_,
   {{0x518313a4,0x60cd1e43,0x399c1e44,0x8c64002d}},	//   _туша, _unam, dís_, итуд,
   {{0x6abc1e45,0x6d58020d,0x5b151e46,0x7bc605db}},	// [14d0] _barf, _évan, гмат, _crku,
   {{0x29041e47,0x78bb025a,0xe8df0028,0x61360102}},	//   _amma_, _sauv, _miễn_, mála,
   {{0x6abc1e48,0xce331e49,0xd366001c,0x61360018}},	//   _darf, _خودک, _گه_, lála,
   {{0xfc640465,0xfc3f058a,0x2d911e4a,0x68e00503}},	//   _върн, _maíz_, muze_, _comd,
   {{0xd366012b,0x6abc1e4b,0x61360018,0x78bb02fd}},	//   _ده_, _farf, nála, _vauv,
   {{0x6abc1e4c,0xddce1e4d,0xb05b007b,0xa5b90284}},	//   _garf, labš, rjäy, ећих_,
   {{0x613600e3,0x399c1e4e,0x212903e3,0x67231e4f}},	//   hála, cís_, _okah_, ronj,
   {{0x2602009d,0xe3b911e7,0x69c70167,0x38c20103}},	//   _वेळी_, еби_, _irje, térő_,
   {{0x67231e50,0x032501a0,0xecc50033,0x6abc01c2}},	//   ponj, лдин, _একাড, _yarf,
   {{0xe8df00ef,0x61e802ad,0x645b1e51,0x2d911e52}},	//   _diễn_, fydl, scui, kuze_,
   {{0x04951e53,0x394d0934,0x13a70281,0xb1461e54}},	//   _ملاح, _kies_, رنگی_, лнол,
   {{0xa6e20102,0x2d910201,0x201e026a,0x00000000}},	//   _öðru, duze_, ştim_, --,
   {{0x394d1e55,0x61361e56,0xdcfc01d3,0x2d910381}},	//   _mies_, gála, strī, euze_,
   {{0x69c71e57,0x272903be,0xe2991e58,0xe8d014e5}},	//   _orje, múns_, _чак_, _सच्च,
   {{0x52390130,0xd33600ca,0x2d911e59,0x26ca0072}},	//   _אײַנ, _גרסה_, guze_, _óboe_,
   {{0x394d03e5,0x399c1e5a,0xa3b7152c,0x6abc1e5b}},	//   _nies_, vís_, _चना_, _sarf,
   {{0x69c71e5c,0x2d8a00e7,0x00000000,0x00000000}},	// [14e0] _arje, srbe_, --, --,
   {{0x80a004dd,0xa3d40067,0x2d911a0f,0x7cf10149}},	//   ग्रे, हमत_, buze_, _våra,
   {{0x6abc1e5d,0x8cbf00a3,0x7ce3007a,0x80d80096}},	//   _varf, _लोको, _võrr, यापे,
   {{0x399c1c27,0xdb0f0428,0x394d00b3,0x7cf10212}},	//   rís_, _escà, _cies_, _tåra,
   {{0xb8dc1e5e,0x394d1e5f,0x66e60f80,0x7bc61e60}},	//   _अस_, _dies_, лода, _urku,
   {{0xd5ba1e61,0x394d00f3,0x399c1e62,0x00000000}},	//   еси_, _eies_, pís_, --,
   {{0x69c704e9,0xdb230103,0xc7b901f9,0x7bc41e63}},	//   _grje, _óráj, _eső_, lviu,
   {{0x29041e64,0x62830150,0xc44800cd,0xfc3f04d8}},	//   _umma_, _adno, نیان_, _raíz_,
   {{0xd2500080,0x27290933,0x12e60077,0x9cd700ca}},	//   ينة_, gúns_, гінг, רופה_,
   {{0x7cf808a8,0xe8df0019,0x61e80149,0x61360018}},	//   _fírg, _viễn_, tydl, vála,
   {{0x7cf800b3,0x62340307,0x80b00033,0x546a1e65}},	//   _gírg, рену, য়ান্, _заем_,
   {{0x2d91023f,0x61361e66,0xe8df00de,0x6283022b}},	//   vuze_, tála, _tiễn_, _edno,
   {{0x8cbf0067,0xe47b006e,0x41b000b7,0x4432020b}},	//   _लोगो, _טראכ, _जनकस, _áy_,
   {{0x43831823,0x613600e3,0xef1f0491,0xb3bb00ca}},	//   _الوق, rála, mrük_, _נמוכ,
   {{0x61361e67,0x6d58025a,0x51860077,0x9f4402c6}},	//   máln, _éval, _сула, ámá_,
   {{0x69c700dd,0x557700c1,0x61360103,0xf1930103}},	//   _rrje, טעלן_, láln, _اُٹھ,
   {{0xe8df00ef,0x3a7500d3,0x1bd4008f,0xa3e40d75}},	// [14f0] _hiện_, илар, ботя, नहि_,
   {{0x6136128f,0xe8df0028,0x394d0120,0x69c70357}},	//   náln, _kiện_, _sies_, _prje,
   {{0xc3330054,0x28c60e28,0xfc3f0032,0x0855007b}},	//   צוע_, _रोहि, _gbín_, авею,
   {{0x2fc90185,0x80d809c3,0x69c71e68,0xd7f10037}},	//   _krag_, याये, _vrje, يكا_,
   {{0x394d1e69,0xdb0f04d8,0x61361e6a,0x960d0557}},	//   _vies_, _escá, káln, िप्ट_,
   {{0x6b8d181f,0x6d4f1e6b,0x394d02db,0x2fc9009c}},	//   mrag, _hica, _wies_, _mrag_,
   {{0x4519167b,0x6d4f0da3,0x25ac0124,0xf773001c}},	//   кция_, _kica, _cpdl_, _گاز_,
   {{0x2bc90f53,0x6d57008a,0x7cf81e6c,0xb3851e6d}},	//   रिपा, _muxa, _vírg, алил,
   {{0x2fc9023e,0x28f800c2,0xe69500ae,0x613600d4}},	//   _nrag_, _сеть_, _визы, fáln,
   {{0x6d4f0197,0x42551e6e,0x61361e6f,0xe8df00de}},	//   _lica, штит, gáln, _biện_,
   {{0x7cf80068,0x6b8d072f,0xa06a1693,0x2fc90188}},	//   _híre, hrag, кана_, _arag_,
   {{0xe8df0028,0xe0461e70,0x6b8d1e71,0x2fc91e72}},	//   _diện_, инни, krag, _brag_,
   {{0xf3670870,0x6136045e,0x611201d3,0x2fc9009c}},	//   _стен, báln, nāli, _crag_,
   {{0xfc3f0032,0x7cf80037,0x7d0600dc,0x2fc91e73}},	//   _abío_, _míre, _smks, _drag_,
   {{0x6d4f0ee4,0x2d9e0257,0x6d570042,0x6b8d1e74}},	//   _bica, îte_, _cuxa, erag,
   {{0x6b8d1e75,0xb4e3009d,0xa2cd009d,0x2fc91e76}},	//   frag, _नको_, ताक्, _frag_,
   {{0x6d4f1e77,0x61360018,0xec4a1e78,0x7cf10f3c}},	// [1500] _dica, lálo, тзал_, _tårn,
   {{0xff7b00c1,0x7bc400ae,0x6d57002b,0x78a90372}},	//   _שטימ, rviu, _fuxa, _abev,
   {{0x6d4f00c9,0x613610a8,0x442f0138,0xdca61e79}},	//   _fica, nálo, _lyg_, _кани,
   {{0xdbdc0074,0x3ead0039,0x2c5c00a5,0x6b8d1e7a}},	//   lšíc, đete_, _bądź_, brag,
   {{0xc7a30aec,0x78b000c6,0x6b8d020d,0x263500fe}},	//   жичк, _įkvė, crag, _áo_,
   {{0x7cf80080,0x7e7c04c8,0x6d441e7b,0x613d0018}},	//   _díre, narp, lmia, méle,
   {{0x442f0167,0x7cf80076,0x6d4f050f,0xd5b00037}},	//   _ayg_, _tírd, _yica, سفة_,
   {{0x442f052f,0x7d161e7c,0x6d43028d,0x7e7c1e7d}},	//   _byg_, nnys, _ènat, harp,
   {{0x2bc90469,0x61360074,0xfbc902c6,0x00000000}},	//   रिया, táln, रियम, --,
   {{0xdbdc025b,0x39581e7e,0xa2cd023a,0x6eeb1e7f}},	//   jšíc, _kurs_, ताग्, _tübi,
   {{0x61361e80,0x7e770063,0xdbdc0094,0x7e7c1e81}},	//   ráln, _rexp, dšíc, darp,
   {{0xb3560814,0x03a60636,0xab5b02e2,0xe8df0028}},	//   _پیدا_, _видо, _früh, _viện_,
   {{0x6d4f168c,0x7cf10939,0x6d44007f,0x00000000}},	//   _rica, _dårl, dmia, --,
   {{0xe8df0028,0x6d4f1e82,0x6b8d1e83,0x6d571097}},	//   _tiện_, _sica, vrag, _puxa,
   {{0x13b61117,0xab5b1e84,0x395801b9,0x61361e85}},	//   _अनुभ, _trük, _nurs_, cálo,
   {{0x61360103,0x00000000,0x00000000,0x00000000}},	//   náll, --, --, --,
   {{0xa2cb0096,0xdd2f02c6,0xdbdc00d4,0x113c00ca}},	// [1510] _थोड्, _těžb, bšíc, _בתהל,
   {{0x6b8d1e86,0xf9c70938,0x6d4f1e87,0x39580233}},	//   rrag, ищен, _wica, _burs_,
   {{0x39581e88,0x6d4f1e89,0x6b8d1e8a,0x7cf80503}},	//   _curs_, _tica, srag, _dírb,
   {{0x39581e8b,0x611201d3,0x69c100e8,0x00000000}},	//   _durs_, tāli, _šles, --,
   {{0x7d0d00a5,0x2366022e,0x00000000,0x00000000}},	//   mias, _ntoj_, --, --,
   {{0x39581e8c,0x442f1e8d,0x7cf80076,0x611201d3}},	//   _furs_, _ryg_, _víre, rāli,
   {{0xa5090396,0x442f1e8e,0x39580141,0xfc3f0503}},	//   лека_, _syg_, _gurs_, _mbím_,
   {{0x7d0d004b,0x61360103,0x201e00d3,0x92c30033}},	//   nias, gáll, ştii_, _একে_,
   {{0x57f5001f,0xe3b10037,0x24860117,0x44391e8f}},	//   _упат, سرة_, _ddom_, ås_,
   {{0x81e200c7,0x7d0d1e90,0x61360b0b,0x6d4400a5}},	//   _নেই_, hias, tálo, zmia,
   {{0x7e7c0088,0x6d440150,0xdbdc0031,0x2b5900b3}},	//   varp, ymia, všíc, _lusc_,
   {{0x5f05033a,0x6136045e,0x387d0150,0x3f6a0291}},	//   होस्_, rálo, nawr_, лимо_,
   {{0x7e7c1e91,0x320b0034,0x442f0a60,0xdbdc0a7f}},	//   tarp, ńcy_, _uyg_, tšíc,
   {{0x613d1e92,0x7529029a,0x3f5d00fe,0xc8f41e93}},	//   véle, loez, _dìu_, _आत्म_,
   {{0x61461e94,0xdbdc025b,0x7e7c1e95,0x51950037}},	//   _лека, ršíc, rarp, _العذ,
   {{0x3d08009d,0x7d0d1e96,0x2b59002b,0x2a781e97}},	//   _सगळे_, gias, _busc_, _serb_,
   {{0x6d441e98,0xdbdc025b,0x4aaa1a6d,0x39580141}},	// [1520] rmia, pšíc, лкан_, _surs_,
   {{0x3f8204a3,0x6d441e99,0x61360103,0xaad2045f}},	//   msku_, smia, záll, साइक,
   {{0x7cf808ec,0x7d0d1e9a,0xc87907aa,0x2b590090}},	//   _círc, bias, _beş_, _eusc_,
   {{0x273200d3,0x2b59028d,0x6f0e01c2,0x7c961e9b}},	//   mâni_, _fusc_, libc, _уроц,
   {{0x3f821e9c,0x09e00081,0x6136111c,0x02b70296}},	//   nsku_, _যেখা, váll, _असून,
   {{0xb8ef0d0b,0x3ce00128,0xe3e80018,0x3f821e9d}},	//   _वो_, ljiv_, یکشن_, isku_,
   {{0xceb300a1,0x9f4f004d,0x3958029a,0x61360103}},	//   פיה_, _ågå_, _uurs_, táll,
   {{0xdb1d0149,0x18a31e9e,0x3ce00995,0x4d7b0142}},	//   _ersä, _насм, njiv_, ארקע,
   {{0x3f8203ce,0x2418055b,0xe73a0396,0xbee80096}},	//   jsku_, ропы_, _беа_, _ऐकून_,
   {{0x3f82005f,0x3f5d00de,0x27f9007a,0x2bc90d61}},	//   dsku_, _rìu_, _üsna_, रिता,
   {{0xd2500a09,0x7529010a,0x00000000,0x00000000}},	//   بند_, boez, --, --,
   {{0x3a370054,0x463b00c1,0x61360103,0xca3700ca}},	//   מרים_, _געבע, lálj, מניה_,
   {{0x39460623,0x00000000,0x00000000,0x00000000}},	//   imos_, --, --, --,
   {{0x61360018,0xdb1d0161,0x28cf1e9f,0x2b5900ee}},	//   nálj, _essê, _सोनि, _rusc_,
   {{0xc27b07a6,0x2b5900e7,0x7d0d1ea0,0x00000000}},	//   _גרוי, _susc_, tias, --,
   {{0xdb060018,0x3f821ea1,0xe21700d7,0x00000000}},	//   _eskü, bsku_, _לקוח_, --,
   {{0x212b1ea2,0x6eeb00a7,0xa2cd0096,0xdcf500e8}},	// [1530] moch_, _sübu, ताच्, luzī,
   {{0x629a1ea3,0x7d0d1ea4,0xda670080,0x39461ea5}},	//   ngto, sias, صائي, emos_,
   {{0xb9b51ea6,0x9962025b,0x7d0d1ea7,0xa2c0039d}},	//   تماع, _píše_, pias, _वसन्,
   {{0x38351ea8,0x212b1ea9,0x319b0142,0x63a20415}},	//   онер, noch_, רבאנ, _oqon,
   {{0x656800dd,0x7d1d01c0,0x6fc90285,0x00000000}},	//   _atdh, _ijss, िटिं, --,
   {{0x212b1eaa,0x3cef0096,0x85b90037,0x52b70285}},	//   hoch_, _इकडे_, لابس_, _असेस,
   {{0x2d831eab,0x212b0181,0x057900e3,0x19941eac}},	//   nsje_, koch_, جمعة_, _наря,
   {{0x3f820188,0x2d8301c0,0x212b0031,0x6ab7016d}},	//   ysku_, isje_, joch_, lexf,
   {{0x212b1ead,0x290f1eae,0x75291eaf,0x7ae7023e}},	//   doch_, miga_, roez, _kojt,
   {{0x290f018d,0xf6f50159,0x13090084,0xdb1d0149}},	//   liga_, _بزرگ, рной_, _ursä,
   {{0xf7480080,0x7ae70559,0x2d83029a,0x63a20415}},	//   _اللي_, _mojt, jsje_, _eqon,
   {{0x3f8202e6,0x290f1eb0,0xa4f700cd,0x7ae7023b}},	//   tsku_, niga_, _دکتر_, _lojt,
   {{0x3f840343,0x61360018,0x2d83029a,0x6ef000bc}},	//   ému_, lálk, esje_, _häbi,
   {{0x3f821eb1,0x290f1eb2,0x68f801d3,0x7cea003e}},	//   rsku_, higa_, īvdi, _nýrr,
   {{0xdd920241,0x290f1eb3,0xddc30012,0x212b0031}},	//   ظور_, kiga_, мбри, boch_,
   {{0x3f821419,0x4c6a0b3b,0x212b1eb4,0x611201d3}},	//   psku_, риан_, coch_, tālu,
   {{0x290f1eb5,0x6ef0007a,0x63bb1eb6,0x2d83029a}},	// [1540] diga_, _läbi, nwun, asje_,
   {{0x2d9100a5,0xdcfc00d9,0x80d8009d,0x60c41eb7}},	//   brze_, turē, यावे, _haim,
   {{0x60c41eb8,0xfce61eb9,0x3eb81eba,0x409300cd}},	//   _kaim, _доно, mert_, _علیر,
   {{0x63bb00ac,0xeb9a1824,0x2d981ebb,0x290f1ebc}},	//   kwun, _ким_, mure_, giga_,
   {{0x39461ebd,0x60c41ebe,0xdb0404e2,0x394000d9}},	//   rmos_, _maim, ntië, ķis_,
   {{0x3946132d,0x60c41ebf,0x6b841ec0,0x3eb81ec1}},	//   smos_, _laim, msig, nert_,
   {{0x2d981ec2,0x290f1ec3,0x6b841ec4,0x77691ec5}},	//   nure_, biga_, lsig, _etex,
   {{0x443d02e2,0x3eb801bf,0x290f1ec6,0x60d6010a}},	//   _bzw_, hert_, ciga_, _nnym,
   {{0x3eb81ec7,0x6b841ec8,0xa6860318,0x14a60af1}},	//   kert_, nsig, _млад, क्षण,
   {{0x61360018,0x2d981ec9,0x212b01bf,0xe73a1eca}},	//   lálh, kure_, woch_, _тез_,
   {{0xd62a0084,0x3eb81ecb,0x60c41ecc,0x629a0abf}},	//   _тоже_, dert_, _baim, rgto,
   {{0x60c40441,0x613d0088,0x61360018,0xdb1d0428}},	//   _caim, féla, nálh, _essè,
   {{0x60c41ecd,0x3eb81ece,0x6b841197,0x212b1ecf}},	//   _daim, fert_, jsig, roch_,
   {{0x6b841ed0,0x290f0198,0x2d83029a,0x3eb801b4}},	//   dsig, ziga_, tsje_, gert_,
   {{0x290f1ed1,0x7ae71ed2,0x2d981ed3,0x2d851ed4}},	//   yiga_, _rojt, gure_, éle_,
   {{0x290f1ed5,0x6b84008c,0x2d831ed6,0x7cf100f2}},	//   xiga_, fsig, rsje_, _kåri,
   {{0x20020067,0x69de1ed7,0x290f1ed8,0x6b841ed9}},	// [1550] czki_, expe, viga_, gsig,
   {{0x3eb800ee,0xdb0400fd,0x2d9805bd,0x80a709c4}},	//   cert_, ntiè, bure_, ट्रे,
   {{0x7ae71eda,0x80b000c7,0x6b841edb,0x6d351edc}},	//   _vojt, য়ার্, asig, _неоф,
   {{0x52b71edd,0x6b84008a,0x63670220,0x02b709a1}},	//   _अस्स, bsig, nčný, _अस्न,
   {{0x290f1ede,0x3f991edf,0x69ce1ee0,0x6b84008a}},	//   riga_, nusu_, _erbe, csig,
   {{0x290f1ee1,0xb05b1ee2,0x00000000,0x00000000}},	//   siga_, ddäm, --, --,
   {{0x3f991ee3,0x290f068d,0x2bc90c9c,0x7cf800b6}},	//   husu_, piga_, रिवा, _mírn,
   {{0xd5ae00e3,0x61360146,0x3f991ee4,0x7bcf007e}},	//   افي_, rálk, kusu_, _krcu,
   {{0x2d981ee5,0x48fa00c1,0x3ea10037,0xdb1d1ee6}},	//   zure_, _פּלא, _ocht_, _assé,
   {{0x61361ee7,0x60c41ee8,0x613d1ee9,0x68e91eea}},	//   máli, _saim, véla, _hoed,
   {{0x3eb81eeb,0x60c41eec,0x80d8030b,0x68fb1eed}},	//   vert_, _paim, याले, _klud,
   {{0x3ea11eee,0x3eb802e2,0x6b841eef,0x443d0034}},	//   _acht_, wert_, ysig, _tzw_,
   {{0x68e91570,0x26c502e8,0xe28e1ef0,0x3eb81ef1}},	//   _moed, _kalo_, _па_, tert_,
   {{0x2d981ef2,0x26c50889,0x60c41ef3,0x3eb80364}},	//   ture_, _jalo_, _waim, uert_,
   {{0x26c50954,0x62811ef4,0x60c41ef5,0x57b800a5}},	//   _malo_, malo, _taim, _इन्ह,
   {{0x3ea11ef6,0x3eb802ec,0xab6604d9,0x26c50256}},	//   _echt_, sert_, звал, _lalo_,
   {{0x2d981ef7,0x2fc01ef8,0x3f9903e0,0x212001dc}},	// [1560] sure_, _usig_, cusu_, _ijih_,
   {{0x2d98013d,0x6b841ef9,0x26c503e1,0xfd1f0065}},	//   pure_, rsig, _nalo_, _ejì_,
   {{0x68fb1efa,0x68e902ae,0x14bd1efb,0xdb04037a}},	//   _blud, _boed, ्याण, ntié,
   {{0x7e7e1efc,0x68e91efd,0x68fb00f0,0x26c50188}},	//   _hepp, _coed, _clud, _aalo_,
   {{0x7e7e0088,0x26c51efe,0x68e2003d,0x68e90150}},	//   _kepp, _balo_, rjod, _doed,
   {{0x6d5e1eff,0x6281042d,0xf1db00a8,0x26c51f00}},	//   _kupa, jalo, यमान, _calo_,
   {{0x62811f01,0xbb431f02,0x69da0220,0x7e7e1f03}},	//   dalo, _черк, _štef, _mepp,
   {{0x68e91f04,0x7e7e1f05,0x6d5e1f06,0x68fb1f07}},	//   _goed, _lepp, _mupa, _glud,
   {{0x6d5e1f08,0x26c51f09,0x6136124d,0x38660072}},	//   _lupa, _falo_, cáli, mcor_,
   {{0x62811f0a,0xe3af1f0b,0x26c51f0c,0x98b8013f}},	//   galo, اري_, _galo_, _kurį_,
   {{0xd48f1f0d,0xb5ca1673,0xdceb0a9e,0xa50a1f0d}},	//   _пр_, _دوام_, _žiča, _лежа_,
   {{0x26c51f0e,0x3f991f0f,0x64a6004b,0x63a400ae}},	//   _zalo_, tusu_, _хада, _ţinu,
   {{0x6d5e1f10,0x7e7e0451,0xe5051f11,0x255501d3}},	//   _aupa, _bepp, _تبلي, _tālr_,
   {{0x628a01c5,0x6d5e1f12,0x7e7e1f13,0x3f991f14}},	//   _udfo, _bupa, _cepp, rusu_,
   {{0xa2a1009d,0x3f991f15,0x7e7e1f16,0x1df80109}},	//   _खात्, susu_, _depp, перы_,
   {{0x291c1f17,0x5d541bd1,0x6d5e00d8,0x00000000}},	//   éval_, екст, _dupa, --,
   {{0x68e902e0,0x201e0b88,0xd0080831,0xb05b007b}},	// [1570] _roed, ştir_, _неће_, hdäk,
   {{0x68fb00d9,0x7cf80018,0x79850201,0x7e7e0036}},	//   _slud, _hírl, tshw, _gepp,
   {{0x68fb1f18,0x68e91f19,0x6d5e1f1a,0x26c50131}},	//   _plud, _poed, _gupa, _ralo_,
   {{0x26c51114,0xf99000b1,0x61361f1b,0x7e7e1f1c}},	//   _salo_, ابل_, táli, _zepp,
   {{0x2b9314df,0x68e904ee,0x37ab1e54,0x7e7e0412}},	//   _سیاس, _voed, стен_, _yepp,
   {{0x68e90a9f,0x61361f1d,0x62810072,0x657a00eb}},	//   _woed, ráli, xalo, _bwth,
   {{0x68e91f1e,0x273200ae,0x61361f1f,0x7cf8037a}},	//   _toed, vânt_, sáli, _oírl,
   {{0x68fb026a,0x61361f20,0x6d4a028d,0x26c51f21}},	//   _ulud, páli, _èfat, _walo_,
   {{0x26c51f22,0xa2a1022d,0x7f5f003d,0x25a701c0}},	//   _talo_, _खाद्, _nuqq, stnl_,
   {{0x21cc02c6,0x7bcd1f23,0x657a00eb,0x613601f9}},	//   _běh_, ivau, _fwth, nálv,
   {{0x387f000b,0x68430032,0x63a4020a,0x7e7e0dd8}},	//   _keur_, _fìdí, _ţint, _repp,
   {{0x62811f24,0x6d5e1f1a,0xdb0405e6,0x7e7e1f25}},	//   salo, _rupa, rtié, _sepp,
   {{0x6d5e1f26,0x387f1f27,0xe8df0023,0x73e4004d}},	//   _supa, _meur_, _nhọn_, _поїз,
   {{0x387f04ea,0x6281041c,0x56b50142,0x00000000}},	//   _leur_, qalo, ופֿן_, --,
   {{0x63a91f28,0x6da30aec,0x00000000,0x00000000}},	//   lten, кира, --, --,
   {{0x249f0102,0x20561b70,0x7cf81f29,0x387f1f2a}},	//   ngum_, _отпр, _víro, _neur_,
   {{0xe8df00ef,0x7e7e1f2b,0x3ceb00b3,0x38c600c6}},	// [1580] _chọn_, _tepp, _docv_, _jūrų_,
   {{0x63a91f2c,0x6d5e1f2d,0xc31f0033,0xf1b10179}},	//   iten, _tupa, _নীতি_, _जहान,
   {{0x63a91f2e,0x80a50442,0x996500f3,0x6d5e0270}},	//   hten, _कामे, етіл, _uupa,
   {{0x63a91f2f,0x00000000,0x00000000,0x00000000}},	//   kten, --, --, --,
   {{0x387f1f30,0x38661f31,0x2ca00124,0x6d4600bc}},	//   _deur_, rcor_, mgid_, _ihka,
   {{0x38661f32,0x61360088,0xdcfc0138,0x291d010a}},	//   scor_, málu, turė, anwa_,
   {{0x63a9002d,0x941801d4,0xceb300a1,0x28cf0789}},	//   eten, ərə_, דיו_, _सोवि,
   {{0x387f1f33,0x2ca01f34,0x63a91f35,0x6128008b}},	//   _geur_, ngid_, ften, nıld,
   {{0x63a91f36,0x77910281,0x2ca000aa,0x69e300ae}},	//   gten, _مینا, igid_, ăteş,
   {{0x69c80072,0x7cf11842,0x2732020a,0x387f0381}},	//   _ádes, _hårt, râns_, _zeur_,
   {{0x6128026a,0x61151f37,0x2b581f38,0x00000000}},	//   kıld, едну, _mirc_, --,
   {{0x63a91f39,0x160700a8,0x00000000,0x00000000}},	//   bten, _वेटर_, --, --,
   {{0x63a91f3a,0xa2940c10,0x7cf10212,0x6128013c}},	//   cten, _залі, _mårt, dıld,
   {{0x44261f3b,0x2fd21e8f,0x7cf80503,0x6d461f3c}},	//   _ixo_, _dryg_, _dírm, _ahka,
   {{0x6d460167,0x9e341689,0x929b00ca,0x5e5800ae}},	//   _bhka, верч, _ויות, диря_,
   {{0x2b581f3d,0xa2d6009f,0x2ca00a4b,0x25df0285}},	//   _airc_, बाक्, ggid_, कमती_,
   {{0x2b5800c4,0x8aa71f3e,0x2fd203a8,0xf09f00ee}},	// [1590] _birc_, дред, _gryg_, siàs_,
   {{0x2d85058a,0x7bcd032c,0xab94004d,0x00000000}},	//   áles_, rvau, тифі, --,
   {{0x63a91f3f,0x387f0257,0x7bcd007b,0xed6400d4}},	//   zten, _peur_, svau, raží_,
   {{0x63a91f40,0xf77100ab,0x09b10081,0x2b580124}},	//   yten, هات_, ছিলা, _eirc_,
   {{0x6d4d1f41,0x2b580072,0x387f0381,0x00000000}},	//   mmaa, _firc_, _veur_, --,
   {{0xd2461f42,0x6d4d1f43,0x61360018,0xc87900ae}},	//   _من_, lmaa, lált, _roşu_,
   {{0x44260131,0x6d4d1f44,0xa8a71d8a,0x00000000}},	//   _axo_, omaa, _орак, --,
   {{0x6d4d1f45,0x61360018,0xe3c80023,0xc9841f46}},	//   nmaa, nált, _bự_, _јури,
   {{0x38341f47,0x249f1f48,0x752200e7,0xe3c80023}},	//   _антр, rgum_, _djoz, _cự_,
   {{0xe3c80028,0x8af00092,0x644200e7,0x6d4d0188}},	//   _dự_, qqət, _dzoi, hmaa,
   {{0x44260da7,0x6d4d1183,0x612803e0,0xa0a60036}},	//   _exo_, kmaa, yıld, нанд,
   {{0xcea9004f,0x248400b3,0x6128013c,0x00000000}},	//   _לי_, camm_, xıld, --,
   {{0x6d4d1f49,0x6136109d,0xdb1d1f4a,0x251a0142}},	//   dmaa, dált, _assí, _צונא,
   {{0x6d4601e5,0x65611f4b,0x6d4d112f,0x201e020a}},	//   _shka, _kulh, emaa, ăti_,
   {{0x65610396,0xe81600a5,0x61280587,0x61360850}},	//   _julh, _देना_, tıld, fált,
   {{0x656100c9,0x6d4d1f4c,0x6b961f4d,0x2fd202b6}},	//   _mulh, gmaa, tryg, _tryg_,
   {{0x612807aa,0xf1c90019,0x2ca01f4e,0xe7bf0179}},	// [15a0] rıld, _hạ_, rgid_, _शैलप,
   {{0x6d4d1f4f,0x6b960537,0x20ac06eb,0x61280233}},	//   amaa, rryg, ट्रध, sıld,
   {{0x753b025b,0x61280587,0x499a1c32,0x91fc00e8}},	//   kluz, pıld, ятая_, ecāj,
   {{0x6d4d008a,0x6d4600c2,0xf1c90023,0x57a608f9}},	//   cmaa, _uhka, _mạ_, ешка,
   {{0xf1c90019,0xe73a1c4c,0x753b1f50,0x69c302b6}},	//   _lạ_, пед_, dluz, æner,
   {{0x8f9b00c1,0xe5c61ada,0x65611f51,0x7d041f52}},	//   פיצי, есио, _bulh, lhis,
   {{0xe3c800ef,0xaa4308d9,0x7cf1040f,0xf1c900de}},	//   _sự_, _берл, _tårt, _nạ_,
   {{0x2d9804c3,0x656103a9,0xe8b503e0,0x273b0023}},	//   irre_, _dulh, mışı, hênh_,
   {{0xd90d037f,0xe8b508bb,0x24841f53,0x00000000}},	//   _بین_, lışı, ramm_, --,
   {{0xf1c900de,0x55e6004d,0x78a21f54,0x23d209a1}},	//   _bạ_, _позб, lgov, तिबद,
   {{0xe8b50740,0x7d040201,0x61361ee7,0x9f4400b6}},	//   nışı, khis, jáls, ámý_,
   {{0xe3c800ef,0x78a20618,0x7d041f55,0xf1c900de}},	//   _tự_, ngov, jhis, _dạ_,
   {{0x66f4007d,0x04570080,0x7d041f56,0x65611f57}},	//   _अवाक_, _كلمة_, dhis, _zulh,
   {{0x3ea50018,0x1ee700cd,0xe8b5026a,0x6abe0027}},	//   ült_, روزی_, kışı, jepf,
   {{0x7bc600dd,0x6d4d1f58,0xf1c900fe,0x6abe0113}},	//   _asku, tmaa, _gạ_, depf,
   {{0x7d041f59,0x23b71362,0x6d4d1f5a,0xd904001c}},	//   ghis, _अहमद, umaa, _طی_,
   {{0x6d4d1f5b,0x61361823,0x628e0034,0x00000000}},	// [15b0] rmaa, rált, óbow, --,
   {{0x6d4d1f5c,0x0a681f5d,0xadf501b3,0xab18004d}},	//   smaa, ерци_, _апош, нієї_,
   {{0x7bc603f3,0x7d041f5e,0xf1c900de,0x6d4d1044}},	//   _esku, bhis, _xạ_, pmaa,
   {{0x7d041f5f,0x38c90018,0x6d4d0188,0x7cf11f60}},	//   chis, بائی_, qmaa, _vårs,
   {{0x65611f61,0xa2a1052c,0x00000000,0x00000000}},	//   _sulh, _खाल्, --, --,
   {{0x7aee1f62,0x00000000,0x00000000,0x00000000}},	//   _gobt, --, --, --,
   {{0x50b10e50,0x656100dc,0x2bc90386,0x00000000}},	//   जभाष, _qulh, रिका, --,
   {{0x69c71f63,0x78a200e7,0x09e70033,0x00000000}},	//   _isje, cgov, পনদা, --,
   {{0x3f8b00a5,0xd4680037,0x753b1f64,0x00000000}},	//   jscu_, رحيم_, rluz, --,
   {{0x466b1f65,0x77900018,0xdcfc01d3,0x69d50034}},	//   _храм_, _ایوا, turī, _krze,
   {{0x3f8b1f66,0x7d041f67,0x76440022,0x65940077}},	//   escu_, yhis, ƙiya, _баху,
   {{0x69d50d12,0xdddc0095,0x7d041f68,0xf1c900fe}},	//   _mrze, jarš, xhis, _vạ_,
   {{0xaca30134,0xc95200c1,0x03a500d3,0xdddc0141}},	//   _chọb, ימט_, _рило, darš,
   {{0x69c7029b,0x78a202e6,0x69d50034,0xf1c900de}},	//   _osje, zgov, _orze, _tạ_,
   {{0x7d041f69,0x2d8c1f6a,0x386d1f6b,0x98ad0090}},	//   this, éde_, _ofer_, _gieħ_,
   {{0x62831f6c,0x7aee0428,0xbddc0065,0x6ef9009c}},	//   _heno, _sobt, _aṣòf, _lìbh,
   {{0x628303a9,0x7aee01fa,0x7d040c2e,0x69c71f6d}},	// [15c0] _keno, _pobt, rhis, _asje,
   {{0x7d041f6e,0x62831f6f,0x386d1f70,0x799e0239}},	//   shis, _jeno, _afer_, tupw,
   {{0x62831535,0x7d041f71,0x1d0a01c9,0x7cf81f72}},	//   _meno, phis, _жени_, _líri,
   {{0xe8b508bb,0x69d50034,0x2900016d,0x00000000}},	//   rışı, _drze, óia_, --,
   {{0x7bc61f73,0x98a31612,0x69d51f74,0x66e61f75}},	//   _usku, риче, _erze, кода,
   {{0x62831f76,0xa3d51f77,0x47330426,0x799e0350}},	//   _neno, हिन_, аніс, pupw,
   {{0x27e0002d,0x69d500a5,0x69d802b6,0x09e316bd}},	//   ţin_, _grze, æved, _корн,
   {{0x3f4f02a1,0xaae000b6,0x00000000,0x00000000}},	//   _jżur_, नावक, --, --,
   {{0x62831f78,0x7d0300d3,0x7cf80131,0x00000000}},	//   _beno, _înse, _círi, --,
   {{0x7cf80037,0xe6c50037,0x80a50006,0x9af00022}},	//   _díri, _متمي, _काहे, _ƙaƙa_,
   {{0x26de1f79,0xe8161362,0x31c3008f,0x320901c2}},	//   _into_, _देता_, асяв, _ƙaya_,
   {{0x29061f7a,0x26cc1f7b,0x7cf80037,0x62831f7c}},	//   nhoa_, _hado_, _fíri, _eeno,
   {{0x26cc1f7d,0x4394168c,0x29061f7e,0xef1f173c}},	//   _kado_, _салс, ihoa_, ssüm_,
   {{0x62831f7f,0x044308c3,0xe5710103,0x80a5077d}},	//   _geno, _течн, _خطے_, _कावे,
   {{0x62881f80,0x26cc1f81,0xdddc025b,0x8233110a}},	//   mado, _mado_, tarš, _پروا,
   {{0x26cc0b0b,0x6d580036,0x3ead00d2,0x00000000}},	//   _lado_, _èval, řet_, --,
   {{0x63a00808,0x7c841f82,0x2b4a0013,0x26de00ca}},	// [15d0] numn, русе, _bhbc_, _onto_,
   {{0x69d51f83,0x62881f84,0x26cc08a8,0x613d0257}},	//   _prze, nado, _nado_, déli,
   {{0x612807aa,0x60cd1f85,0xf9c7008f,0x63a00580}},	//   lıla, _kaam, ъщан, humn,
   {{0x63a01f86,0x60cd1f87,0xf1b300c1,0xa3d51f88}},	//   kumn, _jaam, יסע_, हिम_,
   {{0x60cd1f89,0xb8cb0e50,0x26cc068d,0x61281f8a}},	//   _maam, _खा_, _bado_, nıla,
   {{0x69d50067,0x62881f8b,0xa3d6152c,0x6d5d1f8c}},	//   _trze, jado, ाटन_, _hisa,
   {{0x26cc0d9f,0x7cf81f8d,0xdb04016d,0x69c704e9}},	//   _dado_, _síri, stiã, _usje,
   {{0x23ab01c5,0x62831f8e,0x29061f8f,0x6d5d0051}},	//   tøj_, _seno, choa_, _jisa,
   {{0x6b8d0303,0x62831a49,0x26cc1f90,0x63a01f91}},	//   nsag, _peno, _fado_, gumn,
   {{0x6d5d05a7,0x6128008e,0x26cc1f92,0x7cf81f93}},	//   _lisa, dıla, _gado_, _víri,
   {{0x60cd1f94,0x62830220,0x05960260,0x5ed20033}},	//   _baam, _veno, _مانگ, _সকলে,
   {{0x6d5d08c5,0x63a0019f,0x60cd1f95,0xd5fa006e}},	//   _nisa, bumn, _caam, _אפער,
   {{0xe2991b60,0x61280233,0x60cd1f96,0x80a506eb}},	//   _зал_, gıla, _daam, _कारे,
   {{0x62881f97,0x6d5d0af0,0x6da60012,0x339200e3}},	//   cado, _aisa, лига, _الوز,
   {{0x6d5d1098,0x60cd1f98,0x78a900cc,0xb17600de}},	//   _bisa, _faam, _ocev, _trượ,
   {{0x6d5d1f99,0x60cd1f9a,0x6128071d,0x6b8d01cd}},	//   _cisa, _gaam, bıla, fsag,
   {{0x61281f8a,0x6d5d14a5,0x6b8d1f9b,0xeb971e79}},	// [15e0] cıla, _disa, gsag, лит_,
   {{0x78a90328,0x2bc91388,0x4e361f9c,0x999105db}},	//   _acev, रिजा, _معجز, _dzzž_,
   {{0x6d5d1f9d,0x2d95020f,0x60cd1f9e,0x443d03a8}},	//   _fisa, _кряс, _yaam, _lyw_,
   {{0x613d1f9f,0x6d5d1fa0,0xfce6188d,0x26cc1fa1}},	//   téli, _gisa, _сомо, _sado_,
   {{0x62881fa2,0xbcfb1fa3,0x0137006e,0x443d0172}},	//   yado, _diéd, אָגט_, _nyw_,
   {{0x62881fa4,0x613d1fa5,0x6d5d1fa6,0x36d41e46}},	//   xado, réli, _zisa, рокр,
   {{0xe1e71fa7,0x61280702,0x7d03002d,0x26cc0448}},	//   _اس_, zıla, _însc, _vado_,
   {{0x62881fa8,0x80d40775,0x443d02ad,0x6d5d008a}},	//   wado, _बोले, _byw_, _xisa,
   {{0x62880b0b,0x29041fa9,0x60cd0837,0x28e11317}},	//   tado, _ilma_, _raam, फारि,
   {{0xc8790491,0x443d00f0,0xadf600c3,0xf2c60231}},	//   _inşa_, _dyw_, ीनान_, усин,
   {{0x63a00995,0x22581faa,0x60cd1fab,0x38690542}},	//   sumn, ärk_, _paam, žare_,
   {{0x612803a3,0x6b8d1fac,0x60cd026d,0x443d0150}},	//   tıla, ysag, _qaam, _fyw_,
   {{0x62880979,0x60cd1fad,0x33f615af,0x6b4b042c}},	//   pado, _vaam, _حساس, lüge,
   {{0x612807d1,0x6d5d0efd,0x60cd1fae,0x6b8d00d6}},	//   rıla, _sisa, _waam, vsag,
   {{0x60cd1faf,0xbcfb0257,0x69da1206,0x6b4b01bf}},	//   _taam, _liée, _šten, nüge,
   {{0x61280b88,0x2fc9023e,0x6b8d1fb0,0x6d5d1fb1}},	//   pıla, _tsag_, tsag, _qisa,
   {{0x6d5d1fb2,0x5b151fb3,0x443d023e,0x212903a9}},	// [15f0] _visa, амат, _xyw_, _ijah_,
   {{0xa3d51fb4,0x6d5d1fb5,0x6b8d1fb6,0x78a90036}},	//   हित_, _wisa, rsag, _scev,
   {{0x6b8d1fb7,0x6d5d1fb8,0x06cd0081,0x64b40096}},	//   ssag, _tisa, লামি, ंभाळ,
   {{0xc9130081,0x6b8d1fb9,0xd7d5001f,0xe8160ff9}},	//   িক্ত_, psag, ижењ, _देहा_,
   {{0xdb0409d3,0x21290381,0x75dc044c,0x00000000}},	//   stiá, _mjah_, _lăză, --,
   {{0x6b4b02e2,0x443d00f0,0x29041fba,0x00000000}},	//   füge, _ryw_, _elma_, --,
   {{0x6ead000d,0xba740068,0x256a0441,0x5a4408a1}},	//   _जानु, _چاہت, _cùl_, _гэта,
   {{0x2d9e192a,0xe8161fbb,0xdff700c3,0xf8c91981}},	//   šteg_, _देवा_, ुनाद_, _रसिय,
   {{0xf77000bf,0xab5b00aa,0x320c0031,0x67d400ae}},	//   _فال_, _psüh, ezdy_, _лоту,
   {{0x212900a4,0x98140867,0x82f5129c,0x57f40284}},	//   _ajah_, _طبقا, рчиц, _упут,
   {{0x394d022e,0xf8c909c4,0x75dc078e,0x00000000}},	//   _khes_, _रसाय, _căză, --,
   {{0x33d50426,0x2486028d,0xa3d50034,0x628e11e9}},	//   _вікт, _geom_, हिद_, óbor,
   {{0x95541e49,0x212902ef,0xa93600ca,0x320c0034}},	//   _اخلا, _djah_, שטרה_, azdy_,
   {{0xe299075f,0xa85600a1,0x394d1097,0x23d203b3}},	//   _рак_, יירה_, _lhes_, तिरद,
   {{0x2cb901b9,0x21a50036,0x764e0094,0x00000000}},	//   _bbsd_, _тийм, _úbyt, --,
   {{0x25ed0b5f,0xa3c90034,0x395f1fbc,0xe80800b6}},	//   _अपनी_, _ऊना_, _nius_, वनमा_,
   {{0xed571fbd,0x81cc0081,0xcb6700d3,0x6b4b1fbe}},	// [1600] рот_, রমণ_, иате_, züge,
   {{0x316710f4,0x0d86182e,0x1e961fbf,0x00000000}},	//   _kunz_, _клон, _трир, --,
   {{0x395f02e7,0x6f1c1fc0,0xfc3f0032,0x7e9b00ca}},	//   _bius_, mirc, _eyí_, _בסיו,
   {{0x613d0a61,0x6f1c0036,0x394d030a,0x00000000}},	//   bélu, lirc, _ches_, --,
   {{0x395f0428,0x67d407c7,0x394d0113,0xb8160442}},	//   _dius_, солу, _dhes_, _देशम_,
   {{0x7cf81fc1,0x6f1c1fc2,0x971304a1,0xb8fd0285}},	//   _víru, nirc, оміц, _थो_,
   {{0x4420002d,0x395f1fc3,0x95ca1fc4,0x55060012}},	//   _ţi_, _fius_, тула_, ичиа,
   {{0x395f0036,0xc44800d1,0x00000000,0x00000000}},	//   _gius_, هیان_, --, --,
   {{0x6f1c1fc5,0xdcef0995,0x14a700c3,0x00000000}},	//   kirc, žeće, _गारण, --,
   {{0x6f1c0022,0x21291fc6,0x00000000,0x00000000}},	//   jirc, _sjah_, --, --,
   {{0x8ad9006e,0xd62700c2,0x98af01d3,0x7ad90142}},	//   אַרפ, _кофе_, logā_, אַרה,
   {{0x67381fc7,0x25be0a4b,0x656801ec,0x236600c6}},	//   lovj, _iptl_, _iudh, _tuoj_,
   {{0x65681fc8,0x6f1c0d2a,0x9f59014b,0x85350103}},	//   _hudh, firc, lysé_, _اونچ,
   {{0x65681fc9,0x31670036,0xe7f90287,0x00000000}},	//   _kudh, _funz_, ्नता_, --,
   {{0x51860ff1,0xe2970291,0x656800cd,0x31670227}},	//   _тула, _тај_, _judh, _gunz_,
   {{0x65681fca,0x6f1c036b,0x21290372,0x00000000}},	//   _mudh, airc, _ujah_, --,
   {{0x2d5814fa,0x395f0428,0x656801b9,0x67381fcb}},	// [1610] рить_, _rius_, _ludh, kovj,
   {{0x67380fa3,0x21390052,0x65681183,0xaaac09c4}},	//   jovj, losh_, _oudh, _चाणक,
   {{0x656801dc,0x67381fcc,0x9c830141,0x7c2911dc}},	//   _nudh, dovj, _ščuk, _žerd,
   {{0xa3d605cd,0xbcfb0113,0x21390052,0x00000000}},	//   ाटा_, _diéc, nosh_, --,
   {{0x395f0428,0xb0aa0034,0x2d910034,0x2ca901d3}},	//   _vius_, _कासग, lsze_, mgad_,
   {{0x65681fcd,0x16a91346,0x67381fce,0xa3d510e9}},	//   _budh, увки_, govj, हिस_,
   {{0x394d1fcf,0x2139023b,0xc5d5097a,0xdcfb152c}},	//   _thes_, kosh_, сіль, _एकाध_,
   {{0x2ca91fd0,0x28cf121d,0x7af51fd1,0xb9250037}},	//   ngad_, _सोचि, _hozt, _افري,
   {{0x291d1ee3,0x261700b6,0x21391fd2,0x6f1c0233}},	//   miwa_, _भेरी_, dosh_, yirc,
   {{0x291d1ee3,0xddde1b32,0x73051057,0x6568005c}},	//   liwa_, _lepš, споз, _fudh,
   {{0xdb04001f,0x65681fd3,0x7af51fd4,0x2d910034}},	//   stiç, _gudh, _mozt, jsze_,
   {{0x291d0051,0x21391fd5,0x14ca00d1,0x00000000}},	//   niwa_, gosh_, _مهمی_, --,
   {{0xc50c00c1,0x9fd60033,0xb05b007b,0xa2d20f8f}},	//   _בלאָ, সঙ্গ, seän, _भोक्,
   {{0x65681783,0x291d1fd6,0x644b1fd7,0x84e5009f}},	//   _yudh, hiwa_, _izgi, कावट_,
   {{0x291d1ee3,0x6b50070a,0x78bb1fd8,0x7d0600d9}},	//   kiwa_, lägg, _obuv, _plks,
   {{0x291d0010,0x2ca90149,0x3c6601b3,0x3860007e}},	//   jiwa_, ggad_, скаг, žiri_,
   {{0x09b2110f,0x61281f8a,0x291d0010,0x6d4f1fd9}},	// [1620] ीब्य, nılm, diwa_, _dhca,
   {{0x2ca900f9,0x78bb04ff,0xbcfb020d,0x60c601f9}},	//   agad_, _abuv, _piéc, lekm,
   {{0x8db600d6,0x291d0051,0x6d4f009c,0x7af501ff}},	//   _успі, fiwa_, _fhca, _dozt,
   {{0x98a60a8e,0x6128026a,0x291d1fda,0x6d4f01b9}},	//   сиде, kılm, giwa_, _ghca,
   {{0x65681837,0x31b10018,0xc7a31fdb,0x6d441fdc}},	//   _sudh, ház_, зичк, mlia,
   {{0x61280092,0x6d441fdd,0x05d30096,0x78bb083e}},	//   dılm, llia, थिंब, _ebuv,
   {{0x386904a3,0x6d4402ad,0x291d1fde,0x67381fdf}},	//   žara_, olia, biwa_, rovj,
   {{0x53981031,0x69ce0188,0x291d1fe0,0x6d440076}},	//   авия_, _isbe, ciwa_, nlia,
   {{0x65680da3,0x2d850fb6,0x67380268,0x6d441fe1}},	//   _wudh, ález_, povj, ilia,
   {{0x6d441fe2,0x65681fe3,0x00000000,0x00000000}},	//   hlia, _tudh, --, --,
   {{0xe3af1b67,0x6d44013f,0x69da0087,0x21391fe4}},	//   وری_, klia, _štej, tosh_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d910067,0xb0aa000f,0x6d440150,0x2139023b}},	//   wsze_, _कारग, dlia, rosh_,
   {{0x291d1fe5,0xa3d51fe6,0x69dc1fe7,0x64420113}},	//   ziwa_, हिर_, _orre, _iyoi,
   {{0x7af51fe8,0x8cda009d,0x291d1fe9,0x2d851fea}},	//   _rozt, _पोहो, yiwa_, èle_,
   {{0x6d440465,0x2d911feb,0x656201c2,0x50671469}},	//   glia, rsze_, _jioh, _утка,
   {{0x69dc1fec,0x7af51fed,0x2ca91fee,0x69d802b6}},	// [1630] _arre, _pozt, rgad_, æven,
   {{0x2d9100a5,0x6d441fef,0x69dc1ff0,0xaa671ff1}},	//   psze_, alia, _brre, стак,
   {{0x291d0010,0x612803a3,0x7d0300ae,0xd8790037}},	//   tiwa_, zılm, _înso, لمات_,
   {{0x612807aa,0x628a0103,0x6ca700ba,0xe894004d}},	//   yılm, _lefo, _урож, заць,
   {{0x69dc1ff2,0x62981ff3,0x291d1ff4,0x7d0d1ff5}},	//   _erre, _odvo, riwa_, mhas,
   {{0x7d0d0068,0x291d1ff6,0xab5b0018,0xdb0d0037}},	//   lhas, siwa_, _csüt, otaí,
   {{0x24e90465,0xceb4040a,0xdb0d0037,0x442f0042}},	//   имки_, פיק_, ntaí, _sxg_,
   {{0x61280587,0x6562009c,0x78bb02a4,0x7d0d1ff7}},	//   tılm, _cioh, _ubuv, nhas,
   {{0x628a1ff8,0x1309049f,0x248d0131,0x00000000}},	//   _befo, иний_, raem_, --,
   {{0x612807d1,0x42251ff9,0xe2990859,0x56941ffa}},	//   rılm, ждов, јан_, _наут,
   {{0x90c602fd,0x7d0d1ffb,0x60c600d9,0x6d440150}},	//   обне, khas, tekm, ylia,
   {{0xf9920054,0x61281001,0x7bcf1ffc,0x320b00a5}},	//   ורט_, pılm, _oscu, ący_,
   {{0x7529002d,0x7d0d1ffd,0x6b500704,0x60c6026a}},	//   mnez, dhas, läge, rekm,
   {{0x26c70010,0xa3d60d39,0x628a1ffe,0x753b1fff}},	//   neno_, ाटर_, _gefo, louz,
   {{0x62812000,0x7bcf002d,0x6d442001,0x75292002}},	//   mblo, _ascu, tlia, onez,
   {{0x7d0d2003,0x62812004,0x26c72005,0x6d442006}},	//   ghas, lblo, heno_, ulia,
   {{0x8c432007,0x6d562008,0x6d442009,0x8eba00d3}},	// [1640] дете, rmya, rlia, _кынт_,
   {{0xb0aa14db,0x7bcf037a,0x98ad0031,0x753b0022}},	//   _काँग, _dscu, _cieľ_, houz,
   {{0x7d0d200a,0x26c7200b,0x764401c2,0x49ca0b21}},	//   bhas, deno_, ƙiyi, рлен_,
   {{0x7d0d00ac,0xdb0400e3,0x31ba00c1,0xd7fa002d}},	//   chas, ntiú, יזענ, иул_,
   {{0x765f01d4,0x7529200c,0x6281200d,0x6562200e}},	//   əyyə, dnez, kblo, _rioh,
   {{0x7d040084,0x26c7028d,0x7529200f,0x00000000}},	//   lkis, geno_, enez, --,
   {{0xb0aa2010,0x69dc2011,0xaa432012,0x20aa049d}},	//   _कांग, _urre, _жерл, _कांध,
   {{0x7d042013,0xa3d52014,0x00000000,0x00000000}},	//   nkis, हिं_, --, --,
   {{0x39462015,0x26c72016,0x628a0154,0x25e600c3}},	//   mlos_, beno_, _pefo, _झपकी_,
   {{0x394611ce,0x26c72017,0x20d70023,0x7d040e22}},	//   llos_, ceno_, _ủi_, hkis,
   {{0xd48f2018,0x7d042019,0xdb04034f,0xb5ca00d1}},	//   _ор_, kkis, guié, _خوام_,
   {{0x394602e2,0x657a0103,0x7d0d019f,0x3860031a}},	//   nlos_, _itth, xhas, žiru_,
   {{0x6281201a,0x00000000,0x00000000,0x00000000}},	//   bblo, --, --, --,
   {{0x62980106,0x6281201b,0xdb04201c,0xbcfb0143}},	//   _udvo, cblo, quiè, _cién,
   {{0x7d0d201d,0xf27b0054,0x394601b3,0xbcfb01dc}},	//   thas, _דרוש, klos_, _dién,
   {{0xdb0400e3,0x26c711d5,0x3946023e,0x80a5201e}},	//   ctiú, zeno_, jlos_, _काटे,
   {{0x7d0d201f,0x3946082b,0xdb0d00e3,0x00000000}},	// [1650] rhas, dlos_, staí, --,
   {{0x7d0d2020,0x657a0018,0x26c70042,0x394605e6}},	//   shas, _otth, xeno_, elos_,
   {{0xceb2193b,0x7d0401ad,0x7d0d2021,0xaaac00b6}},	//   _איי_, bkis, phas, _चारक,
   {{0x6b500149,0x39462022,0x7d042023,0xcdda00c1}},	//   väge, glos_, ckis, _פֿיר,
   {{0x26c72024,0x657a061d,0x60dc00c1,0x66e51c66}},	//   teno_, _atth, יקאנ, зола,
   {{0x628101c5,0x39460072,0xff7c006e,0x00000000}},	//   xblo, alos_, סטומ, --,
   {{0x26c70106,0x80ac02e8,0x39462025,0x7bcd2026}},	//   reno_, _झाले, blos_, lwau,
   {{0x61360068,0x39462027,0x6b5001bf,0x62810381}},	//   bály, clos_, räge, wblo,
   {{0x62812028,0x26c72029,0x753b0072,0x7529044c}},	//   tblo, peno_, rouz, rnez,
   {{0x13090ab3,0x753b02c6,0xcfd10033,0x77f900c3}},	//   сной_, souz, ামান, ्नीक_,
   {{0x7d040501,0x753b0995,0xbcfb037a,0xcb1200ca}},	//   ykis, pouz, _rién, גלי_,
   {{0x7bcd01c2,0xbcfb034f,0x00000000,0x00000000}},	//   kwau, _sién, --, --,
   {{0xb4d702d5,0x4aac0096,0x14ca001c,0xaaac0469}},	//   ायी_, _चालव, _دهنی_, _चालक,
   {{0x3f9e025b,0x657a0314,0xe7f31c65,0x63a90a4b}},	//   čtu_, _ytth, _आपना_, muen,
   {{0x7d04202a,0xdb0400fd,0xbcfb034f,0xc27a0327}},	//   tkis, quié, _vién, _פרקי,
   {{0x25710088,0x61fc02c3,0x41b20037,0xa01b01cd}},	//   _mál_, ärle, _أمير, mbön,
   {{0x7d04202b,0xfbdf0131,0x3f89030a,0x63a9202c}},	// [1660] rkis, _crê_, _gwau_, nuen,
   {{0x7d04202d,0xa3dc06ae,0x60d6202e,0xe8160034}},	//   skis, डित_, _haym, _देगा_,
   {{0x9d461da3,0x60d6202f,0x2c750174,0x63a90174}},	//   _неод, _kaym, _ụde_, huen,
   {{0x63a92030,0x7ae7023b,0x61360103,0xaa570076}},	//   kuen, _enjt, tály, سلنا_,
   {{0x39462031,0xe8160c8c,0x2efa01bf,0xdcf700ae}},	//   rlos_, _देखा_, _kopf_, şcăr,
   {{0x61360103,0x39462032,0x4e7a006e,0x00000000}},	//   rály, slos_, זאַצ, --,
   {{0x39462033,0x25710072,0x00000000,0x00000000}},	//   plos_, _cál_, --, --,
   {{0x399b00a1,0x2571030b,0x63a904c3,0x2907023b}},	//   _לילד, _dál_, fuen, ënat_,
   {{0x63a92034,0x2a6a0167,0x07a3001f,0x6b962035}},	//   guen, _kgbb_, _патн, nsyg,
   {{0xa3ab0067,0x877b0341,0x957c007f,0x257100da}},	//   गढ़_, _לאמי, _prąd, _fál_,
   {{0x29062036,0xa3b8023a,0xbcfb014b,0x00000000}},	//   okoa_, _चहक_, _biél, --,
   {{0x63a92037,0x29061d77,0x60d62038,0x644e00a7}},	//   buen, nkoa_, _caym, əbin,
   {{0x63a911c4,0x5f94013d,0xb9090134,0x60d62039}},	//   cuen, ният, _aghọ_, _daym,
   {{0x290f0216,0x957c007f,0x7d1d0206,0x00000000}},	//   zhga_, _trąd, _smss, --,
   {{0x2d9e02e6,0x29060084,0xb2bb00ca,0x00000000}},	//   šten_, kkoa_, _המור, --,
   {{0x6144001f,0x00000000,0x00000000,0x00000000}},	//   _пеја, --, --, --,
   {{0xa3d50067,0xe8df00fe,0x3c5800d3,0x00000000}},	// [1670] हिए_, _chờn_, зитэ_, --,
   {{0x290601ff,0x00000000,0x00000000,0x00000000}},	//   ekoa_, --, --, --,
   {{0x63a90634,0x60d60555,0x30a60103,0x00000000}},	//   zuen, _yaym, _علیہ, --,
   {{0x25e0048a,0x5fb1034c,0xdbcc0139,0x00000000}},	//   किनी_, _जमाल, _kòìp, --,
   {{0x2571203a,0x61360072,0x333e0062,0x63a901c8}},	//   _sál_, rálx, kotx_, xuen,
   {{0x290f11bc,0xb904203b,0x8579007b,0x29060062}},	//   shga_, _भो_, осит_, akoa_,
   {{0x69da0b27,0x20020034,0x00000000,0x00000000}},	//   _štev, zyki_, --, --,
   {{0x58d4203c,0x63a90a00,0xb4d70b89,0x6b4b01bf}},	//   _пост, tuen, ाये_, zügl,
   {{0x2be00c9c,0x68e9203d,0x29070138,0x195800c6}},	//   निया, _ined, ūnas_, _хаты_,
   {{0x68fb203e,0x63a9203f,0x68e90220,0x60d62040}},	//   _houd, ruen, _hned, _saym,
   {{0x68fb2041,0x80d70081,0x60d62042,0x68e92043}},	//   _koud, ধান্, _paym, _kned,
   {{0x200200a5,0x68fb2044,0x63a9037a,0x00000000}},	//   tyki_, _joud, puen, --,
   {{0x212218c4,0x63a92045,0xe2992046,0x68fb2047}},	//   rikh_, quen, _дал_, _moud,
   {{0x67232048,0x290602a7,0xbcfb0113,0x2002007f}},	//   ninj, zkoa_, _diém, ryki_,
   {{0xdd1c025b,0x68e92049,0x644f015c,0x60d6204a}},	//   _vážn, _oned, škić, _taym,
   {{0xdb0d01bf,0x68fb204b,0x2d840094,0x68e90172}},	//   traß, _noud, ďme_, _nned,
   {{0xab66083c,0x2efa042c,0xe3b90103,0x00000000}},	// [1680] двал, _topf_, ntű_, --,
   {{0x290d204c,0x68e9204d,0x6723083e,0x68fb0090}},	//   _alea_, _aned, jinj, _aoud,
   {{0x68fb1b59,0x68e90078,0x3ebe00bc,0x6b960537}},	//   _boud, _bned, õttu_, ssyg,
   {{0xc7c6204e,0x660300a5,0x68fb00fd,0xb4d7030b}},	//   дски, dynk, _coud, ायो_,
   {{0x68fb204f,0x29062050,0x4c3601b3,0x7b0901f9}},	//   _doud, rkoa_, _цэнт, ástó,
   {{0x290601e9,0x291f0063,0x68e92051,0xdddc007f}},	//   skoa_, _emua_, _ened, karż,
   {{0x68fb020d,0x7afc01ff,0xdd1d00d4,0x00000000}},	//   _foud, _iort, lášs, --,
   {{0x25a02052,0x7afc2053,0x68fb2054,0xe81f0b94}},	//   čil_, _hort, _goud, _मेवा_,
   {{0x67232055,0x68430ff5,0x644e0034,0x248f01ee}},	//   binj, _анта, ębio, _degm_,
   {{0x672304a3,0x68fb0ab2,0x7bc60174,0x00000000}},	//   cinj, _zoud, _mpku, --,
   {{0x36060604,0xbcfb0113,0x2d9e02c6,0x66e30b36}},	//   _تواف, _diéj, átel_, _јоха,
   {{0x7afc02a7,0x249d0350,0x7bc60381,0x26170961}},	//   _lort, _gdwm_, _opku, _भेटी_,
   {{0x7afc0185,0x2d9e02df,0x00000000,0x00000000}},	//   _oort, štel_, --, --,
   {{0x7afc1c8d,0x05c202d5,0x15f21073,0x00000000}},	//   _nort, _शहाब, _अपार_, --,
   {{0xa3d60e72,0x7bc601d3,0x6455007f,0xdb0d0131}},	//   ाटक_, _apku, ęzie, ltaç,
   {{0x506708c3,0x6ca42056,0x6b500212,0xa115001c}},	//   _отпа, круж, väga, _سوخت,
   {{0xdb0d0396,0x7afc0572,0x3b550012,0x68fb2057}},	// [1690] ntaç, _bort, екар, _roud,
   {{0x68fb2047,0x291f2058,0xdb0d0161,0x68e92059}},	//   _soud, _smua_, itaç, _sned,
   {{0x68fb205a,0x7afc205b,0x8c420233,0x00000000}},	//   _poud, _dort, öğre, --,
   {{0x2d8301c0,0xe7f3007f,0x3835205c,0x67230079}},	//   mpje_, _आपदा_, ннер, winj,
   {{0x672303ce,0x69da00e9,0x68fb0257,0x31b80103}},	//   tinj, _štet, _voud, héz_,
   {{0x7afc205d,0xe73300b1,0x68fb1030,0x764800eb}},	//   _gort, خصص_, _woud, _bydy,
   {{0x67230b27,0xe81f205e,0x2367023b,0x68fb0383}},	//   rinj, _मेरा_, _rinj_, _toud,
   {{0x6723205f,0x67d52060,0x68e90150,0x7afc0a00}},	//   sinj, _побу, _uned, _zort,
   {{0x386d2061,0x77680072,0x75d300a7,0x00000000}},	//   _iger_, _fidx, _məzə, --,
   {{0xcb1200c1,0x7afc2062,0xfbd200a1,0x21200063}},	//   ָלט_, _xort, נתי_, _smih_,
   {{0x76482063,0x7d0f0018,0xe1262064,0x64da0096}},	//   _gydy, _olcs, емни, _मोकळ,
   {{0x75d301d4,0x70aa2065,0xbcfb03a9,0xe8df0023}},	//   _nəzə, कलेल, _diék, _khốn_,
   {{0xa3d5007d,0x31692066,0x2d83029a,0x13f4008f}},	//   हिओ_, _diaz_, epje_, _изця,
   {{0x2d9e005f,0x63bb2067,0x69c704e9,0x00000000}},	//   štem_, mtun, _opje, --,
   {{0x63bb2068,0x2f140222,0x2d8c2069,0xed5a0aad}},	//   ltun, _lägg_, ède_, зов_,
   {{0x7afc206a,0xc5f200c1,0x40410129,0x629c00d4}},	//   _sort, נדן_, ụmịh, órov,
   {{0x63bb113a,0x60c40193,0xe81f206b,0xa3d5206c}},	// [16a0] ntun, _ibim, _मेला_, हिट_,
   {{0x7afc206d,0x63bb206e,0x386d206f,0x2c760065}},	//   _qort, itun, _ager_, _bùdó_,
   {{0x63bb2070,0x7afc0e78,0xfbdf0023,0x39440113}},	//   htun, _vort, _uyên_, _pkms_,
   {{0x764802ad,0x7afc2071,0x61fc0ac9,0x22a60af0}},	//   _rydy, _wort, ørli, _kíkà_,
   {{0x6d462072,0x7afc0d54,0x60c42073,0xe8df0023}},	//   _ikka, _tort, _mbim, _chốn_,
   {{0x6b842074,0x386d2075,0x98c500e8,0x63bb2076}},	//   mpig, _eger_, ītās_, dtun,
   {{0x60c42077,0xceb300c1,0x63bb2078,0xdb04020d}},	//   _obim, טיג_, etun, vriè,
   {{0x63bb2079,0x75d30092,0xa3dc0b86,0x6b84024a}},	//   ftun, _xəzə, डिल_, opig,
   {{0x63bb207a,0xd4e30084,0xdb0400fd,0x00000000}},	//   gtun, ующи, triè, --,
   {{0xdb0d207b,0x0bb700ca,0x2d830052,0x6b84207c}},	//   rtaç, עלים_, ypje_, ipig,
   {{0x6d46207d,0xdb04025a,0xdb0d001f,0x95ca207e}},	//   _okka, rriè, staç, _хлеб_,
   {{0xdb0d0161,0x26ce207f,0x6d4600f9,0xdcdf034c}},	//   ptaç, lefo_, _nkka, _पोंछ,
   {{0xa3e4000d,0xdb040072,0x63bb0227,0x00000000}},	//   _पछि_, ntió, ctun, --,
   {{0x545302ec,0x6d462080,0x60c40517,0x320502c6}},	//   _світ, _akka, _ebim, byly_,
   {{0x0dc810fb,0x7c870284,0x72030103,0xac951eb9}},	//   нути_, еузе, _مووم, кавш,
   {{0x2b582081,0x2d83029a,0x60c40065,0x75d300a7}},	//   _ahrc_, rpje_, _gbim, _qəzə,
   {{0x8aa72082,0x69c72083,0xfaa70423,0x6b8406a8}},	// [16b0] еред, _spje, ешен, gpig,
   {{0x60dd2084,0x2fc912f5,0x6d460517,0x69d5007f}},	//   ldsm, _ipag_, _ekka, _psze,
   {{0xf9930678,0x63bb1f3f,0x27e40113,0x7dc40018}},	//   ابط_, ztun, _armn_, _یقین,
   {{0x60dd2085,0x2fc90270,0x2d812086,0x63bb06da}},	//   ndsm, _kpag_, _ithe_, ytun,
   {{0xb8c92087,0x69d500a5,0x60dd2088,0x9e67001c}},	//   _गए_, _wsze, idsm, _تاکن,
   {{0x6d4d2089,0x752206b0,0xd246208a,0x2f140212}},	//   llaa, _amoz, _نن_, _vägg_,
   {{0xa3b3009d,0x6d46003e,0x98c7208b,0x6d4d014a}},	//   जून_, _ykka, _псал, olaa,
   {{0x63bb208c,0x386d01c5,0x60dd052f,0x6d4d208d}},	//   ttun, _uger_, jdsm, nlaa,
   {{0x63bb0084,0x7d0300ae,0x7c290117,0xdb040231}},	//   utun, _însu, _žerj, quiã,
   {{0x613d0068,0x63bb02f4,0x7522208e,0x2d9e00b6}},	//   mély, rtun, _emoz, átek_,
   {{0x63bb208f,0x6d4d2090,0x3f80002d,0x2d8101fa}},	//   stun, klaa, _stiu_, _nthe_,
   {{0xbcfb016d,0x2d9e2091,0xdb042092,0x6d4d01cb}},	//   _fiéi, štek_, rrié, jlaa,
   {{0x889a00a1,0x2f140149,0x6d4d0188,0x2d810372}},	//   וברי, _läge_, dlaa, _athe_,
   {{0xdb04025a,0x4ed52093,0x656b2094,0x63a92095}},	//   prié, люст, _high, mren,
   {{0x63a92096,0x656b2097,0x60c4009c,0x6d4d2098}},	//   lren, _kigh, _tbim, flaa,
   {{0x6d4d2099,0x63a9209a,0x656b0174,0x657c0103}},	//   glaa, oren, _jigh, _érhe,
   {{0x656b00a1,0x2d81209b,0x26c50036,0x63a9209c}},	// [16c0] _migh, _ethe_, _oblo_, nren,
   {{0x656b209d,0x613d0018,0x6d4d209e,0x6b84209f}},	//   _ligh, dély, alaa, rpig,
   {{0x2be0007d,0x63a920a0,0x644b013f,0x656b09f7}},	//   निहा, hren, _lygi, _oigh,
   {{0x63a908a9,0x656b20a1,0xfbab17ff,0x6b842096}},	//   kren, _nigh, _चमचम, ppig,
   {{0x68430109,0x613d01f9,0x63a920a2,0x6d4420a3}},	//   анца, gély, jren, moia,
   {{0x656b02bc,0x6d4420a4,0xd09a00a7,0xdb0400ee}},	//   _aigh, loia, rçək, quià,
   {{0xdb0411ce,0x63a920a5,0x28dd0f35,0x2be009c4}},	//   stió, eren, _नोकि, निवा,
   {{0x6d4420a6,0x7d03020a,0x644b03a8,0x00000000}},	//   noia, _înst, _bygi, --,
   {{0xa76620a7,0x63a920a8,0x656b20a9,0xdb040072}},	//   _акад, gren, _digh, ltiñ,
   {{0x86ea0037,0xbcfb0072,0x14ae0096,0xd2500470}},	//   _تعرف_, _viéi, _टाकण, ینک_,
   {{0xdb0408a8,0x63a920aa,0x656b00ca,0x64c60037}},	//   ntiñ, aren, _figh, _ليال,
   {{0x94260084,0x6913026a,0x6d440131,0xdb040072}},	//   _имее, _içec, joia, itiñ,
   {{0x60dd20ab,0x6d4420ac,0x63a920ad,0x00000000}},	//   rdsm, doia, cren, --,
   {{0x656b0134,0xdb2501f9,0x00000000,0x00000000}},	//   _zigh, épül, --, --,
   {{0x7e28116d,0x6d4d20ae,0x6e941a53,0x6b5020af}},	//   віта_, tlaa, рису, rägl,
   {{0xe7f3009d,0x6d4420b0,0x1bd500e5,0x00000000}},	//   _आपला_, goia, лобя, --,
   {{0xdc550303,0x6d4d1f49,0x2d7800e7,0x69da20b1}},	// [16d0] увањ, rlaa, _učen_, _štep,
   {{0x6d4d0934,0xf1b616f8,0x2004042c,0xb05b007b}},	//   slaa, _अमान, ämie_, seäs,
   {{0x6d4d20b2,0x63a920b3,0x2d810060,0x257801f9}},	//   plaa, zren, _uthe_, _nél_,
   {{0xe0df20b4,0x7d160146,0x2be00285,0xa3d2007a}},	//   ndò_, chys, निशा, _हईं_,
   {{0x656b0054,0xfd5613b6,0x49930103,0x00000000}},	//   _righ, _תשרי_, _چیئر, --,
   {{0x656b20b5,0xe8df00fe,0x00000000,0x00000000}},	//   _sigh, _phồn_, --, --,
   {{0x99670aa8,0xdb042027,0x656b20b6,0xbcfb03a9}},	//   _атал, quiá, _pigh, _diév,
   {{0x7d0d20b7,0x693c077e,0x25780103,0x00000000}},	//   nkas, včeg, _dél_, --,
   {{0x63a920b8,0xe2990036,0x7d0d20b9,0x38351538}},	//   uren, нап_, ikas, _снар,
   {{0xe1f902fd,0x63a920ba,0x656b20bb,0x25780018}},	//   его_, rren, _wigh, _fél_,
   {{0x7d0d20bc,0xaca30065,0xaaab0557,0x25780844}},	//   kkas, _akọb, _चयनक, _gél_,
   {{0x38690580,0x64550092,0x656b20bd,0x6d440062}},	//   žaru_, əzin, _uigh, xoia,
   {{0x03a5021c,0x53a50231,0x7d0d20be,0x6d440cc0}},	//   _сило, _салб, dkas, voia,
   {{0x752920bf,0xfd6500fe,0x00000000,0x00000000}},	//   liez, _truồ, --, --,
   {{0xdca61b77,0xc0e620c0,0xdd1d00b6,0xdb040161}},	//   лави, _бойк, lářs, luiç,
   {{0x7d0d20c1,0x7e7c034f,0x752920c2,0x9f4000b3}},	//   gkas, scrp, niez, _triï_,
   {{0x0aea1689,0x6eac00a5,0x6d4420c3,0xdb040161}},	// [16e0] ндай_, _जयपु, roia, nuiç,
   {{0x7d0d0084,0x6d4420c4,0x8a3a00c2,0x945d0034}},	//   akas, soia, няет_, leńs,
   {{0x8886013d,0x6d4420c5,0x752920c6,0x7d1620c7}},	//   глеж, poia, kiez, phys,
   {{0xdb0403be,0x25aa004d,0x7aeb00e8,0xc95501b6}},	//   rtiñ, _åbli_, ēgta, атчы,
   {{0xa3d21f83,0xdb0420c8,0x6ac90081,0x257803a9}},	//   _हैं_, stiñ, রয়ো, _sél_,
   {{0xdd1d00b6,0xaa461787,0x3ce020c9,0x00000000}},	//   dářs, _бегл, ldiv_, --,
   {{0x645d0102,0xceb300a1,0xe5c61ffa,0xbcfb00d1}},	//   ýsin, ציה_, усло, _dhéf,
   {{0x75290634,0x257801cd,0x7c2920ca,0x00000000}},	//   giez, _vél_, _žeri, --,
   {{0x28dd000f,0xdb040161,0x46b60602,0x257801c0}},	//   _नोटि, guiç, _محاس, _wél_,
   {{0x394620cb,0x257820cc,0x9bbb00c1,0x2bac00b6}},	//   loos_, _tél_, עציפ, _चिना,
   {{0xaac620cd,0x80de00c7,0xd25000bf,0x7d0d2012}},	//   र्यक, যান্, تند_, ykas,
   {{0xdb04001f,0xaca30134,0x26de05bd,0x752920ce}},	//   buiç, _kwụd, _hato_, ciez,
   {{0xa3b305d4,0x26de20cf,0x7d0d20d0,0xe0df0451}},	//   जूद_, _kato_, vkas, rdò_,
   {{0x26de0131,0xaca30174,0x527600d3,0x1ee7001c}},	//   _jato_, _mwụd, _суду, دوسی_,
   {{0xc27b07a6,0x7d0d20d1,0x627b040a,0x00000000}},	//   _ארוי, tkas, _אנונ, --,
   {{0x629a20d2,0xf1a900a5,0x26de20d3,0x257100cc}},	//   lato, _कितन, _lato_, _ušle_,
   {{0x394620d4,0x00000000,0x00000000,0x00000000}},	// [16f0] doos_, --, --, --,
   {{0x212b02d6,0x7d0d20d5,0x6eb2007f,0x00000000}},	//   lich_, skas, _जाएँ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629a20d6,0x212b01b5,0x26de01ee,0x00000000}},	//   hato, nich_, _aato_, --,
   {{0x26de20d7,0xbcfb20d8,0x752920d9,0xab5b00ee}},	//   _bato_, _diét, viez, _aqüe,
   {{0x7ceb070a,0x66e520da,0x212b20db,0x945d00a5}},	//   _förä, рока, hich_, zeńs,
   {{0x212b0067,0x26de20dc,0x629a20a8,0xbcfb0042}},	//   kich_, _dato_, dato, _chég,
   {{0x212b0897,0xdb040396,0x7790010d,0x81cd0033}},	//   jich_, tuiç, _کیوا, রিম_,
   {{0x212b01f7,0x26de001f,0x80de0081,0x752920dd}},	//   dich_, _fato_, যাম্, riez,
   {{0x26de20de,0x13090084,0x032516dd,0xdb0420df}},	//   _gato_, тной_, рдон, ruiç,
   {{0x752920e0,0xcb1400a1,0xdce600e8,0xe1f6002d}},	//   piez, מלץ_, _likā, агэ_,
   {{0x212b20e1,0x95670465,0x75ca01d4,0x61461824}},	//   gich_, _създ, _qəze, рема,
   {{0x26de0af0,0x248d001f,0x5edf0081,0x2fdb0090}},	//   _yato_, mbem_, মানে, _csqg_,
   {{0x629a20e2,0x26de00b3,0xb05b0e74,0x6d5d20e3}},	//   cato, _xato_, pfän, _ahsa,
   {{0xde031f0d,0x212b022b,0x78bb03d6,0xb05b0364}},	//   опри, bich_, _ocuv, lfäl,
   {{0x212b0181,0xac8610a6,0x3946023e,0x4fea0c58}},	//   cich_, ргал, xoos_, _амин_,
   {{0x998d20e4,0x8b261ad1,0xb05b0fe8,0xbea60cba}},	// [1700] _ćeš_, адае, nfäl, _капк,
   {{0x6d5d20e5,0xfaa620e6,0xdb04007b,0x6459039f}},	//   _ehsa, ражо, htiö, _mzwi,
   {{0xa2bd00c0,0xbcfb020d,0x6b5000bc,0x693c0141}},	//   _शान्, _piét, nägi, jčec,
   {{0x629a20e7,0x26de20e8,0xfce61894,0xbcfb17dc}},	//   zato, _sato_, _томо, _diés,
   {{0x26de20e9,0x629a20ea,0x394620eb,0xbcfb0113}},	//   _pato_, yato, roos_, _dhéd,
   {{0xadc30065,0x3946023e,0x212b1786,0xb5a6166f}},	//   _atẹg, soos_, zich_, арий,
   {{0xfaa320ec,0x26de0141,0x64590027,0x80d70096}},	//   _фасо, _vato_, _azwi, _बसले,
   {{0x629a00bf,0x26de1114,0x44f4194c,0xbcfb20ed}},	//   wato, _wato_, спис, _hiér,
   {{0x26de030b,0x2fc001fa,0x629a20ee,0xaac609c4}},	//   _tato_, _nqig_, tato, र्थक,
   {{0x68e020ef,0x68e219e4,0x29040239,0x69dc007e}},	//   _hamd, ldod, _homa_, _ksre,
   {{0x290420f0,0xbcfb20f1,0x68e020f2,0x212b20f3}},	//   _koma_, _miér, _kamd, tich_,
   {{0x68e220f4,0x29040877,0x644600bc,0x61b6007f}},	//   ndod, _joma_, ükis, _अमीष,
   {{0x212b20f5,0x2f140222,0xa3dc0af1,0x68e20036}},	//   rich_, _säga_, डिओ_, idod,
   {{0x212b01b5,0x69dc0087,0x69ce20f6,0x290420f7}},	//   sich_, _osre, _opbe, _loma_,
   {{0x2d8504ee,0x4d27001f,0x709520f8,0x68e2084e}},	//   ële_, аќаа, _лайф, kdod,
   {{0x2f140006,0x2904067d,0x5c7520f9,0xfc3f002b}},	//   _väga_, _noma_, слат, _adía_,
   {{0x212902fa,0x68e202ad,0x69dc20fa,0x645c00a7}},	// [1710] _imah_, ddod, _asre, əric,
   {{0xf1da0067,0x21290113,0x4ea71e11,0x2d780117}},	//   _बनान, _hmah_, _триа, _očeh_,
   {{0x2904155e,0x257100c4,0x68e00372,0xceb2006e}},	//   _boma_, _ošla_, _bamd, _ציט_,
   {{0x290420fb,0xc879008e,0x68e00150,0xdb160018}},	//   _coma_, _başa_, _camd, rtyá,
   {{0x27e920fc,0x68e000a6,0xe0df015e,0x00000000}},	//   ían_, _damd, llòs_, --,
   {{0x629820fd,0x81cd00c7,0x7bdd0054,0xc724004d}},	//   _nevo, রিত_, _issu, одій,
   {{0x63a220fe,0xe7f30067,0x212900cd,0xdb0400c2}},	//   _avon, _आपका_, _omah_, ttiö,
   {{0xce3809c1,0x290420ff,0x25a92100,0xd5b8009f}},	//   יאות_, _goma_, čal_, _इमरज,
   {{0x629810ec,0xe7842101,0xa3d20251,0x443d0113}},	//   _bevo, _духо, हौल_, _qxw_,
   {{0xf7700080,0xc2e90068,0x62982102,0x63a20a13}},	//   _قال_, اعظم_, _cevo, _dvon,
   {{0x7c3b0102,0x395f023e,0x62982103,0xb05b2104}},	//   _þurf, _khus_, _devo, sfäl,
   {{0xa3d20ed3,0x443d023e,0x628e0088,0xc8790555}},	//   _हैक_, _txw_, ðbor, _yaşa_,
   {{0xe28e1121,0x4385054f,0xa2e52105,0x63850284}},	//   _на_, _التق, _голд, _угла,
   {{0x62981db2,0xe7fa009d,0x68e22106,0x00000000}},	//   _gevo, ्हता_, zdod, --,
   {{0x63a20d94,0x7bdd2107,0xa3b31b11,0x2c850174}},	//   _zvon, _assu, जूर_, _ụmị_,
   {{0x31a30702,0x61430ea0,0x2bac0285,0x62812108}},	//   mız_, _неща, _चिदा, lclo,
   {{0x29042109,0x68e0210a,0xed5700c9,0x3f5602b6}},	// [1720] _roma_, _ramd, сот_, læum_,
   {{0x2904210b,0x6281210c,0x394d0113,0x68e0210d}},	//   _soma_, nclo, _akes_, _samd,
   {{0x31a3210e,0x7bdd0a15,0x58860138,0x2904210f}},	//   nız_, _essu, была, _poma_,
   {{0x395f2110,0x75ca0092,0x61fc09b5,0xc879020e}},	//   _chus_, _nəza, ärli, _paşa_,
   {{0xe1e70814,0x68e22111,0x765a153c,0xc7960fe9}},	//   _کس_, rdod, _szty, ёрды,
   {{0x2904039f,0x9976004c,0xdb040143,0x612f05aa}},	//   _woma_, _гуаш, briá, _kòlè,
   {{0x63a20102,0x6d410102,0x69dc084f,0x3ce20580}},	//   _svon, élag, _usre, _kakv_,
   {{0x75ca0092,0x186a0881,0x7644026a,0x7d060eaf}},	//   _cəza, _баби_, şiyo, _joks,
   {{0x7d0601b3,0xa3b30336,0x68fd01b9,0x00000000}},	//   _moks, जूल_, _òsda, --,
   {{0x62812112,0x7d062113,0xaab3030b,0xfc3f0143}},	//   gclo, _loks, ुभएक, _odín_,
   {{0x60f92114,0x14ca0084,0x8afb0089,0x2d9e020d}},	//   ання_, _были_, אליז, âtel_,
   {{0x63a20085,0x7d062115,0x657a01b9,0xeb050285}},	//   _tvon, _noks, _iuth, _शक्त_,
   {{0x2571005f,0x62982116,0x321e0034,0x4ad80336}},	//   _ušla_, _tevo, szty_, ड़ाव,
   {{0x657a2117,0x543b00c1,0x612f05aa,0x31a3047e}},	//   _kuth, _געדא, _bòlè, bız_,
   {{0x91860dd0,0x3ce202ac,0x37be0033,0x98bd007f}},	//   _اجتم, _bakv_, _ইনফর, lową_,
   {{0x21292118,0x5d55036c,0x40350077,0x00000000}},	//   _umah_, ікат, _мейс, --,
   {{0x2d582082,0x60cd2119,0x657a211a,0xba99004d}},	// [1730] сить_, _ibam, _luth, иває_,
   {{0x3f890161,0x2dd516de,0x657a0324,0x9f53007f}},	//   _itau_, _джор, _outh, ądów_,
   {{0x395f023e,0x657a03a9,0x5edf0033,0x2d9e211b}},	//   _phus_, _nuth, মাদে, šter_,
   {{0x7644026a,0xfbd00103,0x26cc00fc,0x98bd007f}},	//   ğiyl, بتہ_, _abdo_, kową_,
   {{0x7bc4211c,0x2b931e49,0x657a0054,0x6281211d}},	//   ctiu, _ریاس, _auth, yclo,
   {{0x6b8d211e,0x31a3008b,0xdb231531,0x657a211f}},	//   mpag, yız_, örän, _buth,
   {{0x45192120,0x6b8d2121,0x7d0601e8,0x657a2122}},	//   иция_, lpag, _yoks, _cuth,
   {{0x69c52123,0x75ca0092,0xb3852124,0x657a0441}},	//   mthe, _qəza, олил, _duth,
   {{0x31d10b94,0x3f890d7d,0x4ac62125,0x69c52126}},	//   तब्ध, _ntau_, र्वव, lthe,
   {{0x657a0e7a,0x693c134c,0x60cd2127,0x69c52128}},	//   _futh, nčen, _abam, othe,
   {{0x3f892129,0x657a212a,0x69c5212b,0xc5d9212c}},	//   _atau_, _guth, nthe, _خواص_,
   {{0xe56e02ec,0x69c50a62,0x291d1df6,0x27ed212d}},	//   _із_, ithe, nhwa_, _kren_,
   {{0x31a303a3,0xb05b042c,0x505a061b,0x6283212e}},	//   sız_, nfäh, ршня_, _tfno,
   {{0x6b8d0c45,0xe3b0212f,0x69c52130,0x693c0244}},	//   dpag, _سره_, kthe, jčen,
   {{0x693c0146,0x78a92131,0xec9a1009,0x7d062132}},	//   dčen, _odev, итај_, _poks,
   {{0x27ed2133,0x2d78015c,0xa01b2134,0x60cd0065}},	//   _oren_, _očev_, rbör, _gbam,
   {{0x7d060939,0x6b8d1ba1,0xdee62135,0x8e76002d}},	// [1740] _voks, gpag, _допи, _мунч,
   {{0x78a90012,0x249f0197,0x7bc42136,0xab5b0364}},	//   _adev, haum_, rtiu, _spür,
   {{0x7bc42137,0xe9da2138,0xed5a2139,0xaac6063c}},	//   stiu, рке_, _вон_, र्षक,
   {{0x6b8d213a,0x777b008a,0x7bc415d3,0x27ed213b}},	//   bpag, _buux, ptiu, _bren_,
   {{0x2ca0213c,0x657a213d,0x27ed213e,0x3f89061d}},	//   maid_, _suth, _cren_, _xtau_,
   {{0xfdfe1349,0x6d56213f,0x657a2140,0x69c50d87}},	//   _उपास_, llya, _puth, bthe,
   {{0x27ed2141,0xd5b000e3,0x657a2142,0x69c52143}},	//   _eren_, رفة_, _quth, cthe,
   {{0x291d2144,0x4ac600a5,0x2ca02145,0x98bd0034}},	//   chwa_, र्रव, naid_, tową_,
   {{0x27ed2146,0xdddc01ac,0x2be00096,0x777b008c}},	//   _gren_, jbrž, निटा, _guux,
   {{0xbcfb00e3,0xdb0d0072,0x98bd007f,0x28c8023a}},	//   _mhéa, traé, rową_, रभवि,
   {{0x3f8900d3,0xdcfc0138,0x2ca000aa,0x249f0696}},	//   _stau_, sprę, kaid_, baum_,
   {{0x645c0253,0x2ca0007a,0x249f0231,0x00000000}},	//   ərin, jaid_, caum_, --,
   {{0xb4d617ff,0xc05b01ce,0xb4b60f73,0xdb040161}},	//   ाजी_, рін_, जली_, criç,
   {{0xa3d704dd,0xf6510068,0xc4440504,0x764d013c}},	//   ाबर_, _آئے_, _ویژن_, şaye,
   {{0x6b8d2147,0x69c501ec,0xf1c300b6,0x693c0fee}},	//   wpag, xthe, _vaší_, včen,
   {{0xbcfb00e3,0x2ca02148,0x81cd0033,0x60cd2149}},	//   _bhéa, gaid_, রিশ_, _ubam,
   {{0xbcfb0080,0x0ca8008f,0x7c3b0995,0x693c02c6}},	// [1750] _chéa, ютри_, _žurb, tčen,
   {{0xbcfb054f,0x6b8d214a,0x81cd0081,0x249f214b}},	//   _dhéa, rpag, রির_, zaum_,
   {{0xa2bd10e9,0x291d0060,0x13d30081,0x6b8d214c}},	//   _शास्, thwa_, ়িয়, spag,
   {{0xa2ca1efb,0xbcfb0080,0x2ca0214d,0x69c5214e}},	//   त्त्, _fhéa, caid_, rthe,
   {{0x6cfa00ca,0xbcfb0076,0x693c1206,0x00000000}},	//   _הפרס, _ghéa, pčen, --,
   {{0x291d214f,0x69c52150,0x65620169,0xb05b042c}},	//   shwa_, pthe, _ahoh, rfäh,
   {{0x6ecd000c,0xb05b0364,0x249f0131,0xa8a70cc6}},	//   द्यु, sfäh, taum_, _мрак,
   {{0x27ed2151,0xd4d902ec,0x6562009c,0xdb042152}},	//   _tren_, ські_, _choh, triç,
   {{0x27ed2153,0x249f0e78,0xe3b10037,0x66180a39}},	//   _uren_, raum_, ررة_, _čakš,
   {{0x249f01fa,0xdb040231,0x00000000,0x00000000}},	//   saum_, rriç, --, --,
   {{0xdb0d0fb6,0x6562009c,0x0676006e,0x00000000}},	//   ntañ, _fhoh, _זײער_, --,
   {{0xdb0d1044,0x24840072,0xfbac0442,0x00000000}},	//   kraï, ccmm_, _चिलम, --,
   {{0x2ca00006,0x656900f2,0x205600ba,0x645d00bc}},	//   vaid_, mmeh, ятор, üsid,
   {{0x65620063,0x65692154,0xd3430103,0x00000000}},	//   _zhoh, lmeh, _تفتی, --,
   {{0xdb0d0257,0x551f0640,0xbcfb0037,0x12fa00ca}},	//   traî, _बताए_, _shéa, _להסב,
   {{0xec7a2155,0x753b028d,0x65691537,0x3b860e18}},	//   спа_, nnuz, nmeh, злаг,
   {{0x1d072156,0x6d560270,0x25dd0034,0x2ca02157}},	// [1760] чети_, rlya, _कैसी_, raid_,
   {{0x2ca02158,0x6b500149,0x63a62159,0x7c3b215a}},	//   said_, vägs, ákni, _žurc,
   {{0x2ca0215b,0x6d5600f9,0x49ca153d,0x8e7b00ca}},	//   paid_, plya, слен_, _לניה,
   {{0xbcfb00e3,0x00000000,0x00000000,0x00000000}},	//   _théa, --, --, --,
   {{0xdb04057a,0x24c30033,0x80ce0961,0x00000000}},	//   nsië, ্যাহ, ध्ये, --,
   {{0x656200dd,0x45d4215c,0xa9a6215d,0xdbc700aa}},	//   _shoh, докс, _нигд, tööt,
   {{0xc1da000f,0xdb040149,0x7c2400d3,0x9f400313}},	//   _बनेग, rriä, lzir, _asië_,
   {{0xdce4215e,0x48e3215f,0xb4d61006,0x7d042160}},	//   kmič, _посв, ाजे_, njis,
   {{0xd9430318,0x7c242161,0xa2bd1376,0x00000000}},	//   _чети, nzir, _शाश्, --,
   {{0x645c01d4,0xdce41efa,0x98bd0034,0xdb0d003e}},	//   əril, dmič, dowę_, ntað,
   {{0x65622162,0x867501b3,0x00000000,0x00000000}},	//   _thoh, _жыцц, --, --,
   {{0x2d5701e8,0x78a20a4b,0x3a3700ca,0x7aeb00e8}},	//   rçek_, naov, לרים_, ēgti,
   {{0x50640831,0x75ca0092,0x2d7805db,0xdb0d01cd}},	//   етра, _məzm, _očes_, ktað,
   {{0x7c242163,0x70770260,0x69c10120,0x941e0342}},	//   dzir, _کاغذ, _åleg, ığıy,
   {{0x78a208ac,0x97570796,0x9f4402c6,0xbcfb2164}},	//   kaov, פילו_, ímá_, _dhén,
   {{0xd23b004f,0x7d0401e5,0x91bb00d7,0x9ce400ae}},	//   _לגול, gjis, _המהי, нцул,
   {{0x2b5102ef,0x6f010103,0xdb0d016d,0x00000000}},	// [1770] _pkzc_, ölcs, nuaç, --,
   {{0x501c00ca,0x44242165,0xdb0d00ee,0x00000000}},	//   _לוחו, izm_, rraï, --,
   {{0xceb207a6,0xdb040257,0x99d902a3,0x89d90281}},	//   _ביי_, isiè, تواء_, توار_,
   {{0x7c2409ac,0xa3ac0096,0xb4d600a3,0xdb0d0076}},	//   bzir, गळा_, ाजो_, mraí,
   {{0xdb0d0c1b,0xc6152166,0x66e52167,0xa8780037}},	//   stañ, तन्य_, дола, أحمر_,
   {{0x8ae402ec,0x3ea32168,0xdb0d0161,0x3ce900aa}},	//   _післ, najt_, duaç, ldav_,
   {{0xdb0d0037,0x65692169,0x2d860357,0x2d781e4d}},	//   nraí, tmeh, _čoek_, _hčer_,
   {{0xfdf800a1,0x7ae7216a,0xa2ca0b76,0x3ce900aa}},	//   לצות_, _hajt, त्स्, ndav_,
   {{0x04770068,0x7ae70087,0x6569216b,0xdb0d216c}},	//   _ہلاک_, _kajt, rmeh, hraí,
   {{0x394f00d9,0x6569216d,0xdb16037a,0x00000000}},	//   logs_, smeh, tuyé, --,
   {{0x7ae7216e,0x645c0092,0x7d1d216f,0x7c240451}},	//   _majt, ərim, _olss, zzir,
   {{0xcea9004f,0x7ae72170,0x8fa6085f,0x6fb2009f}},	//   _כי_, _lajt, маме, _जिदं,
   {{0xd9aa0179,0xbcfb0257,0xe7f02171,0xb4e92172}},	//   _चट्ट, _phén, चिया_, मयी_,
   {{0x69d50126,0xdce40aa0,0xdb040313,0xdb16014b}},	//   _opze, rmič, rsië, puyé,
   {{0xdb0d0080,0xc10600e3,0x63bb2173,0xdce42174}},	//   graí, _يوتي, luun, smič,
   {{0x7c2401e9,0x2f1400bc,0x7c3b2175,0x00000000}},	//   tzir, _mägi_, _žura, --,
   {{0x3ce60038,0x7d042176,0x63bb2177,0x7d1600d4}},	// [1780] ľov_, rjis, nuun, rkys,
   {{0x3ce60220,0xd9101ac9,0x7d162178,0x7ae70141}},	//   žov_, گیر_, skys, _cajt,
   {{0x3ce912ba,0x7ae72179,0x6e460d86,0x78a213ea}},	//   bdav_, _dajt, _ценз, taov,
   {{0xdb0d0088,0x3cf90072,0x693c0031,0x63bb217a}},	//   stað, _gnsv_, mček, kuun,
   {{0x98a307df,0x87da16c4,0xdb0400e3,0x97da0e5a}},	//   тиче, تباس_, iriú, تظار_,
   {{0x63bb008a,0x758a004d,0x66e30284,0x00000000}},	//   duun, осив_, воља, --,
   {{0x60c408a9,0x693c0031,0x16150285,0x6b84026d}},	//   _ocim, nček, तनगर_, lqig,
   {{0xdb0d0396,0x7ae71def,0x63bb217b,0x38ca0103}},	//   tuaç, _zajt, fuun, _گاڑی_,
   {{0x7ae7023e,0x693c02c6,0x63bb1f9e,0x33740b36}},	//   _yajt, yčej, guun, нгир,
   {{0x60c40396,0x764d07d1,0x59d21784,0x78a00212}},	//   _acim, şaya, _सहार, _hemv,
   {{0xe135217c,0xdb04217d,0x81d60033,0x26dc0036}},	//   енны, friú, সিভ_, mevo_,
   {{0x26dc217e,0xdb0400fd,0x92be0081,0x63bb1f9a}},	//   levo_, ssiè, ঁজে_, buun,
   {{0x78a0171d,0xc1780138,0xdb0d016d,0x3f80044c}},	//   _memv, tvės_, quaç, _cuiu_,
   {{0xdef80450,0xdb0d217f,0x26dc028d,0x78a02180}},	//   мыс_, traí, nevo_, _lemv,
   {{0x7ae70018,0x3ea32181,0x7d1d00f9,0xdb040037}},	//   _rajt, rajt_, _plss, briú,
   {{0x7ae72182,0xa2ca2183,0x3ea32184,0x78a02185}},	//   _sajt, त्र्, sajt_, _nemv,
   {{0x7ae72186,0x60dd084e,0xc1790138,0x3f6700c2}},	// [1790] _pajt, mesm, svės_, _отоб,
   {{0x60dd2187,0x26dc2188,0xbcfb0257,0xc87900d3}},	//   lesm, jevo_, _théo, _iaşi_,
   {{0x7ae72189,0x26dc218a,0x7ac4008f,0x63bb0174}},	//   _vajt, devo_, ъсте, zuun,
   {{0x25f4218b,0x60dd218c,0x2561003e,0xbb1b044c}},	//   ्मनी_, nesm, kóla_, _atît,
   {{0x63bb008a,0x7ae7218d,0x06e80033,0x394f218e}},	//   xuun, _tajt, পানি, rogs_,
   {{0x2b000557,0x7c200233,0x00000000,0x00000000}},	//   राणु_, _ümra, --, --,
   {{0x60dd218f,0x9f40009c,0x6aa52190,0x2d812191}},	//   kesm, _criù_, mahf, _juhe_,
   {{0x63bb2192,0x3ea12193,0xfba3218b,0x6aa50063}},	//   tuun, _leht_, _ओबाम, lahf,
   {{0x2fc9023e,0x2d8500b6,0xf77802a1,0x36d50f21}},	//   _nqag_, ílej_, _fiħ_, _поар,
   {{0x291f022e,0x26dc00e5,0x60c42194,0xa2052195}},	//   _hlua_, cevo_, _scim, епод,
   {{0x68e918c4,0x68fb2196,0x63bb2197,0x00000000}},	//   _kaed, _knud, suun, --,
   {{0xaacf1efb,0x4acf05a5,0x9f490065,0x628a2198}},	//   स्तक, स्तव, _araà_, _effo,
   {{0x7c3b2199,0x653a00c1,0x63bb026d,0xbcfb0031}},	//   _žurn, _צענד, quun, _chém,
   {{0x63a9219a,0xbcfb03a9,0xfd1f0036,0x2d811ee5}},	//   msen, _dhém, _alì_, _buhe_,
   {{0x63a917d2,0x5239006e,0x60dd219b,0x6fb20096}},	//   lsen, _מײַנ, besm, _जिवं,
   {{0xfce3014d,0x693c0181,0x2d81219c,0xe8e00174}},	//   лосо, rček, _duhe_, raịt_,
   {{0x63a90d63,0x6b4b0103,0xab66219d,0x78a001cb}},	// [17a0] nsen, lügy, евал, _remv,
   {{0x3ea102dc,0x63a9219e,0x68fb219f,0x291f0062}},	//   _geht_, isen, _anud, _alua_,
   {{0x81cd0081,0x26dc21a0,0x291f0113,0x2571007e}},	//   রিক_, vevo_, _blua_, _ešli_,
   {{0xc7c621a1,0x63a921a2,0x80de0081,0x291f00b3}},	//   ески, ksen, যাক্, _clua_,
   {{0x26dc21a3,0xb05b0212,0x63a921a4,0x64590a4b}},	//   tevo_, lfär, jsen, _nywi,
   {{0x63a913cd,0x290d0154,0x36d40d9b,0x60dd21a5}},	//   dsen, _eoea_, токр, zesm,
   {{0xd91014df,0x26dc077e,0x68e908d3,0x78a00087}},	//   _پیش_, revo_, _faed, _temv,
   {{0x628a00e7,0xd90d05bc,0x26dc02ef,0x44f40215}},	//   _sffo, _ویل_, sevo_, тпис,
   {{0x645921a6,0x26dc00e5,0x63a921a7,0x00000000}},	//   _cywi, pevo_, gsen, --,
   {{0x212014f7,0x6d1c030b,0x290d024a,0x9f40009c}},	//   _alih_, नसँग_, _zoea_, _triù_,
   {{0x225801c5,0x75d30190,0x63a921a8,0x7d0b02c3}},	//   ærk_, _ميلا, asen, ögsk,
   {{0x2d8121a9,0x3ea1042c,0x64590178,0xb05b02c3}},	//   _ruhe_, _seht_, _fywi, dfär,
   {{0x60dd21aa,0x2d8121ab,0x64590150,0xc879020a}},	//   resm, _suhe_, _gywi, _paşi_,
   {{0xb05b09b5,0x60dd21ac,0x2d8100ce,0x00000000}},	//   ffär, sesm, _puhe_, --,
   {{0xa01b0018,0x2ca20154,0x1df8163d,0x777a0634}},	//   nböz, _bekd_, неры_, _mitx,
   {{0x81cd00c7,0xbcfb0257,0x2120033b,0x2d8c065b}},	//   রিখ_, _thém, _glih_, ídea_,
   {{0x7ff70037,0x80de0033,0x2d810027,0x5c7500e5}},	// [17b0] _أسعا, যাখ্, _wuhe_, тлат,
   {{0x68fb21ad,0x79a713a2,0x291f0076,0x21200995}},	//   _snud, ерде, _slua_, _zlih_,
   {{0xc33300a1,0xaca30294,0x291f01fa,0x290d07ac}},	//   נוע_, _amụb, _plua_, _poea_,
   {{0x9f5205aa,0x777a0062,0x75ca013c,0x61fe014b}},	//   _aryè_, _aitx, _gəzi, _àplu,
   {{0x672300dd,0x25710106,0x777a0a00,0x7afc009c}},	//   thnj, _ušli_, _bitx, _fnrt,
   {{0x45d50e3a,0x6126003e,0x63a913ea,0x7bcd21ae}},	//   вцит, _gólf, vsen, mtau,
   {{0x7d0f0103,0xb8950037,0x66180031,0x777a01c8}},	//   _kocs, _للأع, _čaká, _ditx,
   {{0x63a921af,0x6723023b,0x68fb00a7,0x7d0f21b0}},	//   tsen, shnj, _unud, _jocs,
   {{0x777a21b1,0x25a00106,0xab5b00ee,0x2d570052}},	//   _fitx, ćila_, _aqüi, lçes_,
   {{0x765a00dd,0x777a0634,0x00000000,0x00000000}},	//   _fyty, _gitx, --, --,
   {{0x63a921b2,0x7bcd00c2,0x64590034,0x6fa400aa}},	//   ssen, htau, _wywi, _कबहू,
   {{0x63a91538,0xbcfb01dc,0xa2bd0835,0x7bcd02db}},	//   psen, _dhék, _शाक्, ktau,
   {{0xa3e51000,0x61e10150,0xab5b0231,0x74290076}},	//   _पनि_, swll, _eqüi, _تكشف_,
   {{0x81bc01d3,0xb464004d,0x539a00ca,0xdb2400f3}},	//   izēj, _скіл, _חיסו, _åsøk,
   {{0x7d0f21b3,0xed5a21b4,0x2d9e21b5,0xdca603d9}},	//   _bocs, дов_, ète_, кави,
   {{0xed4321b6,0xb05b09b5,0x693c0128,0x316900bd}},	//   ансп, rfär, lčev, _ghaz_,
   {{0x75ca01d4,0xed570303,0x7d0f01b9,0x7bcd21b7}},	// [17c0] _vəzi, тот_, _docs, gtau,
   {{0x693c21b8,0x81bc00d9,0x387f01e9,0x27f80117}},	//   nčev, dzēj, _agur_, _črn_,
   {{0x18a621b9,0x7d0f21ba,0xb05b09ab,0x99f5004d}},	//   ваем, _focs, ngän, ляці,
   {{0x672121bb,0xdcfe21bc,0xe995001c,0x00000000}},	//   _allj, _kupč, اهنگ, --,
   {{0x2ba908d4,0x765a00c2,0x693c007e,0xc0ad006e}},	//   _चौपा, _syty, kčev, ליאָ,
   {{0xcf9300c1,0x387f01c8,0x80de0033,0xdcef044c}},	//   סטו_, _egur_, যাট্, _tică,
   {{0x644e0092,0x19b900c2,0xdb0403be,0xe9a30291}},	//   əbiy, _путь_, quiñ, _васп,
   {{0x291c01d3,0xaa4321bd,0x765a00d4,0x254500e8}},	//   īvas_, _тесл, _vyty, tēla_,
   {{0xf36621be,0x765a007f,0x00000000,0x00000000}},	//   ктон, _wyty, --, --,
   {{0x518621bf,0xd76400cd,0x764d0103,0x81d60033}},	//   кума, _صنای, ényé, সিস_,
   {{0x69130b88,0xaad40976,0x6d4614f3,0x54c600ae}},	//   _içer, ठ्यक, _ojka, _абеб,
   {{0x7bcd0138,0x00000000,0x00000000,0x00000000}},	//   ytau, --, --, --,
   {{0x69c402d5,0xc058004d,0x7d0f078e,0x693c0141}},	//   ांडी, вір_, _rocs, bčev,
   {{0x82330260,0x7f941b9d,0xdb23026a,0x81cd0033}},	//   اریا, рарх, örün, রিজ_,
   {{0x5faf007d,0xd37b0266,0x752221c0,0x00000000}},	//   _झटकल, _קרוט, _kloz, --,
   {{0x7bcd21c1,0xaac60d61,0xdb21026a,0x00000000}},	//   ttau, र्घक, ştür, --,
   {{0x2d5802fd,0x8aa70950,0x213921c2,0x75220350}},	// [17d0] тить_, вред, mish_, _mloz,
   {{0xd5a407d9,0x7bcd21c3,0xdd1100d9,0xbcfb0037}},	//   _وہ_, rtau, _kļūd, _mhéi,
   {{0x7bcd21c4,0x9f4901e8,0xdcfe00cb,0x7d0f21c5}},	//   stau, _araç_, _zupč, _tocs,
   {{0xb7d50032,0x213900ca,0x9f49015e,0x7bcd21c6}},	//   _aṣaw, nish_, _braç_, ptau,
   {{0x2ca921c7,0x75ca00a7,0x00000000,0x00000000}},	//   maad_, _məzu, --, --,
   {{0x2ca9008a,0xd2460190,0x7522010a,0x3669079c}},	//   laad_, _هن_, _aloz, нало_,
   {{0xa49309b4,0x44290220,0x693c0128,0x752216ce}},	//   لیات, _ťa_, včev, _bloz,
   {{0x13e9004c,0xdb0d016d,0x29f30095,0x752221c8}},	//   емий_, fraç, _ića_, _cloz,
   {{0xbcfb0080,0xdb0d001f,0x291d21c9,0xef1f00a7}},	//   _chéi, graç, mkwa_, vqün_,
   {{0x213900f9,0x20191a61,0x2ca9008c,0x693c03f1}},	//   eish_, dysi_, haad_, učev,
   {{0xc6920130,0xa0a6090f,0x693c0660,0xbbd0030b}},	//   _האב_, ланд, rčev, _सङ्क,
   {{0xbcfb00e3,0xa2d30789,0xdb0d0161,0xb05b0364}},	//   _fhéi, _बॉर्, braç, rgän,
   {{0x2ca9008a,0xf5390031,0xb4df0caf,0x693c0141}},	//   daad_, miť_, दजी_, pčev,
   {{0x248d21ca,0xf5390181,0x752221cb,0x2d8c0956}},	//   lcem_, liť_, _zloz, ídeo_,
   {{0x63bb00d9,0x2f140212,0x2ca9008c,0xa30a0103}},	//   lrun, _sägs_, faad_, _سروے_,
   {{0xf5390181,0x248d200b,0x67380dd9,0x693c0d94}},	//   niť_, ncem_, zivj, nčet,
   {{0xb7be00c7,0xa2ca0285,0x2d9301e9,0x61260165}},	// [17e0] _ইন্ট, त्क्, _etxe_, _cóle,
   {{0x81d60081,0x5eae0033,0xaca40065,0x291d21cc}},	//   সির_, ঞ্জে, _ikọs, ekwa_,
   {{0x63bb02dc,0x2ca9008a,0x248f0072,0x09f60fe9}},	//   hrun, baad_, _ofgm_, ычая,
   {{0xf5390220,0xb95a0037,0x2ca90188,0x63a40555}},	//   jiť_, رجاء_, caad_, _çing,
   {{0xf5390181,0x6d4421cd,0xb8dc0efd,0x645d00aa}},	//   diť_, mnia, _आय_, üsil,
   {{0x6d4416df,0x6d5601ee,0x63bb21ce,0x21390052}},	//   lnia, loya, drun, zish_,
   {{0x63bb02e2,0x25a008a9,0x6ed60789,0x6d4400bc}},	//   erun, ćilo_, म्यु, onia,
   {{0x6d4421cf,0xdb0d0161,0x7aee1b2b,0x3eaa01bf}},	//   nnia, traç, _habt, habt_,
   {{0x63bb21d0,0xd90d0068,0x6d4421d1,0x7aee21d2}},	//   grun, _تین_, inia, _kabt,
   {{0x6d5621d3,0x7c3b21d4,0x6d4408d3,0xdb0d0161}},	//   hoya, _žurk, hnia, rraç,
   {{0xf5390181,0x6d561cd8,0x2ca9008a,0x2d9821d5}},	//   biť_, koya, yaad_, jpre_,
   {{0x6d44006c,0x2ca90694,0x7aee21d6,0x46130d5b}},	//   jnia, xaad_, _labt, _دومر,
   {{0x21391bc8,0x6d4421d7,0x63bb21d8,0x2937006e}},	//   rish_, dnia, crun, ראכן_,
   {{0x69dc21d9,0x7aee01fa,0x2ca9008a,0x6d4421da}},	//   _opre, _nabt, waad_, enia,
   {{0x693c21db,0x6d440150,0x65600037,0x2d8500fd}},	//   nčes, fnia, olmh, êle_,
   {{0x6d5621dc,0x63a221dd,0x5c07008f,0x6ed600b6}},	//   goya, _kwon, ляза, म्बु,
   {{0x2ca918a7,0x69ce0078,0x9f40037a,0x81c60033}},	// [17f0] raad_, _aqbe, _crió_, _উনি_,
   {{0x61f80995,0xf5390038,0x63a221de,0x2ca921df}},	//   _krvl, ziť_, _mwon, saad_,
   {{0x6d4421e0,0x7aee0197,0x69dc21e1,0x6d5621e2}},	//   bnia, _dabt, _cpre, boya,
   {{0x57f50b21,0x2ba9121d,0x9f40037a,0x6d440034}},	//   ипет, _चौथा, _frió_, cnia,
   {{0x69dc21e3,0xf5390038,0x6b860113,0x7d0d21e4}},	//   _epre, viť_, _gukg, mjas,
   {{0x7d0d21e5,0xc5f900c7,0xbcfb1ba6,0xf7960037}},	//   ljas, _অথবা_, _chév, جنوب_,
   {{0xf5390181,0x2ba9000d,0x7c2d21e6,0x63a221e7}},	//   tiť_, _चौता, lzar, _awon,
   {{0xdb0421e8,0x63a221e9,0x7d0d21ea,0x7aee03e3}},	//   brió, _bwon, njas, _zabt,
   {{0x7c2d21eb,0xf5390181,0xf57600e3,0x693c007e}},	//   nzar, riť_, جميع_, rčet,
   {{0xadf716e2,0x63bb21ec,0x6d4421ed,0xc6a40396}},	//   ुमान_, rrun, znia, _грци,
   {{0x6d4402ad,0xf5390181,0x248d21ee,0x6d5621ef}},	//   ynia, piť_, pcem_, yoya,
   {{0x63bb21f0,0x61f8015c,0x81d60081,0x25f202d5}},	//   prun, _drvl, সিং_, ंटरी_,
   {{0xe28e03fc,0x53a50290,0x6d4421f1,0x6d5621f2}},	//   _ма_, _талб, vnia, voya,
   {{0x6d4421cd,0x26c721f3,0x823500cd,0x0876006e}},	//   wnia, ngno_, _پرتا, יערט_,
   {{0xada621f4,0x7aee21f5,0x442d21f6,0x7bdd21f7}},	//   рабл, _rabt, lze_, _apsu,
   {{0x7aee21f8,0x06af0081,0xef86185c,0x7d0d21f9}},	//   _sabt, চ্চি, _клип, gjas,

   {{0x69dc21fa,0x2d9821fb,0x6d4421fc,0xafe621fd}},	// [1800] _spre, spre_, rnia, _топл,
   {{0x7aee0694,0x2561003e,0x6aa700e7,0x442d21fe}},	//   _qabt, fólk_, _cejf, ize_,
   {{0x09e60423,0x6d5621ff,0x2d8500b6,0xfc3f0487}},	//   роен, poya, ílet_, _veía_,
   {{0x442d06c2,0xdb0406cb,0x29002200,0xe3a704f4}},	//   kze_, trió, ñia_, _ور_,
   {{0x7aee2201,0x442d2202,0x06af0081,0x7c2d0034}},	//   _tabt, jze_, চ্ছি, czar,
   {{0x442d2203,0x6996004d,0x63a205bd,0xdb04167e}},	//   dze_, _врах, _rwon, rrió,
   {{0xe1e72204,0x69dc0220,0x6136015c,0x693c00e7}},	//   _بس_, _upre, ršlj, učes,
   {{0x7c3b08a9,0x62832205,0x75292206,0xa96a02d8}},	//   _žuri, _agno, ghez, _риба_,
   {{0x39460fb6,0x4306004d,0x00000000,0x00000000}},	//   mnos_, аїна, --, --,
   {{0xfd4a199b,0xdb040072,0x39462207,0xf3660da5}},	//   talọ, oriñ, lnos_, јтин,
   {{0x79802208,0x442d0172,0x7c2d0a5f,0xd48f0c3f}},	//   _kimw, aze_, zzar, _мр_,
   {{0x7529068d,0x39462209,0x63a2220a,0x628300bd}},	//   chez, nnos_, _twon, _egno,
   {{0x442d0d1b,0x63a2220b,0x3946220c,0x50670c2b}},	//   cze_, _uwon, inos_, ртна,
   {{0xdced025b,0x6d48220d,0x394600f0,0x63bd1515}},	//   rmač, édan, hnos_, ásne,
   {{0xa69700a1,0xeca707c8,0x28d7220e,0x62330131}},	//   שכלה_, ијан, ण्डि, _мешу,
   {{0x7c2d220f,0x80c1009d,0x39460018,0xc27b00c1}},	//   tzar, _वाटे, jnos_, _ברוי,
   {{0x29e8002d,0x67da01d3,0x7bc42210,0x957c007f}},	// [1810] _aşa_, nājā, guiu, _brąz,
   {{0x7d0d2211,0x39462212,0xa91d00c4,0x6aa70052}},	//   sjas, enos_, _miže, _qejf,
   {{0x442d2213,0x7c2d2214,0x79800193,0xdb042215}},	//   zze_, szar, _bimw, griñ,
   {{0x39462216,0x645d00aa,0x442d2217,0x798003a8}},	//   gnos_, üsik, yze_, _cimw,
   {{0x61260088,0x6d5d0a69,0xa91d00cb,0x7980022b}},	//   _jóla, _iksa, _niže, _dimw,
   {{0x66e51787,0x39462218,0x6d5d0124,0xdb040042}},	//   сока, anos_, _hksa, briñ,
   {{0x7afa003e,0xa3a91cff,0x2d68042c,0x3f89078e}},	//   _ótta, गीन_, ißen_, _luau_,
   {{0x442d2219,0x7ae50fc4,0x69c5221a,0x22490234}},	//   tze_, leht, muhe, _ćak_,
   {{0x3d08007d,0xc95209c1,0x442d221b,0xf79401b3}},	//   हाते_, _זמן_, uze_, _матэ,
   {{0x442d08fa,0x78a9221c,0x27ed0407,0x798002a4}},	//   rze_, _heev, _isen_, _zimw,
   {{0x442d221d,0x75290060,0x568c00c1,0x78a900bc}},	//   sze_, phez, _סטאַ, _keev,
   {{0x2d6802e2,0xf09f0649,0x6126221e,0x7ae5023b}},	//   eßen_, gbà_, _bóla, heht,
   {{0x249f0131,0x78a9221f,0x3f810027,0x69c52220}},	//   mbum_, _meev, _bihu_, huhe,
   {{0x6d5d2221,0x539a0054,0x249f2222,0x612614b3}},	//   _aksa, _עיצו, lbum_, _dóla,
   {{0xe16400cd,0x394600c6,0x853c00c6,0xfbdf0131}},	//   _وضعی, ynos_, _kvėp, _apê_,
   {{0x2ba9000f,0x4c862223,0x61362224,0x61fc056b}},	//   _चौहा, слав, kšli, ærle,
   {{0x79800193,0xf38800de,0xdb0420df,0x394602ef}},	// [1820] _rimw, _lợn_, nsiç, vnos_,
   {{0x6ac600e3,0x6d5d2225,0xdb042226,0xf1db1e93}},	//   إقام, _eksa, isiç, _बहान,
   {{0x1efb00c1,0x27ed05aa,0x78a92227,0x69c52228}},	//   _עלטע, _asen_, _beev, guhe,
   {{0x78a9022e,0xdb042229,0x1d0a222a,0x984a061b}},	//   _ceev, rriñ, _семи_, ляла_,
   {{0x3946222b,0xaab809b4,0x7bc4222c,0x2ca000bc}},	//   rnos_, _نگار_, quiu, mbid_,
   {{0x3946222d,0x96f8002d,0xe9aa001c,0x254c00b6}},	//   snos_, рект_, _مدرن_, děla_,
   {{0x2d82222e,0x78a9222f,0x29e8020a,0xa91d00e8}},	//   _kike_, _feev, _uşa_, _siže,
   {{0xf8b000cd,0x77860084,0x2ca00313,0x2d822230}},	//   _آکا_, _глаз, nbid_, _jike_,
   {{0x4acf2231,0x2d8200ca,0xccf30327,0x44220103}},	//   स्कव, _mike_, לכה_, ák_,
   {{0x2d822232,0xaaa80569,0x78a9029a,0x60cd2233}},	//   _like_, गरिक, _zeev, _scam,
   {{0xd5b902ec,0x712700e3,0x23a9009f,0xe7f0086d}},	//   _всі_, مرحل, चीबद, चिका_,
   {{0x59c92234,0x81bc0029,0xc5f300a1,0x78a901fa}},	//   ांतर, dzēt, _מדע_, _xeev,
   {{0xa2d32235,0xd8d7006e,0xf09f00ee,0x00000000}},	//   _बॉक्, זוכט_, rbà_, --,
   {{0x437400bf,0x4ac70789,0x2d820d2a,0x2d680364}},	//   _بهتر, _लाइव, _aike_, ußen_,
   {{0xd0470092,0xe18900de,0x2d8206dc,0xddc500d2}},	//   _əməl, _hẳn_, _bike_, _vzhů,
   {{0x2d820044,0xbcfb0139,0x60cd063d,0x00000000}},	//   _cike_, _ahér, _ucam, --,
   {{0x2d822236,0x78a92237,0xe509009f,0x7ae52238}},	// [1830] _dike_, _reev, वाति_, teht,
   {{0x9a8705b6,0xbcfb2239,0x2d82223a,0x78a9223b}},	//   суал, _chér, _eike_, _seev,
   {{0x78a901fa,0x2ba90251,0xd91b1e20,0x81d60081}},	//   _peev, _चौरा, льд_, সিক_,
   {{0x69c5223c,0x248601c2,0x5c07223d,0xf3880023}},	//   ruhe, _ngom_, _ляга, _rợn_,
   {{0xf771223e,0x21291a3a,0x78a9223f,0xb8820031}},	//   وات_, _mlah_, _veev, _šíri,
   {{0xb6a52240,0x69c500c2,0x25a500f0,0x21292241}},	//   цикл, puhe, _pwll_, _llah_,
   {{0x21290496,0x78a92242,0xf5920cc8,0x69c50052}},	//   _olah_, _teev, ولوج, quhe,
   {{0x58d412e7,0x254c00b6,0xe3b905cb,0x321e0034}},	//   _ност, těla_, аби_, dyty_,
   {{0x981700bf,0x395f0a00,0x27ed2243,0x00000000}},	//   _ابزا, _ikus_, _usen_, --,
   {{0xdb160084,0xaacc00b6,0x15ab00e5,0xf38800fe}},	//   styö, ालयक, _бъди_, _tợn_,
   {{0x9f4901bf,0x81bc01d3,0x21290133,0x00000000}},	//   _spaß_, dzēs, _blah_, --,
   {{0x6f0500fe,0x2cab039f,0x00000000,0x00000000}},	//   _anhc, _necd_, --, --,
   {{0x2d822244,0x28d10469,0x394d2245,0xd24e001c}},	//   _rike_, _हानि, _mjes_, فنی_,
   {{0xe2992246,0x321e2247,0x21290167,0xd5dd136b}},	//   _так_, byty_, _elah_, _महाज,
   {{0x395f2248,0xad3a004d,0x2ca0033c,0x8e832249}},	//   _okus_, ачає_, tbid_, дгре,
   {{0xc5f200ca,0x4d66224a,0x2cab0503,0x644a0234}},	//   ודל_, ікав, _cecd_, šmiš,
   {{0x6f17224b,0x25a008c5,0x2ca008aa,0xcb050034}},	// [1840] _foxc, ćili_, rbid_, रांड_,
   {{0x5ec10081,0x98a600c4,0x395f058f,0x00000000}},	//   শ্বে, rhoč_, _akus_, --,
   {{0xa3a90b7f,0x80b100a5,0x2d82224c,0x7f5c00fd}},	//   गीत_, _अजमे, _tike_, morq,
   {{0x6d4100fd,0x7f5c0036,0xdd0f0233,0x61fc224d}},	//   élat, lorq, mışs, årli,
   {{0x394d00e7,0xbcfb00fd,0x7d0600c6,0x321e007f}},	//   _djes_, _thér, _inks, zyty_,
   {{0xd5ba03d9,0x394d224e,0x27e90428,0xab2a0831}},	//   аси_, _ejes_, çana_, _тога_,
   {{0x386d224f,0x76a900d6,0x7f5c0072,0xe18900fe}},	//   _ezer_, стів_, iorq, _sẳn_,
   {{0xb6030031,0x00000000,0x00000000,0x00000000}},	//   úšal, --, --, --,
   {{0x73fa0081,0x25a9005f,0x78a22250,0x7bd61d1e}},	//   েন্ট_, ćala_, mbov, ntyu,
   {{0x21290ddc,0x1fd00033,0x63bd0103,0xd3700190}},	//   _slah_, িবাস, ásna, عهد_,
   {{0x92582251,0xaacf00df,0x28d10557,0x61260231}},	//   сант_, स्टक, _हामि, _cólo,
   {{0x69c3033b,0x7bd607ac,0x321e12c5,0x254c02c6}},	//   šneg, ktyu, ryty_, mělo_,
   {{0xb97b0105,0xf8b30327,0x212900e7,0x35730103}},	//   ינטי, ושר_, _vlah_, _تھوڑ,
   {{0x7d06013f,0x321e0031,0x254500e8,0x00000000}},	//   _anks, pyty_, vēli_, --,
   {{0x2129100b,0x61261125,0xdef801b3,0x03572252}},	//   _tlah_, _gólo, цыя_, _ויגש_,
   {{0x21292253,0x4add0285,0x254501d3,0x69c100f3}},	//   _ulah_, न्नव, tēli_, _ålei,
   {{0xb7c50081,0x61260072,0xbcfb03a9,0xa91d0117}},	// [1850] _এন্ট, _móll, _dhép, _niža,
   {{0x6f05102f,0x395f1515,0xdea10103,0x99d70037}},	//   _unhc, _skus_, _سیری, قتصا,
   {{0x386d07ff,0xb7d50065,0x394d0216,0x4c9500ae}},	//   _szer_, _iṣiw, _pjes_, _нинс,
   {{0xdb0d0037,0x254c00d2,0x00000000,0x00000000}},	//   msaí, dělo_, --, --,
   {{0x3d08000f,0x07a510b8,0x8cd8007a,0x395f00d4}},	//   हारे_, чалн, मभरो, _vkus_,
   {{0x3eba00dc,0x3707007b,0x00000000,0x00000000}},	//   _xdpt_, ючев, --, --,
   {{0x7af501ff,0x394d01cb,0xf6251aad,0x00000000}},	//   _iazt, _tjes_, ядко, --,
   {{0x395f0039,0x7af52254,0x6126002b,0x00000000}},	//   _ukus_, _hazt, _cóll, --,
   {{0x61262255,0x7f5c034f,0x59c90096,0x69d70062}},	//   _sólo, yorq, ांवर, ltxe,
   {{0x27ff2256,0xfbd2040a,0x61262257,0x395d00ca}},	//   _irun_, עתי_, _pólo, lows_,
   {{0x644d01b3,0x69d70634,0x7af52258,0xeccb007f}},	//   _žaid, ntxe, _mazt, िलाफ,
   {{0x70c6009d,0xb7d50032,0x7af501c8,0x69d701ff}},	//   वलेल, _aṣiw, _lazt, itxe,
   {{0x7f5c00fc,0xd12f2259,0x00000000,0x00000000}},	//   torq, امُ_, --, --,
   {{0x2d96225a,0xe7e30490,0x395d225b,0x78a20206}},	//   зрас, _गहना_, hows_, zbov,
   {{0x80ab0f71,0x78bb005f,0x69d701fa,0x78a20094}},	//   _কার্, _oduv, jtxe, ybov,
   {{0x80da0081,0x7af501ff,0x61e30139,0xc5f20266}},	//   _বোর্, _aazt, _ipnl, עדן_,
   {{0xc1db0789,0x7af50a00,0xe8df00de,0x3b18225c}},	// [1860] _बहुग, _bazt, _ngựa_, _porq_,
   {{0x59d000c3,0x6136007e,0xd9e00033,0xa91d05db}},	//   _हमदर, ršlu, ণিসম, _riža,
   {{0x273000ef,0xe9da225d,0x27ff0af0,0xdb0d0076}},	//   _hàng_, ске_, _arun_, csaí,
   {{0xd9100260,0xa91d225e,0xdb040076,0x78a202c6}},	//   خیر_, _piža, nsiú, ubov,
   {{0x78a2225f,0x27ff01ec,0xdb040076,0xa09b0266}},	//   rbov, _crun_, isiú, ציסט,
   {{0x7af503f3,0x273000de,0x28d1009f,0x7bc40428}},	//   _gazt, _màng_, _हाथि, mriu,
   {{0x09e306b2,0x27300019,0x98a61012,0xa5d70037}},	//   _порн, _làng_, _ниве, كبير_,
   {{0x53982260,0x2cb20188,0x27ff02c3,0x00000000}},	//   овия_, nayd_, _frun_, --,
   {{0x27300028,0x7af5010a,0x27ff2261,0x83f80231}},	//   _nàng_, _yazt, _grun_, цепс_,
   {{0x59d00067,0xaacc2262,0x798e2263,0x96661807}},	//   _हमार, ालिक, _kubw, _екзе,
   {{0xc4862264,0x20002265,0x00000000,0x00000000}},	//   _елек, _arii_, --, --,
   {{0x27300023,0x798e0435,0xa91d00c4,0xbb1b014b}},	//   _bàng_, _mubw, _ližn, _huît,
   {{0xc05b00c6,0x27300028,0xb4e8007a,0x61260094}},	//   сін_, _càng_, मजी_, _gólm,
   {{0x27300019,0x7bc40138,0xa91d2266,0x00000000}},	//   _dàng_, driu, _nižn, --,
   {{0x7bc4007a,0x7af50087,0x798e0193,0x00000000}},	//   eriu, _razt, _nubw, --,
   {{0x7bc40036,0x8d740452,0x00000000,0x00000000}},	//   friu, فاقا, --, --,
   {{0x6c542267,0xc1580054,0x31ae0081,0x705500cd}},	// [1870] екту, _משהו_, _কমিশ, _زندا,
   {{0x798e0361,0x60dd0571,0x00000000,0x00000000}},	//   _bubw, lfsm, --, --,
   {{0x79a41278,0xa2cf1179,0x69c80120,0x6562039f}},	//   ерче, _दास्, _ådel, _okoh,
   {{0xba742268,0x63742269,0x656203a5,0x7bc4226a}},	//   رالت, lànd, _nkoh, briu,
   {{0x7bc40472,0x6d4d00aa,0x6cfa00ca,0x637400b3}},	//   criu, mnaa, _ופרס, càng,
   {{0x6d4d226b,0x65620169,0x0f1b0096,0x00000000}},	//   lnaa, _akoh, _नकोस_, --,
   {{0x25a908a9,0x6d4d226c,0x798e010a,0xc5d507bf}},	//   ćalo_, onaa, _gubw, філь,
   {{0x6d4d226d,0x27ff00e7,0x63bd0146,0x6298226e}},	//   nnaa, _trun_, ásno, _afvo,
   {{0x47d50080,0x6ece009d,0x68eb0d62,0x27ff2221}},	//   _زيار, _तालु, megd, _urun_,
   {{0x273000de,0x68eb226f,0x798e0169,0x20fa00fe}},	//   _ràng_, legd, _yubw, _ỏi_,
   {{0x69c50150,0x27300023,0x6d4d2270,0x60dd2271}},	//   nrhe, _sàng_, knaa, ffsm,
   {{0xd7d12272,0x254500d9,0xe7d10179,0x7bc40138}},	//   _समाच, tēlu_, _समाप, yriu,
   {{0x69c501bf,0x6d4d0188,0x65692273,0x316c00e8}},	//   hrhe, dnaa, mleh, ēdz_,
   {{0x27300028,0x6d4d2274,0x65690170,0x2cb2008c}},	//   _vàng_, enaa, lleh, wayd_,
   {{0x4ac70789,0xa91d09ac,0xa3a91cff,0x00000000}},	//   _लाजव, _nižo, गीर_, --,
   {{0x6d4d2275,0x273000de,0x798e0079,0x65692276}},	//   gnaa, _tàng_, _rubw, nleh,
   {{0x3b860451,0x6b870126,0x8c432277,0x5fd21bc3}},	// [1880] длаг, _bijg, вете, _तमिल,
   {{0xdcfd00d9,0x6569019f,0x6d4d2278,0xfaa300ae}},	//   _visā, hleh, anaa, вафо,
   {{0x2eaa009d,0xfe720037,0x200501d3,0x6d4d0188}},	//   करीत, _جدة_, ālie_, bnaa,
   {{0xeb9f038c,0x7bc40152,0x2d57003d,0x6d4d008c}},	//   _brød_, priu, għed_, cnaa,
   {{0x69c503ee,0x9f4900ee,0x6d440a4b,0x798e0027}},	//   arhe, _graó_, miia, _wubw,
   {{0xa91d033b,0x6aae0052,0x81e40033,0x6d442279}},	//   _fižo, _uebf, নিত_, liia,
   {{0xdce40146,0x80cf030b,0xa3b0014e,0xb05b227a}},	//   hlič, _थाले, टीन_, ngär,
   {{0xdce40087,0x6ba50149,0x6569227b,0xf38800fe}},	//   klič, _åtgä, gleh, _hợi_,
   {{0xf863227c,0x7c24227d,0xd8d70130,0xa3a90096}},	//   _авто, nyir, _קומט_, गील_,
   {{0x61260102,0xdce40146,0x52140c79,0x00000000}},	//   _fólk, dlič, едот, --,
   {{0x656901af,0xa2cf0640,0x7c240193,0x6d4d0188}},	//   bleh, _दार्, hyir, ynaa,
   {{0xf3880028,0x65620027,0x60dd042c,0x03a6037e}},	//   _lợi_, _ukoh, ufsm, _жидо,
   {{0xdce4025b,0x60dd0088,0x28d10971,0x6374227e}},	//   glič, rfsm, _हासि, tànd,
   {{0x442400a5,0x636f038c,0x272b004d,0x68eb029a}},	//   mym_, lønn, _lønn_, zegd,
   {{0x1df81119,0x4424227f,0x6d4d2280,0x200d00d3}},	//   меры_, lym_, tnaa, ţei_,
   {{0xdce42102,0xa91d2281,0x65602282,0xc445001c}},	//   blič, _rižo, nomh, _آیین_,
   {{0x44242283,0x4ea72284,0x6d4d2285,0x00000000}},	// [1890] nym_, _орна, rnaa, --,
   {{0xdb1606a3,0x65600037,0x6d4d2286,0xb05b0212}},	//   nsyè, homh, snaa, sgäs,
   {{0x6d4d1cab,0x442400d8,0x637400ee,0x65692287}},	//   pnaa, hym_, càne, yleh,
   {{0x7c240193,0x636f00d6,0x4424035d,0x6b9d0124}},	//   byir, jønn, kym_, _ttsg,
   {{0x68eb2288,0x6b8701c0,0x25ac00eb,0xa7fd01f9}},	//   regd, _tijg, _awdl_, _gyűl,
   {{0x442402ad,0x7d1d0018,0x00000000,0x00000000}},	//   dym_, _hoss, --, --,
   {{0xf3880019,0x7d1d2289,0x3cf900bc,0xacbb020d}},	//   _gợi_, _koss, _kasv_, _flût,
   {{0x7d1d02fd,0x00000000,0x00000000,0x00000000}},	//   _joss, --, --, --,
   {{0x7d1d228a,0x657b00dc,0xa3c10fef,0x6569228b}},	//   _moss, rmuh, ौंध_, rleh,
   {{0x6569228c,0x69c1004d,0xdce4228d,0x657b06a8}},	//   sleh, _åles, vlič, smuh,
   {{0xcb12040a,0x216a228e,0x7bcd016d,0x798918f0}},	//   אלי_, зини_, huau, _kiew,
   {{0x7d1d0303,0xdce40087,0x44240fe2,0x00000000}},	//   _noss, tlič, bym_, --,
   {{0xb4271850,0x442400a5,0x394f228f,0xdce40335}},	//   _تعاو, cym_, ings_, ulič,
   {{0x75290018,0x79890185,0xdce410e1,0x7bcd00bc}},	//   lkez, _liew, rlič, duau,
   {{0xdd920241,0xfce60070,0x6e9315af,0x61462290}},	//   اور_, ново, الفا, _пека,
   {{0x798900a5,0x7d1d2291,0xdce418c5,0x5ec10033}},	//   _niew, _coss, plič, শ্লে,
   {{0x7d1d2292,0xf38800de,0x7d1602b6,0x7ff60037}},	// [18a0] _doss, _sợi_, rjys, _أسبا,
   {{0x272b0120,0x637400ee,0x00000000,0x00000000}},	//   _sønn_, mànc, --, --,
   {{0x7d1d0eec,0x3f920010,0x3cfb0ff9,0x7c242293}},	//   _foss, _huyu_, _लोके_, syir,
   {{0x69c304d8,0x59d2086d,0x6126061a,0x6f1e03a8}},	//   ánea, दंबर, _bóli, _hopc,
   {{0x6f1e2294,0xa7fd0103,0x6126065b,0x79892295}},	//   _kopc, _szűr, _cóli, _diew,
   {{0xa8472296,0x44240094,0x57f30291,0x254c02c6}},	//   علوم_, vym_, упшт, měli_,
   {{0x44240067,0x61262297,0x65602298,0x00000000}},	//   wym_, _eóli, tomh, --,
   {{0x61262299,0x7d1d03be,0x4424229a,0x75290103}},	//   _fóli, _xoss, tym_, gkez,
   {{0x3946229b,0x849700e3,0x636f0120,0x3f920169}},	//   mios_, رئيس_, rønn, _nuyu_,
   {{0x656005a3,0x394600c6,0xa91d02dd,0x2eaa009d}},	//   somh, lios_, _nižj, करोत,
   {{0x041e0081,0x6ed7203b,0x442402cb,0xd9430012}},	//   _বেশী_, _बाबु, sym_, _реӂи,
   {{0x3946229c,0x63740428,0x2a6a229d,0x7529229e}},	//   nios_, fànc, _mybb_, ckez,
   {{0x7d1d229f,0xb80322a0,0x5f9400e5,0x3cfb00c3}},	//   _ross, लियम_, лият, _लोगे_,
   {{0x254c00b6,0x539b0341,0x6f1e22a1,0x3cf902ac}},	//   děli_, _ציוו, _copc, _sasv_,
   {{0x7d1d22a2,0x3946013f,0x80a222a3,0x28d100e2}},	//   _poss, kios_, _क्वे, _हालि,
   {{0x9d180cd7,0x3f9203e3,0xe7f10096,0xe8031e05}},	//   ност_, _fuyu_, _आईला_, लिमा_,
   {{0x394622a4,0xeb93029e,0xdb0d001f,0x70bf074c}},	// [18b0] dios_, اظر_, nsaç, ्लील,
   {{0x798922a5,0xdb0d22a6,0x7bcd0063,0xa91d0141}},	//   _siew, trañ, ruau, _vižm,
   {{0xa2d80961,0xa7fd0018,0x394622a7,0xa3b00096}},	//   _मान्, _gyűj, fios_, टीत_,
   {{0x394622a8,0x6126003e,0x3f9222a9,0x26040966}},	//   gios_, _póli, _yuyu_, विनी_,
   {{0x79890054,0x2ca91895,0x7c6722aa,0x00000000}},	//   _view, mbad_, _ساحل, --,
   {{0x2d8b0033,0x2ca9019c,0x36691a54,0xcf940266}},	//   _hice_, lbad_, мало_, אטס_,
   {{0x75290068,0xc6a41c16,0x56920c37,0x00000000}},	//   tkez, урчи, шајт, --,
   {{0x39460d9f,0x2ca922ab,0x00000000,0x00000000}},	//   cios_, nbad_, --, --,
   {{0x80a20852,0x752922ac,0x2d9322ad,0x442b22ae}},	//   _क्षे, rkez, _luxe_, ác_,
   {{0x2d8b00e9,0x3eb322af,0x69ca001f,0xdce50090}},	//   _lice_, _next_, áfeg, _fuhħ,
   {{0x68fb22b0,0x2d8b22b1,0x3f92008b,0x6f1e22b2}},	//   _kaud, _oice_, _suyu_, _ropc,
   {{0x61461a18,0x2eaa0be4,0x637405fe,0x68fb129d}},	//   тема, कर्त, tànc, _jaud,
   {{0x200422b3,0x68fb22b4,0x291f023e,0x2d930cf8}},	//   ími_, _maud, _moua_, _auxe_,
   {{0x2d8b0091,0x80a213ae,0x394622b5,0x63740428}},	//   _aice_, _क्रे, zios_, rànc,
   {{0x2d8b22b6,0x63bb22b7,0x7ed60a85,0x00000000}},	//   _bice_, lsun, _یزدا, --,
   {{0x291f002d,0x68fb06e8,0x394608a8,0x57d106ae}},	//   _noua_, _naud, xios_, _समूह,
   {{0x63bb22b8,0x39461e30,0x6f1e22b9,0xac86004b}},	// [18c0] nsun, vios_, _topc, тгал,
   {{0x5fb700a1,0x6f1e0268,0x81e40081,0x63bb22ba}},	//   _שהיא_, _uopc, নির_, isun,
   {{0x39460610,0x68fb22bb,0x2d8b0044,0x2ca922bc}},	//   tios_, _baud, _fice_, bbad_,
   {{0x3eb822bd,0xc7c622be,0x1e5700ca,0x621a006e}},	//   lart_, вски, _ישיר_, וועק,
   {{0x394622bf,0x68fb22c0,0x291f0012,0x2d8022c1}},	//   rios_, _daud, _doua_, mmie_,
   {{0x394601b3,0x63bb22c2,0x2d8b00d3,0x290d22c3}},	//   sios_, dsun, _zice_, _enea_,
   {{0x39461946,0x68fb0257,0x7afc22c4,0x48fd02d5}},	//   pios_, _faud, _iart, _रोको_,
   {{0x7afc22c5,0x68fb22c6,0x3eb80049,0x29dc11ce}},	//   _hart, _gaud, hart_, mía_,
   {{0x63bb22c7,0x29dc22a6,0x3eb822c8,0x1c0514e5}},	//   gsun, lía_, kart_, रियल_,
   {{0x68fb22c9,0x7afc0a00,0xdb0d016d,0x77630072}},	//   _zaud, _jart, rsaç, conx,
   {{0x29dc11ce,0x7c3a01d4,0x69de1695,0x68fb22ca}},	//   nía_, _ətra, ntpe, _yaud,
   {{0x7afc01e5,0x64a622cb,0x68e222cc,0x2d93002b}},	//   _lart, _рада, nfod, _ruxe_,
   {{0xdb0411ce,0xb4ae114d,0x29dc22cd,0x3eb80429}},	//   nsió, करी_, hía_, fart_,
   {{0x0ccb0da9,0x63a20256,0x3eb822ce,0x2d8b030b}},	//   िल्म, _iton, gart_, _sice_,
   {{0x29dc0487,0x2ca901cb,0xdb04014b,0x69de0216}},	//   jía_, tbad_, mpiè, jtpe,
   {{0xa3e6009d,0x29dc0fb6,0x7afc22cf,0x63a2010a}},	//   _पहा_, día_, _aart, _kton,
   {{0x3eb322d0,0x3eb8057e,0x5c7522d1,0x2ca922d2}},	// [18d0] _text_, bart_, улат, rbad_,
   {{0x7afc22d3,0xe4e21344,0x29dc11ce,0x69de22d4}},	//   _cart, क्ति_, fía_, ftpe,
   {{0x9a8722d5,0x29dc09e9,0x2d8b03ce,0xaca30134}},	//   туал, gía_, _tice_, _alụb,
   {{0x63a222d6,0x7afc22d7,0x23c20980,0x63bb22d8}},	//   _oton, _eart, _शिंद, ysun,
   {{0xb8db0378,0x69dc22d9,0x63a216da,0x68fb22da}},	//   _आज_, _eqre, _nton, _vaud,
   {{0x7afc22db,0x29dc11ce,0x2abc02c6,0x61ea0381}},	//   _gart, bía_, rábí_, _opfl,
   {{0x29dc11ce,0x63a222dc,0x74d70034,0x69de029a}},	//   cía_, _aton, _यादृ, ctpe,
   {{0x7afc22dd,0x394402a1,0x79950350,0x290d0634}},	//   _zart, _gmms_, _iuzw, _unea_,
   {{0xa85522de,0x0ed30789,0x25be01bf,0x61ea009c}},	//   _скач, _तांड, _evtl_, _apfl,
   {{0x63bb22df,0x386d22e0,0x316905aa,0x98ad007e}},	//   rsun, _iyer_, _akaz_, _mleč_,
   {{0x63bb22e1,0x3eb822e2,0x63a222e3,0xe8df00de}},	//   ssun, vart_, _eton, _ngừa_,
   {{0x7fd60f1e,0x8fa622e4,0x34950831,0x63bb22e5}},	//   лігі, ламе, _садр, psun,
   {{0xa2e50231,0x672122e6,0xb1431147,0x7995039f}},	//   _болд, _kolj, снял, _luzw,
   {{0xdbd10364,0x61260103,0x0876006e,0x083a006e}},	//   _süße, _rólu, טערט_, געשל,
   {{0xa2d81a09,0x29dc22e7,0xe8df0174,0xe4f922e8}},	//   _मात्, xía_, _amọn_, ्यपि_,
   {{0x7afc22e9,0x29dc11ce,0x5c160084,0xa3b00789}},	//   _sart, vía_, льзу, टीव_,
   {{0x3eb8014b,0x386d22ea,0x2d8022eb,0x60c422ec}},	// [18e0] part_, _nyer_, rmie_, _idim,
   {{0x7afc00dd,0x29dc04d8,0x2d800031,0x60c40090}},	//   _qart, tía_, smie_, _hdim,
   {{0x7afc0963,0x386d22ed,0x9d4622ee,0xbf9b0161}},	//   _vart, _ayer_, _бенд, nvên,
   {{0x29dc11d1,0x7afc22ef,0x61fc0400,0x386d01df}},	//   ría_, _wart, ærli, _byer_,
   {{0x7afc22f0,0x6d4607d1,0x29dc0fb6,0x23651197}},	//   _tart, _imka, sía_, kolj_,
   {{0xa2d822f1,0xdb0411c4,0x29dc22f2,0xbcfb22f3}},	//   _माध्, rsió, pía_, _akéh,
   {{0xf41f0d64,0x672100cb,0x60c40174,0x63a222f4}},	//   ään_, _dolj, _odim, _ston,
   {{0xb4ae0e72,0x60c422f5,0x80d6009d,0x186a22f6}},	//   करे_, _ndim, _भाषे, _заби_,
   {{0x67212181,0x14d5055c,0xb7f100aa,0x79820d2a}},	//   _folj, _धारण, _आईएम_, mmow,
   {{0xa3b504a9,0x60c422f7,0x672122f8,0x23650dd9}},	//   _जबर_, _adim, _golj, golj_,
   {{0xe693054f,0x415522f9,0x6d4622fa,0x925822fb}},	//   _المد, ивос, _omka, тант_,
   {{0x6ed70efb,0x672102ef,0x798201c2,0x63a20361}},	//   _बाहु, _zolj, nmow, _tton,
   {{0x63a222fc,0x60c422fd,0x5ede0033,0x23650128}},	//   _uton, _ddim, য়নে, bolj_,
   {{0x88bd00a5,0x2fc0033b,0x6d461f9e,0x6b8e00bd}},	//   _kośc, _dvig_, _amka, _nibg,
   {{0x2bc71376,0xd2b722fe,0x2fc00407,0xa3b002d5}},	//   _लिहा, _גלות_, _evig_, टीर_,
   {{0x798200a5,0x31690540,0x79950169,0x00000000}},	//   jmow, _ukaz_, _ruzw, --,
   {{0x7522023e,0xdb04002b,0x8aa722ff,0x00000000}},	// [18f0] _mooz, esiñ, гред, --,
   {{0xf09f0428,0x9b440037,0x200919ea,0x386d02ac}},	//   lcà_, منقو, _irai_, _ryer_,
   {{0xeb9f0c08,0xdb580084,0x386d00dc,0x6b8e030a}},	//   _grøn_, уют_, _syer_, _dibg,
   {{0x20092190,0xb4ae09a1,0x752206b0,0x3f8300e8}},	//   _krai_, करो_, _nooz, lmju_,
   {{0xb9650065,0xdcef007f,0x00000000,0x00000000}},	//   _adìé, _chcą, --, --,
   {{0x8cad00b6,0x386d02c2,0x637d0113,0x00000000}},	//   जरको, _vyer_, mèng, --,
   {{0x236502dd,0x7bcd003e,0x389e0129,0x61ed0a39}},	//   volj_, lrau, _ịre_, _ćalo,
   {{0x2009013f,0xf8b900bc,0x00000000,0x00000000}},	//   _orai_, _उजिय, --, --,
   {{0x36d52300,0xa3b02301,0xe3b60109,0x7bcd2302}},	//   _возр, टील_, абы_, nrau,
   {{0x27ed2303,0x7bcd2304,0x00000000,0x00000000}},	//   _ipen_, irau, --, --,
   {{0x88bd00a5,0x7bcd2305,0x7be10033,0x637d00d1}},	//   _gośc, hrau, নিয়ো, hèng,
   {{0x291d214f,0x7bcd2306,0x00860ac6,0x20092307}},	//   njwa_, krau, илно, _brai_,
   {{0xa0760077,0x273903a9,0xe7b30022,0x20092308}},	//   рынш, _cèng_, _ƙaƙƙ, _crai_,
   {{0x82a502fd,0x7bcd2309,0x56b500c1,0x798200a5}},	//   _такж, drau, יפֿן_, zmow,
   {{0x63a9230a,0x99d70081,0x69c3230b,0xa0a6230c}},	//   lpen, সবুক, šnej, _кайд,
   {{0xf38800ef,0x27ed230d,0x63a9024a,0x200901ff}},	//   _hợp_, _open_, open, _frai_,
   {{0x63a9230e,0x7bcd230f,0x4d63004d,0x0b4601b6}},	// [1900] npen, grau, ікув, анан,
   {{0x68e92310,0x63a91e12,0x09e6075f,0xaca40032}},	//   _abed, ipen, иозн, _ijọs,
   {{0xa2d80789,0xe9da2311,0xaca40134,0xfce62312}},	//   _मास्, тке_, _agụt, _коно,
   {{0x7bcd2313,0xa3e6099d,0x88e600c2,0x76000103}},	//   brau, _पहल_, ржде, házá,
   {{0x798200a5,0x76002314,0xbcfb0af0,0x6d560201}},	//   rmow, kázá, _akéw, mnya,
   {{0x6d560167,0x88bd007f,0x68e904d6,0x6374015e}},	//   lnya, _pośc, _ebed, vàno,
   {{0xd5b70b2f,0x6d56008a,0x63a91226,0xdced00a7}},	//   асы_, onya, epen, nmağ,
   {{0x6d562315,0xa91d2316,0x68e90065,0x25a10206}},	//   nnya, _bižu, _gbed, íhla_,
   {{0x63a92317,0x07a30131,0x27e92318,0xc7a30e3a}},	//   gpen, _матн, çant_, _митк,
   {{0x27390113,0x75220172,0x00000000,0x00000000}},	//   _rèng_, _wooz, --, --,
   {{0x6d562319,0xfa970089,0x752200e7,0x7bcd01d3}},	//   knya, ידיש_, _tooz, zrau,
   {{0x9d210033,0x2bc7231a,0x70220033,0x00000000}},	//   _নগ্ন_, _लिला, _পেইজ_, --,
   {{0xc05b0120,0xe53b0054,0xb4c406ec,0x637d00ee}},	//   тін_, _בתאר, ौली_, fènd,
   {{0x2009025a,0x6d560172,0x637d01dc,0xf09f00ee}},	//   _vrai_, enya, gènd, scà_,
   {{0x937b0089,0x00000000,0x00000000,0x00000000}},	//   _שטות, --, --, --,
   {{0x7bcd231b,0x20090028,0xc0cb231c,0x6d56231d}},	//   trau, _trai_, _руке_, gnya,
   {{0xe4f9231e,0x2d9c01f9,0x00000000,0x00000000}},	// [1910] ्यति_, _éven_, --, --,
   {{0x6d56231f,0x7bcd2320,0xfaa700c6,0xdab901c3}},	//   anya, rrau, ршан, اهات_,
   {{0x81e40081,0x63a90a00,0xceb20341,0x0b882321}},	//   নিক_, zpen, _מיי_, рсти_,
   {{0x273900fd,0x637d2322,0x63a92323,0x7bcd2324}},	//   _mène_, mène, ypen, prau,
   {{0x98e40037,0x6d4d2325,0x9ac70103,0x00000000}},	//   تكنو, miaa, _نگاہ_, --,
   {{0x9b450401,0x6aa90233,0x00000000,0x00000000}},	//   _طنزو, _şeff, --, --,
   {{0x80c200c7,0x7c2d2326,0x760000d2,0x00000000}},	//   ষ্ট্, lyar, vázá, --,
   {{0x58d40b0a,0x68e90284,0x63a92327,0x1e5800ca}},	//   _мост, _ubed, tpen, ישור_,
   {{0x7c2d2328,0xe2990131,0x63a92329,0xd6db00d3}},	//   nyar, лап_, upen, _ате_,
   {{0xf5e700d6,0x63a9202c,0x6d4d00bc,0xdced232a}},	//   _відм, rpen, hiaa, dlač,
   {{0xa2d81da8,0x7c2d232b,0x2249232c,0xdced013c}},	//   _मार्, hyar, упни_, xmağ,
   {{0x04950037,0x645e0034,0x61e100b3,0x00000000}},	//   _الإح, _śpie, rtll, --,
   {{0x7c2d02a4,0xdced0344,0x753b0350,0xd49600d7}},	//   jyar, jmađ, mhuz, _הכנת_,
   {{0x442d232d,0xdced00a7,0x00000000,0x00000000}},	//   mye_, tmağ, --, --,
   {{0x442d232e,0x6d56005c,0x637d232f,0x443f2330}},	//   lye_, tnya, rènd, lzu_,
   {{0x6d4d2331,0xdced2332,0xe0da0831,0x6d56008c}},	//   giaa, rmağ, _сви_, unya,
   {{0x442d2333,0x7c2d0068,0x443f2334,0xec7a123a}},	// [1920] nye_, gyar, nzu_, упа_,
   {{0x8a3a0084,0x442d2335,0x2ca0028e,0x443f01c8}},	//   ляет_, iye_, scid_, izu_,
   {{0xb4f910e9,0xd91000bf,0xdce400cb,0x442d023b}},	//   ्याय_, ویس_, jlić, hye_,
   {{0x7c2d2208,0x6d4d0ab2,0x442d2336,0xf9690120}},	//   byar, ciaa, kye_, арій_,
   {{0xa2d82337,0x291203a3,0x442d0a4d,0x7c2d02a4}},	//   _माल्, ıya_, jye_, cyar,
   {{0x7d042338,0x443f00d9,0x442d2339,0x29000774}},	//   ldis, dzu_, dye_, žia_,
   {{0xe7f40da9,0x7bd614cb,0x442d0188,0x2d9a233a}},	//   _इनका_, luyu, eye_, _jupe_,
   {{0x7d04233b,0x442d0c56,0xdce40095,0x6abe007e}},	//   ndis, fye_, koič, lapf,
   {{0x442d233c,0x7d04233d,0x78a20146,0xfc4a02c6}},	//   gye_, idis, mcov, blíž_,
   {{0xdced0106,0x7d040084,0x78a20146,0xd6d200b1}},	//   vlač, hdis, lcov, _رقص_,
   {{0x442d233e,0x65690113,0x00000000,0x00000000}},	//   aye_, boeh, --, --,
   {{0x78a20074,0x442d1a80,0x753b0010,0xdced233f}},	//   ncov, bye_, chuz, tlač,
   {{0x7d042340,0x50672341,0x443f00a5,0xa2b10096}},	//   ddis, стна, czu_, _आजच्,
   {{0x6d5a2342,0x7bd62343,0xa85700ca,0xdcef00e8}},	//   étan, duyu, מיכה_, _ticī,
   {{0x6d4d2344,0xdced0335,0x8d770604,0x2d9a044c}},	//   tiaa, slač, مارا, _cupe_,
   {{0x2d9a2345,0xdced02dd,0x7d042346,0x78a22347}},	//   _dupe_, plač, gdis, jcov,
   {{0xac182348,0x6d4d2349,0x7bd6234a,0x78a2035d}},	// [1930] боту_, riaa, guyu, dcov,
   {{0x6d4d234b,0x7c2d234c,0x6440234d,0x7d041350}},	//   siaa, ryar, izmi, adis,
   {{0x7c2d0496,0x637d0472,0x442d02f1,0x4c95234e}},	//   syar, lènc, zye_, _минс,
   {{0x273000ef,0x26de0fb6,0x442d234f,0x7bd60167}},	//   _hành_, _acto_, yye_, buyu,
   {{0x81e40081,0x637d0428,0xb90100c3,0x18690b1b}},	//   নিট_, nènc, _दा_, јали_,
   {{0xe73616d9,0x442d2350,0x443f0092,0xdce4042d}},	//   жеш_, vye_, vzu_, tlić,
   {{0xf77000bf,0x78a22351,0x442d2352,0x273000fe}},	//   راه_, bcov, wye_, _mành_,
   {{0x442d0c56,0x443f0a00,0x273000de,0xb3c90c79}},	//   tye_, tzu_, _lành_, ализ_,
   {{0x442d2353,0xdce40b18,0x753b01f9,0x00000000}},	//   uye_, slić, rhuz, --,
   {{0x443f2354,0xa1c50562,0x442d2355,0x637d0472}},	//   rzu_, обод, rye_, dènc,
   {{0x442d2356,0x2d5704f9,0x5f1d0469,0xe7842357}},	//   sye_, għek_, मान्_, _хуто,
   {{0x3eba2358,0x442d06a3,0x6abe2359,0x7bd6235a}},	//   _sept_, pye_, zapf, yuyu,
   {{0x41c50336,0x637d05fe,0xe8df0023,0x7d04235b}},	//   _विकस, gènc, _ngửa_, vdis,
   {{0x78bb0d4d,0x6d5d007e,0x3f81009c,0x27300023}},	//   _leuv, _ajsa, _chhu_, _cành_,
   {{0x27300028,0x7d0408bc,0x78bb0257,0x6da3235c}},	//   _dành_, tdis, _oeuv, диса,
   {{0x78bb235d,0x2fcd02dd,0x0d991ad1,0x7d04235e}},	//   _neuv, šega_, стры_, udis,
   {{0x637d0472,0x78a20146,0x6abe235f,0xac072360}},	// [1940] cènc, vcov, tapf, онта_,
   {{0x91ed1d7d,0x7bd607aa,0x200000ac,0x2d9a2361}},	//   _जहाज_, ruyu, _isii_, _tupe_,
   {{0x6abe02a4,0x3e83020d,0x78bb014b,0x78a22362}},	//   rapf, rété_, _beuv, tcov,
   {{0x7d04025e,0x1d0a2363,0x69c32364,0x00000000}},	//   qdis, _теми_, ânea, --,
   {{0x78a22365,0x386000a7,0x6b830174,0xaae20473}},	//   rcov, çir_, ọgar, _पापक,
   {{0x78a22366,0x00000000,0x00000000,0x00000000}},	//   scov, --, --, --,
   {{0xa3dc0980,0x3f4d00e7,0x27ff0032,0x78a21515}},	//   तून_, džul_, _esun_, pcov,
   {{0x63740428,0x7bc40138,0x6440042c,0x80d602c6}},	//   màni, osiu, tzmi, _भागे,
   {{0x7bc42367,0x741400e3,0x64400106,0x6abc003e}},	//   nsiu, سودا, uzmi, _kerf,
   {{0x799c023f,0x29040dc2,0x637d05fe,0x27e62368}},	//   _kurw, _hama_, vènc, mton_,
   {{0x29042369,0x6abc02a1,0x27e6236a,0x2ef80313}},	//   _kama_, _merf, lton_, derf_,
   {{0x29040a75,0x09cf00c7,0x2906236b,0x637d0472}},	//   _jama_, _রহমা, ndoa_, tènc,
   {{0x64400063,0x6abc236c,0x74130076,0x00000000}},	//   qzmi, _oerf, _يوما, --,
   {{0x2904236d,0x637d0990,0x6abc236e,0x26dc004b}},	//   _lama_, rènc, _nerf, ngvo_,
   {{0x637d0472,0xdcbb236f,0x31352370,0xce94013d}},	//   sènc, ища_, _некр, даръ,
   {{0x5c992371,0x27e62372,0xa3ae2373,0x6abc0037}},	//   ская_, kton_, _ओझा_, _aerf,
   {{0x6abc2374,0xdfdb013d,0x27e6023b,0x7bc42375}},	// [1950] _berf, _тъй_, jton_, gsiu,
   {{0x6abc2376,0x60dd2377,0x6e2a0052,0x799c0b58}},	//   _cerf, lgsm, ëmbë, _burw,
   {{0x6abc1a08,0x78bb025a,0x29042378,0x637405fe}},	//   _derf, _peuv, _bama_, gàni,
   {{0x7af72379,0x2904237a,0x27e6237b,0x69d7237c}},	//   sext, _cama_, fton_, ruxe,
   {{0x29041114,0x01e000c7,0x2d89237d,0x6abc237e}},	//   _dama_, ববিদ, mmae_, _ferf,
   {{0x27390154,0xb6a500d3,0x69d70042,0xdb040131}},	//   _bèna_, чикл, puxe, rpiã,
   {{0x27e60d64,0x672803ce,0x2904237f,0x6b9d207a}},	//   aton_, _dodj, _fama_, _husg,
   {{0x29042380,0x6b9d2381,0x2ee11d21,0x27e60124}},	//   _gama_, _kusg, _lchf_, bton_,
   {{0x27ff034c,0x1c0e0179,0x36d500ae,0x00000000}},	//   _usun_, सियल_, _ноар, --,
   {{0x29040a75,0x6b9d2382,0x466b2383,0x69c52384}},	//   _zama_, _musg, _крем_, oshe,
   {{0xe8030a30,0x69c52385,0x29042386,0x2ef82387}},	//   लिका_, nshe, _yama_, verf_,
   {{0x67232388,0x2ef8000b,0x2129037a,0x23a00154}},	//   ljnj, werf_, _coah_, _fòj_,
   {{0x88bd00a5,0x200f1e6c,0x24640052,0x69c52389}},	//   _rośl, _ágil_, rëmë_, hshe,
   {{0x69c70268,0x395f0149,0x2d9c0103,0x69c5238a}},	//   _ovje, _ljus_, _évek_, kshe,
   {{0x6b9d02dc,0x69c5238b,0x6b40238c,0x88bd007f}},	//   _ausg, jshe, _högg, _pośl,
   {{0x2bc70cf6,0x6b9d238d,0x6b9501d3,0x799c0169}},	//   _लिखा, _busg, _aizg, _rurw,
   {{0x2904238e,0x6b9505db,0x6b9d01c2,0x27e61d91}},	// [1960] _rama_, _bizg, _cusg, xton_,
   {{0x799c238f,0x7bc42390,0x637405fe,0x69c50052}},	//   _purw, rsiu, tàni, fshe,
   {{0x6abc2391,0x4ae202e8,0x67281419,0x69c72392}},	//   _verf, _पाठव, _rodj, _cvje,
   {{0x0edc030b,0x27e62393,0x63740428,0x69c70dd9}},	//   _बाँड, tton_, ràni, _dvje,
   {{0x67281548,0x290402e6,0x29062394,0x6abc1a49}},	//   _podj, _vama_, rdoa_, _terf,
   {{0x395f05aa,0x29042395,0x7d062396,0x28d82397}},	//   _ejus_, _wama_, _haks, _डाकि,
   {{0x29042398,0x7d062399,0x27e6239a,0x67282024}},	//   _tama_, _kaks, ston_, _vodj,
   {{0x7d06239b,0x27e6239c,0xda5b0327,0x394d239d}},	//   _jaks, pton_, _הכלל, _gmes_,
   {{0x7d06239e,0x69c7239f,0x0edc00df,0x00000000}},	//   _maks, _zvje, _बांड, --,
   {{0x883b00a1,0x637d06a3,0x394d23a0,0x00000000}},	//   _התמו, tèna, _zmes_, --,
   {{0x76430067,0x26cc02ad,0xa3b0097c,0x325300d3}},	//   czny, _iddo_, टीज_, евэр,
   {{0xf4870177,0x867b006e,0x27390154,0x60dd00e8}},	//   _کامی, _פראו, _jènn_, ugsm,
   {{0xfc3f23a1,0x60dd23a2,0xcfa7007b,0x00000000}},	//   _afín_, rgsm, яшни, --,
   {{0x3da723a3,0x7d0607ac,0x69c523a4,0x6b9d23a5}},	//   зраб, _aaks, yshe, _rusg,
   {{0x9e14004d,0x6b950216,0x2bda0285,0x00000000}},	//   ндрі, _rizg, यूसा, --,
   {{0x6b9d19db,0x69c50ac1,0x7d0601ee,0x00000000}},	//   _pusg, vshe, _caks, --,
   {{0x69c7029b,0x60cd23a6,0x2d8903a9,0x7d0623a7}},	// [1970] _svje, _idam, rmae_, _daks,
   {{0x69c5067d,0x394d0078,0x23d414db,0x69c30131}},	//   tshe, _smes_, _दिनद, âneo,
   {{0x6aa523a8,0xa3dc02d5,0xf9f908ba,0x6b830174}},	//   rchf, तूत_, تفاع_, ọgor,
   {{0x69c523a9,0xac1923aa,0xe9d00602,0x26cc23ab}},	//   rshe, _дому_, اغل_, _addo_,
   {{0x69c523ac,0x394d033b,0xfc6400e5,0x69da00f3}},	//   sshe, _vmes_, _зърн, _åten,
   {{0xe29a00de,0x69c51175,0xa2d800b6,0x69c70141}},	//   _ngư_, pshe, _माग्, _tvje,
   {{0x69c7029b,0xba7700d0,0x7d0623ad,0x60cd23ae}},	//   _uvje, _راست, _yaks, _odam,
   {{0x60cd23af,0xbe3c00ca,0x26cc010a,0x76430034}},	//   _ndam, מעות, _eddo_, rzny,
   {{0xb4ad10ed,0x387f23b0,0x67d423b1,0x395d023e}},	//   _कभी_, _uzur_, _поту, mnws_,
   {{0x60cd23b2,0x644d013f,0xd75b0100,0x81c900c2}},	//   _adam, _žais, _اجرا_, огов_,
   {{0x77640428,0x61e80124,0x6ed7052c,0x00000000}},	//   éixe, gtdl, _बाजु, --,
   {{0x60430134,0x00000000,0x00000000,0x00000000}},	//   _ọmaj, --, --, --,
   {{0x7d060b4b,0x6b400149,0x60cd23b3,0x00000000}},	//   _raks, _höge, _ddam, --,
   {{0x6d4f23b4,0x60cd23b5,0x4f9500ae,0x00000000}},	//   _amca, _edam, ерсу, --,
   {{0x7d0623b6,0x2d9e025a,0x2d9607cb,0x1b060081}},	//   _paks, ête_, драс, রামে_,
   {{0x395d023e,0x6b402104,0xd2dd023a,0x00000000}},	//   jnws_, _möge, _माँझ, --,
   {{0x7d0600f3,0x5ed30081,0xed570161,0x2739022b}},	// [1980] _vaks, দ্ধে, фот_, _rènn_,
   {{0x5fd3009f,0x6d4f063d,0x9f48007b,0x27390154}},	//   _तितल, _emca, öhän_, _sènn_,
   {{0x7d0623b7,0x63740428,0x752b0381,0x48e623b8}},	//   _taks, mànt, _oogz, доев,
   {{0x395d023e,0x63740428,0xa3ae00c3,0x00000000}},	//   gnws_, lànt, _ओझल_, --,
   {{0xc7a318c6,0xf74623b9,0x07fa15af,0x07a323ba}},	//   вичк, медо, تراع_, вачн,
   {{0xeb9f1484,0xb86523bb,0xf1c00031,0x6b4002db}},	//   _prøv_, رانو, úšky_, _böge,
   {{0x8a03121c,0x395d01fa,0x752b078e,0x00000000}},	//   _изре, bnws_, _bogz, --,
   {{0x4906009f,0x00000000,0x00000000,0x00000000}},	//   _सोचो_, --, --, --,
   {{0x671e0e72,0x14180076,0x00000000,0x00000000}},	//   पादक_, سيدة_, --, --,
   {{0xf7721823,0x778300ae,0x6b4002c3,0x00000000}},	//   _شاء_, _алуз, _högb, --,
   {{0x2fc923bc,0x945d007f,0x00000000,0x00000000}},	//   _svag_, tańc, --, --,
   {{0x92be00c7,0x914b0c10,0xae0d00aa,0x00000000}},	//   ইলে_, ічна_, हिसन_, --,
   {{0xb4da009f,0xf41f007b,0x6b400364,0x945d007f}},	//   ़ली_, äät_, _zöge, rańc,
   {{0x6b4001cd,0x09e50033,0x00000000,0x00000000}},	//   _lögb, নবতা, --, --,
   {{0xf206013d,0x7bd603a9,0x2012041c,0x00000000}},	//   _цяло, eryu, _eryi_, --,
   {{0x9d18008f,0x2c0b0096,0xe0df00b3,0x00000000}},	//   мост_, हटलं_, riòs_, --,
   {{0x63ad23bd,0x395d023e,0xfd1f0023,0x21390167}},	// [1990] _çant, vnws_, _chìa_, mksh_,
   {{0xdb0d003e,0x637400b3,0x00000000,0x00000000}},	//   gsað, cànt, --, --,
   {{0x69c80537,0x00000000,0x00000000,0x00000000}},	//   _ædel, --, --, --,
   {{0xa2d80454,0x656201e5,0xdce4026a,0x8ccb00aa}},	//   _माझ्, _njoh, mliğ, तृशो,
   {{0x7ac70114,0xdce401e8,0x2ca923be,0x00000000}},	//   _осве, lliğ, mcad_, --,
   {{0x6d910181,0x395d023e,0x2ca9008c,0xd7060120}},	//   _sťah, snws_, lcad_, енше_,
   {{0x58d523bf,0x2d9923c0,0xdce401e8,0xd5b10037}},	//   _повт, _kise_, nliğ, دفع_,
   {{0x6b400364,0xd6180f98,0x00000000,0x00000000}},	//   _vöge, بتها_, --, --,
   {{0x2d9923c1,0x47d50080,0x6d5a025a,0x443923c2}},	//   _mise_, _سيار, étai, ás_,
   {{0x422523c3,0x2d9923c4,0xdce4026a,0x6562039f}},	//   едов, _lise_, kliğ, _ejoh,
   {{0x78a423c5,0x4ae20fdd,0x443900d9,0x2d9900fd}},	//   žive, _पासव, šs_, _oise_,
   {{0x2d9923c6,0xa06a0284,0x00000000,0x00000000}},	//   _nise_, зама_, --, --,
   {{0x98a401d3,0xa2d702d5,0x1b060033,0xa07500d3}},	//   _jomā_, _मयप्, রাতে_, вырш,
   {{0xa35700bf,0x2d9923c7,0xd37b00ae,0xcad50033}},	//   _تخصص, _aise_, _ьче_, স্তফ,
   {{0x2d9923c8,0x637400b3,0x00000000,0x00000000}},	//   _bise_, rànt, --, --,
   {{0x628302e6,0x2d990e2a,0xa1c200e5,0x00000000}},	//   _izno, _cise_, _сбъд, --,
   {{0xe7da00c7,0x2d9923c9,0x4f961b10,0xbea60d9b}},	// [19a0] _ধন্য, _dise_, _проу, _папк,
   {{0x2d990313,0x2d9e0161,0xdce407e7,0x00000000}},	//   _eise_, ítes_, bliğ, --,
   {{0xdebb00f5,0x53360130,0x2d9923ca,0x5ebb00ca}},	//   _ממיל, ענען_, _fise_, _מזיק,
   {{0xe1ff00a5,0xeb9a23cb,0x597600cd,0xfd1f0023}},	//   łów_, _ним_, رداز, _thìa_,
   {{0x6d5623cc,0x4e96001c,0x6d4423cd,0x3f9a23ce}},	//   miya, _تشکر, mhia, _kipu_,
   {{0x6d5623cf,0xa5a40034,0x6d440124,0x98a401d3}},	//   liya, _चंदौ, lhia, _domā_,
   {{0xceb30054,0x6b6323d0,0x2d9923d1,0x60c623d2}},	//   ניה_, _скра, _yise_, kakm,
   {{0x6d5623d3,0x60c623d4,0x6d4423d5,0x657b0a69}},	//   niya, jakm, nhia, gluh,
   {{0xe3af03ed,0x60c609a4,0x69de23d6,0xdce4026a}},	//   یری_, dakm, lupe, zliğ,
   {{0x6d5623d7,0xfd1f0028,0x3f9a0479,0x68e223d8}},	//   hiya, _nhìn_, _nipu_, lgod,
   {{0x6d5623d9,0x6d44048e,0xf41f00bc,0x00000000}},	//   kiya, khia, äär_, --,
   {{0x6d5623da,0x88bd00a5,0x68e223db,0xbcfb0032}},	//   jiya, _dośw, ngod, _ajén,
   {{0x6d5623dc,0x5433012b,0xb4bc030b,0x557700c1}},	//   diya, _مرور, अरी_, _װעגן_,
   {{0x2d9923dd,0xae0d007d,0x69de23de,0x15f40e28}},	//   _sise_, हिलन_, kupe, _आहार_,
   {{0x63a223df,0x2d9904a3,0x6d5623e0,0xf8d0009d}},	//   _huon, _pise_, fiya, हणाय,
   {{0x63a21ee3,0x6d5623e1,0x6d441031,0xdce401e8}},	//   _kuon, giya, ghia, rliğ,
   {{0x2ca90188,0x63a200c2,0x656010e4,0x68e223e2}},	// [19b0] rcad_, _juon, inmh, dgod,
   {{0xaa6723e3,0x63a223e4,0x5f950291,0x3a2b00fe}},	//   нтек, _muon, _шипт, _đểđă,
   {{0x6d5623e5,0x63a223e6,0xda6700e3,0x6d44033f}},	//   biya, _luon, رائي, bhia,
   {{0x6d4423e7,0x6d5623e8,0x637d0c56,0xacbb0257}},	//   chia, ciya, vènm, _coût,
   {{0x7c8423e9,0x63a223ea,0x7d0d003e,0x66e5107a}},	//   _буре, _nuon, mdas, вола,
   {{0x7d0d23eb,0x68e20072,0x7bdf008c,0x61f818f0}},	//   ldas, agod, muqu, _opvl,
   {{0xae1405d4,0x7bdf0314,0xc179013f,0x657b0bb6}},	//   डियन_, luqu, ntės_, tluh,
   {{0x63a223ec,0x7d0d23ed,0xacbb0257,0xc1790138}},	//   _buon, ndas, _goût, itės_,
   {{0x63a200de,0xa3dc02d5,0x6b400212,0xa82200d1}},	//   _cuon, तूल_, _höga, _نکون,
   {{0x6d5623ee,0x63a223ef,0x88bd0034,0x7d0d00c2}},	//   ziya, _duon, _pośw, hdas,
   {{0x216a1a2b,0x614602b3,0x7d1d0313,0x6d5623f0}},	//   дини_, вена, _onss, yiya,
   {{0x26c723f1,0x7afe23f2,0x8fa623f3,0x6d5623f4}},	//   lano_, zept, каме, xiya,
   {{0xf9920130,0x7d0d23f5,0xa3a802e8,0x60c6026a}},	//   ירט_, ddas, _खूप_, rakm,
   {{0x26c723f6,0x752920e4,0x60c623f7,0xd24e001c}},	//   nano_, ljez, sakm, _ژنو_,
   {{0x6d5623f8,0x6d4402ad,0x50b623f9,0x26c723fa}},	//   tiya, thia, _испу, iano_,
   {{0x26c723fb,0x7d0d23fc,0x752923fd,0x261211d7}},	//   hano_, gdas, njez, थिती_,
   {{0x26c70c50,0x7afe002d,0x644902e2,0x6d440991}},	// [19c0] kano_, tept, nzei, rhia,
   {{0x6d440197,0x6d5623fe,0x60c423ff,0x69de00d4}},	//   shia, siya, _heim, tupe,
   {{0x60c40e95,0x3ed900c1,0x644901bf,0xa3a81152}},	//   _keim, _אַרא, hzei, _खून_,
   {{0x7afe2400,0x79892401,0x69de2402,0x6c860037}},	//   sept, _chew, rupe, _للجم,
   {{0xb90a2403,0x26c72404,0x798900bf,0x87e300c2}},	//   _मा_, fano_, _dhew, ающе,
   {{0x6a861722,0x3d1601e4,0x68e22405,0x60c42406}},	//   _алга, _पोते_, sgod, _leim,
   {{0x2d9c0068,0x63a22407,0x248000d9,0x98a4020a}},	//   _éves_, _suon, _šim_, _comă_,
   {{0x644901bf,0x6b9c0188,0x00000000,0x00000000}},	//   fzei, _hirg, --, --,
   {{0x07a60eaf,0x46ea007e,0x6b9c2408,0x3cea0caf}},	//   _разн, _одан_, _kirg, _छाने_,
   {{0x39460396,0xdced00e9,0x63a22409,0x7d0d0018}},	//   lhos_, plać, _vuon, zdas,
   {{0x53d4009d,0x7d0d0491,0x60c4240a,0xfb15006e}},	//   _दिवश, ydas, _beim, אַרט_,
   {{0x394600c9,0x63a2240b,0x51870291,0xdb0f015e}},	//   nhos_, _tuon, ђуна, _etcè,
   {{0x934613cb,0x14d70105,0x60c4240c,0x2ba702d5}},	//   _инде, _יואל_, _deim, _कंधा,
   {{0x69d30789,0x53330b1b,0x6b9c240d,0x00000000}},	//   _डिली, _вешт, _nirg, --,
   {{0x2fc0240e,0xa3a8240f,0x139b00ca,0x60c42410}},	//   _ewig_, _खंड_, _קבוע, _feim,
   {{0x60c42411,0xe7d20789,0xd7d209c4,0xc1790138}},	//   _geim, _सिंप, _सिंच, rtės_,
   {{0x7d0d2412,0xdd940138,0x2bda0b94,0x26c72413}},	// [19d0] rdas, раты, यंगा, yano_,
   {{0x7d0d01af,0x7cde00d3,0x26c703eb,0x79892414}},	//   sdas, tărâ, xano_, _shew,
   {{0x26c72415,0x6b9c2416,0xfaa40c3f,0x7d0d2417}},	//   vano_, _dirg, ршун, pdas,
   {{0x26c72418,0x6b9c0503,0x6d5a2419,0x00000000}},	//   wano_, _eirg, état, --,
   {{0x26c7241a,0x3869241b,0x6b9c0d2a,0x7bdf00a7}},	//   tano_, çar_, _firg, ququ,
   {{0x386904f9,0x6b9c241c,0xa03c00a1,0x394600c4}},	//   ħar_, _girg, ועדפ, ahos_,
   {{0x78a403ce,0xa3a80da9,0xa2b8030b,0xdb0600b6}},	//   živa, _खूब_, ोरन्, _utká,
   {{0xf3ff241d,0x3946241e,0xb4ad02e8,0x97c50080}},	//   ção_, chos_, कडे_, _مقرو,
   {{0x26c7241f,0x290d2420,0xf8ae0018,0xc9520089}},	//   pano_, _iaea_, _رکن_, _המן_,
   {{0x644902dc,0x60c42421,0x753b030b,0x2b1c0034}},	//   rzei, _seim, skuz, नाएँ_,
   {{0x64492422,0x7ae503dc,0x7bcd10f4,0x2fc00f5a}},	//   szei, ight, hsau, _swig_,
   {{0xe4cb00cd,0x26c5142a,0x6d1202d5,0x290f03e3}},	//   _آبان_, _helo_, _ढोंग_, ndga_,
   {{0xb4df009d,0xfd1f00de,0x25a52423,0xdb0f0610}},	//   तली_, _chìm_, _hull_, _etcé,
   {{0x25a504f9,0xe8e000b6,0x26c5005f,0x200900dc}},	//   _kull_, _पञ्च, _jelo_, _dsai_,
   {{0x26c52424,0x60c42425,0x1609022d,0x68e9077e}},	//   _melo_, _teim, विटर_, _oced,
   {{0x2d8b12fb,0x61e12426,0x6b9c2427,0x26c52428}},	//   _chce_, mull, _sirg, _lelo_,
   {{0x61e12429,0x7bcd08bc,0xac860ef7,0x2120242a}},	// [19e0] lull, gsau, угал, _inih_,
   {{0x68e90558,0xec77242b,0xfd1f0139,0xaf0617a8}},	//   _aced, упу_, _enì_, _спол,
   {{0x61e1242c,0xaca40134,0x637d0bb3,0x212000b6}},	//   null, _alụs, gèni, _knih_,
   {{0x68e9242d,0x6b40003e,0x290d03a8,0x7bcd042c}},	//   _cced, _gögn, _caea_, bsau,
   {{0x6b9c0029,0x26c5242e,0x7e7e242f,0x2d802430}},	//   _tirg, _belo_, _hypp, mlie_,
   {{0x61e101e5,0x26c52431,0x6b9c01b9,0xfaa32432}},	//   kull, _celo_, _uirg, _гаро,
   {{0x212003ce,0x26c52433,0x394601af,0x637d0428}},	//   _onih_, _delo_, phos_, cèni,
   {{0x9d220f71,0x61e12434,0xa534002d,0x774a0139}},	//   _নতুন_, dull, рнич, _dàbọ,
   {{0x7866088c,0x26c52435,0x77862436,0x6fa00442}},	//   _сказ, _felo_, _блаз, _गंगू,
   {{0x25a52437,0x26c52438,0x61e12439,0x29260a39}},	//   _full_, _gelo_, full, štač_,
   {{0x61e1243a,0x774a0065,0x521300ae,0x25a5243b}},	//   gull, _gàbọ, бдэт, _gull_,
   {{0x26c50b27,0x613f0216,0x64a61502,0xa159243c}},	//   _zelo_, _gëll, _сада, таму_,
   {{0x543600b1,0x26c5243d,0x2d80243e,0x2612080f}},	//   _حرار, _yelo_, dlie_, थिवी_,
   {{0xa2940f1e,0x2d80243f,0x26c50072,0x92942440}},	//   _калі, elie_, _xelo_, _калц,
   {{0x61e12441,0x1df8055b,0x25a50072,0x23d400b6}},	//   cull, леры_, _xull_, _दिँद,
   {{0x2d800982,0x20090044,0x7bcd2442,0x7e7e0ac9}},	//   glie_, _tsai_, tsau, _dypp,
   {{0x20092443,0x5c990109,0x3b551722,0x6fd9074c}},	// [19f0] _usai_, ткая_, акар, _भटिं,
   {{0x7bcd2444,0x3ea10124,0x6d5a2445,0x7ae500ca}},	//   rsau, _ught_, étar, ught,
   {{0x7bcd2446,0x2d800b4e,0x26c52447,0x63a4028d}},	//   ssau, blie_, _relo_, _èinf,
   {{0x26c5042d,0x98c700e3,0x25a52448,0x78a42449}},	//   _selo_, اغان, _rull_, živn,
   {{0xf77116cc,0x26c50303,0x25a5013d,0x61e1244a}},	//   يات_, _pelo_, _sull_, zull,
   {{0x61e122ea,0x7bda00ca,0xaae2030b,0x7bc00052}},	//   yull, _בקשו, _पाएक, _çmua,
   {{0x6b4002dc,0x26c5244b,0x7d0f244c,0xb0b50789}},	//   _mögl, _velo_, _kacs, ंडाग,
   {{0xb4df244d,0x613f00dd,0x61e1244e,0x25a50472}},	//   तले_, _qëll, vull, _vull_,
   {{0xa3e50e50,0xa3dc007d,0x9345244f,0x26c52450}},	//   बंध_, तंग_, иние, _telo_,
   {{0x61e12451,0x63a9023b,0x25a52452,0x00000000}},	//   tull, rqen, _tull_, --,
   {{0xe1262453,0x00000000,0x00000000,0x00000000}},	//   амни, --, --, --,
   {{0xa3e50789,0x7d0f2454,0x6579063d,0x00000000}},	//   बंद_, _nacs, _ukwh, --,
   {{0x22590034,0x31690383,0x00000000,0x00000000}},	//   ńsk_, _djaz_, --, --,
   {{0x61e12455,0x3f9e2456,0x8f761ba7,0x00000000}},	//   pull, ötu_, румі, --,
   {{0x3f8400d9,0x427900c1,0xed5a1278,0x3cb30294}},	//   ēmu_, _באַג, вов_, _ụzụ_,
   {{0x20562457,0x212005db,0xdca32458,0x637d0113}},	//   _втор, _unih_, жати, gènv,
   {{0x0c260058,0xe4f809a1,0x7d0f03a8,0x67210090}},	// [1a00] шман, ्जति_, _dacs, _onlj,
   {{0x973c14f3,0x7e7e2459,0x7d0f0503,0x00000000}},	//   _kiće, _typp, _eacs, --,
   {{0x6edb00a1,0xa3e5245a,0x2d80014b,0xf1ab0e4c}},	//   _בחיפ, बूत_, plie_, _घूमन,
   {{0xebe60e3f,0xaae202e8,0xdb06023b,0x387f0113}},	//   _комп, _पाकक, _kukë, _byur_,
   {{0x7d04245b,0xfaa6245c,0x88bd0034,0x6d46245d}},	//   meis, _ваго, _pośr, _ilka,
   {{0x7d04245e,0x26120aa6,0xed590220,0x6d4601ee}},	//   leis, थिली_, ďže_, _hlka,
   {{0x645d003e,0x1c0e02d5,0x00000000,0x00000000}},	//   úsin, सिकल_, --, --,
   {{0x7d040084,0x2b5803c3,0x00000000,0x00000000}},	//   neis, _hmrc_, --, --,
   {{0xc34a013d,0xa4140081,0x6aa9245f,0x66e61009}},	//   вяне_, িহ্য_, _şefi, _воза,
   {{0x7d042460,0x79820054,0x973c2461,0x60d62462}},	//   heis, llow, _biće, _adym,
   {{0x7d041736,0x6b400212,0x6d46007b,0x00000000}},	//   keis, _rögl, _olka, --,
   {{0x85560103,0x9257007b,0xdb060052,0x7d04007b}},	//   _خیبر_, рают_, _bukë, jeis,
   {{0x3202030b,0x75222463,0x74160504,0x661a007e}},	//   ňky_, _inoz, _خوشا, _hrtk,
   {{0x6d462464,0xc05800d6,0x973c00c4,0x661a0094}},	//   _alka, рію_, _fiće, _krtk,
   {{0xd37802e6,0x7d042465,0x7982007f,0x637d00b3}},	//   moć_, feis, klow, gènu,
   {{0x929b0054,0x7d042466,0x7c87014d,0xe29b1777}},	//   _ביות, geis, аузе, _בשור,
   {{0xdfd100e3,0xfaa72467,0x69d80146,0x63a4028d}},	// [1a10] _عيد_, ашен, áven, _èind,
   {{0x6d462468,0xd3780542,0x98b80325,0xd5a40103}},	//   _elka, noć_, _ērā_, _يہ_,
   {{0x3f8300e9,0x7d0f2469,0x387f171d,0x98bf0580}},	//   mlju_, _tacs, _syur_, _smuđ_,
   {{0xae1a00a1,0x3e16006e,0xfcab0281,0x7982246a}},	//   _עורכ, _פֿיל_, _جادو_, glow,
   {{0x1b0f0081,0xd3780ac3,0xf807246b,0x00000000}},	//   সাবে_, koć_, рчен, --,
   {{0xd246003f,0x38ad0065,0x7522246c,0xdb230421}},	//   _فن_, _bóró_, _anoz, _بوسی,
   {{0x6eba0285,0x79820034,0x69de007e,0x00000000}},	//   ्रतु, blow, crpe, --,
   {{0x8938246d,0x7bdf00ee,0x637d01dc,0x00000000}},	//   _кпсс_, orqu, hènt, --,
   {{0x68fb14a2,0x973c0095,0x52e200c3,0x46150e27}},	//   _ibud, _siće, पलूस, _گوار,
   {{0x27ff00d1,0x38ad0139,0x973c0995,0x7522246e}},	//   _ipun_, _fóró_, _piće, _enoz,
   {{0x7d04246f,0x3f830357,0x00000000,0x00000000}},	//   yeis, dlju_, --, --,
   {{0x752200e7,0x973c007e,0xdb060216,0x9f420113}},	//   _gnoz, _viće, _pukë, muké_,
   {{0x442904ea,0x7d042470,0x057400e3,0xd3a708f9}},	//   _ça_, veis, _بالد, _треп,
   {{0x63bb0b19,0x02391dec,0x7d0402e2,0x59a709c3}},	//   mpun, _مثبت_, weis, गदार,
   {{0x68fb2471,0x7d042472,0x63bb2473,0x6ade0081}},	//   _obud, teis, lpun, ন্ডো,
   {{0x90c60832,0x68fb0129,0x2b5800c4,0x27ff044c}},	//   _убие, _nbud, _smrc_, _opun_,
   {{0x3f83084f,0x63bb2474,0x637d03a9,0x6d5800c6}},	// [1a20] blju_, npun, bènt, _įvad,
   {{0x7d041d2d,0x637d2475,0x00000000,0x00000000}},	//   seis, cènt, --, --,
   {{0x993a0426,0x7d042476,0xe9da0277,0x63a4016d}},	//   ляду_, peis, уке_, _éinv,
   {{0x63bb2477,0x68fb009c,0xe4470076,0x9f420113}},	//   kpun, _cbud, _فض_, duké_,
   {{0xe73a064f,0xbcfb0139,0x798202ac,0xacf70103}},	//   лед_, _ajéw, rlow, _اسپت,
   {{0x68fb2478,0x63bb2479,0x78250037,0x00000000}},	//   _ebud, dpun, تعمل, --,
   {{0xceb30341,0x8f9b0266,0xa96a247a,0xd6d9004d}},	//   ליג_, ניצי, _бива_, рті_,
   {{0x63bb0b8e,0xdb060113,0x93b40120,0x00000000}},	//   fpun, _sukè, обиц, --,
   {{0x63bb247b,0x2906024a,0x00000000,0x00000000}},	//   gpun, meoa_, --, --,
   {{0xdb04247c,0x27e602c9,0x68fb247d,0x1b0f0033}},	//   mpió, muon_, _zbud, সাথে_,
   {{0x3f8302e6,0x63bb0634,0x2e1805aa,0x4b7b0142}},	//   vlju_, apun, _nčf_, רטיג,
   {{0xddcb003d,0x1a9b006e,0xb17f0174,0x73e601b3}},	//   ġiżl, טייע, _ụụlọ_, _годз,
   {{0x637d0428,0x27e602c9,0x3f8309ac,0x96ac00b6}},	//   tènt, nuon_, tlju_, _चलाउ,
   {{0xc90500c3,0x2e1805aa,0xf1f701f3,0x3ea500f3}},	//   _रस्म_, _bčf_, جعیت_, ølt_,
   {{0x20000154,0x29060062,0x00000000,0x00000000}},	//   _epii_, keoa_, --, --,
   {{0x52830080,0x78a40ea3,0x27e60009,0x6b4002c3}},	//   _عليك, živj, kuon_, _högh,
   {{0xfd4f0028,0x26ce010a,0x3f83031a,0x29060a00}},	// [1a30] _khiế, kafo_, plju_, deoa_,
   {{0x27e60d58,0x00000000,0x00000000,0x00000000}},	//   duon_, --, --, --,
   {{0x27ff002d,0x3ce9247e,0x00000000,0x00000000}},	//   _spun_, pgav_, --, --,
   {{0x63bb247f,0x224a0206,0x00000000,0x00000000}},	//   ypun, úbky_, --, --,
   {{0x6aa900ae,0x6d4d18f0,0x65a701f9,0xdd980012}},	//   _şefu, mhaa, _műhe, _ышь_,
   {{0x70b52480,0xfd4f00de,0x6d4d2481,0x6d5f2482}},	//   ंडुल, _nhiế, lhaa, liqa,
   {{0x27ff0063,0xc5d5004d,0x00000000,0x00000000}},	//   _wpun_, ціль, --, --,
   {{0x63bb02e6,0x68fb2483,0x6d4d2484,0x9c130294}},	//   tpun, _ubud, nhaa, họmm,
   {{0x69da070a,0x63bb00c2,0x7c2d2485,0x1425004d}},	//   _åter, upun, nxar, ідом,
   {{0xfd4f00ef,0x6d4d2486,0x63bb2487,0xe1f90848}},	//   _chiế, hhaa, rpun, аго_,
   {{0x63bb2488,0x6d4d2489,0x6f0700b6,0xdced0a9e}},	//   spun, khaa, dejc, hlađ,
   {{0xdced2392,0xaca30139,0x63bb248a,0xd24e001c}},	//   klađ, _alọb, ppun, خچه_,
   {{0x6d4d248b,0x2329248c,0x297a0142,0x00000000}},	//   dhaa, _воли_, שטרא, --,
   {{0x6da6248d,0x6569248e,0x63ab0270,0x973c007e}},	//   жива, lneh, _iugn, _kića,
   {{0x63ab248f,0xa3e50251,0x417609b4,0xad5a18a2}},	//   _hugn, बूर_, _وابس, арах_,
   {{0x63a32490,0x6d4d2491,0x65692492,0x6d4300d3}},	//   _hinn, ghaa, nneh, _înal,
   {{0x63a32493,0x443f2494,0x442d2495,0xfd1f00de}},	// [1a40] _kinn, nyu_, nxe_, _nhìu_,
   {{0x63a32496,0x261a0ed3,0x62830bea,0x63ab028d}},	//   _jinn, _मछली_, _kyno, _mugn,
   {{0x443f1084,0x2d8c2497,0x63ab0149,0x9a6a00e3}},	//   hyu_, ïdes_, _lugn, جمال_,
   {{0x63a32498,0x6d4d2499,0x443f249a,0x98a6249b}},	//   _linn, chaa, kyu_, циде,
   {{0xd70a00ae,0x63ab0270,0xc8cc030b,0x65690031}},	//   инде_, _nugn, ारबट, dneh,
   {{0x1754249c,0xfaa61b82,0xd04e0092,0x501b040a}},	//   явля, _фаво, ükəs, יונו,
   {{0xd94622ee,0x628302ec,0x65690364,0x56930da5}},	//   _деви, _nyno, fneh, машт,
   {{0x6d4401b3,0x63ab249d,0x7d16249e,0x63a3152f}},	//   nkia, _bugn, ndys, _ainn,
   {{0x63a31db2,0xdce404a3,0xfd4f0019,0x443f249f}},	//   _binn, jnič, _phiế, gyu_,
   {{0x63a30514,0x6d5f0415,0x63ab24a0,0x321c24a1}},	//   _cinn, ziqa, _dugn, _prvy_,
   {{0x442d08a8,0x62830150,0x6d4400c2,0x63a31814}},	//   axe_, _cyno, kkia, _dinn,
   {{0x63a30102,0x62830150,0x80b502d5,0x443f24a2}},	//   _einn, _dyno, ंडें, byu_,
   {{0x63a324a3,0xfd4f00ef,0x63ab0036,0x7d1624a4}},	//   _finn, _thiế, _gugn, ddys,
   {{0x63a324a5,0xf4870281,0x26cc24a6,0x93770037}},	//   _ginn, _بامی, _jedo_, _وصور_,
   {{0x26cc24a7,0x6d5f24a8,0x6d4d24a9,0x628300f0}},	//   _medo_, tiqa, thaa, _gyno,
   {{0x91b700d0,0x63a324aa,0x61e8019c,0x7c2d01e9}},	//   _بطور_, _zinn, mudl, txar,
   {{0x6d4d24ab,0x6d5f061d,0x61e824ac,0xdce400d4}},	// [1a50] rhaa, riqa, ludl, cnič,
   {{0x6d4d24ad,0xce95013d,0x26cc02ef,0x6d5f019f}},	//   shaa, _напъ, _nedo_, siqa,
   {{0x60cd0496,0xdced0335,0x2fc907ac,0x61e802c9}},	//   _keam, slađ, _hwag_, nudl,
   {{0x6d5f0063,0x6d4400da,0x443f24ae,0x64400dd8}},	//   qiqa, ckia, yyu_, kymi,
   {{0x880700d0,0x6d5d24af,0x2be20d75,0x65690220}},	//   تظام, _imsa, _पिया, vneh,
   {{0x60cd0527,0x26cc24b0,0x61e80201,0x973c00c4}},	//   _leam, _cedo_, kudl, _pića,
   {{0x63a324b1,0x656924b2,0x63ab008a,0x61e802fa}},	//   _rinn, tneh, _sugn, judl,
   {{0x60cd22c4,0x442d0809,0x63ab24b3,0x63a31556}},	//   _neam, txe_, _pugn, _sinn,
   {{0x656924b4,0xb4bb10ed,0x442d0161,0xb4ab152c}},	//   rneh, _अभी_, uxe_, _खली_,
   {{0xdce424b5,0x442d08a8,0x6d9324b6,0x6d440a00}},	//   vnič, rxe_, lçad, zkia,
   {{0x63a324b7,0x6d4424b8,0x443f090a,0x60cd24b9}},	//   _vinn, ykia, syu_, _beam,
   {{0xdce400e9,0x6d9324ba,0x63ab24bb,0x60cd0037}},	//   tnič, nçad, _tugn, _ceam,
   {{0x60cd07bc,0xe81e0f53,0x823500cd,0x63ab07ac}},	//   _deam, पिया_, زرگا, _uugn,
   {{0x6d5d24bc,0x61e824bd,0x63a30441,0x987a00ca}},	//   _amsa, budl, _uinn, מארט,
   {{0x614624be,0x60cd1ab6,0x00000000,0x00000000}},	//   _нека, _feam, --, --,
   {{0x60cd24bf,0xdce411c1,0x6d440138,0x2d9524c0}},	//   _geam, pnič, ukia, друс,
   {{0x6d4424c1,0x2fc900f0,0x7d1624c2,0x00000000}},	// [1a60] rkia, _gwag_, rdys, --,
   {{0x78a900e5,0x6d5d24c3,0xbcfb0154,0x6d4424c4}},	//   _agev, _emsa, _améd, skia,
   {{0x644024c5,0x7ae324c6,0x00000000,0x00000000}},	//   zymi, ónta, --, --,
   {{0xdb0424c7,0x26cc24c8,0x00000000,0x00000000}},	//   rpiñ, _sedo_, --, --,
   {{0x2d82191c,0x26cc1333,0xdb040072,0x680101f9}},	//   _ikke_, _pedo_, spiñ, _rájö,
   {{0x6d93016d,0x64400206,0x00000000,0x00000000}},	//   açad, vymi, --, --,
   {{0x78ad02e6,0x26cc24c9,0x64401765,0xdb0f0103}},	//   žava, _vedo_, wymi, _utcá,
   {{0x644024ca,0x6d93020d,0x26cc0113,0x945d007f}},	//   tymi, rçag, _wedo_, jańs,
   {{0x7bd624cb,0x60cd24cc,0x00000000,0x00000000}},	//   nsyu, _ream, --, --,
   {{0x60cd24cd,0x6560009e,0x61e802c9,0x394624ce}},	//   _seam, simh, tudl, lkos_,
   {{0x628704f9,0x60cd007a,0x7bd6005c,0x6728003d}},	//   żjon, _peam, hsyu, _indj,
   {{0x3946013f,0xf8cc24cf,0x7bd606a8,0x00000000}},	//   nkos_, ारिय, ksyu, --,
   {{0x61e824d0,0x60cd24d1,0x394624d2,0xb97b00ca}},	//   sudl, _veam, ikos_, מנטי,
   {{0x2d82010a,0x973c0a39,0x673a0216,0x00000000}},	//   _akke_, _mićo, _jotj, --,
   {{0xf8cc0bd9,0x6fd9009d,0xfe700037,0x00000000}},	//   ाराय, _भटकं, هدف_, --,
   {{0x2d5824d3,0x6b400088,0x2fc900f9,0x673a0381}},	//   пись_, _mögu, _twag_, _lotj,
   {{0x6b400088,0x67280dd9,0xb0c307d5,0x2129037a}},	// [1a70] _lögu, _ondj, _व्यग, _inah_,
   {{0x2d8224d4,0xe1ab034c,0x2aab0291,0x00000000}},	//   _ekke_, _घूँघ, стао_, --,
   {{0x7f3c00a1,0x62860034,0x442b0023,0x394602ac}},	//   _לעזו, ękow, ̣c_, fkos_,
   {{0x6d5d24d5,0x67280095,0xbcfb09b3,0x39460510}},	//   _umsa, _andj, _ejér, gkos_,
   {{0x248624d6,0x6d9324d7,0x2ba70096,0x673a0fcf}},	//   _nyom_, rçad, _कंटा, _botj,
   {{0x2be216e2,0x66e500ae,0x00000000,0x00000000}},	//   _पिता, фока, --, --,
   {{0x24860113,0xf8ae0018,0x673a04e9,0xe51e0ee0}},	//   _ayom_, اکہ_, _dotj, _मोहि_,
   {{0x25de049d,0xe3b924d8,0xf99312eb,0x6b400088}},	//   _गिरी_, оби_, _سبز_, _dögu,
   {{0x394d24d9,0x395f24da,0x25a624db,0x2d890113}},	//   _iles_, _imus_, _diol_, ilae_,
   {{0x673a0a39,0xaadd0096,0xc24524dc,0x00000000}},	//   _gotj, मणिक, днок, --,
   {{0x779012eb,0x6b9b0036,0x25a624dd,0x69d70072}},	//   _حیوا, _èugu, _fiol_, nsxe,
   {{0x69d8001f,0x2ec60e19,0x6b400149,0xb05b0fe8}},	//   ávei, वर्त, _högt, rbän,
   {{0x657c01f9,0x00000000,0x00000000,0x00000000}},	//   _írha, --, --, --,
   {{0x394d24de,0x62650058,0x776324df,0x2d89084e}},	//   _lles_, _овла, ninx, elae_,
   {{0x8fa31357,0x394d0167,0x945d007f,0x00000000}},	//   таре, _oles_, pańs, --,
   {{0xa187008f,0x00000000,0x00000000,0x00000000}},	//   _обща_, --, --, --,
   {{0x248601fa,0x00000000,0x00000000,0x00000000}},	// [1a80] _xyom_, --, --, --,
   {{0x394d002d,0x7bd6005a,0x395f24e0,0xe84102c6}},	//   _ales_, rsyu, _amus_, ůběž,
   {{0x6b5201c5,0x973c007e,0x776301ff,0x394624e1}},	//   _lægg, _sićo, dinx, tkos_,
   {{0x3946013f,0x395f002b,0x9cb6001c,0x394d24e2}},	//   ukos_, _cmus_, _زمست, _cles_,
   {{0x394624e3,0x6b400088,0x77630072,0x00000000}},	//   rkos_, _sögu, finx, --,
   {{0x394d0ba0,0xd5ba24e4,0x394624e5,0x25a624e6}},	//   _eles_, оси_, skos_, _siol_,
   {{0x394d24e7,0x09d80081,0xfbb00033,0xda650037}},	//   _fles_, _সহকা, _ছবিত, _كافي,
   {{0xb4e80557,0x2d800036,0x00000000,0x00000000}},	//   बले_, noie_, --, --,
   {{0xd90d1e49,0x25a60df4,0xdc1100a7,0x00000000}},	//   _دین_, _viol_, _məğl, --,
   {{0x25f60034,0x628f0034,0x764324e8,0x00000000}},	//   _एमपी_, ęcon, byny, --,
   {{0x6b400222,0x2129005c,0x25a60072,0x3b1800fc}},	//   _högs, _pnah_, _tiol_, _marq_,
   {{0x78a400d4,0x2d470231,0x056624e9,0x00000000}},	//   živu, _põem_, _ювен, --,
   {{0x6d43002d,0x59ce009d,0x63a40036,0x104b004d}},	//   _înai, हीतर, _èino, іями_,
   {{0x2bb5110f,0x00000000,0x00000000,0x00000000}},	//   _अंबा, --, --, --,
   {{0x27e624ea,0x3da701b3,0x6f1703a9,0xbf9b084e}},	//   hron_, драб, _vaxc, fwêr,
   {{0xa3e5007d,0x98a4022b,0x21290063,0xbf9b02ac}},	//   बूक_, _anmč_, _unah_, gwêr,
   {{0x1eab0037,0x6f17037a,0x21f803a9,0x00000000}},	// [1a90] _وادي_, _taxc, léh_, --,
   {{0xa3e624eb,0x6ec00096,0x7f5924ec,0xb4bb02d5}},	//   _बटन_, वडणु, _хаос_, _अभ्_,
   {{0x27e60890,0x21f801dc,0x27e000e3,0xab840f50}},	//   eron_, néh_, áinn_, тутк,
   {{0x26de02c9,0x0e9a00ca,0xab5b0233,0x00000000}},	//   _adto_, _משתל, _stüd, --,
   {{0x7d0d24ed,0x78ad08a9,0xf210009f,0x6d4f028d}},	//   meas, žavo, ़बड़_, _ilca,
   {{0xf77302fc,0xae03009d,0x7d0d24ee,0x76430084}},	//   خاص_, _लहान_, leas, tyny,
   {{0x27e624ef,0x776324f0,0xfbb50851,0xb9050033}},	//   aron_, rinx, _अंडम, _বউ_,
   {{0x76430a4f,0x7d0d24f1,0x00000000,0x00000000}},	//   ryny, neas, --, --,
   {{0x764300c2,0x99850103,0xf8b20266,0x3160022b}},	//   syny, _élő_, _תשמ_, _rmiz_,
   {{0x7d0d24f2,0x6b400222,0x6b5202b6,0x2be224f3}},	//   heas, _högr, _vægg, _पिसा,
   {{0x26c702dd,0x7d0d0084,0xe1f6002d,0x6d4f24f4}},	//   mbno_, keas, нгэ_, _olca,
   {{0x361a00a1,0x261100c4,0x7d0d044c,0xdb070216}},	//   _מועד, _išo_, jeas, _bijë,
   {{0x2d8024f5,0xdb06045e,0x7d0d24f6,0xab6403e0}},	//   voie_, _luká, deas, lmüş,
   {{0x6d4f0e4d,0x6b400088,0x21f801dc,0x3eac181f}},	//   _alca, _lögr, béh_, ødt_,
   {{0x23650222,0x7d0d036b,0x6b52181f,0x2d9624f7}},	//   milj_, feas, _jæge, ерас,
   {{0x1de10980,0xf11a0cd2,0x7d0d24f8,0x00000000}},	//   _फिरत, _رغبت_, geas, --,
   {{0x6b5201c5,0xec770012,0x63ad028d,0xed57001f}},	// [1aa0] _læge, епт_, _èand, хот_,
   {{0xaca40174,0x27e624f9,0x2d800036,0x06e50033}},	//   _nzụt, vron_, soie_, প্তি,
   {{0x2d730542,0x7d0d24fa,0xeef700ca,0xdb070113}},	//   mćen_, beas, _אמיר_, _mijè,
   {{0x27e624fb,0xaca40294,0x6d4f009c,0xdb060437}},	//   tron_, _azụt, _glca, _duká,
   {{0x27e624fc,0x58831855,0x00000000,0x00000000}},	//   uron_, лыша, --, --,
   {{0x7bc424fd,0xf0930130,0x27e624fe,0x27e024ff}},	//   mpiu, אנד_, rron_, šino_,
   {{0x387200d3,0x27e62500,0x06cf0033,0xe1e70397}},	//   _ţară_, sron_, _রাশি, _حس_,
   {{0xe9a30b9c,0x69dc209a,0xdb1d0154,0x27e62501}},	//   _басп, _ivre, _atsè, pron_,
   {{0xb60300d9,0x888100cd,0x7bc40063,0xd7ca0076}},	//   āšan, _پیون, npiu, _رواه_,
   {{0x26de0124,0x77830915,0x973c007e,0x7d0d00ae}},	//   _udto_, _блуз, _mićk, zeas,
   {{0xdb072502,0x2fc0030a,0x00000000,0x00000000}},	//   _dijè, _atig_, --, --,
   {{0x613f00dd,0x29020149,0xd04600a7,0x9f4b0216}},	//   _pëlq, _ökad_, lakə, pucë_,
   {{0x656200f9,0xe53b00ca,0x2bb50980,0x7d0d020a}},	//   _imoh, _מתאר, _अंधा, veas,
   {{0x4ea72503,0xdb070052,0xd0ed0096,0x69dc0117}},	//   ерба, _vijë, _झाकण_, _ovre,
   {{0x3ea52504,0x7d0d2505,0xdcfd00bd,0xd24f23b8}},	//   ält_, teas, _jisħ, _сц_,
   {{0xdb06025b,0x2bb5114d,0x3ceb00c3,0x6ab90d77}},	//   _ruká, _अंदा, टलें_, इड्र,
   {{0x69dc19a6,0xe7cf0034,0x7d0d2506,0x00000000}},	// [1ab0] _avre, _सौंप, reas, --,
   {{0x7d0d2507,0x20090167,0x64c402c6,0x00000000}},	//   seas, _ipai_, lčič, --,
   {{0x7d0d2508,0x26c7033b,0xdcfd2509,0x69dc05db}},	//   peas, vbno_, _eksā, _cvre,
   {{0x3f83250a,0x64c4103b,0x2139250b,0x7982250c}},	//   loju_, nčič, njsh_, goow,
   {{0xb909250d,0x69dc250e,0x399e02c6,0xa2b800b6}},	//   _मय_, _evre, _růst_, ोरञ्,
   {{0x65620124,0x3f83250f,0x00000000,0x00000000}},	//   _amoh, noju_, --, --,
   {{0xc8f50465,0xda050f53,0xf77016c4,0xc447010d}},	//   _извъ, _रहित_, حان_, کیشن_,
   {{0xab6403e0,0x7c2000c4,0xdb0f0113,0x2ebf0b76}},	//   rmüş, _šmri, _sucè, ्रुत,
   {{0x290f2510,0x3f832511,0x2365031a,0x98a400e8}},	//   mega_, koju_, tilj_, _domē_,
   {{0x290f2512,0x65621195,0x628a0ac9,0x3f8300c6}},	//   lega_, _emoh, _byfo, joju_,
   {{0x2fc02085,0x628a0150,0x63aa00bd,0xa3e502d5}},	//   _stig_, _cyfo, _difn, बूज_,
   {{0x290f0b27,0x291d2513,0x628a0150,0x50460831}},	//   nega_, ndwa_, _dyfo, вемб,
   {{0x61e82514,0x659401b6,0xc8da00d7,0x00000000}},	//   ardl, _сацу, וקרט, --,
   {{0x290f2515,0xdf1502ec,0x3f830880,0x2d9901ee}},	//   hega_, льсь, goju_, _ahse_,
   {{0x290f0b27,0x5ed400c7,0x628a00f0,0x200901c8}},	//   kega_, _তাদে, _gyfo, _epai_,
   {{0x290f2516,0x247e0134,0x7c290357,0x00000000}},	//   jega_, ịme_, _šera, --,
   {{0xc4d20130,0x290f0006,0x6da30012,0x291d0a15}},	// [1ac0] יגן_, dega_, рита, ddwa_,
   {{0x7bc4004b,0x6d9300b3,0x00000000,0x00000000}},	//   rpiu, rçaa, --, --,
   {{0xab5b02e2,0xa9a6008f,0xe8fa01b3,0xbea600f6}},	//   _stüc, вижд, дле_, _јанк,
   {{0x290f2517,0xd7e6224a,0x81bc01d3,0x6d932518}},	//   gega_, віко, lvēc, lçan,
   {{0xa41c00c7,0x79820188,0xe7b32519,0x00000000}},	//   _তথ্য_, roow, لمند, --,
   {{0x6d93251a,0xbcfb000d,0x69d80618,0x69c501fa}},	//   nçan, _jmén, áves, bphe,
   {{0x6f030b88,0x69dc1419,0x290f251b,0x69c50441}},	//   _önce, _uvre, bega_, cphe,
   {{0x290f08a9,0x38c809e5,0x151400d3,0xd9430950}},	//   cega_, _ساری_, удия, _кеси,
   {{0xa8870077,0x98a317a6,0xdb0f002b,0x49170096}},	//   _айта_, _вите, _sucé, _नसतो_,
   {{0x5fdc02b0,0x2bb5009f,0xdcfd0078,0x00000000}},	//   _बिजल, _अंसा, _tisħ, --,
   {{0xe737251c,0x3f83251d,0x6d56026d,0x00000000}},	//   _шеф_, voju_, khya, --,
   {{0xbcfb0257,0x27e904fa,0xfd1f0139,0x628a0094}},	//   _amén, šane_, _akìn_, _vyfo,
   {{0xc0ab06fa,0x5064251e,0x6d56251f,0x3f832520}},	//   بادل_, атра, dhya, toju_,
   {{0x44262521,0x628a2522,0x69c52523,0x973c0559}},	//   _iro_, _tyfo, yphe, _bići,
   {{0x3f832524,0x1df81402,0x00000000,0x00000000}},	//   roju_, керы_, --, --,
   {{0x44262525,0x63ad0451,0x6e2504e9,0xf8cc1677}},	//   _kro_, _èanc, _vrhb, ारोप,
   {{0x290f2526,0x27e00ebd,0x442603a9,0x69d002d5}},	// [1ad0] vega_, šinj_, _jro_, डीसी,
   {{0x69c52527,0x44262528,0x3b542529,0x290f0079}},	//   tphe, _mro_, акур, wega_,
   {{0x290f252a,0x7c260364,0x00000000,0x00000000}},	//   tega_, _erkr, --, --,
   {{0x4426252b,0xa6cf0033,0x00000000,0x00000000}},	//   _oro_, _রাইট, --, --,
   {{0x4426252c,0x290f252d,0x6d4d252e,0x69c5252f}},	//   _nro_, rega_, mkaa, sphe,
   {{0x290f05a7,0x6d4d025e,0x778400f7,0x69c52530}},	//   sega_, lkaa, аліз, pphe,
   {{0x290f1abe,0x6446004d,0x7f3c006e,0x69d80218}},	//   pega_, økin, ועגו, šver,
   {{0xdb0d11c4,0x6d4d2531,0x7d1d2532,0x00000000}},	//   mpañ, nkaa, _jass, --,
   {{0x7d1d0d63,0x44262533,0x79890134,0x38600037}},	//   _mass, _cro_, _ikew, úirt_,
   {{0x7d1d2534,0x96ca0455,0xdced0039,0x44262535}},	//   _lass, _स्पॉ, dnač, _dro_,
   {{0x44262536,0x6d4d2537,0xfb1600c1,0xe6590037}},	//   _ero_, kkaa, אַכט_, _ثلاث_,
   {{0x7d1d2538,0x442600f0,0x6d4d2539,0x7bc100d2}},	//   _nass, _fro_, jkaa, _člun,
   {{0x4426253a,0x6d4d008a,0x65690084,0x79890051}},	//   _gro_, dkaa, mieh, _mkew,
   {{0x973c14f3,0x06e50081,0x6569253b,0x645b0239}},	//   _pići, প্রি, lieh, mzui,
   {{0x7d1d253c,0xfce62348,0x6d93253d,0xb06300aa}},	//   _bass, лово, rçan, äärs,
   {{0x7d1d253e,0x6d4d253f,0x79890294,0xbacd0033}},	//   _cass, gkaa, _nkew, _লাগছ,
   {{0x5f7600cd,0x64490b8b,0x645b01cb,0xdce400c4}},	// [1ae0] _مادر, nyei, nzui, hnić,
   {{0x6d56023f,0x79892540,0x799b0d2a,0x6d9303e0}},	//   shya, _akew, _ahuw, lçal,
   {{0x7d1d2541,0x6d4d0188,0x6e4609b9,0xdce414f3}},	//   _fass, bkaa, _сенз, jnić,
   {{0x3940003e,0x6d932542,0x799b0350,0x753b083e}},	//   ðis_, nçal, _chuw, jjuz,
   {{0x6f1e00fb,0x799b00bf,0x65690407,0x48e32543}},	//   _kapc, _dhuw, dieh, сочв,
   {{0x779100d0,0x7c2406d1,0x79890134,0x7d1d1404}},	//   قیقا, mvir, _ekew, _zass,
   {{0xdced18cc,0x44262544,0x1c1c0469,0x63a40036}},	//   znač, _sro_, निकल_, _èini,
   {{0x44261000,0x69de2545,0x7414177a,0x645b01c0}},	//   _pro_, mspe, لوبا, fzui,
   {{0x7c242546,0x69de2547,0x136a0476,0x06f60241}},	//   nvir, lspe, ешни_, _مساج,
   {{0xa3e510ed,0xbcfb025a,0xe3bf03be,0x07a60291}},	//   _फिर_, _amél, íña_, _сазн,
   {{0xe13502fd,0x69de2548,0x92942549,0x65690220}},	//   анны, nspe, ранц, bieh,
   {{0x25f3007d,0x4426254a,0x69de00e3,0x65690220}},	//   ्झरी_, _tro_, ispe, cieh,
   {{0x442602dd,0x644600aa,0x7d0413ea,0x60d6254b}},	//   _uro_, äkid, dfis, _deym,
   {{0x7d1d254c,0x2b8f02e2,0x69de254d,0x7c24254e}},	//   _sass, rück_, kspe, dvir,
   {{0x7d04254f,0xd9040068,0x6d4d2550,0x8d770604}},	//   ffis, _ٹی_, tkaa, هارا,
   {{0x629800e9,0x69de0bab,0x7d1d0078,0x9d181a57}},	//   _izvo, dspe, _qass, лост_,
   {{0x6d4d025e,0x81b600c7,0x7d1d2551,0x69de2552}},	// [1af0] rkaa, _ছবি_, _vass, espe,
   {{0x7d1d2553,0x6d4d2554,0x656902e2,0x799b0d2a}},	//   _wass, skaa, zieh, _shuw,
   {{0x7d1d2555,0x69de2556,0x6d4d2557,0x7c2400ce}},	//   _tass, gspe, pkaa, avir,
   {{0xa3e504f1,0xe0e70033,0x973c031a,0xdce40034}},	//   _फिल_, গ্রহ_, _miću, knię,
   {{0x6d932558,0x69de00ae,0xdb0d0328,0x5fb50285}},	//   nçam, aspe, spañ, ंदिल,
   {{0x6d5801b3,0xb8ec0789,0x99d70f36,0x5fbc006e}},	//   _įvai, _श्_, _مترا, עצונ,
   {{0xb8db00c7,0x65692559,0xf8c90257,0xeef800ca}},	//   _আজ_, tieh, _créé_, אמור_,
   {{0x7545255a,0xdce40335,0x79a40396,0x7bdf255b}},	//   рниз, rnić, _груе, osqu,
   {{0xdb0f255c,0x65690407,0x7bdf042c,0xdce4255d}},	//   _lucí, rieh, nsqu, snić,
   {{0x7bdf0161,0xe787255e,0x60d6255f,0x65692560}},	//   isqu, _субо, _seym, sieh,
   {{0x291f00aa,0x7d042561,0x656901c0,0x7c29215a}},	//   _kaua_, yfis, pieh, _šerl,
   {{0x6026022a,0x291f034f,0xc4f80037,0x6f1e2562}},	//   адма, _jaua_, _معها_, _sapc,
   {{0xb4c306e4,0x291f0051,0x6d930511,0x60db01cd}},	//   ्री_, _maua_, rçal, ðuma,
   {{0x2d8b030b,0x69de2563,0x644600c2,0x25af007e}},	//   _akce_, yspe, äkie, _higl_,
   {{0x7d040dfd,0xbea60ebf,0x6d9305fe,0x60d62564}},	//   tfis, равк, pçal, _teym,
   {{0x7c2401b3,0x27e0011d,0x69de032e,0x00000000}},	//   tvir, šini_, vspe, --,
   {{0xdee61f0d,0x7d040088,0xab662565,0x63bb019f}},	// [1b00] _копи, rfis, авал, nqun,
   {{0x69de2566,0x68fb2567,0xb4c30be4,0xd00f015a}},	//   tspe, _acud, ्रु_, _کلی_,
   {{0xbd8a003f,0x399c00e3,0x69de2568,0x200200bc}},	//   _لندن_, híse_, uspe, ltki_,
   {{0x6d4300d3,0x68fb009c,0x63a4028d,0xc7c62569}},	//   _înap, _ccud, _èinv, аски,
   {{0x779412eb,0x27e0152f,0xdb0d01cd,0xdb0f044c}},	//   میرا, éin_, ppað, _ducâ,
   {{0x69de256a,0x2d92256b,0x7bc6007b,0x00000000}},	//   pspe, llye_, _itku, --,
   {{0xdb0e023b,0x25af007e,0xcb67002d,0xb4c30b2b}},	//   _libë, _bigl_, _таре_, ्रू_,
   {{0x27e90b4b,0x399c0037,0xa5340b1b,0x291f0634}},	//   šana_, físe_, снич, _gaua_,
   {{0x973c00cc,0xd497002d,0x8cd709a1,0x00000000}},	//   _siću, ирь_, बरतो, --,
   {{0x3944256c,0x316b0034,0xb354256d,0x291f024a}},	//   _homs_, wicz_, скош, _zaua_,
   {{0xe81e218b,0x44e80081,0x7c29003d,0x291f0239}},	//   पिका_, ক্ষক_, _ġerm, _yaua_,
   {{0x7bc602e6,0x26dc256e,0x2b061687,0x8c480511}},	//   _otku, lavo_, स्तु_, _kağı,
   {{0xb4d21981,0x7afc00cc,0x1b1d0033,0x3944256f}},	//   वरी_, _ocrt, নাতে_, _moms_,
   {{0x2005003d,0x26dc2570,0xdb0e0216,0x6d932571}},	//   ċli_, navo_, _dibë, rçam,
   {{0x139b040a,0x539b00a1,0x629800cc,0xc1790138}},	//   _שבוע, _שיוו, _uzvo, urės_,
   {{0x39442572,0x3a2d2573,0x00000000,0x00000000}},	//   _noms_, _čep_, --, --,
   {{0x60dd00f9,0x291f09a1,0x26dc2574,0xdb0e0154}},	// [1b10] masm, _raua_, kavo_, _kibè,
   {{0x7bdf025a,0x26dc2575,0x68fb00e5,0x2ef52576}},	//   rsqu, javo_, _scud, _узор,
   {{0x26dc013f,0x79a705da,0x6f15034f,0x1ddb023a}},	//   davo_, арде, mezc, _बबित,
   {{0x39442577,0x8c4808bb,0xdb0e06a3,0xaca30134}},	//   _coms_, _bağı, _libè, _anụb,
   {{0xdc350132,0x27ff014b,0xec350142,0x26dc004b}},	//   _האָט_, _qqun_, _האָר_, favo_,
   {{0x8c4807d1,0x6dbc0087,0xf3fe0081,0x6f152578}},	//   _dağı, _očal, ্টার_, nezc,
   {{0x6b52052f,0x291f2579,0xb345016d,0xcf580327}},	//   _mægl, _taua_, _loçã, שבות_,
   {{0xb4c30c3c,0xe3bf03be,0x741500e3,0x5e7800ca}},	//   ्रे_, íño_, موعا, יתון_,
   {{0x69c70ea3,0x2120048e,0x26dc0087,0xb3450161}},	//   _htje, _raih_, bavo_, _noçã,
   {{0xda0e1179,0x26dc0451,0x4374004d,0x00000000}},	//   _सहमत_, cavo_, жуют, --,
   {{0xe69500e3,0x6f150a43,0xdb0e0113,0x00000000}},	//   _الاد, dezc, _dibè, --,
   {{0x6721257a,0xf652028c,0x8c4807aa,0x04c900b9}},	//   _halj, _מצב_, _yağı, _صوتي_,
   {{0x6721257b,0xc88200a7,0x9879006e,0x297a0142}},	//   _kalj, _peşə_, ראָט, רטרא,
   {{0x2002257c,0x69c70268,0x67210167,0x00000000}},	//   rtki_, _otje, _jalj, --,
   {{0xed5a0b99,0x2002257d,0x6b6f0138,0xaea90037}},	//   гов_, stki_, _mėgė, لطفل_,
   {{0x26dc043c,0x7afc02ef,0xc21200ca,0x60dd0850}},	//   zavo_, _scrt, _זהה_, casm,
   {{0x3944257e,0xdca30565,0x6fb2007f,0x69c71341}},	// [1b20] _roms_, зати, _इंटू, _atje,
   {{0x39440934,0xb05b0149,0x6721257f,0xef1a0831}},	//   _soms_, rbät, _nalj, _смо_,
   {{0x260108a8,0x26dc0138,0x3f8a2580,0x8c480342}},	//   jóo_, vavo_, mobu_, _sağı,
   {{0x3f8a08dd,0xd91000d0,0xb4c32581,0x69c30037}},	//   lobu_, بیر_, ्रो_, ínea,
   {{0x7d16008a,0xdb0e0257,0x6d460113,0x2be20c54}},	//   meys, _libé, _ioka, _पिटा,
   {{0xa09b0130,0x06d800c7,0x7d162582,0x6d460449}},	//   ניסט, _সাহি, leys, _hoka,
   {{0x6d462583,0x39442584,0x60c404c3,0x6dbc0031}},	//   _koka, _toms_, _ofim, _očam,
   {{0x6d462585,0x7d162586,0x26dc2587,0x8c48013c}},	//   _joka, neys, savo_, _tağı,
   {{0x6d462588,0x6721023b,0x26dc0077,0x00000000}},	//   _moka, _falj, pavo_, --,
   {{0x6d462589,0x69c104ea,0x8c1b00a1,0x7d160188}},	//   _loka, _élec, נויי, heys,
   {{0x60c908a8,0x60dd0a00,0x7179215d,0x61151402}},	//   ñemo, tasm, ибор_, одну,
   {{0x27e0005f,0xdb0e00d1,0x6d46258a,0xb3450131}},	//   šinu_, _dibé, _noka, _poçã,
   {{0xc058258b,0xd4670114,0x60dd258c,0x7d16258d}},	//   бір_, _лице_, rasm, deys,
   {{0x3f8a258e,0xc058097a,0x2bdb0861,0x60dd258f}},	//   gobu_, сію_, मीफा, sasm,
   {{0x6f150890,0xdb0e0113,0x6d9300ee,0xa2b70285}},	//   rezc, _gibé, lçai, ोडर्,
   {{0x22ae0253,0x7d16008a,0x6d4603e3,0x2b9411d0}},	//   mək_, geys, _coka, bäck_,
   {{0x6d9304ea,0x69c700f2,0x7ff70037,0x63a40036}},	// [1b30] nçai, _stje, _اسعا, _èins,
   {{0x8aa70161,0x00000000,0x00000000,0x00000000}},	//   бред, --, --, --,
   {{0x7d160188,0x2bb50096,0x26010072,0xc8b50fe9}},	//   beys, _अंका, xóo_, ослы,
   {{0x6dbc005f,0x75220181,0x7d16008c,0x00000000}},	//   _očaj, _naoz, ceys, --,
   {{0x672113e3,0x261b007d,0xf80700d3,0x387f02a1}},	//   _palj, _मनही_, счен, _qxur_,
   {{0x2fc90124,0x27e90128,0x7bcd2590,0xdb07037a}},	//   _mtag_, šano_, mpau, _fijá,
   {{0x672102e6,0x69c70ea3,0x672304a3,0x6d460517}},	//   _valj, _utje, rdnj, _yoka,
   {{0x22ae0092,0xdb0e2591,0x67212592,0x195800ae}},	//   dək_, _ribé, _walj, _ласы_,
   {{0xe3b60ff8,0x7bcd2593,0x67212594,0x27e000e3}},	//   обы_, npau, _talj, áint_,
   {{0x98ad0220,0x798b2595,0x8c1c00ca,0x43690077}},	//   _hneď_, logw, רוזי, раон_,
   {{0xe299153d,0x4427037f,0x7d160188,0x2fc901cb}},	//   ран_, _گراف, yeys, _atag_,
   {{0x7d160188,0xe4350281,0x00000000,0x00000000}},	//   xeys, _وفاد, --, --,
   {{0x6d462596,0x2bb52183,0x7bcd2597,0x656b2598}},	//   _roka, _अंगा, jpau, _imgh,
   {{0x6d462599,0xbf9b0396,0x83fd0018,0xdb0e259a}},	//   _soka, stên, rződ, _tibé,
   {{0x22ae0253,0x3f8a025b,0x61460424,0x7d16259b}},	//   cək_, robu_, _мека, teys,
   {{0x68e900d1,0x2b94042c,0x3f8a259c,0xb05b02c3}},	//   _nded, päck_, sobu_, rbär,
   {{0x7d16259d,0x7bcd259e,0x6ab202d5,0xed57001f}},	// [1b40] reys, gpau, जश्र, цот_,
   {{0x68e9259f,0x7d16008c,0x6d46007f,0x290d044c}},	//   _aded, seys, _woka, _abea_,
   {{0x32050054,0x6d4625a0,0xaca40af0,0xc8ca25a1}},	//   ntly_, _toka, _ilọs, لوان_,
   {{0xc27a006e,0x7d160188,0x25ef0096,0x798b25a2}},	//   ברעי, qeys, ींनी_, gogw,
   {{0x8816177a,0x68e925a3,0x6dbc0220,0x3ce0023e}},	//   تباط, _dded, _očak, maiv_,
   {{0x05ea25a4,0xe3a7048f,0x68e9063d,0xba090033}},	//   афии_, _زر_, _eded, রয়েড_,
   {{0xd6d90a8d,0xda0e0782,0xd5b702fd,0x79830294}},	//   сті_, _सहित_, осы_, ọwap,
   {{0x7c291197,0x00000000,0x00000000,0x00000000}},	//   _šeri, --, --, --,
   {{0x8d5b006e,0x00000000,0x00000000,0x00000000}},	//   יכקי, --, --, --,
   {{0xc7b90103,0x3ce001fa,0xd7640281,0x6d93014b}},	//   _erős_, haiv_, _عنای, rçai,
   {{0x2c060081,0x2b9401bf,0x2012022b,0x84ea02d1}},	//   রিয়ে_, räch_, _apyi_, _نفاق_,
   {{0x81bc0b4b,0x22ae01d4,0x6dbc0234,0x9cfc0033}},	//   lvēk, rək_, _ečak, ঁজুন_,
   {{0x22ae013c,0x320500d7,0x69c80231,0x00000000}},	//   sək_, atly_, _édef, --,
   {{0x6d9325a5,0xdefb013f,0x7c3b00b3,0x389b0142}},	//   nçav, шым_, _àuri, ייכנ,
   {{0xd25000e3,0x320525a6,0x6d580138,0x20120154}},	//   _سنة_, ctly_, _įvar, _epyi_,
   {{0x395d023e,0x6ecb09c4,0x8d770103,0x7bcd10a5}},	//   xhws_, _त्रु, زازا, tpau,
   {{0x4c9400c2,0x0cab25a7,0x00000000,0x00000000}},	// [1b50] дитс, ртви_, --, --,
   {{0x7bcd25a8,0x399c003e,0x88d70033,0x00000000}},	//   rpau, vísa_, _হাইক, --,
   {{0x391506e7,0x7bcd013f,0x998702c6,0x0a681c47}},	//   змер, spau, ínů_, орци_,
   {{0x28f825a9,0x9b45001c,0x7bcd007b,0x628e007f}},	//   жець_, _کنسو, ppau, żbow,
   {{0x798b25aa,0xdd3a00ca,0x5d3a00ca,0x3d3a00ca}},	//   rogw, _הערכ, _התרא, _הגרס,
   {{0x9a871057,0x70b706e4,0x81bc00e8,0x00000000}},	//   _дубл, ःशुल, rvēj, --,
   {{0xd90f0068,0x64460329,0xb9010033,0x80dc0a43}},	//   _لیا_, äkin, _দা_, _ভাস্,
   {{0xea0000de,0xab5b042c,0x6d930231,0x68e9063d}},	//   _hiếp_, _stüh, açav, _uded,
   {{0x657e0257,0xb7d5001c,0xea000023,0xf3f10037}},	//   épha, _رقاب, _kiếp_, رأة_,
   {{0x0cb80e46,0xdce40233,0x6d5a00e8,0x26c5039f}},	//   _अल्म, kniğ, ītai, _uflo_,
   {{0xbcfb0065,0x00000000,0x00000000,0x00000000}},	//   _iléf, --, --, --,
   {{0x9f42030b,0xf8cb0179,0x320500d7,0x00000000}},	//   mské_, ाडिय, rtly_, --,
   {{0x9f420363,0x44290bfe,0x659a0089,0x23290e21}},	//   lské_, _éa_, _פינק, _голи_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f420343,0x6da625ab,0x2bb5000f,0x442f0085}},	//   nské_, зива, _अंजा, _hrg_,
   {{0xf8b900de,0x442f09a4,0xc6920266,0x657b25ac}},	//   _ngũ_, _krg_, גאל_, nnuh,
   {{0x27e925ad,0xaaba0867,0xf3f900ae,0x81a501c3}},	// [1b60] šanj_, مدار_, nuţ_, _تحول,
   {{0x8b230ae3,0x442f009c,0xed160034,0x8b26013f}},	//   ндуе, _mrg_, _łódź_, ядзе,
   {{0x9f420146,0x7c2f25ae,0xbed7021e,0x69da0037}},	//   jské_, _ercr, _מויז_, صباح_,
   {{0xa6d80081,0x9f42033d,0xf99225a1,0x00000000}},	//   _সাইট, dské_, ربا_, --,
   {{0x181800bf,0x98a600ae,0x28cb25af,0x00000000}},	//   تراک_, чиде, ाड़ि, --,
   {{0xbb4a0080,0x7bcb2567,0x6d5603e3,0x00000000}},	//   _الآن_, ígue, lkya, --,
   {{0x442f03bd,0xdb0f0131,0x6b5201cd,0x6d9325b0}},	//   _arg_, _sucç, _nægi, rçav,
   {{0x6d440759,0xd90d09b4,0x442f0808,0xceb3040a}},	//   njia, _نیم_, _brg_, עיה_,
   {{0x9f590222,0x68e20231,0x00000000,0x00000000}},	//   ltså_, maod, --, --,
   {{0x27e625b1,0x442f0479,0x68e225b2,0xdb1d0161}},	//   mson_, _drg_, laod, _ausê,
   {{0x442f0272,0x6d56006d,0x27e625b3,0x98bf0090}},	//   _erg_, kkya, lson_, _qmuħ_,
   {{0x463b00c1,0x26de06a8,0x68e20239,0x55bb0327}},	//   _לעבע, _heto_, naod, _המאו,
   {{0x26de00dd,0x24aa0081,0x6283034f,0xbf9b0131}},	//   _keto_, _গ্রহ, _exno, stêm,
   {{0x27e604ea,0xd37000bf,0xbf9b00fd,0x2327007b}},	//   ison_, _جهت_, ptêm, _ночи_,
   {{0x27e601c2,0x80dc0081,0x2cb90167,0x26de25b4}},	//   hson_, _ভার্, _pgsd_, _meto_,
   {{0x26de25b5,0x6d440216,0x5d9901b3,0x61fa25b6}},	//   _leto_, gjia, ікаў_, mutl,
   {{0x68e225b7,0x27e60a39,0x7bc0020d,0x61fa25b8}},	// [1b70] daod, json_, _émul, lutl,
   {{0x8aa70c58,0x6d5625b9,0x3213007f,0x7ac413c7}},	//   пред, akya, łbyś_, есце,
   {{0x98bf00d3,0x657b008a,0x61fa25ba,0xd8ca0134}},	//   _nouă_, ynuh, nutl, _ịpịr,
   {{0x1a6803ed,0x9f42025b,0xdb0625bb,0x0dba0018}},	//   سیقی_, vské_, _zukü, _گئیں_,
   {{0xea0000ef,0x26de25bc,0x7d0d25bd,0x443f003d}},	//   _tiếp_, _beto_, mfas, xxu_,
   {{0x9f420074,0x7c2d25be,0x26de0044,0xe7360e21}},	//   tské_, mvar, _ceto_, деш_,
   {{0xa3df0296,0x26de0063,0x442f25bf,0xe70801c3}},	//   धीन_, _deto_, _srg_, ستون_,
   {{0x7d0d25c0,0x98bf002d,0x9f420618,0xd4d90426}},	//   nfas, _două_, rské_, цькі_,
   {{0xb4bd02e8,0xbcfb25c1,0xdc0b0081,0x7c2d25c2}},	//   _आली_, _elég, রিকস_, nvar,
   {{0x04ff0081,0x9f4200b6,0xdb1d0212,0x443f25c3}},	//   ্যের_, pské_, _utsä, rxu_,
   {{0x6d5d0511,0x61fa1192,0x7c2d25c4,0xbcfb0113}},	//   _olsa, gutl, hvar, _kléd,
   {{0x442f0660,0x6560152f,0xdb06002b,0x348e0129}},	//   _trg_, chmh, _yukó, ịdị_,
   {{0x442f0063,0x7d0d25c5,0x995c0e43,0x7c2d05db}},	//   _urg_, dfas, níš_, jvar,
   {{0xdfcf0080,0x442d25c6,0x6d5d25c7,0x61fa25c8}},	//   شيف_, mve_, _alsa, butl,
   {{0x7d0d25c9,0x7c2d0138,0x78bb0361,0x00000000}},	//   ffas, evar, _oguv, --,
   {{0x752925ca,0x78bb068d,0x6da3017b,0x6d5625cb}},	//   ndez, _nguv, виса, ukya,
   {{0x7c2d25cc,0x442d25cd,0x6d440063,0xdced0e94}},	// [1b80] gvar, nve_, rjia, znać,
   {{0xa3df0557,0xeb9f00d6,0x995c0146,0xda660037}},	//   धीय_, _spør_, díš_, واضي,
   {{0x26de22bf,0x442d25ce,0x7c2d25cf,0x69c10103}},	//   _reto_, hve_, avar, _élel,
   {{0x442d02e6,0x26de25d0,0x98a025d1,0x6f1c047e}},	//   kve_, _seto_, žič_, lerc,
   {{0xa3f80081,0x442d00dd,0x8b660260,0x75290036}},	//   _অন্য_, jve_, _قاسم, ddez,
   {{0x27e6064b,0x644600aa,0x442d25d2,0xbcfb0af0}},	//   rson_, äkim, dve_, _eléd,
   {{0xe1e700fb,0x442d25d3,0x27e625d4,0x16de0285}},	//   _جس_, eve_, sson_, _नजीब,
   {{0x6f1c25d5,0xbcfb0113,0xfaa325d6,0x03c625d7}},	//   herc, _gléd, _расо, мсом,
   {{0x26de25d8,0xea0000de,0x15ea0980,0x442d25d9}},	//   _teto_, _khắp_, _टिकर_, gve_,
   {{0x6d9325da,0x68e025db,0x61fa25dc,0x06d80033}},	//   nçar, _hemd, tutl, _সাকি,
   {{0x442d25dd,0x68e00da7,0x7d0d25de,0xdb150383}},	//   ave_, _kemd, yfas, _dizè,
   {{0x442d25df,0x68e000e7,0x394625e0,0x9f4000ee}},	//   bve_, _jemd, njos_, _avià_,
   {{0x3946016d,0x6f1c25e1,0x672825e2,0x00000000}},	//   ijos_, ferc, _kadj, --,
   {{0x6f1c25e3,0x61fa25e4,0x399525e5,0x7c2d013c}},	//   gerc, putl, låst_, vvar,
   {{0x672800dd,0x7d0d25e6,0xbf9b0131,0x6e9425e7}},	//   _madj, tfas, ntêi, виру,
   {{0xbcfb25e8,0x672825e9,0x2fc0015e,0x6abc05db}},	//   _amér, _ladj, _fuig_, _agrf,
   {{0x7d0d25ea,0x6f1c25eb,0xdd9400c6,0xe81e121d}},	// [1b90] rfas, berc, таты, _मैला_,
   {{0x6f1c25ec,0x6728113c,0x386625ed,0x7d0d25ee}},	//   cerc, _nadj, dzor_, sfas,
   {{0x442d25ef,0x3f9125f0,0x2bdf1687,0x68e0039f}},	//   zve_, mozu_, _पौरा, _bemd,
   {{0xb4bd02e8,0x8aa41b48,0xdb1d25f1,0x63b825f2}},	//   _आले_, труд, _musé, _livn,
   {{0xe73925f3,0xdd910068,0x27e925f4,0x69dc25f5}},	//   зел_, _لوگ_, éan_, _ewre,
   {{0x25a60018,0x442d25f6,0x29040090,0x9f59020d}},	//   _ahol_, vve_, _ecma_, fusé_,
   {{0xf7700602,0x995c0074,0x7ae525f7,0xe61112eb}},	//   جان_, síš_, maht, اشت_,
   {{0x442d25f8,0x6f1c0074,0x942519a9,0x6934129c}},	//   tve_, zerc, емие, _инсу,
   {{0x442d25f9,0x291d25fa,0x75290018,0x96ca0455}},	//   uve_, mewa_, rdez, _स्कॉ,
   {{0x291d068d,0x1b1d00c7,0x62980185,0x672825fb}},	//   lewa_, নাকে_, _byvo, _gadj,
   {{0x63b8042d,0x442d25fc,0x6f1c04d6,0x395f25fd}},	//   _divn, sve_, verc, _klus_,
   {{0x2fc005fe,0x291d25fe,0x6f05009c,0x25a6033c}},	//   _puig_, newa_, _achc, _ghol_,
   {{0x25ad25ff,0x394d0665,0xdbd71d2d,0x442d0052}},	//   mmel_, _moes_, _jäät, qve_,
   {{0x7ae50991,0x291d2600,0x2bb20154,0x394d2601}},	//   jaht, hewa_, _gņch_, _loes_,
   {{0x291d2602,0x7bdd0f20,0x2129008c,0x629800c6}},	//   kewa_, _awsu, _faah_, _gyvo,
   {{0xa0a6004b,0x2fc011b9,0x291d2603,0xb4bd0096}},	//   _пайд, _tuig_, jewa_, _आलो_,
   {{0xac861211,0x291d2604,0x2bdb030b,0xa8020092}},	// [1ba0] хгал, dewa_, मीला, _çıxd,
   {{0x395f2605,0xe6250028,0x6b5202b6,0x31720094}},	//   _alus_, _đông_, _nægt, _hmyz_,
   {{0x67282606,0xfce62607,0x68e02608,0x21292609}},	//   _radj, _поно, _pemd, _yaah_,
   {{0x8c461a67,0x672802dd,0xab5b0364,0x291d260a}},	//   _земе, _sadj, _stüt, gewa_,
   {{0x394d260b,0xea000023,0x2d80260c,0x6728260d}},	//   _does_, _thắp_, mnie_, _padj,
   {{0x2d800067,0x69dc016d,0x395f260e,0x96f8260f}},	//   lnie_, _twre, _elus_, фект_,
   {{0xfaa32610,0x56932611,0x395f003d,0x2d801b50}},	//   _баро, лашт, _flus_, onie_,
   {{0x291d2612,0xa53411d9,0x248603be,0x2d802613}},	//   cewa_, тнич, _pxom_, nnie_,
   {{0x63b82614,0x2d802615,0x2bb20154,0x00000000}},	//   _pivn, inie_, _pņch_, --,
   {{0x2d802616,0x7c3b124d,0x3f8509ac,0xd62a001f}},	//   hnie_, _áure, čluk_, _нозе_,
   {{0x7d06070a,0x3f912617,0x63b801fa,0x2d922618}},	//   _ocks, vozu_, _vivn, koye_,
   {{0x25d90979,0xea0000ef,0x7c262619,0x62980579}},	//   _آهنگ_, _nhập_, _oskr, _vyvo,
   {{0x2d800067,0xe5a3180b,0x00000000,0x00000000}},	//   dnie_, _сици, --, --,
   {{0x4426261a,0x2d8000a5,0x2129261b,0x291d261c}},	//   _iso_, enie_, _waah_, zewa_,
   {{0xbe88261d,0x59b0261e,0x3da7261f,0x31600036}},	//   есте_, जगार, ераб, _fliz_,
   {{0x2d802620,0x44262621,0x2d922622,0xea000023}},	//   gnie_, _kso_, goye_, _chập_,
   {{0x7ae513e1,0x44260095,0xab640233,0x394d2623}},	// [1bb0] taht, _jso_, klüğ, _roes_,
   {{0x6d5a074a,0x2d800034,0x63ad0036,0xae2100aa}},	//   ëtar, anie_, _èant, मबदन_,
   {{0xf7711e49,0x395f2198,0x2d92023f,0xdbd700c2}},	//   یات_, _plus_, boye_, _säät,
   {{0xdbd702fd,0x442602a7,0x2d8000a5,0xd8792296}},	//   _päät, _oso_, cnie_, ومات_,
   {{0x44262624,0xb8e9007d,0x7ae502fd,0xbcfb0fb6}},	//   _nso_, _ईल_, paht, _eléc,
   {{0x394d0185,0x6d4f01e8,0xbcfb020d,0x23a201cd}},	//   _woes_, _hoca, _fléc, yðja_,
   {{0x44262625,0x291d0010,0x6d4f2626,0x6b52052f}},	//   _aso_, pewa_, _koca, _vægt,
   {{0x74150391,0x84770139,0x1da708d4,0x44260381}},	//   نوعا, _aáwẹ, _कीमत, _bso_,
   {{0xe4c80190,0xc89500d1,0xc9840450,0x00000000}},	//   ربين_, _شارژ, _сури, --,
   {{0x2d802627,0x6b52003e,0x60cd2628,0x8c1c00ca}},	//   znie_, _hægr, _afam, לוחי,
   {{0x44262629,0x96ca0455,0x36d40084,0x2d800034}},	//   _eso_, _स्टॉ, _сохр, ynie_,
   {{0x27e90b4b,0x29020149,0x6dbc0f72,0x6aba0301}},	//   šanu_, _ökat_, _očar, _útfe,
   {{0xd24e00d0,0x84770032,0x44260141,0x2d9200fc}},	//   منی_, _fáwẹ, _gso_, voye_,
   {{0x7bc00161,0x3ebe004d,0x2d80262a,0x636400b3}},	//   _émui, øtt_, wnie_, _cònd,
   {{0x6d4f262b,0x2d800067,0xfce6014d,0xdee31278}},	//   _boca, tnie_, ково, роси,
   {{0x2bc3262c,0xc5f200c1,0x2b1407ad,0xab640233}},	//   _वंशा, ידל_, न्नु_, zlüğ,
   {{0x2d80262d,0x81bc00e8,0x00000000,0x00000000}},	// [1bc0] rnie_, svēt, --, --,
   {{0x998d18b4,0xab5b0364,0x2d800034,0x6d4f033c}},	//   _češ_, _stür, snie_, _eoca,
   {{0x6d4f0080,0x6dbc02dd,0xea0000de,0xeb970291}},	//   _foca, _včas, _thập_, њих_,
   {{0x6d4f262e,0x00000000,0x00000000,0x00000000}},	//   _goca, --, --, --,
   {{0xf7460303,0x7c26005f,0x6e93262f,0x00000000}},	//   кедо, _uskr, _ملیا, --,
   {{0x7bd62630,0x7d042631,0x6d4f2632,0x63640383}},	//   mpyu, lgis, _zoca, _kòne,
   {{0x27ed0054,0xab6401e8,0x752b007e,0x7c242633}},	//   _even_, rlüğ, _bagz, lwir,
   {{0x7d042634,0x6d4f2635,0x00000000,0x00000000}},	//   ngis, _xoca, --, --,
   {{0x7c240364,0x7bd60124,0x27ed0218,0x872600ae}},	//   nwir, npyu, _gven_, _имаж,
   {{0x44260087,0x60cd028d,0x80dc0033,0x00000000}},	//   _vso_, _sfam, _ভাগ্, --,
   {{0xd5af00c2,0x21790109,0x81bc01d3,0xa266008f}},	//   _вс_, ейны_, evēr, тъпл,
   {{0x442601bb,0x7c240193,0x925700c2,0xd5e90037}},	//   _tso_, kwir, тают_, _أعلن_,
   {{0x250b0103,0x81bc00e8,0x7520024a,0x7c240172}},	//   _آرمی_, tvēs, memz, jwir,
   {{0x65620031,0x69c1028d,0x247e0174,0x2afe052c}},	//   _hloh, _èleg, ịms_, _लागु_,
   {{0xd3780995,0xf1a72636,0xbcfb00fd,0x798200ca}},	//   mić_, _ирин, _aléa, know,
   {{0x798200a5,0x7d042637,0x9f59025b,0x2d5502b6}},	//   jnow, ggis, musí_, _nået_,
   {{0x6c54184d,0x7c240435,0x65620357,0xd0110308}},	// [1bd0] акту, gwir, _mloh, _الخ_,
   {{0x7d042638,0x7658007b,0x31792639,0xf0e3007f}},	//   agis, kyvy, lisz_, _ख़ुद_,
   {{0x3f830995,0xdb050080,0x6562263a,0x27ed263b}},	//   mnju_, gmhá, _oloh, _sven_,
   {{0xd37804eb,0x7c24023f,0x6d4f00e7,0x9f42033d}},	//   hić_, bwir, _uoca, mská_,
   {{0xd37803ce,0x9f420579,0xbcfb0037,0x4424023e}},	//   kić_, lská_, _gléa, jwm_,
   {{0x65620af0,0xd37800e9,0x4908009f,0x628a263c}},	//   _aloh, jić_, _हाथो_, _oxfo,
   {{0x9f420074,0xd37800e9,0x2d5501c5,0x95c5001c}},	//   nská_, dić_, _fået_, ديبه,
   {{0xdb1d0871,0x2d5501c5,0x661a061d,0x442401fa}},	//   _musí, _gået_, _dptk, fwm_,
   {{0x3f830fa3,0xe70500d1,0x00000000,0x00000000}},	//   knju_, _مسای, --, --,
   {{0xd37804eb,0x29020149,0x656222cf,0x3f83042d}},	//   gić_, _ökar_, _eloh, jnju_,
   {{0x3f8300e9,0x9f42035d,0xc0e6263d,0x2fd2057a}},	//   dnju_, jská_, лонк, _styg_,
   {{0x741200cd,0x9f420146,0xd4350a09,0xf5300037}},	//   جویا, dská_, _معتب, _وإن_,
   {{0xd378263e,0xa3df2125,0x7d0403e0,0x442400f0}},	//   bić_, धीश_, vgis, cwm_,
   {{0xd37800a5,0x2d99263f,0x3f830357,0x6364022b}},	//   cić_, _akse_, gnju_, _pòne,
   {{0x31790034,0xa3df1c05,0x79820034,0x81bd01d3}},	//   bisz_, धीर_, ynow, rvēr,
   {{0x7c242640,0x2d960109,0x81bd01d3,0xbcfb0076}},	//   twir, ургс, svēr, _pléa,
   {{0x6da300d3,0x09cc009d,0x3f831912,0x5baa2641}},	// [1be0] сита, ाऱ्य, bnju_, екам_,
   {{0x7c242642,0xfbcd0081,0x20022643,0xdb1d20df}},	//   rwir, _লিখত, muki_, _fusí,
   {{0xe8fa2644,0x20022645,0x7c242646,0x79822647}},	//   еле_, luki_, swir, tnow,
   {{0xd3782648,0x786a0018,0x88e600c2,0xea0000fe}},	//   zić_, _növé, ужде, _chạp_,
   {{0x20022649,0xe3c800de,0x4424023e,0x7982264a}},	//   nuki_, _mực_, xwm_, rnow,
   {{0xdb1c00dd,0xe3c80028,0xfee20033,0x7982007f}},	//   _mirë, _lực_, _বাঁধ, snow,
   {{0xd37800e9,0x6b63264b,0x7bc60d2a,0xd6d9004d}},	//   vić_, _укра, _huku, тті_,
   {{0x7bc6264c,0x1db402e8,0xd37800a5,0x3f830ca7}},	//   _kuku, ंगित, wić_, znju_,
   {{0xd37802e6,0x7bc6264d,0xe64403a3,0x12e607bf}},	//   tić_, _juku, ılığ, лінг,
   {{0x2002264e,0x7bc61a80,0x44240150,0x257a0139}},	//   duki_, _muku, rwm_, _bàlè_,
   {{0xd37802e6,0x7bc6264f,0x3f832650,0xe3c80023}},	//   rić_, _luku, vnju_, _bực_,
   {{0xe3c80028,0x9f42025b,0xf1ab00bf,0x29060a00}},	//   _cực_, vská_, عاده_, ngoa_,
   {{0x7bc62651,0x3f830039,0x69c10257,0xd3782652}},	//   _nuku, tnju_, _élev, pić_,
   {{0x9f42025b,0x317900a5,0x00000000,0x00000000}},	//   tská_, sisz_, --, --,
   {{0x31790067,0x7bc62653,0x3f830106,0x539b0266}},	//   pisz_, _auku, rnju_, _ריוו,
   {{0x7bc62654,0x9f42025b,0x3f8308a9,0x20022655}},	//   _buku, rská_, snju_, buki_,
   {{0x7bc60f8b,0x3f8316a2,0x00000000,0x00000000}},	// [1bf0] _cuku, pnju_, --, --,
   {{0x7bc62656,0x9f4202c6,0x332e00bd,0xa3e606e4}},	//   _duku, pská_, _jafx_, यीय_,
   {{0xfaa712d1,0x2b141bc3,0x0b882657,0x8aa7007e}},	//   ушан, न्धु_, усти_, урад,
   {{0xdc34025b,0x3835002d,0x2d9900bc,0xf1c900fe}},	//   _zúča, инер, _ukse_, _hạc_,
   {{0x7bc62658,0x3b0a00b3,0x6d4d2659,0x00000000}},	//   _guku, _fcbq_, mjaa, --,
   {{0x6d4d265a,0x29060a00,0x2b1404f8,0x38ba0342}},	//   ljaa, agoa_, न्दु_, _sürü_,
   {{0x7bc601bf,0xd0560092,0xf1c900de,0xcf5800a1}},	//   _zuku, _deyə, _mạc_, רבות_,
   {{0x6d4d168b,0xf1c90028,0xdb1d016d,0x69d50634}},	//   njaa, _lạc_, _fusã, _itze,
   {{0x7bc60694,0x68eb265b,0x799b198f,0xe3c800de}},	//   _xuku, magd, _ikuw, _rực_,
   {{0x69c7265c,0x68eb0407,0xdced0367,0xdbd200aa}},	//   _kuje, lagd, ynağ, _rüüt,
   {{0x216a265d,0x67231c54,0x7ae7265e,0x75d100d9}},	//   вини_, menj, _mejt, _bāze,
   {{0x69c703cc,0x672302dd,0xdc340181,0x68eb00a6}},	//   _muje, lenj, _súča, nagd,
   {{0x6603265f,0xe3c80028,0xf1c90019,0xb4d1009d}},	//   lunk, _vực_, _bạc_, वडी_,
   {{0x7bc62660,0x20022661,0x67232662,0xdee3002d}},	//   _ruku, ruki_, nenj, жори,
   {{0x13da00c7,0x7bc62663,0x2002048e,0x799b0a15}},	//   _দিয়, _suku, suki_, _okuw,
   {{0x7bc62664,0x67232665,0x64460149,0x75d101d3}},	//   _puku, henj, åkig, _gāze,

   {{0x67232666,0x644908a8,0x69d502a7,0x68eb1281}},	// [1c00] kenj, nxei, _atze, dagd,
   {{0xaaba09b4,0x66032667,0x79890139,0x69c72668}},	//   ندار_, kunk, _ajew, _buje,
   {{0x7ae72669,0x6723011d,0x69c704a3,0x6da6266a}},	//   _dejt, denj, _cuje, _вина,
   {{0x7bc6266b,0xe3c80019,0xdb0f266c,0xd91012eb}},	//   _tuku, _lựa_, _bucó, ثیر_,
   {{0x3860266d,0x2906266e,0x6569266f,0x7bc62670}},	//   áir_, rgoa_, dheh, _uuku,
   {{0x67232671,0x78a900e7,0x3f982672,0x799b2673}},	//   genj, _dzev, noru_, _ekuw,
   {{0x25fd2674,0x9f5900fd,0xb4d10096,0x69c72675}},	//   रंगी_, ursé_, वडू_, _guje,
   {{0x3f98030b,0xdb1c2676,0xa6e90019,0x7ae72677}},	//   horu_, _sirè, _ngươ, _zejt,
   {{0x69c02678,0x67232679,0xdb07267a,0x69c700e7}},	//   _iime, benj, _gijó, _zuje,
   {{0x4aaa267b,0x672300e9,0x69c0267c,0x60c4267d}},	//   _कराव, cenj, _hime, _agim,
   {{0x69c10068,0x69c0267e,0xe3c800de,0xa159267f}},	//   _élet, _kime, _dựa_, гану_,
   {{0x50672680,0xf1c900de,0x2c5e00d9,0x69c02681}},	//   атга, _sạc_, _kādā_, _jime,
   {{0x938a013d,0x69c02682,0x8ca20fef,0xb4c203a2}},	//   _иска_, _mime, _खरगो, ंशी_,
   {{0x69c02683,0x3f9808a9,0x09d70081,0x6d4d0126}},	//   _lime, goru_, _হিসা, wjaa,
   {{0x7ae72684,0xa187163d,0xdef801b3,0x9ce70307}},	//   _rejt, _выпл, шыя_, ицал,
   {{0x69c02685,0x672300cc,0x69c70079,0x7ae72686}},	//   _nime, zenj, _ruje, _sejt,
   {{0x69c72687,0x6d4d2688,0x6723083e,0x66032689}},	// [1c10] _suje, rjaa, yenj, zunk,
   {{0x69c0268a,0x6d4d268b,0x69c700b3,0xaad2058f}},	//   _aime, sjaa, _puje, दुलक,
   {{0x6723268c,0x69c0268d,0xdb0f00b3,0xc879020a}},	//   venj, _bime, _bucò, _ieşi_,
   {{0x98a90995,0xdb0f037a,0x69c700c4,0xc984268e}},	//   žač_, _pucó, _vuje, оучи,
   {{0xe8f802b7,0x7ae70038,0x67232024,0x68eb00a6}},	//   рлі_, _tejt, tenj, ragd,
   {{0x2fc901bb,0x6603268f,0x69c72690,0x68eb0124}},	//   _muag_, tunk, _tuje, sagd,
   {{0x672308a9,0x2fc901bb,0x69c00383,0x68eb1281}},	//   renj, _luag_, _fime, pagd,
   {{0x66032691,0x99850080,0x67230542,0x799b019f}},	//   runk, _الرو, senj, _ukuw,
   {{0x681a00d9,0x67232692,0x66032693,0x44392694}},	//   gādā, penj, sunk, ís_,
   {{0x69c00010,0x65692695,0xb4e60034,0x68e92696}},	//   _zime, sheh, _बड़ी_, _heed,
   {{0xb6350241,0x68e92697,0x644600c2,0x26c505db}},	//   _دفاع, _keed, äkir, _iglo_,
   {{0x68e90694,0x3f982698,0xdb1c014b,0xd05d013c}},	//   _jeed, woru_, _viré, lasə,
   {{0x34380177,0x68e92699,0x2fc90197,0xe3c800de}},	//   _پسند_, _meed, _cuag_, _tựa_,
   {{0x50d80c16,0x68e9269a,0x98a0084f,0xdb1c020d}},	//   _भ्रष, _leed, žić_, _tiré,
   {{0xc87900d3,0xbcfb269b,0x25fd269c,0x59b91926}},	//   _deşi_, _elém, रंटी_, ेदार,
   {{0xbf9b001f,0x68e900a1,0x3f98269d,0xc692006e}},	//   quên, _need, soru_, פאן_,
   {{0x69c0269e,0x26c500e7,0x3f98269f,0x7ff626a0}},	// [1c20] _rime, _oglo_, poru_, _اسبا,
   {{0x69c026a1,0x290d00d3,0x2b4300ee,0x7d162452}},	//   _sime, _acea_, _cnjc_, sfys,
   {{0xcf57004f,0xe80a007d,0x69c018a4,0x0f5700c1}},	//   _הבית_, हूना_, _pime, _היים_,
   {{0xb4e60abe,0x2fc9022e,0xea000023,0xdb150094}},	//   _बजे_, _yuag_, _nhấp_, _vizá,
   {{0x69c026a2,0x68e926a3,0x00000000,0x00000000}},	//   _vime, _deed, --, --,
   {{0xaa461e65,0xb4c202d5,0x681a00e8,0x98a400c6}},	//   _легл, ्ड्_, vādā, _namą_,
   {{0x69c026a4,0xf38a0649,0x68e926a5,0x6b63163d}},	//   _time, nṣe_, _feed, _экра,
   {{0x68e9008a,0xea000019,0xf3f8090f,0x32050094}},	//   _geed, _chấp_, аниш_, duly_,
   {{0x78660ed8,0x7c290095,0xb4c200b6,0x00000000}},	//   _указ, _šerz, ्डौ_, --,
   {{0x681a0029,0x2fc926a6,0x68e901cb,0x00000000}},	//   rādā, _ruag_, _zeed, --,
   {{0x6b9b00c1,0x68e90188,0xcb9b0796,0x2c140033}},	//   רשיד, _yeed, רסיט, ঠিয়ে_,
   {{0x2fc90197,0xe57203ef,0xbcfb0113,0x216726a7}},	//   _puag_, _عطا_, _plém, стог,
   {{0x2fc9023e,0xf8ba09c4,0x91ca00c0,0x7cff0139}},	//   _quag_, ेशिय, _संवै, _làrà,
   {{0x2fc9006c,0x995c02c6,0x25ef0096,0x00000000}},	//   _vuag_, jíž_, ींची_, --,
   {{0xf1c90028,0x2cd60134,0x995c02c6,0xdbd111bc}},	//   _hạn_, _ọhụ_, díž_, _küçe,
   {{0x2fc926a8,0xbcfb0139,0xf1c900fe,0x00000000}},	//   _tuag_, _ilék, _kạn_, --,
   {{0x68e926a9,0xd05d01d4,0x3b550d9b,0x636d26aa}},	// [1c30] _reed, yasə, окар, _dúnf,
   {{0xf1c900de,0x7cff0032,0x68e926ab,0xdb050076}},	//   _mạn_, _bàrà, _seed, lmhú,
   {{0x9d1900d3,0x6aba01cd,0x636d0065,0x79990313}},	//   _конт_, _útfl, _fúnf, toww,
   {{0xbcfb00b6,0x9f520154,0x8ed81ac9,0xad271ac9}},	//   _mlék, _avyè_, _پذیر_, _اردو,
   {{0xf1c90019,0x26060ed3,0xbae80081,0xb4e608d4}},	//   _nạn_, सूसी_, _পারছ, _बड़े_,
   {{0x7c2f0465,0xe73925e7,0x45d523bf,0xaded009f}},	//   _iscr, рек_, оцит, _जबान_,
   {{0x636d2027,0x68e91953,0x27e001d3,0x00000000}},	//   _húng, _teed, ģina_, --,
   {{0xf1c9011b,0xf7730e8c,0xf1cf030b,0x160b0034}},	//   _bạn_, _کار_, _संबन, संबर_,
   {{0x25fd0ccb,0xf1c90023,0x7c3b00c4,0x6d5a014b}},	//   रूजी_, _cạn_, _šurj, êtai,
   {{0x6d9326ac,0x32050146,0x43740686,0xf1c900fe}},	//   lħad, tuly_, зуют, _dạn_,
   {{0xea000019,0xe1261c0e,0x2d890da7,0x316905db}},	//   _thấp_, омни, knae_, _blaz_,
   {{0x26130396,0x24190084,0x61fc26ad,0x8cd91f88}},	//   mão_, _воды_, árla, _फ्लो,
   {{0x26130396,0x442926ae,0xbcfb0065,0xead0026e}},	//   lão_, _èa_, _elék, _kẹta_,
   {{0x88ba00a1,0x443d09a1,0x5334007b,0x00000000}},	//   יזרי, _irw_, _нечт, --,
   {{0x3ebe26af,0x443d26b0,0x26130161,0x3eac0430}},	//   ätt_, _hrw_, não_, ådt_,
   {{0x2d890085,0x9f420220,0xf1c90023,0x3cf600bc}},	//   gnae_, nskú_, _hạo_, ेलें_,
   {{0x26130161,0x636d0076,0xdca326b1,0x00000000}},	// [1c40] hão_, _cúng, дати, --,
   {{0x443d0328,0x8a3a007b,0x636d033c,0x670e0e28}},	//   _mrw_, ияет_, _dúng, _साधक_,
   {{0x442f0085,0x26130161,0x2d9e00fd,0xf1c900de}},	//   _lsg_, jão_, îtes_, _mạo_,
   {{0x26130396,0x8c4626b2,0x443d06b0,0x9f420206}},	//   dão_, _деме, _orw_, jskú_,
   {{0x274a00b8,0x6d4626b3,0x443d26b4,0x636d0065}},	//   ичко_, _inka, _nrw_, _gúng,
   {{0x29d700bd,0x2613016d,0xf1c900fe,0xa09b0266}},	//   _bħad_, fão_, _rạn_, סיסט,
   {{0x2613001f,0xf1c90019,0xc2e80033,0x443d26b5}},	//   gão_, _sạn_, _খালি_, _arw_,
   {{0x54541681,0xf1c900fe,0x69de007b,0x442f26b6}},	//   звит, _pạn_, mppe, _bsg_,
   {{0x68e226b7,0xf1c900de,0x186726b8,0xe947001c}},	//   mbod, _bạo_, _дати_, _ظرفی,
   {{0x2d6801e8,0x26130161,0xf1c90023,0x68e2004d}},	//   rşey_, bão_, _vạn_, lbod,
   {{0x6d4626b9,0x2613001f,0x29d7003d,0x31690e9e}},	//   _onka, cão_, _għad_, _plaz_,
   {{0xdb1d02e2,0x68e226ba,0x443d0193,0x2b58009c}},	//   _zusä, nbod, _frw_, _lorc_,
   {{0xdb1c0076,0x60c9007e,0x26060285,0x443d00eb}},	//   _airí, žemo, सूरी_, _grw_,
   {{0x6d4626bb,0xf1c900de,0x533418b9,0x7ada0096}},	//   _anka, _gạo_, _хект, _प्लॅ,
   {{0xdb1c0072,0x9e34002d,0xcdd80284,0xbcfb00d2}},	//   _cirí, мерч, жњу_, _ulék,
   {{0x316904a3,0xdb1c04d8,0x200202ef,0xd65700ca}},	//   _ulaz_, _dirí, brki_, חילת_,
   {{0x2613001f,0x636d002b,0x20040428,0x2d8900da}},	// [1c50] zão_, _fúnd, àmit_, rnae_,
   {{0xfaa726bc,0x6d4626bd,0x8aa71907,0x628b042d}},	//   ошен, _enka, оред, šloš,
   {{0x26130396,0x2d5c0042,0x68e201c2,0x539b00ca}},	//   xão_, _cíes_, fbod, סיבו,
   {{0x68e20af0,0xa2da16f8,0x2613016d,0x2d5c00ee}},	//   gbod, पुत्, vão_, _díes_,
   {{0xf74526be,0xb8d302d5,0x9cd60327,0x9f420031}},	//   зело, _ऑर_, _מורה_, vskú_,
   {{0x26130303,0x7d0d26bf,0x7c2d1f1a,0x6fdc0089}},	//   tão_, lgas, mwar, סקוס,
   {{0xf9930241,0xf1c602d5,0x3c2d00c4,0x9f420031}},	//   _قبر_, _रंगन, _hžv_, tskú_,
   {{0x261300c9,0x7d0d26c0,0x442f26c1,0x200201cd}},	//   rão_, ngas, _psg_, yrki_,
   {{0x261300c9,0xa3e6007d,0x7c2d26c2,0x68fb0d16}},	//   são_, यील_, nwar, _idud,
   {{0x2613001f,0x31b6055c,0x6d9303e5,0x77ad0072}},	//   pão_, ृद्ध, nħab, búxa,
   {{0xe2990326,0x7c2d26c3,0x636d0037,0x7d0d26c4}},	//   сан_, hwar, _rúnd, kgas,
   {{0x7c2d06c0,0xfc3f0649,0xf8cb02d5,0x22580212}},	//   kwar, _orí_, िशिय, ärka_,
   {{0xf1c900ef,0x55520103,0x645d01bf,0x81cc0081}},	//   _tạo_, _سپور, äsid, শীল_,
   {{0x442d26c5,0x7c2d26c6,0x752926c7,0xdc3a0092}},	//   mwe_, dwar, leez, xçıv,
   {{0x442d26c8,0xf2d200c1,0x2ca700a7,0x291f0027}},	//   lwe_, _טעג_, əndi_, _obua_,
   {{0x7d0d26c9,0xdb1c26ca,0x442d26cb,0xfc3f0076}},	//   ggas, _virí, owe_, _brí_,
   {{0x442d26cc,0x7c2d26cd,0x2b581065,0xed570396}},	// [1c60] nwe_, gwar, _porc_, чот_,
   {{0x291f0134,0x7d0d26ce,0xf1c90023,0x636d04c3}},	//   _abua_, agas, _lạm_, _fúne,
   {{0xa92607df,0x442d26cf,0xdb1c016d,0x68e2225b}},	//   здел, hwe_, _pirâ, tbod,
   {{0x442d1a84,0xfc3f01cd,0xc7c619e8,0x31b20579}},	//   kwe_, _frí_, пски, báze_,
   {{0x07a626d0,0x442d092f,0x68e226d1,0x684601b6}},	//   падн, jwe_, rbod, янда,
   {{0xe3a71dec,0x501b00a1,0x212002e7,0x1b030081}},	//   _سر_, מונו, _lbih_, র্বে_,
   {{0x442d0185,0xbcfb0037,0x7529083e,0x00000000}},	//   ewe_, _sléi, feez, --,
   {{0x69ce00d3,0x75290283,0xbcfb0076,0x6b9e26d2}},	//   _iube, geez, _pléi, lopg,
   {{0x442d26d3,0x69ce26d4,0xbcfb0065,0x69dc009c}},	//   gwe_, _hube, _eléw, _htre,
   {{0x69ce0c50,0xb4ac000d,0x27f7000d,0x798226d5}},	//   _kube, _गरी_, ření_, liow,
   {{0xcfc40081,0x52130077,0x442d26d6,0x7c2d26d7}},	//   ্ঠান, ндэт, awe_, zwar,
   {{0x442d26d8,0x798200a5,0x69ce26d9,0xe3b8026a}},	//   bwe_, niow, _mube, smı_,
   {{0x69ce26da,0x43461b48,0x7d0d0233,0x660a26db}},	//   _lube, _недв, vgas, lufk,
   {{0x69dc26dc,0x69ce010a,0x00000000,0x00000000}},	//   _otre, _oube, --, --,
   {{0xd78800ef,0x212026dd,0x69ce04d8,0x798b0150}},	//   yển_, _fbih_, _nube, yngw,
   {{0xbcfb26de,0x7c2d26df,0x7aee0062,0x7d0d0653}},	//   _llév, twar, _aebt, ugas,
   {{0x69dc26e0,0x7d0d26e1,0x2d5814fa,0x7c2d01c0}},	// [1c70] _atre, rgas, чить_, uwar,
   {{0x212b26e2,0x69ce26e3,0x7c2d26e4,0x65a50103}},	//   lech_, _bube, rwar, róhi,
   {{0x69ce26e5,0x442d26e6,0x200b00cc,0x7c2d26e7}},	//   _cube, zwe_, luci_, swar,
   {{0xfc3f26e8,0x212b26e9,0x69ce26ea,0x442d26eb}},	//   _trí_, nech_, _dube, ywe_,
   {{0xf77003ed,0x201926ec,0x69dc26ed,0x200b042d}},	//   گان_, ntsi_, _etre, nuci_,
   {{0x7bdd26ee,0xf09400c1,0x660a01c2,0xdb1c0131}},	//   _itsu, ענס_, fufk, _virã,
   {{0xf770006f,0xa3c21843,0x69ce26ef,0x442d057a}},	//   دان_, ्दन_, _gube, wwe_,
   {{0x442d1a80,0x798200a5,0x68fb26f0,0x7bc7037a}},	//   twe_, ciow, _udud, _hiju,
   {{0x442d26f1,0x200b1197,0x212b030b,0x69ce26f2}},	//   uwe_, juci_, dech_, _zube,
   {{0xe1f91681,0x442d26f3,0xdb1c0018,0x7bcf26f4}},	//   ого_, rwe_, _kirá, _mucu,
   {{0x7bcf26f5,0x3f831be3,0x442d26f6,0xf1c90019}},	//   _lucu, diju_, swe_, _tạm_,
   {{0x290f26f7,0x7bdd0006,0x5ec50033,0xdb1c0328}},	//   ngga_, _otsu, ্রাই, _mirá,
   {{0x7bdd01bb,0xbf9b001f,0x200b00cc,0x7bcf26f8}},	//   _ntsu, rrên, guci_, _nucu,
   {{0x3f8303ce,0x1b030033,0xdb1c037a,0x7bc70a4b}},	//   giju_, র্তে_, _oirá, _niju,
   {{0x7bcf04ea,0xddd40031,0xad5a0c4a,0x7bdd26f9}},	//   _aucu, ňažn, орах_, _atsu,
   {{0x7bcf0012,0x200b26fa,0xc692006e,0x2019006c}},	//   _bucu, buci_, דאל_, btsi_,
   {{0x3f832461,0x7bc726fb,0x672102df,0x7aee023e}},	// [1c80] biju_, _biju, _oblj, _pebt,
   {{0x09e61c00,0x7bcf26fc,0x290f0188,0xef8326fd}},	//   дожн, _ducu, egga_, _альп,
   {{0x7bc70cd0,0x6b9e26fe,0x7afc05db,0x69ce26ff}},	//   _diju, ropg, _vdrt, _qube,
   {{0x7aee2700,0xdb1c0328,0x6b9e02b6,0x7bcf01b9}},	//   _webt, _dirá, sopg, _fucu,
   {{0xb4ac000d,0x7bc7015c,0x7bcf0193,0x2baf1c83}},	//   _गरे_, _fiju, _gucu, _जीवा,
   {{0x212b06e4,0x5b3500d3,0x7afc05db,0xa3d10285}},	//   zech_, _пэсу, _udrt, वदन_,
   {{0x69dc2701,0x200b2702,0x8b03030b,0xdb1c002b}},	//   _utre, zuci_, _úřad, _girá,
   {{0xd8260859,0x636400b3,0x6d560079,0x00000000}},	//   _одби, _iòni, njya, --,
   {{0xf8b20251,0x212b2703,0x7bc704ff,0x76410178}},	//   _जरिय, vech_, _yiju, _erly,
   {{0xd370114c,0x200b08a9,0x212b0178,0x00000000}},	//   اهد_, vuci_, wech_, --,
   {{0x3f83005f,0x212b030b,0x69c80103,0x63a82704}},	//   viju_, tech_, _édes, rldn,
   {{0x80fb0d7e,0xe7f50034,0x63640428,0x7c261a39}},	//   ्लेख_, ुंचा_, _mòni, _opkr,
   {{0x3f830542,0x212b2705,0x75220027,0xbcfb0113}},	//   tiju_, rech_, _iboz, _mlét,
   {{0x44262706,0xa29408a1,0x212b2707,0xf487001c}},	//   _ipo_, _палі, sech_, _تامی,
   {{0x290f2708,0x212b2347,0x200b03a9,0x13e30033}},	//   ygga_, pech_, suci_, _মিয়,
   {{0x7bcf2709,0x7bc70010,0x44260294,0xa2da270a}},	//   _pucu, _siju, _kpo_, पुर्,
   {{0x60cd26f6,0x9f420579,0x7bc7270b,0xfc3f0032}},	// [1c90] _igam, lský_, _piju, _eyín_,
   {{0x4426270c,0x7980270d,0x7bcf047e,0x00000000}},	//   _mpo_, _ammw, _vucu, --,
   {{0x9f420618,0x7bc70fb2,0x636400ee,0x2d850103}},	//   nský_, _viju, _còni, éles_,
   {{0x4adf1a09,0x394911ce,0x4426270e,0xdb1c0018}},	//   _प्रव, ñas_, _opo_, _virá,
   {{0x4426022e,0x636d00e3,0x60cd270f,0xba74110a}},	//   _npo_, _lúna, _mgam, _یافت,
   {{0xbcfb2710,0x79800361,0x75222711,0x636405aa}},	//   _elét, _emmw, _aboz, _fòni,
   {{0x4426074a,0x9f420146,0x60cd2712,0x38690786}},	//   _apo_, jský_, _ogam, šar_,
   {{0x60cd2713,0x9f420146,0x77ad0042,0xbcfb0af0}},	//   _ngam, dský_, púxo, _ilés,
   {{0x6d5d2714,0x64422715,0x44260167,0x63a30063}},	//   _mosa, _croi, _cpo_, _pknn,
   {{0x644210d1,0x60cd1a9b,0x44262716,0xf1c90019}},	//   _droi, _agam, _dpo_, _hại_,
   {{0x4426026e,0x80c20789,0x636d0037,0x64422717}},	//   _epo_, रेने, _cúna, _eroi,
   {{0x64422718,0x6d5d2719,0x78a9010a,0x4426271a}},	//   _froi, _nosa, _kyev, _fpo_,
   {{0xf1c90028,0x27ed06a3,0x6569271b,0x00000000}},	//   _mại_, _jwen_, mkeh, --,
   {{0xf1c900ef,0x27ed0c3e,0xa3c00455,0x443f271c}},	//   _lại_, _mwen_, ंगण_, mvu_,
   {{0x6d5d0477,0x443f271d,0x27ed06a3,0x60cd002b}},	//   _bosa, lvu_, _lwen_, _fgam,
   {{0x6d5d271e,0x753b271f,0xed5707ec,0xf65200c1}},	//   _cosa, nduz, нос_, נצן_,
   {{0x6d5d2720,0x443f0283,0xf1ca0023,0xf1ac0ee0}},	// [1ca0] _dosa, nvu_, _nại_, _टीएन,
   {{0x5ba7002d,0x9971007f,0x909b00ca,0x443f2721}},	//   екум_, jął_, _מספק, ivu_,
   {{0x0906117f,0x6d5d17dc,0xbcfb2722,0x3709009f}},	//   епен, _fosa, _boéd, _साड़ी_,
   {{0x443f02e6,0x7e610222,0xf1ca00de,0xebe62723}},	//   kvu_, älpe, _bại_, _помп,
   {{0x69c92724,0x63a12725,0xbcfb0032,0x9f4202c6}},	//   _diee, koln, _elés, zský_,
   {{0xf1ca0023,0x44262726,0x27ed0154,0xb907097c}},	//   _dại_, _rpo_, _dwen_, _म्_,
   {{0xe5c608d8,0x443f122d,0x27ed01b9,0x44262727}},	//   нсио, evu_, _ewen_, _spo_,
   {{0x9f420074,0xd5b7055b,0xdb1c01e8,0x636d2728}},	//   vský_, нсы_, _birç, _rúna,
   {{0x70af0abe,0xbcfb03a9,0xe4522729,0x443f0227}},	//   _घरेल, _klér, اضع_, gvu_,
   {{0x8883272a,0x9f42025b,0xbf9b0257,0x60cd272b}},	//   _служ, tský_, trêm, _sgam,
   {{0xa294224a,0x25710094,0x66e30077,0x69c903a9}},	//   тані, _sále_, _соха, _yiee,
   {{0x3202272c,0x6442272d,0x9f420244,0x6569272e}},	//   čky_, _troi, rský_, ckeh,
   {{0x386605fe,0x4426272f,0x63a12730,0x644201ff}},	//   nyor_, _upo_, boln, _uroi,
   {{0x6d5d1114,0xbf9b020d,0x9f420a7f,0x00000000}},	//   _sosa, prêm, pský_, --,
   {{0xf1a72731,0x644700d9,0x1dac02d5,0x1c0300aa}},	//   _прин, ājie, चतंत, _लिहल_,
   {{0x60cd2732,0xbcfb2733,0x29d700bd,0x5ba90d7e}},	//   _ugam, _alér, _bħan_, कत्व,
   {{0xfbd3006f,0x6d5d2734,0x6386020d,0xbcfb0113}},	// [1cb0] اتر_, _vosa, _génè, _roéd,
   {{0x673a1d88,0xf1bf0072,0x78bd00d4,0xe1cf00a3}},	//   _natj, lmá_, _úsvi, _सूँघ,
   {{0x6d5d0080,0x69c90029,0x61fa2735,0x443f0579}},	//   _tosa, _piee, nstl, zvu_,
   {{0xbcfb0068,0x27ed06a3,0xd70e0b42,0x25a605db}},	//   _elér, _pwen_, _साउथ_, _nkol_,
   {{0xa3c2033a,0xe73913b0,0xa3c00a35,0x29d703e5}},	//   ्दा_, дел_, ंगा_, _għan_,
   {{0x25a62736,0xdb050037,0x61fa2737,0x00000000}},	//   _akol_, rmhó, kstl, --,
   {{0x63a1033d,0x210400c6,0x673a18f0,0xab94004d}},	//   voln, lčių_, _datj, _сирі,
   {{0xf1ca00ef,0x63a100a5,0x7af72738,0x67240e94}},	//   _tại_, woln, laxt, đija,
   {{0x02c9022d,0x210401b3,0xe3b90c28,0x656902e2}},	//   रश्न, nčių_, мби_, rkeh,
   {{0x443f2739,0x6569273a,0x21040138,0x673a02ac}},	//   rvu_, skeh, ičių_, _gatj,
   {{0x77900688,0x443f273b,0x395f02f1,0x2c1d0033}},	//   _دیوا, svu_, _kous_, নিয়ে_,
   {{0x395f05aa,0x636d0032,0x63a10103,0x6386014b}},	//   _jous_, _gúnn, soln, _pénè,
   {{0x63a10b27,0xb0a512e5,0x61e4042d,0x2d820063}},	//   poln, _गुदग, _čile, _rmke_,
   {{0x25ad273c,0xa28300cd,0x25bf00d3,0x395f022b}},	//   llel_, _میخو, lmul_, _lous_,
   {{0xbea61cf2,0x7af7008a,0xe3c800de,0x21040138}},	//   тавк, daxt, _cựu_, ečių_,
   {{0x395f273d,0x41b60018,0x27e000ae,0x6386020d}},	//   _nous_, _جمعر, ţini_, _ténè,
   {{0x91bb00ca,0x29d7013c,0x00000000,0x00000000}},	// [1cc0] _קמפי, _aça_, --, --,
   {{0x395f009c,0x7af7008c,0x394d273e,0x0e66273f}},	//   _aous_, gaxt, _anes_, _акон,
   {{0xc332040a,0x395f2740,0x673a2741,0x00000000}},	//   שוב_, _bous_, _ratj, --,
   {{0x395f2742,0x272200b6,0x02b6006e,0x38662743}},	//   _cous_, _oční_, דלעך_, tyor_,
   {{0x394d0897,0x395f2744,0x261406ed,0x2d922745}},	//   _dnes_, _dous_, नूनी_, mnye_,
   {{0x394d2746,0xbf9b0257,0x2d92005c,0x38662747}},	//   _enes_, quêt, lnye_, ryor_,
   {{0x6aa301bf,0x2bd82748,0x395f2749,0xa3c000b7}},	//   ünft, _भंडा, _fous_, ंगस_,
   {{0x2d92274a,0x316001e9,0x2ef80364,0x395f274b}},	//   nnye_, _noiz_, harf_, _gous_,
   {{0xd0e3274c,0x2d920063,0xdcc500b6,0x47c6013f}},	//   _क्षण_, inye_, लेपछ, _абав,
   {{0x2d9200dc,0x316001ff,0x6376020a,0xc44500d1}},	//   hnye_, _aoiz_, _mâng, ایون_,
   {{0x27e612b7,0xcb1300a1,0xc22409b4,0x2ef801bf}},	//   lpon_, בלת_, اکتو, darf_,
   {{0x25a60bb6,0x2bd800a8,0x395f00b3,0x210400c6}},	//   _ukol_, _भूभा, _xous_, yčių_,
   {{0x27e6274d,0xf1bf0956,0x2d920063,0x3a3801b9}},	//   npon_, rmá_, dnye_, _lsrp_,
   {{0x29d703e5,0x27e607ac,0x69c101dc,0x2d920361}},	//   _bħal_, ipon_, _èlev, enye_,
   {{0x636d0037,0xc3330327,0x260600b6,0x3da7001f}},	//   _múnl, _כוס_, सूची_, враб,
   {{0x31600634,0x9f59014b,0x00000000,0x00000000}},	//   _goiz_, issé_, --, --,
   {{0x0dc8274e,0x64440b14,0xc05b004d,0x5bb91402}},	// [1cd0] тури_, _šiij, _цій_, елая_,
   {{0x395f274f,0x25712750,0x2d92083e,0xe3c80023}},	//   _sous_, _mála_, anye_, _tựu_,
   {{0x29d72751,0x395f2752,0xe8cb11c7,0x2104013f}},	//   _għal_, _pous_, िश्च, sčių_,
   {{0x69c80036,0x67d511f7,0x26de033c,0x210400c6}},	//   _èdel, году, _afto_, pčių_,
   {{0x395f1729,0x6d4f0707,0xb80a02d5,0xd8252753}},	//   _vous_, _inca, हंगम_, удли,
   {{0xa3b20251,0xf1ca0019,0x4639002d,0x394d00f0}},	//   _झील_, _hạt_, ечия_, _wnes_,
   {{0x395f10af,0x637600ae,0x25bf020a,0x00000000}},	//   _tous_, _mând, tmul_, --,
   {{0x224902e6,0x394d0472,0x84590396,0x7af501c8}},	//   _čak_, _unes_, ерот_, _hezt,
   {{0xc98410fb,0x69d52754,0x636d0139,0x321e0143}},	//   _тури, _huze, _fúnl, etty_,
   {{0x25bf002d,0x25ad0146,0x69d52755,0xf1ca00de}},	//   smul_, slel_, _kuze, _lạt_,
   {{0x7515054f,0xa18a11d9,0x6d4f01dc,0x200b0034}},	//   _مواض, ебна_, _onca, erci_,
   {{0x69d52756,0x9f5e00b6,0xd00a0e3a,0xdb1d042c}},	//   _muze, čtí_, неме_, _ausü,
   {{0x69d52757,0xaac3000d,0x2d8903a9,0xe44e0c79}},	//   _luze, वेतक, diae_, _уж_,
   {{0x6d4f2758,0x77ad0072,0x63760606,0xe299065c}},	//   _anca, fúxi, _când, _пал_,
   {{0xa3c2000f,0x2d922759,0x6376020a,0x200b0451}},	//   ्दर_, tnye_, _sâng, arci_,
   {{0x2614009d,0xcd360103,0x7e6102c3,0x00000000}},	//   नंती_, درآب, älpa, --,
   {{0x1c460138,0xf1ca00fe,0x69d5020a,0x7de905aa}},	// [1ce0] ынам, _dạt_, _auze, _pèsò,
   {{0x6d4f275a,0x637600d3,0x69d5275b,0x2d920063}},	//   _enca, _gând, _buze, snye_,
   {{0xd94619a6,0x2d920063,0x68e4037a,0x3f8a0079}},	//   лежи, pnye_, ñido, mibu_,
   {{0x2d89002b,0x99900220,0x2578029a,0xf1ca0023}},	//   ciae_, ťaži_, _zélf_, _gạt_,
   {{0x77611f72,0xe7861472,0x69e00117,0x63640139}},	//   _bolx, луко, _žveč, _mònr,
   {{0x69d5275c,0xfaa6275d,0x22470141,0x07a326fd}},	//   _fuze, _баго, _ornk_, бачн,
   {{0x27e6275e,0xe1e70018,0x2a35002d,0x69d5275f}},	//   spon_, _دس_, _кэтр, _guze,
   {{0x7bce0484,0x3f8a0a4b,0x78b1003e,0x636d0076}},	//   _hibu, hibu_, ðkvæ, _dúnm,
   {{0xa3c202e8,0x7bce2760,0x69d503f3,0xb71600e3}},	//   ्दल_, _kibu, _zuze, _مباش,
   {{0x3f8a068d,0x69d514cb,0x69c21570,0x28b9002d}},	//   jibu_, _yuze, lmoe, _русэ_,
   {{0x6b7b13b6,0x637600d3,0x80c202d5,0x2d5c2243}},	//   גרינ, _rând, रेसे, _díez_,
   {{0x84462761,0x7bce2762,0x69c21044,0xdb1c0558}},	//   _مختل, _libu, nmoe, _cirú,
   {{0x2000009c,0x69c20167,0x200b020d,0x645d00f2}},	//   _cvii_, imoe, urci_, øsit,
   {{0x447b07a6,0x7bce1632,0xf487010d,0x841700ca}},	//   _אנדע, _nibu, _حامی, _עקוב_,
   {{0x2904005f,0x6376044c,0x63030037,0x00000000}},	//   _odma_, _vând, _طويل, --,
   {{0x7bce2763,0x3d0f02d5,0x69d50169,0xfbdf00eb}},	//   _aibu, िलें_, _ruze, _drên_,
   {{0x7bce21e9,0x3f8a1cd1,0x69d52764,0x65620113}},	// [1cf0] _bibu, bibu_, _suze, _mooh,
   {{0x7bce2765,0x59d9018b,0x34d1116e,0x2d890133}},	//   _cibu, _बंदर, _हल्द, siae_,
   {{0x5a352766,0x6fdd0033,0xf1ca00fe,0x2d89066a}},	//   рнет, _বিয়ে, _tạt_, piae_,
   {{0xe9ab0421,0x69c20a88,0xe0df0036,0x65620172}},	//   ردان_, gmoe, ncò_, _nooh,
   {{0x68f90067,0xda01007d,0xf80710f7,0x21290510}},	//   rawd, _लटकत_, учен, _mbah_,
   {{0xf7450467,0x7bce11b9,0x68f90150,0x290403a9}},	//   реко, _gibu, sawd, _edma_,
   {{0x7f3c00c1,0x62fa0033,0x636d0032,0x2129001c}},	//   געוו, ংলায়_, _fúnj, _obah_,
   {{0x3f8a0283,0xdb150072,0x7bce0584,0x656200c4}},	//   zibu_, _tizó, _zibu, _cooh,
   {{0x7bce2767,0xb0c702d5,0x320b0034,0x671300a4}},	//   _yibu, रेमग, ącym_, _ठाऊक_,
   {{0x25a019d0,0x4225232c,0x21291d49,0x671c16e2}},	//   čila_, адов, _abah_, _नायक_,
   {{0xe29904b3,0x45d52768,0xe3b600d3,0x00000000}},	//   тан_, _тоес, рбэ_, --,
   {{0x69d80396,0x257b0139,0x798b2769,0xe6f00032}},	//   ívei, _dàlù_, nigw, _iṣẹd,
   {{0x3f8a068d,0x671c00af,0x00000000,0x00000000}},	//   tibu_, _नामक_, --, --,
   {{0xb4c11362,0x21290113,0xa3c22647,0x25710065}},	//   ंधी_, _ebah_, ्दः_, _kálo_,
   {{0x3f8a068d,0x7bce0991,0x0fc300d6,0x798b0ab9}},	//   ribu_, _ribu, ійсн, kigw,
   {{0x7bce276a,0x3f8a276b,0x25710579,0x4aa9009f}},	//   _sibu, sibu_, _málo_, _कड़व,
   {{0x3b86013f,0x9c870031,0x25710065,0xd7a500a4}},	// [1d00] алаг, vočí, _lálo_, खकाच,
   {{0xfbdf011b,0x6ffb0089,0x1db80096,0x29d70090}},	//   _trên_, _שפיג, _आठवत, _għak_,
   {{0x69c201a2,0xe8fa276c,0x7bce276d,0x25780381}},	//   tmoe, вле_, _vibu, _héle_,
   {{0xc8ca012b,0x636d0143,0xfd120037,0x7bce05bd}},	//   نوان_, _búnk, _بجد_, _wibu,
   {{0x7bce11b9,0x69c2276e,0x97c6276f,0xa01b0364}},	//   _tibu, rmoe, айде, rzög,
   {{0x637600d3,0x69c22770,0x6562008c,0x00000000}},	//   _mânc, smoe, _sooh, --,
   {{0x9c87025b,0xbcfb0113,0x798b2771,0xd6d90120}},	//   počí, _moén, bigw, уті_,
   {{0x29042772,0xa4f80470,0x636d2773,0x3426116a}},	//   _udma_, اکار_, _fúnk, афов,
   {{0xf1d00285,0x68ed0042,0x00000000,0x00000000}},	//   _संजन, ñade, --, --,
   {{0xf366117a,0x65620167,0x29c40294,0x76550103}},	//   ртин, _wooh, _ịchụ_, ógyí,
   {{0x1b0300c7,0x0bb700a1,0xa2a60285,0x81de0a43}},	//   র্কে_, שלים_, _घुश्, দীন_,
   {{0x672d00cb,0x51f710e0,0xa1941536,0x00000000}},	//   đaje, шнюю_, жаюч, --,
   {{0x63760161,0x04140081,0x49070096,0xe0df028d}},	//   _cânc, _তৈরী_, हणतो_, rcò_,
   {{0x93fb0054,0x257802c6,0x00000000,0x00000000}},	//   _ילדי, _déle_, --, --,
   {{0x63a82774,0x798b2775,0x00000000,0x00000000}},	//   modn, yigw, --, --,
   {{0x2129063f,0x2baf0fef,0x25780103,0xead00032}},	//   _ubah_, _जीजा, _féle_, _kẹfa_,
   {{0x25780139,0x91bc00ca,0x00000000,0x00000000}},	// [1d10] _géle_, _במהי, --, --,
   {{0x8ae702ec,0x3b542776,0x09de0081,0x3f152777}},	//   ріал, окур, _ডিজা, _удос,
   {{0xcfe200c7,0x69da0018,0x1fe20033,0x798b18fe}},	//   _বিএন, _étel, _বিএস, tigw,
   {{0x63a82778,0x2bd90a85,0x00000000,0x00000000}},	//   hodn, _ماسک_, --, --,
   {{0x8d5a0054,0xf1d002d5,0x66e502a0,0x00000000}},	//   _עכשי, _संघन, бола, --,
   {{0xcc3a0130,0xdc3a0130,0xf1ca0023,0x8038006e}},	//   _געשט, _געשר, _lạp_, ינדע_,
   {{0x798b0010,0x644601cd,0xb9e40120,0xa3c000c3}},	//   pigw, ækin, _міти, ंगई_,
   {{0x7bc52779,0xf1ca00de,0xddd501f9,0x00000000}},	//   lmhu, _nạp_, nyző, --,
   {{0x79890051,0xe80e034c,0x26130f78,0x636d0154}},	//   _imew, _सिया_, _धमकी_, _húni,
   {{0xf77311a2,0x63a8277a,0xc6a70b1b,0x8339007b}},	//   _بار_, godn, _креи, учит_,
   {{0x636d0018,0x216a0d76,0x6146277b,0x00000000}},	//   _júni, гини_, бена, --,
   {{0x249d0197,0xdb050212,0x636d167e,0xf1ca0023}},	//   _txwm_, llhä, _múni, _cạp_,
   {{0x63a80d94,0x232910a6,0x7989024a,0x00000000}},	//   bodn, _боли_, _mmew, --,
   {{0x2bdb05d4,0x533408d8,0xdee30f76,0x442f00dc}},	//   _बढ़ा, _мечт, зори, _ipg_,
   {{0x22580e74,0x31b201f9,0xdb05014b,0x00000000}},	//   ärkt_, házi_, cohé, --,
   {{0xf1d0277c,0xa19307ed,0x1c030006,0x442f00dc}},	//   _सूचन, _најч, _लिखल_, _kpg_,
   {{0xd1170eda,0x00000000,0x00000000,0x00000000}},	// [1d20] _הקפה_, --, --, --,
   {{0xf3f90f71,0x79890051,0x799b277d,0x636d003e}},	//   _আমার_, _amew, _ajuw, _búni,
   {{0x6e460979,0x2002277e,0x2571003e,0x7c3d02a1}},	//   _انجم, lski_, _páll_, _essr,
   {{0x9f490682,0xf8fa0037,0x442f0234,0xcd36001c}},	//   _hvað_, اءات_, _opg_, _اردب,
   {{0xbf9b020d,0x657b277f,0x443d0703,0x00000000}},	//   prêt, dhuh, _nsw_, --,
   {{0x6d4402a7,0x79890e62,0x3940013f,0x7c242780}},	//   ldia, _emew, žis_, mtir,
   {{0x644b2781,0x65be023b,0x8afb040a,0x7afe0483}},	//   _argi, hëhe, _תהלי, mapt,
   {{0x25a02782,0x63a800a5,0xb99600e3,0x657b2783}},	//   čilo_, wodn, _الرب, ghuh,
   {{0x7c242784,0x69c00084,0x6d442785,0xf1ca00de}},	//   ntir, _ihme, idia, _rạp_,
   {{0x20020335,0x68e201cb,0x7afe2786,0xf1ca00fe}},	//   dski_, lcod, napt, _sạp_,
   {{0x9f5d02b4,0xe1352787,0x442f057c,0xdb1c095d}},	//   _ìwé_, онны, _epg_, _chré,
   {{0x5a9b00c1,0x7afe00d1,0x63a82788,0xf6510018}},	//   רשטא, hapt, sodn, _کئے_,
   {{0x6d4402e0,0x63a800e9,0x7afe2789,0x644b1912}},	//   ddia, podn, kapt, _grgi,
   {{0x60d60018,0x6d44278a,0x7c24278b,0x7c3d01ff}},	//   _egym, edia, dtir, _rssr,
   {{0x41e61790,0xf1ca0019,0xdb1c0037,0xa2930120}},	//   _استف, _tạp_, _ghré, _наші,
   {{0x161902e8,0xd011097d,0x2002278c,0x7c24278d}},	//   नंतर_, _قلب_, bski_, ftir,
   {{0x7c2407ac,0xe520278e,0x442f0131,0x00000000}},	// [1d30] gtir, _यानि_, _xpg_, --,
   {{0x636d1094,0x2efa02ac,0x798900bd,0x00000000}},	//   _púni, _gepf_, _smew, --,
   {{0x6d440947,0x7c24278f,0x7a350037,0xce590e3a}},	//   bdia, atir, تفاص, _танц_,
   {{0xac192790,0x68e22791,0x7c242792,0x69c00094}},	//   _кому_, gcod, btir, _chme,
   {{0x7afe2793,0xe8f816dd,0x44240063,0xa3b8136b}},	//   bapt, слі_, jtm_, चता_,
   {{0x7afe2794,0xd7c80981,0x442f0d07,0xbae50076}},	//   capt, مونه_, _rpg_, _ذكري,
   {{0x442f0085,0x443d2795,0x00000000,0x00000000}},	//   _spg_, _ssw_, --, --,
   {{0x24092796,0x68e22797,0x442f030a,0x79890239}},	//   ании_, ccod, _ppg_, _umew,
   {{0x75ca00a5,0xdced0a39,0x00000000,0x00000000}},	//   _języ, jkač, --, --,
   {{0x657b0010,0xb80e00c3,0x2b430117,0x68fb01ec}},	//   shuh, _सितम_, _jajc_, _heud,
   {{0xcb1209c1,0x200200a5,0x68fb005c,0x7c2401e9}},	//   ולי_, wski_, _keud, ztir,
   {{0x200202e6,0x68fb025a,0x443d006c,0xa4f700d0}},	//   tski_, _jeud, _tsw_, _اکثر_,
   {{0x443d01bf,0x442f002b,0xbee5009d,0x68fb0441}},	//   _usw_, _upg_, कडून_, _meud,
   {{0x947406fa,0x68fb01b5,0xdb1c0037,0x65be023b}},	//   _عدنا, _leud, _thré, rëhe,
   {{0xfc3f11c4,0xdce40307,0x00000000,0x00000000}},	//   _así_, nkić, --, --,
   {{0x20022461,0x7c242798,0x7529008f,0x291f006c}},	//   pski_, ttir, nfez, _ncua_,
   {{0xab662799,0x6449279a,0x7afe279b,0x6fb60c5e}},	// [1d40] овал, nvei, tapt, _ومعا,
   {{0x6d44002b,0x2fd7001c,0x75e70233,0x00000000}},	//   sdia, _گوید_, _kızd, --,
   {{0x68e201cb,0xdce4050d,0xfc3f0af0,0x68fb279c}},	//   tcod, jkić, _esí_, _beud,
   {{0x68fb0441,0x671c00aa,0x7afe279d,0x23670154}},	//   _ceud, _नाहक_, sapt, _lonj_,
   {{0x68fb279e,0x183600ab,0x68ed04d8,0x68e20742}},	//   _deud, تراح, ñada, rcod,
   {{0x68e2279f,0x69d81e14,0x644927a0,0x7529010a}},	//   scod, íves, dvei, efez,
   {{0x7afc00ae,0x699600d3,0x637f02ac,0xd95a0284}},	//   _iert, _драх, _kênf, _краљ_,
   {{0x7ae9007e,0x8ebf0033,0x69dc27a1,0x2b430141}},	//   _đeti, _আলমগ, _iure, _zajc_,
   {{0x7afc27a2,0x6603023e,0x3946004b,0x00000000}},	//   _kert, asnk, mdos_, --,
   {{0x69dc27a3,0x394627a4,0x442400dc,0x68fb01e9}},	//   _kure, ldos_, rtm_, _zeud,
   {{0xc4e627a5,0xbcfb026e,0x394627a6,0x64490231}},	//   _джей, _eléy, odos_, avei,
   {{0x69dc27a7,0x3946226a,0x7afc0b7d,0x21200154}},	//   _mure, ndos_, _lert, _ccih_,
   {{0x81ba0081,0x394627a8,0x84960018,0x7afc27a9}},	//   _অংশ_, idos_, _بجائ, _oert,
   {{0x69dc0933,0x25a90ebd,0x7afc249e,0x67380dd9}},	//   _oure, čale_, _nert, nevj,
   {{0xccfb0291,0x645d007b,0xed8b0095,0x00000000}},	//   ића_, äsiv, асак_, --,
   {{0xdb1c0072,0x394401d3,0x7afc27aa,0xfc3f0a7f}},	//   _oiró, _nams_, _aert, _psí_,
   {{0x7afc0cfb,0x69dc27ab,0x0bd500e3,0x2139023b}},	// [1d50] _bert, _aure, سياح, mesh_,
   {{0x69dc27ac,0x7afc0b87,0x201927ad,0x3946001f}},	//   _bure, _cert, musi_, edos_,
   {{0x2019159d,0x7afc27ae,0xea000019,0x68fb037a}},	//   lusi_, _dert, _đảo_, _peud,
   {{0x69dc27af,0x3f9104a3,0x777a01e9,0x213927b0}},	//   _dure, lizu_, _altx, nesh_,
   {{0x69dc27b1,0x66e50e4a,0x201927b2,0xa3ca009d}},	//   _eure, пола, nusi_, लगा_,
   {{0x7afc27b3,0x39460b0b,0x213900dd,0x69dc27b4}},	//   _gert, ados_, hesh_, _fure,
   {{0x7c3901e8,0x7bdd27b5,0xf7700f36,0x69dc27b6}},	//   şarı, _husu, خان_, _gure,
   {{0x7bdd27b7,0x201927b8,0x7afc27b9,0x21390052}},	//   _kusu, kusi_, _zert, jesh_,
   {{0x201927ba,0x69dc27b9,0x7bdd27bb,0x752927bc}},	//   jusi_, _zure, _jusu, rfez,
   {{0x7bdd27bd,0x644927be,0x201927bf,0x25710088}},	//   _musu, rvei, dusi_, _máli_,
   {{0xcb1207a6,0x644927c0,0x7ae50013,0xa91d013f}},	//   עלט_, svei, icht, _amži,
   {{0x291d27c1,0x201927c2,0xb9230065,0xcf890089}},	//   ngwa_, fusi_, _aarẹ_, _גט_,
   {{0x201927c3,0x7bdd27c4,0x3f910022,0x31690634}},	//   gusi_, _nusu, fizu_, _doaz_,
   {{0xdb1c01b9,0x636d0076,0x7bd527c5,0x394600c6}},	//   _chrì, _cúnt, _nizu, zdos_,
   {{0xe2960dc0,0xed5a27c6,0x272f03a3,0x3ebe0578}},	//   _наш_, бов_, mını_, ått_,
   {{0x7afc10f3,0x201927c7,0x7bdd27c8,0xa0a627c9}},	//   _sert, busi_, _busu, _найд,
   {{0x7afc27ca,0x69dc27cb,0x7bdd0694,0xdca31107}},	// [1d60] _pert, _sure, _cusu, еати,
   {{0xef860a18,0x272f0511,0x394427cc,0x636d0139}},	//   _хлоп, nını_, _sams_, _gúnt,
   {{0x7afc27cd,0x19ba14fa,0x7bd50a00,0x7bdd002b}},	//   _vert, будь_, _dizu, _eusu,
   {{0x7ae5054f,0x7afc27ce,0x7bdd0baa,0xdb1c0bac}},	//   acht, _wert, _fusu, _piró,
   {{0x7afc03b4,0x2d9227cf,0x25ad0305,0x7bdd0193}},	//   _tert, miye_, doel_, _gusu,
   {{0x69dc27d0,0x6d4627d1,0x2d9227d2,0xa3c2000d}},	//   _ture, _haka, liye_, ्दछ_,
   {{0x6d4627d3,0x272f008e,0xfaa327d4,0x98ac00a7}},	//   _kaka, dını_, _заро, ılıq_,
   {{0x6d4627d5,0x2d9227d6,0x7ec70018,0xdb1c27d7}},	//   _jaka, niye_, lépé, _tiró,
   {{0x6d4627d8,0x7bdd27d9,0x66180146,0xb4c80789}},	//   _maka, _xusu, suvk, ोखे_,
   {{0x6d4627da,0x684327db,0x201927dc,0x29d703e5}},	//   _laka, _януа, vusi_, _għas_,
   {{0x2d9227dd,0x213900dd,0x25ad27de,0x69c80036}},	//   kiye_, tesh_, boel_, _èdes,
   {{0x6d4627df,0x201927e0,0x63640154,0x25ad03a9}},	//   _naka, tusi_, _jònz, coel_,
   {{0x2d9227e1,0x2139023b,0x645d27e2,0x2d801d42}},	//   diye_, resh_, äsit, dhie_,
   {{0x201927e3,0x6d4606a8,0x1be3009f,0x2139023b}},	//   rusi_, _aaka, _कंबल_, sesh_,
   {{0x201927e4,0x4ea424e9,0x7bdd27e5,0x213900dd}},	//   susi_, ерта, _susu, pesh_,
   {{0x2d8027e6,0x201927e7,0x6d4618c4,0x2d92023f}},	//   ghie_, pusi_, _caka, giye_,
   {{0x071c1e5e,0x6d4627e8,0xea000028,0x7ae527e9}},	// [1d70] _नांव_, _daka, _đạo_, tcht,
   {{0xe3b806d7,0x7ae501bf,0xad2701f3,0x0bb40686}},	//   nlı_, ucht, _کردو, ебую,
   {{0x7bd527ea,0x6d4627eb,0x68ed0fb6,0x2d9227ec}},	//   _vizu, _faka, ñado, biye_,
   {{0x2d8027ed,0x4426002b,0x7ae501bf,0x64420084}},	//   chie_, _oqo_, scht, _osoi,
   {{0x25ad01a2,0xe3b801e8,0x442627ee,0xb905009f}},	//   voel_, klı_, _nqo_, _नल_,
   {{0xaca30174,0x32050094,0xe80e0336,0xe3b8071d}},	//   _laịb, ysly_, _सिरा_, jlı_,
   {{0x6d4627ef,0x25ad0db1,0xe3b800a7,0xda34013f}},	//   _yaka, toel_, dlı_, _перы,
   {{0x5ebf0081,0xc17401c2,0xa3de02d5,0x1dbf2172}},	//   _আলাই, _kiɗe_, _दंश_, ्षित,
   {{0xe3b80740,0x272f08bb,0x290d27f0,0x31b20103}},	//   flı_, tını_, _idea_, zázs_,
   {{0x29d7003d,0x27ed27f1,0xd389004d,0x69cb27f2}},	//   _għar_, _iten_, ійне_, lmge,
   {{0x272f08f5,0xaca300ac,0x9f5900c2,0x25ad27f3}},	//   rını_, _baịb, issä_, poel_,
   {{0x272f0390,0x72070018,0xe3b800a7,0x645d007b}},	//   sını_, _ہفتہ_, alı_, äsis,
   {{0x6d4627f4,0xa01b0068,0xe3ae08a1,0xd469171b}},	//   _raka, szön, _аб_, _филе_,
   {{0x6d4627f5,0xdb1c00e3,0x2d9227f6,0x81bd01d3}},	//   _saka, _phrí, wiye_, ntēj,
   {{0x6d4627f7,0x2d9227f8,0xa2c901e4,0x2d8027f9}},	//   _paka, tiye_, हेश्, thie_,
   {{0xed570e96,0x9f5900c2,0x753b2153,0xa2a6058f}},	//   мос_, essä_, neuz, _घुट्,
   {{0x6d4627fa,0x2d9227fb,0x656b27fc,0x27ed27fd}},	// [1d80] _vaka, riye_, _mogh, _nten_,
   {{0x6d4627fe,0x2d9227ff,0x656b2800,0x290d2801}},	//   _waka, siye_, _logh, _adea_,
   {{0x6d462802,0x2d802803,0x637f2804,0x443f005c}},	//   _taka, phie_, _gêne, hwu_,
   {{0x3d1804a9,0x443f06c0,0xe3b80587,0x6d460027}},	//   _फाटे_, kwu_, zlı_, _uaka,
   {{0x7d042805,0xe3b807d1,0xd90d00d0,0xb8f6009d}},	//   mais, ylı_, صیل_, _सण_,
   {{0x7d042806,0x75220451,0x656b01b9,0x290d0113}},	//   lais, _scoz, _aogh, _edea_,
   {{0x27ed2807,0xa3c309c3,0x656b2808,0xa3c10f42}},	//   _eten_, ्षन_, _bogh, ंतन_,
   {{0x7d042809,0x25780257,0x753b0051,0x656b0a9a}},	//   nais, _vélo_, geuz, _cogh,
   {{0x656b280a,0xe3b803a3,0xa2d0280b,0x443f06c0}},	//   _dogh, tlı_, डेन्, gwu_,
   {{0x7d04280c,0x636d00b3,0x656b03dc,0x6724007e}},	//   hais, _búnq, _eogh, đijs,
   {{0x7d04280d,0x656b0a21,0x81bd0029,0xa3de245a}},	//   kais, _fogh, stēm, _दूर_,
   {{0x7d04280e,0xe3b80491,0x2d9e0103,0xc5f30327}},	//   jais, slı_, étel_, _ידע_,
   {{0x9f5900c2,0xe3b80233,0xdb1c009c,0x637f084e}},	//   yssä_, plı_, _ohrà, _sêne,
   {{0xe3b801d4,0x81bd00d9,0xd2502296,0xc05807bf}},	//   qlı_, otēk, _منت_, фію_,
   {{0xdfd4280f,0xd90414df,0x8d7700e3,0xaca30174}},	//   торы, _پی_, وارا, _mbụb,
   {{0x7d042810,0x656b2811,0x75200350,0x00000000}},	//   gais, _xogh, ngmz, --,
   {{0xfbdf2812,0xdb1c0441,0x2bbd00b6,0x3b552813}},	// [1d90] _quê_, _bhrà, ्गला, нкар,
   {{0x31a403a3,0xa3c31ab1,0xdb1c01f7,0x60c02814}},	//   mıza_, ्षय_, _chrà, ümme,
   {{0x7d042815,0x27ed2816,0xdb1c2817,0x290d00f9}},	//   bais, _sten_, _virð, _pdea_,
   {{0xaca30294,0x7d042818,0x00000000,0x00000000}},	//   _abụb, cais, --, --,
   {{0x656b0514,0x31a403a3,0x69cb2819,0xa3c300c3}},	//   _rogh, nıza_, rmge, ्षम_,
   {{0xf1ca0019,0x656b00e3,0xdb07004d,0xdb1c0441}},	//   _dạy_, _sogh, _skjæ, _ghrà,
   {{0x81bd0029,0xd90f00d0,0x45d5016e,0xbbbd05a5}},	//   rtēj, _نیا_, нцит, ्गीक,
   {{0x79820067,0x443f0034,0x290d281a,0x81bd01d3}},	//   chow, twu_, _udea_, stēj,
   {{0x27ed02ec,0x656b0451,0xfbdf281b,0x753b281c}},	//   _uten_, _vogh, _trêu_, reuz,
   {{0x2d8c020d,0xc48205b6,0xc8a800bc,0x00000000}},	//   édez_, ульк, _छुटट, --,
   {{0x68e40039,0x656b0037,0x1ddb00b7,0x443f0027}},	//   žide, _togh, _मंगत, swu_,
   {{0x92df0081,0xe4510037,0x31a40233,0x00000000}},	//   তরে_, _مضت_, fıza_, --,
   {{0x600702ec,0x7d04281d,0x00000000,0x00000000}},	//   нням_, vais, --, --,
   {{0xdb1c0094,0x00000000,0x00000000,0x00000000}},	//   _ohrá, --, --, --,
   {{0xf77200f5,0x7d04281e,0xed5a124c,0x00000000}},	//   נקל_, tais, пов_, --,
   {{0x61ee058a,0x7bc713db,0xdb1c01f7,0x5d6700d3}},	//   íble, _ahju, _shrà, нисм_,
   {{0x7d04281f,0xdee62820,0xc19b00ca,0xdb1c01b9}},	// [1da0] rais, _попи, _משקי, _phrà,
   {{0x7d042821,0x60c40060,0x8fa60d5b,0xdb1c0037}},	//   sais, _izim, _سمجه, _bhrá,
   {{0xdb1c0074,0xe9da225d,0xc332028c,0x4efb00a1}},	//   _chrá, чке_, רוב_, _מהיו,
   {{0xfbdf0257,0x4aaf0096,0x307a006e,0x2571003e}},	//   _prêt_, _जुळव, ּאַנ, _máls_,
   {{0xb8e80ccb,0xdb1c0441,0x75e7047e,0x00000000}},	//   _उर_, _thrà, _rıza, --,
   {{0x38cb1e49,0x60c42822,0xfc3f0042,0x2bd80034}},	//   سانی_, _mzim, _uxía_, _भूचा,
   {{0xdb1c0076,0xfaa60095,0xe2870037,0x00000000}},	//   _ghrá, _чаво, _إذ_, --,
   {{0x60c42823,0x04660221,0x00000000,0x00000000}},	//   _ozim, етом, --, --,
   {{0x60c42824,0x81e70033,0xe8e00174,0x18a32825}},	//   _nzim, মীম_, niọs_, _батм,
   {{0x29060062,0x00000000,0x00000000,0x00000000}},	//   laoa_, --, --, --,
   {{0x60c42826,0x63760231,0x00000000,0x00000000}},	//   _azim, _jâni, --, --,
   {{0x4a9b00c1,0x546a008f,0xc486002d,0xbcfb00fd}},	//   לייג, _наем_, _плек, _inég,
   {{0xc953040a,0x25710103,0x06d50033,0x74132827}},	//   אמר_, _vált_, _স্পি, _مونا,
   {{0xa3c300e2,0x60c400d9,0x25a002dd,0xadc40065}},	//   ्षण_, _dzim, čilu_, _ikẹt,
   {{0x60c42828,0x5e5800ae,0x00000000,0x00000000}},	//   _ezim, ниря_, --, --,
   {{0x3eba0120,0x2906024a,0x212f009c,0x00000000}},	//   _dypt_, jaoa_, _ùgh_, --,
   {{0x2ef50465,0xe802030b,0xafdb00f2,0xdb1c0076}},	// [1db0] _изпр, रीमा_, rvøs, _shrá,
   {{0xc5f60081,0x200b2829,0x8aa7282a,0x7e610212}},	//   _ঘটনা_, msci_, нред, älps,
   {{0xd5df000f,0x321e282b,0xdd91001c,0x200b0036}},	//   _पूंज, nuty_, _نود_, lsci_,
   {{0xc17403e3,0x7ec70065,0x1a680281,0x27e60381}},	//   _kiɗa_, _eépí, ریقی_, fqon_,
   {{0x6d5d08f8,0xdbdb0032,0x200b0036,0x00000000}},	//   _insa, _fàáj, nsci_, --,
   {{0x7c2d01e5,0x3949282c,0x6d4d0b54,0xdb1c0037}},	//   mtar, žas_, ldaa, _thrá,
   {{0xfbdf0396,0xe708012b,0xadc40065,0xcf5800a1}},	//   _três_, رتون_, _akẹt, תבות_,
   {{0x6d4d282d,0x4904177a,0x7c2d282e,0xe4590927}},	//   ndaa, _موفق, otar, джи_,
   {{0x200b00cc,0x6d5d00f9,0xd6db282f,0x62880031}},	//   jsci_, _mnsa, _ете_, ezdo,
   {{0x7c2d2830,0x69da2831,0x6d4d008c,0x27ff0139}},	//   itar, _éter, hdaa, _iwun_,
   {{0x7c2d2832,0x69c901bb,0x6f070220,0x6d5d2833}},	//   htar, _khee, dajc, _onsa,
   {{0x04b500e5,0xafe610e0,0x00000000,0x00000000}},	//   _исля, комл, --, --,
   {{0x6d4d2834,0x7c2d023b,0x1b0c0033,0x69c901b9}},	//   ddaa, jtar, স্টে_, _mhee,
   {{0x6d5d2835,0x6d4d2836,0x4255002d,0x321e00e2}},	//   _ansa, edaa, _атит, buty_,
   {{0x7c2d2837,0x20192838,0x637f020d,0x3f810206}},	//   etar, arsi_, _gêna, _dlhu_,
   {{0xe8021376,0x656900dd,0x6d4d2839,0x69db0113}},	//   रीडा_, njeh, gdaa, _niue,
   {{0x60c408a9,0x7c2d283a,0x1ae6283b,0x6376020a}},	// [1dc0] _uzim, gtar, возм, _sâni,
   {{0x6d5d283c,0x61e3283d,0xa3c105d4,0x6f0700e9}},	//   _ensa, _kunl, ंति_, cajc,
   {{0x442d283e,0xbcfb283f,0x3f98005f,0x7c2d2840}},	//   hte_, _poét, miru_, atar,
   {{0x3f98063f,0x6d4d008a,0x7c2d2841,0x69c92842}},	//   liru_, cdaa, btar, _chee,
   {{0x69c90694,0x7c2d2843,0xa3c10f73,0x69db05fe}},	//   _dhee, ctar, ंता_, _diue,
   {{0x442d2844,0xbb76008f,0xa9250031,0x63760131}},	//   dte_, _румъ, _rožň, _tâni,
   {{0x442d24d4,0xe1e70214,0x00000000,0x00000000}},	//   ete_, _خس_, --, --,
   {{0x7bdc2845,0x657b2846,0x628815fe,0x3f982847}},	//   _hiru, gkuh, vzdo, hiru_,
   {{0x442d2848,0x75e701e8,0x37e600d6,0x23470018}},	//   gte_, _hızl, _розг, چسپی_,
   {{0x671c10e9,0x61e30702,0x201908a9,0x75e701e8}},	//   _नाटक_, _bunl, vrsi_, _kızl,
   {{0x442d2849,0x7bdc284a,0xf3630fe9,0x6d4d008a}},	//   ate_, _miru, ртын, ydaa,
   {{0x442d284b,0x7c2d284c,0xfd550134,0x29040239}},	//   bte_, ytar, _draị, _jema_,
   {{0x442d284d,0x29040051,0x7c2d284e,0x3f8101fa}},	//   cte_, _mema_, xtar, _plhu_,
   {{0x2904284f,0xfd550294,0x7bdc0ee7,0xdce601d3}},	//   _lema_, _fraị, _niru, _rokā,
   {{0x7c2d0034,0x6d4d000b,0x91e30291,0xdced007e}},	//   wtar, tdaa, _које, nkać,
   {{0x7c2d2850,0x672d0106,0xdd1100a7,0xa3e71115}},	//   ttar, đaji, _düşd, _मूड_,
   {{0x6d4d2851,0x7bdc2852,0xd1b8110a,0x69c91c02}},	// [1dd0] rdaa, _biru, _جاوا_, _rhee,
   {{0x09cb0c16,0x2d820db8,0xd9cb2853,0x7bdc0623}},	//   िष्य, _elke_, िष्ट, _ciru,
   {{0x442d2854,0x7bdc2855,0x69c90197,0x29042856}},	//   zte_, _diru, _phee, _bema_,
   {{0x7c2d074a,0x6d5d1098,0x442d2857,0x27e400a4}},	//   ptar, _unsa, yte_, _bumn_,
   {{0x442d2858,0x7bdc2859,0x69db0428,0xec3500c1}},	//   xte_, _firu, _viue, _גאָר_,
   {{0x442d025b,0x7bdc285a,0xf1bf285b,0x69c9285c}},	//   vte_, _giru, hlá_, _whee,
   {{0x69c9285d,0xc79400cd,0x6abc0150,0x442d285e}},	//   _thee, جشنب, _gyrf, wte_,
   {{0x7bdc285f,0x6f0500b6,0x75451a0c,0xa3e70980}},	//   _ziru, _lehc, униз, _मंद_,
   {{0x442d2860,0xf1bf0038,0x77930068,0x25a605aa}},	//   ute_, dlá_, _پیغا, _djol_,
   {{0xe1f90a54,0x657b2861,0x61e32862,0xf7700192}},	//   нго_, skuh, _punl, _وال_,
   {{0x35f52863,0x656903c6,0x395f2864,0x25a60212}},	//   _спер, pjeh, _knus_, _fjol_,
   {{0x06d50033,0x3f9805bd,0x00000000,0x00000000}},	//   _স্থি, wiru_, --, --,
   {{0x394d02ad,0x442d023b,0xdb150094,0xd0960ae3}},	//   _maes_, qte_, _ekzé, ушны,
   {{0x749a2865,0x649a0130,0x61e30139,0x25bf2866}},	//   _אינפ, _אינה, _tunl, llul_,
   {{0xe1f1172a,0x20002867,0x3f982868,0x61e30270}},	//   _است_, _wwii_, riru_, _uunl,
   {{0x0ce20081,0x2258052f,0x3f982869,0x7f9400a7}},	//   বর্ত, ærke_, siru_, _müqə,
   {{0x3f980106,0x64440b14,0x25bf00ae,0x2904286a}},	// [1de0] piru_, _šiiz, ilul_, _rema_,
   {{0xdd040dea,0x2904286b,0x09dc0096,0x69c3020d}},	//   ısın, _sema_, यद्य, înen,
   {{0x75e70092,0x7bdc286c,0x2904286d,0x00000000}},	//   _qızl, _viru, _pema_, --,
   {{0x394d0850,0x25780103,0xdcf7020a,0x7bdc286e}},	//   _caes_, _téli_, ăcăr, _wiru,
   {{0x29040051,0x9f40009c,0x00000000,0x00000000}},	//   _vema_, _stiù_, --, --,
   {{0x6fb4000f,0x7d06286f,0x29042822,0xc3190081}},	//   ंकिं, _heks, _wema_, ত্তি_,
   {{0x7d062870,0xfbde0072,0x637600ae,0x394d00f0}},	//   _keks, _iiª_, _mânt, _faes_,
   {{0x782600e3,0x746a0084,0x5e5700c1,0x81bd00d9}},	//   _معطل, еров_, ריקע_, ntēt,
   {{0x644d007e,0x5fb4023a,0x49910401,0xa3e70ff9}},	//   _šair, ंकाल, _بینر, _मूद_,
   {{0x7d060b85,0x883b00ca,0x25bf00ae,0x38cb0281}},	//   _leks, _אתמו, alul_, _ساقی_,
   {{0x4ebf00c7,0xf1bf0031,0x25bf020a,0x877b006e}},	//   _আল্ল, tlá_, blul_, _ראבי,
   {{0x25bf00ae,0x6fc009b5,0x00000000,0x00000000}},	//   clul_, böck, --, --,
   {{0x33f600ae,0x637f0231,0x8cb00ff9,0x6376044c}},	//   _счес, _gêno, _अँगो, _sânu,
   {{0x637600d3,0xf1bf035d,0x1b1a0033,0x00000000}},	//   _cânt, slá_, ন্তে_, --,
   {{0xa3c316e2,0xa3c11493,0x7d062871,0x3da72872}},	//   ्षर_, ंतर_, _beks, граб,
   {{0x9e430146,0xfc15002d,0x00000000,0x00000000}},	//   žďov, имбэ, --, --,
   {{0x7d062873,0xbcfb0610,0x6376020a,0xd0110d83}},	// [1df0] _deks, _anéc, _fânt, _بلخ_,
   {{0x7d060270,0x3d1b0139,0x3dc006a8,0x395f2874}},	//   _eeks, _bàwà_, aliw_, _snus_,
   {{0x394d2875,0x7d0601f9,0x00000000,0x00000000}},	//   _paes_, _feks, --, --,
   {{0x4dfa0130,0xa9072876,0x7d061cab,0x00000000}},	//   _שפרא, ابان, _geks, --,
   {{0xd7050b1e,0x1b1a0033,0x00000000,0x00000000}},	//   азли, ন্ধে_, --, --,
   {{0xe7392877,0x257801dc,0x6b810294,0x394d01cb}},	//   тек_, _mélu_, ịgbo, _waes_,
   {{0x6d4f2878,0x25bf00d3,0x27f80087,0x7c3d01ff}},	//   _kaca, tlul_, _črne_, _hpsr,
   {{0x395f2879,0x6d4f287a,0x2d89287b,0x6fc002db}},	//   _unus_, _jaca, nhae_, töck,
   {{0xb81c0d7e,0x87271850,0x64a5287c,0x27f8025b}},	//   _नियम_, _معام, рапа, čený_,
   {{0x6d4f0694,0x00000000,0x00000000,0x00000000}},	//   _laca, --, --, --,
   {{0xb1130129,0x49b80103,0x25bf287d,0x255e0174}},	//   _tụle, _شاہد_, plul_, ọlam_,
   {{0x249600bf,0x6d4f0188,0x672d0106,0xe80200c3}},	//   انید_, _naca, đaju, रीवा_,
   {{0x764e0088,0x7d060088,0x63761497,0x00000000}},	//   _ábyr, _reks, _pânt, --,
   {{0x64590090,0x248d01fa,0x6376020a,0x00000000}},	//   _irwi, mzem_, _dâns, --,
   {{0xe81c0251,0x2d9600c6,0x7d06287e,0x3ebe0088}},	//   _निभा_, арас, _peks, ætt_,
   {{0x6d4f287f,0x6459007f,0xa1930b36,0x00000000}},	//   _caca, _krwi, _мајч, --,
   {{0x7d0600f3,0x6d4f0188,0x81bd01d3,0x63760231}},	// [1e00] _veks, _daca, rtēt, _tânt,
   {{0x644b00bf,0x6d4f01f7,0x25780088,0x29d70090}},	//   _msgi, _eaca, _hélt_, _għaz_,
   {{0x7d0601ce,0x6d4f0013,0x7c3d2880,0x81e70081}},	//   _teks, _faca, _epsr, মীর_,
   {{0x6d4f2881,0x323600c1,0x2d8918c7,0x6e3e0063}},	//   _gaca, יטען_, chae_, _ippb,
   {{0x6d442882,0x69da0036,0x7c3d0062,0xa01b0103}},	//   meia, _ètem, _gpsr, szöv,
   {{0x2d8000a5,0x248d2702,0x6d4f2883,0xab090182}},	//   lkie_, dzem_, _zaca, _متفق_,
   {{0xfaa32884,0xeb970b3b,0x6d4f2885,0x64592886}},	//   _даро, _тир_, _yaca, _arwi,
   {{0x2d800665,0xdb0700f3,0x6d4f002b,0xa3e700c3}},	//   nkie_, _skjø, _xaca, _मूह_,
   {{0xb71600cd,0xa3c300a4,0x69c200bc,0xf4862887}},	//   _نباش, ्षं_, mloe, руйн,
   {{0x69c20150,0x443d0167,0x6e3e004d,0x6d442888}},	//   lloe, _dpw_, _oppb, heia,
   {{0x2d800665,0x0cc30abe,0x64592889,0x443d0063}},	//   kkie_, _शर्म, _erwi, _epw_,
   {{0x7c241fce,0xdb1c0503,0x00000000,0x00000000}},	//   kuir, _chrú, --, --,
   {{0x6d44288a,0x7bce0063,0x248d0034,0xdb050072}},	//   deia, _ohbu, czem_, rohú,
   {{0x6d4f288b,0x7c24288c,0xdb050149,0x4ea7288d}},	//   _saca, duir, llhö, арба,
   {{0x6d4f288e,0x8de8036a,0xf206008f,0x69c201c8}},	//   _paca, ифта_, _тяло, kloe,
   {{0x69c80029,0xdb1c0037,0xccf80284,0x7c24288f}},	//   _ūden, _ghrú, ићу_, fuir,
   {{0x44242890,0x65620074,0x7bce02ef,0x69c300fd}},	// [1e10] num_, _mnoh, _bhbu, înem,
   {{0x25a91c56,0x6d4f2891,0xde470504,0x68e400d4}},	//   čali_, _waca, _پیرو_, židl,
   {{0x6d4f0422,0x442411b9,0xa91d0220,0x5a3510b8}},	//   _taca, hum_, _dlžn, снет,
   {{0x44242892,0x2d802893,0x79a423c3,0xac1900d6}},	//   kum_, ckie_, орче, _йому_,
   {{0x765a0067,0x44242894,0xbcfb0037,0x7c2400ae}},	//   _arty, jum_, _gnéa, cuir,
   {{0xbb85054f,0x44242895,0x7d0d2896,0x248d02dd}},	//   _السي, dum_, laas, vzem_,
   {{0x636d2897,0x69c22898,0xff1800ca,0x443d2899}},	//   _gúny, bloe, בקות_, _spw_,
   {{0x7d0d289a,0x44240102,0x248d05fe,0xa01b01bf}},	//   naas, fum_, tzem_, nzös,
   {{0x4424289b,0xe3b91510,0x00000000,0x00000000}},	//   gum_, лби_, --, --,
   {{0xd7740080,0x7d0d289c,0x248d289d,0x2d8001e9}},	//   _والع, haas, rzem_, zkie_,
   {{0x7d0d289e,0x248d1feb,0xdb1c01f7,0x29d702a1}},	//   kaas, szem_, _chrù, _bħax_,
   {{0x7d0d289f,0x442428a0,0xdb1c01b9,0x00000000}},	//   jaas, bum_, _dhrù, --,
   {{0x442428a1,0x7d0d0694,0x55520068,0x645902a4}},	//   cum_, daas, _رپور, _urwi,
   {{0xa0270102,0x752928a2,0x644900f0,0x00000000}},	//   _stöð, lgez, mwei, --,
   {{0x51f51857,0x644901bf,0x7d0d1e09,0xdb1c009c}},	//   _استر, lwei, faas, _ghrù,
   {{0x7d0d28a3,0x752928a4,0x7c2428a5,0x29d703e5}},	//   gaas, ngez, tuir, _għax_,
   {{0x69c201a2,0x644902e2,0x3b861b48,0x2d800abf}},	// [1e20] vloe, nwei, благ, rkie_,
   {{0x2d8028a6,0x4f2607df,0x7c2428a7,0xa01b01f9}},	//   skie_, _удоб, ruir, rzöt,
   {{0x644928a8,0x7d0d28a9,0x7c2408a9,0x6e3e1df0}},	//   hwei, baas, suir, _uppb,
   {{0x442428aa,0x7529029a,0x6f0e01c2,0x645501d3}},	//   yum_, jgez, labc, āzij,
   {{0x7c2428ab,0xe80b000f,0xa3e71358,0x44241a4a}},	//   quir, _सौदा_, _मूल_, xum_,
   {{0x64490150,0x6f0e0d2a,0x9f4000b3,0x69c228ac}},	//   dwei, nabc, _juià_, sloe,
   {{0x442428ad,0x69c21030,0x3f9a0063,0x75290364}},	//   wum_, ploe, _mmpu_, fgez,
   {{0x752928ae,0x64490364,0x9f8400c2,0x3e580383}},	//   ggez, fwei, löä_, _mčt_,
   {{0x6449133e,0x394628af,0x81ae0033,0x77ca28b0}},	//   gwei, meos_, কতা_, _благ_,
   {{0x442428b1,0xf36628b2,0x39461ba6,0xa3e7009d}},	//   rum_, стин, leos_, _मूळ_,
   {{0x7d0d025e,0xb7d70c5e,0x3e580383,0x6f0e00ee}},	//   yaas, _اولا_, _nčt_, dabc,
   {{0x798200a5,0x4424003e,0x394628b3,0x65620084}},	//   nkow, pum_, neos_, _unoh,
   {{0x54330688,0x657d02c3,0x7d0d28b4,0x00000000}},	//   _فرور, öshe, vaas, --,
   {{0x7d0d28b5,0x3e580383,0x6f0e01c2,0x2d9928b6}},	//   waas, _bčt_, gabc, _smse_,
   {{0x7d0d28b7,0x63ba109b,0x7a1c00d3,0x877b0089}},	//   taas, motn, nătă, נאלי,
   {{0x63ba02dd,0xdd940138,0x3253008f,0x3f9a00d1}},	//   lotn, пасы, _хвър, _empu_,
   {{0x7d0d28b8,0x79820034,0x2d5800c2,0xdb9928b9}},	// [1e30] raas, dkow, щить_, авач_,
   {{0x7d0d28ba,0x3e5806a3,0x5b1528bb,0x60cd1937}},	//   saas, _fčt_, імет, _izam,
   {{0x27f80087,0x39460610,0x64490364,0x7d0d28bc}},	//   _črna_, feos_, zwei, paas,
   {{0x41c90403,0xf1c904f8,0x63ba28bd,0x61ea28be}},	//   रतिस, रतिन, hotn, _mufl,
   {{0x18691d5c,0x63ba28bf,0xf8b10504,0x00000000}},	//   рали_, kotn, ذکر_, --,
   {{0x36190084,0xa09c00c1,0xb09c006e,0x60cd28c0}},	//   ацию_, ניגט, ניגר, _mzam,
   {{0x752901c0,0x994d0220,0x63ba0167,0x39460328}},	//   tgez, môžu_, dotn, beos_,
   {{0x644928c1,0xdb1c2502,0x394609d3,0xe57928c2}},	//   twei, _akrè, ceos_, рзи_,
   {{0x290f28c3,0xe10100c7,0x79890139,0x752928c4}},	//   maga_, ্লাহ_, _ilew, rgez,
   {{0x290f28c5,0x644928c6,0x752928c7,0x00000000}},	//   laga_, rwei, sgez, --,
   {{0x644928c8,0x60cd28c9,0x76ab28ca,0x79892502}},	//   swei, _azam, _став_, _klew,
   {{0x290f28cb,0xc17401c2,0x61ea28cc,0x98a4009e}},	//   naga_, _kiɗi_, _dufl, _qamħ_,
   {{0x799b0361,0x798902a1,0x637f00fe,0xafdb0120}},	//   _mmuw, _mlew, _lêni, lvøy,
   {{0x60cd050d,0xd347001c,0x79890178,0x56b5006e}},	//   _dzam, _ایده_, _llew, ַפּן_,
   {{0x290f28cd,0xdee328ce,0xe2960036,0x798928cf}},	//   kaga_, дори, _маш_, _olew,
   {{0xa3c30bd9,0xa0a6004d,0x72420018,0xb4f9006e}},	//   ्षक_, _майд, _کھیل, שפּי,
   {{0x290f28d0,0x9f8400c2,0xada30231,0xa01b0103}},	// [1e40] daga_, töä_, фатл, ször,
   {{0x76410021,0xa2d00789,0x61e428d1,0x798928d2}},	//   _oply, डेक्, _hiil, _alew,
   {{0x79820067,0x61e428d3,0x9f40016d,0x8a0601ce}},	//   tkow, _kiil, _guiá_, ізде,
   {{0x5f46037f,0xed5a28d4,0x08c61e13,0x290f28d5}},	//   _انگل, _том_, обен, gaga_,
   {{0x798228d6,0x3946222b,0x61e428d7,0x798901dc}},	//   rkow, reos_, _miil, _dlew,
   {{0x798928d8,0x39460fb6,0x798200a5,0x39520138}},	//   _elew, seos_, skow, žys_,
   {{0x63ba28d9,0x290f0549,0x394604d8,0x637f016d}},	//   votn, baga_, peos_, _gêni,
   {{0x61e40857,0x6d5628da,0x290f28db,0x63ba0034}},	//   _niil, ndya, caga_, wotn,
   {{0x98a328dc,0x61ea002d,0x60c428dd,0x7c360429}},	//   _жите, _sufl, _nyim, ntyr,
   {{0x61e4009c,0x63a80167,0xd37a23b9,0xdb17002b}},	//   _aiil, undn, рчи_, toxé,
   {{0x63ba28de,0x326600d6,0xa3ab02d5,0x60cd2214}},	//   rotn, ітов, _गदर_, _szam,
   {{0x63ba28df,0x60c405bd,0xdb17002b,0x61e4008c}},	//   sotn, _byim, roxé, _ciil,
   {{0x63ba0087,0x9f490161,0x60c405bd,0x490b10e9}},	//   potn, _itaú_, _cyim, ारतो_,
   {{0x290f28e0,0x60cd0087,0xa294224a,0xdb170072}},	//   zaga_, _vzam, _налі, poxé,
   {{0x290f28e1,0xdd9b1d18,0x3f83003e,0x61e428e2}},	//   yaga_, аша_, rkju_, _fiil,
   {{0xf1a400d3,0x3f8328e3,0x1b040081,0x61e40009}},	//   _орын, skju_, _লাগে_, _giil,
   {{0x6ebb04dd,0x60cd28e4,0x290f28e5,0x637f0131}},	// [1e50] _शुरु, _uzam, vaga_, _sêni,
   {{0x69c022bb,0x637f0161,0xc17401c2,0xddeb001c}},	//   _akme, _pêni, _riɗi_, _پرده_,
   {{0xdced084f,0x290f28e6,0xdb07003e,0xfc3f00fe}},	//   ljač, taga_, _skjó, _axít_,
   {{0x20090d2a,0xe81c0287,0x00000000,0x00000000}},	//   _kwai_, _निशा_, --, --,
   {{0x290f28e7,0x64460092,0xf84b00ae,0x764100d4}},	//   raga_, çkil, рчей_, _sply,
   {{0x290f28e8,0x637f001f,0x69c0026a,0x200928e9}},	//   saga_, _têni, _ekme, _mwai_,
   {{0x64420ba0,0xf96b28ea,0x00000000,0x00000000}},	//   _apoi, _край_, --, --,
   {{0xe79500d0,0x76410220,0x799b0bb6,0x64420037}},	//   _کارک, _vply, _umuw, _bpoi,
   {{0xdced1419,0xd7f8090f,0x68e90090,0x00000000}},	//   jjač, _дух_, _iged, --,
   {{0x61e4289c,0xdced042d,0x69d928eb,0x60c40079}},	//   _siil, djač, lmwe, _ryim,
   {{0x4b7c0130,0x76410146,0x61e4032c,0xbcfb00fc}},	//   יאזו, _uply, _piil, _aném,
   {{0xe8020976,0x644f052f,0x27ed03a9,0x68e90090}},	//   रीका_, æcis, _kuen_, _jged,
   {{0x27e520bb,0x61e428ec,0x27ed01ff,0x68e902a1}},	//   _kiln_, _viil, _juen_, _mged,
   {{0x61e4008a,0xdce40995,0x2d8b0231,0x221500e5}},	//   _wiil, ljić, _alce_, _ефир,
   {{0x63a128ed,0x68e928ee,0x257100d4,0x61e428ef}},	//   miln, _oged, _sály_, _tiil,
   {{0x68e928f0,0xdce403d6,0x63a12516,0x65790188}},	//   _nged, njić, liln, _jowh,
   {{0x27ed0a00,0x8c4328f1,0x27f80087,0x6b810174}},	// [1e60] _nuen_, нете, _črno_, _ịgak,
   {{0xe7ef0251,0x63a11d67,0x68e9059f,0x69d90381}},	//   _चढ़ा_, niln, _aged, emwe,
   {{0x7c3617d2,0x6ac600e3,0x62810891,0x5eda0033}},	//   styr, أقام, nylo, _ব্রে,
   {{0xb4ea007d,0x27ed0081,0x290d002d,0x7e6101c5}},	//   _मले_, _buen_, _ceea_, ælpe,
   {{0xa3cb1115,0x7d041d60,0x63a128f2,0x9f410113}},	//   लता_, mbis, kiln, _sihé_,
   {{0x26c5000d,0x27ed02a7,0x69d928f3,0x68ff0092}},	//   _bylo_, _duen_, amwe, ıqda,
   {{0x63a128f4,0x68ed28f5,0x6b6304a1,0xaa430975}},	//   diln, žada, _якра, _перл,
   {{0xb608030b,0x7f8b0092,0x7d0428f6,0xe944010d}},	//   jišť, _müqa, nbis, _ترسی,
   {{0xdb050610,0x7d0428f7,0xbcfb0031,0x26081c05}},	//   cohó, ibis, _poéz, _सबकी_,
   {{0xfbbe1860,0x63a11a79,0x57fb00a1,0xb5fc009e}},	//   ्तिम, giln, _ללמו, _arġe,
   {{0x27ed03f3,0x20090a4b,0x00000000,0x00000000}},	//   _zuen_, _swai_, --, --,
   {{0xa3e717ff,0x7c2428f8,0x320200d4,0x63a101b9}},	//   _मूक_, krir, ďky_, ailn,
   {{0x63a128f9,0x533400c2,0x7d0428fa,0xfbbe28fb}},	//   biln, _желт, dbis, ्ताम,
   {{0x7c2428fc,0x7d0400bc,0x00000000,0x00000000}},	//   drir, ebis, --, --,
   {{0xdced1197,0x433b00a1,0x777a28fd,0xe3b3006e}},	//   sjač, _העוב, _motx, _אױס_,
   {{0x7c2428fe,0x7d041ba1,0xb60614f3,0x3eac00d8}},	//   frir, gbis, mošć, _šitý_,
   {{0x7c2428ff,0xb6061197,0x00000000,0x00000000}},	// [1e70] grir, lošć, --, --,
   {{0x3b5407bf,0x44240a1b,0x2fc700fe,0xeb9b01f9}},	//   нкур, irm_, _óng_, حضرت_,
   {{0xb6060039,0x7c242900,0xbefb0285,0x00000000}},	//   nošć, arir, ्रीन_, --,
   {{0xdb1c0076,0x442400d4,0xf1bf0231,0x00000000}},	//   _bhró, krm_, noá_, --,
   {{0x27ed2901,0xdb1722e7,0xdb1c2902,0x7c2400fd}},	//   _quen_, loxí, _chró, crir,
   {{0x777a0472,0x3dc92903,0xf7710037,0x7d1d080e}},	//   _cotx, llaw_, ضات_, _hdss,
   {{0x63a12904,0x44240090,0x7d0f0103,0x777a01ff}},	//   viln, erm_, _kecs, _dotx,
   {{0xb60600cb,0x63a10034,0x3dc90eaa,0x27ed007b}},	//   došć, wiln, nlaw_, _tuen_,
   {{0x63a12905,0x69c300fd,0x3dc90270,0x753b23ca}},	//   tiln, îneu, ilaw_, rfuz,
   {{0x645b2906,0x62812907,0x7d0f0103,0x00000000}},	//   rvui, tylo, _lecs, --,
   {{0x63a102dd,0x3ce60220,0xb6062908,0x3dc90bb6}},	//   riln, ľovi_, gošć, klaw_,
   {{0xa0a60307,0x7c24003e,0x777a01ff,0x3ce60206}},	//   дамд, yrir, _zotx, žovi_,
   {{0x63a12909,0x3dc902c9,0xbcfb0220,0x31b90094}},	//   piln, dlaw_, _inéh, nézy_,
   {{0x7c24290a,0xf8ab00fe,0x637f0231,0x7df500c6}},	//   vrir, _đời_, _cênt, _sąsa,
   {{0xafe30036,0x7d0f0103,0xdb170042,0x25ad0ac1}},	//   торл, _becs, goxí, onel_,
   {{0x25ad290b,0x7c24290c,0x25bf020a,0x637f0231}},	//   nnel_, trir, noul_, _vênu,
   {{0x7d04290d,0xdca3290e,0x629c1515,0xa01b00c2}},	// [1e80] rbis, вати, úrov, lyön,
   {{0x25bf022b,0x7c2402a7,0xdcef020a,0x637f0231}},	//   houl_, rrir, _pocă, _tênu,
   {{0xdb1c01f7,0x68ed0031,0x3dc900f0,0x00000000}},	//   _bhrò, ľadn, blaw_, --,
   {{0x7c24008f,0x3dc9290f,0xdb1c033f,0xda650037}},	//   prir, claw_, _phró, عالي,
   {{0xb8f60d0b,0xaca40174,0xdb1c01b9,0x25bf2910}},	//   _हर_, _maịs, _dhrò, doul_,
   {{0x4b5500e5,0x00000000,0x00000000,0x00000000}},	//   _пъст, --, --, --,
   {{0x2b580095,0x9f8d003e,0x00000000,0x00000000}},	//   _iarc_, nþá_, --, --,
   {{0xa5341940,0xbf0a0096,0xb6060995,0x2d920085}},	//   хнич, वरुन_, vošć, nhye_,
   {{0x29062911,0x777a2912,0x00000000,0x00000000}},	//   mboa_, _totx, --, --,
   {{0x2b582913,0xb6060995,0x42742914,0x00000000}},	//   _jarc_, tošć, егос, --,
   {{0xa2c1121d,0x3218025b,0x2b582915,0x25bf2916}},	//   _रुद्, éry_, _marc_, boul_,
   {{0xe4a60221,0xc486164d,0x68e400e7,0x5a17006e}},	//   _орло, _олек, židu, וקטן_,
   {{0xa3e705d4,0xc058224a,0xbf0a009d,0x10742917}},	//   _मंच_, мір_, वरून_, вляю,
   {{0x0efb2918,0x2b582919,0x47cc0081,0x3dc900f9}},	//   ्रेस_, _narc_, াদকী, wlaw_,
   {{0x3ceb291a,0x9e340036,0xf1bf0231,0x5e5800ae}},	//   _pgcv_, керч, poá_, миря_,
   {{0x3dc90124,0x7f570188,0x637f02ac,0xcdd80284}},	//   ulaw_, _waxq, _fêns, дњу_,
   {{0x3dc90373,0x7d020328,0x7d0f291b,0x2b580178}},	// [1e90] rlaw_, ñosa, _vecs, _barc_,
   {{0xdb1c01ec,0x00000000,0x00000000,0x00000000}},	//   _shrò, --, --, --,
   {{0xb50e009f,0x7d0f291c,0xdb1c01b5,0x2b5800fc}},	//   सराय_, _tecs, _phrò, _darc_,
   {{0x645c00d9,0x68ed0220,0x31b9291d,0x00000000}},	//   ārij, ľado, tézy_, --,
   {{0x68ed025b,0x2b58291e,0x201900c2,0x6cfa0327}},	//   žado, _farc_, nssi_, _מפרס,
   {{0x7c2d291f,0xb17b0ac9,0x00000000,0x00000000}},	//   muar, lmåd, --, --,
   {{0x7c2d2920,0x2bbe046e,0xbcfb0161,0x1995055b}},	//   luar, ्तरा, _anéi, _завя,
   {{0xc867008f,0x6d4d2921,0x25ad078e,0x00000000}},	//   _отзи, neaa, unel_, --,
   {{0x38342922,0x7c2d2923,0x25bf00ae,0x25ad2924}},	//   _интр, nuar, roul_, rnel_,
   {{0x25ad2925,0x25bf0052,0x69cb2926,0xe2990291}},	//   snel_, soul_, llge, зао_,
   {{0x25ad01b9,0x2d890167,0x7c2d2927,0x69cb0313}},	//   pnel_, kkae_, huar, olge,
   {{0x7c2d2928,0xa3cf0179,0x865a00d7,0xe56e0077}},	//   kuar, _वीर_, _מדעי, _ёз_,
   {{0x656b2929,0xbcfb00e3,0x7c2d292a,0x80c80081}},	//   _ingh, _gnéi, juar, রেন্,
   {{0x7c2d292b,0xdb1e023b,0x442d292c,0x69cb0364}},	//   duar, ropë, mue_, hlge,
   {{0x442d292d,0x20191fc2,0x68fb05fb,0x00000000}},	//   lue_, assi_, _ofud, --,
   {{0xbefb02d5,0x7c2d0076,0x68fb06b0,0x0efb0285}},	//   ्रॉन_, fuar, _nfud, ्रॉस_,
   {{0x2b58292e,0x7c2d292f,0x6aa80386,0x442d2930}},	// [1ea0] _parc_, guar, कप्र, nue_,
   {{0x291f2931,0x2d92023f,0xa3c10852,0x68fb0361}},	//   _adua_, shye_, ूति_, _afud,
   {{0x27ff1bde,0x3ea60fe3,0xa92622be,0x6376020a}},	//   _atun_, _чинг, едел, _pânz,
   {{0x442d2932,0xb17b0149,0x7c2d2933,0x2b5802ac}},	//   kue_, rmåg, buar, _warc_,
   {{0xc7c62321,0x7d160694,0x6376002d,0x6e2e017a}},	//   нски, mays, _vânz, lubb,
   {{0x7d162934,0x656b2935,0xfaa60f00,0x442d2936}},	//   lays, _angh, _заго, due_,
   {{0xbbbe0966,0x442d020d,0x6e2e2937,0x5bbe2674}},	//   ्तीक, eue_, nubb, ्तीव,
   {{0x7d162938,0x09e317e9,0x442d2939,0x2c520154}},	//   nays, _босн, fue_, _kņd_,
   {{0x442d22d3,0x98af00c6,0x6e2e225b,0xdb1e00ee}},	//   gue_, degė_, hubb, topè,
   {{0x656b0150,0x7d16008a,0x96960a29,0x21200154}},	//   _engh, hays, _преш, _adih_,
   {{0x7d16293a,0x7c2d293b,0xd5af0e05,0xbcfb020d}},	//   kays, zuar, _бс_, _inév,
   {{0xdce605aa,0x0efb0179,0xbbbe00b6,0x00000000}},	//   _ankč, ्र्स_, ्तुक, --,
   {{0x7d16008a,0x7c2d293c,0x5fd2007a,0xa2cc023a}},	//   days, xuar, _दीहल, _हरक्,
   {{0x201901a5,0x7c2d0216,0x00000000,0x00000000}},	//   rssi_, vuar, --, --,
   {{0x656b02ad,0x6f151427,0x6e2e293d,0x5d67293e}},	//   _yngh, razc, gubb, нтаз,
   {{0x7d16008a,0x7c22003d,0x7c2d293f,0x40950037}},	//   gays, ġorn, tuar, _للبر,
   {{0xb81c1ae6,0x6d4d2940,0x00000000,0x00000000}},	// [1eb0] _निगम_, reaa, --, --,
   {{0x7c2d2011,0x6e2e2941,0xb17b02b6,0x3df5247a}},	//   ruar, bubb, småd, _изос,
   {{0x7d16008a,0x442d0a00,0x6d4d2942,0xf7780090}},	//   bays, zue_, peaa, _jiħu_,
   {{0xa91d0087,0x3c4301d3,0x7d160188,0x27ff0167}},	//   _možg, tīvā_, cays, _ptun_,
   {{0x7c2d2943,0xe10c00c1,0x89340037,0x8d8400ae}},	//   quar, פּאָ, اعما, _суэд,
   {{0x442d2944,0xa3cf0034,0x394400f9,0x386400c4}},	//   vue_, _वीं_, _ebms_, _drmr_,
   {{0xead400c2,0x442d0174,0xe8df0065,0x00000000}},	//   _борь, wue_, _ibọn_, --,
   {{0x27ff01ff,0xa01b007b,0x00000000,0x00000000}},	//   _ttun_, työl, --, --,
   {{0xe43200e3,0x00000000,0x00000000,0x00000000}},	//   لفيد, --, --, --,
   {{0x442d2945,0x394f2946,0xdb1e2947,0x260e0096}},	//   rue_, legs_, topé, णीही_,
   {{0x200000d3,0x442d00a1,0x27f8033b,0xfbd200ca}},	//   _stii_, sue_, _črni_, שתי_,
   {{0xdb1e025a,0x656b2948,0x7d16008a,0x0f0a0176}},	//   ropé, _ungh, xays, वर्स_,
   {{0x442d2949,0x8edf00c7,0x45d400c2,0x212005db}},	//   que_, _ব্লগ, _соцс, _vdih_,
   {{0x7d16026d,0xdb1c023c,0x03a5294a,0x00000000}},	//   ways, _okrá, _шило, --,
   {{0x6da6075f,0x7d16008c,0x7d020328,0x22470062}},	//   вива, tays, ñoso, _upnk_,
   {{0x6e2e294b,0x12e800c1,0xdd920867,0x320500ca}},	//   rubb, _אַפּ, جور_, mply_,
   {{0xa91d02e6,0x7d160694,0x2bf624d3,0x67211912}},	// [1ec0] _možd, rays, тябр, _odlj,
   {{0x6e2e294c,0x7d16294d,0xaf0a0037,0xb17b0537}},	//   pubb, says, _تقدم_, rmåe,
   {{0xa3c2294e,0x7d16020d,0x00000000,0x00000000}},	//   ंवत_, pays, --, --,
   {{0x7d160188,0x637e02c6,0x00000000,0x00000000}},	//   qays, _záně, --, --,
   {{0x6d460139,0xe9470103,0x25780206,0x00000000}},	//   _ibka, ئرمی, _gély_, --,
   {{0xe8df0065,0x8b0501c2,0xa09b2252,0xe81309a1}},	//   _gbọn_, ƙƙau, וינט, _डबरा_,
   {{0x6ae000c7,0x98b2026a,0xfaa60e05,0x00000000}},	//   _প্রো, ıyı_, _раво, --,
   {{0x80d300a4,0x00000000,0x00000000,0x00000000}},	//   _ठरले, --, --, --,
   {{0xdb1c00b6,0x00000000,0x00000000,0x00000000}},	//   _zkrá, --, --, --,
   {{0xf3660a3a,0xa91d0141,0x27f903a9,0x00000000}},	//   ттин, _požg, _ésna_, --,
   {{0x7980294f,0x00000000,0x00000000,0x00000000}},	//   _komw, --, --, --,
   {{0x316d2950,0xfbdf00f0,0x00000000,0x00000000}},	//   ñez_, _apêl_, --, --,
   {{0x75220294,0x60d6007f,0x94760076,0x00000000}},	//   _idoz, _czym, _جداا, --,
   {{0x547b00a1,0x9e352951,0x6d462952,0x79800172}},	//   _קטגו, легч, _abka, _lomw,
   {{0x2bec02d5,0xdb0602c6,0x236e0350,0x63a82953}},	//   _अंजू_, ámýc, _infj_, midn,
   {{0xa91d025b,0x7bc70d3e,0x7e65211b,0x62882954}},	//   _kože, _skju, _vrhp, mydo,
   {{0xdb1c2955,0x62880138,0xa91d2956,0xebd91510}},	// [1ed0] _skrá, lydo, _jože, едаш_,
   {{0xa91d02e6,0x4ea72957,0x8f5502ec,0x63a800e7}},	//   _može, _арма, _свої, nidn,
   {{0x75222958,0x61ed2959,0xa91d015c,0x798002ac}},	//   _odoz, _kial, _lože, _bomw,
   {{0x60cd295a,0x75220294,0xafdb02b6,0xaa64013f}},	//   _kyam, _ndoz, stød, штук,
   {{0xa3c20454,0xa91d042d,0x6d5d0a6c,0xc19c00ca}},	//   ंवा_, _nože, _iasa, ושאי,
   {{0x7522295b,0x60cd295c,0x61ed03d3,0x00000000}},	//   _adoz, _myam, _lial, --,
   {{0x6d5d295d,0xe5a5290e,0x798001c2,0x27ec00a1}},	//   _kasa, лики, _fomw, _didn_,
   {{0x61ed295e,0x7bc50af0,0xe4591d7b,0x60cd06b0}},	//   _nial, lohu, ежи_, _oyam,
   {{0x6d5d295f,0x60cd2960,0xa91d0307,0x69db0294}},	//   _masa, _nyam, _vožd, _ihue,
   {{0x6d5d2961,0x2bd902b0,0x490b000d,0x75222962}},	//   _lasa, _बीमा, ारको_, _edoz,
   {{0x61ed2963,0x60cd2964,0x69c90172,0x60d62965}},	//   _bial, _ayam, _kkee, _szym,
   {{0x6d5d2966,0x60cd21e9,0x00000000,0x00000000}},	//   _nasa, _byam, --, --,
   {{0x61ed1206,0x44292967,0x343900c1,0x7bc50f18}},	//   _dial, _ía_, _נײַע, kohu,
   {{0x9474006f,0x443f2968,0x63a80580,0x6d5d2969}},	//   _خدما, mtu_, cidn, _aasa,
   {{0x6d5d296a,0xa2ca0e72,0x61ed296b,0x69c916ae}},	//   _basa, _सुप्, _fial, _okee,
   {{0x5bbe0c3c,0x61ed296c,0x69c9006c,0xed5711b6}},	//   ्त्व, _gial, _nkee, лос_,
   {{0x443f296d,0x6d5d26f7,0xbcfb00b3,0x60cd083e}},	// [1ee0] ntu_, _dasa, _anés, _gyam,
   {{0x443f296e,0xa09b006e,0x69c9296f,0x69db024a}},	//   itu_, _נייט, _akee, _ahue,
   {{0x6d5d2970,0x443f2971,0x6da62972,0x69db0037}},	//   _fasa, htu_, _бина, _bhue,
   {{0x6d5d2973,0x644b02b6,0x8d56203c,0x7d56004d}},	//   _gasa, _opgi, _сточ, _стої,
   {{0x443f2974,0xa2ca0354,0x8eb3001c,0x69db0113}},	//   jtu_, _सुन्, _نمیش, _dhue,
   {{0x6d5d12c5,0xdb1c052f,0x7c2b01ab,0xfbb8203b}},	//   _zasa, _skræ, ágre, _आदिम,
   {{0x6d5d2975,0xb8eb000c,0xbb3b00c1,0x56942976}},	//   _yasa, _रु_, _רעלי, райт,
   {{0xa91d00cb,0x6d5d0694,0x7df50138,0x69c901ff}},	//   _pože, _xasa, _sąsk, _gkee,
   {{0x61ed054f,0x20e3034d,0x63a80149,0x7bdc2977}},	//   _rial, _गणेश_, tidn, _khru,
   {{0x2d822978,0x61ed2979,0xa91d05db,0xf206297a}},	//   _loke_, _sial, _vože, лямо,
   {{0x61ed1084,0x60cd048e,0x443f297b,0xf3631ad1}},	//   _pial, _syam, atu_, стын,
   {{0x6288297c,0xa91d0087,0x7bc50051,0xe80b030b}},	//   rydo, _tože, zohu, सीका_,
   {{0x629a297d,0x61ed297e,0x143900cd,0x7bc50051}},	//   szto, _vial, _لينک_, yohu,
   {{0x6d5d27e5,0x60cd0010,0x98a9007f,0xd3700037}},	//   _sasa, _vyam, żać_, _ذهب_,
   {{0x6d5d297f,0xcddb0cb8,0x6d442980,0x2d822981}},	//   _pasa, ења_, ffia, _boke_,
   {{0x6d5d2982,0x2d582983,0x5d55001f,0x645900f0}},	//   _qasa, лись_, јкат, _yswi,
   {{0x5b152984,0x6d5d2985,0x7bc52986,0x7bdc0091}},	// [1ef0] имат, _vasa, tohu, _bhru,
   {{0x6d5d2987,0x7bdc0a21,0x69c92988,0x9d150081}},	//   _wasa, _chru, _skee, িলেন_,
   {{0x6d5d2989,0x443f02a7,0x2cae0092,0x7bdc03ea}},	//   _tasa, ztu_, _əldə_, _dhru,
   {{0x6d5d0a02,0xbcfb298a,0x25fb0034,0x6440298b}},	//   _uasa, _enér, _लंबी_, ktmi,
   {{0xe739298c,0x443f298d,0xb8fd14e5,0x99870103}},	//   вел_, xtu_, _डर_, énő_,
   {{0x8ae7116d,0x7bdc0a02,0x321e0034,0x66050161}},	//   _бібл, _ghru, ksty_, апка,
   {{0x69db298e,0x01d60033,0x61fc0072,0x98a700c4}},	//   _thue, _সংসদ, írll, điđi_,
   {{0x443f298f,0x1425022f,0x7c2d296c,0x7bdc033d}},	//   ttu_, адим, orar, _zhru,
   {{0x443f2990,0x998400e3,0x7c2d026e,0xa91d0087}},	//   utu_, _القو, nrar, _tožb,
   {{0x395f2991,0x443f2992,0x25a62993,0x7d0d0113}},	//   _haus_, rtu_, _emol_, hbas,
   {{0x395f2994,0x65952995,0xe10a1510,0xd5751c32}},	//   _kaus_, _кажу, кенд_, _вуль,
   {{0x9f490088,0x7c2d2996,0x2935006e,0xc0e61720}},	//   _stað_, krar, סאָן_, ионк,
   {{0x2d820087,0x395f2997,0x64590239,0x3f9800eb}},	//   _roke_, _maus_, _uswi, thru_,
   {{0x395f0197,0x442d20a8,0x2d822998,0x765a02ad}},	//   _laus_, mre_, _soke_, _ysty,
   {{0xeab00f71,0xdee61a18,0xa3c22999,0x7c2d01e9}},	//   _কর্ম, рови, ंवर_, erar,
   {{0x7d0d299a,0x442d299b,0x7bdc299c,0x395f299d}},	//   gbas, ore_, _shru, _naus_,
   {{0x7c2d299e,0x6db70106,0x6d44299f,0x7bdc01b9}},	// [1f00] grar, pćan, rfia, _phru,
   {{0x442d29a0,0x2d8229a1,0x316029a2,0x8b26004d}},	//   ire_, _woke_, _haiz_, рдже,
   {{0x6f1c2243,0x442d29a3,0x7c2d29a4,0x7d0d29a5}},	//   marc, hre_, arar, bbas,
   {{0xd9462240,0x442d29a6,0x6f1c29a7,0x395f29a8}},	//   реди, kre_, larc, _caus_,
   {{0x395f022e,0x7c2d002d,0x442d29a9,0x31601a86}},	//   _daus_, crar, jre_, _maiz_,
   {{0x442d0b81,0x0eba009f,0x7df529aa,0xa50e0521}},	//   dre_, _उखाड, _sąsi, सर्च_,
   {{0xd5ba29ab,0x395f022e,0x70d3030b,0xe8fa002d}},	//   кси_, _faus_, _सर्ल, _алб_,
   {{0x442d29ac,0x6f1c29ad,0x31600a00,0x395f29ae}},	//   fre_, harc, _naiz_, _gaus_,
   {{0x57ea29af,0x442d0b6a,0x6fc60096,0x765a007f}},	//   _адам_, gre_, लकां, _wsty,
   {{0x46a6013d,0x07a31d68,0x883b00a1,0x395f0197}},	//   _казв, _даун, _בתמו, _zaus_,
   {{0x442d29b0,0x644029b1,0x6f1c29b2,0x395f006c}},	//   are_, stmi, darc, _yaus_,
   {{0x442d29b3,0x04460fa5,0x395f006c,0xa91d015c}},	//   bre_, _ведн, _xaus_, _koža,
   {{0x6f1c1064,0x2fc70023,0xdcef01d3,0x9f84003e}},	//   farc, _ưng_, ādīt, töð_,
   {{0x6f1c29b4,0x7c2d0012,0x533300ae,0xa91d0117}},	//   garc, vrar, _дешт, _moža,
   {{0x316029b5,0x3da729b6,0xbe8829b7,0xa3110031}},	//   _faiz_, араб, асте_, äčšo,
   {{0x527b040a,0xdd9814e8,0x40c80134,0x00000000}},	//   _ינוא, ашу_, ọrị_, --,
   {{0x7d0d29b8,0x7c2d29b9,0xdce6013f,0x395f29ba}},	// [1f10] rbas, urar, _mokė, _raus_,
   {{0x7c2d29bb,0x6f1c29bc,0x395f29bd,0xd9bf0557}},	//   rrar, carc, _saus_, एक्ट,
   {{0x395f29be,0x2bbe0378,0x442d0103,0x7d0d0381}},	//   _paus_, ्तजा, zre_, pbas,
   {{0x442d29bf,0x395f023e,0x7c2d29c0,0x75e70103}},	//   yre_, _qaus_, prar, _tűzi,
   {{0x395f023e,0x4dda00ca,0x9f400428,0xdb1c01df}},	//   _vaus_, _תחרו, _guió_, _skrå,
   {{0x442d29c1,0x06b20081,0x395f01c2,0xd874001c}},	//   vre_, য়েছি, _waus_, تامب,
   {{0xa6c929c2,0x395f006c,0xaa950037,0xcae50033}},	//   ылка_, _taus_, _الأث, _প্রফ,
   {{0x6f1c29c3,0xa2c10096,0xa2ca0403,0xa3cf0096}},	//   zarc, _रुग्, _सुध्, _वीज_,
   {{0x442d29c4,0x7f8b01d4,0x291d29c5,0x6f1c0044}},	//   ure_, _hüqu, mawa_, yarc,
   {{0x442d0519,0x291d29c6,0x316008d3,0x61f80542}},	//   rre_, lawa_, _saiz_, _buvl,
   {{0xa2ca009d,0x442d0018,0x6f1c29c7,0xe6b30260}},	//   _सुद्, sre_, varc, _بلاگ,
   {{0x442d1f17,0x291d29c8,0xd00a29c9,0x68ed025b}},	//   pre_, nawa_, леме_, žadu,
   {{0x6f1c29ca,0x31601820,0x76430085,0x7dfc0383}},	//   tarc, _vaiz_, ltny, _pčso,
   {{0x291d29cb,0x76430167,0xafe61e11,0xdb1e1f20}},	//   hawa_, otny, согл, kopá,
   {{0x291d29cc,0x2d9620da,0x38660094,0x29dc00b3}},	//   kawa_, брас, zvor_, níac_,
   {{0x6da3187c,0x6f1c29cd,0x2b4a0167,0x291d29ce}},	//   писа, sarc, _sbbc_, jawa_,
   {{0x291d29cf,0xcaf600e3,0x249f0268,0x6f1c29d0}},	// [1f20] dawa_, مساب, nzum_, parc,
   {{0xa91d29d1,0xa3dd0789,0x61e60973,0x764329d2}},	//   _roža, _थीम_, lmkl, ktny,
   {{0x25ad29d3,0xdb070018,0x291d006d,0xb17b13c8}},	//   kiel_, ámár, fawa_, kmål,
   {{0x291d29d4,0xa91d0d95,0x38661419,0x38cb010d}},	//   gawa_, _poža, tvor_, گامی_,
   {{0x53c70693,0x25ad0181,0x6d5629d5,0x394629d6}},	//   रकाश, diel_, meya, rfos_,
   {{0x38cb00cd,0x6d5629d7,0x9b960037,0x386629d8}},	//   دامی_, leya, _الست, rvor_,
   {{0x25ad0272,0x291d29d9,0x77610188,0xdb1c0031}},	//   fiel_, bawa_, _dalx, _okrú,
   {{0x2d8029da,0xd94329db,0x25ad29dc,0x6d561dbd}},	//   njie_, _неси, giel_, neya,
   {{0x764329dd,0x61f80f39,0xf8dc00aa,0x09e30036}},	//   atny, _suvl, _बरिय, _хотн,
   {{0x5c5b00c1,0x388e00d9,0x00000000,0x00000000}},	//   נדיק, _vērā_, --, --,
   {{0xa91d0ec8,0x25ad122f,0x6d560113,0xcb1303c2}},	//   _možn, biel_, keya, הלת_,
   {{0x25ad29de,0xa91d00b6,0x7df50138,0xf09f015e}},	//   ciel_, _ložn, _mąst, tzà_,
   {{0x2d800185,0x6d5629df,0x7df50138,0x23e6097a}},	//   djie_, deya, _ląst, _лікв,
   {{0x291d29e0,0xdbf1030b,0xa91d1c56,0x92940832}},	//   zawa_, _příl, _nožn, _малц,
   {{0x291d001b,0xfdc4009f,0x00000000,0x00000000}},	//   yawa_, वकूफ, --, --,
   {{0x6d5629e1,0x2d800216,0x00000000,0x00000000}},	//   geya, gjie_, --, --,
   {{0x212902fa,0x4dd40037,0x00000000,0x00000000}},	// [1f30] _idah_, ستفس, --, --,
   {{0xdea403ed,0x291d29e2,0x25ad29e3,0xe3b829e4}},	//   _کیفی, wawa_, ziel_, nnı_,
   {{0x291d29e5,0x6d5629e6,0x9f8400aa,0x2d85020d}},	//   tawa_, beya, töö_, êles_,
   {{0x6ab909c3,0x291d0051,0x8f55001c,0xe3b800a7}},	//   _आशीर, uawa_, _انگش, hnı_,
   {{0x291d29e7,0xf770037f,0x25ad29e8,0x2d9901d0}},	//   rawa_, کان_, viel_, _ilse_,
   {{0x291d29e9,0x25ad0371,0x776100a7,0xdb15022b}},	//   sawa_, wiel_, _qalx, _ekzò,
   {{0x291d0a4b,0x25ad29ea,0x66e2004b,0x19950138}},	//   pawa_, tiel_, моша, _давя,
   {{0x20090332,0x764329eb,0x7d1f0216,0x29dc00ee}},	//   _otai_, rtny, naqs, ríac_,
   {{0x25ad29ec,0x92e60081,0xb17b0073,0x764329ed}},	//   riel_, যুৎ_, rmål, stny,
   {{0x422529ee,0x2129005c,0xb17b0c96,0x25ad29ef}},	//   одов, _adah_, smål, siel_,
   {{0x80d100c7,0x25ad29f0,0x09b500c1,0x6d5629f1}},	//   সেম্, piel_, ַפֿט_, yeya,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5629f2,0x10a300ae,0x61e629f3,0xb5c800d1}},	//   veya, диян, rmkl, _اونم_,
   {{0x69cb29f4,0x212900dc,0xaab90252,0xe3b30b9f}},	//   hoge, _edah_, _आशंक, _عرش_,
   {{0x59c906e4,0x2d800665,0xa91d29f5,0x6d5629f6}},	//   िकार, tjie_, _rožn, teya,
   {{0x753b29f7,0xa01b007b,0x69cb083e,0x00000000}},	//   nguz, työt, joge, --,
   {{0x6d5629f8,0x3b86249b,0xae1a009f,0x8c4311f8}},	// [1f40] reya, олаг, _फौरन_, мете,
   {{0xa91d29f9,0x394d0063,0x6d5629fa,0x2d9900ca}},	//   _božo, _abes_, seya, _else_,
   {{0xe8fa12e9,0x69cb29fb,0x2904039f,0x00000000}},	//   але_, foge, _pfma_, --,
   {{0x69cb29fc,0x7d1f00a7,0xfd120076,0xe3b811bc}},	//   goge, caqs, _تجد_, znı_,
   {{0xa91d0087,0x386d0558,0xbcfb01dc,0x97c61ad2}},	//   _tožn, _crer_, _kaén, ойде,
   {{0x7c24152f,0x7d0429fd,0xf0930796,0x81c20033}},	//   msir, lcis, ונד_, ্গি_,
   {{0x41ca277c,0x69cb29fe,0xbf9b00fd,0x7c2429ff}},	//   रवास, boge, mpêt, lsir,
   {{0x69cb2a00,0x7d042a01,0x386d0154,0xa2ca08c0}},	//   coge, ncis, _frer_, _सुष्,
   {{0x7c242a02,0xdb1e052f,0xc31e0081,0xb8660281}},	//   nsir, ropæ, _দাবি_, _بازو,
   {{0x779200bf,0x7c242a03,0x926a2a04,0x212909a4}},	//   _زیبا, isir, арма_, _sdah_,
   {{0x20092a05,0xe3b81577,0x7dfc022b,0x8afb0a41}},	//   _stai_, rnı_, _dčsk, יליז,
   {{0x7c24181b,0x96330f1e,0xa194224a,0x00000000}},	//   ksir, _ініц, даюч, --,
   {{0xa2ca000c,0x78a20146,0x7c24042d,0x48b80081}},	//   _सुर्, nzov, jsir, _জরুর,
   {{0x442600cb,0x69cb02e2,0xc05800d6,0x09b72a06}},	//   _ivo_, zoge, цію_, _अद्य,
   {{0x69cb0283,0x44262a07,0xddab00d3,0x8d770037}},	//   yoge, _hvo_, атал_, يارا,
   {{0x212902e8,0x7c242a08,0x2bbf2a09,0x75200a4b}},	//   _udah_, fsir, ्वभा, namz,
   {{0x69cb2a0a,0x78a20b14,0x7c242a0b,0x442603a9}},	// [1f50] voge, jzov, gsir, _jvo_,
   {{0x09b30454,0x69cb0517,0x63ba01bf,0x78a20220}},	//   ंच्य, woge, nntn, dzov,
   {{0x69cb2a0c,0x7c240361,0x00000000,0x00000000}},	//   toge, asir, --, --,
   {{0x442603ce,0x7d041c9a,0x44240063,0xceb20142}},	//   _ovo_, ccis, ksm_, _טיי_,
   {{0x1869021c,0x7d1d03a8,0x6c79006e,0x48e6023a}},	//   сали_, _iess, _האָפ, जेलो_,
   {{0x7d1d2a0d,0x69cb2a0e,0xbdf81ac9,0x80c80033}},	//   _hess, soge, _دریا_, রেক্,
   {{0xa2ca1bc3,0x44262a0f,0x98bf00c4,0x29dc2a10}},	//   _सुल्, _avo_, _obuć_, mían_,
   {{0xc485064f,0xf1c00094,0x386d00f3,0xdb1c00f2}},	//   злик, čák_, _trer_, _skrø,
   {{0x7d1d0e04,0xe3b1003f,0x937900e3,0x753b0d2a}},	//   _mess, فرد_, مصدر_, rguz,
   {{0xf8ae00d0,0x798901a2,0x29dc0890,0x7d1d089a}},	//   _حکم_, _hoew, nían_, _less,
   {{0x442602e6,0x799b2a11,0x9ad30134,0x216a090f}},	//   _evo_, _kluw, _dịgo, бини_,
   {{0x7d1d1880,0xe610001c,0xbcfb00cd,0xafdb0120}},	//   _ness, _ششم_, _saén, støl,
   {{0xb4fa00a1,0x764b013f,0x92b50470,0x7989084e}},	//   _הפני, žnyč, تحکا, _moew,
   {{0x6dac026a,0x22450124,0x9f58013c,0x799b03a8}},	//   rşam, ptlk_, _özün_, _lluw,
   {{0x7d1d02e2,0x29dc04d8,0x2d96287c,0x78a20f1c}},	//   _bess, dían_, прас, zzov,
   {{0x7c242a12,0x7d1d2a13,0xb88300b6,0x91e31bc1}},	//   tsir, _cess, _klíč, _поще,
   {{0x7d1d2a14,0x7d042a15,0xe3190023,0x61e40372}},	// [1f60] _dess, rcis, _điể, _ihil,
   {{0xa01b0084,0x799b0361,0x29dc00e1,0x7d040d63}},	//   pyör, _aluw, gían_, scis,
   {{0x4efb0054,0x7c242a16,0x61e42a17,0xc33200a1}},	//   _להיו, ssir, _khil, תוב_,
   {{0xd7fa0562,0x7d1d2a18,0x799b0113,0xdb052a19}},	//   бук_, _gess, _cluw, rihá,
   {{0x29dc0fb6,0x61e40a02,0x799b01dc,0x79890113}},	//   bían_, _mhil, _dluw, _doew,
   {{0xc7a307c8,0x29dc04d8,0x78a22316,0x60d600c2}},	//   ничк, cían_, rzov, _myym,
   {{0x44260682,0x7d1d2a1a,0xdb1e01bf,0x9f480d79}},	//   _svo_, _yess, ropä, óhùn_,
   {{0x2abb00a1,0x44260f13,0x79890313,0x00000000}},	//   _המלא, _pvo_, _goew, --,
   {{0x3a3a03e5,0x212203a9,0x75202a1b,0x00000000}},	//   lupp_, dakh_, ramz, --,
   {{0xe44f0080,0x6f1e0995,0x00000000,0x00000000}},	//   اضي_, _nepc, --, --,
   {{0x61e40a02,0xaabe00a8,0x7dda0b8e,0x2bbf18ff}},	//   _bhil, ्थिक, eïsm, ्वता,
   {{0x61e42a1c,0x4426003e,0x867b00ca,0xc10800ae}},	//   _chil, _tvo_, _לרבו, зэре_,
   {{0x7d1d2a1d,0xa91d2a1e,0x44262a1f,0x61e42a20}},	//   _ress, _božj, _uvo_, _dhil,
   {{0x7d1d2a21,0xa91d2a22,0x6447020a,0x61e40415}},	//   _sess, _rožm, ăjit, _ehil,
   {{0x7d1d00c9,0xd3e512eb,0x29dc0610,0x61e4009b}},	//   _pess, _تقوی, vían_, _fhil,
   {{0x61e42a23,0xbcfb0042,0x5d6400e5,0x00000000}},	//   _ghil, _gaél, нтуз, --,
   {{0x6ecd2a24,0x6c5407c6,0x29dc0610,0xa3d00d77}},	// [1f70] _दुरु, нкту, tían_, वकप_,
   {{0x7d1d084e,0x69c00234,0x7e6102b6,0xa2a00096}},	//   _wess, _ajme, ælps, खनप्,
   {{0x7d1d2a25,0x29dc11ce,0xbb8400e3,0xecf90f1e}},	//   _tess, rían_, علمي, _менш_,
   {{0x6f1e2a26,0x00000000,0x00000000,0x00000000}},	//   _zepc, --, --, --,
   {{0xa3cc2a27,0x6d4d0167,0xa3c10096,0x00000000}},	//   लवा_, mfaa, ्कम_, --,
   {{0x2d8b04eb,0x6d4d2a28,0x79890113,0x00000000}},	//   _hoce_, lfaa, _woew, --,
   {{0xb8f42a29,0x6b830088,0x79892a2a,0x29dc0072}},	//   _सु_, öngu, _toew, cíao_,
   {{0x6d4d2a2b,0x799b005c,0x2d8b2a2c,0x2409007b}},	//   nfaa, _uluw, _joce_, онии_,
   {{0xafdb0537,0xd4692914,0x00000000,0x00000000}},	//   rtøj, ципе_, --, --,
   {{0x61e42a2d,0x69d901bf,0x2d8b002b,0x6d4d0188}},	//   _shil, llwe, _loce_, hfaa,
   {{0x61e42a2e,0x95cb0e06,0x00000000,0x00000000}},	//   _phil, _луда_, --, --,
   {{0x67232a2f,0x2d8b2a30,0x6f1e044c,0x00000000}},	//   lanj, _noce_, _sepc, --,
   {{0x81c20081,0x27ff2a31,0x291f015e,0x6f1e05db}},	//   ্গল_, _juun_, _meua_, _pepc,
   {{0x82351e49,0x67232a32,0xe2992a33,0x61e40054}},	//   _قربا, nanj, _мал_, _whil,
   {{0x61e42a34,0x6d4d2a35,0x2d8b0106,0x68fb06b0}},	//   _thil, ffaa, _boce_, _ogud,
   {{0x67232a36,0x291f01fa,0x65690e32,0x68fb2a37}},	//   hanj, _neua_, ndeh, _ngud,
   {{0x64492a38,0x67232a39,0x2d8b2a3a,0xbfc62a3b}},	// [1f80] ntei, kanj, _doce_, _обик,
   {{0xd9b80386,0x69d9281c,0x00000000,0x00000000}},	//   ेक्ट, elwe, --, --,
   {{0x236702dd,0x64492a3c,0x6d4d023e,0x2d8b2a3d}},	//   _manj_, htei, bfaa, _foce_,
   {{0x2d8b2a3e,0x64492a3f,0x3a3a2a40,0x20000113}},	//   _goce_, ktei, rupp_, _kuii_,
   {{0x26030eb8,0xdcb902fd,0xc7c629db,0xdb0e0088}},	//   _año_, _ещё_, мски, þjón,
   {{0x31bb1c0a,0x65690cad,0x29062a41,0xdce40146}},	//   _उद्ध, edeh, scoa_, ndič,
   {{0xc34e00de,0x6e3c037a,0x45d4139c,0x291f01dc}},	//   _bổng_, nurb, нокс, _feua_,
   {{0xc34e0019,0x64492a42,0x68fb010a,0xafdb0565}},	//   _cổng_, ftei, _ggud, ttøk,
   {{0x29e80092,0x3944016d,0x6e3c0112,0x27e5009c}},	//   _uşaq_, _icms_, hurb, _fhln_,
   {{0x672302e6,0x9696013d,0x6e3c003e,0x68fb00ae}},	//   canj, _ореш, kurb, _zgud,
   {{0xa2940c10,0x777a0634,0x00000000,0x00000000}},	//   хані, _intx, --, --,
   {{0x2000010a,0x14af0096,0x64490364,0x6e3c2a43}},	//   _buii_, _जेवण, btei, durb,
   {{0x14e21e9f,0x2d8b030b,0xdb1c2a44,0x3e480364}},	//   _परिण, _roce_, _skrý, eßt_,
   {{0x61ee0181,0x2000009c,0x00000000,0x00000000}},	//   _ďale, _duii_, --, --,
   {{0x2bbf2a45,0x2d8b0a39,0xdb0e00ee,0x6e3c01cd}},	//   ्वसा, _poce_, _imbè, gurb,
   {{0x236706c6,0xa2ad000d,0x7d160313,0x00000000}},	//   _zanj_, ुपर्, gbys, --,
   {{0x2d8b11f4,0xf1bf025b,0x67232a46,0x6d4d0188}},	// [1f90] _voce_, mná_, yanj, rfaa,
   {{0xf1bf0618,0xa3e4074c,0x291f05fe,0x6d4d2a47}},	//   lná_, _भीम_, _seua_, sfaa,
   {{0x6e3c2502,0x2d8b0036,0xdb1c0094,0x23a00154}},	//   curb, _toce_, _ukrý, _gòje_,
   {{0xf1bf2a48,0x67232a49,0xa91d0ebd,0x777a01e9}},	//   nná_, wanj, _koži, _antx,
   {{0x672303ce,0x644910f4,0xd05401c2,0xdb0e00d1}},	//   tanj, xtei, ɓaɓa, _ombè,
   {{0xf77100e3,0xa3dd00a5,0x66e50077,0x23dd03b3}},	//   طات_, _थीं_, нола, _नींद,
   {{0x67232a4a,0x92c20081,0xe91900d6,0xa91d2a4b}},	//   ranj, ্ধু_, _нові_, _loži,
   {{0x64492a4c,0xf1bf0579,0xdb0e0113,0x2367033b}},	//   ttei, jná_, _ambè, _sanj_,
   {{0xf1bf0897,0xa91d038d,0x65692a4d,0x23672a4e}},	//   dná_, _noži, rdeh, _panj_,
   {{0x64492a4f,0x4374004d,0x2fd100c4,0x9cd800ca}},	//   rtei, вуют, jozg_, ווחה_,
   {{0xc34e0028,0xfbd200a1,0x61460a51,0xb34520df}},	//   _tổng_, רתי_, нена, _acçã,
   {{0x5694245c,0x64492a50,0x67212a51,0x2000020a}},	//   _шахт, ptei, _helj, _puii_,
   {{0x25bf002d,0x7f5c2a52,0x66012a53,0x02cf04f1}},	//   mnul_, terq, _hulk, _सुरभ,
   {{0x66012a54,0xe8df0129,0x81bd01d3,0xa2ca2a55}},	//   _kulk, _arịa_, nsēj, _सुक्,
   {{0x660102fd,0xf1bf025b,0xe2990426,0x25bf00ae}},	//   _julk, bná_, _хай_, onul_,
   {{0x66011114,0xf1bf0146,0xdd921d28,0xdb0e2a56}},	//   _mulk, cná_, دور_, _imbé,
   {{0xdca32135,0x7d162a57,0x45da006e,0x395d02ac}},	// [1fa0] гати, rbys, פֿלא, dews_,
   {{0xa3c1000f,0x6721198c,0xf40100c7,0x7d1602ad}},	//   ्कि_, _nelj, _এবার_, sbys,
   {{0x1b1f0081,0xdb1c0034,0xa91d0141,0x00000000}},	//   _পাশে_, _skró, _zoži, --,
   {{0x6da6004d,0x00000000,0x00000000,0x00000000}},	//   _чима, --, --, --,
   {{0x1b1f00c7,0x67211d67,0x66010634,0x69c3020d}},	//   _পারে_, _belj, _aulk, énea,
   {{0x672102dd,0xf1bf0579,0xd7ef0037,0x764a0212}},	//   _celj, zná_, مكن_, ttfy,
   {{0x67212a58,0x6601022b,0x6db700e7,0x1ae32a59}},	//   _delj, _culk, mćar, _борм,
   {{0xa2ca088d,0x66010138,0xf1bf0031,0x25bf020a}},	//   _सुग्, _dulk, xná_, gnul_,
   {{0x6d4602e5,0xf1bf135f,0xb7da1915,0xe73a2a5a}},	//   _mcka, vná_, _فورا_, _неа_,
   {{0xc45300e3,0xa91d2a5b,0x25bf2a5c,0x6b8e0090}},	//   اضيع, _roži, anul_, _jobg,
   {{0xf1bf0074,0x363612eb,0x668105d1,0xa91d0141}},	//   tná_, _سراس, _نیول, _soži,
   {{0x672100cc,0xa91d2a5d,0xf484001c,0x6b8e0090}},	//   _zelj, _poži, _لاتی, _lobg,
   {{0x55770130,0xf1bf0074,0x66012a5e,0x3325010a}},	//   _רעדן_, rná_, _zulk, balx_,
   {{0xe47b0105,0xf1bf025b,0x53342a5f,0x00000000}},	//   _מרדכ, sná_, _рект, --,
   {{0xf1bf025b,0x66010188,0x2fd100c4,0xdd9b0b0a}},	//   pná_, _xulk, rozg_, пша_,
   {{0x13d50081,0xa91d033b,0xa3e409c3,0xcdd80291}},	//   _হওয়, _toži, _भीत_, ењу_,
   {{0x41c40c5e,0x00000000,0x00000000,0x00000000}},	// [1fb0] _حقيق, --, --, --,
   {{0x75220231,0x6d461d79,0x00000000,0x00000000}},	//   _leoz, _ecka, --, --,
   {{0x7cea01f9,0x00000000,0x00000000,0x00000000}},	//   töré, --, --, --,
   {{0xc98423c3,0xdd160031,0x98b90095,0x00000000}},	//   лучи, _päťd, млет_, --,
   {{0x66012a60,0x67212388,0xa3d0030b,0xf7452a61}},	//   _sulk, _pelj, वका_, вело,
   {{0x66012a62,0x6d5f0216,0x7c3f0188,0xb17b02c3}},	//   _pulk, leqa, muqr, llåd,
   {{0x67212a63,0xbbbf0f62,0x19ab2a64,0x3666008f}},	//   _velj, ्वीक, _етап_, ващо_,
   {{0x6d5f1a4a,0x25bf00ae,0x2d892a65,0x00000000}},	//   neqa, unul_, njae_, --,
   {{0x67212a66,0x9f530990,0x25bf00d3,0x57f52657}},	//   _telj, _així_, rnul_, _апат,
   {{0x66012a67,0x25bf2a68,0x43751c1b,0xe8740397}},	//   _tulk, snul_, туит, _حافظ,
   {{0x2d892a69,0xb2f400c2,0x0cde261e,0x27e00d2a}},	//   kjae_, ляющ, _मर्म, ɓin_,
   {{0xe2962a6a,0x7afa2a6b,0x75c800d2,0xe196007b}},	//   таю_, _útte, těze, троэ,
   {{0x6d5f061d,0x2ca92a6c,0x656b009c,0x00000000}},	//   deqa, jzad_, _iagh, --,
   {{0x656b0080,0x2ca902ef,0x443f008c,0xe3b30246}},	//   _hagh, dzad_, muu_, _حرص_,
   {{0x443f2a6d,0x6d460124,0x7e230e2c,0x00000000}},	//   luu_, _pcka, идрж, --,
   {{0xdde900cd,0xfce62a6e,0x656b0078,0xed570a54}},	//   فرقه_, вобо, _jagh, кос_,
   {{0x656b2a6f,0x443f2a70,0x6f02044c,0xfc032012}},	// [1fc0] _magh, nuu_, _şocu, ипто,
   {{0x4e060747,0x656b2a71,0x9f4c00c2,0xb17b0120}},	//   _изоб, _lagh, ödä_, småt,
   {{0x6a86013d,0x3ea62a72,0x443f2a73,0x91fc01d3}},	//   ължа, _ринг, huu_, lvār,
   {{0x443f2a74,0x656b2a75,0x290d002b,0x64591044}},	//   kuu_, _nagh, _cfea_, _opwi,
   {{0x92bd00c7,0xd943255a,0x91fc00d9,0xd90d010d}},	//   _আরো_, речи, nvār, سیل_,
   {{0x6d442a76,0x244b052f,0x443f008a,0xafdb01df}},	//   lgia, døm_, duu_, støv,
   {{0x64590154,0xacbb020d,0xdce60154,0x00000000}},	//   _apwi, _jeûn, _makč, --,
   {{0x6d442a77,0x443f0051,0xa2a0009d,0xa91d09ac}},	//   ngia, fuu_, खनस्, _božu,
   {{0x80e1110f,0x656b2a78,0x443f2a79,0x6d442a7a}},	//   _नरें, _dagh, guu_, igia,
   {{0x6d442a7b,0xb4e20104,0xa91d0234,0x69c2007e}},	//   hgia, _धरी_, _dožu, lnoe,
   {{0x656b2a7c,0x752202ef,0xc7d700ca,0xbb3b00ca}},	//   _fagh, _teoz, _יומי_, ועיי,
   {{0x80d10081,0x656b00ac,0x69c200f0,0x443f2a7d}},	//   _সৃষ্, _gagh, nnoe, buu_,
   {{0xa3c102d5,0xb17b0212,0x753d01f9,0x443f2a7e}},	//   ्कश_, vlåd, ósze, cuu_,
   {{0x656b2a7f,0x64402a80,0xf45700ca,0x4fc40ed4}},	//   _zagh, mumi, _סיור_, асса,
   {{0x64402a81,0xa3c10b7f,0x93fb0341,0x75e50103}},	//   lumi, ्कर_, _קלוי, lóza,
   {{0x6d440465,0x46b500aa,0x7bde0381,0x656b00bd}},	//   ggia, _अइसह, elpu, _xagh,
   {{0x64402a82,0x3b5500d3,0x2d890072,0x6d5f2a83}},	// [1fd0] numi, лкар, rjae_, reqa,
   {{0x6d5f0372,0xbbbf000c,0x765a0034,0x6f090065}},	//   seqa, ्वेक, _opty, _dèbó,
   {{0x6440068d,0x6e952a84,0x443f0a4b,0xb17b02c3}},	//   humi, _сину, zuu_, plåd,
   {{0x64402a85,0x99d10081,0x443f2a86,0x57cb0096}},	//   kumi, িষ্ক, yuu_, िव्ह,
   {{0x443f025e,0x64400029,0x7c842863,0x656b2a87}},	//   xuu_, jumi, _куре, _ragh,
   {{0x64402a88,0xb6050343,0x7d0d2a89,0x7c2d2a8a}},	//   dumi, hláš, lcas, msar,
   {{0x656b1336,0x99670aeb,0x7d0d028d,0x45d50e3a}},	//   _pagh, _итал, ocas, лцит,
   {{0x4efc0054,0x443f2a8b,0x64402a8c,0xa91d0106}},	//   ולוג, tuu_, fumi, _požu,
   {{0x64402a8d,0xa3c1022d,0x656b028d,0x7bc7010a}},	//   gumi, ्कल_, _vagh, _kjju,
   {{0x244b038c,0x443f2a8e,0x7d0d009c,0x656b2a8f}},	//   røm_, ruu_, hcas, _wagh,
   {{0xe2992a90,0x656b2a91,0x6d4400f0,0x443f2a92}},	//   хан_, _tagh, ygia, suu_,
   {{0xe5701850,0x64402a93,0x443f2a94,0x7c2d2a95}},	//   _وطن_, bumi, puu_, ksar,
   {{0xad9b2a96,0x64400ee7,0x7d0d2a97,0x7c2d02c3}},	//   _miúd, cumi, dcas, jsar,
   {{0x442d2a98,0x7c2d0bc6,0x442f2a99,0x75292a9a}},	//   mse_, dsar, _ivg_, laez,
   {{0x442d2a9b,0xed5a142f,0xd5ac0068,0x442f0103}},	//   lse_, нов_, _رہی_, _hvg_,
   {{0x442d2a9c,0x69c30103,0x7bc7083e,0x75290062}},	//   ose_, énel, _ajju, naez,
   {{0x442d2a9d,0x707700e3,0x6d442a9e,0x6abe0bba}},	// [1fe0] nse_, _مميز_, rgia, ्थ्र,
   {{0x442d2a9f,0x442f2aa0,0x6d4400f0,0x7d0d002b}},	//   ise_, _mvg_, sgia, acas,
   {{0x64402aa1,0x442d2aa2,0x7c2d2aa3,0xb17b02b6}},	//   zumi, hse_, asar, slåe,
   {{0x442d2aa4,0x9f5a06a3,0x7d0d028d,0xafdb01df}},	//   kse_, _sipè_, ccas, støt,
   {{0x64e205d4,0x442d2aa5,0x69c22aa6,0xb4e2009f}},	//   _परेश, jse_, rnoe, _धरे_,
   {{0x38cb0e8c,0x442d2aa7,0xb7d20081,0x64402aa8}},	//   رانی_, dse_, াষ্ট, vumi,
   {{0xfaa60424,0x499412eb,0x7bcb283f,0xaab822a0}},	//   _саво, _پیشر, égue, _आधिक,
   {{0x64402aa9,0xad9b0076,0xafdb00f2,0x442d2aaa}},	//   tumi, _giúd, ntør, fse_,
   {{0xd3262aab,0x442d2aac,0xb99300e3,0x48e302b3}},	//   льни, gse_, _القب, _готв,
   {{0x64402aad,0xf3662aae,0x39462aaf,0xaca40134}},	//   rumi, утин, lgos_, _nsọt,
   {{0x442d2ab0,0x7c2d0029,0xafdb038c,0x66e600c2}},	//   ase_, zsar, ktør, _сожа,
   {{0x39462ab1,0xaca40032,0x442f028d,0x64402ab2}},	//   ngos_, _asọt, _fvg_, pumi,
   {{0xc5f300a1,0x442d2ab3,0x6440063d,0x88bd0034}},	//   _הדף_, cse_, qumi, _leśn,
   {{0x6ed61792,0x7d0d2ab4,0x75e500d4,0x672a23ff}},	//   _मुहु, wcas, nózn, nafj,
   {{0x7c2d01af,0x98ad0117,0x539b0327,0x00000000}},	//   wsar, _rdeč_, _איגו, --,
   {{0x63ba0343,0x7c2d2ab5,0xc27b0341,0x27ec00dc}},	//   litn, tsar, _טרוי, _lhdn_,
   {{0x7d0d2ab6,0x69c3025a,0x61ed2ab7,0x212b2ab8}},	// [1ff0] rcas, énem, _ihal, mach_,
   {{0x212b2ab9,0x63ba1b32,0x39462aba,0x798002f1}},	//   lach_, nitn, egos_, _anmw,
   {{0x7c2d2abb,0x61ed2abc,0xf1ca0c38,0x5fdc00ca}},	//   ssar, _khal, रवचन, _אחזק,
   {{0x212b2abd,0x442d2abe,0x7c2d2abf,0x61ed00bd}},	//   nach_, yse_, psar, _jhal,
   {{0x39490029,0x18692ac0,0x61ed117b,0x63ba0a1d}},	//   ļas_, тали_, _mhal, kitn,
   {{0x212b0091,0xe7362ac1,0x629a013f,0x3946013f}},	//   hach_, аеш_, kyto, agos_,
   {{0x212b2ac2,0x442d2ac3,0x61ed00e7,0x69ca00fd}},	//   kach_, wse_, _ohal, éfec,
   {{0x442d2ac4,0x629a16e0,0x212b0034,0x2bbf1e05}},	//   tse_, dyto, jach_, ्वका,
   {{0x212b2ab9,0x291d2ac5,0x442d2ac6,0x75290634}},	//   dach_, mbwa_, use_, raez,
   {{0xe7a9033a,0x61ed02a7,0x63ba06a8,0x7bd70042}},	//   _कतिप, _ahal, gitn, noxu,
   {{0x61ed2ac7,0x212b2ac8,0x60cd01ee,0x61ff01ee}},	//   _bhal, fach_, _axam, _biql,
   {{0x442d2ac9,0x212b2aca,0x3f812acb,0x442f08a8}},	//   pse_, gach_, _anhu_, _tvg_,
   {{0x76432acc,0x61ed025e,0x15f40d74,0x3f930a7f}},	//   luny, _dhal, _اسلح, _boxu_,
   {{0x629a2acd,0x63ba0f1c,0x61ed2ace,0x39462acf}},	//   byto, citn, _ehal, zgos_,
   {{0x212b2ad0,0x3946013f,0x76432343,0xc7b200ca}},	//   bach_, ygos_, nuny, קבל_,
   {{0x61ed2ad1,0x3d2000a5,0xd1ba0068,0x4ad9097c}},	//   _ghal, बरें_, _جاتا_, _बुधव,

   {{0x76432ad2,0x8c462ad3,0x4b26261f,0xafdb01df}},	// [2000] huny, резе, имав, rtør,
   {{0x76431c7b,0x69db0350,0x109b03c2,0xafdb13c8}},	//   kuny, _akue, _סביב, stør,
   {{0x32070990,0x34e208fa,0x76430808,0x7f3b00a1}},	//   _juny_, _पर्द, juny, _בעיו,
   {{0x3946013f,0xeae6009d,0x320703a9,0x76430372}},	//   ugos_, _करीत_, _muny_, duny,
   {{0x39462ad4,0x8eb300cd,0x2d8201c2,0xa91d2ad5}},	//   rgos_, _همیش, _inke_, _požr,
   {{0x81bd0029,0x39460890,0x76432ad6,0x69c90172}},	//   lsēt, sgos_, funy, _ejee,
   {{0x76430b32,0x569405e1,0x7980010a,0x68e90415}},	//   guny, сайт, _tnmw, _ezed,
   {{0x6d5606a3,0x63ba2ad7,0xe5c60291,0x28160411}},	//   nfya, witn, јско, _نورس,
   {{0x88bd0067,0x2fd80149,0x29042ad8,0x77632ad9}},	//   _jeśl, korg_, _igma_, benx,
   {{0x61ed2ada,0x386900dd,0x26de030b,0x212b0034}},	//   _shal, çare_, _tyto_, wach_,
   {{0x212b2adb,0x76432adc,0x63ba2add,0x6ed6030b}},	//   tach_, cuny, ritn, _मुलु,
   {{0x29dc0610,0x96950d62,0x629a2ade,0xbcfb01dc}},	//   mías_, _уруш, ryto, _maér,
   {{0x212b2adf,0x29dc0610,0x67282ae0,0x66080429}},	//   rach_, lías_, _kedj, _hudk,
   {{0x212b2ae1,0x2d822ae2,0x644f0472,0xd83f0618}},	//   sach_, _anke_, àcie, _účet_,
   {{0x61ed2ae3,0x67282ae4,0x212b2ae5,0x29dc0610}},	//   _thal, _medj, pach_, nías_,
   {{0x67280ca7,0x61ed0051,0xdce601d3,0xdda8002d}},	//   _ledj, _uhal, _sakā, атул_,
   {{0x2fd82ae6,0xdce601d3,0x6be50037,0x3f9301ff}},	// [2010] borg_, _pakā, مكرم, _toxu_,
   {{0x67280292,0xa3e61344,0x69db038c,0x76432ae7}},	//   _nedj, पति_, _skue, yuny,
   {{0x68e90018,0x200100f9,0x200901c2,0x7ff41f11}},	//   _szed, _iihi_, _huai_, _بسيا,
   {{0x76432ae8,0x29dc04d8,0x200901c2,0xbcfb00d1}},	//   vuny, días_, _kuai_, _daér,
   {{0xa3e600c3,0xa2d80455,0xe7391312,0x68e002ad}},	//   पता_, _नुस्, гел_, _cymd,
   {{0x785a0029,0x8a1700bf,0x76432ae9,0x29dc0fb6}},	//   dāvā, _نظرا, tuny, fías_,
   {{0xf77000b1,0x29dc0890,0x69c9029a,0x7763002b}},	//   بان_, gías_, _tjee, renx,
   {{0x76430808,0x2fd80126,0x69c9008a,0x2009020d}},	//   runy, zorg_, _ujee, _ouai_,
   {{0xbee4033a,0x76432aea,0x68e00150,0x69d92aeb}},	//   _गर्न_, suny, _gymd, mowe,
   {{0x76430706,0x29dc05e6,0x20010134,0x69d92aec}},	//   puny, bías_, _nihi_, lowe,
   {{0xe1fa2aed,0x6b9509ef,0x29dc04d8,0xd575013f}},	//   лго_, _mozg, cías_, _гуль,
   {{0x200900dc,0x672800e7,0xdcfd05aa,0x35f50f91}},	//   _buai_, _zedj, _ansč, _упер,
   {{0xd24e037f,0x200900dc,0x2fd8003e,0x212901b9}},	//   ونی_, _cuai_, torg_, _deah_,
   {{0x443f2aee,0x20090063,0xf41200a1,0x69d92aef}},	//   mru_, _duai_, _צפו_, howe,
   {{0x23652af0,0x69d90034,0xdee623b1,0x394d0218}},	//   melj_, kowe, сови, _oces_,
   {{0x2900013f,0x394d023e,0xdced0220,0x2fd82af1}},	//   žiai_, _nces_, adač, sorg_,
   {{0x69d900a5,0x20092af2,0x6b952af3,0x3f8c00bc}},	// [2020] dowe, _guai_, _bozg, ödus_,
   {{0x443f2af4,0x68e00212,0x00000000,0x00000000}},	//   iru_, _rymd, --, --,
   {{0x29dc08a8,0x490600e3,0x443f2af5,0x69d90201}},	//   xías_, مواق, hru_, fowe,
   {{0x5d860080,0x70530814,0x29dc0328,0x6d980072}},	//   _الحل, _بنیا, vías_, _vías,
   {{0x6b9500e7,0x67280095,0xdb0e0072,0x23650141}},	//   _fozg, _pedj, _embá, kelj_,
   {{0x443f2af6,0x29dc255c,0x236502ef,0x7bdc0ac1}},	//   dru_, tías_, jelj_, _ukru,
   {{0x443f2af7,0x9f52037a,0x386d0233,0x69d9007f}},	//   eru_, _huyó_, _eser_, bowe,
   {{0x29dc11c4,0x443f2af8,0x98a60012,0x29040009}},	//   rías_, fru_, _либе, _ugma_,
   {{0x443f2af9,0x29dc0610,0x9f5a028d,0x6b950233}},	//   gru_, sías_, _pipì_, _yozg,
   {{0x29dc0328,0x23650141,0x00000000,0x00000000}},	//   pías_, gelj_, --, --,
   {{0x20090332,0x225800c2,0x4df80cce,0xe71700ca}},	//   _suai_, шины_, ंगाई_, _החבר_,
   {{0x443f2afa,0x25a60270,0xeae600aa,0x00000000}},	//   bru_, _ulol_, _करैत_, --,
   {{0x443f0012,0x20092afb,0x6ac4055c,0x53340aeb}},	//   cru_, _quai_, वपुर, _делт,
   {{0x4426026e,0x33f607c8,0x4fc700c2,0x69d92afc}},	//   _iwo_, _учес, ссма, zowe,
   {{0x69d90051,0x6b952afd,0x3da707ef,0xdced0580}},	//   yowe, _rozg, браб, rdač,
   {{0xd13100cd,0x200900dc,0x64402afe,0x44260517}},	//   _کمک_, _tuai_, ormi, _kwo_,
   {{0xdcfd00e7,0xb606080e,0xd011015a,0xf1bf0072}},	// [2030] _posđ, lišć, _تلخ_, miá_,
   {{0x6ac41344,0x44262aff,0x64400037,0x66022b00}},	//   वपूर, _mwo_, irmi, _liok,
   {{0x69d92b01,0x3cde009d,0xdd9500c6,0x44262b02}},	//   towe, _कुठे_, _даны, _lwo_,
   {{0x19590138,0x44260649,0x127b00c1,0x443f2b03}},	//   рады_, _owo_, טאבע, yru_,
   {{0x44260af0,0xf09f2b04,0x69d92b05,0x6d4f00bd}},	//   _nwo_, nyà_, rowe, _icca,
   {{0x645c002d,0xbcfb104d,0x01cf0081,0x69d92b06}},	//   ăril, _abég, রতিদ, sowe,
   {{0x44262b07,0x443f043f,0x64400a2c,0x2365033b}},	//   _awo_, wru_, ermi, velj_,
   {{0x44260b92,0x84592b08,0x394d15b1,0xb60602f7}},	//   _bwo_, арот_, _uces_, dišć,
   {{0x443f2b09,0x386d0054,0xf1bf0220,0x44260085}},	//   uru_, _user_, diá_, _cwo_,
   {{0x443f182f,0xdb0e003e,0xfe0902d5,0x44260154}},	//   rru_, _embæ, वदास_, _dwo_,
   {{0x6d5d0871,0x66022b0a,0x6d4f1ef7,0x44262b0b}},	//   _obsa, _fiok, _occa, _ewo_,
   {{0x443f2b0c,0x66020036,0x23650141,0xbcfb0032}},	//   pru_, _giok, selj_, _gbég,
   {{0x44262b0d,0x2365015c,0x25bf00ae,0xeae600b7}},	//   _gwo_, pelj_, miul_, _कर्त_,
   {{0x6d5d2b0e,0x6d4f013d,0x25bf00d3,0x3cdd02ed}},	//   _absa, _acca, liul_, _खड़े_,
   {{0x9f520032,0x1d0a00e5,0xf1bf0956,0x00000000}},	//   _buyò_, иеви_, biá_, --,
   {{0x25bf002d,0x3dc9019c,0xf1bf13a9,0x0c260b36}},	//   niul_, gnaw_, ciá_, жман,
   {{0x249f2b0f,0x752b2b10,0x248d00b3,0xfce32348}},	// [2040] nyum_, _megz, nxem_, дото,
   {{0x25bf00ae,0x61e60650,0x6d4f0027,0x248d00ee}},	//   hiul_, llkl, _ecca, ixem_,
   {{0xed5a00c9,0x3dc90270,0x00000000,0x00000000}},	//   _кон_, bnaw_, --, --,
   {{0xe9da2311,0xd378042d,0x00000000,0x00000000}},	//   шке_, moće_, --, --,
   {{0x25bf002d,0x25ad00d1,0x999c01f9,0x00000000}},	//   diul_, dhel_, évő_, --,
   {{0x4426023f,0xc7a31510,0x38690131,0x207b006e}},	//   _rwo_, мичк, çara_, יאנא,
   {{0x81c30033,0x7bce01cb,0xd37814f3,0x00000000}},	//   ্তত_, _ijbu, noće_, --,
   {{0x2cbf14f3,0x25ad2b11,0x2d92023f,0x7e9b00c1}},	//   _žudi_, ghel_, njye_, יסצו,
   {{0x938a2610,0xa73a0103,0xbcfb0065,0xf1bf2b12}},	//   асна_, _نثار_, _gbéd, viá_,
   {{0xa3e40251,0x442601c0,0x61e62b13,0x7c291930}},	//   _भीख_, _vwo_, elkl, _çere,
   {{0x86c600e3,0x25bf2b14,0xcb1300a1,0xf1bf03be}},	//   _بيان, biul_, ולת_, tiá_,
   {{0xb6062b15,0x44260054,0x25bf002d,0x2900013f}},	//   rišć, _two_, ciul_, žiau_,
   {{0x4426092f,0x25d900cd,0xcf0000a7,0xf1bf0031}},	//   _uwo_, _اهنگ_, əşən_, riá_,
   {{0x437400cd,0xad9b00da,0x00000000,0x00000000}},	//   _رهبر, _ciún, --, --,
   {{0x3ea50018,0x6d5d009c,0xf1bf0231,0x00000000}},	//   ált_, _pbsa, piá_, --,
   {{0x321e03a9,0xdb170042,0x51872b16,0x463b006e}},	//   mpty_, rixí, _фука, יעלע,
   {{0x030e0cce,0xad9b2b17,0xa1f90103,0xc19c00ca}},	// [2050] _सलाह_, _fiún, _پڑھا_, _כשהי,
   {{0x09d309a0,0x1fa72972,0x6ed61da8,0xda7b00e5}},	//   तव्य, _фриг, _मुकु, ияе_,
   {{0xf0b800d1,0xfd470103,0xaf010033,0x00000000}},	//   _هایش_, _ویسٹ_, ্রহণ_, --,
   {{0x249f1732,0x67ed04c3,0x7aed00e8,0x2ca02b18}},	//   yyum_, dúja, _ģitā, byid_,
   {{0xdb1e00b3,0x6d4d10ad,0xb17c006e,0x5d7a0142}},	//   kipè, mgaa, יטאר, _פאשק,
   {{0x81c30f71,0x2d990193,0x6cfa00a1,0x7b642b19}},	//   ্তি_, _hose_, _לפרס, _отсе,
   {{0x2d992b1a,0x25ad2b1b,0x67ed0018,0x25bf00ae}},	//   _kose_, thel_, gúja, tiul_,
   {{0x6d4d2b1c,0x3915097a,0x2d992b1d,0x00000000}},	//   ngaa, _хмар, _jose_, --,
   {{0x81c300c7,0x25bf002d,0x395f0154,0x57b51c4c}},	//   ্তা_, riul_, _ibus_, _ебат,
   {{0xbcfb0065,0x2d9906dc,0x752b0dbc,0x249f2b1e}},	//   _gbée, _lose_, _wegz, ryum_,
   {{0x69cb2b1f,0x249f2b20,0x25bf00d3,0x95cb194c}},	//   onge, syum_, piul_, _куда_,
   {{0x2ca02b21,0x69cb2b22,0x6d4d2b23,0xbcfb01dc}},	//   yyid_, nnge, jgaa, _mbéb,
   {{0x69cb2b24,0x6d4d2b25,0x920b08d4,0x26110023}},	//   inge, dgaa, _सूरज_, _háo_,
   {{0xd9b8000c,0xa4fa00ca,0x2d990113,0x4abd0f35}},	//   _अष्ट, _פלסט, _aose_, ्पाव,
   {{0x2d99023f,0x59db05a5,0x764302e7,0x8e83117c}},	//   _bose_, यकार, nrny, нгре,
   {{0x6d4d2b26,0x2d99013d,0x7643005c,0xa3b70ff9}},	//   ggaa, _cose_, irny, घोर_,
   {{0xdb1e01e5,0x6ac40569,0x76430167,0x7a0c013c}},	// [2060] qipë, वप्र, hrny, _iğti,
   {{0x6d4d29cb,0x65692b27,0x395f080b,0xa3cb0096}},	//   agaa, heeh, _abus_, रचि_,
   {{0x2d992b28,0x2ca0117e,0x98b0005f,0x9f9b00ca}},	//   _fose_, syid_, đači_, _הסיפ,
   {{0x5f460018,0x2d990634,0xe8fa2360,0x00000000}},	//   _بنگل, _gose_, бле_, --,
   {{0xa3bd02e8,0xa3cb009d,0x7d7b00ca,0x395f01ff}},	//   ीचा_, रचा_, _הנכו, _dbus_,
   {{0x261100ef,0xdb1e03a9,0x64490472,0x2d990193}},	//   _báo_, kipé, duei, _zose_,
   {{0x26110028,0x2d99023f,0xdbc713e1,0x7c36057e}},	//   _cáo_, _yose_, töös, lsyr,
   {{0x7bde2b29,0x69c30018,0x00000000,0x00000000}},	//   lopu, énet, --, --,
   {{0x64492b2a,0x76432b2b,0xdce40138,0x7c360b97}},	//   guei, arny, keič, nsyr,
   {{0x31600167,0x69c22b2c,0x290000c6,0xdc9b006e}},	//   _abiz_, lioe, žias_, צייל,
   {{0xe4d614df,0x6d4d2b2d,0x0edb2b2e,0xf77300ca}},	//   _کتاب, ygaa, _मुंड, _רקע_,
   {{0x7bde0294,0xfbc40081,0x64490428,0x69c22b2f}},	//   hopu, ্তিত, buei, nioe,
   {{0x644904ea,0x7bde00c2,0xad9b0037,0x78a22b30}},	//   cuei, kopu, _diúl, nyov,
   {{0x225900a5,0x69c201ff,0x00000000,0x00000000}},	//   ńska_, hioe, --, --,
   {{0x6d4d1f58,0xdb1e00e3,0x69cb14ef,0x649502a1}},	//   tgaa, cipé, ynge, _eżiġ,
   {{0x91e40291,0xdd9403a7,0x69c20062,0x00000000}},	//   _поје, насы, jioe, --,
   {{0x113c00ca,0x9c190037,0x00000000,0x00000000}},	// [2070] _התחל, زياء_, --, --,
   {{0x6d4d2b31,0x09c50096,0x2d9902a4,0x2a630085}},	//   sgaa, लच्य, _wose_, _ppjb_,
   {{0x6d4d2b32,0x69c201ff,0x671000aa,0x2d9901b6}},	//   pgaa, fioe, ाशनक_, _tose_,
   {{0x69cb008f,0xdb1e00c2,0x69c22b33,0x68220294}},	//   unge, enpä, gioe, _ọdac,
   {{0x26110023,0xeab00018,0x69cb2b34,0x656901cb}},	//   _sáo_, نٹے_, rnge, veeh,
   {{0x69da2b35,0xdb2300cd,0x66e52b36,0xac182b37}},	//   _íten, _سوری, мола, _хору_,
   {{0xe7302b38,0x69c20062,0x00000000,0x00000000}},	//   اصه_, bioe, --, --,
   {{0x69c22b39,0x395f02c9,0x64492b3a,0x387f00f3}},	//   cioe, _ubus_, tuei, _trur_,
   {{0x387f0188,0x29000220,0x79892b3b,0x00000000}},	//   _urur_, žiar_, _inew, --,
   {{0x261100de,0x799b01cb,0xad9b0076,0xe2a200fe}},	//   _táo_, _houw, _siúl, _thử_,
   {{0x61460ef7,0x799b02f1,0x798902ac,0x3f9a13be}},	//   мена, _kouw, _knew, _ropu_,
   {{0x5ec10081,0x799b2b3c,0xdb1e1e7d,0x7bde024a}},	//   _শুভে, _jouw, ripé, zopu,
   {{0x64492b3d,0x799b01c0,0xad9b016d,0xafdb0120}},	//   quei, _mouw, _ciúm, rrøn,
   {{0x69c20a00,0x799b2b3e,0xd84f0134,0xbef900a4}},	//   zioe, _louw, lọsi_, ंधून_,
   {{0xdb0e00fc,0x00000000,0x00000000,0x00000000}},	//   _embû, --, --, --,
   {{0x69bf0e72,0xdb1c119e,0x79890172,0x2be60285}},	//   लोमी, _imré, _nnew, _जीजू_,
   {{0x7bde2b3f,0x5f760391,0x7e65009c,0x3f9a2b40}},	// [2080] topu, _قادر, _ephp, _topu_,
   {{0xd84f0134,0x78a20a4b,0xfaa60974,0x00000000}},	//   họsi_, vyov, мазо, --,
   {{0x81c300c7,0x799b0ab2,0x7c3602c3,0x7bde055f}},	//   ্তর_, _bouw, ssyr, ropu,
   {{0x7bde2b41,0x00000000,0x00000000,0x00000000}},	//   sopu, --, --, --,
   {{0x69c201e9,0x799b2b42,0x2a6d007e,0x61e40aa9}},	//   rioe, _douw, _ćebe_, _mkil,
   {{0x7a0c00d3,0x79892b43,0x69c32b44,0x69c22b45}},	//   _aşte, _enew, éner, sioe,
   {{0x799b0154,0x6b9c2843,0x69c201c8,0x00000000}},	//   _fouw, _iorg, pioe, --,
   {{0x6b9c2b46,0x61e42b47,0x320e028d,0x799b000b}},	//   _horg, _nkil, _rufy_, _gouw,
   {{0x69c02b48,0xbeeb02d5,0xdb1c0113,0x6b9c07f9}},	//   _imme, _टर्न_, _amré, _korg,
   {{0x61e40010,0xf3662b49,0x00000000,0x00000000}},	//   _akil, фтин, --, --,
   {{0xbcfb0037,0x6b9c1556,0x316b007f,0x00000000}},	//   _mbéa, _morg, tecz_, --,
   {{0x6b9c0a02,0x61f60d7b,0x00000000,0x00000000}},	//   _lorg, _chyl, --, --,
   {{0x6b9c0185,0x0cc90081,0x65620169,0x00000000}},	//   _oorg, _শর্ত, _iboh, --,
   {{0x6b9c0a8d,0x61e42b4a,0xe4c7001c,0xa5c604c8}},	//   _norg, _ekil, _تصمی, bjóð,
   {{0x69c02b4b,0xdd9b11cc,0xa3bd007f,0x3ced00d8}},	//   _omme, оша_, ीचर_, _šev_,
   {{0xc5f801d3,0x00000000,0x00000000,0x00000000}},	//   _spēj_, --, --, --,
   {{0x3cfc01e9,0x6b9c2b4c,0x7989028d,0x799b029a}},	// [2090] рvv_, _borg, _rnew, _rouw,
   {{0x799b022b,0x69c02b4d,0x21f20220,0x6b9c2b4e}},	//   _souw, _amme, máha_, _corg,
   {{0x65620146,0xafdb004d,0xfd100103,0x799b022b}},	//   _oboh, nrøm, اجہ_, _pouw,
   {{0x9f5a00c2,0x49b8001c,0x4c951009,0x00000000}},	//   _eipä_, واند_, _зимс, --,
   {{0x6b9c2b4f,0x2d8b026a,0x799b029a,0x7e620a39}},	//   _forg, _ince_, _vouw, _ćopi,
   {{0x69c02b50,0xdce40b88,0x65622b51,0x6b9c2b52}},	//   _emme, ldiğ, _aboh, _gorg,
   {{0x16a92b53,0xdcfd0138,0x799b2b3c,0x4ae401b3}},	//   явки_, _posė, _touw, _аўта,
   {{0x6b9c2b54,0xc8c002e8,0x7bc52b55,0xdce401e8}},	//   _zorg, _शेवट, lihu, ndiğ,
   {{0x44392b56,0x290d028d,0x6b9c2b57,0xafdb0120}},	//   és_, _igea_, _yorg, støy,
   {{0x61e4238c,0x7bc52b58,0x57f400ae,0x6562039f}},	//   _skil, nihu, _апут, _eboh,
   {{0x2d8b1647,0x98a4020a,0x969000d1,0x00000000}},	//   _once_, _temă_, _نیوش, --,
   {{0x22590034,0xe29a0023,0xa91d0138,0x65620032}},	//   ńsko_, _ngưu_, _požy, _gboh,
   {{0x32090270,0xa5c60088,0x6abd0966,0x7bc52b59}},	//   _diay_, sjóð, ्पुर, kihu,
   {{0x2d8b2b5a,0x3cf502d5,0x7bc52b5b,0x65620094}},	//   _ance_, ्धने_, jihu, _zboh,
   {{0x645b2b5c,0x24592b5d,0x3d1506c0,0x61f6030a}},	//   ltui, lèm_, _ụwa_, _thyl,
   {{0x657b2b5e,0x32090019,0x61e40239,0x628300e1}},	//   nduh, _giay_, _ukil, _irno,
   {{0x68e9001c,0xf39000de,0x6b9c2b5f,0x8c431272}},	// [20a0] _nyed, _mảnh_, _porg, лете,
   {{0x6abd08fa,0x2d8b0042,0x290d0a43,0x7bc50193}},	//   ्पूर, _ence_, _agea_, gihu,
   {{0x6b9c02e2,0x68e92b60,0x645b2b61,0x7c292b62}},	//   _vorg, _ayed, htui, _çern,
   {{0x68e9010a,0x645b0f5a,0xe8fa100c,0x6b9c084e}},	//   _byed, ktui, пле_, _worg,
   {{0x6b9c2b63,0x20120022,0xdb1e2b64,0x7bc505bd}},	//   _torg, _juyi_, lipí, bihu,
   {{0x290d002b,0x20120022,0x62832b65,0x00000000}},	//   _egea_, _muyi_, _orno, --,
   {{0xfa672b66,0x56942b67,0x7c242b68,0xd9462a6e}},	//   _парк_, тайт, lpir, _певи,
   {{0xd5b72b69,0xf3900028,0x69c02b6a,0x657b019c}},	//   есь_, _cảnh_, _umme, gduh,
   {{0x62832b6b,0x7c242b6c,0xb886033d,0x657901b9}},	//   _arno, npir, _blíž, _dawh,
   {{0xafdb01df,0xdb1700a7,0x21f200d4,0x00000000}},	//   trøm, rixç, váha_, --,
   {{0x628300e9,0xf8bf0102,0xf36301b6,0x0bb700ca}},	//   _crno, _þér_, утын, גלים_,
   {{0x20122b6d,0x645b057a,0x65790090,0x62830147}},	//   _buyi_, btui, _gawh, _drno,
   {{0xdce4026a,0x777a01c8,0xf1c02b6e,0x7bc52b6f}},	//   vdiğ, _katx, शोधन, yihu,
   {{0x229400e3,0x7c240087,0x777a01ff,0x81c30033}},	//   _للتس, dpir, _jatx, ্তই_,
   {{0xfe700068,0x777a2b70,0x0edb2171,0x00000000}},	//   یدہ_, _matx, _मुखड, --,
   {{0xdced007e,0x777a0062,0x7bc50169,0x00000000}},	//   ndać, _latx, wihu, --,
   {{0x3cfc2b71,0xdce40b88,0x7c242b72,0xd164013d}},	// [20b0] लेले_, rdiğ, gpir, _същи,
   {{0x657b2b73,0xa91d2b74,0xe1ff2b75,0x777a0062}},	//   zduh, _inži, lmó_, _natx,
   {{0xc33300a1,0xdcef00ae,0xbcfb0032,0xad9b033c}},	//   רוע_, _bacă, _gbén, _liúi,
   {{0x7bc52b76,0x00000000,0x00000000,0x00000000}},	//   sihu, --, --, --,
   {{0x777a2b77,0x65792b78,0xf3900023,0xed6002c6}},	//   _batx, _rawh, _rảnh_, ížet_,
   {{0xf7710192,0xf3900023,0x777a00ee,0x98a22b79}},	//   شات_, _sảnh_, _catx, рише,
   {{0x067524c0,0x777a01ff,0x39152b7a,0xd91501b3}},	//   туля, _datx, _амбр, _адбы,
   {{0xd6ce0080,0x645b00c2,0xdb0e0154,0xa50900ae}},	//   تقى_, ttui, _albè, мейа_,
   {{0x777a2b7b,0x657b2b7c,0xad9b0076,0x7a0c020e}},	//   _fatx, rduh, _ciúi, _işta,
   {{0x645b0934,0x5ed70081,0x21320063,0x777a01c8}},	//   rtui, _ধরনে, _seyh_, _gatx,
   {{0x65792b7d,0x645b2b7e,0xa91d00e7,0x20120d2a}},	//   _tawh, stui, _anži, _suyi_,
   {{0x628302ef,0x201203a9,0x645b2843,0xcec400d2}},	//   _vrno, _puyi_, ptui, hoří_,
   {{0x75292b7f,0x98a40138,0x7c240113,0x99e80031}},	//   mbez, _temą_, xpir, liňá,
   {{0x64492b80,0x644614f3,0x43452b81,0x75292b82}},	//   mrei, škic, _рекв, lbez,
   {{0xdee62348,0xd0071c30,0xed5a21b4,0x64492b83}},	//   тови, тере_, мов_, lrei,
   {{0x661c0018,0xd00f0068,0xb6020088,0x75292b84}},	//   _érke, صلہ_, _þátt, nbez,
   {{0xff262b85,0x973c084f,0x64492b86,0x62810629}},	// [20c0] _импо, _hoće, nrei, lvlo,
   {{0x64492b87,0xd00f0260,0x7c242b88,0x442f0178}},	//   irei, _گلی_, rpir, _mwg_,
   {{0x64492b89,0xf1c62b8a,0x442f01fa,0x2d9e0257}},	//   hrei, _लगान, _lwg_, êtes_,
   {{0x64492b8b,0x6cc60450,0x442f0063,0xd00f0470}},	//   krei, _айма, _owg_, _دلی_,
   {{0xb82200c7,0x442f022e,0xaca40294,0x777a01e9}},	//   _নিহত_, _nwg_, _kpọt, _patx,
   {{0x64492b8c,0xb17b0149,0xbcfb01dc,0x00000000}},	//   drei, llåt, _mbél, --,
   {{0x973c2b8d,0x163700e3,0x660b2b8e,0x2b582b8f}},	//   _noće, نسية_, _bigk, _icrc_,
   {{0x64492b90,0xd01a00c7,0x557401c9,0xadf800a5}},	//   frei, তীয়_, угит, ंगटन_,
   {{0x64492b91,0xa80600ae,0x660b0313,0xdb0e01f9}},	//   grei, _азал, _digk, _albé,
   {{0x442f02e5,0x6e3e007e,0x75c802c6,0x00000000}},	//   _dwg_, _ovpb, tězs, --,
   {{0xf1f60034,0x69bf02d5,0xcb370266,0x261105db}},	//   ीगढ़_, लोवी, כניק_, _cšod_,
   {{0xf1a721b6,0x64492b92,0x973c02ef,0x442f0178}},	//   трон, brei, _doće, _fwg_,
   {{0xe1ff0890,0xc0580565,0x6e220a9e,0x64492b93}},	//   rmó_, кір_, _čoba, crei,
   {{0x9f530990,0x26180019,0x3869023b,0x9f430216}},	//   _això_, _kéo_, çari_, mojë_,
   {{0x4ea42b94,0x2fcd0106,0x9f43023b,0x9f34004d}},	//   арта, đeg_, lojë_, ресі,
   {{0x442f0197,0x24862b95,0x261800fe,0x00000000}},	//   _ywg_, _krom_, _méo_, --,
   {{0x6abd0179,0x69c30257,0x9f43023b,0x26182b96}},	// [20d0] ्प्र, ènem, nojë_, _léo_,
   {{0x8aa71c30,0x2d9e020d,0x21392b97,0x7529007e}},	//   кред, êter_, lash_, zbez,
   {{0x2618020d,0x9f430216,0x00000000,0x00000000}},	//   _néo_, hojë_, --, --,
   {{0xdd950ff8,0x9f43023b,0x21390052,0x64492b98}},	//   _самы, kojë_, nash_, yrei,
   {{0x2486023e,0x9f430052,0xafdb02b6,0xf7452b99}},	//   _nrom_, jojë_, gsøg, гело,
   {{0x261800de,0x442f01fa,0xdb070018,0x9f430052}},	//   _béo_, _rwg_, _eljá, dojë_,
   {{0xcf9413b6,0x24862b9a,0xfc3f01ab,0x442f009c}},	//   יטס_, _arom_, _hví_, _swg_,
   {{0x442f01fa,0x24861cab,0xafdb02b6,0x21390216}},	//   _pwg_, _brom_, bsøg, jash_,
   {{0x752918c4,0x24862b9b,0x9f430052,0x21392b9c}},	//   rbez, _crom_, gojë_, dash_,
   {{0x64492b9d,0x62811570,0x75292b9e,0x248614bd}},	//   rrei, tvlo, sbez, _drom_,
   {{0x64492b9f,0x660b0124,0x248601cb,0x35552ba0}},	//   srei, _tigk, _erom_, _مناز,
   {{0x2486004f,0x442f01bb,0x6449091f,0x6446013f}},	//   _from_, _twg_, prei, škia,
   {{0x3fc800bf,0xf5390220,0x6281000b,0x291f2ba1}},	//   ندسی_, mať_, svlo, _mfua_,
   {{0xf5390220,0x25ad0fcf,0x200c2ba2,0x00000000}},	//   lať_, lkel_, ödi_, --,
   {{0xfc3f00b3,0x261800fe,0x61ef0113,0x00000000}},	//   _aví_, _xéo_, blcl, --,
   {{0x25ad2ba3,0xf5390220,0x40e50129,0x67380234}},	//   nkel_, nať_, ụrị_, zavj,
   {{0xb17b0212,0x5ed70033,0xac86022a,0xdb1e00b3}},	// [20e0] rlåt, _ধরণে, ыгал, tipà,
   {{0xb3460396,0x9f5e0084,0xf5390220,0xb17b2ba4}},	//   moçõ, ötä_, hať_, slåt,
   {{0x25ad2ba5,0xbea62ba6,0x3ea62ba7,0x533600c1}},	//   kkel_, _санк, _синг, רנען_,
   {{0x3ea52ba8,0xf5390031,0x1ad50d7a,0xe9e50120}},	//   älte_, jať_, _दशरथ, аціо,
   {{0xe8942a6a,0xf5392ba9,0x07a6067f,0xc7c611b7}},	//   раль, dať_, ладн, лски,
   {{0xafdb0021,0x9f43023b,0x6e020129,0x21390216}},	//   rsøg, vojë_, _ọchụ, zash_,
   {{0x67380b27,0x61e600e7,0xad9b0558,0xdb07003e}},	//   ravj, kokl, _viúv, _smjö,
   {{0x6d562baa,0xd49a1c0e,0x2d802bab,0x9f43023b}},	//   ngya, еро_, ndie_, tojë_,
   {{0xa84a0dd0,0x61e600d9,0x2d802bac,0x21391175}},	//   _سلام_, dokl, idie_, vash_,
   {{0x9f4300dd,0x21f202c6,0x248601cb,0x00000000}},	//   rojë_, sáhl_, _vrom_, --,
   {{0x9f43023b,0x2139023b,0xe81a0034,0xf5390031}},	//   sojë_, tash_, _फंडा_, bať_,
   {{0x24862bad,0x2d80020a,0x25ad2bae,0xf5390031}},	//   _trom_, jdie_, ckel_, cať_,
   {{0x21392baf,0x73c4262f,0x5ff500d3,0x00000000}},	//   rash_, _پيغم, изму, --,
   {{0x2a660034,0x14d700ca,0x6d560188,0x21392bb0}},	//   łoby_, _גודל_, egya, sash_,
   {{0x3944037a,0xbcfb0139,0x21390216,0x00000000}},	//   _odms_, _gbéj, pash_, --,
   {{0x6d562bb1,0x61e62bb2,0x21392bb3,0x7c292bb4}},	//   ggya, cokl, qash_, _çerk,
   {{0x48b60033,0x00000000,0x00000000,0x00000000}},	// [20f0] জপুর, --, --, --,
   {{0x91fd0029,0xf5390181,0x2fca007e,0xdb1e2bb5}},	//   stād, zať_, cibg_, tipá,
   {{0x3a7501b6,0x20d41e49,0x25ad2bb6,0x2ca9134a}},	//   рлер, _نتیج, ykel_, syad_,
   {{0x6e25009c,0x57dd0096,0x3e41004b,0x00000000}},	//   _ithb, यव्ह, mėt_, --,
   {{0xf5392ba9,0xd5b100fe,0xa3d400a4,0x3d3a00d7}},	//   vať_, _lúc_, सचा_, _בגרס,
   {{0x225900a5,0x10380341,0x69ca2bb7,0xdd1c00c6}},	//   ński_, נטום_, éfer, _iššo,
   {{0xf5390181,0x25ad007a,0x98d20134,0x1a680a85}},	//   tať_, tkel_, sịpụ, _میلی_,
   {{0xa4450450,0x00000000,0x00000000,0x00000000}},	//   анид, --, --, --,
   {{0x69cb2bb8,0xf5390181,0x9848013d,0x6446013f}},	//   mige, rať_, _бяха_, škin,
   {{0x69cb040f,0xf5390181,0x25ad075b,0x386d1cb2}},	//   lige, sať_, skel_, _iper_,
   {{0x27e72bb9,0xd6d10867,0x25b00103,0xf5390031}},	//   monn_, _بقا_, álló_, pať_,
   {{0x69cb2bba,0x91e62bbb,0x61e600c6,0x00000000}},	//   nige, роме, uokl, --,
   {{0x6e2500e3,0x80c000b6,0x00000000,0x00000000}},	//   _athb, _लेखे, --, --,
   {{0x443f2bbc,0x69cb2bbd,0x753b2bbe,0xdfd20037}},	//   msu_, hige, lauz, زيز_,
   {{0xa91d0871,0x09b5009d,0x63a30049,0x69cb149c}},	//   _každ, ंसाठ, _ionn, kige,
   {{0x63a32bbf,0x1d260e20,0x27e72bc0,0x32da00ca}},	//   _honn, рмам, honn_, _שחקנ,
   {{0x63a32bc1,0x443f2bc2,0x2d80040c,0x69cb2bc3}},	// [2100] _konn, nsu_, rdie_, dige,
   {{0x443f2bc4,0x63a32bc5,0x2f1c0139,0xeab20037}},	//   isu_, _jonn, _dàgó_, يعا_,
   {{0x69cb2bc6,0x3dd70649,0x63a32bc7,0x973c0335}},	//   fige, úewé_, _monn, _noća,
   {{0x63a30037,0x88862bc8,0x69cb2bc9,0xa01b003e}},	//   _lonn, илеж, gige, kvöl,
   {{0x91fd00d9,0x38cb015a,0x6eca0635,0x76410572}},	//   ltāc, پانی_, _हेतु, _avly,
   {{0x63a32bca,0x98a400b6,0x973c2bcb,0xc66a00c2}},	//   _nonn, _země_, _boća, вшие_,
   {{0x69cb2bcc,0x2956013d,0xafdb038c,0x443f2bcd}},	//   bige, _възр, prøv, esu_,
   {{0x443f2bce,0xd37802e6,0x6d460063,0x04662bcf}},	//   fsu_, moći_, _jdka, атом,
   {{0x26160067,0x63a32bd0,0x443f00f9,0xb0c50034}},	//   _पूरी_, _bonn, gsu_, _लेंग,
   {{0x63a32bd1,0x7980023f,0x3d1d0032,0x79821b0d}},	//   _conn, _hamw, _káwó_, ldow,
   {{0x6d460871,0x79802bd2,0x63a315bc,0x443f2bd3}},	//   _odka, _kamw, _donn, asu_,
   {{0x7c2600e9,0x79822bd4,0x63a300a4,0x31c71eac}},	//   _otkr, ndow, _eonn, рсов,
   {{0x63a32bd5,0x8463008f,0x7980030a,0x443f2bd6}},	//   _fonn, _дъще, _mamw, csu_,
   {{0x44262bd7,0x63a32bd8,0x6d46008a,0x64422bd9}},	//   _ito_, _gonn, _adka, _ivoi,
   {{0x7c2624e5,0xc3fb00a1,0x644001df,0x69cb2bda}},	//   _atkr, _שלוש, lsmi, yige,
   {{0x44262bdb,0xa91d08a9,0x63a32bdc,0x79800198}},	//   _kto_, _kaže, _zonn, _namw,
   {{0x63a30283,0x61ed1331,0x69cb0727,0xdb1e00c2}},	// [2110] _yonn, _ikal, vige, kipä,
   {{0x44262bdd,0x69d80257,0xa91d013f,0x69cb2bde}},	//   _mto_, éven, _maže, wige,
   {{0x69cb2bdf,0x79800ab1,0x386d00d3,0x61ed2be0}},	//   tige, _bamw, _sper_, _kkal,
   {{0x44262be1,0x443f2be2,0x64402be3,0x79822be4}},	//   _oto_, ysu_, ksmi, gdow,
   {{0x44262be5,0xfd9600a1,0x61ed0051,0xe6cb0088}},	//   _nto_, _הדרך_, _mkal, _íbúð,
   {{0x64402be6,0x628a2be7,0xdb1e00aa,0x3d1d0139}},	//   dsmi, _orfo, gipä, _fáwó_,
   {{0x44262be8,0x3f8118c4,0x64422be9,0x28a702d5}},	//   _ato_, _mahu_, _avoi, _कॅरि,
   {{0x81bd0b4b,0x63a32bea,0x973c2beb,0x27e706a3}},	//   spēj, _sonn, _voća, sonn_,
   {{0x69c92bec,0x27e70c56,0x63a32bed,0x64402bee}},	//   _imee, ponn_, _ponn, gsmi,
   {{0x443f2bef,0xd7fb02fd,0x61ed2bf0,0xaca30294}},	//   rsu_, _руб_, _akal, _adịb,
   {{0x44262bf1,0x443f2bf2,0x63a32bf3,0x79802bf4}},	//   _eto_, ssu_, _vonn, _yamw,
   {{0x443f2bf5,0x63a3083e,0x64402bf6,0x00000000}},	//   psu_, _wonn, bsmi, --,
   {{0x628a02dc,0x3f810d17,0x973c005f,0x644f18c8}},	//   _erfo, _bahu_, _moćn, ácid,
   {{0x63ba2bf7,0x23262440,0x61ed2bf8,0x7982007f}},	//   chtn, _лоши_, _ekal, zdow,
   {{0xdfcf00e3,0x65b50146,0xa91d1f54,0x3f8114f3}},	//   ريف_, _záha, _zaže, _dahu_,
   {{0x973c00e9,0x3d28001c,0x68fb2bf9,0xdcfd04a8}},	//   _noćn, شتری_, _ozud, _alsı,
   {{0x6da32bfa,0x3f810234,0x4426037a,0x68fb010a}},	// [2120] чита, _fahu_, _xto_, _nzud,
   {{0xa3ca08e7,0x69c92bfb,0x6ee10134,0x79802bfc}},	//   रोप_, _amee, _ịbel, _samw,
   {{0x8e8600e3,0x7980022b,0x2bb9009d,0x0a4a00c2}},	//   _الجه, _pamw, _इतरा, узей_,
   {{0xe93a1823,0x8d560aad,0xe9da0fd6,0x6d4602b6}},	//   اسات_, _уточ, ыке_, _udka,
   {{0x79822bfd,0xa3e70ded,0x515b00ca,0x60000ee2}},	//   rdow, पवा_, רכנו, römf,
   {{0xbcfb0065,0x69c92bfe,0x79802bff,0x7982033c}},	//   _abéw, _emee, _wamw, sdow,
   {{0x442603ce,0x2d821114,0xa91d2c00,0x65b51ba6}},	//   _sto_, _kake_, _saže, _sáha,
   {{0x64400f05,0xa91d013f,0xa3ca0179,0xb8ce0081}},	//   tsmi, _paže, रोन_, _ওই_,
   {{0x2d820054,0x4426016d,0x64402c01,0x81bd01d3}},	//   _make_, _qto_, usmi, spēk,
   {{0xa91d005f,0x61ed2c02,0xd37a1121,0xd4e300c2}},	//   _važe, _skal, учи_, яющи,
   {{0x9f8d00b6,0xc7b300ca,0xdddc0117,0xd2f800ae}},	//   uží_, _צבע_, zvrš, ренц_,
   {{0xdb1c0102,0x2d820044,0x3f810022,0x64402c03}},	//   _umræ, _nake_, _sahu_, psmi,
   {{0x44262c04,0xafdb038c,0x673a0084,0xd4f60281}},	//   _uto_, drør, _ketj, _اثاث,
   {{0x623412e7,0x2d820139,0x82330018,0x43940219}},	//   _деку, _aake_, _کروا, _факс,
   {{0x25a62c05,0x673a007e,0x61ed2c06,0x3f832c07}},	//   _kool_, _metj, _tkal, rdju_,
   {{0x673a0268,0x7bdc0078,0x61ed2c08,0x21f90094}},	//   _letj, _ajru, _ukal, mého_,
   {{0x3f812c09,0x21f90074,0x2d820a75,0xdb0e00ee}},	// [2130] _tahu_, lého_, _dake_, _albà,
   {{0x673a0cad,0x69c90a9f,0x661a01c2,0x75d300ae}},	//   _netj, _smee, _outk, răzi,
   {{0x21f90897,0x1df90fe9,0x973c00c4,0x2d8200d7}},	//   ného_, _вены_, _poćn, _fake_,
   {{0xd37800e9,0x25a6008a,0x2d820079,0xad9b0076}},	//   moću_, _nool_, _gake_, _dhúc,
   {{0x973c2c0a,0x673a038c,0x21f90146,0xdcfd05aa}},	//   _voćn, _betj, hého_, _kasč,
   {{0x21f90871,0x7c2d22d3,0x2d82068d,0x661a2c0b}},	//   kého_, mpar, _zake_, _butk,
   {{0x2d822c0c,0x2013009e,0x660505b6,0x2f5c0266}},	//   _yake_, _mixi_, опка, אדונ,
   {{0x69c92c0d,0x9425004c,0x25a600ca,0x21f90094}},	//   _umee, омие, _cool_, dého_,
   {{0x6f002c0e,0x7c2d2c0f,0x57d50396,0xdfe90179}},	//   _kábí, npar, _доаѓ, ओवाद_,
   {{0x387f01ff,0x673a02ac,0xd378037d,0x37f900d3}},	//   _isur_, _getj, koću_, _тезэ_,
   {{0x395f0b14,0xd6db1eb9,0x27e00037,0x56942c10}},	//   _kcus_, _ста_, éine_, _нафт,
   {{0x65bf0139,0x20130428,0x25a6008c,0x69d90364}},	//   _dàhù, _aixi_, _gool_, nnwe,
   {{0x09a7007d,0x20130188,0x64a52c11,0xdbc600aa}},	//   _खवैय, _bixi_, _фала, mööb,
   {{0x2d822c12,0x44072c13,0x7c2d2c14,0x21f90094}},	//   _sake_, _учеб, dpar, bého_,
   {{0x2d822c15,0x442d2c16,0x76432c17,0x7c2d2c18}},	//   _pake_, lpe_, nsny, epar,
   {{0x65692c19,0x60000149,0x201b2c1a,0x69d901c0}},	//   nfeh, döme, _fuqi_, jnwe,
   {{0x90c302fd,0xfaf80029,0x442d0c56,0x7c2d2c1b}},	// [2140] _объе, _šī_, npe_, gpar,
   {{0xdb1c0501,0x442d2c1c,0x7a0c01d4,0xe81d0251}},	//   _områ, ipe_, _işti, _पढ़ा_,
   {{0x6da60581,0x2d820054,0x65b50244,0x387f2c1d}},	//   _дина, _take_, _náho, _asur_,
   {{0xa96a007e,0x442d2c1e,0x673a23ff,0x2d82006c}},	//   рида_, kpe_, _setj, _uake_,
   {{0x7c2d009c,0x661a2c1f,0x7a400065,0x673a2c20}},	//   cpar, _sutk, _bátá, _petj,
   {{0x661a00c2,0x25a6019a,0xe7930291,0x395f009c}},	//   _putk, _sool_, дишњ, _ecus_,
   {{0xd5ba1102,0x8f9b00f5,0x442d0185,0x673a2c21}},	//   иси_, ייסי, epe_, _vetj,
   {{0x21f90c01,0x746a2c22,0x77b400b3,0x00000000}},	//   vého_, аров_, _tàxo, --,
   {{0x7643005c,0x442d0270,0x7c290c2f,0x65b500d2}},	//   asny, gpe_, _çert, _táhn,
   {{0x661a2c23,0x21f90579,0xe73700d3,0x3160173c}},	//   _tutk, tého_, _меу_, _aciz_,
   {{0x25a62c24,0x741400cd,0x442d2c25,0xe57a008f}},	//   _tool_, _کوتا, ape_, _взе_,
   {{0x21f90074,0xd46a2c26,0x442d03a9,0x00000000}},	//   rého_, _виде_, bpe_, --,
   {{0x38662c27,0x65b515bf,0x9f4e0146,0x7c2d2c28}},	//   ntor_, _záho, šným_, xpar,
   {{0xa91d013f,0xb4c80521,0x9f5a06a3,0x38662c29}},	//   _maža, ोपी_, _sipò_, itor_,
   {{0xa91d031a,0x20132c2a,0x6602063d,0x38660216}},	//   _laža, _vixi_, _khok, htor_,
   {{0x65b5033d,0xd3780034,0x22510031,0xdd982c2b}},	//   _náhl, leć_, ázke_, ошу_,
   {{0xa91d02e6,0xf1bf0037,0x3a2a0bb6,0x3866023b}},	// [2150] _naža, mhá_, _atbp_, jtor_,
   {{0x7c2d2c2c,0x66020085,0x2b4a03a8,0xf1bf2c2d}},	//   rpar, _lhok, _cdbc_, lhá_,
   {{0x7a400080,0x37d00033,0x76580350,0x00000000}},	//   _rátá, াকার, juvy, --,
   {{0xa3ca0469,0x195902e3,0xbd6b1ad1,0x4e7a00c1}},	//   रोत_, сады_, _трое_, _פארצ,
   {{0xf1b400a1,0x76430167,0x69d902db,0x00000000}},	//   וסף_, wsny, rnwe, --,
   {{0xa91d2c2e,0xec3600ca,0x66022c2f,0x31a20094}},	//   _daža, _מאשר_, _ahok, _dózy_,
   {{0x6602101e,0x38662c30,0x9aa513c3,0xc9772c31}},	//   _bhok, ator_, _عمرو, _وارث,
   {{0x31790067,0x66022c32,0xdb07023b,0x65b5035d}},	//   jesz_, _chok, _lojë, _váho,
   {{0x442d2c33,0x38662c34,0x764302ae,0x31790103}},	//   upe_, ctor_, ssny, desz_,
   {{0x75d300d3,0x65692c35,0x76432c36,0x1b1d0033}},	//   văzu, sfeh, psny, _পড়তে_,
   {{0x656902e2,0x65151a13,0x00000000,0x00000000}},	//   pfeh, _فوائ, --, --,
   {{0x442d0b65,0x216a2c37,0xd5b801d3,0x91fd00e8}},	//   ppe_, щими_, _stāv_, stān,
   {{0xbcfb01dc,0x43951605,0xd37800c4,0x00000000}},	//   _mbés, _надс, beć_, --,
   {{0x66092c38,0x35d1009f,0x21f20094,0x1c1f00aa}},	//   lmek, _तगड़, váhu_, _बढ़ल_,
   {{0xa3b81f11,0x59bd02d5,0xbcfb020d,0x00000000}},	//   _ظاهر_, ्फार, _obés, --,
   {{0x317900a5,0xf1bf025b,0x9c260d5e,0x66092c39}},	//   cesz_, chá_, здад, nmek,
   {{0x90460037,0x25bf00dc,0x60002c3a,0x1d072c3b}},	// [2160] _عنده, ihul_, römb, зети_,
   {{0xdb070052,0x66090e5b,0xa91d2c3c,0x00000000}},	//   _gojë, hmek, _raža, --,
   {{0x66092c3d,0xa91d00cc,0x200a0063,0x2eff0022}},	//   kmek, _saža, mmbi_, ƙufa_,
   {{0x38662c3e,0x58862787,0x25bf2acb,0xa91d0138}},	//   ttor_, зыка, jhul_, _paža,
   {{0xd90d09b4,0x660900bc,0xc18d006e,0x91fd00e8}},	//   لیف_, dmek, יטאָ, dtāl,
   {{0x66022c3f,0x38662c40,0xa91d005f,0xaa462c41}},	//   _shok, rtor_, _važa, _негл,
   {{0x7bce2c42,0x3e8702c6,0xd3780880,0x200a06b0}},	//   _imbu, mítá_, već_, imbi_,
   {{0xbcfb2c43,0x9adb00a1,0x38660ab0,0x25bf2c44}},	//   _ibér, _החלט, ptor_, ghul_,
   {{0xa91d0039,0x6d4b0037,0x386600b3,0x00000000}},	//   _kažn, ógai, qtor_, --,
   {{0xad9b0019,0x644f2c45,0x00000000,0x00000000}},	//   _nhún, ácia, --, --,
   {{0x7bce02e7,0xdcfd01d3,0x21790fe9,0x66022c46}},	//   _mmbu, _masā, ойны_, _thok,
   {{0xa91d042d,0x80ab0081,0x25bf2c47,0x7bce0042}},	//   _lažn, _চেষ্, chul_, _lmbu,
   {{0x4420002d,0x26091362,0xbcfb2c48,0x00000000}},	//   _îi_, ागरी_, _océa, --,
   {{0xad9b00ef,0xefc82c49,0x03a3060b,0xf09f00ee}},	//   _chún, пуск_, _пичо, rxà_,
   {{0xdb070113,0xad9b0076,0x00000000,0x00000000}},	//   _gojè, _dhún, --, --,
   {{0x40ee06c0,0x22f700a1,0x9df907bf,0x63aa14bd}},	//   ọrọ_, _מזון_, інат_, _hofn,
   {{0xa91d013f,0xbcfb0139,0x6285003e,0xc1050076}},	// [2170] _bažn, _abér, _áhor, _توظي,
   {{0xbcfb033c,0x91fd00e8,0xad9b033c,0x00000000}},	//   _ccéa, itām, _ghún, --,
   {{0xa91d01b3,0xfe24007b,0x00000000,0x00000000}},	//   _dažn, _пьян, --, --,
   {{0x7bce2c4a,0x6aaa0222,0x63aa0178,0x7af500d2}},	//   _embu, äffa, _lofn, _vyzt,
   {{0x81b003e3,0x2d992c4b,0xdcfd00e8,0x00000000}},	//   _jiɓa, _inse_, _fasā, --,
   {{0xab842c4c,0xbcfb00e3,0xbcb600ca,0x75f70231}},	//   _пуск, _gcéa, _חפשו_, mãzi,
   {{0x66092c4d,0x25bf2c4e,0xbcfb0af0,0x00000000}},	//   tmek, thul_, _gbér, --,
   {{0x2d892c4f,0x75fe023b,0x6d5f019f,0x9f4a13c6}},	//   ndae_, tëza, ngqa, robé_,
   {{0x91fd0029,0x66092c50,0x394d00cc,0x44392c51}},	//   rtāl, rmek, _ides_, ès_,
   {{0x63aa0150,0xe3b10037,0x65620231,0x25bf0ac1}},	//   _cofn, ئرة_, _ecoh, shul_,
   {{0x91e62c52,0x2d992c53,0x61ef0503,0x2d8902ac}},	//   доне, _onse_, focl, kdae_,
   {{0x44b52c54,0xa91d0138,0x600002c3,0x00000000}},	//   _обес, _mažo, döma, --,
   {{0xa3ca034d,0xa91d00cc,0x2d890f5a,0x00000000}},	//   रोह_, _lažo, ddae_, --,
   {{0x2d992c55,0x3fcc0081,0x63aa00f0,0x98ad0031}},	//   _anse_, লক্ষ, _gofn, _oceľ_,
   {{0x394d08a9,0xa91d0b18,0x248d2c56,0xdb1e0052}},	//   _odes_, _ražn, lvem_, shpë,
   {{0xbcfb00e3,0x394d03a9,0x70ef0294,0x2176036c}},	//   _scéa, _ndes_, ụrụi, _цукр,
   {{0xa91d03ce,0xdcfd0029,0x64460335,0x3a2d1523}},	// [2180] _pažn, _pasā, škiv, _čepa_,
   {{0x973c2c57,0x2d992c58,0x394d00b3,0x6b87007e}},	//   _voćk, _ense_, _ades_, _cajg,
   {{0xa91d02e6,0x00000000,0x00000000,0x00000000}},	//   _važn, --, --, --,
   {{0xe8fa2c59,0x394d0231,0xa91d2c5a,0x00000000}},	//   оле_, _cdes_, _dažo, --,
   {{0x6b872c5b,0x394d030a,0xa91d1405,0x00000000}},	//   _fajg, _ddes_, _tažn, --,
   {{0x6d442c5c,0x394d0084,0xc5f82c5d,0x7bce0201}},	//   laia, _edes_, ुष्य_, _umbu,
   {{0xd90d0068,0x5a55013d,0xba232c4c,0x00000000}},	//   لیہ_, _пъту, _адск, --,
   {{0x77b40472,0x6d442c5e,0x1dde2c5f,0x973c09ac}},	//   _màxi, naia, नचित, _moći,
   {{0x628300f9,0x186a117c,0x00000000,0x00000000}},	//   _asno, _фази_, --, --,
   {{0x6d4401e9,0x69c22c60,0x69b40096,0xa91d0880}},	//   haia, lhoe, _आवडी, _lažl,
   {{0x6d4406ee,0x973c00cc,0x452a00ae,0xc7d70289}},	//   kaia, _noći, _джен_, _קובי_,
   {{0x850606f6,0x22510579,0x69c22c61,0xa194224a}},	//   _قوان, ázka_, nhoe, ваюч,
   {{0x6d442c62,0x64b60182,0x3c2400a7,0x4613001c}},	//   daia, _تحار, _növ_, _شوهر,
   {{0x7bde0381,0x00000000,0x00000000,0x00000000}},	//   jnpu, --, --, --,
   {{0x05b20789,0x6d441789,0xafdb00f3,0x69c21cab}},	//   _जवाब, faia, lsøk, khoe,
   {{0xa91d0029,0x6d442c63,0x973c007e,0xe3b80233}},	//   _ražo, gaia, _doći, lkı_,
   {{0x2d890313,0x2616034c,0x69c22c64,0xafdb0ac9}},	// [2190] rdae_, _पूछी_, dhoe, nsøk,
   {{0x2d89057a,0x09d70096,0x69c21570,0xe3b807e7}},	//   sdae_, ढच्य, ehoe, nkı_,
   {{0x6d442c65,0x248d00b6,0xb17b0120,0x63a702c3}},	//   baia, zvem_, pnåd, öjni,
   {{0xd5a62c66,0x69c22c67,0xafdb00f3,0x6d44078e}},	//   _صف_, ghoe, ksøk, caia,
   {{0xe7eb007d,0xe3b801e8,0x394d023b,0x6d4f2c68}},	//   टवला_, kkı_, _vdes_, _idca,
   {{0x65bc2c69,0xe79b0076,0xafdb0170,0xd7c81cc8}},	//   _réha, تخصص_, dsøk, وونه_,
   {{0x65bc01dc,0x00000000,0x00000000,0x00000000}},	//   _séha, --, --, --,
   {{0x394d21d5,0x91fd00d9,0xff1800ca,0x644f0031}},	//   _udes_, stāj, וקות_, ácio,
   {{0xa924025b,0x60000149,0x799b0d2a,0x00000000}},	//   _úžas, dömn, _inuw, --,
   {{0xf7702c6a,0xb6050146,0xa3ca2853,0x656000e3}},	//   _نام_, dnáš, रोल_, agmh,
   {{0xeb920130,0xe2992c6b,0x79890113,0x00000000}},	//   אָר_, чан_, _kaew, --,
   {{0xdb070102,0x1df902d5,0xcb120327,0x56b6006e}},	//   _hljó, ंतोष_, טלי_, _אפען_,
   {{0xbcfb2c6c,0x6d440131,0x79890113,0x00000000}},	//   _scén, vaia, _maew, --,
   {{0x6d44063f,0x75292c6d,0xb4cb0336,0x973c0357}},	//   waia, lcez, रछी_, _poći,
   {{0x670f000c,0x64492c6e,0xa91d0039,0x6d442c6f}},	//   ाधिक_, lsei, _pažl, taia,
   {{0x973c00c4,0x442f2c70,0x00000000,0x00000000}},	//   _voći, _ktg_, --, --,
   {{0x64492c71,0x6d442c72,0x6b5600e3,0x9f4a015e}},	// [21a0] nsei, raia, فضائ, lobí_,
   {{0x6d442c73,0x7c2b2c74,0x644901ec,0xaca40134}},	//   saia, ígra, isei, _nrụt,
   {{0xc0a900bf,0x6d441a47,0x69c22c75,0x443d2c76}},	//   _فایل_, paia, thoe, _lww_,
   {{0xdca62249,0x68460642,0x394000e3,0xaca40134}},	//   _зами, енда, úis_, _arụt,
   {{0x69c204e2,0x2ac60065,0x201a024a,0xad1b00ca}},	//   rhoe, _bíbé_, _kipi_, _מוכר,
   {{0x64492c77,0x61e41100,0xc7a32549,0x69c201d0}},	//   dsei, _ljil, личк, shoe,
   {{0x644b0578,0x69c22c78,0x201a03a9,0x442f07ee}},	//   _avgi, phoe, _mipi_, _atg_,
   {{0x38cb00d0,0x9f4a0363,0x75fe00dd,0xa91d0087}},	//   _کافی_, dobí_, rëzo, _lažj,
   {{0x69c02c79,0x91fd00d9,0x3946001c,0xdb072c7a}},	//   _ilme, stāk, maos_, _fljó,
   {{0xa3ca0d1b,0x61e4068d,0x442f0808,0xafdb00d6}},	//   रों_, _ajil, _dtg_, rsøk,
   {{0xe3b803a3,0x443d00f9,0x969601b6,0xa281001c}},	//   rkı_, _eww_, _яраш, لیوو,
   {{0x644902e2,0x39462c7b,0x7529028d,0xe3b8026a}},	//   bsei, naos_, ccez, skı_,
   {{0xecd002d5,0x61e42c7c,0x201a00c4,0x443d0381}},	//   _सेलफ, _djil, _bipi_, _gww_,
   {{0x6d4f1df6,0x64460087,0x24860027,0xa91d0141}},	//   _sdca, škis, _isom_, _ražm,
   {{0x69c02c7d,0x7c2f0381,0x39460324,0xb60500d2}},	//   _olme, _stcr, kaos_, snáš,
   {{0x61e4023b,0x39462c7e,0x00000000,0x00000000}},	//   _gjil, jaos_, --, --,
   {{0x6ad900c3,0x39462c7f,0xa01b0c19,0x3209020b}},	// [21b0] भप्र, daos_, rvös, _ihay_,
   {{0x69c02c80,0xdb150072,0x61fd2c81,0x973c00c4}},	//   _alme, _alzá, llsl, _koću,
   {{0x29040239,0x32090023,0x2a780027,0xb7b500fe}},	//   _azma_, _khay_, _cprb_, _lịc,
   {{0x28d22c82,0x248600e7,0x201a2c83,0x3237006e}},	//   _देहि, _osom_, _zipi_, גטאן_,
   {{0x69c0009c,0x50b30c38,0x63ba010a,0x00000000}},	//   _dlme, ुनिष, kktn, --,
   {{0x2d8b0f71,0x9a872c84,0x69c02c85,0xa91d013f}},	//   _hace_, _публ, _elme, _kažk,
   {{0x2d8b2c86,0x973c015c,0xdb071405,0x600002c3}},	//   _kace_, _noću, _kojí, döml,
   {{0x64492c87,0x2d8b08a9,0x442f18c4,0x69c0009c}},	//   tsei, _jace_, _ptg_, _glme,
   {{0x2d8b006d,0x75290451,0xb4cb00a3,0xdb072c88}},	//   _mace_, rcez, रछे_, _mojí,
   {{0x61f625c5,0x64492c89,0x3209008a,0xb7b500fe}},	//   _skyl, rsei, _ahay_, _dịc,
   {{0x13090084,0xa2e501b6,0x320900f9,0x920d0034}},	//   ьной_, тонд, _bhay_, सगंज_,
   {{0x442f2c8a,0x201a06a8,0x32092c8b,0x9f4a1515}},	//   _ttg_, _sipi_, _chay_, robí_,
   {{0x9f4a025b,0x644603da,0x442f2c8c,0x7bd701ff}},	//   sobí_, škir, _utg_, kixu,
   {{0x2b43033b,0x61fd0381,0x00000000,0x00000000}},	//   _nejc_, alsl, --, --,
   {{0x201a2c8d,0x2d8b0044,0xdb071054,0x7bd701ff}},	//   _vipi_, _bace_, _bojí, dixu,
   {{0xc69200f5,0x2d8b00e7,0xdb07034f,0x291f00fe}},	//   סאן_, _cace_, _cojí, _ngua_,
   {{0x201a2c8e,0x2d8b1114,0xab661c4c,0x68fb2c8f}},	// [21c0] _tipi_, _dace_, квал, _nyud,
   {{0x291f2c90,0x2d8b0167,0x6d4b01cd,0xa01b2a6b}},	//   _agua_, _eace_, ógar, svör,
   {{0x68fb0eb8,0xcf570054,0x0f570130,0x2d8b2c91}},	//   _ayud, _בבית_, _ביים_, _face_,
   {{0x2d8b02a4,0x68fb0537,0x7a470103,0x00000000}},	//   _gace_, _byud, _sétá, --,
   {{0x2d80002d,0x39462c92,0x63ba0120,0x1874186f}},	//   meie_, raos_, yktn, угля,
   {{0x2d8b2c93,0x2d80004d,0x7bc5225b,0x7c362c94}},	//   _zace_, leie_, chhu, mpyr,
   {{0xfaa32c95,0x2d8b1114,0xc7b80b14,0x69262c96}},	//   _каро, _yace_, _niđe_, _амба,
   {{0xa2c50d77,0x5e5700c1,0x2d8b0072,0x69c02c97}},	//   ानन्, דיקע_, _xace_, _ulme,
   {{0x68fb2c98,0x29042c99,0x65b500d8,0x00000000}},	//   _gyud, _uzma_, _náhu, --,
   {{0x21200063,0x3209008c,0x394413ea,0x7afc033c}},	//   _agih_, _shay_, _hems_, _kyrt,
   {{0x2d800185,0xd7ef00e3,0xe3af08ba,0x63ba01cb}},	//   keie_, _بكل_, تري_, rktn,
   {{0xb6d900c1,0x2486006c,0x39440294,0xa5da2c9a}},	//   _אַנט, _tsom_, _jems_, _غبار_,
   {{0x2d8b2c9b,0x61fd2c9c,0x00000000,0x00000000}},	//   _race_, rlsl, --, --,
   {{0x2d8b0044,0x040d00fe,0x39440144,0x00000000}},	//   _sace_, _mườn, _lems_, --,
   {{0x32090028,0x2d8b2c9d,0xdb0e023b,0x040d0023}},	//   _thay_, _pace_, _dobë, _lườn,
   {{0x32090270,0x21200113,0xd8482c9e,0x60b50103}},	//   _uhay_, _ggih_, kọ_, _ممبئ,
   {{0x52e2178c,0x00000000,0x00000000,0x00000000}},	// [21d0] _पशुस, --, --, --,
   {{0x1ae70081,0xe1ff2c9f,0x2d8b0044,0xad9b0037}},	//   _করবে_, lló_, _wace_, _mhúi,
   {{0x2d8b006d,0x68fb0a69,0x7afc03a8,0x65b500d4}},	//   _tace_, _syud, _cyrt, _záhu,
   {{0xe1ff0018,0x68fb0270,0xa91d2ca0,0x00000000}},	//   nló_, _pyud, _kaži, --,
   {{0x040d0019,0x7c220037,0x39440180,0xdb0e0154}},	//   _cườn, íort, _dems_, _lobè,
   {{0xa91d013f,0x69d804d4,0x040d00de,0x66e501b6}},	//   _maži, éver, _dườn, лола,
   {{0xf7701fa7,0x39442ca1,0xdb0e05aa,0x7afc03a8}},	//   تان_, _fems_, _nobè, _gyrt,
   {{0x7f450090,0xad9b0503,0x291f0350,0x00000000}},	//   _lehq, _bhúi, _ugua_, --,
   {{0x7afc00dd,0xad9b00e3,0x98680018,0xc7b8042d}},	//   _zyrt, _chúi, _لینے_, _siđe_,
   {{0x69d92ca2,0x52a9193d,0xd7740470,0xa91d00d4}},	//   liwe, евом_, _نامع, _naži,
   {{0xd5750805,0x61462ca3,0x216a2ca4,0xdb0e0052}},	//   _буль, лена, нини_, _robë,
   {{0x60000212,0x69d92ca5,0x9f4a0146,0xe1ff0301}},	//   römm, niwe, dobá_, gló_,
   {{0x753b2ca6,0xe3b3001c,0xad9b033c,0x00000000}},	//   mbuz, _پرش_, _ghúi, --,
   {{0xe1ff034f,0x3eb82ca7,0x645b112f,0x434518d4}},	//   aló_, tyrt_, mrui, _секв,
   {{0x3ebe0088,0xe1ff2ca8,0x69d92ca9,0xe2a800e3}},	//   átt_, bló_, kiwe, _لاين_,
   {{0x69d90051,0x3f8c1e3a,0xd8482caa,0x7bd50350}},	//   jiwe, ždu_, yọ_, _amzu,
   {{0x645b2cab,0x6721033b,0x2d802cac,0xdca30b1e}},	// [21e0] nrui, _oglj, reie_, бати,
   {{0x3ea62cad,0x69d902ac,0x8b262cae,0x645b02ac}},	//   _биог, eiwe, удже, irui,
   {{0x7c362caf,0x645b0037,0x7bcb0216,0xdb1c042c}},	//   spyr, hrui, ëgua, _umrü,
   {{0x91fd0029,0xa91d1b32,0x645b0a9f,0x08c600d3}},	//   stāv, _zaži, krui, лбен,
   {{0x6d4601d3,0x645b0381,0x00000000,0x00000000}},	//   _ieka, jrui, --, --,
   {{0x91fd0029,0x6d462cb0,0x645b2cb1,0xa63400d6}},	//   ltāt, _heka, drui, анкі,
   {{0x2605007d,0x6d462cb2,0xf1c1025b,0xad9b0076}},	//   _हीही_, _keka, ášky_, _shúi,
   {{0x54542cb3,0x645b2cb4,0x040d0019,0x6d462cb5}},	//   авит, frui, _tườn, _jeka,
   {{0xa2d92cb6,0x973c0095,0x645b112f,0x136a008f}},	//   _फेब्, _anće, grui, ншни_,
   {{0x1ae70f71,0x6d462cb7,0x42742cb8,0x7c262cb9}},	//   _করতে_, _leka, агос, _mukr,
   {{0xb3450161,0x75fe0052,0xd377004b,0xa3ca2cba}},	//   _seçã, hëzi, учы_, रोग_,
   {{0x6d462cbb,0x645b2cbc,0x04462cbd,0x0ecf00bc}},	//   _neka, brui, _бедн, _हेगड,
   {{0x645b2cbe,0xa91d013f,0x10742cbf,0x7c262cc0}},	//   crui, _paži, бляю, _nukr,
   {{0xa3e82087,0x92942cc1,0x69d92cc2,0x53342cc3}},	//   _यदि_, _вакц, ziwe, _тект,
   {{0x6d462cc4,0x4426068d,0xdd9b2cc5,0xa91d013f}},	//   _beka, _huo_, нша_, _važi,
   {{0x6d462cc6,0x4426013f,0x7c262cc7,0x628a0078}},	//   _ceka, _kuo_, _bukr, _isfo,
   {{0x62982cc8,0x44262cc9,0xa3e82cca,0x41c408ba}},	// [21f0] _hrvo, _juo_, _यदा_, _دقيق,
   {{0xf1bf00b6,0x7c260138,0x6d462ccb,0x69d8014b}},	//   lká_, _dukr, _eeka, èven,
   {{0x6d462ccc,0x3f830095,0x44262ccd,0x69d92cce}},	//   _feka, meju_, _luo_, tiwe,
   {{0x195900c6,0xf1bf2ccf,0x3ebe1484,0x893700e3}},	//   тады_, nká_, øtte_, اعضا,
   {{0x442608a1,0x69d92cd0,0xb7b50174,0x386d0231}},	//   _nuo_, riwe, _dịn, _qqer_,
   {{0x6d462cd1,0x65b50074,0x62980018,0xd2461a13}},	//   _zeka, _náhr, _orvo, _ون_,
   {{0x6d462cd2,0x7982002b,0x00000000,0x00000000}},	//   _yeka, beow, --, --,
   {{0x44262cd3,0x6442010a,0x6b8e01c2,0x7c26010a}},	//   _buo_, _bwoi, _zabg, _yukr,
   {{0x629802fd,0x442604a3,0x05a60084,0xf1bf0146}},	//   _arvo, _cuo_, рвый_, dká_,
   {{0xf7730dd0,0x645b2cd4,0x6721005f,0xe2990291}},	//   _دار_, rrui, _uglj, вао_,
   {{0x62980580,0x645b2cd5,0xd5ae015a,0x59b91b11}},	//   _crvo, srui, سفی_, _आवार,
   {{0x629808a9,0x645b2cd6,0x22582cd7,0x947900ae}},	//   _drvo, prui, árka_, _аску_,
   {{0x6d4603ce,0x628a2b2a,0x62980126,0x03a52cd8}},	//   _reka, _esfo, _ervo, _вило,
   {{0x6d4610e3,0x91fd00d9,0x4ab502d5,0xbcfb0076}},	//   _seka, tuāc, ंहाव, _gcéi,
   {{0x7c262cd9,0x44260294,0xf233001c,0x629e0231}},	//   _sukr, _zuo_, _ابتک, _àpop,
   {{0xf1bf0871,0x65b50181,0x3dc91ef8,0x25bf2cda}},	//   cká_, _záhr, ghaw_, nkul_,
   {{0xd7c50096,0x0b462cdb,0xab2a193d,0xa91d00c4}},	// [2200] वसाच, инан, воза_, _kažu,
   {{0x75fe00dd,0x91fd01d3,0x6d462cdc,0x29db0174}},	//   rëzi, grāf, _weka, ụala_,
   {{0x6d460706,0xbea62cdd,0xa9262cde,0xae1f009f}},	//   _teka, _танк, адел, _मंचन_,
   {{0x25ad2cdf,0xd37809ac,0xda650037,0x6d460113}},	//   jjel_, miće_, صامي, _ueka,
   {{0xd3780ca7,0x83fd0103,0xe8942246,0x63a401c2}},	//   liće_, ntős, саль, _ɗinb,
   {{0x91fd0b4b,0xd90d00d0,0x442600ac,0x75220036}},	//   ntār, ریل_, _ruo_, _sgoz,
   {{0x44260465,0x4b7b09c1,0x64420067,0xd37803d6}},	//   _suo_, _שאלו, _swoi, niće_,
   {{0x2d9214b1,0xbcfb00e3,0x44262ce0,0xa3d30251}},	//   ndye_, _scéi, _puo_, सोस_,
   {{0x81b003e3,0xa91d007e,0x98bd007f,0x3a2d0141}},	//   _giɓi, _sažv, tawą_, _čepi_,
   {{0x62980954,0xa5070291,0xd37800c4,0xa91d00c6}},	//   _prvo, шења_, kiće_, _pažv,
   {{0xe7e3007d,0x3f830138,0xf1bf035d,0xd37809ac}},	//   कचरा_, veju_, tká_, jiće_,
   {{0x44262ce1,0x28db143d,0x644200a5,0xd37801ac}},	//   _tuo_, _मेडि, _twoi, diće_,
   {{0xe3af0177,0xdb0e01e8,0x75d30037,0xf1bf2ce2}},	//   سری_, _albü, _بينا, rká_,
   {{0xf1bf0074,0x33f32ce3,0xbcfb0065,0xd3780559}},	//   ská_, _وسوس, _gbéy, fiće_,
   {{0x3dc92ce4,0x3f832ce5,0x24520103,0x00000000}},	//   thaw_, reju_, _انڈس, --,
   {{0x3dc907ac,0x3f832ce6,0x3ead0357,0x00000000}},	//   uhaw_, seju_, ćet_, --,
   {{0x91fd00d9,0x26e20034,0xa3da00c3,0x4c94007b}},	// [2210] stās, गपुर_, _ठगा_, оитс,
   {{0x3dc9006c,0x60c01484,0xd3780542,0x2ca90188}},	//   shaw_, ømme, biće_, rxad_,
   {{0x200300e9,0x6e950080,0x3a750221,0xad9b033c}},	//   mlji_, _الجا, слер, _bhút,
   {{0x628600a5,0xdb0e034f,0xaa58022f,0xad9b033c}},	//   łkow, _albó, рицу_, _chút,
   {{0x9f51030b,0x182113ae,0x260a148e,0xb4e5007f}},	//   hozí_, मदेव_, ातनी_, _नशे_,
   {{0x600000c2,0xdb1c009c,0x26e20096,0x68190154}},	//   tömi, _flrà, गपूर_, _kňdi,
   {{0x7c2d2ce7,0x200300e7,0x7bc7009e,0x75fe0216}},	//   lqar, ilji_, _ilju, hëzu,
   {{0x59f90084,0x39400088,0x77bd0428,0xc7b80995}},	//   _себя_, ðist_, _mèxi, _viđa_,
   {{0x7bc703f1,0x26c10181,0x38600013,0x25bf16cf}},	//   _klju, šho_, àirt_, rkul_,
   {{0x25bf2ce8,0xd6db2ce9,0x68e40037,0x00000000}},	//   skul_, _ите_, úide, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd3782cea,0xd5430139,0xad9b0076,0x930d0233}},	//   viće_, _dẹ̀d, _mhús, _ışık,
   {{0x7bc72ceb,0x34ab0037,0x61e603bd,0x75fe0216}},	//   _olju, _جداً_, rnkl, gëzu,
   {{0xd3780335,0x65690eb3,0x6d4b003e,0x9f580052}},	//   tiće_, lgeh, ðgan, morë_,
   {{0xed5a062a,0xada621a1,0x6da61d3f,0x75fe023b}},	//   лов_, бавл, бива, rëzv,
   {{0x65692cec,0xd3780335,0xb14600d3,0x29db0134}},	//   ngeh, riće_, _унил, ụaja_,
   {{0xdca321be,0xd378077e,0x7bc700cb,0x9f58023b}},	// [2220] пати, siće_, _blju, norë_,
   {{0x65bc025a,0x7f8600e3,0xd3780335,0x61180139}},	//   _véhi, _الدن, piće_, _e̟lò,
   {{0xdb0e05aa,0x387f01e9,0x7c2d041c,0x1617110d}},	//   _albò, _apur_, aqar, दगार_,
   {{0x27e90037,0x9f58023b,0xdb1c0212,0x6569029a}},	//   éann_, korë_, _omrö, jgeh,
   {{0x28d21efb,0xfbd10103,0xa2d909b0,0xb4d600c3}},	//   _देखि, ستے_, _फेस्, _सधे_,
   {{0xab270058,0x207b0266,0xfaa60836,0x00000000}},	//   _гора_, ראסא, _лаго, --,
   {{0x7bde2ced,0x8f9b00a1,0x65692cee,0x2b4a2cef}},	//   mipu, טיסי, fgeh, _iebc_,
   {{0x7bde0706,0x69cb20a0,0x65690a2c,0x743400d3}},	//   lipu, chge, ggeh, ониф,
   {{0xc34a2cf0,0xdb0e0131,0x387f009c,0x00000000}},	//   ляне_, _mobí, _gpur_, --,
   {{0x7bde0979,0x32540c58,0xd62a2cf1,0x66e62cf2}},	//   nipu, овор, _боже_, _лоза,
   {{0xd5af160f,0x20031271,0x38660063,0xc205007f}},	//   _ес_, vlji_, luor_, रतलब_,
   {{0x645d0fb6,0x7bde00cd,0xba9b0341,0x69c22cf3}},	//   ásic, hipu, אסטי, nkoe,
   {{0x7bde2cf4,0x2bfa0285,0x107406c4,0x644f0143}},	//   kipu, ्तां_, пляю, ácit,
   {{0x75fe0052,0xb4e40179,0x02a62cf5,0x8f340221}},	//   rëzu, फपी_, _грим, зерц,
   {{0x7bde2cf6,0x91fd00d9,0x7de50138,0x637700a1}},	//   dipu, trād, lėsi, _הגוף_,
   {{0x1ae70081,0x7c2d2cf7,0x7bc70995,0x7bcb00e8}},	//   _করলে_, tqar, _slju, īgum,
   {{0x2003005f,0xcf8e00cd,0x22ae0092,0xdb0e033d}},	// [2230] plji_, رژی_, dəki_, _dobí,
   {{0x7bde2cf8,0x61ed2085,0xad9b00e3,0x2bbb0037}},	//   gipu, _hjal, _chúr, دارة_,
   {{0x387f2cf9,0xc33300ca,0x7bc7033b,0x61ed01cd}},	//   _spur_, פוף_, _vlju, _kjal,
   {{0x39492cfa,0x2b58039f,0x38662cfb,0x7bde18f0}},	//   úas_, _edrc_, fuor_, aipu,
   {{0x7c2d0090,0x27e904d8,0x61ed2cfc,0xdd9800ae}},	//   qqar, éano_, _mjal, _ушэ_,
   {{0x7bc71197,0x98482787,0xad9b0503,0xdb0e00ae}},	//   _ulju, сяца_, _thús, _dobâ,
   {{0x61ed2cfd,0x65692cfe,0x3ffc006e,0xa01b0364}},	//   _ojal, tgeh, אפגע, rwöh,
   {{0xe459215f,0x61ed2cff,0x9f58023b,0x8beb0033}},	//   ажи_, _njal, torë_, _কঠিন_,
   {{0x65692d00,0x69c92d01,0x2919020d,0xb3c900d3}},	//   rgeh, _ilee, _àsa_, илиз_,
   {{0xa3d3000f,0x61ed2d02,0xd7fb2d03,0x394f0088}},	//   सों_, _ajal, _суб_, lags_,
   {{0xf77011a2,0x69c92d04,0x9f58023b,0x00000000}},	//   _سال_, _klee, sorë_, --,
   {{0x216a08d1,0x3860042d,0xb1da004d,0x7de5004b}},	//   шими_, šire_, рьох_, bėsi,
   {{0x61ed2d05,0x69c900e7,0xdb0e0031,0x3f930062}},	//   _djal, _mlee, _robí, _baxu_,
   {{0xee3a2d06,0xd9b62b8a,0x69c22d07,0xa3cd0179}},	//   инг_, _अक्ट, zkoe, _रति_,
   {{0x61ed2d08,0x69c92d09,0x80db0081,0x9f58014b}},	//   _fjal, _olee, _যুদ্, noré_,
   {{0x61ed2d0a,0x8066225a,0x22510074,0xe1f200cd}},	//   _gjal, _движ, ázku_, _تست_,
   {{0x7bde2d0b,0xd3780039,0x394f2d0c,0x3f9300d8}},	// [2240] tipu, lića_, dags_, _faxu_,
   {{0x69c92d0d,0x69db0a43,0xb7b50134,0x61ed007e}},	//   _alee, _amue, _dịk, _zjal,
   {{0x7bde2d0e,0xd378005f,0xdb0e1ba6,0x8eb30018}},	//   ripu, nića_, _tobí, _ہمیش,
   {{0x7bde2d0f,0x0906002d,0x7ae30037,0xa9672440}},	//   sipu, опен, únta, жица_,
   {{0x69c22d10,0x91fd00d9,0x7bde00cd,0xd3782d11}},	//   rkoe, duāl, pipu, hića_,
   {{0x69c92d12,0xa09b0341,0xd3780335,0x69c22d13}},	//   _elee, יינט, kića_, skoe,
   {{0xeb910130,0xd37801ac,0x3a2a0124,0xa3bf00aa}},	//   _אָן_, jića_, _uubp_, ीसन_,
   {{0xd37800e9,0x35f700d1,0x00000000,0x00000000}},	//   dića_, يريد_, --, --,
   {{0xb7e625d6,0x249d030a,0x61ed00bd,0x38660158}},	//   _джак, _crwm_, _rjal, quor_,
   {{0x61ed2d14,0xd3780106,0x9f5800fd,0x7de50138}},	//   _sjal, fića_, boré_, rėsi,
   {{0x69c90084,0xd3781197,0x27fc02ef,0x67280dd9}},	//   _ylee, gića_, movn_, _igdj,
   {{0xfec20033,0x20180216,0x00000000,0x00000000}},	//   োপাধ, emri_, --, --,
   {{0xa5071121,0xc953040a,0x60f81402,0x7bdc2d15}},	//   _деца_, ומר_, жняя_, _omru,
   {{0xcf2700e3,0xd3780106,0x42550018,0x00000000}},	//   ترحي, bića_, _کنٹر, --,
   {{0xcddb2d16,0x61ed003e,0x91fd01d3,0xd37809ac}},	//   ања_, _tjal, grāc, cića_,
   {{0x7bdc2d17,0x61ed00d8,0xad9b00da,0xdda800d3}},	//   _amru, _ujal, _chúp, отул_,
   {{0x61fd2d18,0x7e67023e,0xbcfb016f,0x00000000}},	// [2250] mosl, sujp, _acér, --,
   {{0x69c92d19,0x7a330090,0x91fd01d3,0x9f43034f}},	//   _slee, _aħta, zuāl, rojó_,
   {{0x69c92d1a,0x8ae702ec,0xaa9500e3,0x394f2d1b}},	//   _plee, ціал, ثلاث, tags_,
   {{0x61fd2d1c,0xbcfb0220,0x160a0034,0xfbdf00eb}},	//   nosl, _dcér, _हीलर_, _gwên_,
   {{0x69c903ee,0x21290124,0xe73902b3,0x394f2d1d}},	//   _vlee, _mgah_, бел_, rags_,
   {{0x290402ad,0x61fd00d4,0x00000000,0x00000000}},	//   _dyma_, hosl, --, --,
   {{0x6fc20220,0x91fd00d9,0x21292d1e,0x61fd0d95}},	//   _dôch, tuāl, _ogah_, kosl,
   {{0xd37800e9,0xd90e0068,0x2d8903a9,0x2129061d}},	//   vića_, ئیے_, neae_, _ngah_,
   {{0x478b0084,0x00000000,0x00000000,0x00000000}},	//   _всем_, --, --, --,
   {{0xd3781419,0x63b8023e,0x25a60072,0x394d0188}},	//   tića_, _covn, _enol_, _hees_,
   {{0x88bd0081,0x7bc52d1f,0x9f4e033d,0x6b95129d}},	//   _অধিক, ikhu, áním_, _mazg,
   {{0xd3780039,0x200102e7,0xdb070139,0x6b950062}},	//   rića_, _akhi_, _bojú, _lazg,
   {{0x64a52d20,0x394d2d21,0xd9bd0081,0xd3780106}},	//   _хала, _mees_, _আগাম, sića_,
   {{0x394d2d22,0x437507a6,0x443f1bd6,0xdd92110a}},	//   _lees_, _זײַן_, mpu_, کور_,
   {{0x443f2d23,0x60120088,0x61fd2d24,0xc332006e}},	//   lpu_, væmd, bosl, _אוו_,
   {{0x394d022e,0xc8bd0e72,0xb7b50134,0x62832d25}},	//   _nees_, ्नाट, _dịi, _ipno,
   {{0x443f0154,0x6b950234,0xdd8f097d,0xafe600ae}},	// [2260] npu_, _bazg, دوق_, _ноил,
   {{0x6000173a,0x3a242d26,0xa09b0089,0x2bc10096}},	//   röms, _simp_, _פייט, _शकणा,
   {{0x394d2d27,0xc7b80995,0x3f8a03a9,0x00000000}},	//   _bees_, _rođ_, mebu_, --,
   {{0x2d892d28,0xa96a0c3f,0x3f8a2d29,0x394d2d2a}},	//   ceae_, сида_, lebu_, _cees_,
   {{0x6d441763,0x394d2d2b,0xbcfb0139,0x68430c2b}},	//   mbia, _dees_, _adéf, енча,
   {{0x6d44013f,0x3f982d2c,0x6e260270,0x628318f0}},	//   lbia, ndru_, _hikb, _opno,
   {{0x3a240012,0x63b80074,0xd9461a54,0x2bc10096}},	//   _timp_, _rovn, _неви, _शकता,
   {{0x394d0f87,0x6fcb0367,0x3f8a2d2d,0x6d442d2e}},	//   _gees_, _müca, hebu_, nbia,
   {{0x443f0270,0x6b952d2f,0x3f8a2d30,0xd49700ae}},	//   gpu_, _yazg, kebu_, прэ_,
   {{0x63ad01c2,0x6027020d,0x260a0096,0x3f8a14f3}},	//   _ɗang, hémè, ातही_, jebu_,
   {{0x394d0197,0x61fd2d31,0x7d060f5a,0xd6c4001c}},	//   _yees_, tosl, _lyks, _تمای,
   {{0x394d01fa,0x25a60150,0xdceb033b,0x3f9801d3}},	//   _xees_, _unol_, _žičn, edru_,
   {{0x61fd2d32,0x64a32d33,0x66020032,0x77bd0428}},	//   rosl, _паца, _ikok, _tèxt,
   {{0xb7bd002d,0x3f8a2d34,0x00000000,0x00000000}},	//   _puţi, gebu_, --, --,
   {{0x644004e2,0xbcfb0072,0xddd00fb0,0xd37800c4}},	//   lpmi, _acép, _šeši, lićo_,
   {{0x6d442d35,0x00000000,0x00000000,0x00000000}},	//   gbia, --, --, --,
   {{0x394d2d36,0x6e2602ac,0x7de500c6,0x66020a3d}},	// [2270] _rees_, _dikb, dėst, _mkok,
   {{0xfe6e14df,0x60cf07aa,0xbca40037,0x7dca0094}},	//   دگی_, ınmı, عملي, _výsa,
   {{0x6d442d37,0x66022d38,0x394d2d39,0x6b95026a}},	//   bbia, _okok, _pees_, _vazg,
   {{0x394d022e,0x3ebe2d3a,0x66022d3b,0x3eac0170}},	//   _qees_, ätte_, _nkok, ådte_,
   {{0x394d2d3c,0x315800c1,0x6b950141,0x00000000}},	//   _vees_, ליאן_, _tazg, --,
   {{0x394d040c,0x66020d79,0xbcfb0032,0x6d4f2d3d}},	//   _wees_, _akok, _adég, _heca,
   {{0x6d4f1084,0x996700ae,0x9f5e014b,0x00000000}},	//   _keca, _нтал, ôté_, --,
   {{0x84592d3e,0x7c272d3f,0x6e380103,0x3860042d}},	//   орот_, _hijr, _évbe, šira_,
   {{0x855400cd,0x6f0900b6,0x6add0a50,0x00000000}},	//   ریور_, řech, _मधुर, --,
   {{0x6d4f2d40,0x443f2d41,0x798b2d42,0x00000000}},	//   _leca, rpu_, legw, --,
   {{0x7c2f0a29,0xa18a1147,0x6d4400f0,0x6d5d0edb}},	//   _lucr, обна_, ybia, _odsa,
   {{0x443f0cbc,0x6d4f2d43,0x798b00f0,0x3f8a2d44}},	//   ppu_, _neca, negw, webu_,
   {{0x661b2d45,0xc4fb00cd,0x66092d46,0x9554001c}},	//   mmuk, _اعضا_, mlek, _سخنا,
   {{0x661b2d47,0x7d062d48,0x443d00fc,0x00000000}},	//   lmuk, _ryks, _itw_, --,
   {{0x6d4f2c34,0x442f2d49,0x7d060084,0x3f8a2d4a}},	//   _beca, _hug_, _syks, rebu_,
   {{0x44272d4b,0x6d4f2d4c,0x7e610088,0x66092d4d}},	//   _hin_, _ceca, álpa, nlek,
   {{0x6d442421,0xfce3016c,0x442f28f8,0x7c2f00de}},	// [2280] rbia, вото, _jug_, _cucr,
   {{0x44270913,0x8bf100c7,0x7d06013f,0x66090201}},	//   _jin_, _জীবন_, _vyks, hlek,
   {{0x442f2d4e,0xbcfb2d4f,0x7c2f0072,0x6eb51fb4}},	//   _lug_, _adéd, _eucr, _उपयु,
   {{0x44272d50,0x66092d51,0x442f00ae,0x6d4f2d52}},	//   _lin_, jlek, _oug_, _geca,
   {{0x645d0146,0x443d023e,0x442f0197,0xa3bf07d5}},	//   ásil, _ntw_, _nug_, ीसा_,
   {{0x44272d53,0x66092d54,0xb8d6278e,0x661b0e91}},	//   _nin_, elek, _छप_, emuk,
   {{0x34b8099d,0xd6d000e3,0x443d0085,0x442f00ca}},	//   ेन्द, طقة_, _atw_, _aug_,
   {{0xd5b0054f,0x44272d55,0x661b0d1f,0x66090ac9}},	//   افة_, _ain_, gmuk, glek,
   {{0x44272d56,0x442f0531,0x443d033c,0x00000000}},	//   _bin_, _cug_, _ctw_, --,
   {{0x3946013f,0xa3d800a5,0x66092d57,0xe8d70327}},	//   lbos_, ठों_, alek, _חומר_,
   {{0xbcfb2d58,0x442f01f7,0x200f00c6,0x00000000}},	//   _idée, _eug_, _ūgio_, --,
   {{0x44272d59,0x7dc3007a,0x39461570,0xf6690037}},	//   _ein_, _tõsi, nbos_, _رحمه_,
   {{0x6d4f1e6c,0x29f82d5a,0x443d0167,0x39462d5b}},	//   _reca, mčad_, _gtw_, ibos_,
   {{0x44272d5c,0x6d4f2c09,0x9f4300dd,0xa2d9023a}},	//   _gin_, _seca, mijë_, _फेक्,
   {{0x7c2f2d5d,0x7dd10073,0x442f0364,0x9f5800b3}},	//   _sucr, _låse, _zug_, corí_,
   {{0x44272d5e,0x442f0197,0xa01b0364,0x29f80995}},	//   _zin_, _yug_, gwör, nčad_,
   {{0x44272d5f,0x6d4f2d60,0x62970072,0x00000000}},	// [2290] _yin_, _veca, _áxor, --,
   {{0x2fc700ef,0x44270028,0x60c00222,0x66090018}},	//   _ông_, _xin_, ämme, zlek,
   {{0x386600dc,0x6d4f2d61,0xf09f015e,0x798b2d62}},	//   eror_, _teca, lvà_, tegw,
   {{0x6d5d052f,0x6eae030b,0x38660150,0x7f55037a}},	//   _udsa, ीहरु, fror_, lazq,
   {{0xdd3a0054,0x798b2d63,0x6609103b,0x52ca034d}},	//   _מערכ, regw, vlek, ानुस,
   {{0x2d99008a,0xe7392d64,0xe611001c,0xa6950859}},	//   _hase_, чек_, گشت_, ериј,
   {{0x44272d65,0x2d992d66,0x27e901ac,0x442f2d67}},	//   _rin_, _kase_, đan_, _sug_,
   {{0x44272d68,0x9f580181,0xfc3f00e3,0x3866017a}},	//   _sin_, vorí_, _tríd_, bror_,
   {{0x661b26f7,0x66092d69,0x442706f5,0x998a02c6}},	//   rmuk, rlek, _pin_, _zubů_,
   {{0xe3b1054f,0x2d992d6a,0xe8bd0455,0x66092d6b}},	//   ارة_, _lase_, ्नीच, slek,
   {{0x44272d6c,0x66092d6d,0x443d084e,0x00000000}},	//   _vin_, plek, _wtw_, --,
   {{0x442f01bb,0x44272d6e,0x76430167,0xe296083c}},	//   _tug_, _win_, mpny, хаю_,
   {{0x44272d6f,0x30752d70,0x2ec817ad,0x443d0027}},	//   _tin_, курс, रन्त, _utw_,
   {{0x44272d71,0x25bd0188,0xd0122ba0,0x63a40044}},	//   _uin_, _howl_, الس_, _ɗink,
   {{0xf8bd000d,0x3946013f,0xfc3f0065,0x2d992d72}},	//   ्नुप, ybos_, _atí_, _base_,
   {{0x2d992d73,0xdb1c0257,0xa3cd007f,0x7dca00d4}},	//   _case_, _forê, रसव_, _výso,
   {{0xa3c302e8,0x3dd202e0,0x8fa61bb8,0xbcfb0af0}},	// [22a0] _एका_, rhyw_, _запе, _adéb,
   {{0x61e62d74,0xfc3f0080,0x395f2d75,0x66002d76}},	//   likl, _dtí_, _adus_, zomk,
   {{0x160f0971,0x66001a87,0xfc3f0af0,0x7dd102c3}},	//   ातार_, yomk, _etí_, _såse,
   {{0x3f9a2d77,0x61e62d78,0x38662d79,0x39462d7a}},	//   _hapu_, nikl, tror_, ubos_,
   {{0xe8942d7b,0x6d562d7c,0xa92702ec,0x39462d7d}},	//   таль, maya, ніше_, rbos_,
   {{0x2d991b32,0x2d802d7e,0x38662d7f,0xa3e10285}},	//   _zase_, lfie_, rror_, नोम_,
   {{0x3f9a2a4b,0xdb1c023b,0x61e62d80,0xd90d0018}},	//   _mapu_, _morë, kikl, میہ_,
   {{0xceb30054,0x6d562d81,0x3f9a00d9,0x39490088}},	//   ריה_, naya, _lapu_, ðast_,
   {{0x61e62d82,0x18670396,0x29f8007e,0x778602f3}},	//   dikl, _пати_, rčad_, _плаз,
   {{0x6d562d83,0xb34620df,0x7dca003e,0x3f9a00c4}},	//   haya, diçõ, _sýsl, _napu_,
   {{0x6d5612f5,0xd257004d,0x2ca000aa,0x61e62d84}},	//   kaya, нця_, hvid_, fikl,
   {{0x6d562cb2,0xab64026a,0x25bd0078,0x61e62d85}},	//   jaya, ldüğ, _gowl_, gikl,
   {{0x7dca0074,0x6d562d86,0x1ae700c7,0xe516030b}},	//   _výsl, daya, _করছে_, देखि_,
   {{0xb4be02d5,0x6fcb0092,0x2ca00149,0x20050220}},	//   ीनी_, _gücl, dvid_, ôli_,
   {{0x2d9914b1,0x2d802d87,0xdb1c00dd,0xdb1519a3}},	//   _pase_, ffie_, _dorë, _pozí,
   {{0x6d562d88,0x32530465,0xb3460396,0x3ebe0149}},	//   gaya, _свър, biçõ, ätta_,
   {{0xdb15025b,0xa91d15fe,0xacf82d89,0x9f5800ee}},	// [22b0] _vozí, _obža, енту_, borà_,
   {{0xdb1c2d8a,0x9f5800b3,0xe7e200b6,0x00000000}},	//   _korè, corà_, कोमा_, --,
   {{0x6d562d8b,0x20030138,0x3a752d8c,0x2d992d8d}},	//   baya, moji_, тлер, _tase_,
   {{0x20032d8e,0x6d562d8f,0xaf4b0103,0x9f580131}},	//   loji_, caya, _بشکل_, porã_,
   {{0x7dda02c6,0x83fd0103,0xdb1c03a9,0xa01b003e}},	//   růst, rtőz, _lorè, rtöf,
   {{0x61e62d90,0x20032d91,0x00000000,0x00000000}},	//   zikl, noji_, --, --,
   {{0x34c9099d,0x00000000,0x00000000,0x00000000}},	//   िन्द, --, --, --,
   {{0x20030051,0x00000000,0x00000000,0x00000000}},	//   hoji_, --, --, --,
   {{0x61e605a3,0x20031177,0x998700c6,0x91a900fe}},	//   vikl, koji_, ūnų_, _giả_,
   {{0xad9b01cd,0xd7591dec,0x20032d92,0x799b1a3b}},	//   _skúl, _آلات_, joji_, _hauw,
   {{0x6d562d93,0x27e70088,0x216a19a9,0x799b2d94}},	//   yaya, minn_, мини_, _kauw,
   {{0xe3b11e49,0x27e72d95,0x3f9a2d96,0xb3460161}},	//   ارک_, linn_, _sapu_, tiçõ,
   {{0x61e62d97,0x799b2d98,0x3f9a2d99,0x32020146}},	//   rikl, _mauw, _papu_, roky_,
   {{0x20030b27,0x6d5623b0,0xb346001f,0x27e7003e}},	//   goji_, waya, riçõ, ninn_,
   {{0x6d562d9a,0xb346001f,0xa3d60592,0x61e62d9b}},	//   taya, siçõ, _सतत_, pikl,
   {{0x27e70049,0x799b2d9c,0x69cb029a,0xdce40357}},	//   hinn_, _nauw, jkge, ngić,
   {{0x6d562d9d,0x27e70088,0x7e7c0128,0x61e42d9e}},	// [22c0] raya, kinn_, strp, _imil,
   {{0x6d562d9f,0x80db2da0,0xfaa62da1,0x9f4a05e6}},	//   saya, _যুক্, казо, robó_,
   {{0x6d562da2,0x799b2da3,0x81f70260,0x7c36023b}},	//   paya, _bauw, _سفیر_, sqyr,
   {{0x5e570130,0x6d560188,0xe8ea2753,0x186a001f}},	//   _ביטע_, qaya, ммед_, дади_,
   {{0xf772003f,0x27e72da4,0x799b2da5,0x61e42da6}},	//   لاغ_, finn_, _dauw, _mmil,
   {{0x27e72da7,0xf0930341,0x7a3302a1,0x69cb05c2}},	//   ginn_, ינד_, _oħth, akge,
   {{0x61e400cb,0xbcfb2da8,0xd6cf00ab,0x7dc3007a}},	//   _omil, _idéa, يقه_, _tõst,
   {{0x6b9c2da9,0xd8760068,0xad9b0139,0x69cb01bf}},	//   _harg, _لائب, _akúj, ckge,
   {{0xb4be2daa,0xb4cc110f,0x6b9c2dab,0xd3780335}},	//   ीने_, रने_, _karg, lići_,
   {{0x61e42dac,0x69c02dad,0x27e701b5,0x79822dae}},	//   _amil, _home, cinn_, lfow,
   {{0xd6c41e49,0xa3e30abe,0xa3c30006,0x6b9c2daf}},	//   _حمای, _नगर_, _एकर_, _marg,
   {{0x6b9c2db0,0xdb1c2db1,0x3869228d,0x80db0a43}},	//   _larg, _coré, šare_, _যুগ্,
   {{0xdb151ba6,0xdb1c2db2,0x20032db3,0x6b9c01ff}},	//   _mozá, _doré, toji_, _oarg,
   {{0x61e42db4,0xbcfb00e3,0xa3e11efb,0x60c00149}},	//   _emil, _ndéa, नोद_, ämma,
   {{0xdd9b065c,0x9e0702ec,0x20032db5,0x9c130065}},	//   мша_, вчал, roji_, _bọnn,
   {{0xd378005f,0x6b9c2db6,0xdb1c03a9,0x20032db7}},	//   dići_, _aarg, _goré, soji_,
   {{0x320912f5,0x78a20d62,0xa3d6009f,0x799b2db8}},	// [22d0] _ikay_, jvov, _सता_, _rauw,
   {{0x6b9c0d9f,0xd3782461,0xfc3f0610,0x799b2db9}},	//   _carg, fići_, _cría_, _sauw,
   {{0x6b9c2dba,0x799b2dbb,0x69c01b05,0x65620031}},	//   _darg, _pauw, _bome, _odoh,
   {{0x70010134,0x27e70364,0x64420634,0x6b9c01b9}},	//   _ịcho, winn_, _otoi, _earg,
   {{0x27e72dbc,0x69cb03ee,0x6b9c2dbd,0x26c702ad}},	//   tinn_, rkge, _farg, wyno_,
   {{0x6b9c2dbe,0xd37808a9,0x628a052f,0x656201dc}},	//   _garg, bići_, _opfo, _adoh,
   {{0x27e72dbf,0x69c02dc0,0x06e316f8,0x64422dc1}},	//   rinn_, _fome, _केशव_, _atoi,
   {{0x27e72dc2,0x69c02dc3,0x6b9c1114,0x09ca0081}},	//   sinn_, _gome, _zarg, লোবা,
   {{0x3f910a00,0x6b9c026a,0x753b028d,0x27e7056e}},	//   kezu_, _yarg, rcuz, pinn_,
   {{0x69c00ab2,0x3a2d00de,0x645b2dc4,0x6b9c008c}},	//   _zome, _hiep_, rsui, _xarg,
   {{0xdb1c0bfe,0x4226016a,0x645b2dc5,0x3f912dc6}},	//   _poré, лдов, ssui, dezu_,
   {{0x9f4e0074,0x7dca035d,0xa06a0291,0x645b2dc7}},	//   čník_, _výsk, нама_, psui,
   {{0xc60f06ed,0xa91d013f,0x6fcb01bf,0xd37800cc}},	//   ातीय_, _pažy, _küch, zići_,
   {{0x3a2d01c0,0xdee62dc8,0x8335006e,0x69da00c6}},	//   _liep_, гоги, _גאַס_, _įtem,
   {{0xdb1c00d1,0xa26300fe,0x80a200aa,0x00000000}},	//   _toré, _xuố, खिहे, --,
   {{0xd37804a3,0xa01b0018,0x7dd12dc9,0x68fb00a7}},	//   vići_, gtöb, _påsa, _oxud,
   {{0x5baa2cbf,0x6b9c2dca,0x3b860dd8,0xb88600b6}},	// [22e0] нкам_, _parg, ллаг, _kníž,
   {{0x69c02dcb,0xd3780106,0x5eff00c3,0x6b9c02a1}},	//   _some, tići_, _शुक्_, _qarg,
   {{0x68fb22e7,0x69c0230b,0x6b9c2dcc,0xc33200a1}},	//   _axud, _pome, _varg, צוא_,
   {{0x6b9c2dcd,0x9f5805fe,0xd3780106,0x2b470233}},	//   _warg, forç_, rići_, ınca_,
   {{0x2d922dce,0x17540a01,0x3a2d0305,0xd7e60c10}},	//   meye_, авля, _diep_, ліко,
   {{0x6fcb02e2,0x78a20146,0x69c02dcf,0xd3780995}},	//   _rück, rvov, _wome, pići_,
   {{0x64422dd0,0xb4cc0285,0xa2630023,0x22400357}},	//   _stoi, रन्_, _quố, _čiko_,
   {{0x2d9227dd,0xa3d606ed,0xa2a20557,0xa5340e0e}},	//   neye_, _सतह_, गिस्, шнич,
   {{0x98a32dd1,0xf7460870,0x7c2e2dd2,0xdb1e2dd3}},	//   _лите, _безо, _kibr, skpä,
   {{0x7c2e2dd4,0x3dc2039f,0x2d9205bd,0xdcef0559}},	//   _jibr, _lokw_, heye_, šeće,
   {{0x3f9104a3,0x86462dd5,0x2d922dd6,0x05860036}},	//   vezu_, _снеж, keye_, _булм,
   {{0x7c2e2bd4,0xf65100fb,0x6fcb0364,0x3dc2039f}},	//   _libr, _گئے_, _züch, _nokw_,
   {{0x7c2e0080,0x3f910ca7,0xbcfb1561,0x2d9204d6}},	//   _oibr, tezu_, _adén, deye_,
   {{0x40341553,0x00000000,0x00000000,0x00000000}},	//   серс, --, --, --,
   {{0x629800e9,0xddab002d,0x442e02a1,0x00000000}},	//   _usvo, нтал_, _iif_, --,
   {{0x7c2e00e3,0xb8860220,0x442e2dd7,0x32090d16}},	//   _aibr, _zníž, _hif_, _ukay_,
   {{0x442e04f9,0x3b552dd8,0x7c2e0062,0x3a2d029a}},	// [22f0] _kif_, икар, _bibr, _riep_,
   {{0x7c2e2dd9,0x3a2d0381,0x00000000,0x00000000}},	//   _cibr, _siep_, --, --,
   {{0x2d922dda,0x7c2e2ddb,0x3a2d07e6,0xfd1f0032}},	//   beye_, _dibr, _piep_, _gbìn_,
   {{0xaca30174,0xd37800cb,0x2d922ddc,0x6fcb042c}},	//   _agụb, miću_, ceye_, _süch,
   {{0x6d4d2ddd,0xd37801ac,0xbcfb20ed,0x9984020a}},	//   mbaa, liću_, _idéo, _simţ_,
   {{0xdcfd0029,0x7c2e2dde,0xf7710e5a,0x6d4d2ddf}},	//   _lasī, _gibr, زات_, lbaa,
   {{0x45d52de0,0xd3780106,0x3a2d0023,0x63a401c2}},	//   ицит, niću_, _tiep_, _ɗint,
   {{0x6d4d2de1,0xb88600b6,0x44652de2,0x05a900c2}},	//   nbaa, _sníž, авив, твий_,
   {{0x851f2de3,0xd37802ef,0x79890139,0x6e37078e}},	//   मेंट_, hiću_, _ibew, _luxb,
   {{0x442e03e3,0x2d922de4,0x98170037,0x7c2e0858}},	//   _cif_, zeye_, _إبرا, _xibr,
   {{0x629e199c,0x6d4d04ee,0x6b600103,0xd3780995}},	//   _špor, kbaa, lágí, jiću_,
   {{0x78a92de5,0xd3780039,0x442e2de6,0x6d4d01c0}},	//   _krev, diću_, _eif_, jbaa,
   {{0x6d4d2de7,0x32db0af0,0x442e2de8,0x78a901ff}},	//   dbaa, _báyé_, _fif_, _jrev,
   {{0xbcfb0032,0xd3780106,0xfe4609e0,0x6d4d010a}},	//   _adéo, fiću_, инго, ebaa,
   {{0xed5a2de9,0x2d922dea,0xdbcf0220,0x6d4d2deb}},	//   ков_, teye_, bľúb, fbaa,
   {{0x38600335,0x78a92dec,0x6d4d2ded,0x442e2dee}},	//   širi_, _orev, gbaa, _zif_,
   {{0x2d9227dd,0xd00f0068,0x32db0032,0x64492c6f}},	// [2300] reye_, سلہ_, _fáyé_, npei,
   {{0x2d922def,0x79892df0,0xd3780995,0x00000000}},	//   seye_, _abew, biću_, --,
   {{0x7f5c2df1,0xeb971bf9,0x78a91428,0xfc3f04d8}},	//   marq, рих_, _arev, _frío_,
   {{0x225118ed,0xa96a2b16,0x3a990109,0x973c0559}},	//   ázky_, тида_, ытую_, _maće,
   {{0x78a92df2,0x386000e3,0x7c2e2df3,0xad9b0139}},	//   _crev, éir_, _tibr, _akúw,
   {{0x78a923a0,0x7f5c1c40,0x600000c2,0x63a401c2}},	//   _drev, narq, tömy, _ɗins,
   {{0x442e2df4,0xd9100421,0xdb1c0032,0x64490381}},	//   _rif_, _کیش_, _korí, epei,
   {{0x69d92df5,0x7dd800e3,0x442e2df6,0x1dbf058f}},	//   chwe, _físe, _sif_, _एकछत,
   {{0x030b00a5,0x2e3c0088,0xd378015c,0xdb1c2df7}},	//   _सुबह_, _líf_, ziću_, _morí,
   {{0x66e62df8,0x2b58015e,0x442e0f09,0xdb1c0139}},	//   _коза, _jerc_, _qif_, _lorí,
   {{0xbcfb2df9,0xe7370084,0x29f8042d,0x442e2dfa}},	//   _adél, _тех_, nčao_, _vif_,
   {{0xd37800e9,0x973c0a39,0x9257007b,0x9f8f013c}},	//   viću_, _daće, шают_, _küç_,
   {{0x90982dfb,0x7dd12dfc,0x92b60033,0x10740686}},	//   авят_, _såso, ছনে_, оляю,
   {{0xd3782c0a,0x92172dfd,0xc88400a7,0xb6010231}},	//   tiću_, _धीरज_, mağı_, _àáre,
   {{0x6d4d2dfe,0x637b0089,0x4ea41e61,0xdb1c0103}},	//   tbaa, _סנהד, орта, _borí,
   {{0xcdd80831,0xd3780335,0xdb1c016d,0x6d4d2dff}},	//   ању_, riću_, _corí, ubaa,
   {{0xdce606d7,0x6d4d09e3,0x7f5c2e00,0xd90400cd}},	// [2310] _bakı, rbaa, barq, _آی_,
   {{0x6d4d19fb,0x3ceb009d,0xfaa7075f,0x2b58020a}},	//   sbaa, _घेणे_, ишен, _cerc_,
   {{0x69d90201,0x6d4d0a9f,0xfc3f0610,0xd8b8001c}},	//   thwe, pbaa, _trío_, یدها_,
   {{0xf99300cd,0x7dd8030b,0x6ec400b6,0x80a40a85}},	//   تبط_, _píse, रहरु, _امین,
   {{0x2d8b023e,0x98a52e01,0xf7451c21,0xaf080281}},	//   _ibce_, силе, бело, _مقیم_,
   {{0x78a9031a,0x69d92e02,0x940f0d2a,0xc8841577}},	//   _vrev, shwe, ɗaɗe_, dağı_,
   {{0x6b6001f9,0x00000000,0x00000000,0x00000000}},	//   ságí, --, --, --,
   {{0x78a92e03,0xdce80034,0x29f8033b,0x7989039f}},	//   _trev, śląs, nčal_, _ubew,
   {{0xdce60b88,0xcdb800a1,0x6fcb0092,0x9f8f026a}},	//   _yakı, שפחה_, _hücu, _güç_,
   {{0xa3e12e04,0x395d2e05,0x3cff00a5,0x62811a92}},	//   नों_, laws_, _रखने_, ttlo,
   {{0x64492e06,0x2d8b1b6d,0x11d600e3,0x7c250076}},	//   spei, _obce_, متحد, imhr,
   {{0xbcfb0065,0x64490d67,0x9f510103,0xc88407e7}},	//   _adém, ppei, kozó_, bağı_,
   {{0xc88408bb,0x53a5002d,0x7f5c0db4,0xd469231c}},	//   cağı_, _галб, tarq, _силе_,
   {{0x395d0197,0xd91a22fe,0x248f0063,0x66092e07}},	//   haws_, טורל, _ipgm_, loek,
   {{0x6fd009b5,0x601201cd,0x00000000,0x00000000}},	//   _häck, næmi, --, --,
   {{0x25bf00d1,0xdce6026a,0xad9b01cd,0x00000000}},	//   njul_, _sakı, _ljúf, --,
   {{0x2b580018,0x395d022e,0x7f5c2bb5,0x5b360c5e}},	// [2320] _perc_, daws_, parq, معار,
   {{0x66092e08,0x25bf2e09,0x2f560284,0xa01b1c49}},	//   hoek, hjul_, _утис, ltön,
   {{0x6fd00149,0x66092e0a,0x4e1a0260,0xdce60233}},	//   _läck, koek, _متحد_, _vakı,
   {{0x200a2e0b,0x29f809ac,0xc884020e,0x7dd8217f}},	//   lobi_, rčao_, yağı_, _dísc,
   {{0x1cba029e,0xc7c60747,0x06e500c7,0xdce60b88}},	//   _صاحب_, йски, _পুলি, _takı,
   {{0x3a382e0c,0x7dca033d,0x29f800e7,0xdb1c0231}},	//   _turp_, _výsu, pčao_, _corã,
   {{0xe0df0451,0x91fd00e8,0x00000000,0x00000000}},	//   zzò_, nsāc, --, --,
   {{0x6fd00f3a,0xd6d9004d,0xc884020e,0x660901c8}},	//   _bäck, шті_, tağı_, goek,
   {{0xbcfb0139,0xdb1c015e,0x70b400b6,0xad9b0065}},	//   _adéj, _horà, ुहोल, _ikút,
   {{0x6fd00212,0x249d0154,0xc88403e0,0x25bf020a}},	//   _däck, _dswm_, rağı_, ajul_,
   {{0x66090cad,0x51f900d6,0x200a2e0d,0x91fd01d3}},	//   boek, иною_, dobi_, krāt,
   {{0xdb1c00b3,0x3860007e,0xc8840342,0x00000000}},	//   _morà, širu_, pağı_, --,
   {{0x63bc2e0e,0x91fd01d3,0x2ed102f0,0xdb1c0065}},	//   örns, drāt, सन्त, _lorà,
   {{0x63ad03e3,0x3fe70033,0x03a300ae,0x200a010a}},	//   _ɗank, পক্ষ, _ничо, gobi_,
   {{0xd35b09c1,0xe2460192,0x6fd00364,0xe6b6023a}},	//   _גדול, _اختي, _mäch, _अपोज,
   {{0x395d022e,0x6fd00364,0x72070103,0x3ebf0234}},	//   xaws_, _läch, _دفعہ_, ćut_,
   {{0xf1f800d0,0x71f81487,0x320b00a5,0x200a0044}},	// [2330] _دعوت_, _دروس_, mocy_, bobi_,
   {{0x66090ab2,0x6fd002e2,0x200a0113,0x9f510103}},	//   zoek, _näch, cobi_, rozó_,
   {{0x6fb500cd,0xad270470,0xfbd00037,0x00000000}},	//   _همکا, _گردو, رتك_, --,
   {{0x7dd10021,0x6fcb01e8,0x7dd80072,0x39152e0f}},	//   _måsk, _vücu, _vísc, омер,
   {{0x7dca0618,0x6d5f2e10,0x9ccb055b,0x893400e3}},	//   _výst, maqa, _сына_, أعما,
   {{0x6fd00222,0x395d023e,0x61ef2e11,0x6d5f2e12}},	//   _räck, saws_, hicl, laqa,
   {{0x7ac41cf2,0x66092e13,0x2ca92e14,0x6fd017a5}},	//   _есте, toek, lvad_, _säck,
   {{0x59f90084,0x6d5f008c,0xa2d7058f,0xe6190396}},	//   _тебя_, naqa, मनस्, јди_,
   {{0x224700a4,0x66092e15,0x38600037,0x61ef14d9}},	//   _stnk_, roek, áirt_, dicl,
   {{0xdb1c0f3f,0xd26508d8,0x66090185,0x6498013d}},	//   _horá, окой, soek, стър_,
   {{0xdb1c2e16,0x27e0006d,0x2ca92e17,0x59dd00aa}},	//   _korá, ɗin_, hvad_, _मतार,
   {{0x7bc72e18,0x6fd00149,0x249d022e,0x9c130139}},	//   _loju, _täck, _tswm_, _dọin,
   {{0x200a0032,0xb9150139,0xdb1c2e19,0x6d5f2e1a}},	//   tobi_, _agbẹ_, _morá, daqa,
   {{0x34b20979,0x23292e1b,0xb4c700aa,0x25e516e2}},	//   _آموز, _коли_, ैनी_, जोरी_,
   {{0x200a2e1c,0x443f2e1d,0x61ef22d4,0x63a32e1e}},	//   robi_, lqu_, bicl, _iann,
   {{0x63a32e1f,0xdd922761,0x657b1a45,0x6d5f2e20}},	//   _hann, بور_, nguh, gaqa,
   {{0x63a32e21,0x7bc72e22,0x443f02a1,0x2f2300fd}},	// [2340] _kann, _boju, nqu_, tégé_,
   {{0x63a32e23,0xad9b2e24,0x443f014b,0xdb1c033c}},	//   _jann, _skút, iqu_, _aorá,
   {{0x63a32e25,0x3f9803e4,0x6d5f2e26,0x91fd01d3}},	//   _mann, meru_, baqa, prāt,
   {{0x63a32e27,0xdb1c04c3,0x6fd0042c,0x29f800c4}},	//   _lann, _corá, _säch, pčam_,
   {{0x91a00023,0x7bc70065,0xdb1c00d4,0xdbdc0af0}},	//   _chỉ_, _foju, _dorá, _láél,
   {{0x63a32e28,0x6d441834,0x3f982e29,0x3cff0034}},	//   _nann, lcia, neru_, _रखते_,
   {{0xdb1c0037,0xd90d0018,0x9f9d0139,0x00000000}},	//   _forá, نیہ_, _dìè_, --,
   {{0x6d442e2a,0x39420006,0x26c004a3,0x63a309e3}},	//   ncia, _üks_, ćio_, _aann,
   {{0x63a32e2b,0x22492e2c,0x6d442e2d,0x3f982e2e}},	//   _bann, _čaka_, icia, keru_,
   {{0x69c20934,0x3f9800cb,0x63a3188c,0x7dd12e2f}},	//   ljoe, jeru_, _cann, _påsk,
   {{0x61ef2e30,0x6d5f2e26,0x973c14f3,0x6d442e31}},	//   ticl, yaqa, _gaća, kcia,
   {{0x63a31909,0x51f80fe9,0x6d442e32,0x00000000}},	//   _eann, жнюю_, jcia, --,
   {{0x63a32e33,0x3f982e34,0xa3c3009d,0x2d8701f9}},	//   _fann, feru_, _एकच_, őnek_,
   {{0xa3ce018b,0x65602e35,0x3f982e36,0x6d462e37}},	//   _रवि_, lamh, geru_, _afka,
   {{0x9f340120,0xbcfb001f,0x6d5f041c,0x244000fe}},	//   дері, _idéi, taqa, _hòm_,
   {{0x63a32e38,0x24400c56,0xad9b0af0,0x65602e39}},	//   _zann, _kòm_, _ojúe, namh,
   {{0x63a32e3a,0xad9b0181,0x3f982e3b,0x6d5f2e3c}},	// [2350] _yann, _skús, beru_, raqa,
   {{0x6d5f2e3d,0xdb1c0018,0x7dd8003e,0x2ca92e3e}},	//   saqa, _sorá, _vísa, rvad_,
   {{0xdd910080,0x61ed0087,0x5a350a7c,0xdb1c2e3f}},	//   _كود_, _kmal, чнет, _porá,
   {{0x6d44013d,0xfe9a00c1,0xf1bf2e40,0x6d5f2e41}},	//   ccia, _פירמ, zmán_, qaqa,
   {{0x6d5d00d9,0x61ed0129,0x65602e42,0xa01b007b}},	//   _iesa, _mmal, damh, ytöl,
   {{0x6d5d2e43,0x05a3049d,0x61ed2e44,0x60c013ce}},	//   _hesa, _खोजब, _lmal, ämmi,
   {{0x63a32e45,0x6d5d2e46,0x7c3d2df3,0xdb1c10d9}},	//   _rann, _kesa, _husr, _torá,
   {{0x63a32e47,0x3f982e48,0x6d5d2e49,0x65602e4a}},	//   _sann, zeru_, _jesa, gamh,
   {{0x6d5d2e4b,0x63a32e4c,0xb4d50cce,0xf1ba0023}},	//   _mesa, _pann, सने_, _đơ_,
   {{0x61ed2e4d,0x443f2e4e,0x6d5d2e4f,0xbcfb0139}},	//   _amal, rqu_, _lesa, _eeég,
   {{0x63a32e50,0x443f025a,0x3f980dab,0x7c350154}},	//   _vann, squ_, veru_, _mizr,
   {{0x63a32e51,0x6d5d2e52,0xdb1c01c5,0x3f982e53}},	//   _wann, _nesa, _foræ, weru_,
   {{0x7c3d2e54,0x63a32e55,0x3ea1023b,0xe4490037}},	//   _nusr, _tann, _asht_, _التى_,
   {{0xf8a50979,0x69db2e56,0x63a30565,0x04540018}},	//   _یک_, _llue, _uann, _آئند,
   {{0x6d5d2c09,0x7c3d02e2,0xaca40294,0x443d0319}},	//   _besa, _ausr, _mpụt, _huw_,
   {{0xf0662e57,0x7c3501d3,0x1c461f47,0xf1bf003e}},	//   _екип, _aizr, знам, nmál_,
   {{0x6d5d2e58,0xdb1c00dd,0x3f982e59,0x3ea1023b}},	// [2360] _desa, _korç, peru_, _esht_,
   {{0x6d442e5a,0x69db02fd,0xe81b009f,0x6d5d01ee}},	//   scia, _alue, _पीला_, _eesa,
   {{0x69c202ac,0xcf5700ca,0x160b09c3,0x443d0483}},	//   tjoe, _מבית_, हकार_, _luw_,
   {{0x6d5d2e5b,0xf3f12e5c,0xaca40129,0x79a32458}},	//   _gesa, hị_, _apụt, ерше,
   {{0x2d820149,0xb4d500bc,0x00000000,0x00000000}},	//   _icke_, सनो_, --, --,
   {{0x569400a0,0xbcfb0af0,0x24402e5d,0x69c22e5e}},	//   дакт, _adéw, _ròm_, sjoe,
   {{0x69db2e5f,0x6d5d2e60,0x64590078,0x8f9b0266}},	//   _flue, _yesa, _awwi, מיסי,
   {{0xe9a313fc,0x7c3d02e7,0x66040031,0x244005aa}},	//   _пасп, _yusr, čiko, _pòm_,
   {{0xdb1c008b,0x28160103,0x65602e61,0x2ca205db}},	//   _borç, _فورس, ramh, _jskd_,
   {{0x46a62e62,0x65602e63,0x61ed00a1,0xa01b0084}},	//   _назв, samh, _smal, ttöm,
   {{0xdb050113,0x6b6701f9,0x24400383,0x00000000}},	//   gdhè, légí, _wòm_, --,
   {{0x3946132d,0x7ae10103,0x443d03a8,0x00000000}},	//   ncos_, _ülte, _fuw_, --,
   {{0xdb1c2e64,0x39462027,0x7dd800b6,0xf8be10e9}},	//   _forç, icos_, _písn, ्हिय,
   {{0x6d5d2d96,0x925700bf,0x3ea10167,0x38660063}},	//   _sesa, _کشور_, _psht_, isor_,
   {{0x6d5d2e65,0x7c3d02e6,0x9f4a0314,0xdb05023b}},	//   _pesa, _susr, cibí_, rdhë,
   {{0x61ed2e66,0x42fb00a1,0x7c3d2e67,0x131700d7}},	//   _umal, _להוס, _pusr, _מחול_,
   {{0x7bdc010a,0x6d5d2e68,0xa01b2e69,0x25a62e6a}},	// [2370] _blru, _vesa, ntök, _maol_,
   {{0x3f812e6b,0x6e992610,0x39462e6c,0x2d820364}},	//   _uchu_, _двор_, ecos_, _ecke_,
   {{0xdb5800c2,0xdd0c0034,0x20042e6d,0x61fd2e6e}},	//   яют_, góło, émie_, onsl,
   {{0x61fd2e6f,0x23c8030b,0x22580094,0x3a24037a}},	//   nnsl, ाउँद, árky_, _chmp_,
   {{0x07a52e70,0xf3f10134,0x5fd10ff9,0x78a60206}},	//   далн, yị_, _सकाल, _škvr,
   {{0x443d01cb,0x945d007f,0xdb1c02c3,0x27c7007b}},	//   _ruw_, zyńs, _borä, ящег,
   {{0x6446003e,0x56921009,0xa01b007b,0x25a60076}},	//   íkin, вајт, ttöj, _baol_,
   {{0x25a60a02,0x63b80154,0x39462e71,0x291f01ff}},	//   _caol_, _anvn, ccos_, _tzua_,
   {{0xf1bf2e72,0xdb1c0161,0x443d0113,0x62880f5a}},	//   rmál_, _porç, _quw_, etdo,
   {{0x395f2e73,0x7dd8037a,0xf1bf003e,0xa01b007b}},	//   _heus_, _aísl, smál_, stöj,
   {{0x395f01c0,0xfc3f0037,0x2d9b2e74,0xfbd200ca}},	//   _keus_, _luí_, keqe_, דתי_,
   {{0x25a60a02,0x77630858,0xaca30139,0x67210fa3}},	//   _gaol_, lanx, _afọb, _izlj,
   {{0x395f2e75,0x644b0ec9,0xdb1c255b,0x20b504d9}},	//   _meus_, _utgi, _torç, нёрс,
   {{0x7dd80220,0x61fd1cab,0xe82006e4,0x395f2e76}},	//   _píso, ansl, यतया_, _leus_,
   {{0xe7e5007a,0x628801cb,0x83fd01f9,0x00000000}},	//   _कतना_, ctdo, lsőo, --,
   {{0x26130161,0x395f2e77,0xe1f2001c,0x9f9400c2}},	//   mãos_, _neus_, _جست_, _sää_,
   {{0x39a601b3,0xfc3f0037,0xdbdc0af0,0x9f94007b}},	// [2380] _jūsų_, _cuí_, _fáìl, _pää_,
   {{0x39a601b3,0xafdb038c,0x67212e78,0x3ebe02c3}},	//   _mūsų_, spør, _ozlj, ätts_,
   {{0x395f00b3,0x776300ee,0xa5bd00c6,0x00000000}},	//   _beus_, danx, rmųj, --,
   {{0x395f009c,0xbcfb00b3,0xfc3f034f,0xa01b007b}},	//   _ceus_, _adéu, _fuí_, ytök,
   {{0x395f2e79,0x5fd20067,0x186715a7,0x9f9400c2}},	//   _deus_, _हवाल, дачи_, _tää_,
   {{0x25a600e3,0x77630428,0x2d802e7a,0x7a2300aa}},	//   _saol_, ganx, lgie_, võte,
   {{0xc7b80028,0x69d800dd,0xdb1c0149,0x61fd2e7b}},	//   _vnđ_, ëves, _borå, ynsl,
   {{0x746a2082,0x395f2e7c,0x2d802e7d,0x69d801d3}},	//   оров_, _geus_, ngie_, īves,
   {{0xd49a004d,0x211d2918,0x38c300c6,0xdbdc0139}},	//   іри_, _नरेश_, gūrą_, _láíl,
   {{0x1b210081,0xf1bf0146,0x77630072,0x26130131}},	//   _বলতে_, rmám_, canx, fãos_,
   {{0xc7b3040a,0xdb1c038c,0x26130161,0xa01b2e7e}},	//   _שבע_, _forå, gãos_, stök,
   {{0x22ac00b6,0xa01b003e,0x3cff007a,0x00000000}},	//   _věk_, ptök, _रखले_, --,
   {{0x7dd1070a,0x2ca01d49,0x61fd2e7f,0x9f58034f}},	//   _måst, jwid_, rnsl, joró_,
   {{0x75222e80,0x7dd1032e,0x2d8002ac,0x00000000}},	//   _izoz, _låst, egie_, --,
   {{0x40342e81,0x1d4c0134,0x2ee603e3,0xfc3f0076}},	//   терс, _ọdịm, _ƙofa_, _suí_,
   {{0x2d802e82,0x6d562e83,0x442c01cb,0xd83800c4}},	//   ggie_, gbya, lmd_, _lič_,
   {{0x395f0472,0xfc3f0023,0x442c029a,0x212f01b9}},	// [2390] _reus_, _quí_, omd_, _àgh_,
   {{0x395f2e84,0xd8382e85,0x75220239,0x7e7c01e9}},	//   _seus_, _nič_, _mzoz, burp,
   {{0x395f0428,0xbcfb0af0,0xe1ff2e86,0x442c029a}},	//   _peus_, _adét, onó_, imd_,
   {{0x20112e87,0x66022e88,0x9f5800e1,0x3ebe0b81}},	//   lozi_, _njok, boró_, åtte_,
   {{0x7b670d64,0x386900e3,0x395f05fe,0x6e2d2e89}},	//   _отве, éar_, _veus_, mmab,
   {{0x48e00081,0x660200c2,0x63ad03e3,0x7b74001c}},	//   বপূর, _ajok, _ɗans, _لطفا,
   {{0x395f2e8a,0x776308a8,0x260b05a5,0xd8380146}},	//   _teus_, ranx, ावली_, _dič_,
   {{0x442c0cad,0xd5b106f6,0xdcef0740,0x20112e8b}},	//   emd_, افظ_, _hacı, hozi_,
   {{0x20111a80,0x6012052f,0x31602e8c,0xd838007e}},	//   kozi_, kæmp, _reiz_, _fič_,
   {{0x9f9d0139,0x69d9000b,0x66020372,0x28be2c82}},	//   _bìí_, lkwe, _ejok, ्हरि,
   {{0xd24e037f,0x7dd826e0,0xb81b0034,0x69d92e8d}},	//   ینی_, _sísm, _पीएम_, okwe,
   {{0x7dd8025b,0x6602023b,0x9f9d0065,0x442c18f0}},	//   _písm, _gjok, _dìí_, amd_,
   {{0x76411331,0xa3d51612,0x661b024a,0x26130131}},	//   _huly, _подч, mluk, sãos_,
   {{0x20112e8e,0x661b20bc,0x7641083e,0x66020141}},	//   gozi_, lluk, _kuly, _zjok,
   {{0x442702e2,0xdee61a18,0xdb150031,0x236500c4}},	//   _ihn_, хови, _pozý, malj_,
   {{0x76412e8f,0xd24e00e3,0x6e2d019c,0x661b2e90}},	//   _muly, _اني_, gmab, nluk,
   {{0x2011092f,0xfce32e91,0x91fd00d9,0x921700c1}},	// [23a0] bozi_, гото, ksāj, _אַזױ_,
   {{0x9f9d02b4,0xfc3f00e3,0x661b067d,0xbcfb0065}},	//   _yìí_, _arís_, hluk, _adés,
   {{0x7dd109ce,0xdb1c0181,0x44270085,0x9f580036}},	//   _påst, _horú, _mhn_, borò_,
   {{0xceb3028c,0x69d90d1f,0xdb1c2e92,0x661b031a}},	//   _עיר_, gkwe, _korú, jluk,
   {{0xdb0703a9,0x661b2e93,0x6d3b00ca,0x442c2e94}},	//   _lajè, dluk, _מתכנ, ymd_,
   {{0x66022e95,0x76412e96,0x998d0031,0x44272e97}},	//   _sjok, _buly, _vieš_, _nhn_,
   {{0xfc032e98,0x09e600d6,0x69962e99,0xdb152e9a}},	//   _спро, _зовн, _прах, _dozó,
   {{0x661b2e9b,0x69d92e9c,0x7bce00aa,0x76412e9d}},	//   gluk, ckwe, _hobu, _duly,
   {{0x09e32e9e,0xb4da0251,0x7bce2e9f,0xa492001c}},	//   _сотн, ठने_, _kobu, ایتت,
   {{0x7bce00d3,0x224e01ff,0x236500c4,0x00000000}},	//   _jobu, _ptfk_, galj_, --,
   {{0x76412ea0,0x7bce2ea1,0x442c0126,0x45e400de}},	//   _guly, _mobu, rmd_, _đượ,
   {{0x79822ea2,0x7bce0201,0x20112ea3,0x44272ea4}},	//   ngow, _lobu, wozi_, _ehn_,
   {{0x20112ea5,0xe3b200cd,0x2365077e,0x9f580036}},	//   tozi_, _مرغ_, balj_, vorò_,
   {{0x644f1f8d,0x7bce2ea6,0xdb1c0065,0xa3d70096}},	//   ície, _nobu, _dorú, _सवय_,
   {{0x20110193,0xe28f0037,0x6e942ea7,0x20040031}},	//   rozi_, _هذي_, лиру, émia_,
   {{0x63aa2ea8,0x20112ea9,0x3f850078,0xdb1c0032}},	//   _hafn, sozi_, żlu_, _forú,
   {{0x7dd82eaa,0x7bce2eab,0xbcfb0032,0x20110a4b}},	// [23b0] _získ, _bobu, _adér, pozi_,
   {{0x63aa0102,0x64422eac,0x7bce2ead,0x661b047e}},	//   _jafn, _muoi, _cobu, zluk,
   {{0xa03600a1,0xbb840037,0x29d7026a,0x9f8f00aa}},	//   _שאתה_, المي, _uçak_, _müü_,
   {{0x65622eae,0x9f580088,0xdb0e0131,0x91a000fe}},	//   _neoh, lorð_, _robô, _khí_,
   {{0x76412eaf,0x69d92eb0,0x98a52eb1,0x661b015c}},	//   _suly, rkwe, тиле, vluk,
   {{0x69d92eb2,0x62980305,0x63aa0088,0x3f83003e}},	//   skwe, _opvo, _nafn, ngju_,
   {{0x2365031a,0x69d901cb,0x00000000,0x00000000}},	//   valj_, pkwe, --, --,
   {{0xceb40130,0x7bce2eb3,0x44272eb4,0xf9932eb5}},	//   ריק_, _zobu, _shn_, _حبس_,
   {{0x661b06ee,0x23652ceb,0xf8bf0146,0x64422eb6}},	//   rluk, talj_, _šéf_, _cuoi,
   {{0x9aa40018,0x7641083e,0x7dd82eb7,0xd7670018}},	//   _جمہو, _tuly, _písk, _سائٹ,
   {{0x386d2eb8,0xb17b038c,0xd6db0084,0x63aa2eb9}},	//   _hver_, rhån, _эта_, _dafn,
   {{0x999800d9,0xa06a192f,0xdb1c2eba,0x2365015c}},	//   _kurš_, мама_, _corù, salj_,
   {{0x4427063f,0x9f9d0139,0x2365015c,0x2ee601c2}},	//   _thn_, _bìà_, palj_, _ƙofo_,
   {{0xb4bf02e8,0xb4cd009d,0x29f80ebd,0x3f8301cd}},	//   ीही_, रही_, nčar_, ggju_,
   {{0x248d2ebb,0x91a000de,0x6fd901b9,0x7dd80503}},	//   ltem_, _thì_, _mìch, _hísi,
   {{0x386d0054,0xbcfb020d,0x7bce0201,0xb17b02c3}},	//   _over_, _adéq, _sobu, nhål,
   {{0x248d2ebc,0x9f58003e,0xe7f208d4,0xa2a92ebd}},	// [23c0] ntem_, borð_, _अगला_, टिक्,
   {{0xeafa1629,0x7dd82ebe,0x248d2ebf,0x7bce2ec0}},	//   ورات_, _mísi, item_, _qobu,
   {{0x386d013d,0xdb1c0649,0x6f79006e,0x317200b6}},	//   _aver_, _yorù, _אָרג, _kdyz_,
   {{0xe9da00d6,0x248d2ec1,0x7bce019f,0xe8fa007b}},	//   ьке_, ktem_, _wobu, мле_,
   {{0xe8942ec2,0x7bce2ec3,0x6b87009c,0x7982007f}},	//   уаль, _tobu, _fcjg, rgow,
   {{0x248d2ec4,0x65622ec5,0x25ad2c97,0x394d2ec6}},	//   dtem_, _seoh, edel_, _efes_,
   {{0x386d00a1,0x973c0a39,0x00000000,0x00000000}},	//   _ever_, _jaći, --, --,
   {{0x63aa0088,0xa01b0103,0xab270e05,0xb4cd0d75}},	//   _safn, ltöt, _роса_, रहू_,
   {{0x64422ec7,0x98a3038f,0x248d2ec8,0x9987020a}},	//   _quoi, _ките, gtem_, ţiţi_,
   {{0x32020038,0x7c3c03e5,0x660d2ec9,0x25ad2eca}},	//   enky_, _jirr, čaka, adel_,
   {{0x51f9036c,0x7c3c2ecb,0x386d096d,0x27e90044}},	//   енню_, _mirr, _zver_, ɗan_,
   {{0xcb13040a,0x973c14f3,0x91a000fe,0x644200fe}},	//   ילת_, _naći, _phí_, _tuoi,
   {{0x6abf009d,0x248d00ee,0xfc3f0139,0x7c3c01b5}},	//   _एप्र, ctem_, _asín_, _oirr,
   {{0x7c3c2ecc,0xdb1c01df,0x200500bc,0x00000000}},	//   _nirr, _forø, õli_, --,
   {{0xbcfb0032,0xb5fc02a1,0x973c0357,0x9f58003e}},	//   _adép, _ewġe, _baći, rorð_,
   {{0x3253013d,0x7c3c009c,0x443c00d7,0x61e6042c}},	//   _твър, _airr, _hiv_, chkl,
   {{0x443c2ecd,0x7c3c2ece,0xbddb00fd,0xdb050037}},	// [23d0] _kiv_, _birr, _lièg, rdhí,
   {{0x7c3c2ecf,0x3b542ed0,0xe7bd0081,0x7c84016c}},	//   _cirr, икур, _অত্য, јуте,
   {{0x443c2ed1,0x20032461,0x248d0018,0x3a751894}},	//   _miv_, mnji_, ztem_, улер,
   {{0xe7e5110f,0x443c2ed2,0x973c01ac,0x00000000}},	//   कसभा_, _liv_, _gaći, --,
   {{0xd5b600c3,0x6d4d008c,0x851e074c,0x67d52877}},	//   _अफ़ज, mcaa, _परगट_, лоду,
   {{0x443c2ed3,0x6e3d03e3,0x00000000,0x00000000}},	//   _niv_, _hisb, --, --,
   {{0x6e3d2ed4,0xb17b02c3,0x32020e4b,0x00000000}},	//   _kisb, thål, ynky_, --,
   {{0x248d0068,0x069600e3,0x443c023e,0x26c9005f}},	//   ttem_, انية_, _aiv_, ćao_,
   {{0x6e3d2ed5,0x25ad17d2,0xb17b0222,0x20030141}},	//   _misb, rdel_, rhål, knji_,
   {{0x7dd80102,0x200308a9,0x248d2ed6,0xb17b0149}},	//   _vísi, jnji_, rtem_, shål,
   {{0x7d1d0222,0x17f800e3,0x998600c4,0x00000000}},	//   _lyss, _شركة_, lmoš_, --,
   {{0x64b50f43,0x6e3d2ed7,0x5ed70033,0x248d2ed8}},	//   _محتر, _nisb, _ডেভে, ptem_,
   {{0x443c2ed9,0x20041789,0x7d1d084e,0x00000000}},	//   _fiv_, émio_, _nyss, --,
   {{0x443c01c5,0x75fe00d9,0xa2ab06e4,0x6d4f041c}},	//   _giv_, vīzi, _जनप्, _afca,
   {{0x6e3d2eda,0xdee32edb,0xe81b009f,0xf3f000e3}},	//   _bisb, бори, _पीछा_, _بأن_,
   {{0x7c3c2edc,0x443c08a9,0xdca62edd,0x6d4f01ff}},	//   _sirr, _ziv_, лаби, _cfca,
   {{0x7c3c2ede,0xa3d71757,0x443c023e,0x61e42edf}},	// [23e0] _pirr, _सवा_, _yiv_, _ilil,
   {{0xfc3f00e3,0x79890022,0x63a12ee0,0x20030a39}},	//   _tsín_, _acew, neln, cnji_,
   {{0x7c3c2ee1,0x61e40113,0xdce400c6,0x9f580216}},	//   _virr, _klil, maič, hirë_,
   {{0x7cda01d3,0xaa57071c,0x5f46010d,0x63a12ee2}},	//   _pārā, النا_, _جنگل, heln,
   {{0xb4cd007d,0x7c3c003d,0xd917013a,0x62812ee3}},	//   रहो_, _tirr, льш_, hulo,
   {{0x62812ee4,0x63a108a9,0xbddb00fd,0xda660037}},	//   kulo, jeln, _pièg, _ماري,
   {{0x63a12ee5,0x1ae600c2,0x998d0220,0x61e40129}},	//   deln, _совм, _sieť_, _olil,
   {{0x443c0d7d,0x6e3d0694,0x20031197,0xa01b0149}},	//   _siv_, _xisb, znji_, ntör,
   {{0x443c0197,0x69c02ee6,0x80a40ed3,0x09060f99}},	//   _piv_, _inme, _चैले, _спан,
   {{0x61e42ee7,0x644f2ee8,0x443c006c,0x63a12ee9}},	//   _alil, ícia, _qiv_, geln,
   {{0x443c2eea,0xa01b2eeb,0x7bde00dc,0x20030357}},	//   _viv_, ktör, ikpu, vnji_,
   {{0x154628c2,0xa01b0084,0xe13500c2,0x61e4009c}},	//   _седм, ytös, инны, _clil,
   {{0x443c0197,0x20030039,0x6e3d0968,0xc10800ae}},	//   _tiv_, tnji_, _risb, гэре_,
   {{0x62812eec,0x53341f5d,0x7d1d2eed,0x3cff013f}},	//   bulo, _келт, _ryss, _žuvo_,
   {{0x62812eee,0x9f3500d6,0x539b00a1,0x7d1d0e3e}},	//   culo, реві, _ניהו, _syss,
   {{0x200304a3,0x5d550476,0x7d1d1531,0x7bde1183}},	//   snji_, ркат, _pyss, ekpu,
   {{0x6e3d2eef,0x8f5500cd,0x20032ef0,0xad9b003e}},	// [23f0] _visb, _پنجش, pnji_, _hjúk,
   {{0x69c02ef1,0x6d4d2ef2,0x212907e7,0xad9b003e}},	//   _anme, scaa, _izah_, _kjúk,
   {{0x973c1523,0xa01b00c2,0x61e4007b,0x78a90172}},	//   _kaću, stös, _ylil, _ssev,
   {{0x63a12ef3,0x5fc30aa6,0xdb07003e,0x7d1d1aad}},	//   zeln, शावल, _snjó, _tyss,
   {{0x79c909e5,0x62812ef4,0x973c0218,0xad9b003e}},	//   _یوسف_, zulo, _maću, _ljúk,
   {{0x69c02ef5,0x244901cd,0x2d84026a,0x7bde2ef6}},	//   _enme, _rúm_, _ömer_, ckpu,
   {{0x0f5800ca,0xbddb014b,0x63a12ef7,0x4af900e5}},	//   ניהם_, _tièd, veln, _ревю_,
   {{0x660d02dd,0x9f58023b,0x78a901fa,0x9f410220}},	//   čako, tirë_, _tsev, _dlhé_,
   {{0x63a12294,0xa787110a,0x78a92ef8,0x2bc90f8f}},	//   teln, _مشاو, _usev, रापा,
   {{0x62812ef9,0x66190510,0x9f580216,0x00000000}},	//   tulo, _wkwk, rirë_, --,
   {{0x0206002d,0x21290063,0xc7c42efa,0xa2062efb}},	//   изон, _azah_, _усти, ипод,
   {{0x63a12efc,0xd9f70789,0xdb0700b6,0x3a2d0063}},	//   seln, ूचित_, _nají, _jhep_,
   {{0x7dd8000d,0x63a12efd,0x62812efe,0x3d0400a5}},	//   _míst, peln, sulo, _रखें_,
   {{0x7dd8025b,0x2d991b5a,0x0eb300aa,0x3a2d0113}},	//   _líst, _abse_, ुमंड, _lhep_,
   {{0x316b0067,0x21761067,0xdb07037a,0x420a00ae}},	//   bacz_, _купр, _bají, _инко_,
   {{0x260b07d5,0x290d0072,0x61e42eff,0x61f600d8}},	//   ावटी_, _oxea_, _ulil, _umyl,

   {{0xab662f00,0xf1bf1e6f,0xa01b186b,0x9f5801dc}},	// [2400] ивал, rmát_, rtör, hiré_,
   {{0xfbdf0f5a,0x973c0a39,0x9f5803a9,0x00000000}},	//   _stêr_, _zaću, kiré_, --,
   {{0xa01b2f01,0x0f7b0266,0x00000000,0x00000000}},	//   ptör, _בריל, --, --,
   {{0x20182f02,0x2d962f03,0xf296006e,0x23672f04}},	//   lori_, _трос, יכער_, _lenj_,
   {{0x9f512f05,0x3a2d0113,0xc7c6125f,0x69c00023}},	//   lizá_, _dhep_, иски, _vnme,
   {{0xdb07000d,0x20182f06,0x224000bc,0x7dd801cd}},	//   _zají, nori_, _liik_, _vísu,
   {{0xb76500d6,0x46671402,0xa5f82efb,0x9f582f07}},	//   стій, арым_, леку_, giré_,
   {{0xd5b719a0,0x20180150,0xba570089,0x3a3f0023}},	//   ась_, hori_, _כסלו_, _giup_,
   {{0xad9b0088,0xa4f800cd,0x20182f08,0x2247037a}},	//   _sjúk, دکار_, kori_, _aunk_,
   {{0x20182f09,0x9f58034f,0xf1bf0103,0xf7432b81}},	//   jori_, biré_, ymás_, _дефо,
   {{0x20182f0a,0x91fd00d9,0xa6ca00e3,0x0bb700a1}},	//   dori_, ksāt, _جوال_, בלים_,
   {{0x7dd82f0b,0xdb1c0cb6,0x05830d86,0xd49a2f0c}},	//   _míss, _horó, _душм, _арк_,
   {{0x76482f0d,0x24540182,0x291f023e,0x20182f0e}},	//   _hudy, _انتس, _xyua_, fori_,
   {{0xb7f8022d,0x7a2300aa,0xdb1c0139,0x00000000}},	//   ्चिम_, võtm, _joró, --,
   {{0x62350476,0xdb1c2df7,0xe8172397,0x22470090}},	//   _леку, _moró, दकता_, _gunk_,
   {{0x5d78007b,0x23672f0f,0xfe7902c6,0xaac700d1}},	//   ийся_, _zenj_, čů_, یتان,
   {{0x2018042d,0x409500e3,0xdb070146,0x71f800d1}},	// [2410] bori_, _الخر, _vají, _خروس_,
   {{0x20182f10,0xdb0e00cd,0x3a3f0167,0xcc250033}},	//   cori_, _kabè, _siup_, বদ্ধ_,
   {{0x24840124,0x44290022,0x3a2d0023,0xdb0e022b}},	//   humm_, _ɗa_, _phep_, _jabè,
   {{0x29d703e0,0x3219109b,0x00000000,0x00000000}},	//   _açar_, nosy_, --, --,
   {{0x7dd8124d,0xa8a700c2,0xdb0e0513,0x7648007f}},	//   _víst, ррек, _labè, _audy,
   {{0xf77104f4,0xab842f11,0x764800a5,0x61fd2f12}},	//   سات_, _муск, _budy, hisl,
   {{0x3a3f02e7,0x61fd2f13,0x2ca900f0,0xe8df0139}},	//   _tiup_, kisl, lwad_, _igọn_,
   {{0x61fd2f14,0x644f2f15,0x23670ebd,0x2d890a4b}},	//   jisl, ício, _senj_, ngae_,
   {{0x442e02ef,0x20182f16,0x2240007a,0x2ca900f0}},	//   _bhf_, yori_, _riik_, nwad_,
   {{0x53c92f17,0xdb0e0154,0xdb1c0139,0x60dd2f18}},	//   угом_, _babè, _goró, dysm,
   {{0x216a29db,0x7a23007a,0xdb1c015e,0x31690062}},	//   лини_, võtj, _horò, _beaz_,
   {{0x442e0088,0x78bb2f19,0xddce00e8,0x00000000}},	//   _ehf_, _kruv, rsbū, --,
   {{0x63c200b6,0x799b2f1a,0x442e2f1b,0x67212f1c}},	//   ávní, _mbuw, _fhf_, _hylj,
   {{0xd91a00a1,0xb4e317ff,0xe8df00de,0x76480167}},	//   רושל, ननी_, _ngọn_, _yudy,
   {{0x799b2f1d,0x20182f1e,0xe29900ae,0xc2551850}},	//   _obuw, rori_, _сай_, _اختت,
   {{0xfbdf0019,0x22910103,0xa2c400b7,0xdb1c042c}},	//   _quên_, mák_, िमर्, _vorü,
   {{0xbddb0257,0x7bd501e8,0x2ca90124,0x229110a8}},	// [2420] _sièc, _bozu, gwad_, lák_,
   {{0xbddb04ea,0x9f862f1f,0x20181a4a,0xdb0e2f20}},	//   _pièc, _угод, qori_, _habé,
   {{0xfe72223e,0x1c3900a9,0xdb0e01dc,0x6c330037}},	//   _عدد_, рять_, _kabé, أفلا,
   {{0xed3600ae,0x3eb8080e,0xed5a008f,0x78bb00f3}},	//   _гэгэ, mvrt_, _щом_, _bruv,
   {{0xdb1c2f21,0xad9b0032,0x25f60789,0x6d460124}},	//   _poró, _ajúw, एफसी_, _igka,
   {{0x6e24131f,0xa09b00f5,0x2bc907b2,0x22910103}},	//   llib, ריסט, राणा, kák_,
   {{0x22912f22,0x3eb80087,0x78bb037a,0x61fd2f23}},	//   ják_, nvrt_, _eruv, yisl,
   {{0x54542f24,0x61fd08a8,0xfbc904f8,0x6e240bb6}},	//   овит, xisl, राथम, nlib,
   {{0x61fd0074,0x7bd5013c,0x6d460270,0x78bb2ba4}},	//   visl, _yozu, _mgka, _gruv,
   {{0xb2742f25,0x764800f9,0xd4970109,0x4adc1e05}},	//   олош, _tudy, ёры_, _यथाव,
   {{0x61fd0038,0x764807ac,0x17570796,0x6d5f008c}},	//   tisl, _uudy, _הסבר_, ybqa,
   {{0xd46a00c9,0x6446003e,0x60dd007b,0x61fd0a4b}},	//   _биде_, íkis, tysm, uisl,
   {{0xdce60090,0x682d0031,0xdb071f20,0xdb0e00d8}},	//   _dekċ, súde, _majá, _dabé,
   {{0x22912f26,0x6d462f27,0x61fd2f28,0xdb0e01dc}},	//   bák_, _agka, sisl, _tabè,
   {{0x7bd52f29,0x8c000033,0x8234001c,0xdd9b00e5}},	//   _rozu, ্তান_, تریا, лша_,
   {{0x6e242f2a,0xbcfb0018,0x4cd10033,0x7bd52f2b}},	//   glib, _idéz, _সেগু, _sozu,
   {{0x7bd50092,0xe1ff275a,0x76420239,0x00000000}},	// [2430] _pozu, mió_, _mioy, --,
   {{0xe1ff2f2c,0x6e24083e,0xdb1c24c7,0x29fe0129}},	//   lió_, alib, _enrí, ọala_,
   {{0xe7c700a5,0x7bd502ef,0x00000000,0x00000000}},	//   लासप, _vozu, --, --,
   {{0xe1ff0990,0x78bb2f2d,0x3ebe052f,0xddab2f2e}},	//   nió_, _pruv, ætte_, _стол_,
   {{0x7bd52f2f,0x3ea10167,0x2bc90034,0x7c8400ae}},	//   _tozu, _hpht_, रादा, _нуре,
   {{0x22910103,0x8bcb00ae,0xe78700ba,0x2bcb0231}},	//   yák_, _сымб_, судо, _сумо_,
   {{0x99852f30,0xdddc0a39,0x75221c7b,0x00000000}},	//   _ولسو, lurš, _ayoz, --,
   {{0x64990f32,0x22912f31,0x91a90023,0x78bb2f32}},	//   атор_, vák_, _nhà_, _truv,
   {{0xe1ff2f33,0xb4e300a5,0x13e92f34,0x66df0139}},	//   dió_, नने_, имий_, _bàkú,
   {{0x22912e16,0x22510146,0xdb0e2f35,0xe2910076}},	//   ták_, ízko_, _sabé, وذج_,
   {{0xd5ae00bf,0xe29900f6,0x645b2f36,0x2329141a}},	//   رفی_, шан_, spui, рони_,
   {{0xe1ff2f37,0xbba60455,0x22910730,0x36340037}},	//   gió_, _ऑस्क, rák_, _فرنس,
   {{0x22912e16,0x601b020a,0x66091a8a,0x661b0dd8}},	//   sák_, tîmp, mnek, mouk,
   {{0xa2e5016a,0x3eb80542,0x645923d1,0x661b2f38}},	//   _молд, tvrt_, _itwi, louk,
   {{0xdb1c0102,0x7f432f39,0xe1ff0081,0x66090010}},	//   _norð, держ, bió_, onek,
   {{0xe1ff2f3a,0x66092f3b,0x644b092f,0x64432f3c}},	//   ció_, nnek, _kugi, _hini,
   {{0x656b2f3d,0x6e24005a,0x44252e6a,0x644b007e}},	// [2440] _megh, rlib, oll_, _jugi,
   {{0x9f580080,0xdb070068,0x644b2f3e,0xdb1c0088}},	//   oirí_, _sajá, _mugi, _borð,
   {{0x44252f3f,0x9d462a84,0x661b2f40,0x644b2f41}},	//   ill_, _менд, kouk, _lugi,
   {{0xa92607f3,0x661b00c2,0x2bdc030b,0x64590034}},	//   одел, jouk, _मकवा, _otwi,
   {{0x76420113,0xdce605db,0x7dd80231,0x682400ee}},	//   _rioy, _kekč, _uísq, lòdi,
   {{0x660901e9,0x64432f42,0xdb1c003e,0xe1ff0103}},	//   enek, _nini, _forð, zió_,
   {{0x644b013f,0x98a30138,0x656b028d,0x645905bd}},	//   _augi, _ąją_, _begh, _atwi,
   {{0x64432f43,0x644b2f44,0x44252f45,0xd49a0a52}},	//   _aini, _bugi, ell_, аро_,
   {{0x64432f46,0x656b2f47,0xe1ff058a,0x644b2f48}},	//   _bini, _degh, vió_, _cugi,
   {{0x64432f49,0x644b0995,0xa2f400d6,0x539700c2}},	//   _cini, _dugi, зпоч, овья_,
   {{0xe1ff0890,0x661b2f4a,0xe3b801e8,0x644b01ff}},	//   tió_, bouk, llık_, _eugi,
   {{0x644b2f4b,0x64430e78,0x81e30033,0xd5a6001c}},	//   _fugi, _eini, ফোন_, _گلچی,
   {{0xe1ff0890,0xe3b801e8,0x6443188c,0x62812f4c}},	//   rió_, nlık_, _fini, arlo,
   {{0xe1ff0990,0x64432f4d,0xd25000e3,0xbddb0472}},	//   sió_, _gini, _كنت_, _cièn,
   {{0x3a262f4e,0x2ee5003e,0xbddb01dc,0x2bc92f4f}},	//   klop_, álf_, _dièn, रासा,
   {{0x63a82f50,0x644b02e5,0x64432f51,0x62882f52}},	//   ledn, _yugi, _zini, mudo,
   {{0x62880081,0x25d70266,0x7dd800e1,0x64432f53}},	// [2450] ludo, קומן_, _vísp, _yini,
   {{0xa2be05a5,0x60c002b6,0x9b27007b,0x6443026d}},	//   षिप्, æmme, офел, _xini,
   {{0x62882f54,0x2bdc0285,0x66092f55,0x67ef0537}},	//   nudo, _मकरा, ynek, _højg,
   {{0x660002c6,0xda78097a,0xdb1c0653,0x2bc902c6}},	//   jimk, іях_, _vorð, राहा,
   {{0x44252f56,0x998d0181,0xad9b0103,0x656b2f57}},	//   yll_, _tiež_, _amúg, _regh,
   {{0x63a80ca7,0x644b2f58,0x62882f59,0x656b028d}},	//   jedn, _rugi, kudo, _segh,
   {{0xfbd20054,0x644b2f5a,0x661b2f5b,0x64432f5c}},	//   _אתם_, _sugi, touk, _rini,
   {{0x2bc917ff,0x644b2f5d,0xc6210033,0x3a2600b3}},	//   रावा, _pugi, _পূজা_, clop_,
   {{0x64432f5e,0x656b2f5f,0xdb070231,0x5a44002d}},	//   _pini, _vegh, _enjô, _цэра,
   {{0x656b2f60,0x6443019f,0x682d0031,0x66092f61}},	//   _wegh, _qini, búda, snek,
   {{0x442500eb,0x04c900d1,0xdce60154,0x39400234}},	//   rll_, _گوشي_, _rekč, žist_,
   {{0x644b2f62,0x7a310727,0x64432f63,0xdce600d4}},	//   _tugi, båte, _wini, _sekč,
   {{0x64432f64,0x63a80284,0x7bc701c0,0x64592f65}},	//   _tini, bedn, _onju, _utwi,
   {{0x628812fb,0xdfd20f98,0x682400b3,0x00000000}},	//   budo, ريز_, tòdi, --,
   {{0xf1bf0080,0x62882027,0xe7f30006,0xe3b8026a}},	//   mlán_, cudo, _अतना_, zlık_,
   {{0x7bc72f66,0x67ef052f,0x40962f67,0x6d4b0087}},	//   _anju, _højd, _ерот, žgan,
   {{0xdca31107,0x32020146,0x00000000,0x00000000}},	// [2460] нати, miky_, --, --,
   {{0xa09700f5,0x66000555,0x32021515,0xdb1c02c3}},	//   _צדיק_, zimk, liky_, _morö,
   {{0x3ce6135f,0xf1bf002b,0x34a81678,0x4a461982}},	//   šov_, ilán_, _कन्द, чнев,
   {{0x3202025b,0x63a800a5,0x8c4600c2,0xaca40294}},	//   niky_, zedn, _неме, _ahụr,
   {{0xd7c70b79,0xe8942f68,0x2bc9055c,0x394000ce}},	//   लांच, фаль, राशा, äis_,
   {{0xdb0e11ce,0xe3b801e8,0x9f582f69,0x7bc70357}},	//   _habí, rlık_, nirà_, _gnju,
   {{0xcfb60081,0xfbc90976,0x3a262253,0xa01b17a5}},	//   ঞাপন, रारम, plop_, krön,
   {{0xf64f00cd,0xceb300ca,0x682d0076,0x62882f6a}},	//   دئو_, תיה_, rúda, vudo,
   {{0x66002f6b,0x62880134,0x32020094,0x00000000}},	//   rimk, wudo, diky_, --,
   {{0x62882f6c,0x68420065,0x66000a4b,0xb05b0212}},	//   tudo, _dídì, simk, lväg,
   {{0x63a80fee,0xa75b00a1,0x32020146,0x9f582f6d}},	//   redn, _הדבר, fiky_, dirà_,
   {{0xdb0e033a,0x6288052f,0x63a8200b,0xaca40065}},	//   _nabí, rudo, sedn, _awọt,
   {{0x68e22f6e,0x2fda03a4,0x7a2300aa,0xbddb0113}},	//   nyod, _bopg_, mõtt, _dièl,
   {{0xa01b0103,0x2d9c0103,0xf1bf2f6f,0xe47b0142}},	//   ltöz, ővel_, clán_, _פרוכ,
   {{0xa3b50490,0x245200de,0x32020031,0xe3b803e0}},	//   _चोट_, _hâm_, biky_, mdı_,
   {{0xe3b80702,0xdb0e065b,0x3ebe2f70,0x61e62f71}},	//   ldı_, _cabí, ætta_, ckkl,
   {{0x61ed2f72,0x67ef01c5,0x9f582f73,0x2bc92f74}},	// [2470] _ilal, _høje, birà_, राला,
   {{0xe3b80702,0x68e22f75,0x9f580451,0x24520023}},	//   ndı_, dyod, cirà_, _mâm_,
   {{0x20032f76,0x24520019,0xbd02029a,0xdb0e0231}},	//   miji_, _lâm_, _éénm, _fabí,
   {{0x9f5810d9,0xa954004d,0x00000000,0x00000000}},	//   mirá_, екці, --, --,
   {{0x61ed198d,0xbc770031,0x9f58034f,0x00000000}},	//   _mlal, ýšľa, lirá_, --,
   {{0xb8d504dd,0x7bc70479,0x61ed2f77,0xdb0e1054}},	//   _जन_, _unju, _llal, _zabí,
   {{0xdce600d9,0x9f582ad4,0xe69200cd,0x67ef02b6}},	//   _iekā, nirá_, نلود, _nøje,
   {{0x20032f78,0xb9c500e3,0xe459079c,0x61ed03a9}},	//   hiji_, _تقري, ожи_, _nlal,
   {{0xdcfd0587,0x69c92851,0xf1bf0a43,0x245200fe}},	//   _kası, _inee, tlán_, _câm_,
   {{0x61ed23b6,0x20032f79,0x69c901fa,0x24520019}},	//   _alal, jiji_, _hnee, _dâm_,
   {{0x3202025b,0x61ed2f7a,0x69db0313,0x7a430065}},	//   tiky_, _blal, _koue, _gìtì,
   {{0x471a07a6,0x69db04ea,0xd6d80084,0x9f582f7b}},	//   _וועג, _joue, _эту_, dirá_,
   {{0x2509172a,0x69db2f7c,0x32020146,0x2bb2023a}},	//   _برای_, _moue, riky_, ीयमा,
   {{0xdcfd0b88,0xdb0e0af3,0x69db2f7d,0xdce600d9}},	//   _nası, _sabí, _loue, _nekā,
   {{0x9f582f7e,0x69c92f7f,0x50431262,0x00000000}},	//   rirà_, _onee, терб, --,
   {{0x61ed0113,0x69c90517,0x69db2f80,0x20030350}},	//   _glal, _nnee, _noue, aiji_,
   {{0x20031386,0xdcfd03a3,0x245200de,0xdb150052}},	// [2480] biji_, _bası, _xâm_, _fazë,
   {{0x9f5804d8,0x69c92f81,0xe50e00c0,0x68e20239}},	//   birá_, _anee, ापति_, vyod,
   {{0x69db2f82,0x9f580610,0xfc3f0328,0x00000000}},	//   _boue, cirá_, _asís_, --,
   {{0xa9670ac6,0x79a31fdb,0x09061bb8,0xe3b80511}},	//   дица_, врше, мпен, zdı_,
   {{0x7a23007a,0xd6cf00cd,0xe3b803a3,0xe9ff00de}},	//   võtt, یقه_, ydı_, _giận_,
   {{0x68e22f83,0xb05b0149,0x69c9083e,0xe3b800a7}},	//   ryod, sväg, _enee, xdı_,
   {{0x24522f84,0x7a2300aa,0x69db020d,0x7bdc0076}},	//   _sâm_, tõtt, _foue, _ioru,
   {{0x7bdc008a,0xc88301e8,0x69db1a8d,0x00000000}},	//   _horu, üğü_, _goue, --,
   {{0x7bdc2f85,0xe3b800a7,0x9f580131,0xdcfd0342}},	//   _koru, tdı_, zirá_, _yası,
   {{0x61ed0d62,0x88bd00a5,0x7bdc00f3,0x00000000}},	//   _slal, _myśl, _joru, --,
   {{0x200308a9,0xe3b80702,0x61ed2f86,0x9f580042}},	//   viji_, rdı_, _plal, xirá_,
   {{0x245200ef,0x7bdc0032,0x9f580165,0x3869020a}},	//   _tâm_, _loru, virá_, ţare_,
   {{0x60f8055b,0xdb0e0154,0xd5cf020b,0xdb150216}},	//   дняя_, _labà, _kềnh_, _pazë,
   {{0x9f5809d3,0x67ef02b6,0x14d70266,0x00000000}},	//   tirá_, _tøje, _קוגל_, --,
   {{0x61ed2f87,0xdb1505aa,0xe7e6007a,0xd5cf00fe}},	//   _tlal, _gazè, _कवना_, _mềnh_,
   {{0x200308a9,0x9f582f7b,0x63b80856,0x61ed0415}},	//   siji_, rirá_, _havn, _ulal,
   {{0x69db0257,0x22980470,0x629a2c37,0xad9b003e}},	// [2490] _roue, lék_, ltto, _djúp,
   {{0x7bdc2f88,0xfe710068,0x69c92f89,0x69db0154}},	//   _coru, _مگر_, _snee, _soue,
   {{0x7bdc01d9,0x69db2f8a,0x495c0129,0xdb0e0db4}},	//   _doru, _poue, _ịtụ_, _cabà,
   {{0x7bdc0154,0xdb0e0161,0x629a007b,0xf1bf2f8b}},	//   _eoru, _sabã, itto, klám_,
   {{0x18692887,0x07a508c3,0xd5cf00fe,0x22490350}},	//   чали_, еалн, _bềnh_, _miak_,
   {{0x63b80939,0x7bdc2f8c,0xdb0705fe,0x76b300a7}},	//   _navn, _goru, _majú, _həyə,
   {{0x26c1033a,0xd6d118a9,0x48ff009f,0x00000000}},	//   ího_, اقع_, _शेरो_, --,
   {{0x22980018,0x7bdc01e8,0x99980138,0x7a311f60}},	//   dék_, _zoru, _durų_, båta,
   {{0x7bdc2f8d,0x21290063,0xdb070031,0x629a166f}},	//   _yoru, _nyah_, _najú, etto,
   {{0xf6e7166f,0x2bd20096,0x224901ff,0x63b8044c}},	//   _оцен, साया, _aiak_, _cavn,
   {{0x63b803ce,0x2129005a,0xdb15025b,0xdb0e2299}},	//   _davn, _ayah_, _bazé, _kabá,
   {{0x22492f8e,0xbddb03a9,0x70cb2f8f,0x386d0154}},	//   _ciak_, _dièk, ामूल, _kwer_,
   {{0x629a0084,0x25ad2f90,0x64a501b3,0x2bd20096}},	//   atto, meel_, _чала, सामा,
   {{0x21292f91,0x63b802b6,0x25ad2f92,0xdb0e02c3}},	//   _dyah_, _gavn, leel_, _inbö,
   {{0x5f1a0251,0x6da62f93,0x76b30092,0xada600c2}},	//   _मुख्_, нива, _bəyə, навл,
   {{0x7bdc210e,0x25ad04ee,0xc1ba00ab,0x22490124}},	//   _soru, neel_, _رابط_, _giak_,
   {{0x7bdc021d,0x76b30092,0x248d2f94,0x1de1007a}},	// [24a0] _poru, _dəyə, nuem_, _नवरत,
   {{0xa09b0130,0x25ad0cad,0x7bdc01d4,0x1f6616dd}},	//   _צייט, heel_, _qoru, _яком,
   {{0x386d0113,0x88bd00a5,0x7bdc0088,0xed5a0dcc}},	//   _awer_, _wyśl, _voru, _нон_,
   {{0x60c42f95,0xd9100260,0x70770421,0x386d2f96}},	//   _krim, لیز_, _تمیز_, _bwer_,
   {{0x25ad0305,0xbcfb0065,0x7bdc2f97,0x21290063}},	//   deel_, _aféf, _toru, _xyah_,
   {{0x60c4270d,0xe7c700a3,0xd6da0208,0x00000000}},	//   _mrim, लागप, зти_, --,
   {{0x63b8011d,0x629a01b9,0x2cb20150,0xa96a2f98}},	//   _ravn, xtto, lwyd_, _нива_,
   {{0x63b82f99,0x2d922f9a,0x60c42f9b,0x7af20233}},	//   _savn, ngye_, _orim, ıktı,
   {{0x248d24ba,0x2cb202ad,0x22492f9c,0x60c400d1}},	//   guem_, nwyd_, _riak_, _nrim,
   {{0x22980068,0xa87b0054,0xa01b2f9d,0xdb0e2c85}},	//   ték_, _מאמר, tröm, _zabá,
   {{0x60c42f9e,0x05662f9f,0x7dd80018,0x21290706}},	//   _arim, _звен, _dísz, _syah_,
   {{0x60c42fa0,0x22980470,0x20010212,0x248d0131}},	//   _brim, rék_, _smhi_, buem_,
   {{0x60c42fa1,0xd5af0867,0x629a2fa2,0x66022fa3}},	//   _crim, _دفن_, stto, _imok,
   {{0x2cb20150,0x7c3e0381,0x00000000,0x00000000}},	//   dwyd_, jmpr, --, --,
   {{0x443e02dc,0x60c42fa4,0x6e260167,0x00000000}},	//   mmt_, _erim, _bkkb, --,
   {{0x7c3e124d,0x442c2fa5,0x60c40407,0xbcfb0103}},	//   empr, lld_, _frim, _beép,
   {{0x644a2fa6,0x60c421ad,0x2cb20150,0x443e01cb}},	// [24b0] _kifi, _grim, gwyd_, omt_,
   {{0x62880036,0x644a009e,0xdb150031,0xdb0e0850}},	//   ordo, _jifi, _enzý, _sabá,
   {{0x442c003e,0x67ef02b6,0x25ad008c,0x443e2fa7}},	//   ild_, _nøja, yeel_, imt_,
   {{0x443e0364,0x644a2fa8,0x24670139,0xf1bf00d4}},	//   hmt_, _lifi, _jímò_, dlák_,
   {{0x25ad0db8,0x644a003b,0x7ae5007b,0xa91d0141}},	//   veel_, _oifi, syht, _odže,
   {{0x644a2fa9,0x660202a4,0xd83805aa,0x6e2d2faa}},	//   _nifi, _amok, _chč_, llab,
   {{0x6e2d0cfd,0x25ad2fab,0x2011028d,0x79a701b3}},	//   olab, teel_, inzi_, _прае,
   {{0x6e2d2fac,0x2bc9030b,0x02a20294,0xa91d009a}},	//   nlab, राका, _chọọ, _adže,
   {{0x8cc400a5,0x6e2d0054,0x644a0193,0x25ad04e2}},	//   रियो, ilab, _bifi, reel_,
   {{0x6e2d0060,0xd6db00d3,0xee0e0285,0xd7f82fad}},	//   hlab, _нте_, _िद्ध_, _пух_,
   {{0x60c42fae,0x6e2d2faf,0x25ad000b,0x6d5d2fb0}},	//   _srim, klab, peel_, _ofsa,
   {{0xd70d0557,0x442c01c0,0x443e0d87,0x644a2fb1}},	//   िपीठ_, ald_, amt_, _eifi,
   {{0x644a2998,0x248d2fb2,0xe3ae263d,0x6e2d2fb3}},	//   _fifi, quem_, _кб_, dlab,
   {{0x6569038c,0x7a382fb4,0x644a02a4,0x6e2d2fb5}},	//   lbeh, míte, _gifi, elab,
   {{0x91fd00d9,0x6e2d2fb6,0x44270063,0x7a380182}},	//   mpān, flab, _ikn_, líte,
   {{0x6e2d2fb7,0xa6e90019,0x65692fb8,0x60c41173}},	//   glab, _trươ, nbeh, _trim,
   {{0x7a382fb9,0x1d071121,0x60c42fba,0x44270479}},	// [24c0] níte, вети_, _urim, _kkn_,
   {{0xdca31dde,0x2bd20d88,0x6e2d2fbb,0x2cb20150}},	//   рафи, साधा, alab, rwyd_,
   {{0xee3a2311,0x44271d49,0xeb972fbc,0xb11300ac}},	//   _оно_, _mkn_, тих_, bụsa,
   {{0x656901c0,0xa3c82fbd,0x58860109,0x44272fbe}},	//   jbeh, _लोन_, выка, _lkn_,
   {{0x443e1df0,0x442c2fbf,0xdce40106,0x26c501e9}},	//   ymt_, yld_, obič, _arlo_,
   {{0x65690220,0x02a20134,0x66022fc0,0xc8650037}},	//   ebeh, _shọọ, _smok, اطني,
   {{0x644a2fc1,0x6009042d,0xa3d52fc2,0x764b2fc3}},	//   _rifi, nžma, हान_, _bigy,
   {{0x644a2fc4,0x44272fc5,0x6adb0081,0x7ae316f9}},	//   _sifi, _akn_, _যেকো, änte,
   {{0x41d6000c,0x44270808,0x7a380018,0x644a034f}},	//   धानस, _bkn_, gíte, _pifi,
   {{0x442c0054,0x38662fc6,0x52d80120,0xdce405db}},	//   uld_, mpor_, емою_, jbič,
   {{0x764b0068,0x443e0f05,0x442c2042,0xd5af2fc7}},	//   _figy, rmt_, rld_, _кс_,
   {{0xad9b0065,0x6e2d0072,0x764b030a,0x6602063d}},	//   _amún, xlab, _gigy, _umok,
   {{0x442c0063,0x7bce02ac,0x7a15007f,0x00000000}},	//   pld_, _onbu, kątn, --,
   {{0x44270072,0x6e2d2fc8,0x764b0172,0x00000000}},	//   _gkn_, wlab, _zigy, --,
   {{0x6e2d2fc9,0xd3780034,0xdbdc003e,0x00000000}},	//   tlab, mać_, _ráðl, --,
   {{0x51872c49,0x6e2401e9,0x7bce2fca,0xd3780034}},	//   _рука, goib, _anbu, lać_,
   {{0x6e2d2fcb,0x31792fcc,0xe3b8013c,0x00000000}},	// [24d0] rlab, masz_, llıq_, --,
   {{0x317900fb,0xd37800a5,0x6e2d2fcd,0xa3d50efb}},	//   lasz_, nać_, slab, हाय_,
   {{0xf09f2fce,0x1622269c,0x78a90220,0x6e242fcf}},	//   ltà_, मवार_, _spev, boib,
   {{0xd3782fd0,0xf1bf0065,0xfd1f0032,0xa01b003e}},	//   hać_, ndá_, _adìe_, fsög,
   {{0xd37800a5,0xf09f2fd1,0xa7a92fd2,0x9d140120}},	//   kać_, ntà_, екла_, _вдяч,
   {{0xe7392277,0xf09f2af2,0xd378007f,0x7a382fd3}},	//   нел_, ità_, jać_, víte,
   {{0xd3780067,0x9f510890,0x31792214,0x6569225b}},	//   dać_, lizó_, kasz_, tbeh,
   {{0x26c502e6,0xe3b80092,0xa2d61678,0x00000000}},	//   _vrlo_, dlıq_, यमन्, --,
   {{0x75f5030b,0x39152fd4,0x78a90146,0x2ed02fd5}},	//   _náze, _смар, _upev, _हप्त,
   {{0x7a380b05,0x7c250146,0xd3780034,0x9f410206}},	//   ríte, nohr, gać_, _dlhú_,
   {{0x420a0d47,0xf09f013d,0x7a382fd6,0xa91d005f}},	//   енно_, età_, síte, _udžb,
   {{0x28c70569,0x7a380103,0x442718ef,0xf1bf0231}},	//   लिपि, píte, _wkn_, gdá_,
   {{0x66091cab,0xdb1c2fd7,0x44272fd8,0x53a5065c}},	//   miek, _carê, _tkn_, _балб,
   {{0x66092fd9,0x25bd2fda,0xd378007f,0xc30401f3}},	//   liek, _hawl_, cać_, ابیو,
   {{0x44252fdb,0x249f2fdc,0x539a00a1,0x9324001c}},	//   mol_, ltum_, _ניקו, _پرون,
   {{0x66090b4b,0xe1f200bf,0x25bf2fdd,0x44252fde}},	//   niek, _دست_, ndul_, lol_,
   {{0xa3c80e28,0x6e242fdf,0xf09f00ee,0x25bd00eb}},	// [24e0] _लोड_, roib, ctà_, _mawl_,
   {{0x442502e0,0x249f2fe0,0x2d99009c,0xeb9700d3}},	//   nol_, itum_, _ecse_, лиу_,
   {{0xdee60161,0x7f9b00a1,0xc98603f2,0xb05b0212}},	//   _сони, _אביז, гули, nvän,
   {{0x44252fe1,0x200a2fe2,0xd3780034,0x249f2fe3}},	//   hol_, libi_, zać_, ktum_,
   {{0x44252fe4,0x7a1c00b6,0x25bf01c2,0xb4bf0179}},	//   kol_, jčte, ddul_, ुमो_,
   {{0x44252fe5,0x2ca00bab,0x38662fe6,0xbddb05aa}},	//   jol_, mtid_, rpor_, _chèf,
   {{0x2ca02fe7,0x44252fe1,0x09a900c7,0x38662fe8}},	//   ltid_, dol_, ওয়া, spor_,
   {{0xd3780d1b,0x200a03a3,0xb05b0149,0xf8760037}},	//   wać_, hibi_, dvän, _مهرج,
   {{0x200a2fe9,0x442502ad,0x2ca02fea,0xc79600b1}},	//   kibi_, fol_, ntid_, _مشاب,
   {{0x3a2601a2,0x44252feb,0x200a006d,0xad9b0065}},	//   loop_, gol_, jibi_, _amúl,
   {{0x53342fec,0x66092fed,0xa91d02ef,0x25bf2fee}},	//   рент, biek, _idža, bdul_,
   {{0xf09f0465,0xe3b80092,0xd37800a5,0x2ca0007a}},	//   ttà_, rlıq_, sać_, ktid_,
   {{0x44252fef,0x3dc00150,0x200a2ff0,0xf1bf2ff1}},	//   bol_, ddiw_, fibi_, rdá_,
   {{0x44252ff2,0xf09f2ff3,0xc3560465,0x682d077f}},	//   col_, rtà_, _съдъ, túdi,
   {{0x3a260a9f,0xa36f0220,0xf09f2ff4,0xe3b800a7}},	//   koop_, äčši, stà_, qlıq_,
   {{0x270e01d4,0x9f510487,0x443c0430,0xa3d509a1}},	//   _mən_, tizó_, _hhv_, हाथ_,
   {{0x9f4100dd,0x200a2ff5,0xa91d031a,0x1ae20081}},	// [24f0] _kohë_, bibi_, _odža, _গেলে_,
   {{0x320b2ff6,0x66092ff7,0xbcfb0072,0x9f510314}},	//   licy_, ziek, _aféc, rizó_,
   {{0xddd001e8,0x9e352ff8,0xa3d52ff9,0x28c700b6}},	//   _çeşi, _венч, हात_, लिभि,
   {{0x320b0034,0x44252ffa,0xdb1c00b3,0xac951be7}},	//   nicy_, zol_, _marè, _камш,
   {{0x44252ffb,0x2ca000f0,0xa3e51101,0xdb1c05aa}},	//   yol_, ctid_, _नवल_, _larè,
   {{0xba770f36,0x660900a5,0x25bd0150,0x00000000}},	//   _مارت, wiek, _sawl_, --,
   {{0x66092ffc,0xec3600a1,0x44252694,0xa26500fe}},	//   tiek, _כאשר_, vol_, _cuộ,
   {{0x249f2ffd,0x44252ffe,0x270e0092,0x3ebe003e}},	//   ttum_, wol_, _dən_, ætti_,
   {{0x44252fff,0x25bf3000,0xfa34001c,0x443c3001}},	//   tol_, rdul_, _طرفد, _bhv_,
   {{0x66093002,0x249f3003,0x78bb0a39,0x7a383004}},	//   siek, rtum_, _isuv, míta,
   {{0x249f3005,0xddc701b3,0xc5d53006,0x216a0245}},	//   stum_, gpjū, _віль, кини_,
   {{0x442502ad,0x249f003e,0xb05b0222,0xdb070103}},	//   sol_, ptum_, rvän, _hajó,
   {{0x200a3007,0xdb1c023b,0xe7b90096,0xb05b0212}},	//   tibi_, _parë, _इसाप, svän,
   {{0x88bd00a5,0x248d3008,0x44253009,0xb4fa00ca}},	//   _wyśw, mrem_, qol_, _בפני,
   {{0x645b0eb8,0x200a300a,0x5275300b,0xdb1c300c}},	//   lqui, ribi_, _тулу, _garè,
   {{0xdd92300d,0x06af0081,0x8e5502ec,0x14a90096}},	//   تور_, কিপি, стрі, _कहाण,
   {{0x248d0167,0xb05b007b,0x245b02ac,0x51f60103}},	// [2500] nrem_, nväl, _jêm_, _مسکر,
   {{0x907b0130,0x2ca00170,0x307b00a1,0x27220220}},	//   _שטיי, rtid_, _שאינ, nčné_,
   {{0x2ca0300e,0xdb15001f,0x78bb0673,0xdb1c300f}},	//   stid_, _razã, _asuv, _karé,
   {{0x7ae315bd,0x7053110a,0xb05b0149,0x61e40084}},	//   änta, _دنیا, kväl, _joil,
   {{0x270e0092,0x3a261044,0xdb1c3010,0x61e40037}},	//   _sən_, roop_, _maré, _moil,
   {{0xdb073011,0xb227003e,0x248d3012,0x18670291}},	//   _cajó, _klæð, drem_, шаљи_,
   {{0x645b037a,0xdb15016d,0xdb050364,0x61e402ac}},	//   equi, _vazã, gehä, _ooil,
   {{0xe5c60459,0x61e43013,0x443c3014,0x786600d6}},	//   рско, _noil, _shv_, _вказ,
   {{0x7a3817eb,0x6aa900e7,0x91830023,0x69c001ff}},	//   cíta, _ćefi, _nếu_, _iame,
   {{0x69c2043e,0xdb1c06a3,0x6287003d,0x53e600ae}},	//   ldoe, _parè, ġjon, рциа,
   {{0x78a23015,0x4b7b00c1,0xec3700a1,0x248d3016}},	//   ltov, כטיג, שאיר_, arem_,
   {{0x61e40091,0x248d3017,0x69c23018,0x69c03019}},	//   _coil, brem_, ndoe, _jame,
   {{0x78a20094,0xfeb803ed,0x69c010f6,0x61e4301a}},	//   ntov, یافت_, _mame, _doil,
   {{0xd7d90096,0xdb070154,0xb22701cd,0x00000000}},	//   ढायच, _majò, _blæð, --,
   {{0x69c00012,0x61e41519,0x75f50018,0x34b61fb4}},	//   _oame, _foil, _háza, _अनुद,
   {{0x5d5507f3,0xdb05070a,0x78a20094,0x69c0301b}},	//   скат, nehå, ktov, _name,
   {{0x78a2301c,0xbddb00fd,0x69c200f0,0xdb070154}},	// [2510] jtov, _bièr, ddoe, _najò,
   {{0x6fb509e5,0x7a381e6f,0xeb93097d,0x61e4301d}},	//   _امدا, víta, تظر_, _zoil,
   {{0xdb150181,0x69c00b1a,0x645b00e1,0xbddb00b3}},	//   _bazá, _bame, zqui, _dièr,
   {{0xc987193d,0x69c029b0,0x34b60034,0x645b037a}},	//   ружи, _came, _अनूद, yqui,
   {{0xf1bf0103,0xf09400c1,0xb05b0212,0xbddb020d}},	//   llás_, ַנק_, kväm, _fièr,
   {{0x645d0fb6,0xf1bf002b,0xa01b02c3,0xe8f8013f}},	//   ísim, xoán_, mrös, шлі_,
   {{0x657b0bb6,0x69c0301e,0x7a38301f,0xa3d50296}},	//   tauh, _fame, síta, हास_,
   {{0x248d3020,0x69c03021,0xff18040a,0x7a380b66}},	//   trem_, _game, יקות_, píta,
   {{0x32f70092,0xf1bf0220,0x9f410113,0x78a200d8}},	//   məyə_, hlás_, _dohé_, ctov,
   {{0x61e41b08,0x69c03022,0x248d3023,0xdb1c00cd}},	//   _soil, _zame, rrem_, _saré,
   {{0x645b3024,0x61e43025,0x69c03026,0xdb1c3027}},	//   squi, _poil, _yame, _paré,
   {{0x245b0396,0xa06a3028,0xb0c33029,0x248d302a}},	//   _têm_, лама_, शिंग, prem_,
   {{0x61e4025a,0x705600e3,0x68fc00a7,0x00000000}},	//   _voil, إنسا, _ərdo, --,
   {{0x7afe302b,0x76aa01d4,0x51f6001c,0x64590113}},	//   yzpt, _həya, _گستر, _iuwi,
   {{0x670d033a,0x229500e3,0x52850037,0x64592fee}},	//   िपटक_, _العس, _البك, _huwi,
   {{0x78a20074,0x6459302c,0x51f60100,0xb17b17d2}},	//   ytov, _kuwi, _دستر, skår,
   {{0x22830b88,0x78a2025b,0x14620e62,0x7ae30212}},	// [2520] lık_, xtov, _kọọp, äntn,
   {{0x69c0302d,0x628109ac,0x78a20095,0x6b56302e}},	//   _same, oslo, vtov, стах,
   {{0xdcef0029,0x628116f3,0x7d09042d,0xcf5700a1}},	//   _vecā, nslo, _žest, _לבית_,
   {{0xe8fa1c32,0x69c0302f,0x65793030,0x78a23031}},	//   лле_, _qame, _newh, ttov,
   {{0x69c23032,0x17540243,0x64593033,0xb3b718ff}},	//   rdoe, овля, _nuwi, _असंख,
   {{0x69c01ee3,0x78a23034,0xab2a3035,0x6283042d}},	//   _wame, rtov, _бога_, _ovno,
   {{0x78a23036,0x69c03037,0x76aa0092,0x46670109}},	//   stov, _tame, _bəya, брым_,
   {{0x8a06062c,0x78a23038,0x228301e8,0x64590bb6}},	//   _узбе, ptov, dık_, _buwi,
   {{0x628300cc,0x7a380103,0x645903a9,0x62813039}},	//   _avno, líto, _cuwi, eslo,
   {{0x27e501c2,0x6459303a,0x75f50c90,0x9f4100d1}},	//   _goln_, _duwi, _váza, _wohé_,
   {{0x02a30938,0xdb050212,0x628113ea,0x7a3801f9}},	//   прям, pehå, gslo, níto,
   {{0x2240303b,0xa3c800aa,0x00000000,0x00000000}},	//   _chik_, _लोर_, --, --,
   {{0x25b700cd,0x224000d1,0x9f410031,0x777a01ff}},	//   _دهند_, _dhik_, _dlhý_, _ketx,
   {{0x765a303c,0xb4e40096,0xb4d40096,0x26cc007e}},	//   _kuty, नही_, हमी_, _krdo_,
   {{0xa3d50c8c,0x2283026a,0x0cd100c0,0x777a303d}},	//   हार_, cık_, सम्म, _metx,
   {{0x765a083e,0xf1bf0018,0x75f500b6,0x7bcb01d3}},	//   _muty, rlás_, _lázn, ēgum,
   {{0xc4b6110f,0xae021e93,0x13ac0033,0x00000000}},	// [2530] _अनोख, रोइन_, _কোয়, --,
   {{0x3a2d0185,0x60cd0169,0x41a5000c,0x26cc303e}},	//   _skep_, _iram, ग्रस, _ordo_,
   {{0x1dc4303f,0xbddb06a3,0xb4e40ec3,0x00000000}},	//   _लोकत, _chèc, नहु_, --,
   {{0x60cd3040,0x777a01ff,0xdb1c033c,0x2bf500a4}},	//   _kram, _aetx, _anró, _इतकं_,
   {{0x26cc3041,0x777a00b3,0x27e5033b,0x2283026a}},	//   _ardo_, _betx, _poln_, zık_,
   {{0x26cc04a3,0x765a3042,0x62813043,0xf7710037}},	//   _brdo_, _buty, yslo, ذات_,
   {{0x7bd53044,0xe7390084,0xa91d02ef,0x64593045}},	//   _inzu, шек_, _idžm, _suwi,
   {{0x7d090682,0x60cd3046,0x291f022e,0x7aea00a2}},	//   _þess, _oram, _txua_, äfte,
   {{0xa3d504f8,0x79890154,0x777a01ff,0x41dd11c7}},	//   हाल_, _idew, _fetx, यानस,
   {{0x7bc500bf,0x22830b88,0x981726a0,0x52a93047}},	//   ndhu, tık_, _ابرا, авом_,
   {{0x60cd3048,0xe9ff00de,0x28c70378,0x765a0435}},	//   _aram, _nhẫn_, लिवि, _guty,
   {{0x64593049,0x75f50244,0x60cd304a,0x6aa5304b}},	//   _tuwi, _zázn, _bram, ithf,
   {{0x316d1de1,0x6281304c,0x645900f9,0x442e0139}},	//   ñeza_, sslo, _uuwi, _fkf_,
   {{0x6281304d,0x6283304e,0xae0202d5,0x6a800139}},	//   pslo, _tvno, रोईन_, _jáfá,
   {{0x60cd304f,0xd34700cd,0x22403050,0xe2993051}},	//   _eram, _دیده_, _thik_, _тай_,
   {{0x60cd3052,0x7bd502e2,0x79893053,0x61fd0364}},	//   _fram, _anzu, _ndew, chsl,
   {{0xdca321b6,0xac0a0161,0x640200d1,0x7bc501cb}},	// [2540] мати, анаа_, _رژیم, fdhu,
   {{0x7bc53054,0x79893055,0x602600d6,0x91a60018}},	//   gdhu, _adew, _єдна, _اچھے_,
   {{0x75f53056,0x2bce02e8,0x1c3900a9,0x79890090}},	//   _názo, _होणा, сять_, _bdew,
   {{0xa3d50e5e,0x7bd53057,0x7a380103,0x7bc5009c}},	//   हाँ_, _enzu, ríto, adhu,
   {{0x79890150,0x2db700a1,0x7a380018,0x636600b6}},	//   _ddew, _ולכן_, síto, nční,
   {{0x7a383058,0x79893059,0xdb1c058a,0x2d80305a}},	//   píto, _edew, _harí, laie_,
   {{0xf1ca000c,0x26c30234,0x56940e3f,0x75fc01f9}},	//   ियान, _šjor_, чайт, _léze,
   {{0x2bce1e9f,0x442e07ee,0x95ca0291,0x636602c6}},	//   _होता, _skf_, рука_, kční,
   {{0xdb1c305b,0xa3d52171,0x75fc0018,0xe9ff00de}},	//   _marí, हां_, _néze, _hiến_,
   {{0xe9ff0028,0x26cc0117,0x6a800139,0x765a0517}},	//   _kiến_, _trdo_, _gáfá, _tuty,
   {{0x6fde017f,0x75f501f9,0x5fde02c6,0x0bb700d7}},	//   मानं, _gázo, मानल, חלים_,
   {{0x60cd305c,0x320b0231,0xe9ff00fe,0x442e0154}},	//   _pram, рхон_, _miến_, _wkf_,
   {{0x107413fc,0x2bbb00b6,0x845a0161,0x7a312059}},	//   мляю, _उसला, _трет_, mått,
   {{0xe9ff0023,0x24860218,0x05a600b6,0x442e305d}},	//   _phẫn_, _ivom_, क्रब, _ukf_,
   {{0x22630220,0xdb1c0032,0xe2971009,0x15ee00bc}},	//   ľské_, _barí, _дај_, _जवार_,
   {{0x442c305e,0x2d582082,0xc3330105,0x02fb0327}},	//   lod_, жить_, _קוק_, _כלומ,
   {{0xa80201e8,0x60cd305f,0xdb1c04d8,0x75fc01f9}},	// [2550] şıyo, _uram, _darí, _kézb,
   {{0x442c3060,0xe9ff0028,0xaca30134,0x6d5a00a7}},	//   nod_, _biến_, _nhục, _ştat,
   {{0x20113061,0xdb1c3062,0x7bc53063,0x9e350a51}},	//   mizi_, _farí, rdhu, _неоч,
   {{0x248603ce,0x20113064,0x442c3065,0xaca30174}},	//   _ovom_, lizi_, hod_, _ahục,
   {{0x442c3066,0x7e62033b,0x6e2d3067,0x00000000}},	//   kod_, _čopi, moab, --,
   {{0xcc760105,0x20113068,0x442c3069,0x7ae302b6}},	//   _מעשה_, nizi_, jod_, ønts,
   {{0x442c306a,0x69a602d5,0xea630018,0x00000000}},	//   dod_, _टॉकी, _آپری, --,
   {{0x2011306b,0x7642292c,0x9f580036,0x644818f0}},	//   hizi_, _choy, nirò_, emdi,
   {{0x442c02ad,0x201108a5,0x764201dc,0x6fcb0096}},	//   fod_, kizi_, _dhoy, ायां,
   {{0x442c306c,0x730500e5,0x2011024a,0x24860fee}},	//   god_, зпоз, jizi_, _dvom_,
   {{0x2011306d,0xdb070094,0x23290e96,0x00000000}},	//   dizi_, _objí, сони_, --,
   {{0x27340037,0x00000000,0x00000000,0x00000000}},	//   súnú_, --, --, --,
   {{0x442c02ad,0xa01b02e2,0x455a040a,0x2011306e}},	//   bod_, rsön, _הכנס, fizi_,
   {{0x7649306f,0x7fd50c10,0x644f0428,0x201101e2}},	//   lmey, місі, ïcid, gizi_,
   {{0xdb1c3070,0x2d8000ae,0xdee6004d,0xd0070b0a}},	//   _parí, taie_, чови, чере_,
   {{0x661b3071,0x764901e8,0xe1ff3072,0xbcfb002b}},	//   nnuk, nmey, chó_, _efém,
   {{0xd34700cd,0xdb1c3073,0x20113074,0xb05b00c2}},	// [2560] _دیگه_, _varí, bizi_, yväi,
   {{0x2d8000fd,0x5ebb0033,0x2011044c,0x76493075}},	//   saie_, _উপরে, cizi_, hmey,
   {{0x7a380018,0x05bd0096,0x661b00f9,0x76493076}},	//   sítm, ्याब, knuk, kmey,
   {{0x442c3077,0xad9b0032,0xdb1c016d,0x98a63078}},	//   zod_, _alúf, _parâ, зиде,
   {{0x442c1331,0xed5200cd,0x64430146,0xdb1c016d}},	//   yod_, _سپس_, _ohni, _barã,
   {{0xe9ff0028,0x2609000f,0xdb0e00b6,0x6d3b00ca}},	//   _tiến_, ़ोसी_, _zabý, _לתכנ,
   {{0x8c431b60,0x248603ce,0x36330260,0x7d040036}},	//   _чере, _svom_, کروس, lzis,
   {{0xd49a04e6,0xceb30054,0x442c00f0,0x64433079}},	//   бро_, גיה_, wod_, _ahni,
   {{0x38c80979,0x442c307a,0x7d04307b,0x29020222}},	//   _بازی_, tod_, nzis, _åka_,
   {{0xa2f400d6,0x6e2d0f61,0x6443036b,0x7d00003e}},	//   дпоч, zoab, _chni, _ýmsu,
   {{0x7642005c,0x644800d9,0x2011307c,0x6443009c}},	//   _thoy, rmdi, vizi_, _dhni,
   {{0x248604a3,0x442c307d,0x7a380146,0x79820051}},	//   _tvom_, sod_, dítk, naow,
   {{0x2011307e,0x5067307f,0x6443009c,0x7d041cc9}},	//   tizi_, ятна, _fhni, jzis,
   {{0x1ae200c7,0x442c3080,0x7d043081,0xdb0e3082}},	//   _গেছে_, qod_, dzis, _jabó,
   {{0x20113083,0xc43b00a1,0x53333084,0xbddb03a9}},	//   rizi_, _התגי, _пешт, _dhèn,
   {{0x63ba3085,0x67ef052f,0x753d00a5,0x76aa0092}},	//   letn, _højt, ższe, _rəyl,
   {{0x629a3086,0x271800a5,0x9f58028d,0x76aa013c}},	// [2570] luto, धपुर_, rirò_, _səyl,
   {{0xf04509b4,0x7a3806fa,0x76492ddc,0x629a0a4b}},	//   _تعبی, líth, zmey, outo,
   {{0x3f8303ce,0x629a0d9f,0xdb1c0472,0x9f580036}},	//   maju_, nuto, _carà, pirò_,
   {{0x63ba0018,0x391500c2,0x7aea0212,0xdb1c0065}},	//   hetn, ммер, äfta, _darà,
   {{0x48ab1da3,0x25e03087,0x63ba3088,0x629a09a1}},	//   стем_, कानी_, ketn, huto,
   {{0x63ba3089,0x629a308a,0xfe70001c,0x2ca90212}},	//   jetn, kuto, _جدی_, mtad_,
   {{0x2ca9308b,0x7649026a,0xdb1c0131,0x629a308c}},	//   ltad_, tmey, _varã, juto,
   {{0x629a308d,0x661b24ae,0x3f8318ea,0x7bc7308e}},	//   duto, unuk, haju_, _haju,
   {{0x3f8300e9,0x2ca9308f,0x764901e8,0x7bc73090}},	//   kaju_, ntad_, rmey, _kaju,
   {{0x3f8303ce,0xdb1c2ca8,0x386d3091,0xdb0e0072}},	//   jaju_, _hará, _iter_, _gabó,
   {{0x3f830335,0x629a3092,0x7bc70a55,0x7d043093}},	//   daju_, guto, _maju, zzis,
   {{0x7bc73094,0x2ca93095,0xa91d007e,0xe5e5001c}},	//   _laju, ktad_, _adži, _تزئی,
   {{0xa3c81349,0x53a50a52,0x2be007ad,0xdb0e0154}},	//   _लोक_, _жалб, नामा, _jabò,
   {{0x63ba00cc,0x3f830fbd,0xdb0e002b,0xad9b00ee}},	//   cetn, gaju_, _xabó, _llúd,
   {{0xe9ff0028,0x67ef052f,0xdb0e00b3,0x6da63096}},	//   _nhắn_, _højs, _labò, мива,
   {{0xee3a116d,0x51563097,0x3ce001fa,0xdb1c0146}},	//   іна_, _отпу, txiv_, _nará,
   {{0x3f8303ce,0xbc6a0dd0,0x2ca93098,0xad9b0139}},	// [2580] baju_, زمان_, gtad_, _amús,
   {{0x60c43099,0x3f8303ce,0x7d04309a,0xdb1c05fe}},	//   _isim, caju_, rzis, _parà,
   {{0xdb1c309b,0x09e60f2e,0x7bc72345,0xe9ff0019}},	//   _bará, можн, _daju, _chắn_,
   {{0xdb1c309c,0xaca40129,0x25ad01c0,0xad9b0037}},	//   _cará, _akụr, jfel_, _clúd,
   {{0x7a38309d,0x307a00c1,0xdb0e309e,0x61fd0052}},	//   níti, קאַנ, _cabò, ërli,
   {{0x60c40010,0x7bc70998,0xdb0e0383,0x629a03e3}},	//   _msim, _gaju, _dabò, yuto,
   {{0xa3c81085,0x25ad309f,0x63ba30a0,0xdb1c30a1}},	//   _लोग_, ffel_, vetn, _fará,
   {{0xdb1c128f,0x60c430a2,0x3f8300cc,0x63ba0167}},	//   _gará, _osim, zaju_, wetn,
   {{0x7bc730a3,0x60c430a4,0x8cc400b6,0x629a0027}},	//   _yaju, _nsim, रिटो, wuto,
   {{0x42740231,0xa3d50c13,0xdb1c30a5,0xb05b0364}},	//   нгос, हाग_, _zará, hwäc,
   {{0x3f8303ce,0x629a0270,0xe215163d,0x65c60110}},	//   vaju_, uuto, емны, _обжа,
   {{0x629a30a6,0x3f830d79,0x27ec0220,0x63ba23ff}},	//   ruto, waju_, _hodn_, setn,
   {{0x3f8303ce,0xbddb0113,0xc5f300ca,0x798002f1}},	//   taju_, _dhèl, _בדף_, _memw,
   {{0x629a30a7,0x67ef01c5,0x7a380103,0xbbc830a8}},	//   puto, _højr, síth, रयोक,
   {{0x3f8303ce,0x60c430a9,0x7bc730aa,0xa01b02c3}},	//   raju_, _esim, _raju, lsök,
   {{0x3f8304a3,0x2ca930ab,0x7bc730ac,0x79800ea4}},	//   saju_, ttad_, _saju, _nemw,
   {{0x645830ad,0x3f8304a3,0xe81f30ae,0x7bc702ab}},	// [2590] _kivi, paju_, _बदला_, _paju,
   {{0x2ca930af,0x2c640149,0x9f4506f0,0x61ed30b0}},	//   rtad_, _död_, óló_, _hoal,
   {{0x2ca930b1,0x3a2f30b2,0x628830b3,0x386d0db1}},	//   stad_, togp_, nsdo, _ster_,
   {{0x645830b4,0xdb2600bf,0x7bc70010,0xceb200c1}},	//   _livi, رونی, _waju, _גיט_,
   {{0x7bc730b5,0x9f5800e3,0x6d5d0009,0x61ed30b6}},	//   _taju, mhrá_, _igsa, _moal,
   {{0x07a20476,0xbcfb0065,0xf7450012,0xb05b0853}},	//   гашн, _agég, нело, lväs,
   {{0x25ad0012,0x49bb00bf,0x75f50018,0x7980010a}},	//   tfel_, _وارد_, _házi, _femw,
   {{0xcf58004f,0x6b850d17,0x649900d3,0xad9b0072}},	//   ובות_, lahg, птор_, _flúe,
   {{0x25ad30b7,0x645830b8,0xa91d0031,0x176b002d}},	//   rfel_, _bivi, _beže, _дреп_,
   {{0x69cb30b9,0xc7470037,0xa283001c,0x690103e0}},	//   ldge, _قضاي, نیتو, ızdı,
   {{0xa91d0087,0x61ed00d3,0x798005bd,0x25ad0364}},	//   _deže, _boal, _yemw, pfel_,
   {{0x61ed30ba,0x69cb0418,0x25e0009d,0x60c40106}},	//   _coal, ndge, काणी_, _psim,
   {{0xe9ff00ef,0x69c90167,0xbddb05aa,0x61ed01c8}},	//   _nhận_, _maee, _chèm, _doal,
   {{0x7a3830bb,0x2c640149,0x99dd0094,0x645800ca}},	//   ríti, _röd_, _ohňo, _givi,
   {{0x6e290146,0xa3dc0b7f,0x6288009c,0x00000000}},	//   čebn, डार_, csdo, --,
   {{0x60c430bc,0x91fd01d3,0x69c900f9,0xdb120103}},	//   _tsim, spār, _naee, _ígér,
   {{0xdd8f0a09,0x60c430bd,0x28bf0557,0xf652006e}},	// [25a0] صول_, _usim, _शैलि, רצן_,
   {{0x61ed0505,0x26c502ec,0x7aea0212,0x38a930be}},	//   _zoal, _oslo_, äfto, dúr_,
   {{0xdb1c0396,0x8f9b00c1,0x69cb029a,0xb05b30bf}},	//   _març, _ציטי, fdge, svät,
   {{0x5fde030b,0xa92630c0,0x491100b7,0x69cb04aa}},	//   मावल, ндел, _देहो_, gdge,
   {{0x6b85061d,0x27fe0085,0xb05b30c1,0x27ec0141}},	//   bahg, _pltn_, lvär, _podn_,
   {{0xfaa630c2,0x69db01ff,0x29061f72,0x6d5d00c4}},	//   _паго, _enue, rzoa_, _zgsa,
   {{0x4df430c3,0x2d8230c4,0x8f9b006e,0x798030c5}},	//   _इकाई_, _keke_, ליסי, _temw,
   {{0x645830c6,0xc1ca099d,0xa91d30c7,0x2d82039f}},	//   _sivi, ियोग, _seže, _jeke_,
   {{0x61ed30c8,0xdb1c30c9,0x765902ad,0x64580154}},	//   _roal, _barç, _diwy, _pivi,
   {{0xa01b070a,0x61ed1bd6,0xaca40129,0x66e62135}},	//   rsök, _soal, _ahịr, _поза,
   {{0x6458255c,0x645d0af0,0x61ed020a,0xb05b007b}},	//   _vivi, ísir, _poal, yväs,
   {{0x2d8203ce,0x628810ef,0xb05b0212,0x76aa013c}},	//   _neke_, rsdo, dvär, _nəyi,
   {{0x61ed020a,0x7bdc04e2,0x62880141,0xad9b015e}},	//   _voal, _onru, ssdo, _llúc,
   {{0xdb1c30ca,0xa91d30cb,0xa3c800a3,0x00000000}},	//   _garç, _idžt, _लोच_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbddb025a,0xe9ff0019,0x7bdc01bf,0xbedb0139}},	//   _thèm, _phận_, _anru, _aṣòw,
   {{0x76aa01d4,0x5d5530cc,0x4c94215d,0x2d8230cd}},	// [25b0] _dəyi, ткат, литс, _deke_,
   {{0xb6030181,0xb60600cb,0x69c901ee,0xfe7101f3}},	//   čšin, lešć, _saee, _نگر_,
   {{0x22490113,0x201300bd,0xb05b02c3,0xa01b01f9}},	//   _khak_, _imxi_, sväs, kröz,
   {{0x38a930ce,0xe9ff00de,0x98bf0090,0x614901d3}},	//   túr_, _thận_, _jfuħ_, _tūlī,
   {{0x69cb0eb3,0x491100c3,0x28f8004d,0xf09f00ee}},	//   rdge, _देशो_, нець_, nuà_,
   {{0xe7390a95,0x673a084e,0x00000000,0x00000000}},	//   мел_, _bytj, --, --,
   {{0x38a90037,0x3d150096,0x2001009c,0xa01b042c}},	//   súr_, _नेते_, _mlhi_, rsöh,
   {{0xa91d1cae,0x660d0220,0xb6060880,0x9b581c47}},	//   _vežb, ďako, ješć, _чист_,
   {{0xdb1c03a3,0xf1bf0220,0x00000000,0x00000000}},	//   _parç, deá_, --, --,
   {{0x75f50074,0x00000000,0x00000000,0x00000000}},	//   _názv, --, --, --,
   {{0xf1dd0454,0xfbd200a1,0x41dd0403,0x56941894}},	//   यांन, בתי_, यांस, _бахт,
   {{0x224914b1,0x151530cf,0xbddb03a9,0x7a380103}},	//   _chak_, _идея, _dhèk, sítv,
   {{0xd9e30081,0x2d8230d0,0x28c70592,0x22490113}},	//   _মতাম, _reke_, लिटि, _dhak_,
   {{0x35a7000f,0x2d8230d1,0x224901c8,0x25bf044c}},	//   _गाड़, _seke_, _ehak_, leul_,
   {{0x2d8230d2,0x8e8300ae,0x0eb9163d,0x2be0052c}},	//   _peke_, игре, нуты_, नासा,
   {{0xf1bf00e3,0x25bf30d3,0x395f009c,0x00000000}},	//   ceá_, neul_, _ngus_, --,
   {{0xb05b0149,0x25b201e8,0xd24f0037,0xad9b0031}},	// [25c0] rvär, _öyle_, _بني_, _slúc,
   {{0x395f1884,0x0e661c66,0xb05b30d4,0x2d820185}},	//   _agus_, _икон, svär, _weke_,
   {{0x201830d5,0x395f02e7,0x91a00174,0xaca40174}},	//   miri_, _bgus_, _ghị_, _ihọr,
   {{0x201830d6,0xb33c03e5,0x75f50094,0x60d630d7}},	//   liri_, ngħa, _zázv, _krym,
   {{0x25bf30d8,0x8b6603ef,0x18671510,0xf1aa0ff9}},	//   deul_, _لازم, вачи_, _कानन,
   {{0xe9ff0028,0xf1e40251,0x6d4628df,0x201830d9}},	//   _phản_, गाड़_, _izka, niri_,
   {{0xcac72f17,0x2ca00cad,0x1ae330da,0x25bf020a}},	//   _игре_, luid_, _корм, feul_,
   {{0x201830db,0x7c3e19ce,0x25bf30dc,0xbddb0154}},	//   hiri_, llpr, geul_, _chèh,
   {{0x201830dd,0x69d3025b,0xb606077e,0x2ca030de}},	//   kiri_, ádež, vešć, nuid_,
   {{0x201830df,0xaca400ac,0x9f5a00ee,0xe9ff0023}},	//   jiri_, _nhọr, _alpí_, _thản_,
   {{0x20181a8e,0x25bf01ec,0x2bf70266,0xdd2f02c6}},	//   diri_, beul_, דמין_, měťo,
   {{0x7a380b0b,0xaca40294,0xdb150146,0x2ca0007a}},	//   pítu, _ahọr, _nazý, kuid_,
   {{0x201830e0,0xb1130134,0x3eba30e1,0xf1bf0076}},	//   firi_, wụba, _appt_, reá_,
   {{0xdb17001f,0xaca406c0,0x6602063d,0x3eba0085}},	//   nexã, _chọr, _hlok, _bppt_,
   {{0x660230e2,0xbe8817b9,0x6d460a00,0x0d67008f}},	//   _klok, ксте_, _azka, възм,
   {{0x443e30e3,0xa91d30a0,0x60d600dd,0xd35700a1}},	//   llt_, _leža, _frym, _בשוק_,
   {{0x20181e59,0x60d61070,0xf09f0036,0xdb170072}},	// [25d0] biri_, _grym, quà_, rexí,
   {{0xaca40294,0x25bf00d3,0x61fd0eb3,0x75f50103}},	//   _ghọr, zeul_, lksl, _házt,
   {{0x443e30e4,0x660230e5,0xfb152c9a,0xf1aa099d}},	//   ilt_, _olok, دواج, _कामन,
   {{0x443e02e2,0x7c3e05c2,0x321930e6,0x629a007b}},	//   hlt_, alpr, nisy_, irto,
   {{0x69342223,0xa91d30e7,0x3f870131,0xe9d00037}},	//   анцу, _beža, _ônus_, تغل_,
   {{0x660230e8,0x02a2026e,0x7e650085,0x16a92a72}},	//   _alok, _akọọ, _kuhp, евки_,
   {{0x7a380068,0x2be00c9c,0x25bf00ae,0xe7362b49}},	//   gíts, नारा, teul_, леш_,
   {{0x201830e9,0xe51400b7,0xdb1e30ea,0x280900c6}},	//   ziri_, _तेहि_, depè, _šunį_,
   {{0x893706fa,0x644a00e3,0x629a30eb,0x20180198}},	//   _شعرا, _bhfi, erto, yiri_,
   {{0x660230ec,0x3fce0081,0x25bf00ae,0xbddb009c}},	//   _elok, _রক্ষ, seul_, _dhèi,
   {{0x660230ed,0x7a382c74,0x201830ee,0xb33c003d}},	//   _flok, mítr, viri_, tgħa,
   {{0x201830ef,0x443e30f0,0x7524215a,0x673c00f3}},	//   wiri_, alt_, _žize, _ørja,
   {{0x25e006ae,0x201830f1,0x657b0d2c,0x629a0381}},	//   कारी_, tiri_, mbuh, arto,
   {{0x5ebb00c7,0x6fde00a5,0x049200e3,0xf1dd030b}},	//   _উপজে, माइं, _الوح, याउन,
   {{0x201830f2,0x657b08a9,0x44270063,0x539a00ca}},	//   riri_, obuh, _ijn_, _טיסו,
   {{0x201830f3,0x60d630f4,0x657b0124,0x2ca000aa}},	//   siri_, _trym, nbuh, tuid_,
   {{0x271f0782,0x201830f5,0x248d30f6,0xfce318c6}},	// [25e0] यपुर_, piri_, nsem_, бото,
   {{0x2018023b,0x6d46033d,0xdb150072,0x207b006e}},	//   qiri_, _vzka, _nazó, _ראיא,
   {{0x657b06a8,0xa91d2a4e,0x9eaa2742,0xda650037}},	//   kbuh, _reža, _явна_, لاني,
   {{0x3f8a30f7,0x248d30f8,0x533600c1,0x6e9b00ca}},	//   labu_, ksem_, אנען_, _אבטח,
   {{0x443e30f9,0x81ce0081,0xddc40034,0x461400cd}},	//   ylt_, রাপ_, rmiń, یوتر,
   {{0x67d430fa,0x660230fb,0x57b301b6,0x3f8a024a}},	//   року, _slok, йбіт, nabu_,
   {{0x660230fc,0x25e000c0,0x7bce00f9,0xfc0330fd}},	//   _plok, काली_, _iabu, _упро,
   {{0x7bce30fe,0x442700e7,0x3f8a30ff,0x629a0220}},	//   _habu, _ajn_, habu_, vrto,
   {{0xa91d25d1,0x7a383100,0x248d0103,0x6602112f}},	//   _teža, síts, gsem_, _vlok,
   {{0x443e3101,0x7bce3102,0x78a230cf,0x3f8a0239}},	//   ult_, _jabu, muov, jabu_,
   {{0x7bce3103,0x81ce0033,0x3f85003e,0x629a3104}},	//   _mabu, রান_, ðlum_, urto,
   {{0x7bce3105,0x66020ec4,0xd7e20096,0x25e00096}},	//   _labu, _ulok, पावच, काळी_,
   {{0x78a20451,0x61fd3106,0x44f70214,0x06bc0033}},	//   nuov, rksl, _مروج_, _অপটি,
   {{0x7bce3107,0xbcfb0072,0xdb1c0065,0x629a033b}},	//   _nabu, _ofér, _darú, prto,
   {{0x32191670,0xa91d3108,0x78a211f1,0x629c0094}},	//   pisy_, _nežn, huov, árod,
   {{0x7bce3109,0x2bc7009f,0x78a2310a,0x82150018}},	//   _aabu, रजभा, kuov, _خوبص,
   {{0x3f8a068d,0x7bce310b,0x69c21484,0xbcfb310c}},	// [25f0] babu_, _babu, deoe, _afér,
   {{0x26e402ed,0xa91d0181,0x5d54139c,0x3f150120}},	//   _कपूर_, _bežn, скут, _вдос,
   {{0xdb15310d,0x5e470037,0x7bce310e,0xdce401d3}},	//   _razó, _مضحك, _dabu, rciā,
   {{0x65620415,0x248d310f,0xa91d033b,0xdb150143}},	//   _ngoh, ysem_, _dežn, _sazó,
   {{0xa3d4058f,0x225902c6,0xdb1c0139,0x00000000}},	//   हया_, írky_, _marù, --,
   {{0xb8cd0abe,0x248d0087,0x96950291,0xa69519e8}},	//   _कम_, vsem_, ариш, ариј,
   {{0x69c21cab,0x00000000,0x00000000,0x00000000}},	//   beoe, --, --, --,
   {{0x7bce3110,0x6b870a39,0x78a21054,0x5b14062a}},	//   _zabu, _hejg, buov, _умст,
   {{0x81ce0f71,0xccf20130,0xdb0501bf,0x7bce2127}},	//   রাম_, ַכט_, gehö, _yabu,
   {{0x3ea300dd,0x798b3111,0x248d3112,0x00000000}},	//   kujt_, lagw, rsem_, --,
   {{0x248d3113,0xfbcf0081,0x657b06a8,0x4226017b}},	//   ssem_, রাপত, pbuh, идов,
   {{0xdb053114,0xc0490341,0xc10600e3,0x22161c16}},	//   behö, _חז_, لوجي, рфор,
   {{0x3f8a3115,0x7d0d09ac,0xa91d00e8,0x00000000}},	//   tabu_, jzas, _mežo, --,
   {{0x2bd504a9,0x661b013f,0x8fa600c9,0x660903e5}},	//   _डोला, liuk, јаве, lhek,
   {{0x7bce3116,0x539a00a1,0x3f8a3117,0xa22500cd}},	//   _rabu, _סיקו, rabu_, _گروه,
   {{0x7bce3118,0x3f8a0051,0x75f50146,0x661b0138}},	//   _sabu, sabu_, _zázr, niuk,
   {{0xdca63119,0x7bce311a,0xed5a00c9,0x6b87003d}},	// [2600] рази, _pabu, тоа_, _bejg,
   {{0x9f4c2897,0x7bce311b,0x4f96311c,0x6441311d}},	//   ódó_, _qabu, _триу, nlli,
   {{0xbf9b0105,0x6441311e,0x661b311f,0xdee63120}},	//   _בייש, illi, kiuk, _тони,
   {{0x7bce3121,0xbcfb0018,0xe8fa3122,0xdca6168c}},	//   _wabu, _igén, кле_, _ками,
   {{0x7fe90f03,0xe7e21843,0x7d0d007f,0x660900d1}},	//   _شریف_, पालप, czas, dhek,
   {{0xdb17002b,0x4813004d,0x9b8901f3,0x69c201c8}},	//   sexá, оміс, _مخفف_, seoe,
   {{0xddc400d9,0x29003123,0x2cb2057a,0x798b3124}},	//   rmiņ, šia_, ltyd_, bagw,
   {{0x64410084,0xa01b3125,0x88810068,0x75fc0103}},	//   elli, nsör, _کیون, _kézi,
   {{0x75fc0154,0x07a6232c,0x186a004d,0x479602d1}},	//   _jézi, _вазн, _рази_, _نجاس,
   {{0xe9ff00ef,0xf3661e0e,0x690803a3,0x64410124}},	//   _phần_, штин, ırdı, glli,
   {{0x66090060,0x7bd900c1,0xbcfb00d1,0x53343126}},	//   bhek, אַרק, _ngén, сент,
   {{0x9f5800e3,0x66090051,0x64413127,0xd5b0110a}},	//   bhrú_, chek, alli, _رفت_,
   {{0xbcfb104d,0x6002016d,0xba570266,0x00000000}},	//   _agén, _cômo, יסטו_, --,
   {{0xe9ff0028,0x20050088,0x3317001c,0xfe73097d}},	//   _thần_, óli_, ازید_, قدر_,
   {{0x543900c1,0x798b3128,0x3a260629,0x22940190}},	//   _געװא, yagw, knop_, _البس,
   {{0x2cb20313,0x443c00c4,0x75fc020d,0xb7fe0033}},	//   ftyd_, _hkv_, _bézi, ্চিত_,
   {{0x6b87023b,0x7c870226,0x2cb20f5a,0x00000000}},	// [2610] _pejg, рубе, gtyd_, --,
   {{0x60cd3129,0x81ce0081,0x3ea30052,0x661b00c6}},	//   _isam, রাণ_, pujt_, ziuk,
   {{0x2c7d0065,0xa91d007e,0xdce70555,0xf09f015e}},	//   _bádò_, _pežo, ılıd, lrà_,
   {{0xa2d722a0,0x60cd312a,0x00000000,0x00000000}},	//   यित्, _ksam, --, --,
   {{0x98c70f99,0xe9ff0019,0x6441312b,0x49110034}},	//   рсел, _nhấn_, ylli, _देखो_,
   {{0x60cd0051,0x8d5a00ca,0xf09f312c,0x00000000}},	//   _msam, _תכשי, irà_, --,
   {{0x6609312d,0xa91d015c,0xfeca006e,0x661b0683}},	//   thek, _težo, ָמפּ, tiuk,
   {{0xc485312e,0x5bc70e50,0x9f580037,0x7bc5312f}},	//   блик, _रघुव, thrú_, lehu,
   {{0x999f025b,0xe9ff00de,0x64413130,0x661b02e3}},	//   _chuť_, _chấn_, tlli, riuk,
   {{0x75f50cda,0xf09f3131,0x66093132,0xf7700037}},	//   _vázq, drà_, shek, _قام_,
   {{0xd7f82a6a,0x60cd3133,0x7c220257,0xf09f00e5}},	//   _тут_, _asam, éori, erà_,
   {{0x7bc5023b,0x60cd0063,0x64413134,0xf09f00ee}},	//   hehu, _bsam, slli, frà_,
   {{0x7bc53135,0x79893136,0x60cd3137,0xf09f00ee}},	//   kehu, _meew, _csam, grà_,
   {{0x438500e3,0x183500c1,0x79893138,0x81ce0081}},	//   _الثق, מאָל_, _leew, রাধ_,
   {{0x60cd3139,0xf09f0428,0x7bc5313a,0x249f29fb}},	//   _esam, arà_, dehu, lrum_,
   {{0x249f313b,0x4d66313c,0xf09f0428,0x629c00e8}},	//   orum_, скав, brà_, šroc,
   {{0x61e4313d,0x1b150081,0x4d4a0291,0xa01b0212}},	// [2620] _inil, _তুলে_, упан_, rsör,
   {{0xf1bf00e3,0x7bc5313e,0x2cb2057a,0xac0a00ae}},	//   nnán_, gehu, rtyd_, ынза_,
   {{0x61e407ac,0x249f07e7,0x34c406ec,0x79890361}},	//   _knil, hrum_, _वन्द, _beew,
   {{0x61f602ac,0x994a0037,0xbddb00cd,0x9b96015a}},	//   _joyl, هلال_, _dhès, _گلست,
   {{0x2d80313f,0x98a33140,0x249f3141,0x60cd3142}},	//   mbie_, зиче, jrum_, _xsam,
   {{0x249f3143,0xdb1e301f,0x2bb700b6,0x7bc53144}},	//   drum_, lepí, _věcí_, cehu,
   {{0xfaa33145,0x61e43146,0xf1760139,0x6674010d}},	//   _наро, _onil, _abọ́_, زگار,
   {{0x2be014e5,0xe5c60084,0xe9ff00de,0x443c003e}},	//   नाका, сско, _phấn_, _skv_,
   {{0x8cdb0179,0x2a6a0063,0x32ee00a7,0x249f0596}},	//   नियो, _hubb_, məyi_, grum_,
   {{0x61e43147,0xf09f008f,0x2ca03148,0x79893149}},	//   _anil, vrà_, irid_, _zeew,
   {{0x61f6314a,0x60cd0172,0x7989083e,0x00000000}},	//   _boyl, _ssam, _yeew, --,
   {{0x64a6314b,0xf09f314c,0x201a0451,0x02a8009f}},	//   _гада, trà_, _ampi_, _कमीन,
   {{0x41aa314d,0x44fa00b9,0x2ca00063,0x7bc50239}},	//   _कारस, _حراج_, jrid_, yehu,
   {{0x3e6e000d,0xf09f314e,0x61e40150,0x2ca00133}},	//   _být_, rrà_, _enil, drid_,
   {{0xa3d5030b,0xa3c5314f,0x7bc500f2,0x32b70076}},	//   ाएर_, उजर_, vehu, _هدية_,
   {{0x60cd3150,0xf09f0451,0xa91d033b,0x61e43151}},	//   _tsam, prà_, _dežj, _gnil,
   {{0x3209041c,0x7bc53152,0x798901ee,0x00000000}},	// [2630] _ilay_, tehu, _reew, --,
   {{0x7b673153,0xbddb3154,0x79893155,0xdcfd00c6}},	//   стае, _chèr, _seew, _nesą,
   {{0x2ca0007a,0xb9950f36,0xbddb01dc,0x998c00c4}},	//   arid_, قلاب, _dhèr, _šoša_,
   {{0x80cc0081,0xdb1c003e,0x249f3156,0x00000000}},	//   ামর্, _farþ, yrum_, --,
   {{0xb05b0220,0x7bc53157,0x75fc0103,0x32090350}},	//   dväz, pehu, _jézu, _mlay_,
   {{0x249f3158,0xbddb00fd,0x4cba006e,0x86990d81}},	//   vrum_, _thès, _דזשו, атит_,
   {{0x41aa0eeb,0x2d8b3159,0x3209008b,0x59d4058f}},	//   _कालस, _kece_, _olay_, _ठोकर,
   {{0xf1d9000f,0xb05b01bf,0x32ee00a7,0xa91d04ad}},	//   _बोलन, swäh, cəyi_, _ježk,
   {{0xdb1e00d3,0x2d8b03e3,0xc7ab001c,0x00000000}},	//   cepâ, _mece_, _مدال_, --,
   {{0x3209315a,0x61e4315b,0x249f315c,0x2d8b0218}},	//   _alay_, _snil, rrum_, _lece_,
   {{0xf1bf315d,0x320900ee,0x81ce0033,0x249f315e}},	//   rnán_, _blay_, রাস_, srum_,
   {{0x2d8b08a9,0xcad600a1,0x201a061d,0xb1130174}},	//   _nece_, קורת_, _smpi_, pụla,
   {{0x248601c2,0xa06a315f,0x628e0103,0x05743160}},	//   _gwom_, рага_, ábor, _راند,
   {{0xee3f0220,0x3a2d0357,0x6b503161,0x00000000}},	//   _aký_, _ljep_, _jógí, --,
   {{0x32090154,0x0f040285,0x24860381,0x9e053162}},	//   _flay_, रनेस_, _zwom_, रसंघ_,
   {{0x3d1505a7,0x2d8b3163,0x2bac00b6,0x00000000}},	//   _नइखे_, _cece_, _चाहा, --,
   {{0x2d8b0291,0xbddb0257,0xee37084c,0xdb1e0669}},	// [2640] _dece_, _chèq, іну_, repí,
   {{0xa91d033b,0x41aa0557,0xeb9a2766,0x2ca0058f}},	//   _težj, _काँस, риж_, rrid_,
   {{0x2d8b00e5,0xf1bf0103,0x6ac60867,0x32ee013c}},	//   _fece_, knál_, تقام, təyi_,
   {{0xa3d50067,0xfce63164,0x3a3f0899,0x2d8b0587}},	//   ाएँ_, _домо, _ckup_, _gece_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d8b00d3,0xec341ac9,0x7aea02c3,0xdb1e0231}},	//   _zece_, _روزگ, äfts, repâ,
   {{0x491a000d,0x6fad000f,0xdb1c00dd,0x02a80852}},	//   _मेरो_, _जासू, _mbrë, _कमेन,
   {{0x16370080,0x7ae10068,0xd5b72983,0xf1bf15bf}},	//   يسية_, _álta, ось_, gnál_,
   {{0xa3d50067,0x79823165,0x6fca009d,0x69dd0143}},	//   ाएं_, mbow, ाजां, _ósea,
   {{0x22400018,0x25da09a1,0x00000000,0x00000000}},	//   _akik_, _खोरी_, --, --,
   {{0x32093166,0xe73a004d,0x2a64024a,0x48f400b6}},	//   _play_, _теж_, _kimb_, ्नको_,
   {{0x60100222,0x80ac0cce,0x78a20146,0x00000000}},	//   _jämf, _जमशे, orov, --,
   {{0x2d8b3167,0xf9930796,0xd25808a1,0x76900139}},	//   _rece_, ורר_, юць_, _fóyá,
   {{0xb4d60d88,0x600b00aa,0x2d8b007e,0x78a200c6}},	//   ाटी_, _sümb, _sece_, irov,
   {{0x28d1000c,0x2d8b00d4,0x657900fd,0x78a200e7}},	//   _दैनि, _pece_, _éché, hrov,
   {{0xdb1c02e2,0xb5fc0090,0x31353168,0x12770076}},	//   _darü, _buġi, _нейр, _بحوث_,
   {{0x2d8b04a3,0x31690018,0x69c6003e,0x78a20b14}},	// [2650] _vece_, _igaz_, _ókey, jrov,
   {{0xdb1c3169,0x78a2316a,0x26de316b,0x9f580088}},	//   _naró, drov, _orto_, skrá_,
   {{0x3f91316c,0xa91d02dd,0x81ce0081,0x78a2316d}},	//   mazu_, _težk, রার_, erov,
   {{0x3f91005f,0x2a642fc5,0xdb1c034f,0x78a200d4}},	//   lazu_, _cimb_, _aaró, frov,
   {{0x78a2025b,0xdb1c27d7,0xdb150161,0x26de316e}},	//   grov, _baró, _razõ, _arto_,
   {{0xf77104f4,0xdb1c03be,0xa3da17ff,0xa91d0954}},	//   رات_, _caró, _ढोल_, _ježi,
   {{0x78a200d4,0x1ab41bec,0x7bd5020a,0x7982010a}},	//   arov, _обря, _iazu, bbow,
   {{0xc4852dd1,0xa91d316f,0xdce40034,0x7bd53170}},	//   плик, _leži, ecię, _hazu,
   {{0x629c08a8,0xf1bf3171,0xdb1c3172,0x442e007e}},	//   áron, rnál_, _abrè, _bjf_,
   {{0xa91d3173,0xf1bf0103,0x22403174,0x4374004d}},	//   _neži, snál_, _skik_, муют,
   {{0x7bd53175,0x09be0033,0xb1130134,0x3f910634}},	//   _mazu, _ইফতা, bụka, dazu_,
   {{0xdb1c0034,0x06c30081,0xad9b3176,0x98bf007f}},	//   _zaró, ্মদি, _flúi, _czuć_,
   {{0xa91d21b8,0x386d01c2,0xad9b0037,0x799b0113}},	//   _beži, _juer_, _glúi, _mduw,
   {{0x316901ff,0xdb1c05aa,0x25ad00b7,0x386d3177}},	//   _egaz_, _marò, lgel_, _muer_,
   {{0xdee33178,0x6d4f034f,0x25ad00f0,0x7982007f}},	//   нори, _azca, ogel_, ybow,
   {{0x799b00bf,0x386d0185,0x75fc0113,0xe9ff00fe}},	//   _nduw, _ouer_, _hézr, _thẹn_,
   {{0x7bd53179,0x386d01c2,0xed57001f,0x602600ae}},	// [2660] _bazu, _nuer_, зот_, _ндиа,
   {{0x7bd50012,0x799b317a,0x2a64061d,0x60c40169}},	//   _cazu, _aduw, _simb_, _ipim,
   {{0xf1bf0146,0x386d317b,0x7bd5317c,0xd9100504}},	//   znám_, _auer_, _dazu, چیز_,
   {{0x38c8010d,0xdb1c015e,0x25ad007e,0x6abb0995}},	//   قاتی_, _barò, jgel_, _ćuft,
   {{0xdb1c317d,0x2d92317e,0xdce40034,0x386d2307}},	//   _paró, maye_, ycię, _cuer_,
   {{0x2d92317f,0x25ad3180,0x0ee0055c,0x386d0c89}},	//   laye_, egel_, _पछाड, _duer_,
   {{0xdb1c0610,0x2a640063,0x386d0364,0xb05b0212}},	//   _varó, _timb_, _euer_, rväx,
   {{0x78a23181,0x25ad3182,0x386d0364,0x2d923183}},	//   prov, ggel_, _fuer_, naye_,
   {{0x7bd53184,0xb4d60efd,0xb05b0212,0x7e663185}},	//   _yazu, ाटे_, pväx, _mikp,
   {{0x2d923186,0xd77600e3,0x6d4600dc,0xb8650037}},	//   haye_, _رائع, _myka, _قالو,
   {{0x600b01d4,0x60c43187,0x26de028d,0x2d923188}},	//   _nüma, _apim, _urto_, kaye_,
   {{0xb05b02db,0xa91d0141,0x00000000,0x00000000}},	//   hwät, _seži, --, --,
   {{0x2d923189,0x463b006e,0x3f91318a,0x6b9c0141}},	//   daye_, _פעדע, tazu_, _odrg,
   {{0x545300d6,0x7c3e00e7,0x644f1695,0x00000000}},	//   _звіт, jopr, ïcit, --,
   {{0x645a0102,0x69c00181,0x3f9106e9,0xa91d318b}},	//   mmti, _obme, razu_, _veži,
   {{0x443e2ef9,0x2d92318c,0x7e660063,0x6d46057a}},	//   lot_, gaye_, _cikp, _byka,
   {{0x423809c1,0xa91d02e6,0x7bd5318d,0x443e318e}},	// [2670] _מנהל_, _teži, _pazu, oot_,
   {{0x443e318f,0xf09209c1,0x442c3190,0x69c00364}},	//   not_, _שני_, nnd_, _abme,
   {{0x2d923191,0x7bd5002d,0x386d3192,0x600b013c}},	//   baye_, _vazu, _suer_, _güma,
   {{0xa2a40557,0x7bd53193,0x2d923194,0xdb1c3195}},	//   _किन्, _wazu, caye_, _parò,
   {{0x443e3196,0xddc40dea,0x386d0396,0x89370080}},	//   kot_, lmiş, _quer_, أعضا,
   {{0xd3660080,0x443e0029,0x7642283d,0x7c3e0451}},	//   _له_, jot_, _akoy, copr,
   {{0x443e3197,0x6e2d3198,0xddc40587,0xc1740022}},	//   dot_, onab, nmiş, _haɗe_,
   {{0x6e2d0283,0x644819fb,0x442c3199,0x386d00fd}},	//   nnab, eldi, end_, _tuer_,
   {{0x6298008f,0x442c0088,0x443e319a,0xdb1c003e}},	//   _avvo, fnd_, fot_, _harð,
   {{0x443e319b,0x69d927a9,0x69cb319c,0x25ad00c4}},	//   got_, ldwe, lege, sgel_,
   {{0x81d70081,0xdb1c0088,0x2d92006d,0xd1ca00c2}},	//   সান_, _jarð, yaye_, олне_,
   {{0x69d9319d,0x64480a00,0x442c319e,0x7ae300c2}},	//   ndwe, aldi, and_, änty,
   {{0x2004001f,0x5155319f,0x6e2d0150,0x628a0090}},	//   êmio_, етру, dnab, _ewfo,
   {{0x443e31a0,0x2d9231a1,0x200c31a2,0x81ce0081}},	//   cot_, waye_, ódi_, রাই_,
   {{0x7c3e0ca7,0x7f430084,0x2d9231a3,0x69cb31a4}},	//   vopr, верж, taye_, kege,
   {{0x6e2d31a5,0x69cb31a6,0x764931a7,0x6b8e00bd}},	//   gnab, jege, nley, _sebg,
   {{0x7c3e31a8,0x2d9231a9,0x69cb31aa,0x60c431ab}},	// [2680] topr, raye_, dege, _upim,
   {{0x2d9231ac,0xc1740022,0x6d460146,0xa91d007e}},	//   saye_, _daɗe_, _vyka, _ježu,
   {{0x764931ad,0x6281022b,0x600b007a,0x6d460034}},	//   kley, nplo, _kümn, _wyka,
   {{0x69cb31ae,0x6b8e0a00,0x443e31af,0xbcfb00d1}},	//   gege, _webg, zot_, _ngéw,
   {{0x443e31b0,0x442c0088,0x64480bc6,0x2fc100dc}},	//   yot_, ynd_, yldi, _ybhg_,
   {{0x6e2431b1,0x656b028d,0x93bc020a,0x8cdb19af}},	//   liib, _aggh, lnăv, निरो,
   {{0x443e00d2,0xdb1c0088,0x7d0431b2,0xb4d60179}},	//   vot_, _garð, lyis, ाट्_,
   {{0xceb30054,0xd49a0114,0x442c31b3,0xb05b0364}},	//   דיה_, оро_, wnd_, nwär,
   {{0x443e31b4,0x7d040863,0x64a3001f,0x26c509a1}},	//   tot_, nyis, вања, _eplo_,
   {{0x442c0054,0x9f5a0052,0xb05b042c,0x765b010a}},	//   und_, _copë_, hwär, amuy,
   {{0x443e1ee8,0x442c31b5,0x271c0033,0xd5af31b6}},	//   rot_, rnd_, _পুরো_, _ис_,
   {{0x443e31b7,0x20ca0455,0x7d040084,0x84ea06cf}},	//   sot_, िबंध, kyis, _وفاق_,
   {{0xe8e00134,0x6e240188,0xdb1e1d4b,0x6281084e}},	//   daịs_, diib, lepä, aplo,
   {{0xdb1e0161,0xa294258b,0xc17403e3,0xddc4008b}},	//   cepç, _закі, _raɗe_, tmiş,
   {{0x69cb31b8,0x81d70033,0xb05b042c,0x15f20386}},	//   yege, সাব_, fwär, _आचार_,
   {{0xc33300a1,0xddc4008e,0x764031b9,0x600b00aa}},	//   _שוק_, rmiş, nomy, _gümn,
   {{0x69cb31ba,0xd90431bb,0xde6400e5,0xdc550c37}},	// [2690] vege, _ئی_, търп, евањ,
   {{0x69cb31bc,0x9f89003e,0x7649020e,0xb05b042c}},	//   wege, _góðu_, zley, rwäs,
   {{0x69cb31bd,0x764031be,0x764901e8,0xe0df0036}},	//   tege, komy, yley, lvò_,
   {{0xdb1c0088,0x764000a5,0xdddd007f,0xd9f91147}},	//   _varð, jomy, _wisł, янец_,
   {{0xf1c100b7,0x69d9000b,0x7d1600a5,0x5d7a006e}},	//   ष्यन, rdwe, czys, _מארק,
   {{0x78ab0a9f,0x9f5a022b,0x3e7505e8,0x00000000}},	//   rugv, _bopè_, _kåt_, --,
   {{0x764931bf,0x69cb2774,0x00000000,0x00000000}},	//   tley, pege, --, --,
   {{0xb8d500c7,0x6ec2009f,0xad9b31c0,0x53d700aa}},	//   _জন_, _लहसु, _glút, _भोजश,
   {{0x3e7531c1,0x764931c2,0xe7e00714,0xf1bf0076}},	//   _låt_, rley, _गोवा_, dfá_,
   {{0x764931c3,0x628131c4,0x3707246b,0xa93400d3}},	//   sley, tplo, _очев, _реуш,
   {{0x3e750149,0x76490fa0,0xc7d600ca,0x0ece007f}},	//   _nåt_, pley, _רועי_, _हैंड,
   {{0x6e24008a,0x628131c5,0x7d16007f,0x76400113}},	//   xiib, rplo, yzys, comy,
   {{0xe8e00174,0x70ca00b6,0x00000000,0x00000000}},	//   vaịs_, िबेल, --, --,
   {{0x66091816,0x3e750ec9,0x25bf21d8,0x62810e37}},	//   lkek, _båt_, lful_, pplo,
   {{0x6e240283,0x8464008f,0xcee70c3f,0x00000000}},	//   tiib, _ръце, ндре_, --,
   {{0x7d0402fd,0x644131c6,0xee3a00d6,0xa2a40403}},	//   tyis, loli, їна_, _कित्,
   {{0x44251519,0xdca30ba4,0xa3b6000d,0x25bf31c7}},	// [26a0] oil_, лати, ङ्क_, iful_,
   {{0x7d160d1b,0x442531c8,0x25bf31c9,0x41c1030b}},	//   rzys, nil_, hful_, ष्ठस,
   {{0xa3b702e8,0x387f210f,0xad9b31ca,0x93bc00ae}},	//   _छान_, _atur_, _clús, mnăt,
   {{0x442513b5,0xaca40134,0x13d80033,0x81ce0033}},	//   hil_, _ajụr, তায়, রাক_,
   {{0x644131cb,0x25bf0178,0x76400169,0x00000000}},	//   koli, dful_, vomy, --,
   {{0x442531cc,0x644131cd,0xf09300ca,0x6609168b}},	//   jil_, joli, ננו_, ekek,
   {{0x644131ce,0x0cd0143d,0xa3b3034c,0x764031cf}},	//   doli, _हनुम, टलन_, tomy,
   {{0xe7e00789,0xdb1e00aa,0x442531d0,0x9f5a020d}},	//   _गोरा_, repä, eil_, _copé_,
   {{0x644131d1,0xddde00d9,0xf8d4121d,0xdb1e0302}},	//   foli, _atpū, _धनिय, sepä,
   {{0x644131d2,0x600b008e,0x76400435,0xdcef01d3}},	//   goli, _cüml, somy, _secī,
   {{0xa3b6030b,0xdb1c31d3,0xb05b042c,0x46a60a3a}},	//   ङ्ग_, _obrí, ltäg, _чаев,
   {{0x44250a1b,0x660931d4,0xad9b00b3,0x3e750537}},	//   ail_, ckek, _llúr, _råt_,
   {{0xc05b00d6,0x29060a4b,0x62950094,0xf1bf0076}},	//   зів_, nyoa_, ázor, rfá_,
   {{0x442531d5,0x644131d6,0x20d60c27,0xdb1c24c7}},	//   cil_, coli, džić_, _abrí,
   {{0x9f3400f3,0x80c40081,0x28e231d7,0xdd95013f}},	//   гері, শিষ্, पिडि, кавы,
   {{0xe7e7009f,0x3e750b85,0x629a256f,0x00000000}},	//   _टोना_, _våt_, msto, --,
   {{0x629a1b1a,0x61ed31d8,0xd2f80018,0x905531d9}},	// [26b0] lsto, _inal, _رکھا_, _ивиц,
   {{0x600b31da,0x61ed1d89,0x629a0dd8,0x00000000}},	//   _kümm, _hnal, osto, --,
   {{0xd01100fb,0x61ed31db,0xc1740044,0xe9d90034}},	//   _ملک_, _knal, _haɗa_, _paź_,
   {{0x644131dc,0xdbd70fc4,0x629a1ff7,0xc1740d2a}},	//   zoli, _sääs, isto, _kaɗa_,
   {{0xdbd7069d,0x442531dd,0x644131de,0xfd96028c}},	//   _pääs, yil_, yoli, _בדרך_,
   {{0x442501d4,0x2ca931df,0x64410415,0x25bf0158}},	//   xil_, mrad_, xoli, wful_,
   {{0x629a00e9,0x25bf31e0,0x61ed31e1,0x442531e2}},	//   jsto, tful_, _onal, vil_,
   {{0x442531e3,0x78a40039,0x644131e4,0x2ca90a02}},	//   wil_, šiva, woli, orad_,
   {{0x629a0181,0x6fb200a5,0xc1740d2a,0x25bf31e5}},	//   esto, _जालं, _naɗa_, rful_,
   {{0x69db02a7,0x629a31e6,0x2b9c030b,0x13090084}},	//   _haue, fsto, mácí_, дной_,
   {{0x15b901b6,0x629a31e7,0x2ca90146,0x69db31e8}},	//   _жылы_, gsto, hrad_, _kaue,
   {{0x442531e9,0xe5e5001c,0x412a004d,0xdb17002b}},	//   sil_, _جزئی, домо_, lexó,
   {{0x442531ea,0x66060018,0x224231eb,0x69db0364}},	//   pil_, ökke, rokk_, _maue,
   {{0x7fd501ce,0x61ed31ec,0x442531ed,0xc1740022}},	//   лісі, _enal, qil_, _daɗa_,
   {{0x629a24db,0xa06731ee,0x539a00ca,0x7db631ef}},	//   csto, тара_, _חיצו, ксац,
   {{0x645801e5,0xf1bf0328,0xc1740d2a,0x69db0827}},	//   _zhvi, lián_, _faɗa_, _naue,
   {{0x2ca92461,0xdd8f06fa,0x8e5500d6,0x6b970072}},	// [26c0] grad_, زول_, утрі, faxg,
   {{0x61ed31f0,0x6286077e,0x81ce0033,0xaf0605da}},	//   _znal, ćkov, রাও_, _апол,
   {{0x3f98006d,0x69db01bf,0x93bc020a,0xbf9b2252}},	//   maru_, _baue, onăr, _קיטש,
   {{0x69db2f7c,0x2ca931f1,0x3ced015c,0xc1740d2a}},	//   _caue, brad_, _ševe_, _yaɗa_,
   {{0x69db23f2,0xa9671111,0xd7fa00ae,0x629a31f2}},	//   _daue, вица_, дуй_, zsto,
   {{0xbcfb0068,0x25da1592,0x629a31f3,0xdb210031}},	//   _egés, _खोजी_, ysto, štát,
   {{0x48ee0067,0x59dd31f4,0xf1bf0094,0x7bdc07bc}},	//   _आपको_, _नोकर, onát_, _iaru,
   {{0x7bdc31f5,0xe5c631f6,0x765931f7,0x3f9831f8}},	//   _haru, тско, _chwy, haru_,
   {{0x260331f9,0x3f980a75,0x629a31fa,0x7bdc31fb}},	//   _años_, karu_, wsto, _karu,
   {{0x629a31fc,0x7bdc0022,0x7bde000b,0x61ed08c5}},	//   tsto, _jaru, ndpu, _snal,
   {{0x81dc0081,0x629a31fd,0xa1950b9c,0x68e201b6}},	//   ঠান_, usto, ланч, lvod,
   {{0x7bdc31fe,0x3f9331ff,0xa526020f,0xe8df00fe}},	//   _laru, _sexu_, _имед, _uyển_,
   {{0x629a3200,0xf1bf06cb,0x68e202ef,0x3f983201}},	//   ssto, bián_, nvod, faru_,
   {{0x629a0429,0x6fca0034,0xf1bf0072,0xb4be03b3}},	//   psto, ाजगं, cián_, ँझी_,
   {{0x5f943202,0x81ce0033,0xbcfb03a9,0x26030062}},	//   рист, রাজ_, _ngér, _iñor_,
   {{0x7bdc0af0,0x61ed3203,0x2ca9236c,0xdb050f05}},	//   _aaru, _unal, trad_, nghå,
   {{0x68e22461,0x7bdc08cc,0x3f983204,0x5d550950}},	// [26d0] jvod, _baru, baru_, укат,
   {{0x7bdc3205,0x600b07d1,0x69db3206,0x2ca93207}},	//   _caru, _mümk, _saue, rrad_,
   {{0xba740037,0x69db3208,0xb4ce00a3,0x68e2044c}},	//   لانت, _paue, शबु_, evod,
   {{0xc3330054,0xb05b0704,0x2ca90220,0x60100212}},	//   בוע_, städ, prad_, _jämn,
   {{0x7bdc3209,0x76590150,0x80d9320a,0x621c006e}},	//   _faru, _rhwy, मिटे, וואק,
   {{0x6010070a,0x7bdc320b,0xf1bf002b,0x2b9c02c6}},	//   _lämn, _garu, xián_, rácí_,
   {{0xaa67320c,0x8cdb0976,0xf1bf0072,0x69db10a5}},	//   _атак, निको, vián_, _taue,
   {{0x7bdc00d4,0x60100149,0xb4ce009f,0x2459020d}},	//   _zaru, _nämn, शबू_, ième_,
   {{0x7bdc320d,0x2919320e,0x58d4007b,0x2459020d}},	//   _yaru, _åsa_, _котт, hème_,
   {{0x7bdc0694,0x6b950039,0xa2a40789,0x224908d3}},	//   _xaru, _jezg, _किश्, _akak_,
   {{0x3f98320f,0xf1bf3210,0x6b953211,0xb7da00ca}},	//   varu_, rián_, _mezg, _רקעי,
   {{0x3f983212,0xa2a4201e,0x79992190,0x394d022b}},	//   waru_, _किर्, naww, _kyes_,
   {{0x93bc020a,0xdb1c00da,0x00000000,0x00000000}},	//   rnăr, _mbrá, --, --,
   {{0x70562ba0,0x799903e3,0x2a6d0364,0xdb15014b}},	//   انسا, haww, _lieb_, _eczé,
   {{0xdb1c0871,0x6da62887,0x3f983213,0x04560037}},	//   _obrá, лива, raru_, _حلوة_,
   {{0x7bdc3214,0x2bc606ed,0x22490113,0x394d037a}},	//   _saru, र्ना, _gkak_, _oyes_,
   {{0x6b953215,0x1bea0231,0x3f983216,0x629c2347}},	// [26e0] _bezg, ндаи_, paru_, árov,
   {{0x20130167,0xb05b00c2,0xdb1c033c,0xd0f700ca}},	//   _glxi_, ttäe, _abrá, _עמית_,
   {{0x7bdc3217,0x81d70081,0x09e6062a,0x2a6d0078}},	//   _varu, সার_, ложн, _bieb_,
   {{0x7bdc3218,0xe9470260,0x386c3219,0x02b6006e}},	//   _waru, گرمی, _sidr_, טלעך_,
   {{0x7bdc321a,0xa3b3009d,0x69c2321b,0x984a0219}},	//   _taru, टला_, rfoe, няка_,
   {{0xd6da321c,0xa2a4009d,0xbddb00d1,0x78a4015c}},	//   ети_, _किल्, _akèh, šivo,
   {{0x5fb2007d,0xfd500023,0x394d00ca,0xb05b02c3}},	//   _जाईल, _nghẹ, _eyes_, ltäc,
   {{0xa5bd0138,0x00000000,0x00000000,0x00000000}},	//   liųj, --, --, --,
   {{0x27ef000d,0x2018321d,0x75fc01f9,0x00000000}},	//   ální_, khri_, _kézz, --,
   {{0x63ad0044,0x1cbb006e,0xe7ae0096,0x77920d7f}},	//   _ɓang, עמיע, _घाटप, _ایثا,
   {{0xa686133d,0x2bc607ad,0xfbc60c38,0xe9ff00de}},	//   _след, र्या, र्यम, _chặn_,
   {{0x54e60dd0,0xaca4321e,0xf1bf321f,0xdb050364}},	//   _مستق, _akọr, ciál_, pfhö,
   {{0x75d30037,0x00000000,0x00000000,0x00000000}},	//   _دينا, --, --, --,
   {{0x2bc606ae,0xddd0042d,0xc17401c2,0x75fc0103}},	//   र्मा, _češk, _faɗo_, _nézz,
   {{0x6e9522ee,0xe1ff0103,0x00000000,0x00000000}},	//   рибу, tmód_, --, --,
   {{0x66020006,0x6288028d,0xfc240033,0x2459020d}},	//   _jook, mpdo, বকোষ_, rème_,
   {{0x823409b4,0x200100aa,0xfbab1728,0x2bc60bf5}},	// [26f0] _دروا, _tohi_, етей_, र्भा,
   {{0x66023220,0x6fb200a5,0x60cd3221,0xbd681ad1}},	//   _look, _जाएं, _ipam, урсе_,
   {{0xdddc0995,0x00000000,0x00000000,0x00000000}},	//   sprš, --, --, --,
   {{0xfde90f35,0x6602010a,0x60cd0294,0x2bc6142e}},	//   _ऑफिस_, _nook, _kpam, र्बा,
   {{0x26cc00f9,0x02d11678,0x6b953222,0x0ff80103}},	//   _apdo_, _तन्न, _tezg, _شعیب_,
   {{0x60cd3223,0x60103224,0x79993225,0xa3e3034c}},	//   _mpam, _näml, saww, _पों_,
   {{0x66023226,0xe57100e3,0xc9872bcf,0x00000000}},	//   _book, يطة_, _бузи, --,
   {{0x7aea01c5,0x66023227,0xf1bf0031,0x79990063}},	//   æfte, _cook, fiám_, qaww,
   {{0xf1bf0074,0xc7d9008f,0x6288084e,0x69c9026e}},	//   riál_, _имах_, epdo, _ibee,
   {{0x68e93228,0x291d0a4b,0x4ac900a4,0xe4c80076}},	//   _ired, mzwa_, _रहाव, ابين_,
   {{0xfbd200a1,0x60cd01dc,0x244b3229,0x2d9b0052}},	//   חתי_, _apam, dømt_, kaqe_,
   {{0x01662dfb,0x998f0138,0xb34500ee,0x660206b0}},	//   икно, mogų_, _alçà, _gook,
   {{0xe0d7013d,0x291d322a,0xaca40174,0x69c90517}},	//   авя_, nzwa_, _kwụt, _mbee,
   {{0x66020172,0x6e260063,0x68e903a9,0x7bc501cb}},	//   _zook, _smkb, _mred, jfhu,
   {{0x44d60d1b,0x66020032,0x249f01cd,0x9e660113}},	//   _zł_, _yook, lsum_, لارن,
   {{0x0d8603a0,0xee372fad,0x3ced015c,0x7e6f034f}},	//   рлан, анс_, _ševa_, _cicp,
   {{0x249f322b,0x8fa6322c,0x6010322d,0x0c26322e}},	// [2700] nsum_, _капе, _hämm, аман,
   {{0x69c90283,0x515b00ca,0x6010322f,0x00000000}},	//   _abee, _בכפו, _kämm, --,
   {{0xf1eb0ed3,0x68e93230,0xf778003d,0x69c906b0}},	//   _जोड़_, _ared, _naħa_, _bbee,
   {{0x68e90b97,0xb05b0149,0x249f3231,0xda6500e3}},	//   _bred, ptäc, ksum_, ماني,
   {{0x68e929b0,0x66023232,0x60100084,0x80c40081}},	//   _cred, _rook, _lämm, শিক্,
   {{0xb8ce3233,0x66023234,0x44273235,0x69c9083e}},	//   _कि_, _sook, _nmn_, _ebee,
   {{0x68e917c7,0xfaa30265,0x2bc605a5,0x8f9b006e}},	//   _ered, _маро, र्णा, דיצי,
   {{0x68e90501,0x2d803236,0x28da0006,0x3e7c030b}},	//   _fred, ncie_, _मैथि, _mít_,
   {{0x68e93237,0xfbc60d7a,0x3e7c3238,0x2bc60403}},	//   _gred, र्थम, _lít_, र्था,
   {{0x5fb2007d,0xe3b80f28,0x660200a4,0x44270da7}},	//   _जागल, lnız_, _wook, _cmn_,
   {{0x2d803239,0x68e900f1,0xae940139,0x6602323a}},	//   kcie_, _zred, _bẹmb, _took,
   {{0x2bc60be4,0x2ca00006,0x2d800034,0xe4e6004d}},	//   र्ता, ksid_, jcie_, _вікн,
   {{0x4427323b,0x601002c3,0x25a60158,0x00000000}},	//   _fmn_, _täml, _idol_, --,
   {{0x442700a4,0x2d8000a5,0x24860009,0x2ca000aa}},	//   _gmn_, ecie_, _itom_, dsid_,
   {{0x6448323c,0xf09f323d,0x442c323e,0x6d4f323f}},	//   modi, ssà_, mid_, _syca,
   {{0x442c3240,0xef190034,0x51870cc6,0x131700ca}},	//   lid_, ąż_, _тука, _כחול_,
   {{0x60cd3241,0x442c3242,0xddc400e8,0x00000000}},	// [2710] _upam, oid_, kliņ, --,
   {{0x64483243,0x442c3244,0x1fa72a84,0x46a7034c}},	//   nodi, nid_, _триг, _गिलह,
   {{0x2bc63245,0x25a63246,0x7e6401dc,0x2ca009a1}},	//   र्धा, _odol_, bmip, asid_,
   {{0x68e93247,0x64481b32,0x2d80028d,0x7e6403a9}},	//   _pred, hodi, ccie_, cmip,
   {{0x442c3248,0x2ca03249,0xb9c400e3,0x2486023e}},	//   kid_, csid_, تقني, _ntom_,
   {{0x68e9324a,0x6e2d324b,0xe73913cb,0x442c324c}},	//   _vred, liab, лел_, jid_,
   {{0x2486324d,0x7d0d324e,0x68e9324f,0x2d993250}},	//   _atom_, lyas, _wred, _kese_,
   {{0x249f04de,0x68e90d3e,0x442c3251,0xdb160037}},	//   tsum_, _tred, eid_, _ócái,
   {{0x2d993252,0x7d0d3253,0x8939101b,0x644800f0}},	//   _mese_, nyas, _спас_, fodi,
   {{0x644802e6,0x6e2d3254,0x249f3255,0x2d993256}},	//   godi, hiab, rsum_, _lese_,
   {{0x249f3257,0x8c1a00a1,0x2d800034,0x24860113}},	//   ssum_, רותי, ycie_, _etom_,
   {{0x2d993258,0x442c3259,0x2ca00188,0x28ae030b}},	//   _nese_, aid_, ysid_, _घिमि,
   {{0xddc608a9,0x442702e7,0x442c325a,0x661b0239}},	//   _nikš, _tmn_, bid_, mhuk,
   {{0x7d0d325b,0x44271d42,0x661b0167,0x6010007b}},	//   dyas, _umn_, lhuk, _tämm,
   {{0x81bf00c7,0x2d99325c,0xddc6013f,0x81cd0081}},	//   ীয়_, _bese_, _aikš, রয়_,
   {{0x2ca0007a,0xdb170161,0xf2d200c1,0x2d990610}},	//   tsid_, nexõ, _זעה_, _cese_,
   {{0x2d99325d,0x2d80325e,0x7d0d0018,0x6e36325f}},	// [2720] _dese_, rcie_, gyas, rnyb,
   {{0x80ad0be4,0xe7e700aa,0x2d990139,0x78a40094}},	//   _जिते, _टोला_, _eese_, šivk,
   {{0x2ca000aa,0x6e2d3260,0xd24f0421,0xb5fd00e7}},	//   ssid_, biab, _زنی_, zmša,
   {{0x6e2d3261,0x753d0034,0x64483262,0x2d99057a}},	//   ciab, ższy, zodi, _gese_,
   {{0x442c3263,0xdb1e0018,0x64483264,0xe3b8026a}},	//   yid_, lepü, yodi, ygı_,
   {{0x442c3265,0xf09300ca,0xc8793266,0x00000000}},	//   xid_, לנד_, _duş_, --,
   {{0x24863267,0x09e61c66,0x2d993268,0x07a30e2c}},	//   _stom_, _ловн, _yese_, чајн,
   {{0x442c3269,0xd5ba2d70,0x3f9a077e,0xf1bf0103}},	//   wid_, уск_, _lepu_, riák_,
   {{0x38cb110a,0xa3b3009d,0x693400d1,0x00000000}},	//   _مالی_, टलं_, _بکار, --,
   {{0x3e41013f,0x6e2d20a6,0x2a66016d,0x79820034}},	//   mėte_, ziab, lmob_, lcow,
   {{0x442c326a,0x6448326b,0x95ca00d6,0x4bfb0341}},	//   rid_, rodi, _була_, אליס,
   {{0x442c05a7,0x661b068d,0xdb1e0034,0x78a209ac}},	//   sid_, chuk, lepó, osov,
   {{0x2d99028d,0x2486326c,0x442c326d,0x6b9e19e6}},	//   _rese_, _utom_, pid_, kapg,
   {{0x2d99326e,0x7d0d326f,0x3f9a3270,0x09cc0033}},	//   _sese_, vyas, _cepu_, _রোমা,
   {{0x2d993271,0x877b028c,0x59c80455,0x53333272}},	//   _pese_, ראלי, रभार, _нешт,
   {{0x7d0d3273,0x3eac3274,0x2bc600b6,0x2d990216}},	//   tyas, ádta_, र्सा, _qese_,
   {{0x2d993275,0x6e2d3276,0x443c11bc,0xdb993277}},	// [2730] _vese_, riab, _kjv_, ивач_,
   {{0x224b3278,0x6e2d04de,0x2d993279,0x7d0d327a}},	//   lock_, siab, _wese_, ryas,
   {{0x7d0d327b,0x2d99327c,0x6a730090,0x78a20094}},	//   syas, _tese_, _aħfr, esov,
   {{0x224b0154,0xddc601d3,0xbf050179,0x2a66016d}},	//   nock_, _tikš, रहीन_, gmob_,
   {{0x26de01c8,0xbddb0139,0x2bc602d5,0x6e3d327d}},	//   _asto_, _ajèg, र्हा, _ijsb,
   {{0x6d5d01d3,0x1869327e,0x00000000,0x00000000}},	//   _izsa, шали_, --, --,
   {{0xb05b0084,0x661b327f,0x2a66022e,0xe3ae0033}},	//   ytän, thuk, bmob_, কভাব,
   {{0xc4850408,0x7bd73280,0x06093281,0x34a90291}},	//   олик, lexu, рник_, авио_,
   {{0x2bc611c6,0x26de0eb8,0xe3b11857,0xe61600d6}},	//   र्वा, _esto_, ورد_, ідь_,
   {{0x661b3282,0x42c93283,0x799b0313,0x00000000}},	//   shuk, агон_, _heuw, --,
   {{0xb05b0084,0xd7f80019,0x26de00f9,0xc17403e3}},	//   ttän, _khăn_, _gsto_, _haɗi_,
   {{0xb6860018,0x00000000,0x00000000,0x00000000}},	//   _بھول_, --, --, --,
   {{0xb05b0853,0x53a50231,0x00000000,0x00000000}},	//   rtän, _далб, --, --,
   {{0xb05b3284,0x799b0085,0x248d080f,0x00000000}},	//   stän, _leuw, mpem_, --,
   {{0xdee30f99,0x248d016d,0x3f6a078b,0x7bd7044c}},	//   мори, lpem_, риво_, dexu,
   {{0xe1ff0610,0xd7f80023,0x3f9a0294,0x799b0364}},	//   lmón_, _nhăn_, _wepu_, _neuw,
   {{0xad6600bf,0x3f9a3285,0xafe60d85,0x248d0063}},	// [2740] زاره, _tepu_, _допл, npem_,
   {{0x6b561e6d,0x61e63286,0xc17403e3,0x80d70034}},	//   отех, ldkl, _naɗi_, यबरे,
   {{0x61e40256,0x00000000,0x00000000,0x00000000}},	//   _kail, --, --, --,
   {{0xd7f800de,0xdcfd0138,0x27e90022,0x78a23287}},	//   _chăn_, _nesė, ɓani_, tsov,
   {{0xe8943288,0x2d923289,0x68460036,0xc17401c2}},	//   чаль, mbye_, онда, _baɗi_,
   {{0xacd90130,0x76aa328a,0x2cb202ad,0x78a2328b}},	//   _פֿרי, атив_, mryd_, rsov,
   {{0xa01b00c2,0xc1740d2a,0x26de0036,0x7bce009e}},	//   mpöt, _daɗi_, _qsto_, _ibbu,
   {{0x78ad03ce,0x6b9c328c,0x2bc609f6,0x2bd8009f}},	//   šava, _herg, र्रा, ड़वा,
   {{0x07a6328d,0x6b9c007a,0x7aee0087,0xc1740d2a}},	//   _маан, _kerg, _hrbt, _faɗi_,
   {{0x3eb800dd,0x6b9c328e,0x136a0c59,0x2fd802b6}},	//   kurt_, _jerg, ишни_, jerg_,
   {{0x61e4328f,0x6b9c3290,0x26de04e9,0x4b7b006e}},	//   _bail, _merg, _usto_, יטיג,
   {{0x61e43291,0x201a3292,0x6b9c3293,0x00000000}},	//   _cail, _alpi_, _lerg, --,
   {{0x61e43294,0x660f00a2,0x6b9c0178,0x7bce010a}},	//   _dail, öcke, _oerg, _obbu,
   {{0xcbd500c7,0x3eb83295,0x6b9c3296,0x2fd8010a}},	//   _হচ্ছ, furt_, _nerg, gerg_,
   {{0xdd9b0508,0x2d880294,0x93cb0018,0x3ea50103}},	//   иша_, _ọlị_, _خانہ_, élt_,
   {{0x3ead0897,0x61e43297,0x7bce003d,0xbddb0139}},	//   čet_, _gail, _abbu, _akèr,
   {{0x6b9c3298,0x2fd802c3,0xc05b02ec,0x40353299}},	// [2750] _berg, berg_, _він_, _неис,
   {{0xa2a40dba,0x6b9c329a,0x61e40a00,0x3eb80364}},	//   _किञ्, _cerg, _zail, burt_,
   {{0x23c2000f,0x6b9c329b,0xb05b00c2,0x0a6b0d85}},	//   _शानद, _derg, ntäm, арди_,
   {{0x6b9c1044,0x69c00f09,0x7bce083e,0x2cb200f0}},	//   _eerg, _ccme, _ebbu, bryd_,
   {{0x6b9c329c,0x6d5d00e4,0x00000000,0x00000000}},	//   _ferg, _uzsa, --, --,
   {{0x3abb0979,0x6b9c329d,0x66e5268e,0xa69519e8}},	//   _پاسخ_, _gerg, зока, приј,
   {{0x1995329e,0x09c20033,0x00000000,0x00000000}},	//   _навя, োয়া, --, --,
   {{0x6b9c0a00,0xd6ce00e3,0x6b8500f0,0xbcfb300f}},	//   _zerg, اقي_, lchg, _izéb,
   {{0x69d9329f,0x6d4301bf,0xc17401c2,0x3a2d00b3}},	//   mewe, ßnah, _taɗi_, _imep_,
   {{0x69d932a0,0x69cb32a1,0x6b9c0072,0x942200c2}},	//   lewe, lfge, _xerg, емье,
   {{0x81e500c7,0xef2000a5,0xb05b0212,0x91e611cc}},	//   নান_, ążki_, rtäl, поне,
   {{0xb05b070a,0x614632a2,0x69d9089a,0x00000000}},	//   stäl, зема, newe, --,
   {{0x61e6084e,0x61e432a3,0xf99200ca,0xc7b800fe}},	//   rdkl, _vail, ערך_, _tmđt_,
   {{0xb4d70409,0xe3b3001c,0xa06a0077,0xb05b007b}},	//   ाबी_, _آرش_, сага_, ltäj,
   {{0x61e432a4,0x6aba00b6,0x00000000,0x00000000}},	//   _tail, _उमेर, --, --,
   {{0x2cb20185,0xbddb10fe,0x69d901cb,0xbc760037}},	//   tryd_, _ajèb, jewe, كهرب,
   {{0x69d932a5,0x3eb832a6,0xee37004d,0x224003a9}},	// [2760] dewe, surt_, їну_, _ijik_,
   {{0xdce600d9,0xef1a0284,0x27e502ac,0x3eb832a7}},	//   _iekļ, _гмо_, _naln_, purt_,
   {{0x6b9c32a8,0x9f9700a1,0x78b901cb,0xc98605cb}},	//   _verg, _מדיה_, euwv, пули,
   {{0x69d90b7c,0x63a132a9,0xe8fa32aa,0x320900de}},	//   gewe, haln, йле_, _xoay_,
   {{0x6b9c06ee,0xc5c30081,0x3a3f0572,0x7e7e32ab}},	//   _terg, ্যাপ, _djup_, _hupp,
   {{0xfaa632ac,0xb05b00c2,0x5fc00285,0x7e7e32ad}},	//   _наго, ytäm, श्चल, _kupp,
   {{0x8c1b00a1,0x7c2e0f2c,0x69d932ae,0xbb4300c2}},	//   _פולי, _imbr, bewe, _зерк,
   {{0x44f40f94,0xbb3b040a,0xc1740022,0xd5e200fe}},	//   дпис, _העלי, _haɗu_, _khỏ,
   {{0x63a10995,0x81e50081,0x7e7e1894,0xc17401c2}},	//   faln, নাম_, _lupp, _kaɗu_,
   {{0xb05b02fd,0x2281003e,0x320932af,0x26c70141}},	//   ttäm, _bók_, _soay_, btno_,
   {{0xe1d902ec,0x316032b0,0xd5af180b,0x7e7e0f18}},	//   одні_, _aziz_, _пс_, _nupp,
   {{0x250b0260,0xa194224a,0x63a100aa,0xb05b00c2}},	//   _گرمی_, наюч, aaln, rtäm,
   {{0xd6250080,0xb05b32b1,0xf1a40138,0x0cd70081}},	//   _تعلي, stäm, эрэн, _সপ্ত,
   {{0x63a132b2,0xb4e802d5,0x3e4100c6,0x00000000}},	//   caln, मटी_, dėta_, --,
   {{0x628a3135,0x69d90239,0x00000000,0x00000000}},	//   _utfo, yewe, --, --,
   {{0x433b00ca,0xd25100b9,0x7e7e0ac9,0xc3330eda}},	//   _לעוב, _جنب_, _dupp, _רוק_,
   {{0x69d91e72,0xb05b16c7,0x00000000,0x00000000}},	// [2770] vewe, ntäk, --, --,
   {{0x69d90361,0x7055001c,0xf77800bd,0x6f0300b3}},	//   wewe, _زنجا, _daħk_, _ànco,
   {{0x34d9000d,0x442e031a,0xd7f80019,0x6b8501bf}},	//   _भन्द, _mmf_, _chăm_, rchg,
   {{0x63a105c5,0xf1bf32b3,0x7c2e32b4,0x6b850364}},	//   zaln, ngá_, _embr, schg,
   {{0x37e50769,0x7e7e0451,0x69cb31fc,0x7c2e0381}},	//   долг, _zupp, rfge, _fmbr,
   {{0xacfa00a1,0x69d932b5,0x78ad031a,0x9be40120}},	//   _והשכ, sewe, šavo, _піск,
   {{0x63a10b27,0xb05b0084,0x69d9010a,0xb7c80037}},	//   valn, ttäj, pewe, سبوك_,
   {{0x60100222,0x26c70660,0x63a10034,0x00000000}},	//   _hämt, rtno_, waln, --,
   {{0x26c702dd,0xc17403e3,0xf2b60033,0xb4d700c3}},	//   stno_, _yaɗu_, _জনগণ, ाबे_,
   {{0x60100212,0x52a9248d,0xb05b00c2,0x78a9039f}},	//   _jämt, овом_, stäj, _ivev,
   {{0x387f16b4,0x56940831,0xfbcf0469,0x04ef0033}},	//   _huur_, _захт, स्यम, য়নের_,
   {{0x63a132b6,0x387f32b7,0x600b00bc,0x1515166f}},	//   saln, _kuur_, _sümp, _одея,
   {{0x7e7e32b8,0x63a132b9,0xe44e32ba,0xa5bd013f}},	//   _supp, paln, _аж_, siųs,
   {{0x22810088,0x387f0305,0x7e7e32bb,0x2bcf1e05}},	//   _tók_, _muur_, _pupp, स्मा,
   {{0x41c60034,0x00000000,0x00000000,0x00000000}},	//   _वापस, --, --, --,
   {{0x25bf32bc,0xb7d40065,0x00000000,0x00000000}},	//   ngul_, _iṣeg, --, --,
   {{0xdca330fa,0x387f32bd,0xed570396,0x7e7e32be}},	// [2780] кати, _nuur_, дот_, _wupp,
   {{0x7e7e32bf,0x8d6300c2,0x4d63004d,0x798932c0}},	//   _tupp, твуе, ткув, _afew,
   {{0x78a90465,0x78ad2f54,0x0e661b04,0xb9e600d6}},	//   _avev, šavl, _окон, діли,
   {{0xd3780106,0x81e50033,0x387f32c1,0xb05b007b}},	//   meće_, নাথ_, _buur_, ytäk,
   {{0xd3781100,0x02da046e,0x41c6023a,0xb4d700c3}},	//   leće_, _बन्न, _वानस, ाबो_,
   {{0x387f32c2,0xd7f80019,0x6d4600bd,0x368a004d}},	//   _duur_, _thăm_, _ixka, осин_,
   {{0x6a830231,0xd378077e,0x7a370174,0x81e50033}},	//   _алса, neće_, ụtaa, নাত_,
   {{0x973c02e6,0x25bf32c3,0xd5b00103,0x3ced00c4}},	//   _neće, ggul_, اہش_, _ševi_,
   {{0xe3ce0028,0x47c60831,0x442e32c4,0x60101531}},	//   _dựng_, _обав, _pmf_, _jäms,
   {{0x25bf020a,0x7863002d,0x7c3e32c5,0x3cfb021e}},	//   agul_, _акуз, nnpr, קלינ,
   {{0x0bb70054,0xd37820e4,0x225900c2,0x387f029a}},	//   ולים_, jeće_, зины_, _zuur_,
   {{0xd37802e6,0x442e08bc,0x00000000,0x00000000}},	//   deće_, _wmf_, --, --,
   {{0x764232c6,0xf1bf037a,0x00000000,0x00000000}},	//   _ijoy, rgá_, --, --,
   {{0x656228e4,0xdb1c32c7,0x442e32c8,0x7c3e01cb}},	//   _izoh, _acrí, _umf_, jnpr,
   {{0x768701e8,0xe6dc32c9,0x660b023e,0x443e32ca}},	//   _kıya, _मनोज, _yogk, mnt_,
   {{0x645a02ad,0xf1d00019,0x601001bf,0x7c3e01ff}},	//   llti, _hạng_, _sämt, enpr,
   {{0x443e01b5,0x2d580978,0xf4bc0081,0x9cc800c2}},	// [2790] ont_, дить_, _অনুব, дыха_,
   {{0x443e32cb,0x3dc00270,0xdefb1402,0x2bbb0037}},	//   nnt_, agiw_, _дым_, تارة_,
   {{0x443e32cc,0xf1d00028,0x387f007a,0x645a32cd}},	//   int_, _mạng_, _suur_, ilti,
   {{0x443e02e2,0x321932ce,0xdb1c0037,0x387f32cf}},	//   hnt_, nksy_, _gcrí, _puur_,
   {{0x7e6d32d0,0x625d014b,0xa3be32d1,0x497400d1}},	//   mmap, véol, इला_, ندهآ,
   {{0xb9070d0b,0x764208dd,0xd3661f11,0x7e6d32d2}},	//   _बन_, _ajoy, _مه_, lmap,
   {{0x7ac432d3,0x2aa832d4,0x65621c64,0x443e32d5}},	//   _исте, _отто_, _azoh, dnt_,
   {{0x443e32d6,0xceb42865,0x387f1973,0x645a18ef}},	//   ent_, דיק_, _tuur_, elti,
   {{0x2bcf20cd,0x2ca90fa0,0x25bf32d7,0xa954004d}},	//   स्था, nsad_, rgul_, _акті,
   {{0xd3780039,0x443e32d8,0x69320018,0x73050b1b}},	//   zeće_, gnt_, _حکمر, епоз,
   {{0xf1d00019,0xc6a40095,0x973c00c4,0x656232d9}},	//   _dạng_, _арчи, _peće, _ezoh,
   {{0x2bcf0fef,0x443e32da,0xfbcf1678,0x2ca900bc}},	//   स्ता, ant_, स्तम, ksad_,
   {{0x973c04a3,0xa1550465,0xd3780335,0x443e036b}},	//   _veće, върш, veće_, bnt_,
   {{0xdb1c0080,0x201e32db,0x6606003e,0x62840ebd}},	//   _scrí, óti_, ökkv, _čiov,
   {{0xd3782461,0x60100212,0x00000000,0x00000000}},	//   teće_, _säms, --, --,
   {{0x201832dc,0x7e6d0eac,0x7c3e32dd,0x2ca932de}},	//   skri_, gmap, wnpr, fsad_,
   {{0x15f20251,0xd3780106,0x2b580113,0xfe4332df}},	// [27a0] _अफसर_, reće_, _syrc_, унто,
   {{0xaf9a0084,0x24820220,0x25af1bbd,0xb05b007b}},	//   _этих_, íkmi_, _ldgl_, ytäi,
   {{0x3f9832e0,0x2bc60efd,0x7c3e32e1,0xe8032748}},	//   mbru_, र्गा, rnpr, लाना_,
   {{0xda650037,0x2d96227c,0x0f37006e,0x3946007b}},	//   ناني, _ярос, _טריט_, ннег,
   {{0x443e32e2,0x64431e4d,0x00000000,0x00000000}},	//   ynt_, _ojni, --, --,
   {{0xb05b02fd,0x6e240124,0x2bc605fa,0xf6e600d3}},	//   ttäi, lhib, र्खा, ецин,
   {{0x8c431116,0xd6d732e3,0x443e0856,0x765b32e4}},	//   _сере, еты_, vnt_, fluy,
   {{0xa3d22c5f,0x443e32e5,0x2bd800c3,0xfaf700ca}},	//   ह्न_, wnt_, ड़का, _אצלי_,
   {{0x290200dd,0x2bc70640,0x443e32e6,0x6846001f}},	//   _çka_, _लामा, tnt_, _знаа,
   {{0xe8d700a1,0x443e32e7,0x69c21044,0xb05b0853}},	//   _אומר_, unt_, lgoe, ltäv,
   {{0xa195055b,0x443e32e8,0x7bde02ac,0xf1d0020b}},	//   канч, rnt_, iepu, _vạng_,
   {{0x765b14e2,0x2bc7007d,0x69c232e9,0xb05b00c2}},	//   cluy, _लाभा, ngoe, ntäv,
   {{0x6e2432ea,0x7bde32eb,0xf1d00023,0x6606003e}},	//   dhib, kepu, _tạng_, ökku,
   {{0xb05b0084,0x60100149,0xb80332ec,0xe8030034}},	//   htäv, _sämr, लायम_, लाया_,
   {{0x69c218f0,0xdb1c0503,0x00000000,0x00000000}},	//   kgoe, _mbró, --, --,
   {{0x6e2432ed,0x09d50081,0x2ca932ee,0xc1520174}},	//   ghib, _সোনা, tsad_, ọkọr,
   {{0xd90411a2,0x7e6d32ef,0xe803030b,0xe8df0174}},	// [27b0] _ای_, rmap, लामा_, _kwụa_,
   {{0x7e6d0113,0x2bd80034,0x2ca932f0,0x7bde32f1}},	//   smap, ड़गा, rsad_, gepu,
   {{0x2ca932f2,0xa3d21fb4,0x69c201c0,0x1eab0037}},	//   ssad_, ह्य_, fgoe, _عادي_,
   {{0x6e2432f3,0xddc4044c,0x00000000,0x00000000}},	//   chib, rmiţ, --, --,
   {{0x260416e2,0x601032f4,0x9f5a022b,0x2ca9041c}},	//   वानी_, _kämp, _anpè_, qsad_,
   {{0x7bde0012,0xec350130,0xa3d2009d,0x69c20634}},	//   cepu, _יאָר_, ह्म_, agoe,
   {{0xf4c200c7,0x765b0233,0x99850076,0x00000000}},	//   ্টোব, tluy, _للزو, --,
   {{0x601032f5,0x00000000,0x00000000,0x00000000}},	//   _lämp, --, --, --,
   {{0xe1ff0034,0x9f5a0154,0x5a440ff1,0x68e20113}},	//   lmów_, _enpè_, _сэра, cwod,
   {{0x2496001c,0x6e24033b,0xa934001f,0x28da32f6}},	//   کنید_, zhib, _сеуш, _मैटि,
   {{0x232909f2,0x2bc632f7,0xfbc609c4,0x00000000}},	//   фони_, र्टा, र्टम, --,
   {{0x65951b77,0x7aea052f,0x80cb0033,0x7bde007f}},	//   _раду, æfti, িবন্, zepu,
   {{0xbcfb0103,0xc24332f8,0x661b0350,0x00000000}},	//   _szén, рняк, mkuk, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e2432f9,0x8fa32ca3,0x60100f3a,0xb05b00c2}},	//   thib, расе, _dämp, ytäv,
   {{0x63a332fa,0x68e202ad,0x7bd501bf,0x661b32fb}},	//   _henn, ywod, _abzu, nkuk,
   {{0x644132fc,0x628332fd,0x7bde32fe,0x6e2432ff}},	// [27c0] onli, _huno, tepu, rhib,
   {{0x62833300,0x64413301,0xd3780335,0x973c0234}},	//   _kuno, nnli, leća_, _leća,
   {{0x81e50f71,0x26040789,0x63a33302,0xb05b02fd}},	//   নার_, वामी_, _menn, ttäv,
   {{0x63a33303,0x62833304,0x7bde3305,0xaca40294}},	//   _lenn, _muno, sepu, _amụr,
   {{0xe3a70434,0x69c23306,0x92cd0081,0x62833307}},	//   _پر_, rgoe, রিয়_, _luno,
   {{0x63a33308,0x64410ab2,0xb05b0084,0x8d770103}},	//   _nenn, jnli, stäv, _جاپا,
   {{0x29000012,0x973c00cc,0xc5eb0081,0x4ab900d3}},	//   ţia_, _beća, কানা_, _путя_,
   {{0xd3780292,0x64413309,0x661b00a6,0xcb67330a}},	//   jeća_, enli, gkuk, _расе_,
   {{0x70dc02e8,0xd37803ce,0x63a3330b,0x6283330c}},	//   यबोल, deća_, _benn, _auno,
   {{0x63a3330d,0xe7c900a5,0x2bc6030b,0x6283330e}},	//   _cenn, _रायप, र्चा, _buno,
   {{0x63a3017a,0x62830012,0x42752777,0x601000bc}},	//   _denn, _cuno, лгос, _rämp,
   {{0x628319a1,0x9f410094,0x058300d3,0x27ec0158}},	//   _duno, _nahá_, _кушм, _hadn_,
   {{0xc05b02ec,0x63a3330f,0xe7c91687,0x81e50033}},	//   дів_, _fenn, _रामप, নাল_,
   {{0x63a33310,0x44253311,0xe44f0281,0x628301ff}},	//   _genn, chl_, _وضو_, _funo,
   {{0x63a805f1,0x628300d3,0x9f4104bf,0x645800d9}},	//   madn, _guno, _bahá_, _ikvi,
   {{0x78ad0039,0x337700a1,0x2bc6077d,0xf365004d}},	//   šavi, _בתוך_, र्घा, _стін,
   {{0x63a30283,0x39490034,0x61ed0270,0x16bf0469}},	// [27d0] _yenn, żasz_, _iaal, _एम्ब,
   {{0x61ed3312,0xddc43313,0x63a82029,0x6283029a}},	//   _haal, rmiš, nadn, _yuno,
   {{0x61ed3314,0xfe6e12eb,0x00000000,0x00000000}},	//   _kaal, تگی_, --, --,
   {{0x61ed008a,0x63a83315,0xc33300a1,0x3a2600f9}},	//   _jaal, hadn, סוף_, ghop_,
   {{0x61ed3316,0x394900c9,0x66090292,0x7e7d3317}},	//   _maal, ças_, vjek, _iisp,
   {{0xd37800e9,0xa3d22480,0x973c104b,0xab9400d6}},	//   zeća_, _हॉल_, _seća, _вирі,
   {{0x63a33318,0xadc40065,0x973c0580,0x644113c8}},	//   _renn, _ajẹs, _peća, vnli,
   {{0x61ed3319,0x2bcf080f,0x7e7d003d,0x3a26029a}},	//   _naal, स्रा, _jisp, chop_,
   {{0x69cc025b,0x7e7d331a,0x661b331b,0x6283265b}},	//   ílež, _misp, rkuk, _suno,
   {{0x7bc5331c,0x6283331d,0x6609331e,0x661b331f}},	//   nghu, _puno, sjek, skuk,
   {{0x63a33320,0xc5d502ec,0x61ed3321,0xbcfb0018}},	//   _venn, _біль, _baal, _szél,
   {{0x61ed0694,0x63a305c9,0x7e7d3322,0xaca30174}},	//   _caal, _wenn, _nisp, _akọc,
   {{0x61ed3323,0x04c80037,0x63a33324,0x63a83325}},	//   _daal, _لوني_, _tenn, badn,
   {{0x62833326,0xf77803e5,0x34b200cd,0xd378031a}},	//   _tuno, _taħt_, _اموز, seća_,
   {{0x61ed3327,0x6d5d0694,0xb05b0003,0x7e7d3328}},	//   _faal, _aysa, kräf, _bisp,
   {{0xc6920130,0x61ed3329,0x69c9006c,0xfce60859}},	//   מאל_, _gaal, _ncee, лобо,
   {{0xdd8f0602,0x2604332a,0xaca40174,0xbcfb03a9}},	// [27e0] سول_, वाती_, _otụt, _nyéd,
   {{0x69c9002d,0x309b09c1,0x61ed0517,0x7e7d332b}},	//   _acee, _רשימ, _zaal, _eisp,
   {{0x61ed332c,0x68e9332d,0xbcfb0af0,0xb05b17a5}},	//   _yaal, _ased, _ayéd, rtät,
   {{0x61ed0694,0xb05b02e2,0x63a80087,0x7e7d00ee}},	//   _xaal, stät, zadn, _gisp,
   {{0x522d00c1,0xd5e200fe,0x09360076,0x6d5d03a8}},	//   וואַ, _nhó, دراج, _gysa,
   {{0xcaa600e3,0x3a26332e,0xdd3b006e,0x3db00033}},	//   _مصري, shop_, _װעלכ, ঙ্খল,
   {{0x63a81b30,0x68e9332f,0xd5e200fe,0x0b59022a}},	//   vadn, _esed, _phò, _арты_,
   {{0xa28100a5,0xe4e600d6,0xb05b15e6,0xd49a3330}},	//   łość_, гіон, ntär, нро_,
   {{0x61ed008a,0x2ba8063c,0x39460291,0x27fe0113}},	//   _raal, गरपा, _снаг, _tntn_,
   {{0x61ed3331,0x25070103,0x00000000,0x00000000}},	//   _saal, ارٹی_, --, --,
   {{0x2604022d,0x61ed3332,0xb05b0212,0xcc57006e}},	//   वादी_, _paal, ktär, רביי_,
   {{0x63a81d25,0x64a63333,0x61ed0188,0xf8c80ded}},	//   sadn, _бада, _qaal, _रमाय,
   {{0x7e7d07fa,0x61ed3334,0x68e90063,0xf1bf1ac3}},	//   _risp, _vaal, _xsed, bhán_,
   {{0x43943335,0xf1bf0080,0x61ed3336,0x7e7d06a3}},	//   _такс, chán_, _waal, _sisp,
   {{0x61ed3337,0x5f943338,0x3e410138,0x248600c2}},	//   _taal, сист, lėti_, _huom_,
   {{0x92b30f36,0x387e3339,0x95e200a3,0x00000000}},	//   _احوا, _litr_, _खसोट_, --,
   {{0x7e7d0029,0x3e41013f,0xc04731bb,0x00000000}},	// [27f0] _visp, nėti_, _مخدو, --,
   {{0x25a60150,0x6d5d0579,0x7e7d02ac,0xb05b0212}},	//   _leol_, _vysa, _wisp, dräg,
   {{0x78bc00d9,0xb05b333a,0x7e7d333b,0xe80309c4}},	//   _ārva, träf, _tisp, लासा_,
   {{0x973c0f39,0x3e41013f,0x2bc70096,0x2d8201ff}},	//   _pećn, kėti_, _लावा, _ggke_,
   {{0xe945001c,0x05260033,0xae9500fe,0x00000000}},	//   جرای, মপুর_, _kẹos, --,
   {{0x3e4101b3,0x25a90087,0x973c0095,0x20130062}},	//   dėti_, _žal_, _većn, _joxi_,
   {{0xbddb0154,0x00000000,0x00000000,0x00000000}},	//   _skèy, --, --, --,
   {{0x25a60a1b,0x68e901c2,0x9b5800ae,0x2486281b}},	//   _ceol_, _tsed, _сист_, _buom_,
   {{0x387e333c,0x68e9333d,0xf1bf0037,0xf77802a1}},	//   _fitr_, _used, thán_, _daħq_,
   {{0x22490d17,0x391400ae,0x893800d3,0x00000000}},	//   _ajak_, _умур, _спус_, --,
   {{0x2a6d333e,0x69cc000d,0x63bc0088,0x31690103}},	//   _kheb_, _हामी, órna, _azaz_,
   {{0xd575333f,0x20010124,0xa4d5004d,0x3e410138}},	//   _куль, _anhi_, _воді, bėti_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa06a01b3,0xfaf801d3,0x8fa33028,0x00000000}},	//   тага_, _šīm_, жаре, --,
   {{0xb05b00c2,0x25a60da7,0xdee63340,0x4375006e}},	//   ttär, _yeol_, шови, _דײַן_,
   {{0x644f0257,0x2249023b,0x9ac700bd,0x3dd90178}},	//   écif, _gjak_, _miċħ, _cbsw_,

   {{0x6fd600d6,0xc0e62bbb,0xa2a10e28,0xe1ff2a6b}},	// [2800] _кінц, _топк, कीर्, rmót_,
   {{0xb05b3341,0xd00f0076,0x5faa007f,0x00000000}},	//   stär, _يلي_, _क़िल, --,
   {{0x395f07ac,0xe6d403b3,0x79a6016d,0xaca40032}},	//   _ayus_, _दहेज, арле, _ijọr,
   {{0xb05b02d6,0x2efa2243,0x2a6d3342,0x5fd2314f}},	//   träg, _irpf_, _cheb_, द्रल,
   {{0x26041344,0x386c0094,0xda650076,0xb05b02c3}},	//   वासी_, _phdr_, حالي, bräd,
   {{0x25a600e3,0xdca3215c,0x68431165,0x9856002d}},	//   _seol_, _фари, онча, штеш,
   {{0x973c0106,0x387e3343,0x00000000,0x00000000}},	//   _većo, _vitr_, --, --,
   {{0xb05b0fe8,0xd8480134,0x387e020b,0x6b630120}},	//   präg, wọd_, _witr_, _єкта,
   {{0x87da03ed,0x6f1c00f0,0x81ac0033,0x00000000}},	//   _لباس_, hyrc, খলা_, --,
   {{0xbcfb0018,0x3e410138,0xa9230206,0x00000000}},	//   _szék, rėti_, úžen, --,
   {{0x233801b3,0x05ea00ae,0xb6cb0103,0x00000000}},	//   упны_, _афли_, _لانے_, --,
   {{0xd25800d6,0x25dd3344,0xd377013f,0x3e4100c6}},	//   иця_, _कॉपी_, шчы_, pėti_,
   {{0x04943345,0xfd560294,0x66023346,0x625d014b}},	//   _التح, robị, _inok, déot,
   {{0x251b0266,0x04db0142,0x26040096,0x398d0065}},	//   _בודא, _סקול, वावी_, _kósó_,
   {{0x6f1c02ad,0xbe883347,0x66023348,0x6367008f}},	//   gyrc, исте_, _knok, _кръг_,
   {{0x30a722ff,0xdd98231c,0x2249042d,0xa3d200b6}},	//   _кров, ишу_, _ujak_, ह्र_,
   {{0xb05b0149,0x786d016d,0x629a3349,0x25dd136b}},	// [2810] träd, lúve, lpto, _कॉफी_,
   {{0x2bb80076,0x00000000,0x00000000,0x00000000}},	//   لامة_, --, --, --,
   {{0x19b9334a,0xd8480294,0x6602334b,0xb05b3341}},	//   гуль_, kọb_, _onok, rräd,
   {{0x2a6d022e,0x4975107a,0x6602010a,0x9f430216}},	//   _qheb_, блес, _nnok, hejë_,
   {{0x26de1f97,0xe8030096,0x8cf4013f,0xd8e702e1}},	//   _apto_, लाला_, _дзяц, рцеп,
   {{0x66022eab,0x1d1600ca,0xb8ff0d7a,0x00000000}},	//   _anok, _הקשר_, _तह_, --,
   {{0x2a7f061d,0x6dbb007f,0x00000000,0x00000000}},	//   _tiub_, ałał, --, --,
   {{0xb8cd00c7,0x3dc90fa0,0x26de334c,0x1c0503b3}},	//   _কম_, ngaw_, _dpto_, रावल_,
   {{0x81d60033,0xe4590c59,0x629a05c2,0x00000000}},	//   _সফল_, лжи_, epto, --,
   {{0x981400bf,0x9b4400fb,0x68fb02a7,0x9f4c0579}},	//   _وبلا, _انہو, _irud, ždé_,
   {{0x68fb0146,0xe7190d59,0x00000000,0x00000000}},	//   _hrud, _حيات_, --, --,
   {{0x68fb334d,0x625d014b,0x00000000,0x00000000}},	//   _krud, déos, --, --,
   {{0x2604334e,0x291d334f,0x850500cd,0xf1bf0094}},	//   वारी_, nywa_, _دوشن, chám_,
   {{0x3cfe00b6,0xc2c8001c,0xe3b80233,0x656b02a1}},	//   _čtv_, دبیل_, lkın_, _izgh,
   {{0x66f91677,0xfbcd0033,0x66f73350,0xd7f100fe}},	//   ्मिक_, রজাত, ंटिक_, _mã_,
   {{0x0d8616a1,0x68fb3351,0xe3b8028e,0x442701cb}},	//   слан, _orud, nkın_, _hln_,
   {{0x61e63352,0x6fb100a3,0x00000000,0x00000000}},	// [2820] mekl, _जयचं, --, --,
   {{0x69db0890,0x44270710,0x61e63353,0x3b0a176e}},	//   _abue, _jln_, lekl, лезо_,
   {{0x44273354,0xfc3f0990,0x6d4f0575,0x25ad3355}},	//   _mln_, _avís_, _exca, kael_,
   {{0x68fb0429,0x80cb00c7,0x61e63356,0xb3460161}},	//   _brud, িবর্, nekl, leçõ,
   {{0x25ad0150,0xddcd2326,0x656f0220,0x7e643357}},	//   dael_, llaş, ýchl, mlip,
   {{0xe4470246,0x69db039f,0x629a1190,0x66021e95}},	//   _رض_, _ebue, ypto, _snok,
   {{0xddcd008e,0x61e601e8,0x26040409,0x00000000}},	//   nlaş, kekl, वाली_, --,
   {{0x61e60dd9,0x7e640bb6,0x291d007f,0x7afc042c}},	//   jekl, nlip, bywa_, _irrt,
   {{0xa9260084,0x61e63358,0x44272058,0x26180113}},	//   _удал, dekl, _bln_, _béor_,
   {{0xddcd01e8,0xb3460131,0xe8240103,0x00000000}},	//   klaş, jeçõ, _بذری, --,
   {{0x5c5b00c1,0x2bf700ca,0x7bdc3359,0x04fa0033}},	//   רדיק, זמין_, _mbru, েনের_,
   {{0xad9b0396,0x2604009d,0x5b7b0341,0xc0cb0284}},	//   _anún, वाळी_, טריא, луге_,
   {{0x661d0853,0x629a2b12,0xdb070216,0x4427335a}},	//   öske, spto, _pejë, _fln_,
   {{0xa2c0142e,0xb9210065,0x70a90179,0x3dc90270}},	//   _विप्, _aisọ_, _कबील, wgaw_,
   {{0x443e335b,0x543b00c1,0x644f0257,0x61e6335c}},	//   mit_, _געגא, écie, bekl,
   {{0x645a335d,0x7bdc335e,0x61e6335f,0x7e642783}},	//   loti, _abru, cekl, glip,
   {{0x7bdc009c,0x973c3360,0x64483361,0x443e27aa}},	// [2830] _bbru, _bećk, ondi, oit_,
   {{0x645a3362,0x64483363,0x7afc0167,0x3dc90124}},	//   noti, nndi, _brrt, sgaw_,
   {{0x64483364,0x68fb0234,0x207c006e,0xdb6b0231}},	//   indi, _srud, _גאזא, урал_,
   {{0x443e3365,0x1df90084,0x7e643366,0xc1b70ff9}},	//   hit_, _темы_, clip, _अयोग,
   {{0x443e3367,0x645a3368,0x65620027,0x7c3e3369}},	//   kit_, koti, _nyoh, bipr,
   {{0x62980954,0x443e336a,0x63aa0102,0x645a336b}},	//   _otvo, jit_, _nefn, joti,
   {{0xa3be0f53,0x443e336c,0x645a336d,0x6562336e}},	//   ेलन_, dit_, doti, _ayoh,
   {{0xe619336f,0x64483370,0x68fb3371,0x6e2d3372}},	//   рди_, endi, _trud, nhab,
   {{0x44270714,0x25ad3373,0x64483374,0x645a0146}},	//   _pln_, rael_, fndi, foti,
   {{0x443e3375,0xddcd1f8a,0x63aa02ad,0xe705001c}},	//   git_, ylaş, _cefn, _وسای,
   {{0x63aa02e0,0x27e73376,0xdb1c00e3,0x6e2d3377}},	//   _defn, menn_, _scrú, khab,
   {{0x69cb1084,0x27e73378,0x60c6117e,0x64480010}},	//   ngge, lenn_, tukm, andi,
   {{0xe3ae3379,0x645a337a,0x61e6337b,0x6e2d337c}},	//   _об_, boti, rekl, dhab,
   {{0x442c337d,0x645a337e,0x61e6337f,0x27e73380}},	//   chd_, coti, sekl, nenn_,
   {{0xa3d20067,0x26c73381,0x61e63382,0xb346016d}},	//   _हॉट_, nuno_, pekl, reçõ,
   {{0x22b500d9,0xddcd0740,0x27e73383,0x76493384}},	//   māk_, rlaş, henn_, nney,
   {{0x22b500d9,0x7e640f22,0x81d30081,0x27e706a3}},	// [2840] lāk_, rlip, _হোক_, kenn_,
   {{0x27e73385,0xebe33386,0xddcd07e7,0x7e643387}},	//   jenn_, моуп, plaş, slip,
   {{0x27e705aa,0x6e2d3388,0xd24f0260,0x22b500d9}},	//   denn_, bhab, _سنی_, nāk_,
   {{0x6e2d3389,0x443e338a,0xe8fa1491,0xddcd002d}},	//   chab, zit_, иле_, rmaţ,
   {{0x6448338b,0x3ead00e9,0x645a338c,0x28f8338d}},	//   yndi, ćete_, yoti, сель_,
   {{0x443e338e,0x27e7009c,0x973c00e7,0x645a338f}},	//   xit_, genn_, _heći, xoti,
   {{0x645a03ce,0xdcf6008e,0x26c73390,0xe5c61ac7}},	//   voti, mayı, guno_, оспо,
   {{0xdcf607d1,0x443e3391,0x22a70103,0x22b500e8}},	//   layı, wit_, dők_, dāk_,
   {{0x443e3392,0x629803ce,0x645a3393,0x27e70383}},	//   tit_, _stvo, toti, benn_,
   {{0x186a0465,0x47c30e38,0xd37808a9,0x64483394}},	//   _тази_, _обув, leći_, undi,
   {{0x443e0bb0,0x2bcf0521,0x1bfb00c1,0x26c71ce2}},	//   rit_, स्टा, בליב, cuno_,
   {{0x443e3395,0x95c70508,0xd37808a9,0xa2c00096}},	//   sit_, _душа_, neći_, _विठ्,
   {{0x443e3396,0xda7b0054,0x51843397,0xdcf603e0}},	//   pit_, ינטר, дура, kayı,
   {{0x7640013f,0x22b500d9,0x443e023b,0xc05b004d}},	//   limy, bāk_, qit_, рім_,
   {{0x69cb1484,0x6e2d3398,0x973c050d,0x539b040a}},	//   ygge, thab, _beći, _דיוו,
   {{0x2bdd09c3,0x27e7022b,0xd378005f,0x6e240270}},	//   न्ना, zenn_, jeći_, gkib,
   {{0xd37802e6,0x6e2d3399,0x26c721c8,0xacf8339a}},	// [2850] deći_, rhab, zuno_, онту_,
   {{0x6e2d339b,0x1c050251,0x26c7339c,0xad9b0161}},	//   shab, राइल_, yuno_, _inúm,
   {{0x2c00007d,0xce590231,0x76490188,0x7640339d}},	//   राजू_, _ганц_, yney, kimy,
   {{0x26c7339e,0x656f0031,0x76400169,0x00000000}},	//   vuno_, ýchk, jimy, --,
   {{0x8cc207e2,0x22b500d9,0x22a70018,0x27e7339f}},	//   _लियो, zāk_, zők_, tenn_,
   {{0xf80733a0,0x26c70150,0xbff20129,0x00000000}},	//   ючен, tuno_, _ọṅụ_, --,
   {{0x27e733a1,0xd3780542,0x2a660eac,0x5ed90033}},	//   renn_, beći_, blob_, ডিকে,
   {{0x060933a2,0x22a70103,0x22b500e8,0x76400027}},	//   сник_, vők_, vāk_, gimy,
   {{0x27e733a3,0x764933a4,0xe4d600e3,0x443c037a}},	//   penn_, rney, كويت_, _bmv_,
   {{0x22a70018,0x26c70fa0,0x870700e3,0x22b501d3}},	//   tők_, puno_, _وبال, tāk_,
   {{0x2bdd0efd,0xfbdd0473,0x625d020d,0x28f800d3}},	//   न्या, न्यम, téop, _леӂь_,
   {{0x22b50b4b,0x2c6d18ed,0x26f90b89,0xe803045f}},	//   rāk_, _vždy_, ्मीर_, लाका_,
   {{0x48fe06ec,0x22b501d3,0xdcf60342,0x00000000}},	//   लियो_, sāk_, yayı, --,
   {{0xd3780ca7,0xd8480134,0xb4fa0327,0x9f4c1e15}},	//   zeći_, họn_, _לפני, ždí_,
   {{0x644133a5,0x973c0335,0x0e6a00e3,0xf1d402d5}},	//   mili, _peći, مصري_, _थापन,
   {{0xe1ff0fb6,0xa2c00abe,0x798933a6,0x41c602d5}},	//   llón_, _वित्, _ngew, _वाटस,
   {{0x973c02e6,0x52db10e9,0x6e2433a7,0xd37808a9}},	// [2860] _veći, _बहुस, rkib, veći_,
   {{0x6e2433a8,0x7989010a,0xddcd0b14,0x61f633a9}},	//   skib, _agew, rmaš, _hayl,
   {{0x61f633aa,0xd378005f,0xbcfb0103,0xdcf60511}},	//   _kayl, teći_, _szét, rayı,
   {{0x98a033ab,0x2242004d,0x61f6041c,0xddc400c4}},	//   šič_, nikk_, _jayl, lmiž,
   {{0x644133ac,0x201a1584,0xd37804a3,0x61f633ad}},	//   kili, _kopi_, reći_, _mayl,
   {{0xd37808a9,0x64410051,0x442533ae,0xb05b01bf}},	//   seći_, jili, jkl_, hrän,
   {{0x644133af,0xd3780995,0x442500dc,0x443c33b0}},	//   dili, peći_, dkl_, _rmv_,
   {{0xa3d91b79,0x61f633b1,0x644133b2,0xf7720103}},	//   ड्स_, _nayl, eili, واں_,
   {{0x644133b3,0xbcfb33b4,0x764033b5,0x786d0031}},	//   fili, _nyél, rimy, súva,
   {{0x682f09af,0x3a260abf,0x3949002b,0x764033b6}},	//   _rødg, lkop_, úase_, simy,
   {{0x644f04ea,0x61f633b7,0x46a30581,0xe7b30103}},	//   écia, _bayl, _захв, _سمند,
   {{0xb05b0222,0x7ae101bf,0x3a2605c2,0x22420120}},	//   grän, _älte, nkop_, gikk_,
   {{0x21672a6a,0x2baf00a5,0xe1ff33b8,0x682f0b81}},	//   ятог, टरमा, blón_, _fødd,
   {{0x201a00f0,0xe1ff0328,0x80df0033,0xbddb0113}},	//   _copi_, clón_, মিল্, _njèr,
   {{0x629c0618,0xf1c6009d,0x61f61321,0xb05b33b9}},	//   írod, _वाचन, _fayl, brän,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3209025e,0xbcfb0068,0x91bc00a1,0xc1bc00a1}},	// [2870] _inay_, _azér, _המחי, _המחש,
   {{0x682f02b6,0x320900fe,0x62860231,0x201a0178}},	//   _køde, _hnay_, _éhor, _gopi_,
   {{0x682f13c8,0x998900b6,0x61f6020e,0x3a2602ac}},	//   _jøde, íkům_, _yayl, fkop_,
   {{0x682f01c5,0x3a260bb6,0x644133ba,0x78a9022b}},	//   _møde, gkop_, zili, _pwev,
   {{0xa3be0553,0xbcfb0018,0xd37800cc,0x644133bb}},	//   ेला_, _ezér, meću_, yili,
   {{0xd378031a,0x66e52bcf,0x00000000,0x00000000}},	//   leću_, дока, --, --,
   {{0xe81e17ff,0x3209026a,0x64410fda,0x682f0170}},	//   _बकरा_, _onay_, vili, _rødd,
   {{0x644102e0,0xc7440080,0xdb07030b,0x63a400e7}},	//   wili, عضوي, _její, _đina,
   {{0x3d000b95,0x280800b6,0x61f607e7,0xdb072df7}},	//   रिये_, átní_, _rayl, _mejí,
   {{0x61f633bc,0x320933bd,0xe7b512eb,0x66190167}},	//   _sayl, _anay_, _آماد, _wowk,
   {{0x61f60702,0xb05b1680,0x1b1f0081,0x224202ec}},	//   _payl, trän, _যেতে_, tikk_,
   {{0x644133be,0x2bdd0d7a,0xd3782392,0xdb0e0161}},	//   sili, न्ता, jeću_, _bebê,
   {{0x644133bf,0xd37801ac,0x2242004d,0xb05b09df}},	//   pili, deću_, rikk_, rrän,
   {{0x682f0c08,0x224200d6,0xdee600c2,0x23290236}},	//   _føde, sikk_, моги, _моли_,
   {{0x682f0537,0x00000000,0x00000000,0x00000000}},	//   _kødb, --, --, --,
   {{0x7bc301cd,0x9f4300d2,0x00000000,0x00000000}},	//   ónun, cejí_, --, --,
   {{0x224033c0,0x201a33c1,0xac8633c2,0xdb0e0f5a}},	// [2880] _imik_, _topi_, дгал, _gebê,
   {{0xf1bf33c3,0x25dd1c3b,0x3a2d33c4,0x93bc020a}},	//   nkán_, क्ती_, _alep_, lhăr,
   {{0x2bdd030b,0x63bc0ce1,0x3e4800ae,0x5f46001c}},	//   न्धा, órni, eşte_, _آنجل,
   {{0xfaf800d9,0x1d0a1e11,0xb9e30120,0x00000000}},	//   _šīs_, _деми_, віши, --,
   {{0x2bc733c5,0x249d023e,0x089733c6,0x3a2633c7}},	//   _लाचा, _ntwm_, وضوع_, rkop_,
   {{0x0ee2099d,0x2bdd2010,0x68ed0161,0x9f4302c6}},	//   _पहाड, न्दा, çada, zejí_,
   {{0xdb8300d3,0x7c2e0036,0x3a2633c8,0xe803023a}},	//   _агри, _ilbr, pkop_, लाजा_,
   {{0x26c033c9,0x2487003b,0x44f433ca,0xe5c617ab}},	//   čio_, _ainm_, епис, фско,
   {{0x83fc053f,0x25af0036,0x682f0430,0x25bd030a}},	//   hođe, _degl_, _søde, _ddwl_,
   {{0x83fc0292,0xd3780335,0x224033cb,0x00000000}},	//   kođe, zeću_, _amik_, --,
   {{0xd6cf006f,0x9726001c,0x78a20234,0x00000000}},	//   _نقل_, _تفاو, lpov, --,
   {{0xc7b802e6,0x64a6013f,0xd25131bb,0x7afa003e}},	//   _dođe_, _жада, انح_, _áttu,
   {{0xd8480294,0xe8030096,0x7c2e33cc,0xd3780995}},	//   họm_, लाचा_, _olbr, veću_,
   {{0x656f01bf,0xd8480134,0x9f4302c6,0x00000000}},	//   üche, kọm_, sejí_, --,
   {{0x5f94133b,0x83fc00e9,0x442e01ff,0xd378007e}},	//   тист, gođe, _ilf_, teću_,
   {{0x41e7116d,0x32090124,0x5c990109,0xddc4007f}},	//   _ціка, _unay_, зкая_, enił,
   {{0x5c750084,0x78a22c0a,0xd37808a9,0x7bde33cd}},	// [2890] елат, jpov, reću_, ffpu,
   {{0x78a20074,0x83fc04a3,0x9f4c025b,0x6f030072}},	//   dpov, bođe, ždá_, _ánco,
   {{0xb5fd03d6,0x00000000,0x00000000,0x00000000}},	//   loše, --, --, --,
   {{0xdb1c24c7,0xd37b006e,0x8c490233,0x2cc4020e}},	//   _acró, קראט, _başö, ürdü_,
   {{0x5d8533ce,0xb5fd00cb,0x682f0170,0x00000000}},	//   _سلسل, noše, _rødb, --,
   {{0xd8480174,0x2c050034,0x46f5004d,0xb05b007b}},	//   bọm_, राओं_, ечит, ttäy,
   {{0xa2c0077d,0xf4140033,0x661d1b80,0x7b64007b}},	//   _विष्, িসার_, ösko, _атте,
   {{0x442e2452,0x248f0063,0xb5fd33cf,0x3a3f03a9}},	//   _alf_, _pugm_, koše, _umup_,
   {{0xb5fd0307,0x26040f42,0xdb1c06a3,0xf992006e}},	//   joše, वाजी_, _adrè, _תרמ_,
   {{0xa2c00851,0x7af50034,0xb5fd2281,0x25a2026a}},	//   _विश्, _kszt, doše, ıkla_,
   {{0x25af0ac9,0x3169173c,0x43740120,0x00000000}},	//   _tegl_, _ayaz_, куют, --,
   {{0x83fc03ce,0xc7b80ca7,0x349507c8,0xdb0e0154}},	//   vođe, _vođe_, _задр, _debè,
   {{0x660b172a,0x65940291,0xb5fd0095,0x2bff00c3}},	//   _ingk, _рачу, goše, ईयां_,
   {{0x26c7013d,0x7af50018,0x95cc0092,0x3169022b}},	//   orno_, _oszt, _çərç, _dyaz_,
   {{0xdee333d0,0xbcfb0018,0x2604009d,0xe29a00de}},	//   лори, _szép, वाची_, _trưa_,
   {{0x2612099d,0x83fc005f,0x9f5833d1,0xd7df00aa}},	//   थायी_, rođe, ndré_, प्तच,
   {{0x61e433d2,0x660b02e7,0x7af50018,0xed572b85}},	// [28a0] _ibil, _mngk, _aszt, еот_,
   {{0x799b0d2a,0xa7fc0233,0xc5eb0033,0x3ec5020e}},	//   _afuw, _akın, কাটা_, üstü_,
   {{0x4fd707a6,0x7fd70130,0xe7c9034c,0x660b1f12}},	//   _אויב_, _אויס_, _राजप, _ongk,
   {{0x6ad00034,0x660b0113,0xd7d20285,0x78a200c4}},	//   _हमीर, _nngk, _साहच, tpov,
   {{0x61e433d3,0x67d433d4,0x2bdd33d5,0x7af50103}},	//   _mbil, волу, न्हा, _eszt,
   {{0x660b159d,0x25dd1c0a,0x7c2e00e8,0xa2c03162}},	//   _angk, क्सी_, _ulbr, _विल्,
   {{0x61e403ce,0x78a20ca7,0x799b010a,0x6b8e0139}},	//   _obil, spov, _ffuw, _igbg,
   {{0x78a200c4,0x7d090072,0xdb0e05aa,0x442e32a7}},	//   ppov, _áesc, _rebè, _slf_,
   {{0x545433d6,0x69c00090,0x00000000,0x00000000}},	//   квит, _idme, --, --,
   {{0x660b14f7,0xccf300a1,0x26c733d7,0x88bb00ca}},	//   _engk, רכז_, brno_, _מזמי,
   {{0x6fd7007a,0xdb0e2218,0x61e400bd,0x31690063}},	//   _बाबू, _bebé, _bbil, _syaz_,
   {{0x5ab707a6,0x290405db,0x00000000,0x00000000}},	//   עלכע_, _krma_, --, --,
   {{0x442e1484,0x64a307bf,0xdb0e0328,0x76420065}},	//   _tlf_, _бача, _debé, _imoy,
   {{0x61e433d8,0xb5fd0660,0xdb070103,0x442e0572}},	//   _ebil, roše, _lejá, _ulf_,
   {{0xa3d933d9,0x69c033da,0xb5fd33db,0xc0ab1ac9}},	//   _डॉट_, _odme, soše, _کابل_,
   {{0xdb0e03a9,0x28d133dc,0x61e40032,0x00000000}},	//   _gebé, _समलि, _gbil, --,
   {{0x8bc7121c,0xf1bf045e,0xb05b02c3,0xb5fd00c4}},	// [28b0] есед, nkám_, nräk, lošc,
   {{0x69c033dd,0x61e433de,0x61fd33df,0xf1bf0031}},	//   _adme, _zbil, ldsl, chár_,
   {{0xdb070103,0x8f3500ae,0xb5fd0357,0x76420372}},	//   _bejá, _ренц, nošc, _omoy,
   {{0x61fd25be,0x61ef33e0,0xaca30174,0x68ed33e1}},	//   ndsl, necl, _amục, çado,
   {{0xd36600bf,0x7e6d33e2,0xfd660294,0xdb070487}},	//   _چه_, mlap, _mkpị, _dejá,
   {{0xd36600bf,0x7e6d33e3,0x764233e4,0x7bd50034}},	//   _نه_, llap, _amoy, _uczu,
   {{0x8f9c00c1,0x6c5403a0,0x316c007f,0x644f020d}},	//   ליגי, _скру, ędzi_, écim,
   {{0x24991f84,0x59d802d5,0x7e6d0018,0x60dd33e5}},	//   ísmo_, _डायर, nlap, ktsm,
   {{0x9f4a05fe,0x25dd022d,0x91a20179,0x78bb0239}},	//   rebé_, क्षी_, _क्षै, _uvuv,
   {{0x61e4028d,0x7642019f,0x7e6d33e6,0xe3b10076}},	//   _sbil, _emoy, hlap, جرة_,
   {{0x6fdf0789,0xe6c700e3,0x26dc035d,0x13a733e7}},	//   _पॉइं, _ستاي, ctvo_, ونکی_,
   {{0x660b10dd,0xa69600f5,0x60dd33e8,0x61e40090}},	//   _ungk, _סכנה_, ftsm, _qbil,
   {{0x463a0130,0x628e33e9,0x7e6d33ea,0x54e500c3}},	//   _קענע, íbor, dlap, _कहिए_,
   {{0x6a782b39,0x25dd1fb4,0xb5fd00e7,0xa0a31d57}},	//   mífe, क्री_, bošc, рард,
   {{0x998f013f,0x61e433eb,0x644333ec,0x60dd05c9}},	//   nigų_, _tbil, _imni, atsm,
   {{0x61e4042d,0x7e6d12ff,0xe8d10378,0xa7fc026a}},	//   _ubil, glap, _समूच, _akıl,
   {{0x0d8612d1,0x6a781f72,0x3e5a02c6,0xc7b80218}},	// [28c0] тлан, nífe, jďte_, _lođa_,
   {{0xe0b70c6a,0x9f5a0052,0x29fe0134,0xfce32b79}},	//   _שליט_, _japë_, _ịa_, рофо,
   {{0xe9da2c37,0x3daa007b,0xcb0a0037,0x6fd700a3}},	//   дке_, _окно_, بيان_, _बातू,
   {{0x98a61d3f,0x831a00c1,0xceb80138,0xbcfb0113}},	//   виде, וועז, šęs_, _nyéw,
   {{0x83fc00e7,0xb17b09af,0x00000000,0x00000000}},	//   hođa, leår, --, --,
   {{0xf1bf0094,0x6b9c0131,0x913b021e,0x69b400a4}},	//   vkám_, _ufrg, וענק, _उजवी,
   {{0x8c4333ed,0xddcd00d3,0x27ee00f0,0xcf9300ca}},	//   _тере, noaş, refn_, סטה_,
   {{0x644333ee,0x35f4192f,0xf1bf0094,0xceb30327}},	//   _amni, упир, tkám_, ביה_,
   {{0x29040012,0x61ef02e5,0xd9100260,0xba5500e5}},	//   _urma_, vecl, _دیش_, _стръ,
   {{0x1e1f33c5,0xa84a04c6,0x7e6d33ef,0xf1bf00d4}},	//   _यक्ष_, _غلام_, zlap, rkám_,
   {{0x83fc0106,0x1db21b11,0x0bb70327,0xf1bf0437}},	//   gođa, जरात, כלים_, skám_,
   {{0x27e904eb,0x76420060,0x644333f0,0x60dd05e8}},	//   đane_, _umoy, _emni, ttsm,
   {{0x61fd33f1,0x6a780072,0x041e0033,0xdb050076}},	//   rdsl, cífe, যোগী_, rbhé,
   {{0xdb05003e,0x69b40789,0x61ef33f2,0xb5fd00e8}},	//   rahú, आरडी, secl, moša,
   {{0x442c33f3,0x69d300aa,0xf487001c,0x7e6d0103}},	//   mkd_, _डाली, _شاهی, tlap,
   {{0x2d8f052f,0x64430034,0xfda40284,0x00000000}},	//   øge_, _zmni, ијум, --,
   {{0x23b6000f,0x3d0d00a5,0xb5fd00d9,0xd7d200aa}},	// [28d0] _आजाद, समें_, noša, _सांच,
   {{0x7e6d33f4,0x00000000,0x00000000,0x00000000}},	//   slap, --, --, --,
   {{0x68e9013d,0xe0df028d,0x613801f9,0x7e6d33f5}},	//   _sped, ltò_, _túlé, plap,
   {{0x644833f6,0x6e36025b,0xe1ff33f7,0x628d33f8}},	//   hidi, chyb, ndó_, _jiao,
   {{0x6e2d33f9,0xe0df33fa,0xb5fd01d3,0x89a8004d}},	//   mkab, ntò_, joša, тків_,
   {{0xb5fd00d9,0x628d03e3,0x6e2d33fb,0x00000000}},	//   doša, _liao, lkab, --,
   {{0x644833fc,0x81cb0081,0x366933fd,0x81b90081}},	//   didi, র্য_, нако_, _চান_,
   {{0x83fc02e6,0xc7b80039,0x6a7833fe,0x64430063}},	//   vođa, _vođa_, tífe, _smni,
   {{0x9f4300c2,0x629c03be,0xb5fd00e8,0x6e2d1f9e}},	//   lejä_, íron, goša, ikab,
   {{0x644833ff,0xe576004b,0x628d009c,0x81cb0033}},	//   gidi, ызы_, _aiao, র্ম_,
   {{0x6e2d3400,0x05130033,0x8458008f,0x7e640a4b}},	//   kkab, িনের_, ърът_, yoip,
   {{0x83fc01ac,0x628d3401,0x82361ac9,0xddc43402}},	//   rođa, _ciao, اردا, kliš,
   {{0x64483403,0x7d0908a9,0x628d2a7b,0x656b0063}},	//   bidi, _šesn, _diao, _uygh,
   {{0xddc4030b,0x9f430084,0x6443019f,0x661b3404}},	//   dliš, kejä_, _umni, ljuk,
   {{0x75290018,0xd5b706ed,0x3ebe0088,0xb7b50134}},	//   lyez, _इजाज, étt_, _nọm,
   {{0x661b06ee,0x6e2d20c1,0x81cb0081,0x764900f9}},	//   njuk, gkab, র্ব_, niey,
   {{0x75293405,0x753b3406,0xec7a2cf1,0xdcff00a7}},	// [28e0] nyez, nzuz, епа_, faqı,
   {{0x661b13e1,0xbc6a1790,0x1c0e11bb,0x00000000}},	//   hjuk, رمان_, साइल_, --,
   {{0x6e462383,0x49ca3407,0xae1c00a3,0x8cd5023a}},	//   _бенз, елен_, _पचपन_, यूबो,
   {{0x64483408,0xb05b0212,0x9f5a05aa,0xb4f80285}},	//   zidi, tsäg, _rapè_, ्टमय_,
   {{0x28f80bb9,0xad9b0181,0x64483409,0x627c0034}},	//   тель_, _vnút, yidi, _głoś,
   {{0x7d04340a,0xb5fd00d9,0xb8dc007a,0x00000000}},	//   mvis, voša, _आब_, --,
   {{0xa3d707d5,0xddc401d3,0x627c007f,0xfaa30da5}},	//   िलन_, rniņ, _złoś, _гасо,
   {{0xb5fd0029,0xceb300a1,0x644802ad,0x7d0400bc}},	//   toša, זיה_, widi, ovis,
   {{0x81cb00c7,0x7d040501,0x3ce0340b,0x049e0174}},	//   র্ড_, nvis, ntiv_, _bọọd_,
   {{0xb5fd00d9,0x2a6600a6,0xbddb00b3,0x5c37006e}},	//   roša, loob_, _amèl, ָרטן_,
   {{0xd7930080,0xddc4035c,0x7d040084,0xb5fd0106}},	//   _المخ, zliš, hvis, mošn,
   {{0xb5fd340c,0x6448340d,0x2a6604de,0x66760018}},	//   lošn, sidi, noob_, _صدار,
   {{0xa2c00efd,0x6448340e,0xe1ff340f,0xc5f300a1}},	//   _विक्, pidi, rdó_, _לדף_,
   {{0xe0df0451,0x2a66006c,0xb5fd00e7,0x682f0430}},	//   rtò_, hoob_, nošn, _nødl,
   {{0xd9040434,0xf8d13410,0xe0df3411,0x9f34004d}},	//   _کی_, _सम्प, stò_, бері,
   {{0xddc40095,0x3ceb00b3,0x7d043412,0x00000000}},	//   tliš, _ppcv_, fvis, --,
   {{0xdb0e04d8,0xbcfb01dc,0x62950e43,0x661d007b}},	// [28f0] _debí, _nyét, ízov, öski,
   {{0xad9b0ba0,0x6e2d01c5,0x224b3413,0x63ba3414}},	//   _saúd, skab, lick_, natn,
   {{0x81cb0081,0x7d043415,0x09bc0081,0xbcfb0af0}},	//   র্ণ_, avis, _ইউজা, _ayét,
   {{0x98a92461,0xdb070149,0x63ba3416,0x7d04037a}},	//   šač_, _rejä, hatn, bvis,
   {{0x212b3417,0x3ce000d3,0x61ff3418,0x30840470}},	//   nych_, ctiv_, _maql, _خلیف,
   {{0x63ba084f,0x2ca900cd,0xfbcc0081,0xb5fd00e7}},	//   jatn, mpad_, র্বত, gošn,
   {{0x2ca93419,0x75d5001c,0xc7c400c2,0x224b341a}},	//   lpad_, ليغا, ссчи, kick_,
   {{0x0609185c,0x212b0181,0x248e02a1,0x81cb0033}},	//   тник_, kych_, _aifm_, র্ত_,
   {{0x680b0029,0x63ba341b,0xe61610e0,0xb5fd02ef}},	//   _pēdē, fatn, рды_, bošn,
   {{0x212b341c,0x13090084,0x661b0160,0x63ba341d}},	//   dych_, вной_, sjuk, gatn,
   {{0x35f514fa,0x75290154,0x9f4c0220,0xb05b042c}},	//   _впер, syez, ždú_, nräu,
   {{0x61ff0188,0x224b341e,0x7d04341f,0x255e0129}},	//   _caql, gick_, yvis, ịla_,
   {{0xd176065c,0x63ba005a,0xae0005a7,0x25ad3420}},	//   рыны, batn, _लोगन_, mbel_,
   {{0x7d040f2f,0x98a002e6,0x645d3421,0x63ba3422}},	//   vvis, šić_, ésid, catn,
   {{0xc44700fb,0x6fd70557,0xdfcf00e3,0x71a63423}},	//   _لیکن_, _बारू, ظيف_, _кайз,
   {{0x7d043424,0x3ce003e5,0x3126008f,0xfbb20033}},	//   tvis, ttiv_, _вдиг, _চাইত,
   {{0x212b0067,0x1c46013f,0x68fb0172,0x6834009c}},	// [2900] cych_, анам, _nsud, _làda,
   {{0x629e132d,0x69db14e2,0x3ce03425,0xda0b0096}},	//   _époc, _acue, rtiv_, _सोबत_,
   {{0x68fb3426,0x7d040dd8,0x3ce03427,0x25ad3428}},	//   _asud, svis, stiv_, kbel_,
   {{0x09e63429,0x09061994,0x7d04342a,0x25ad01c0}},	//   родн, ипен, pvis, jbel_,
   {{0x63ba063f,0xb5fd342b,0x9f5805fe,0xaca40174}},	//   yatn, tošn, ldrà_, _mmịr,
   {{0xd90d0260,0x69db0143,0x25ad342c,0xb05b042c}},	//   عیل_, _ecue, ebel_, bräu,
   {{0x63ba00e9,0x212b00a5,0x9f580472,0x27fe0c09}},	//   vatn, zych_, ndrà_, _vatn_,
   {{0x27e903ce,0x2c0a02e8,0x63ba0808,0xddcd14f3}},	//   đana_, _होतं_, watn, zmaž,
   {{0x63ba12fb,0x15e2009d,0x27e00044,0x3d0900c3}},	//   tatn, क्षर_, ƙin_, सिये_,
   {{0x61ff342d,0xaca40134,0x3cf90cce,0x212b0146}},	//   _saql, _amịr, _उनसे_, vych_,
   {{0x212b0d1b,0x25ad342e,0x14c200a4,0x9f510216}},	//   wych_, bbel_, _शिकण, rezë_,
   {{0x2ca9342f,0x212b3430,0x05863431,0xdb15022b}},	//   ypad_, tych_, _кулм, _dezè,
   {{0x224b3432,0x63ba3433,0xd8480174,0x925800e5}},	//   rick_, patn, bọt_, раят_,
   {{0x212b3434,0x63ba02a1,0xf1a7049d,0x104b1b60}},	//   rych_, qatn, _क्रन, тями_,
   {{0xc05802ec,0xe29700c9,0x645d3435,0x61ff3436}},	//   рія_, _кај_, ésie, _taql,
   {{0x2ca93437,0xdda800d3,0x5baf0285,0x682f00f2}},	//   tpad_, итул_, टर्व, _rødm,
   {{0xdb050080,0xb5fd3438,0x63b8023e,0xbcfb0139}},	// [2910] rbhí, došl, _kevn, _ayér,
   {{0x62983439,0x0ba70f6b,0x63b8004d,0x2ca9343a}},	//   _kuvo, ршам, _jevn, rpad_,
   {{0xb9950037,0xdb150103,0xddc4007f,0x68e209a1}},	//   ملاب, _kezé, nniś, etod,
   {{0x6298343b,0x63b8030b,0x2ca90212,0x3a240d63}},	//   _muvo, _levn, ppad_, _comp_,
   {{0x2001343c,0xe1ff343d,0xa3b60592,0xb05b042c}},	//   _kahi_, llós_, जरा_, sräu,
   {{0x63b800d6,0x81dd0081,0x9f580487,0x2003343e}},	//   _nevn, ড়ি_, ldrá_, ndji_,
   {{0x26c1272c,0x6298343f,0xad9b0161,0x7afc0063}},	//   ého_, _nuvo, _gaúc, _gsrt,
   {{0xa2c0218b,0x20013440,0x9f5809b3,0x26c91419}},	//   _विज्, _lahi_, ndrá_, čao_,
   {{0x81dd00c7,0x25ad3441,0x68fb0559,0x2ba400b6}},	//   ড়া_, rbel_, _usud, खुवा,
   {{0xc6e70a8d,0x200103f3,0x62980138,0x22490634}},	//   _відп, _nahi_, _buvo, _amak_,
   {{0x2a7f022e,0xd6db0831,0xe36500a9,0x9f5a0036}},	//   _khub_, _шта_, скни, _capì_,
   {{0x69d93442,0xf59500e3,0x81cb0081,0xb21b02b6}},	//   ngwe, _الإج, র্স_, smæn,
   {{0x20013443,0x66ea00a7,0xdb1500d4,0x5fdc0386}},	//   _bahi_, _təkc, _dezé, _बादल,
   {{0x8fa30a99,0x22493444,0xa879006e,0xb21b01cd}},	//   заре, _emak_, טאָר, lmæl,
   {{0x9e5a3445,0xdb1c0146,0x20010847,0xb05b0212}},	//   граф_, _odrá, _dahi_, vrät,
   {{0x2a7f023e,0xb05b3341,0x7bc73446,0xdb0e00d4}},	//   _nhub_, tsäc, _adju, _nebá,
   {{0x629801bf,0x3a243447,0x66ea00a7,0xb05b02c3}},	// [2920] _zuvo, _romp_, _məka, trät,
   {{0xd37e1197,0xddcd007f,0x60c4063d,0x69d90381}},	//   šćem_, gnał, _ivim, egwe,
   {{0xb05b3448,0x5f062787,0x3a243449,0x9f5a0154}},	//   rrät, _узна, _pomp_, _enpò_,
   {{0xb05b0149,0xb7b50174,0x9acb0103,0x69d90361}},	//   srät, _kọw, ادلہ_, ggwe,
   {{0xa3d70efd,0xb05b0212,0xc7b8007e,0xe918018a}},	//   िला_, prät, _peđ_, ролі_,
   {{0x6c3609b4,0xd6da344a,0xc5e50033,0x3bd500d3}},	//   _افسا, гти_, _খোলা_, _мюсс,
   {{0xb5fd03ce,0x68e2344b,0x63b8344c,0x3d000d75}},	//   pošl, stod, _revn, रिके_,
   {{0xb8ce0f71,0x60c40559,0x63b81c54,0xf1bf0103}},	//   _কি_, _ovim, _sevn, nkát_,
   {{0x63b818ed,0x62980fb0,0xdb050555,0x00000000}},	//   _pevn, _suvo, zahü, --,
   {{0x96ba344d,0x2249344e,0x682f00f2,0x9f580206}},	//   _буду_, _smak_, _nødh, zdrá_,
   {{0xe69600e3,0x88810421,0xd5af344f,0xd8480134}},	//   _الصد, _تیون, _нс_, sọs_,
   {{0xe7170054,0x80dd00c7,0x3cf9000d,0xddcd007f}},	//   _לחבר_, যবস্, _उनले_, znał,
   {{0xdb150103,0x914b24ec,0x645d0145,0x85760103}},	//   _vezé, учна_, ésic, _ادائ,
   {{0xf1db00ec,0x25de1117,0xdb1c052f,0x234800cd}},	//   _भावन, _गाडी_, _idræ, _پستی_,
   {{0x02a20134,0x81cb0033,0x80ce0096,0x9f34004d}},	//   _klọọ, র্ষ_, _तिथे, пері,
   {{0x6602007a,0x2001024a,0x22491912,0x6a7800e1}},	//   _jaok, _wahi_, _umak_, dífo,
   {{0x61ed3450,0x20013451,0x6e260113,0xd7c80096}},	// [2930] _ibal, _tahi_, _dokb, रणाच,
   {{0x44e20088,0xb6062461,0x81cb0081,0x00000000}},	//   ið_, lašć, র্শ_, --,
   {{0x2a7f036b,0xaab5004d,0x00000000,0x00000000}},	//   _phub_, ійді, --, --,
   {{0x2a7f01fa,0x66023452,0x998d3453,0x27ec3454}},	//   _qhub_, _naok, _aleš_, _abdn_,
   {{0x61ed3455,0x4ac5007d,0x7bc30102,0x998d05db}},	//   _mbal, _लटकव, ónus, _bleš_,
   {{0x16a93456,0xbcfb0257,0x23d402d5,0x7bc703a9}},	//   авки_, _exéc, _दागद, _udju,
   {{0xe7390a29,0x46393457,0x02a20294,0xb21b003e}},	//   рей_, ичия_, _blọọ, tmæl,
   {{0xe7f500a5,0x25de009d,0x79e70018,0xb5fd0f1c}},	//   _इसका_, _गाणी_, _دورہ_, mošk,
   {{0x998d0d12,0xd83805aa,0x8459001f,0xb21b2b4c}},	//   _fleš_, _flč_, ирот_, rmæl,
   {{0x61ed3458,0x72c500d3,0x81b90033,0xb21b3459}},	//   _abal, обоз, _চাষ_, smæl,
   {{0x60c402e6,0xfbd2040a,0x61ed083e,0x7c27007e}},	//   _svim, ותי_, _bbal, _mojr,
   {{0x7c27023b,0x02a20174,0xe5ef00c2,0x7b20031a}},	//   _lojr, _glọọ, äkää, _ušuš,
   {{0x644f025a,0xe44e345a,0x25de02d5,0x6286345b}},	//   écis, _жж_, _गाती_, rmko,
   {{0xb5fd038d,0x61ed345c,0xdfd20037,0x16170096}},	//   košk, _ebal, بيس_, थावर_,
   {{0xb5fd04a3,0x81b90081,0xa3a9142e,0x44272ab4}},	//   jošk, _চার_, गुण_, _ion_,
   {{0x4427345d,0x78a9030b,0x6d0502d5,0xee37345e}},	//   _hon_, _otev, रिंग_, онс_,
   {{0x4427345f,0x0c263460,0xec4a0084,0x9c260476}},	// [2940] _kon_, оман, азал_, одад,
   {{0x69c90694,0x44273461,0x61ed3462,0xb05b02c3}},	//   _adee, _jon_, _zbal, lsän,
   {{0x442710af,0x290d3463,0x6286028d,0x7c27007f}},	//   _mon_, _area_, _èhos, _dojr,
   {{0x290d3464,0x44270019,0x38c8010d,0x8f7b00ca}},	//   _brea_, _lon_, ماتی_, _כניק,
   {{0xa88a0077,0x290d2af2,0x44270878,0x7761016d}},	//   айда_, _crea_, _oon_, _axlx,
   {{0x44273465,0xb8f20c38,0x764b02ad,0xf1bf2e92}},	//   _non_, _वि_, _amgy, nkár_,
   {{0xab2a0020,0xb5fd00e7,0xd6d00037,0xd838080e}},	//   _това_, cošk, رقة_, _vlč_,
   {{0x44270fab,0x25bf3466,0x290d0072,0xcf9300ca}},	//   _aon_, gaul_, _frea_, וטו_,
   {{0x44273467,0xe4e602ec,0x25eb05a7,0x290d00ae}},	//   _bon_, ційн, _अउरी_, _grea_,
   {{0x44273468,0x44e20102,0x61ed3469,0x66020a4b}},	//   _con_, rð_, _sbal, _waok,
   {{0x2be2244d,0x44270054,0xd25100bf,0xe7f717ff}},	//   _पाना, _don_, فند_, ंजरा_,
   {{0x9258007b,0x9f451405,0xe80200b6,0x00000000}},	//   жают_, ýlí_, लयका_, --,
   {{0x4427346a,0xc21800d6,0x8556001c,0xb60600cc}},	//   _fon_, ією_, _بخاط, rašć,
   {{0x4427346b,0x9f4c0618,0xdb1e016d,0xddcd007f}},	//   _gon_, ždý_, rapê, znań,
   {{0x764b02ad,0x6235338d,0x61310af0,0x645a01c2}},	//   _ymgy, _неку, _bólú, mnti,
   {{0x4427346c,0x61ed346d,0xc7b800cb,0x443e0124}},	//   _zon_, _ubal, _dođi_, lht_,
   {{0x4427346e,0x2d8f02d6,0xe04b00cd,0x645a346f}},	// [2950] _yon_, äge_, _نشده_, onti,
   {{0xfbab004b,0x645a3470,0xae140179,0x683400b3}},	//   ртай_, nnti, डाउन_, _bàdm,
   {{0xc7b8007e,0x61310065,0x443e042c,0xdb1e00b3}},	//   _gođi_, _fólú, iht_, napè,
   {{0xb5fd0b27,0x290d002d,0xf9c702ec,0x7b64008f}},	//   rošk, _prea_, іщен, фтуе,
   {{0x8d873471,0xf9902b38,0x25bf00e7,0x00000000}},	//   _фунд, نبه_, vaul_, --,
   {{0x290d002d,0x2be20096,0xb5fd3472,0x09340037}},	//   _vrea_, _पाया, pošk, برمج,
   {{0x443e3473,0x7ac41141,0x2b57001c,0x44273474}},	//   dht_, _осте, _بیاد_, _ron_,
   {{0x44270632,0x682f1484,0x443e01bf,0x645a3475}},	//   _son_, _nødv, eht_, enti,
   {{0x25bf3476,0xb5fd00e8,0x60c904e9,0x3d0e00b7}},	//   raul_, noši, šemj, ठिये_,
   {{0x443e004f,0x44271175,0x9f5a0139,0x00000000}},	//   ght_, _qon_, _lapá_, --,
   {{0x44273477,0xa82200cd,0xdb0e01bf,0x25bf3478}},	//   _von_, _سکون, _gebä, paul_,
   {{0x645a3479,0xfc3f266d,0xc04900a1,0x4427347a}},	//   anti, _stíl_, _גז_, _won_,
   {{0x4427347b,0x443e0527,0x645a01fa,0xb5fd347c}},	//   _ton_, bht_, bnti, joši,
   {{0x443e347d,0x9f5a00e5,0xb05b347e,0x32040031}},	//   cht_, _papà_, ssän, žmy_,
   {{0xe7ed13b4,0x25bd00f9,0xfbd20018,0xdb1e0216}},	//   च्या_, _kewl_, ہتا_, rapë,
   {{0x9f4b0103,0xc7b8031a,0x00000000,0x00000000}},	//   áját_, _vođi_, --, --,
   {{0x629c0094,0xdb1c20df,0x6284009c,0xb5fd347f}},	// [2960] írov, _gerê, _ihio, goši,
   {{0x62960875,0xc8620294,0x628401b9,0x9f580216}},	//   _hiyo, kọọd, _hhio, nerë_,
   {{0xeb971c00,0x62963480,0x4f9b00ca,0xef1700d3}},	//   чих_, _kiyo, _לביצ, _емэ_,
   {{0x62960dc2,0xdb1c023b,0x9f580052,0x628702c6}},	//   _jiyo, _herë, herë_, ňkov,
   {{0x645a3481,0x62963482,0x62840091,0x6e240239}},	//   ynti, _miyo, _mhio, mjib,
   {{0x186710e8,0x9f580052,0x6296019f,0x6d440350}},	//   пачи_, jerë_, _liyo, mzia,
   {{0x81d400c7,0x8f9b0341,0xf1be030b,0xe3c30081}},	//   স্য_, זיצי, ्णान, ্ভাব,
   {{0x62963483,0x645a32dd,0x6e360138,0xaad108c0}},	//   _niyo, wnti, nkyb, _हितक,
   {{0x6d440465,0x682f181f,0xa4f8015a,0xa3d700a4}},	//   nzia, _rødv, تکار_, िलं_,
   {{0x645a3484,0x7bde11b9,0x81b90081,0x53340e21}},	//   unti, ngpu, _চাই_, деот,
   {{0x62963485,0xddcd030b,0x62840049,0xe41a0220}},	//   _biyo, hlaš, _bhio, _kľúč,
   {{0x443e074a,0x62843486,0x26f8009d,0x6d4431cc}},	//   sht_, _chio, ंबीर_, kzia,
   {{0x62963487,0x6284151d,0x6d44022e,0x9f5a0231}},	//   _diyo, _dhio, jzia, _rapá_,
   {{0x6d440067,0xc9530054,0xc05b0f1e,0xb7b50134}},	//   dzia, תמש_, сім_, _họr,
   {{0x6284003b,0x7e6d3488,0x9f5a0610,0xb17b052f}},	//   _fhio, toap, _papá_, dgåe,
   {{0x33770054,0x6296058d,0x62843489,0x443c00de}},	//   _מתוך_, _giyo, _ghio, _hlv_,
   {{0x7e6d002d,0x8d7700e3,0xdb1c015e,0xd8620129}},	// [2970] roap, سارا, _herè, zọọt,
   {{0x6296348a,0xdb1c0154,0x7e6d020a,0x7a330342}},	//   _ziyo, _kerè, soap, _içti,
   {{0x3cf910ed,0x6296348b,0x682f02b6,0x69c200f0}},	//   _उनके_, _yiyo, _mødt, faoe,
   {{0xddcd348c,0xdb1c00b3,0x7bde02ac,0x00000000}},	//   blaš, _merè, agpu, --,
   {{0x8c3b02dc,0x9984030b,0x443c178f,0xc7b814f3}},	//   _auße, _domů_, _olv_, _lođu_,
   {{0x7d0d348d,0x66ea0092,0xddc4015c,0x443c02ac}},	//   mvas, _təkl, moiš, _nlv_,
   {{0x7d0d348e,0x261900c3,0x69c20231,0x00000000}},	//   lvas, भाली_, baoe, --,
   {{0x443c00c2,0xbddb0154,0x80b30033,0x69c20231}},	//   _alv_, _imès, _জিন্, caoe,
   {{0x799b0124,0x7d0d348f,0x58d43490,0x9f580052}},	//   _iguw, nvas, _потт, terë_,
   {{0x62963491,0x62840a02,0xdb1c0154,0xd8620174}},	//   _siyo, _shio, _berè, pọọt,
   {{0xb05b0222,0x6fd7009d,0x7d0d0673,0x62963492}},	//   rsäl, _बाजू, hvas, _piyo,
   {{0xc7b804a3,0x1c0a009d,0x5eac0081,0x443c3493}},	//   _dođu_, _होईल_, _ছিলে, _elv_,
   {{0xdb1c00dd,0xdb1e0610,0xd0120018,0x443c3494}},	//   _perë, rapé, پلز_, _flv_,
   {{0x409506d5,0x66093495,0xddcd2c0a,0xdfd20037}},	//   ерст, ldek, vlaš, ضير_,
   {{0xdee33496,0x62843497,0xdb1c3498,0x26c709ac}},	//   кори, _thio, _verë, nsno_,
   {{0x6d440a00,0x799b3499,0xa3a90bd9,0x682f0537}},	//   tzia, _nguw, गुर_, _køds,
   {{0x7d0d17be,0x6e240167,0x61e4349a,0xdb1c05aa}},	// [2980] gvas, rjib, _icil, _zerè,
   {{0x6d44349b,0x64410201,0x660900c2,0x3eba016d}},	//   rzia, nhli, hdek, _twpt_,
   {{0x7d09200b,0xdb1c349c,0x25de00af,0xf0930796}},	//   _šest, _keré, _गाली_, _שנת_,
   {{0x8c480092,0xa2d5349d,0xceb3040a,0xddcd01d3}},	//   _başç, _भिन्, _שיר_, plaš,
   {{0x81cb0081,0x66090517,0x81d40081,0x201a0167}},	//   র্ক_, ddek, স্থ_, _knpi_,
   {{0x76aa349e,0x9f5806a3,0x645d00fd,0xfbd50033}},	//   отив_, terè_, ésil, স্বত,
   {{0x6441064b,0x8c3b01bf,0x61e4007e,0x6d4100a7}},	//   dhli, _fußb, _ocil, _əlam,
   {{0x60c90995,0x81d40081,0x682f0537,0xa3b0349f}},	//   šemi, স্ত_, _bøds, टुन_,
   {{0x998d025b,0x69c000d9,0x6ad30081,0x7d090072}},	//   _pleť_, _ieme, _সহযো, _áest,
   {{0x69c034a0,0x682f0856,0x290434a1,0x61e434a2}},	//   _heme, _døds, _isma_, _acil,
   {{0x69c034a3,0xbbd70341,0x78a00169,0x27fc00fe}},	//   _keme, וויץ_, _humv, mevn_,
   {{0x69c034a4,0x78a0023f,0x682f0856,0x201a34a5}},	//   _jeme, _kumv, _føds, _anpi_,
   {{0x69c003b4,0x394634a6,0x656f01bf,0x644110e4}},	//   _meme, nzos_, ücht, bhli,
   {{0x644102e2,0x69c034a7,0xdb0e0072,0x443c13c8}},	//   chli, _leme, _debú, _ulv_,
   {{0xfe731850,0x3267008f,0x9f41028d,0xdb1c00b3}},	//   ندر_, _отив, _xchè_, _feré,
   {{0x69c034a8,0x27e903ce,0xdb15025b,0xe5080019}},	//   _neme, đani_, _nezá, _kỷ_,
   {{0xa2da0961,0x61fd34a9,0xddc40a87,0x682f01df}},	// [2990] पूर्, mesl, bliž, _mødr,
   {{0x69c01f72,0x320934aa,0x4ea73283,0x6609026a}},	//   _aeme, _haay_, _орма, zdek,
   {{0x69c034ab,0x290434ac,0x3ce934ad,0x7d0d34ae}},	//   _beme, _asma_, stav_, svas,
   {{0xfe350130,0x61fd34af,0xdb05095d,0x78a00193}},	//   _נאָך_, nesl, nché, _bumv,
   {{0x69c00902,0xadd6040a,0x29040124,0x320934b0}},	//   _deme, _אורח_, _csma_, _maay_,
   {{0xa3b000bc,0x682f00f2,0x013800ca,0x61fd00d4}},	//   टुम_, _røds, ורדת_, hesl,
   {{0x69c034b1,0x7bc534b2,0x66090cad,0x3ea100aa}},	//   _feme, mahu, tdek, _juht_,
   {{0x69c034b3,0x7bc534b4,0x32090124,0xd90e0018}},	//   _geme, lahu, _naay_, جیے_,
   {{0x644134b5,0x290434b6,0x27e90d2a,0x00000000}},	//   thli, _gsma_, ƙan_, --,
   {{0x69c034b7,0x7bc51098,0xc9841104,0x61e40037}},	//   _zeme, nahu, _руси, _scil,
   {{0x69c034b8,0x35b516dd,0xdb1c33b4,0x320934b9}},	//   _yeme, _збер, _peré, _baay_,
   {{0xcb120130,0x61fd01a2,0x68340472,0x6a7810d9}},	//   אלט_, gesl, _ràdi, tífi,
   {{0x7bc534ba,0x78a0023e,0x6f0534bb,0xfc3f0139}},	//   kahu, _xumv, _ashc, _etíi_,
   {{0xf8b200a1,0x3a2d1183,0x7bc534bc,0x15f900a4}},	//   רשם_, _loep_, jahu, ्यकर_,
   {{0xdb1c2299,0x3a3f34bd,0x61fd34be,0x7bc534bf}},	//   _teré, _olup_, besl, dahu,
   {{0x61e4015c,0x2be20096,0xa3d700c3,0x66ea013c}},	//   _ucil, _पाहा, िलक_, _səkk,
   {{0xc6920c6a,0x69c034c0,0x7afb1a5d,0x6bd60103}},	// [29a0] ראן_, _reme, _ćuta, فتار,
   {{0x7bc534c1,0x6cd30037,0x09d80096,0xec771fbf}},	//   gahu, اقلا, डल्य, епу_,
   {{0x69c0117e,0x68e90372,0x3a2d02ac,0x06b40033}},	//   _peme, _aqed, _boep_, _টিভি,
   {{0x4ad1009d,0x9fb80033,0xc9861675,0x00000000}},	//   _हिरव, _জায়গ, нули, --,
   {{0xa3cf3245,0x7bc534c2,0x2610206b,0x69c00052}},	//   षणा_, bahu, _दोषी_, _veme,
   {{0x26dc34c3,0x394634c4,0x7bce052f,0x7bc534c5}},	//   tuvo_, rzos_, _udbu, cahu,
   {{0x81cb00c7,0x8c1b0130,0x316c00a5,0xcb67334a}},	//   র্ট_, _צולי, ędzy_, _заре_,
   {{0x3a3f08c5,0xb21b02b6,0x7c2e34c6,0x9b1700ca}},	//   _glup_, mlæg, _hobr, _אחלה_,
   {{0x7c2e34c7,0xb21b02b6,0x61fd04d6,0x00000000}},	//   _kobr, llæg, vesl, --,
   {{0xb05b0222,0xb8060068,0x22400e69,0x73380d86}},	//   rsäk, _سکتے_, _alik_, дзор_,
   {{0x1de10b95,0x224034c8,0xb21b34c9,0xb05b0853}},	//   _फालत, _blik_, nlæg, ssäk,
   {{0x64a634ca,0xe5080028,0x60dd03cf,0xb0a5009f}},	//   _зада, _tỷ_, tusm, _गंदग,
   {{0x61fd34cb,0xdb0534cc,0x7bc534cd,0x3ea10673}},	//   resl, rché, yahu, _suht_,
   {{0x7c2e34ce,0xdb050503,0x61fd00a7,0x224034cf}},	//   _nobr, sché, sesl, _elik_,
   {{0xb5fd00cc,0xddc40034,0x60dd00aa,0x59d00096}},	//   pošt, bliż, susm, हणार,
   {{0x442e34d0,0xa2d5000d,0xb21b052f,0x7bc50051}},	//   _hof_, _भित्, dlæg, wahu,
   {{0x7bc534d1,0x5c750fe3,0x3a2d1507,0x3d1b0034}},	// [29b0] tahu, влат, _roep_, नमें_,
   {{0xddeb00bf,0x3a2d01c0,0xe1ff2e56,0x7c2e34d2}},	//   _کرده_, _soep_, leó_, _cobr,
   {{0x7bc534d3,0x442e34d4,0x3a2d1183,0xfbe2023a}},	//   rahu, _mof_, _poep_, _पारम,
   {{0x7bc509cf,0x442e34d5,0xe1ff037a,0x60cd13c8}},	//   sahu, _lof_, neó_, _kvam,
   {{0x7bc534d6,0xbddb05fe,0x26cc02ef,0xe0df028d}},	//   pahu, _elèc, _avdo_, nuò_,
   {{0x81cb00c7,0xbddb34d7,0x28d2201e,0x7d090072}},	//   র্চ_, _flèc, _सिरि, _áesq,
   {{0x1c0a34d8,0x3a2d057a,0x6e2f0141,0x68340441}},	//   _होटल_, _toep_, _kocb, _nàdu,
   {{0x7c2e0c01,0x60cd34d9,0xb9070033,0xe1ff037a}},	//   _zobr, _ovam, _বন_, jeó_,
   {{0xe1ff0018,0xe81e0251,0x98f4003f,0x26cc0085}},	//   deó_, पाशा_, _مثلا, _evdo_,
   {{0x224000f3,0x442e00f0,0xddcd0034,0x9f580036}},	//   _slik_, _cof_, niał, ferì_,
   {{0xb21b34da,0x60cd34db,0xe81e02d5,0x22400034}},	//   klæd, _avam, पारा_, _plik_,
   {{0x6b9a003e,0x81cb0033,0x27e90b18,0x6e2f009c}},	//   _útge, র্ঘ_, đanu_, _nocb,
   {{0xf1bf0018,0x7e690995,0xa50934dc,0xdd0102c6}},	//   pján_, čepl, _цела_, čtět,
   {{0xd47900c1,0x60cd0357,0x660b34dd,0x442e0178}},	//   _קאַל, _dvam, _hagk, _gof_,
   {{0xe45600c1,0x660b0124,0x60cd34de,0xd46634df}},	//   _ביסט_, _kagk, _evam, _шише_,
   {{0xb17b0149,0x22400120,0x28d202f0,0xb21b0537}},	//   mgån, _ulik_, _सिलि, glæd,
   {{0xed571a6d,0x7c2e34e0,0x660b34e1,0xdca3167b}},	// [29c0] вот_, _pobr, _magk, иати,
   {{0x14d4009d,0x1c1c00aa,0x660b0b97,0x2137006e}},	//   _दिसण, नाइल_, _lagk, _סטיל_,
   {{0x9f480084,0x8b96245c,0x403b0289,0xb17b02c3}},	//   ähän_, трач, _חגיג, ngån,
   {{0x660b03cb,0xb21b34e2,0xd838080e,0x6da6268e}},	//   _nagk, rlæg, _miče_, _шима,
   {{0x61f600dd,0x09e32dc8,0xd9461612,0xd838042d}},	//   _mbyl, рочн, ъеди, _liče_,
   {{0xddcd00a5,0x7d0402a4,0x7c2e042d,0xb8da030b}},	//   ciał, mwis, _uobr, _अझ_,
   {{0x442000ef,0x660b34e3,0x7d0434e4,0xd838031a}},	//   _đi_, _bagk, lwis, _niče_,
   {{0x442e34e5,0x26192a45,0xb17b0212,0xddcd00d4}},	//   _sof_, भागी_, dgån, plať,
   {{0x18a634e6,0x2ca60080,0x57ea001f,0x660b34e7}},	//   _разм, íodh_, _одам_, _dagk,
   {{0x442e0694,0x6a782b12,0x683400b3,0xdb1c0f20}},	//   _qof_, rífu, _pàdu, _lerí,
   {{0x60cd34e8,0x442e01cb,0x9f58037a,0x7d0434e9}},	//   _svam, _vof_, ferí_, hwis,
   {{0x7d0434ea,0xddcd0034,0x44eb0120,0x80d732d1}},	//   kwis, ział, bø_, _बिदे,
   {{0x442e34eb,0x66000a4b,0x76420065,0x628f0381}},	//   _tof_, memk, _iloy, rmco,
   {{0xb21b0537,0x24400383,0x6e2f34ec,0xe1ff037a}},	//   gmær, _fòma_, _socb, seó_,
   {{0x67380103,0x9f53002b,0x925934ed,0x2c1c00c3}},	//   nyvj, _raxó_, _пакт_, नाईं_,
   {{0x6d0e110f,0xddcd0034,0x1287001c,0xd258002d}},	//   सिंग_, wiał, _جمعی_, _аць_,
   {{0xd9041b67,0x2d5802fd,0x225902fe,0xb21b052f}},	// [29d0] _بی_, вить_, misk_, smæs,
   {{0x764234ee,0x5fb722a0,0x2259040f,0x61f602c6}},	//   _lloy, _अभिल, lisk_, _zbyl,
   {{0xddcd00a5,0x98b801d3,0x0ba404e6,0x61fa01f9}},	//   riał, _ārā_, ршум, őtle,
   {{0x225902fe,0x629e0257,0x6600033b,0xddcd0034}},	//   nisk_, _épou, jemk, siał,
   {{0x4dda0054,0xdb1c34ef,0x62560117,0xbd6b0284}},	//   _אחרו, _cerâ, dšol, _црне_,
   {{0xd3660981,0x764234f0,0x00000000,0x00000000}},	//   _هه_, _aloy, --, --,
   {{0x660b1395,0x2259057e,0xf094006e,0x00000000}},	//   _pagk, kisk_, בנס_, --,
   {{0xd83802ef,0xf5091369,0xdb0701f9,0x2bcb0287}},	//   _riče_, енил_, _bejö, ाणका,
   {{0x225917d2,0x03a5090f,0x9f580031,0xdb050076}},	//   disk_, липо, verí_, ichí,
   {{0x2c1c0034,0x58870ab3,0x76420154,0x44eb004d}},	//   नाएं_, _рыба, _eloy, rø_,
   {{0x225902fe,0xc73500d0,0x660b34f1,0x7d0434f2}},	//   fisk_, _حفاظ, _tagk, zwis,
   {{0x225902fe,0x764200eb,0x68fb0174,0xb17b0212}},	//   gisk_, _gloy, _kpud, rgån,
   {{0x51560077,0x51550231,0xb21b0537,0x00000000}},	//   утну, атру, tmær, --,
   {{0xdee60b99,0xdb1c11ce,0xc5e3009f,0x25ad0314}},	//   логи, _serí, _गाँठ_, lcel_,
   {{0xdb1c34f3,0x225917d2,0x644305db,0xb21b0537}},	//   _perí, bisk_, _ilni, rmær,
   {{0x25ad34f4,0x6d4101d4,0x7d0434f5,0x22590034}},	//   ncel_, _əlav, twis, cisk_,
   {{0xdb1c34f6,0x0d862549,0x00000000,0x00000000}},	// [29e0] _verí, улан, --, --,
   {{0x7d0434f7,0x66000074,0xc00634f8,0x629e05fe}},	//   rwis, zemk, _спок, _èpoc,
   {{0xdb1c34f9,0x91a934fa,0x28c60455,0x41b8007a}},	//   _terí, _hoá_, रीनि, _आभास,
   {{0x66ea01d4,0x61e60918,0x9f5834fb,0xfe421aaa}},	//   _məkt, ngkl, merà_, _اکسی,
   {{0x9f580451,0xc7b80218,0xbddb03a9,0xed3600d3}},	//   lerà_, _anđa_, _klèn, _сэнэ,
   {{0xdcfd00d9,0x6d4800a7,0xbddb0113,0x66000174}},	//   _uzsā, _ədal, _jlèn, wemk,
   {{0xf1ba0028,0x9f580451,0xd5e20294,0x660001ff}},	//   _đơn_, nerà_, _nhọ, temk,
   {{0x7e64007a,0x963434fc,0xb05b0212,0x7c3e000b}},	//   nnip, рниц, lsät, lkpr,
   {{0x80a034fd,0x3d170fef,0x89660457,0x9f5800e5}},	//   _गंगे, निये_, _скаж, herà_,
   {{0x2619009d,0x5454008f,0xb05b34fe,0x660034ff}},	//   _मोठी_, рвот, nsät, semk,
   {{0x225902fe,0xa3e502e8,0xb89300e3,0x7e6418ef}},	//   tisk_, _फार_, _اللع, knip,
   {{0x9f5800e5,0xdb050161,0xbb3b006e,0x64433500}},	//   derà_, lchã, געטי, _elni,
   {{0x225902fe,0xf1bf0018,0xe3af00cd,0xbddb03a9}},	//   risk_, lják_, غری_, _blèn,
   {{0x225902fe,0xbddb03a9,0xdb1e037a,0x7afc05db}},	//   sisk_, _clèn, zapá, _oprt,
   {{0x645a3501,0x22593502,0x331706fa,0x2139023b}},	//   miti, pisk_, _مزيد_, sysh_,
   {{0x443e3503,0x7e642375,0x442c0212,0x31660095}},	//   lkt_, gnip, ljd_, _žoze_,
   {{0xdc550a28,0x26c10018,0xad9b002b,0x28c60c22}},	// [29f0] авањ, ához_, _naút, रीमि,
   {{0xe7e0110f,0x645a3504,0xb05b0149,0x68e20138}},	//   _नागप, niti, gsät, duod,
   {{0x443e3505,0x20033506,0xdb0e01bf,0x629f1097}},	//   ikt_, meji_, _gebü, _épos,
   {{0x20033507,0xdb1c0396,0x645a3508,0x39151165}},	//   leji_, _serã, hiti, имер,
   {{0x628d117b,0xfc3f0037,0x443e003e,0x64480188}},	//   _mhao, _dtír_, kkt_, khdi,
   {{0x443e0505,0x645a3509,0x2011350a,0x7c3e227a}},	//   jkt_, jiti, ndzi_, ckpr,
   {{0x645a350b,0xfc3f0fb6,0xdb1c001f,0xaa9500d6}},	//   diti, _guía_, _verã, _вивч,
   {{0xceb4193b,0x6e2d350c,0x443e1324,0x7bc70193}},	//   זיק_, njab, ekt_, _heju,
   {{0x645a350d,0x2003350e,0x7bc70496,0x87e70391}},	//   fiti, keji_, _keju, _مثال,
   {{0x69cb350f,0x7bc73510,0xdb1c002b,0x25ad3511}},	//   lage, _jeju, _herá, scel_,
   {{0x38ab01df,0x7bc70294,0x2003033d,0x9f580428}},	//   _hør_, _meju, deji_, xerà_,
   {{0x628d1519,0x69cb3512,0x7bc72d60,0x443e0126}},	//   _chao, nage, _leju, akt_,
   {{0x645a3513,0x628d10f0,0x9f580ba0,0x32020146}},	//   biti, _dhao, derá_, reky_,
   {{0x443e3514,0x69cb3515,0x9f58343f,0x26193516}},	//   ckt_, hage, terà_, _मोती_,
   {{0x69cb3517,0x38ab038c,0x628d0013,0x7e56014d}},	//   kage, _lør_, _fhao, атац,
   {{0x628d0091,0x9f583518,0xfe433519,0x764901af}},	//   _ghao, rerà_, онсо, nhey,
   {{0xb05b09df,0x6486003e,0x7afc351a,0x753b0193}},	// [2a00] tsät, iðin, _sprt, nyuz,
   {{0x628d01c2,0x9f58351b,0x765b019c,0x68e200c2}},	//   _zhao, perà_, hiuy, vuod,
   {{0xb05b0704,0x9f58351c,0xf1da1b92,0x7bc7351d}},	//   rsät, berá_, _भयान, _deju,
   {{0x9f580d9f,0x38ab1a08,0x644800dd,0xdb1c04d8}},	//   cerá_, _bør_, zhdi, _cerá,
   {{0x645a0283,0x3940351e,0x443e351f,0x76493520}},	//   yiti, áis_, ykt_, dhey,
   {{0x645a3521,0xf1bf0018,0x26dc3522,0x2c1c00a5}},	//   xiti, tják_, trvo_, नाओं_,
   {{0x69cb28e1,0x12e00081,0x394033f4,0xab2708f9}},	//   bage, _বন্দ, šis_, _кора_,
   {{0x38ab1a08,0x261930a8,0x69cb3523,0xf1bf0103}},	//   _før_, _मोदी_, cage, rják_,
   {{0x38ab0021,0x645a3524,0xb8db0081,0xd943022f}},	//   _gør_, titi, _আয়_, _дети,
   {{0x628d0099,0x9f580220,0x443e01d3,0x7d5700ca}},	//   _shao, zerá_, ukt_, ייפד_,
   {{0x443e3525,0x6d4d0517,0x63a300dc,0xd5af0cb1}},	//   rkt_, zzaa, _dgnn, _мс_,
   {{0x443e0173,0x645a3526,0x64483527,0xdb1c002b}},	//   skt_, siti, shdi, _xerá,
   {{0x645a0239,0x9f58001f,0xc05b00d6,0x68e40049}},	//   piti, verá_, вів_, àidh,
   {{0x02a63528,0x69cb3529,0xc05b00d6,0xdb1e0428}},	//   _крим, zage, тім_, capç,
   {{0x628d10f0,0x69cb352a,0x44f0352b,0x9f5810d9}},	//   _thao, yage, là_, terá_,
   {{0x7bc706ee,0xb05b00c2,0xf8a607d5,0x92b3071c}},	//   _seju, tsäs, खदाय, _بحوا,
   {{0xdb05135f,0x7bc70d17,0x44f0352c,0xf1bf352d}},	// [2a10] dchá, _peju, nà_, mbá_,
   {{0xdb1c11ce,0x6d4d0ab2,0x69cb352e,0x38ab01df}},	//   _será, rzaa, wage, _rør_,
   {{0x69cb352f,0x38ab00f3,0xb05b16f9,0x6d4d3530}},	//   tage, _sør_, ssäs, szaa,
   {{0xceb20132,0xbddb0383,0x00000000,0x00000000}},	//   _מיט_, _klèm, --, --,
   {{0xdb1c3531,0x81d40081,0xe9d8013f,0x798000f0}},	//   _verá, স্ক_, ркі_, _cymw,
   {{0x44f03532,0xdb050037,0x81ad0033,0x7bd51819}},	//   dà_, achá, গরি_, _udzu,
   {{0xdb1c26ca,0x7649063d,0xb9e7004d,0xdb050206}},	//   _terá, they, _візи, bchá,
   {{0x38ab038c,0x683d05fe,0x81cc0081,0xbddb0154}},	//   _tør_, _mèdi, _লাভ_, _amèz,
   {{0x64860102,0xf80700d6,0x79800150,0x76493533}},	//   rðin, _вчен, _gymw, rhey,
   {{0x76493534,0xe0df3535,0x61ed3536,0xddcd033b}},	//   shey, drò_, _acal, jlaž,
   {{0x78a90033,0x9f580472,0xe0df028d,0x60c43537}},	//   _huev, merç_, erò_, _swim,
   {{0x78a13538,0x66ea00a7,0x6458039f,0x44f02269}},	//   _hilv, _təkr, _emvi, bà_,
   {{0x78a93539,0x25bf2f9c,0xf6741823,0x645d353a}},	//   _juev, mbul_, _بالخ, ésis,
   {{0x78a9058a,0x25bf0124,0x7e7d353b,0xf1bf016d}},	//   _muev, lbul_, _aksp, abá_,
   {{0xddcb2c0a,0x7ae5007a,0xf1bf0103,0x61ed0090}},	//   _šiša, juht, bbá_, _fcal,
   {{0x25bf0b88,0x290d0a43,0xf8a500cd,0xe0df0036}},	//   nbul_, _osea_, _يک_, brò_,
   {{0x78a931f9,0x7c3505aa,0x925a0470,0x644100c6}},	// [2a20] _nuev, _bozr, _لشکر_, okli,
   {{0xdd8f048f,0x09d0009d,0x3212003a,0x6441353c}},	//   رول_, हण्य, _hayy_, nkli,
   {{0xdb1c353d,0xb09b00a1,0x25bf353e,0x6441353f}},	//   _merç, _תייר, kbul_, ikli,
   {{0xd9100177,0xdb1e00bc,0x64411d7e,0x0dba0076}},	//   ویز_, vapä, hkli, _حادث_,
   {{0x64413540,0x78a90328,0x78a10b97,0xda1d0336}},	//   kkli, _cuev, _bilv, फाजत_,
   {{0x78a10b4b,0x44f03541,0xaad100c3,0x78a90036}},	//   _cilv, và_, _हिचक, _duev,
   {{0x64410149,0x290d037a,0x56940e65,0x26193542}},	//   dkli, _esea_, оакт, _मोही_,
   {{0x44f03543,0xc8e0000f,0x44b400d6,0xbb3b00c1}},	//   tà_, _निपट, обис, _געלי,
   {{0xdb1c0161,0x7afb0b18,0x3ea201cb,0x3ebf0218}},	//   _berç, _ćuti, _mikt_, ćuti_,
   {{0x44f03544,0x15ea0557,0xe0df0451,0x9f5a0428}},	//   rà_, _टावर_, vrò_, _japó_,
   {{0x6d4101d4,0x44f03545,0xd7640018,0x92953546}},	//   _əlaq, sà_, _بنای, жанц,
   {{0x78a10126,0x64410185,0x3ea200a5,0xe0df00e5}},	//   _zilv, akli, _nikt_, trò_,
   {{0xdb1c0084,0x64410ac1,0x867b0a41,0xf5960076}},	//   _herä, bkli, _גראו, _الشج,
   {{0x64413547,0xdb1c3548,0xe0df0451,0x61ed0034}},	//   ckli, _gerç, rrò_, _wcal,
   {{0x62350231,0x7c351799,0xc0580c10,0xce6b3549}},	//   _меку, _rozr, сія_, град_,
   {{0x4caa0081,0xbddb0113,0xe0df028d,0xa1490103}},	//   _চৌধু, _ilèk, prò_, _نسخے_,
   {{0x7c350038,0x7cd900cd,0xdd9400c6,0x3ea20f63}},	// [2a30] _pozr, شواز_, заты, _dikt_,
   {{0x4d981736,0x9f5a2df7,0x00000000,0x00000000}},	//   скую_, _capó_, --, --,
   {{0x25a6354a,0x78a90042,0xa91d0141,0x5f950161}},	//   _ogol_, _suev, _izži, _финт,
   {{0x6441316d,0x7e9902d1,0x7d0e00ce,0x00000000}},	//   zkli, _خنجر_, änsä, --,
   {{0x78a1354b,0xbcfb137f,0x7ae52a3c,0x6441286f}},	//   _pilv, _exér, suht, ykli,
   {{0x8aa7064f,0xdb1c0222,0x25b3023a,0xdd3100a5}},	//   _град, _berä, ीर्ण, zęśc,
   {{0x81d40f71,0xa6b40081,0x78a1354c,0x2249354d}},	//   স্ট_, _টিউট, _vilv, _olak_,
   {{0x62560094,0xd83805db,0xb05b042c,0xe8920206}},	//   lšov, _fičo_, lpäd, ĺňať_,
   {{0x78a1354e,0x89370d74,0xe9d90034,0xbddb05aa}},	//   _tilv, _اعزا, _idź_, _alèk,
   {{0xf9901574,0x2249354f,0x261917ff,0x99480037}},	//   _سبق_, _alak_, _मोरी_, _الكل_,
   {{0x64413550,0xdb1c3551,0x22493552,0xb21b052f}},	//   rkli, _gerä, _blak_, rlæn,
   {{0x81e200c7,0x64413553,0x28e01efb,0x28c600a8}},	//   ন্ন_, skli, _निमि, रीवि,
   {{0xdb1c0396,0xa2d51d96,0xbddb0383,0x2249033b}},	//   _terç, _भिक्, _elèk, _dlak_,
   {{0x22493554,0x3ea22ba4,0xbddb03a9,0x2d823555}},	//   _elak_, _sikt_, _flèk, _ryke_,
   {{0x032500d6,0x8fa31110,0x2d821aad,0x4fa300e5}},	//   _єдин, даре, _syke_, дирв,
   {{0x00e63556,0x3f8400e8,0x00000000,0x00000000}},	//   _джин, āmu_, --, --,
   {{0x3ea20149,0x00000000,0x00000000,0x00000000}},	// [2a40] _vikt_, --, --, --,
   {{0x62863557,0x2a7f01c2,0x81b001c2,0xc8e000c3}},	//   llko, _akub_, _daɓe, _निबट,
   {{0x6da60fa5,0xe7ed009d,0xad9b0139,0x3ea23558}},	//   _мина, च्छा_, _abúd, _tikt_,
   {{0x387e0085,0x2d8200b3,0xf9861e46,0x66fc00e8}},	//   _sktr_, _tyke_, огео, nākš,
   {{0xa3e90454,0x15e33559,0x00000000,0x00000000}},	//   यला_, _गाजर_, --, --,
   {{0xd6da355a,0xdb1c0084,0xa3e50336,0x201301ff}},	//   ати_, _perä, _फाग_, _xaxi_,
   {{0x27e00b88,0x81e20081,0xdca3355b,0x81b00044}},	//   ğin_, ন্য_, _цари, _zaɓe,
   {{0xa534355c,0x91e60490,0xdb1c02e2,0x27e008bb}},	//   знич, _कागज_, _verä, şin_,
   {{0xd40623a3,0x69c2355d,0xad9b0139,0x746a166f}},	//   ояни, mboe, _gbúd, иров_,
   {{0x81e20081,0xb35400d6,0xdb1c00c2,0x69c2355e}},	//   ন্ম_, зкош, _terä, lboe,
   {{0x28c60c16,0x683d00ee,0x68e20381,0x68e40076}},	//   रीरि, _cèdu, lrod, áidf,
   {{0x69c20ab2,0x64a601b3,0x68e20a4b,0x00000000}},	//   nboe, _дада, orod, --,
   {{0x2249355f,0x1a9b0130,0x2beb009d,0x62560146}},	//   _vlak_, ייטע, _चालू_, yšov,
   {{0x9f5a06a3,0x62863560,0x741400d1,0x60db250f}},	//   _rapò_, alko, _روبا, šumo,
   {{0xd8383561,0x69c201d0,0x2ca301c0,0x644a0167}},	//   _moč_, kboe, _rijd_, _ilfi,
   {{0x2cb902e5,0x68e23562,0x224900f9,0xa91d00b6}},	//   _ptsd_, krod, _ulak_, _lyža,
   {{0xa3ae009f,0x5d5501c9,0xfbab00a9,0x6b9a01cd}},	// [2a50] _कला_, чкат, атей_, _útgj,
   {{0x64dd02e8,0x68e23563,0xd8380087,0x69c23564}},	//   _मिसळ, drod, _noč_, eboe,
   {{0x625610e1,0x69c202ac,0x00000000,0x00000000}},	//   ršov, fboe, --, --,
   {{0xc3330130,0x69c20a9f,0x5a352a6e,0x68e20178}},	//   ווע_, gboe, янет, frod,
   {{0x2ca30505,0x68e200a5,0xb5fd0335,0x62560146}},	//   _tijd_, grod, niše, pšov,
   {{0xd7fb004c,0x7d0d3565,0x38b0009c,0x9f580036}},	//   руд_, mwas, _dàr_, ffrè_,
   {{0xe7393566,0x7d0d3567,0x44290028,0x3ffc0130}},	//   сей_, lwas, _đa_, יפגע,
   {{0xb0dc04a9,0xecdf0034,0x38b0009c,0xdb17002b}},	//   _बिलग, _फटाफ, _fàr_, saxó,
   {{0xdb0502dc,0x81e200c7,0x7d0d3568,0x83fc2a6c}},	//   schä, ন্ড_, nwas, ziđe,
   {{0x28e01b92,0xb5fd015c,0x7d0d06a8,0xd838007e}},	//   _निति, diše, iwas, _goč_,
   {{0x59cf022d,0x7d0d3569,0x3ce90197,0x60db09ac}},	//   _हजार, hwas, huav_, šuml,
   {{0x7d0d356a,0x83fc0039,0x80b30081,0xdb120018}},	//   kwas, viđe, _জিজ্, égév,
   {{0xa567001c,0x271c0023,0x6609356b,0x6f1e0a39}},	//   _بدان, _ảnh_, meek, _srpc,
   {{0xdb150364,0x6609356c,0x3af50212,0xbddb0154}},	//   _bezü, leek, kåp_, _klèw,
   {{0x44271c1a,0xe29a2569,0x00000000,0x00000000}},	//   _inn_, _лак_, --, --,
   {{0x7c270449,0x6f1e00cb,0x291f0134,0x6609356d}},	//   _anjr, _vrpc, _orua_, neek,
   {{0x7d0d0a69,0x28e00179,0x78bb0027,0x6abb05db}},	// [2a60] gwas, _निधि, _ntuv, _čufa,
   {{0x69db034f,0x8b9608f9,0x8cdd0557,0xac8311a0}},	//   _adue, преч, _पिरो, егул,
   {{0x291f356e,0x69c21044,0x103b00ca,0x78bb0bbd}},	//   _arua_, tboe, _הגיע, _atuv,
   {{0xdca61c66,0x2018356f,0x200a3570,0x4427009c}},	//   _нами, ldri_, lebi_, _lnn_,
   {{0x44273571,0x291f00e3,0x69c21183,0xb05b007a}},	//   _onn_, _crua_, rboe, späe,
   {{0x68e23572,0x69c204e2,0x69db0072,0xb17b0b85}},	//   rrod, sboe, _edue, pgåv,
   {{0xa91d025b,0x1c020455,0x7bdc00dc,0xa09b006e}},	//   _vyža, _रॉयल_, _idru, זיסט,
   {{0x44273573,0x81e20f71,0x54b80e38,0x200a1a0d}},	//   _ann_, ন্ত_, огия_, hebi_,
   {{0x7bce0f8b,0x48e33574,0x291f023b,0x44273575}},	//   _kebu, _потв, _grua_, _bnn_,
   {{0xb5fd04eb,0x7bce001c,0xaae00179,0x200a0880}},	//   više, _jebu, _पटाक, jebi_,
   {{0x212003a9,0x67bb00ca,0x6609083e,0xf3660dfb}},	//   _arih_, _המבק, beek, ятин,
   {{0x44270c09,0x7bce3576,0x3ce9023e,0x9f580206}},	//   _enn_, _lebu, yuav_, berú_,
   {{0x3ce9006c,0x81cc0033,0xbddb0154,0x660d00d2}},	//   xuav_, _লাশ_, _klèv, ánků,
   {{0x7bce3577,0xb5fd0786,0x44273578,0x64a31982}},	//   _nebu, riše, _gnn_, _зача,
   {{0x543309b4,0x81e20081,0xff042c37,0x8c3b0364}},	//   _سرور, ন্ধ_, нятн, _mußt,
   {{0x7d0d3579,0xb5fd0128,0x00000000,0x00000000}},	//   twas, piše, --, --,
   {{0x7bce357a,0xdcef01d3,0x200a026a,0x2d8f2222}},	// [2a70] _bebu, _izcī, bebi_, åge_,
   {{0x81e200c7,0xfbab00c6,0x200a357b,0x6609357c}},	//   ন্দ_, стай_, cebi_, zeek,
   {{0x81b00d2a,0x3ce9022e,0x78bb032e,0x7ac400d3}},	//   _haɓa, suav_, _stuv, есче,
   {{0xdb15025b,0xfd1f0019,0xa3dc04f8,0x81b001c2}},	//   _sezó, _trì_, तृत_, _kaɓa,
   {{0x7e6d357d,0x9f51058a,0x6609357e,0xdb050076}},	//   mnap, pezó_, veek, nchú,
   {{0x7bce357f,0x66093580,0x6fbf02d5,0x81b003e3}},	//   _gebu, week, ्रिं, _maɓa,
   {{0x66090a15,0x7bc53581,0xac9416d9,0x6d4000bc}},	//   teek, mbhu, _чарш, _ümar,
   {{0x7bdc19be,0x7e6d3582,0x7bce3583,0xdb26010d}},	//   _zdru, nnap, _zebu, _توفی,
   {{0x5fbf000d,0x66093584,0x14dd009d,0x81cc0081}},	//   ्राल, reek, _मिळण, _লাল_,
   {{0x68e4054f,0x66093585,0x7e6d3586,0xb4ad0096}},	//   áide, seek, hnap, _कढी_,
   {{0x7e6d18f0,0xe29a2cad,0xc7b200a1,0x420a2976}},	//   knap, жан_, _סבא_, онно_,
   {{0xd9ff0b7f,0x9f58037a,0x68e40094,0x7bc50076}},	//   ोजित_, perú_, šide, hbhu,
   {{0x7e6d3587,0x68eb02c9,0xd4350037,0x241910e0}},	//   dnap, nugd, _يعتب, _моды_,
   {{0xe8000c38,0xa91d0146,0x672109ac,0xd49b2f34}},	//   ल्पा_, _lyžo, _krlj, _уре_,
   {{0xa0a30360,0x7bce3588,0x10a31aad,0x00000000}},	//   тард, _rebu, тирн, --,
   {{0x7bce2c09,0x7ae500cc,0x67210106,0xbf280139}},	//   _sebu, drht, _mrlj, _aṣòr,
   {{0x62843589,0x81b00022,0x7bce0085,0x2bb2034c}},	// [2a80] _ikio, _gaɓa, _pebu, _जलदा,
   {{0x1daa074c,0x8b6a008f,0x67210357,0xfce32fad}},	//   _कलकत, оизв_, _orlj, тофо,
   {{0x28e00557,0x3cea009f,0x81b00d2a,0x00000000}},	//   _निहि, _चमके_, _zaɓa, --,
   {{0x7bce358a,0x1bf00251,0x5336006e,0xfd1f0139}},	//   _webu, _चावल_, ונען_, _iyìn_,
   {{0x7bce358b,0x83fc00e7,0x644f01d3,0xb17b032e}},	//   _tebu, hiđa, īcij, lgår,
   {{0x7bdc02e6,0x59cc000d,0x67210995,0x7e64358c}},	//   _udru, ारहर, _brlj, liip,
   {{0xb17b040f,0x2bc4277c,0x68e40076,0x28e0136b}},	//   ngår, _ल्या, áidb, _निवि,
   {{0x4420016a,0x1514060b,0x7e640032,0x67210542}},	//   _şi_, едия, niip, _drlj,
   {{0x7c3c358d,0x6d441bd6,0xd8380335,0x68e400c4}},	//   _korr, nyia, _liči_, šidb,
   {{0xdb1c038c,0x62840051,0x7c3c01e9,0x6296010a}},	//   _berø, _akio, _jorr, _ahyo,
   {{0x81b00d2a,0x672114f3,0xbddb022b,0x00000000}},	//   _saɓa, _grlj, _klèt, --,
   {{0x81e20081,0x63ad358e,0x68ed0138,0xa91d0117}},	//   ন্স_, _şant, žodž, _izžr,
   {{0x629600f9,0xbddb0113,0x7c3c0313,0xa19404a1}},	//   _dhyo, _mlèt, _oorr, каюч,
   {{0x7c3c358f,0x62843590,0x75220027,0x00000000}},	//   _norr, _ekio, _iroz, --,
   {{0xe80013b4,0x9f5f0b88,0x7522025b,0xb5fd0039}},	//   ल्या_, _ürün_, _hroz, liša,
   {{0x443c3591,0x7e6400f9,0x81b00d2a,0xe3b8047e}},	//   _hov_, giip, _taɓa, lcı_,
   {{0x443c3592,0x660200bf,0xfd1f0139,0x7c3c3593}},	// [2a90] _kov_, _mbok, _eyìn_, _borr,
   {{0x7c3c3594,0xe3b80587,0x6f050019,0xbddb0154}},	//   _corr, ncı_, _tphc, _alèt,
   {{0x443c3595,0x7c3c3596,0x60cd0167,0x629d169c}},	//   _mov_, _dorr, _hwam, omso,
   {{0x60cd3597,0x443c3598,0x75223599,0x625600e7}},	//   _kwam, _lov_, _oroz, nšop,
   {{0x7c3c3320,0xa80301e8,0x6e3d0124,0x6721042d}},	//   _forr, _çıkt, _iosb, _srlj,
   {{0x672104a3,0x6602359a,0x7c3c359b,0x60cd359c}},	//   _prlj, _abok, _gorr, _mwam,
   {{0x3949359d,0xddc402dd,0x98bf008b,0x60cd019b}},	//   šas_, lniš, ırım_, _lwam,
   {{0x83fc08a9,0x752209ac,0x7c3c1075,0x3ce60031}},	//   viđa, _broz, _zorr, šove_,
   {{0x7522209a,0x60cd0294,0xd7fb359e,0x6e3d0216}},	//   _croz, _nwam, _муж_, _mosb,
   {{0x443c1071,0x20cd359f,0x67210106,0x6e3d35a0}},	//   _cov_, dži_, _trlj, _losb,
   {{0x443c35a1,0x60cd35a2,0x63ad35a3,0x13a709e5}},	//   _dov_, _awam, _şans, بندی_,
   {{0x23bf05cd,0x60cd2622,0xd5750457,0x66020139}},	//   _श्रद, _bwam, _пуль, _gbok,
   {{0x752235a4,0x1bf0007d,0xddc41271,0xc56b03ef}},	//   _groz, _चालल_, jniš, _بحال_,
   {{0x6aa935a5,0xddc415f4,0x653a00c1,0x44f902f1}},	//   _lief, dniš, _מענד, mè_,
   {{0x44f935a6,0x661910a4,0x6e3d1044,0x75221799}},	//   lè_, _kawk, _bosb, _zroz,
   {{0x661b35a7,0xb17b0bab,0x62840239,0x443c006c}},	//   nduk, rgår, _ukio, _zov_,
   {{0xfce335a8,0x60cd0a75,0x44f906a3,0x6e3d0150}},	// [2aa0] лото, _gwam, nè_, _dosb,
   {{0x443c01bb,0x7e7b0335,0x7d1b003d,0x3157006e}},	//   _xov_, čupa, _ġust, _ניין_,
   {{0x7c3c35a9,0x6d4435aa,0x6aa935ab,0x9f5a0131}},	//   _vorr, syia, _bief, _capô_,
   {{0xddc40b27,0x7ae335ac,0x2bb206ed,0x661b1912}},	//   bniš, ánta, _जलवा, jduk,
   {{0x44f906a3,0x6aa904e2,0x7c3c35ad,0x661b0283}},	//   jè_, _dief, _torr, dduk,
   {{0x752435ae,0x98a335af,0x661b02b1,0xb5fd35b0}},	//   _šizo, гиче, eduk, viša,
   {{0x443c01bb,0x09e602ec,0x798935b1,0x201a25d1}},	//   _rov_, _повн, _eyew, _mapi_,
   {{0x752235b2,0x443c35b3,0x661b019c,0x6aa90036}},	//   _proz, _sov_, gduk, _gief,
   {{0x443c0197,0xc8ca1f11,0xbddb03a9,0x798926e3}},	//   _pov_, _روان_, _klèr, _gyew,
   {{0xa2b4007d,0x60cd3223,0x61f622d4,0x201a0018}},	//   _ईंद्, _rwam, _acyl, _napi_,
   {{0x443c35b4,0xddc40087,0xcf120081,0x39460103}},	//   _vov_, zniš, হমুদ_, lyos_,
   {{0xb5fd35b5,0x764935b6,0x752235b7,0x201a07ac}},	//   lišn, ckey, _troz, _aapi_,
   {{0x81a900c7,0x443c35b8,0x39460018,0x26190ed3}},	//   খুন_, _tov_, nyos_, _मोटी_,
   {{0x201a35b9,0xc5692ba0,0x229235ba,0xb5fd35bb}},	//   _capi_, _تحمل_, ráka_, unšv,
   {{0x81b003e3,0x141b00ca,0x6e3d35bc,0xddd414f3}},	//   _gaɓo, _מוגב, _posb, _šaša,
   {{0x6d1c0789,0xddc419d0,0x60cd35bd,0xbddb00b3}},	//   निंग_, tniš, _twam, _alèr,
   {{0x30a7008d,0x313533d4,0x22ac00b6,0x60cd02a4}},	// [2ab0] _пров, _репр, _věku_, _uwam,
   {{0xb5fd04a3,0xddc40087,0x394600f9,0xbddb0113}},	//   jišn, rniš, dyos_, _clèr,
   {{0xb5fd02e6,0xddc40106,0x5b241ad1,0xcfb600a1}},	//   dišn, sniš, льца, _בלתי_,
   {{0x44f935be,0xd838080e,0x3cea0096,0xddc407c0}},	//   yè_, _miču_, _चमचे_, pniš,
   {{0xca7435bf,0x201a35c0,0x00000000,0x00000000}},	//   دالغ, _yapi_, --, --,
   {{0x6bd409f4,0xd94235c1,0x201a01ff,0xddeb00d1}},	//   _متفر, реши, _xapi_, _برگه_,
   {{0x6aa901bf,0x79c900e3,0xd838015c,0x394606a8}},	//   _tief, _يوسف_, _niču_, ayos_,
   {{0x44f906a3,0x7bd735c2,0x39460113,0x00000000}},	//   tè_, laxu, byos_, --,
   {{0xb5fd0580,0x3d170096,0x81b003e3,0x661b35c3}},	//   bišn, निटे_, _saɓo, rduk,
   {{0x44f935c4,0x7bd7020b,0xd838007e,0x764935c5}},	//   rè_, naxu, _biču_, skey,
   {{0x201a0d17,0x3a3f06a3,0x44f935c6,0x3a2d057e}},	//   _rapi_, _koup_, sè_, _knep_,
   {{0x44f935c7,0x201a072f,0x216a35c8,0x3ce90c96}},	//   pè_, _sapi_, дими_, krav_,
   {{0x212400e3,0x64860088,0x9f5801cd,0x44f90036}},	//   ímh_, gðis, rfrí_, qè_,
   {{0x3a3f201c,0xb05b0c19,0x00000000,0x00000000}},	//   _loup_, spän, --, --,
   {{0xe1ff35c9,0xfc3f137f,0x7bd701ff,0xb5fd0e31}},	//   mión_, _luís_, daxu, nišo,
   {{0x201a0010,0x224b171d,0x3dc9019c,0x33760327}},	//   _wapi_, ckck_, gbaw_, _בעצם_,
   {{0x201a042b,0xbea335ca,0xe7f20096,0x3eab35cb}},	// [2ac0] _tapi_, ратк, _घाला_, _dict_,
   {{0xe1ff0f07,0x3eab0027,0xf1a700b6,0x224001ff}},	//   nión_, _eict_, _गणतन, _hoik_,
   {{0xb5fd005f,0x3a3f022b,0x00000000,0x00000000}},	//   višn, _boup_, --, --,
   {{0x3a3f025a,0xc3320327,0x27e903e3,0x9f5800b3}},	//   _coup_, יוב_, ɗani_, mfrà_,
   {{0x99dd0154,0x3ea035cc,0xc7b814f3,0xee3700ae}},	//   _alňs, mmit_, _lađe_, _рня_,
   {{0xdb1c0068,0x3ea035cd,0xb7d80037,0x394600f9}},	//   _kerü, lmit_, روبا_, ryos_,
   {{0x7c2e35ce,0xc7b8005f,0xb5fd031a,0x81d90033}},	//   _inbr, _nađe_, rišn, ালত_,
   {{0xeb971b60,0x5eea00b6,0x9f58037a,0x692600ae}},	//   _рис_, _छिन्_, leró_, _имба,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1ff35cf,0x9f580314,0xb5fd1515,0x3ea00052}},	//   gión_, neró_, bišo, hmit_,
   {{0xad9b026e,0x2252057a,0x3a3f01cb,0x25bd030a}},	//   _abúl, _blyk_, _youp_, _ffwl_,
   {{0xdb1c35d0,0xacbb00fd,0x3ea035d1,0xb5da2259}},	//   _heró, _brûl, jmit_, _آباء_,
   {{0xe1ff08a8,0x81cc0081,0x7c2e112f,0x00000000}},	//   bión_, _লাখ_, _onbr, --,
   {{0xe1ff35d2,0x545335d3,0x14d70130,0x64860088}},	//   ción_, _квіт, _יודל_, rðis,
   {{0x3eab0085,0x9f580487,0x00000000,0x00000000}},	//   _pict_, deró_, --, --,
   {{0x320f0068,0x02a4022c,0x5bcb0f8f,0x7c2e35d4}},	//   _úgy_, _крым, िर्व, _anbr,
   {{0x5c752f11,0xad9b0065,0x3eab0169,0x2fd80027}},	// [2ad0] глат, _gbúl, _vict_, barg_,
   {{0x7ae335d5,0x3a2d2618,0x3a3f35d6,0x00000000}},	//   ánto, _snep_, _soup_, --,
   {{0x629f00e5,0xe81d0789,0x3ea000a1,0x201135d7}},	//   _èpos, _योगा_, bmit_, mezi_,
   {{0x201135d8,0x3ce902dd,0x7c2e0062,0x3ce61b62}},	//   lezi_, prav_, _enbr, šova_,
   {{0x26de35d9,0x9f5805b4,0x99d400d1,0x3a3f022b}},	//   _avto_, beró_, شتنا, _voup_,
   {{0xe1ff0fb6,0x81d90033,0x9f5800ee,0x628f00d4}},	//   xión_, ালি_, ceró_, hlco,
   {{0x27e908bb,0x8aa70095,0xead40c4a,0x9f580036}},	//   ğan_, _арад, _вось, lerò_,
   {{0x1dd3007d,0x27e90702,0x442e01af,0x3a2d35da}},	//   तरित, şan_, _anf_, _unep_,
   {{0x2a64013d,0xe1ff1ba6,0xe80013b8,0x442e35db}},	//   _търг, tión_, ल्हा_, _bnf_,
   {{0x3ea000dd,0x69d935dc,0x442e35dd,0x201135de}},	//   zmit_, lawe, _cnf_, jezi_,
   {{0x7bd535df,0x25af005c,0x9f580451,0xdb1c00b3}},	//   _mezu, _tggl_, herò_, _herò,
   {{0xe1ff11d1,0x69d9068d,0xddd6025b,0x442e022b}},	//   sión_, nawe, chyň, _enf_,
   {{0xdb0e0065,0x648601cd,0x224002ac,0x2fd8007f}},	//   _egbè, rðir, _voik_, targ_,
   {{0x201135e0,0x9f58028d,0xdb1c002b,0x7bd5063d}},	//   gezi_, derò_, _xeró, _nezu,
   {{0x2d8f01bf,0x37d80033,0x38b9098c,0x69d935e1}},	//   ügen_, _সামর, _lèr_, kawe,
   {{0x69d935e2,0xdb050037,0xad9b0139,0x229935e3}},	//   jawe, hchó, _ibúj, téke_,
   {{0x61e435e4,0x3ea00539,0x628635e5,0x69d90201}},	// [2ae0] _idil, rmit_, moko, dawe,
   {{0x628635e6,0x09cc0d88,0xdb1c0018,0x3ea035e7}},	//   loko, ार्य, _terü, smit_,
   {{0x27230702,0x7bd535e8,0xdb1c015e,0x8cb0007f}},	//   _nın_, _dezu, _aerò, _अंको,
   {{0x248535e9,0x628635ea,0x69d935eb,0x9f4100e1}},	//   holm_, noko, gawe, _echó_,
   {{0x1ae033d9,0x186a35c1,0x9f5835ec,0x62860350}},	//   _पटकथ, нади_, peró_, ioko,
   {{0x628635ed,0x7bd535ee,0xddcd0034,0xdb1c05aa}},	//   hoko, _gezu, chał, _derò,
   {{0xeb970d62,0x69d935ef,0x628635f0,0xdb1c0328}},	//   _бир_, bawe, koko, _veró,
   {{0x60c4129e,0x61e435f1,0x2bc00469,0x20112002}},	//   _otim, _ndil, शुरा, zezi_,
   {{0x54542007,0x2011083e,0xb21b01df,0x60c435f2}},	//   ивит, yezi_, klær, _ntim,
   {{0xdb0e0032,0xe6440491,0x59cc00b6,0xb7b5020b}},	//   _agbé, ılış, ारकर, _hạn,
   {{0x60c435f3,0x439435f4,0x61e40090,0x26010096}},	//   _atim, ранс, _bdil, व्ही_,
   {{0x201135f5,0xe4520688,0x628635f6,0x61e4009c}},	//   wezi_, _گفتگ, goko, _cdil,
   {{0x201135f7,0x61e40150,0x9f4103a9,0xb7b50023}},	//   tezi_, _ddil, _idhé_, _mạn,
   {{0x61e435f8,0x7642008a,0x9f580451,0x27170092}},	//   _edil, _hooy, verò_, _sənə_,
   {{0x201135f9,0xa91d0244,0x69d935fa,0xda040176}},	//   rezi_, _vyži, yawe, रभात_,
   {{0x7bd535fb,0x7642321d,0x9f58028d,0x244901cd}},	//   _sezu, _jooy, terò_, _rúmi_,
   {{0x201135fc,0xdb0501bf,0x320900f9,0x76420188}},	// [2af0] pezi_, schü, _ibay_, _mooy,
   {{0x69c035fd,0x69d90010,0x9f580451,0x2129001c}},	//   _afme, wawe, rerò_, _irah_,
   {{0x7bd50e94,0x69d935fe,0x8af90f32,0x5b151272}},	//   _vezu, tawe, тнес_, рмет,
   {{0x7f3a00c1,0x2129023b,0x7d1600f0,0xd0110018}},	//   _סערו, _krah_, bwys, _الگ_,
   {{0xe0df35ff,0x67283600,0x65ab013c,0x80a4015a}},	//   nsò_, _ardj, _möhü, _خمین,
   {{0xe80020cd,0xb34601e8,0x67280a39,0x635300a7}},	//   ल्ला_, _kaçı, _brdj, sənə,
   {{0xe7390274,0x62863601,0x39be0294,0xdb050076}},	//   тей_, yoko, _ịse_, rchó,
   {{0x8aa43602,0xb5fd0138,0x2129037d,0xb346026a}},	//   _груд, mišk, _orah_, _maçı,
   {{0xb5fd3603,0x76423604,0xf1c800b6,0xdb1c01cd}},	//   lišk, _dooy, ndář_, _herð,
   {{0x62863605,0x32093606,0x290d0131,0xb4651440}},	//   woko, _abay_, _ipea_, ркол,
   {{0x21291084,0x62863607,0xb5fd3603,0xe29a0831}},	//   _arah_, toko, nišk, као_,
   {{0x76420188,0x69ac00a3,0x543501f9,0x00000000}},	//   _gooy, ुँची, ارکر, --,
   {{0x62863608,0x62460139,0x212903a9,0xb5fd033b}},	//   roko, _bóor, _crah_, hišk,
   {{0x9f580088,0x25bf3609,0xb5fd013f,0x7e660063}},	//   ferð_, lcul_, kišk, _smkp,
   {{0x8fa6266a,0x6286360a,0x9f580088,0xb5fd360b}},	//   раве, poko, gerð_, jišk,
   {{0x25bf048e,0x13da0081,0x6443360c,0xb5fd360d}},	//   ncul_, _দায়, _honi, dišk,
   {{0x6443360e,0xb21b00d6,0x21291cb4,0x60c4360f}},	// [2b00] _koni, plær, _grah_, _utim,
   {{0x7d160185,0x64433610,0xddd500e8,0x3ce600d4}},	//   rwys, _joni, ābša, šovo_,
   {{0x64433611,0xb5fd013f,0xe9da3612,0xc7b80a39}},	//   _moni, gišk, вке_, _nađa_,
   {{0x64431622,0xa92613cb,0x62872650,0x6aa20baa}},	//   _loni, идел, čkog, umof,
   {{0xd37803ce,0x6728077e,0x76420313,0x2ba73613}},	//   maće_, _srdj, _rooy, केबा,
   {{0xdb1c0102,0x64433614,0x6aa23615,0xb5fd3616}},	//   _ferð, _noni, smof, bišk,
   {{0xdb1c0102,0xd6d70761,0x290d0a00,0xd5e20174}},	//   _gerð, аты_, _epea_, _nkọ,
   {{0x7e7601af,0x96343617,0xddcd020a,0xd01f0033}},	//   nnyp, сниц, mnaţ, দায়_,
   {{0xd90e1e49,0xd49a2a84,0x3ce20113,0x99340018}},	//   _آیت_, кро_, _jvkv_, _دہشت,
   {{0x656f3618,0x76423619,0x320900f9,0x6443361a}},	//   úcha, _wooy, _sbay_, _coni,
   {{0xc5e800c7,0x0bb70054,0x6f0900a5,0xc7b8015c}},	//   ক্ষা_, ילים_, łecz, _gađa_,
   {{0xd3782461,0x21290128,0x32673051,0x81b003e3}},	//   jaće_, _prah_, ртов, _zaɓi,
   {{0xdfdb013d,0x6443361b,0xd37800cb,0xc69300ca}},	//   къв_, _foni, daće_, _ואף_,
   {{0x6443361c,0xd48f004d,0xe0df0036,0x916900fe}},	//   _goni, _єр_, rsò_, _vừa_,
   {{0x09d70081,0xe0df361d,0xb05b00c2,0xb34600a7}},	//   _হাসা, ssò_, npäi, _qaçı,
   {{0xb5fd013f,0x877b006e,0x443e0212,0xd3780095}},	//   višk, דאלי, ljt_, gaće_,
   {{0x656d0181,0x21290087,0x6443361e,0x2d8f052f}},	// [2b10] _ľahk, _urah_, _yoni, æge_,
   {{0xa80207e7,0xb5fd013f,0x6443361f,0x270e0092}},	//   çıla, tišk, _xoni, _kənd_,
   {{0x95ff0033,0x6aa3029a,0xd3780e94,0xc5ff0033}},	//   ্যতম_, ïnfo, baće_, ্যতা_,
   {{0xdb1c0682,0xb5fd3603,0xc7b808a9,0xd378007e}},	//   _verð, rišk, _rađa_, caće_,
   {{0x634a01d4,0xb5fd013f,0x645a008a,0x628d3620}},	//   lənd, sišk, khti, _mkao,
   {{0x89340068,0x1ed80260,0x7e6d065c,0xb5fd00c6}},	//   تعما, _حبیب_, liap, pišk,
   {{0x81e200c7,0x6d4d0b5b,0xb9200134,0x36693621}},	//   ন্ট_, lyaa, _karị_, лако_,
   {{0x80b800c7,0x64433622,0xb9200174,0xceb400ca}},	//   _অবস্, _soni, _jarị_, חיק_,
   {{0x6d4d3623,0x64433624,0x25bf00d3,0xb5fd0b9c}},	//   nyaa, _poni, rcul_, niši,
   {{0x25bf3625,0x799b0d2a,0x628d3626,0x2ab70090}},	//   scul_, _izuw, _akao, _aħbi_,
   {{0xd7950080,0x64433627,0x7e6d3628,0xe1ff0018}},	//   _الاخ, _voni, kiap, ciók_,
   {{0xc0493629,0x64430505,0x425621fd,0x22991e6f}},	//   _אז_, _woni, стот, téka_,
   {{0xd3780039,0x2ba7009d,0x6443362a,0x00000000}},	//   vaće_, केता, _toni, --,
   {{0x645a362b,0x10a6002d,0xb5fd362c,0x4613001c}},	//   chti, сигн, diši, _دوچر,
   {{0xd3782a6c,0x6d4d0188,0x934500d3,0x00000000}},	//   taće_, eyaa, _ынке, --,
   {{0x765b362d,0x7e6d362e,0x00000000,0x00000000}},	//   nhuy, giap, --, --,
   {{0xd37801ac,0x6da3362f,0x6d4d3630,0x101605b6}},	// [2b20] raće_, зита, gyaa, _льня,
   {{0xb3d50033,0x3ce03631,0xd378031a,0x00000000}},	//   _দাঁড়, rsiv_, saće_, --,
   {{0x3ce03632,0x6d4d3633,0xff261942,0xaca40174}},	//   ssiv_, ayaa, _умно, _nnụr,
   {{0xeb9714fa,0xddcd00d3,0x6d4d3634,0xb5fd0234}},	//   щих_, rnaţ, byaa, biši,
   {{0xaca40129,0xdd921850,0x2d8400fd,0x645a00c2}},	//   _anụr, _روس_, _âme_, yhti,
   {{0x6e24073b,0x99dd0094,0xb90000c3,0x7d043635}},	//   ldib, _voňa, _दब_, mtis,
   {{0x7bde3636,0x6b630b0c,0x09d70081,0x04200081}},	//   mapu, _екра, _হারা, বামী_,
   {{0x6e243637,0x645d00dd,0xceb300a1,0xdb1c0149}},	//   ndib, ësin, היה_, _berö,
   {{0x7d043638,0xb05b00c2,0x3eba044c,0x00000000}},	//   ntis, späi, _lupt_, --,
   {{0x7bde3639,0x634a01d4,0x7d04363a,0xe7f20490}},	//   napu, yənd, itis, _घाटा_,
   {{0x7d04363b,0x539800d6,0x9f45008b,0x81b003e3}},	//   htis, рвня_, ülü_, _maɓu,
   {{0x645a01e5,0x7d040e9f,0x6d4d363c,0x7ae30610}},	//   shti, ktis, yyaa, ánti,
   {{0x7bde363d,0x6d4d008a,0x68e2363e,0xc05b004d}},	//   kapu, xyaa, nsod, гів_,
   {{0x80b80081,0x634a0092,0x7bde363f,0xdb1c3640}},	//   _অবশ্, tənd, japu, _afrí,
   {{0x6fda0c13,0x7e6d2c6f,0xe3b80367,0x00000000}},	//   _बजरं, tiap, ndım_, --,
   {{0xdceb135f,0x7d043641,0x6e243642,0x22c40294}},	//   žičk, ftis, gdib, _ịkwa_,
   {{0x68e20117,0x7d043643,0x60d600eb,0x00000000}},	// [2b30] jsod, gtis, _gwym, --,
   {{0x7e6d18c4,0x7bde3644,0xb5fd0995,0x6d4d008a}},	//   siap, gapu, riši, ryaa,
   {{0x6d4d17b6,0x6e243645,0x39be0134,0x200400a7}},	//   syaa, bdib, _ịsa_, əmi_,
   {{0xb5fd191d,0x27fe0234,0x5a350e3f,0x00000000}},	//   piši, _actn_, юнет, --,
   {{0xab6207d1,0x645814e2,0x7d043646,0xe9d808a1}},	//   _çünk, _olvi, ctis, скі_,
   {{0xd5e20065,0xe9d9007f,0x00000000,0x00000000}},	//   _amò, _weź_, --, --,
   {{0x70b50034,0x765b00fe,0x00000000,0x00000000}},	//   ंदुल, thuy, --, --,
   {{0x245b04ea,0x81b003e3,0x7996007f,0x656f3647}},	//   _même_, _zaɓu, żywa, úcho,
   {{0x1fa617ad,0xe45908c3,0x69db00f0,0x68e201f9}},	//   _खण्ड, ижи_, _ieue, csod,
   {{0xdb1c25ea,0x69db1399,0x765b0169,0x99dd0206}},	//   _verö, _heue, shuy, _koňo,
   {{0x2c0b00b7,0x765b0079,0x00000000,0x00000000}},	//   स्यं_, phuy, --, --,
   {{0xa3b504f8,0x7bde03be,0x7de60018,0x7d04003e}},	//   _झलक_, zapu, _késő, ytis,
   {{0xe820000d,0x7bde3648,0x69db00ee,0x3eba3649}},	//   _यसमा_, yapu, _meue, _supt_,
   {{0x9f580257,0x660913fb,0x69db057a,0xdb05016d}},	//   lgré_, lfek, _leue, lchõ,
   {{0xe29a364a,0x1faa1c00,0xfd1f0139,0x7bde0f06}},	//   _как_, ркви_, _asì_, vapu,
   {{0x69db02dc,0x7bde03fa,0x6e24209a,0x7d04364b}},	//   _neue, wapu, udib, ttis,
   {{0x7bde2846,0x0eb6000f,0xd3780106,0x1c460b22}},	// [2b40] tapu, _आंकड, maća_, онам,
   {{0x765902ad,0x212000bf,0x8b96364c,0xe3b8071d}},	//   _llwy, _isih_, ореч, ydım_,
   {{0x8fa620e6,0x9f0600b9,0x69db364d,0x3bd500c2}},	//   _фане, _بوجو, _beue, яютс,
   {{0x2018074e,0x2120005c,0x634a0092,0x7ff6015a}},	//   leri_, _ksih_, lənc, _اسکا,
   {{0x7bde364e,0xcaa500e3,0x69c208a8,0xdca62d70}},	//   papu, أصلي, rcoe, _мами,
   {{0x2018364f,0xab2a0cc1,0x75290018,0x212009a4}},	//   neri_, _кога_, dvez, _msih_,
   {{0xf8bf0ab2,0x66090f05,0x68e23650,0x69db01bf}},	//   _één_, ffek, ssod, _feue,
   {{0x7bdc3651,0x20183652,0xe3b808bb,0x68ed0d62}},	//   _heru, heri_, rdım_, šada,
   {{0x7bdc3653,0xd3780dd9,0xdb21007b,0xbddb022b}},	//   _keru, daća_, ätös, _plèz,
   {{0x201802e6,0xddc41b32,0x344a1352,0x29060239}},	//   jeri_, jniž, рчин_, mtoa_,
   {{0x7bdc2c09,0x21201bdf,0x765902ad,0xdb0501bf}},	//   _meru, _asih_, _flwy, schö,
   {{0xbddb00fd,0x75290128,0x2906358c,0x6abc3654}},	//   _poèm, bvez, otoa_, _murf,
   {{0x29063655,0xddcd00b6,0xe3af0018,0xdb1502f1}},	//   ntoa_, chař, ٹری_, _egzè,
   {{0x20183656,0x7bdc3657,0xe3af0018,0x270e0092}},	//   geri_, _neru, عری_, _gənc_,
   {{0x6abc005c,0xcddb07ed,0x212000d1,0xff04163d}},	//   _nurf, иња_, _esih_, мятн,
   {{0x7bdc3658,0x20180172,0x29060062,0x00000000}},	//   _aeru, aeri_, ktoa_, --,
   {{0x7bdc3659,0x2018365a,0xdb0e0032,0xb5fd1912}},	// [2b50] _beru, beri_, _agbà, mišt,
   {{0xb5fd02e6,0x2018365b,0x7bdc365c,0x69db0428}},	//   lišt, ceri_, _ceru, _seue,
   {{0x7bdc365d,0x200100f0,0x69db365e,0x6abc0076}},	//   _deru, _ichi_, _peue, _curf,
   {{0x61fd1842,0x78bb0673,0x81d90081,0x6abc365f}},	//   ngsl, _puuv, ালক_, _durf,
   {{0x3ea902fd,0x7bdc3660,0x61fd1d09,0x69db0428}},	//   mmat_, _feru, igsl, _veue,
   {{0x7bdc0b7c,0x3ea93661,0xb5fd0087,0xeafb0470}},	//   _geru, lmat_, hišt, _پرست_,
   {{0x7bc51644,0x69db01bf,0x6abc0044,0x645d0052}},	//   mchu, _teue, _gurf, ësim,
   {{0xe9df0682,0xb5fd0d95,0x386c01af,0x7bdc3662}},	//   _þú_, jišt, _emdr_, _zeru,
   {{0x7bdc3663,0x1c0b000d,0x1a6800cd,0x20183664}},	//   _yeru, स्थल_, _بینی_, yeri_,
   {{0x20011ee3,0x75290068,0x3ea93665,0x7bc53666}},	//   _nchi_, rvez, hmat_, nchu,
   {{0x3ea90496,0x7ae5023b,0x75293667,0xb5fd02ef}},	//   kmat_, nsht, svez, fišt,
   {{0x20183668,0x7bc5151d,0x6721015c,0x3ce60094}},	//   weri_, hchu, _islj, šovi_,
   {{0x20183669,0x3ea908d3,0xd3780106,0x55ba00ca}},	//   teri_, dmat_, raća_, _המנו,
   {{0x394000c2,0x2a7f033b,0xb5fd366a,0x7bc500d4}},	//   äisi_, _ljub_, rišu, jchu,
   {{0x2018366b,0x43750130,0x7bdc366c,0x634a00a7}},	//   reri_, _מײַן_, _reru, rənc,
   {{0x7bdc113a,0x20010294,0x3ea9366d,0xb5fd015c}},	//   _seru, _echi_, gmat_, cišt,
   {{0x7bdc2590,0x2018366e,0x6abc366f,0xc5e80033}},	// [2b60] _peru, peri_, _surf, ক্কা_,
   {{0xdb0e026e,0xf1bf3670,0x8fa63671,0x20180052}},	//   _agbá, ndán_, _напе, qeri_,
   {{0x7bdc3672,0x2ba70b94,0x68f901c0,0x1c020034}},	//   _veru, केला, euwd, र्गल_,
   {{0x7bdc3673,0xfc3f03be,0x290600c2,0xda650190}},	//   _weru, _xuíz_, ttoa_, واني,
   {{0x7bdc0332,0x3a26000b,0xf918001c,0x3a241d91}},	//   _teru, rdop_, تراژ_, _vamp_,
   {{0x7bc53674,0xb5fd08c5,0x6e260bb6,0x2a7f3675}},	//   cchu, zišt, _hakb, _ejub_,
   {{0x29063676,0x98a4020a,0xc66a007b,0x7ae5009c}},	//   stoa_, _armă_, йшие_, csht,
   {{0xb86600d0,0xa5343677,0x6e260034,0xddc40034}},	//   _کارو, днич, _jakb, jniż,
   {{0xb5fd2188,0xfc3f167e,0x6e263678,0x32190031}},	//   višt, _ruíz_, _makb, vesy_,
   {{0x3ea93679,0x6e26367a,0xe9ff020b,0x00000000}},	//   zmat_, _lakb, _toản_, --,
   {{0xb5fd2617,0x04fe0081,0xe9ff0023,0x3ea90a5d}},	//   tišt, ্টের_, _hoạn_, ymat_,
   {{0x2001367b,0x76bb00ca,0x3ea911bc,0x00000000}},	//   _schi_, _המאפ, xmat_, --,
   {{0xb5fd02e6,0x32191670,0x61fd093e,0x9f5101cd}},	//   rišt, resy_, rgsl, _íbúa_,
   {{0x04200081,0xb5fd0234,0x752209d8,0x00000000}},	//   বাহী_, sišt, _isoz, --,
   {{0xb5fd030b,0xe9ff0019,0x9f34004d,0x6e26367c}},	//   pišt, _loạn_, нері, _bakb,
   {{0x5f9400d6,0x5eb40870,0x644a1e72,0x3ea931cf}},	//   хист, ейст, _hofi, umat_,
   {{0x644a367d,0x61ed29e6,0x628f0181,0xad9b0065}},	// [2b70] _kofi, _idal, moco, _abúr,
   {{0x60cd367e,0x5ba733d4,0x628f3536,0x2001367f}},	//   _itam, през, loco, _uchi_,
   {{0x7bc53680,0x644a0f20,0xa1340260,0x6602007e}},	//   rchu, _mofi, _قریش, _ocok,
   {{0xe1ff3681,0x7bc53682,0x7ae500dd,0x6e260090}},	//   ngó_, schu, rsht, _gakb,
   {{0xa95400d6,0x08c400f3,0xddd60031,0x75223683}},	//   нкці, ебін, dkyň, _nsoz,
   {{0xf7700979,0x644a3684,0x7ae5023b,0x60cd0051}},	//   گاه_, _nofi, psht, _mtam,
   {{0x16a90ed1,0x628f3685,0x61ed3686,0xab95004d}},	//   овки_, koco, _odal, _циві,
   {{0x7c273687,0x61ed3688,0x60cd3689,0x2a7f368a}},	//   _hajr, _ndal, _otam, _ujub_,
   {{0x644a368b,0x68e400e3,0x60cd1a0f,0x7c27368c}},	//   _bofi, áidt, _ntam, _kajr,
   {{0x61ed1268,0x644a368d,0x6602063d,0x55ff0033}},	//   _adal, _cofi, _ecok, ্যেক_,
   {{0x60cd368e,0x1c0208fa,0x67210477,0x628f305a}},	//   _atam, र्टल_, _uslj, foco,
   {{0x628f002b,0x68e933c2,0x00000000,0x00000000}},	//   goco, _kved, --, --,
   {{0x98a400d3,0x61ed368f,0x6e263690,0x644a3691}},	//   _urmă_, _ddal, _rakb, _fofi,
   {{0x764b0068,0x7c273692,0x60cd3693,0x661b3694}},	//   _hogy, _najr, _dtam, leuk,
   {{0x2dcb0857,0x628f3695,0x60cd2c58,0x28dd2373}},	//   _ụlọ_, boco, _etam, नीति,
   {{0x44273696,0x661b3697,0xf1bf1125,0x764b1a3a}},	//   _han_, neuk, ndál_, _jogy,
   {{0x44273698,0x7c273699,0xfce30084,0x3cf500a5}},	// [2b80] _kan_, _bajr, кото, एंगे_,
   {{0x4427369a,0x61ed1d25,0xb05b32ee,0x69c9026d}},	//   _jan_, _zdal, spär, _afee,
   {{0x4427256f,0x6e26369b,0xe1ff369c,0xa05700c1}},	//   _man_, _takb, ciós_, _חסיד_,
   {{0x4427369d,0xe1ff00a5,0x7c270634,0x6e26010a}},	//   _lan_, chód_, _eajr, _uakb,
   {{0x09e310f7,0x44270023,0xe3e30081,0x3e77003d}},	//   точн, _oan_, _মানব, għtu_,
   {{0x4427369e,0x68e9007e,0xb8e609a1,0x7afa02c3}},	//   _nan_, _dved, _ईं_, _åtto,
   {{0x69c9083e,0xeb972c37,0x752206b0,0x644a369f}},	//   _ffee, _жир_, _ssoz, _rofi,
   {{0x442736a0,0x661b0051,0x7c270034,0x764b00eb}},	//   _aan_, geuk, _zajr, _cogy,
   {{0x442736a1,0x628f36a2,0xe7cf332a,0xd7cf034d}},	//   _ban_, voco, _स्वप, _स्वच,
   {{0x4427004f,0xddd624a1,0x00000000,0x00000000}},	//   _can_, skyň, --, --,
   {{0x442736a3,0x764b0018,0x68e92449,0xd3700037}},	//   _dan_, _fogy, _zved, اهج_,
   {{0xc7b836a4,0x442736a5,0x925800c2,0x644a36a6}},	//   _nađi_, _ean_, дают_, _wofi,
   {{0x442736a7,0xe8050b95,0x644a36a8,0xe1ff36a9}},	//   _fan_, _रामा_, _tofi, rgó_,
   {{0x442736aa,0xa3df2014,0x628f36ab,0xd4c50037}},	//   _gan_, तरण_, soco, _أغني,
   {{0x764b36ac,0x2bdd0096,0x3f852ddc,0x626b00d2}},	//   _yogy, यरसा, çlu_, dřov,
   {{0x61ed36ad,0x442736ae,0x7c2700cd,0x2cb8152f}},	//   _udal, _zan_, _sajr, _aird_,
   {{0x442736af,0x6e940b26,0x60cd03ec,0xe1ff36b0}},	// [2b90] _yan_, титу, _utam, biór_,
   {{0x69c90126,0x4cc80081,0x442736b1,0x22990103}},	//   _sfee, _লিখু, _xan_, déki_,
   {{0x68e936b2,0xaca30134,0xa3df02d5,0x2ef400ae}},	//   _sved, _nrụb, तरत_, _изэр,
   {{0x5ba400d3,0xdd91212c,0xdb0e01f9,0x37d80033}},	//   труз, _موج_, áján, _সাগর,
   {{0x7c2702a1,0xe6ed0181,0xcce700e3,0xcdf60266}},	//   _tajr, _väčš, _تسجي, _אמרי_,
   {{0x07a50318,0xa15800ca,0x00000000,0x00000000}},	//   налн, ובדה_, --, --,
   {{0x442736b3,0x3eb936b4,0x2bae045f,0x661b01ce}},	//   _ran_, _kist_, झेदा, teuk,
   {{0x2d9900c2,0x1c100096,0x66c70233,0x68e90b81}},	//   _kyse_, ठ्ठल_, _cıka, _tved,
   {{0x68e90618,0x3eb936b5,0xe5790084,0x442736b6}},	//   _uved, _mist_, язи_, _pan_,
   {{0x3eb936b7,0x442736b8,0x98ad007e,0x00000000}},	//   _list_, _qan_, _kreč_, --,
   {{0x442736b9,0xe29a0aeb,0x2d9901df,0x3eb90270}},	//   _van_, зан_, _lyse_, _oist_,
   {{0x442736ba,0x00000000,0x00000000,0x00000000}},	//   _wan_, --, --, --,
   {{0xdb1c0222,0x442736bb,0x634a00a7,0x00000000}},	//   _ifrå, _tan_, lənl, --,
   {{0x442736bc,0x3eb9009c,0x6d4036bd,0x00000000}},	//   _uan_, _aist_, _àmai, --,
   {{0x3eb936be,0x66c7026a,0xa0a336bf,0x3229007b}},	//   _bist_, _yıka, уард, ötyä_,
   {{0x3eb936c0,0x2d9903a8,0x00000000,0x00000000}},	//   _cist_, _byse_, --, --,
   {{0x61e636c1,0x626b00b6,0x0d8600ae,0x6e9336c2}},	// [2ba0] makl, třov, хлан, القا,
   {{0x61e636c3,0xa3df0ff9,0x3eb936c4,0x4f2636c5}},	//   lakl, तरि_, _eist_, _здоб,
   {{0x09d700c7,0xb3460161,0x20c600de,0x6296010a}},	//   _হাজা, maçõ, _hôi_, _kkyo,
   {{0x2cb802d6,0xb346001f,0x61e636c6,0x320236c7}},	//   _wird_, laçõ, nakl, ngky_,
   {{0x626b02c6,0xa3df0c17,0xb4de00aa,0x00000000}},	//   přov, तरा_, _तबे_, --,
   {{0xeee700bf,0x20c60019,0xd6da09f2,0xb3460161}},	//   _تغیی, _môi_, пти_, naçõ,
   {{0xf0930105,0x20c600de,0x61e636c8,0x44dd0031}},	//   אנג_, _lôi_, kakl, eň_,
   {{0x96342249,0x629606b0,0x7e64024a,0x354636c9}},	//   тниц, _nkyo, nhip, ехов,
   {{0x06e004f1,0x61e62b0f,0x7afe36ca,0x20c60023}},	//   _गौरव_, dakl, lupt, _nôi_,
   {{0x54542de0,0x629636cb,0xdb1c023b,0x6d5636cc}},	//   твот, _akyo, _ngrë, iyya,
   {{0xb346016d,0x7e640201,0x66c70233,0x7afe078e}},	//   daçõ, khip, _tıka, nupt,
   {{0x20c600de,0xa75b0327,0xbddb0154,0x634a00a7}},	//   _bôi_, _מדבר, _inèg, səno,
   {{0x518436cd,0x7e6403a9,0x20c60023,0x3eb9300e}},	//   гура, dhip, _côi_, _rist_,
   {{0x3eb902ec,0xb34636ce,0x634a0092,0x20050103}},	//   _sist_, gaçõ, lənm, üli_,
   {{0x61f40212,0x5f95016d,0xe8120096,0x78ba042c}},	//   ådlö, тивт, ढ्या_, _mitv,
   {{0x78ba36cf,0x61e601e8,0x439b00a1,0x7e6436d0}},	//   _litv, cakl, _מבוג, ghip,
   {{0x3eb936d1,0x8d770bf4,0x442c0150,0x67020096}},	// [2bb0] _vist_, رارا, odd_, रंडक_,
   {{0x645a36d2,0xb3460396,0xe80509c3,0x3eb90126}},	//   nkti, caçõ, _राधा_, _wist_,
   {{0x442c36d3,0x2d99057a,0x443c007e,0x7afe0090}},	//   idd_, _wyse_, _mnv_, gupt,
   {{0x7d09020a,0x443c0381,0x98ad0141,0x200336d4}},	//   _ţesu, _lnv_, _vreč_, lgji_,
   {{0x6e3d01bf,0x26de36d5,0x20c60023,0x88c8004d}},	//   _insb, _awto_, _xôi_, елів_,
   {{0xa3bc1244,0x61e6062d,0x6e2d36d6,0xc7b800e7}},	//   _अलग_, zakl, ldab, _lađu_,
   {{0x7d0d36d7,0xddcd00d3,0x81e70033,0xdb1c01dc}},	//   ltas, ciaţ, _পান_, _ngrè,
   {{0x6e2d36d8,0xb34600c9,0x442c02e0,0x443c36d9}},	//   ndab, zaçõ, edd_, _anv_,
   {{0x12bd00c7,0x443c36da,0xc48500d6,0x2c640149}},	//   _আবেদ, _bnv_, клик, _född_,
   {{0x799b01c2,0x629d0313,0x443c36db,0x61e60063}},	//   _iyuw, elso, _cnv_, wakl,
   {{0x61e636dc,0x7d0d36dd,0x20c600de,0xb3460161}},	//   takl, htas, _sôi_, vaçõ,
   {{0x27e736de,0x7d0d36df,0x443c36e0,0x6e2d023e}},	//   lann_, ktas, _env_, jdab,
   {{0xb3460396,0x61e636e1,0x6e2d008a,0x443c36e2}},	//   taçõ, rakl, ddab, _fnv_,
   {{0x27e70080,0x7d0d01c5,0x10a633d6,0x61e636e3}},	//   nann_, dtas, тигн, sakl,
   {{0xb3460396,0xdee31693,0xafe30070,0x7e6436e4}},	//   raçõ, иори, росл, thip,
   {{0x20c600ef,0x27e736e5,0xdcf402ef,0x6d440a00}},	//   _tôi_, hann_, žačk, txia,
   {{0x7d0d2783,0x799b00bf,0xdbdf003e,0x614636e6}},	// [2bc0] gtas, _nyuw, tíði, _репа,
   {{0x61e423ff,0xe3b80740,0x3f9a1670,0x27e702f1}},	//   _heil, mdır_, _typu_, jann_,
   {{0xbddb36e7,0x27e736e8,0x09e636e9,0x61e436ea}},	//   _poèt, dann_, воен, _keil,
   {{0x6aa936eb,0x7afe36ec,0x60c40010,0x6abb36ed}},	//   _chef, rupt, _kuim, _ciuf,
   {{0x442c1a2e,0xe3b8008e,0x27e736ee,0x645a05e8}},	//   ydd_, ndır_, fann_, ykti,
   {{0xcee914df,0x27e736ef,0x61e436f0,0x60c436f1}},	//   _ترین_, gann_, _leil, _muim,
   {{0x8a0628b9,0xa7fc0587,0xb8c90ccb,0x60c40076}},	//   _изве, _alıc, _गी_, _luim,
   {{0xfaa636f2,0x61e436f3,0x442c02ad,0x765b019c}},	//   _рабо, _neil, wdd_, gkuy,
   {{0xd3781419,0x27e736f4,0x47e10081,0x090619e8}},	//   maći_, bann_, _নারী, _шпан,
   {{0x78ba04ee,0xdb1c0257,0x27e7033f,0x6b9c36f5}},	//   _uitv, _agré, cann_, _kyrg,
   {{0x442c02e0,0x7d0d36f6,0x2c140789,0xa2b500e5}},	//   rdd_, ztas, न्यू_, лбоч,
   {{0xd378084f,0x7d0d36f7,0x442a0087,0x645a36f8}},	//   naći_, ytas, žb_, skti,
   {{0x61e436f9,0x60c410f0,0xd2510018,0x46130281}},	//   _deil, _cuim, لنگ_, _خونر,
   {{0xa2ca167f,0x645d023b,0x394636fa,0xe5a31c3e}},	//   _संप्, ësit, ixos_, _тичи,
   {{0x61e436fb,0x260f13ae,0x2003023b,0x3ce8009f}},	//   _feil, थ्वी_, rgji_, _चौबे_,
   {{0x7d0d32a7,0x61e436fc,0x60c436fd,0x22990094}},	//   ttas, _geil, _fuim, téku_,
   {{0x60c436fe,0x16df121d,0xf1c40094,0xd3780357}},	// [2bd0] _guim, _नब्ब, ášť_, daći_,
   {{0x7d0d36ff,0xbbdd0455,0x61e43700,0x6aa93701}},	//   rtas, यरेक, _zeil, _shef,
   {{0x27e73702,0xddc600a5,0x3946002b,0xd9f93703}},	//   vann_, _dokł, exos_, енец_,
   {{0x27e73704,0xa2ca167f,0x99d40190,0x00000000}},	//   wann_, _संन्, لتها, --,
   {{0x27e73705,0xee3f0181,0xe9d801b3,0xa3e300a3}},	//   tann_, _iný_, ткі_, _फजल_,
   {{0xfa230081,0x6b9c3706,0x00000000,0x00000000}},	//   ফাইল_, _fyrg, --, --,
   {{0x27e73707,0x12bd0081,0xe3b8008b,0x6aa93708}},	//   rann_, _আব্দ, zdır_, _thef,
   {{0x27e73709,0xddcd0029,0x060914fb,0xf6250e3a}},	//   sann_, skaņ, хник_, удио,
   {{0x27e7370a,0x61e4370b,0x3a3f0124,0xe6160c5f}},	//   pann_, _reil, _inup_, уды_,
   {{0x60c404ee,0x61e4370c,0xe3e30033,0x765b0124}},	//   _ruim, _seil, _মাহব, skuy,
   {{0x91e6370d,0x60c4370e,0x212923b0,0x65690103}},	//   лоне, _suim, _asah_, szeh,
   {{0x94030022,0xe3b800a7,0x00000000,0x00000000}},	//   ƙƙoƙ, tdır_, --, --,
   {{0x61e4370f,0x645d01e5,0x290f0324,0xc6922252}},	//   _veil, ësis, ntga_, _פאד_,
   {{0xe3b80702,0x26c53710,0x61e43711,0x99dd00d2}},	//   rdır_, _kulo_, _weil, _koňs,
   {{0x61e43712,0x21290063,0x9975007f,0x26c50af0}},	//   _teil, _esah_, nęło_, _julo_,
   {{0xa2060eea,0x26c53713,0x6fd4014e,0x60c43714}},	//   _спид, _mulo_, _ब्रू, _tuim,
   {{0x0eb90963,0x22400383,0x4c863715,0xe3b80092}},	// [2be0] туры_, _inik_, глав, qdır_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd37803d6,0x22400abf,0xfaa60284,0x00000000}},	//   taći_, _knik_, гажо, --,
   {{0x1efb0341,0xc9860c59,0x2cb000c6,0x3ce805cd}},	//   _אלטע, лули, _žodį_, _चौथे_,
   {{0xed57036a,0xf9920308,0xd37814f3,0x00000000}},	//   _боя_, حبا_, raći_, --,
   {{0x3ea03716,0x66c70b88,0xf7720068,0xf72a004c}},	//   llit_, _tıkl, یاں_, еций_,
   {{0x26c53717,0xb8eb0c9c,0xd378037d,0x224001c8}},	//   _culo_, _रू_, paći_, _onik_,
   {{0x7c2e3718,0x26c50bb6,0x3ea0003e,0x09de0033}},	//   _habr, _dulo_, nlit_, _ডাকা,
   {{0x59863719,0x634a01d4,0x7c2e371a,0x270e0092}},	//   _слаб, məni, _kabr, _məni_,
   {{0x634a0092,0xd91b0089,0x245200ae,0x38a90206}},	//   ləni, _אומל, _câmp_, túre_,
   {{0x3ea0371b,0x7c2e1606,0x36060602,0x26c5371c}},	//   klit_, _mabr, _مواف, _gulo_,
   {{0x7c2e371d,0x21b500d6,0xa2950426,0xdbdf003e}},	//   _labr, ийня, рамі, _líðu,
   {{0x667b00c1,0x463b006e,0x3ea0371e,0x26c50634}},	//   _אטאק, _רעדע, dlit_, _zulo_,
   {{0x224000e7,0xe1ff0328,0x3e6700aa,0x5334371f}},	//   _enik_, chón_, _mõte_, _вект,
   {{0xe7f7143d,0x442e0149,0x634a0092,0x316b3720}},	//   ीलता_, _iaf_, kəni, szcz_,
   {{0x3ea03721,0x442e3722,0xddcd3723,0x2bdd0d7a}},	//   glit_, _haf_, snaž, यर्थ,
   {{0x3cee0067,0x634a01d4,0x21290655,0x442e3724}},	// [2bf0] ेंगे_, dəni, _usah_, _kaf_,
   {{0x442e3725,0x3ea009d6,0x9f4300b6,0x3a3f02b6}},	//   _jaf_, alit_, lají_, _snup_,
   {{0x2baa02e8,0x3ea03726,0x7c2e3727,0xbb840037}},	//   _करणा, blit_, _dabr, ملكي,
   {{0x27e50b14,0x9f4300b6,0x7c2e009c,0x442e3728}},	//   _seln_, nají_, _eabr, _laf_,
   {{0x7c2e3729,0xd3780106,0xd945372a,0x00000000}},	//   _fabr, maću_, рели, --,
   {{0x46f52e81,0x442e372b,0x26c5372c,0x2c142010}},	//   ачит, _naf_, _pulo_, न्दू_,
   {{0xf7710fba,0x3669372d,0x270e0092,0x9f4300b6}},	//   غات_, како_, _yəni_, kají_,
   {{0x7c2e11d5,0xbb840080,0x2baa02e8,0x7ae300d3}},	//   _zabr, _الفي, _करता, ântu,
   {{0x81eb0081,0x9f43030b,0x98b9372e,0x6e2f372f}},	//   মলা_, dají_, _алат_, _macb,
   {{0x26c53730,0xd3781528,0xf8b91f11,0x7c2e002b}},	//   _tulo_, haću_, _شهاب_, _xabr,
   {{0x03a50d9b,0xd37809ac,0x53a5016d,0x383400d3}},	//   рино, kaću_, ранб, _ынфр,
   {{0x67b80192,0xcb1200ca,0xd378007e,0x00000000}},	//   _صالح_, חלט_, jaću_, --,
   {{0xd3780995,0x04453283,0x00000000,0x00000000}},	//   daću_, _велн, --, --,
   {{0x442e3731,0x05a800d6,0x270e0092,0xad9b0037}},	//   _gaf_, _свій_, _səni_, _gcúi,
   {{0x634a0092,0xdee63732,0x3ea03733,0xa2a70096}},	//   yəni, роби, tlit_, _टीव्,
   {{0xdbdf0102,0x22403734,0x3f8c003d,0x3ea03735}},	//   _síðu, _unik_, ħdu_, ulit_,

   {{0x3ea00088,0x7c2e3736,0x645c3737,0x37e60033}},	// [2c00] rlit_, _pabr, örig, _নাসর,
   {{0xa7fc0702,0x3ea03738,0x7c2e0188,0x2baa00aa}},	//   _alın, slit_, _qabr, _करदा,
   {{0x62870074,0xf1a9001c,0x634a0092,0xd37809ac}},	//   čkov, _لایه_, təni, baću_,
   {{0xeb973739,0x6286373a,0x2c640149,0x3e7f007b}},	//   ших_, nnko, _döda_, rätä_,
   {{0x7c2e373b,0x634a00a7,0x93bc00ae,0x3e7f00c2}},	//   _tabr, rəni, ndăr, sätä_,
   {{0x7d043589,0xceb40092,0x2c640212,0x634a00a7}},	//   muis, lmə_, _föda_, səni,
   {{0x7d04373c,0xa2ca03a2,0x368a0ef1,0x81e70033}},	//   luis, _संध्, ксин_, _পাস_,
   {{0x2bd20ded,0x442e373d,0x95d700e5,0xceb4013c}},	//   दुरा, _saf_, адът_, nmə_,
   {{0x9f43030b,0x7d04373e,0x00000000,0x00000000}},	//   vají_, nuis, --, --,
   {{0x6286373f,0xb80600cd,0x6e2401bf,0x442e3740}},	//   enko, _خبره, heib, _qaf_,
   {{0x7d043741,0x22920094,0x9f4302c6,0x43940859}},	//   huis, láky_, tají_, санс,
   {{0x7d043742,0x442e3743,0x62860b81,0x00000000}},	//   kuis, _waf_, gnko, --,
   {{0x442e1599,0x7d043744,0x61f602ad,0xe4d409e5}},	//   _taf_, juis, _ddyl, _اقتد,
   {{0x03770260,0x7d043745,0x251b0089,0x62863746}},	//   احیت_, duis, _סווא, anko,
   {{0xf0b400d6,0xe80e00b6,0x6aa23747,0x1df90fe9}},	//   ійсь, _साना_, klof, левы_,
   {{0x2c640149,0xdce601e8,0x5f943748,0x00000000}},	//   _röda_, _aykı, цист, --,
   {{0x7d043749,0xd90412eb,0xa2ca1687,0xd378042d}},	// [2c10] guis, _تی_, _सूत्, raću_,
   {{0x38a9374a,0x80dd0033,0xd3780e94,0x2292023c}},	//   kúra_, _বিপ্, saću_, dáky_,
   {{0x5b151087,0x76420172,0x00000000,0x00000000}},	//   смет, _onoy, --, --,
   {{0x7d04374b,0xe8f500e3,0x3d0702d5,0x00000000}},	//   buis, مستخ, िंदे_, --,
   {{0x3cfe0067,0x7d04374c,0x8d840e1d,0xb7c30231}},	//   _लिये_, cuis, _дурд, çãoz,
   {{0xf1bf0103,0x26d90094,0x2bcb0450,0xd3662164}},	//   ldás_, _čsob_, _шумо_, _فه_,
   {{0xda351ad1,0x62860034,0x9986374d,0x81bf0033}},	//   _левы, ynko, rdoš_, েরি_,
   {{0x7c25374e,0xf1bf01f9,0x229200d4,0x80dd0033}},	//   lehr, ndás_, báky_, _বিন্,
   {{0x78bd0036,0x673a0f5a,0x229200d4,0x2aff074c}},	//   _èsvo, _ertj, cáky_, शंकु_,
   {{0xb46502fd,0x98650018,0x81bf0033,0x6e24374f}},	//   скол, _دیتے_, েরা_, zeib,
   {{0x6e243750,0x673a0381,0x60d63751,0x00000000}},	//   yeib, _grtj, _stym, --,
   {{0x99800038,0x628601e9,0x201a0063,0x17680b9e}},	//   žiť_, unko, _sbpi_, _труп_,
   {{0xf65200a1,0xd5480adb,0x7c250364,0x62860b84}},	//   _מצא_, _نجوم_, kehr, rnko,
   {{0x753600c1,0x1c0305a7,0x75293752,0x66093753}},	//   _לאנד_, _लागल_, mwez, lgek,
   {{0x64433754,0x44253755,0xceb40092,0x81e70033}},	//   _inni, mel_, tmə_, _পার_,
   {{0x66093756,0x7d040423,0xf1d10179,0x75290a4b}},	//   ngek, tuis, थुआन, owez,
   {{0x75290ab2,0x6e243757,0x291f006c,0xceb40092}},	// [2c20] nwez, reib, _npua_, rmə_,
   {{0x22920146,0xa3ab1fbb,0x7c250364,0xc006186d}},	//   váky_, _खरा_, gehr, _упок,
   {{0x291f0084,0x7d043758,0x75293759,0x201813ea}},	//   _apua_, suis, hwez, mfri_,
   {{0x4425375a,0x22920146,0x7d041c1e,0x75290201}},	//   hel_, táky_, puis, kwez,
   {{0x4425375b,0x64430084,0x2baa02b0,0x660904e2}},	//   kel_, _onni, _करवा, dgek,
   {{0xbb460978,0xd90d00d0,0x38a9375c,0x200a375d}},	//   _легк, ئیل_, túra_, ngbi_,
   {{0xe80e1349,0xf1bf0220,0xf1c80e19,0x6aa20f5a}},	//   _साठा_, ndár_, रखान, plof,
   {{0x4425043e,0x660902f9,0x6443375e,0x26ca0131}},	//   eel_, ggek, _anni, _ébom_,
   {{0x4425375f,0x89663760,0xd90d0504,0x96170037}},	//   fel_, _укаж, _لین_, صغير_,
   {{0xe8d700ca,0x29060a4b,0x00000000,0x00000000}},	//   _לומר_, muoa_, --, --,
   {{0xf7433761,0xdb0e0065,0x2f380383,0x9f4a00d1}},	//   _нефо, _igbó, _nčg_, babé_,
   {{0x32670b57,0x64433762,0x466900d6,0x21200167}},	//   стов, _enni, _крім_, _bpih_,
   {{0x44253763,0x2018003d,0x9f4100b3,0x752904ff}},	//   bel_, ffri_, _vehí_, cwez,
   {{0x44253764,0x27ee003e,0x2e350134,0xe81b0296}},	//   cel_, nafn_, _ụf_, प्पा_,
   {{0x447b00ca,0x00000000,0x00000000,0x00000000}},	//   _תנוע, --, --, --,
   {{0x7c250364,0x62870094,0x2906024a,0x00000000}},	//   wehr, čkos, kuoa_, --,
   {{0xa7fc026a,0x463b00c1,0xdb1c0428,0xdc550291}},	// [2c30] _alım, נעמע, _agrà, овањ,
   {{0x61ef0e2a,0xba3d00b6,0x00000000,0x00000000}},	//   lacl, _lhůt, --, --,
   {{0x50d40068,0x212b02ad,0x99d700e3,0xfbab00c6}},	//   _وزیر, lwch_, متشا, утай_,
   {{0x44253765,0x61ef3766,0xdb0e0af0,0x00000000}},	//   zel_, nacl, _agbó, --,
   {{0x44253767,0x212b0150,0xa2bc006e,0xfbe80033}},	//   yel_, nwch_, אמאט, _পারত,
   {{0xf9902ce3,0x7e6d2c70,0xb901007a,0x00000000}},	//   ربن_, lhap, _दऽ_, --,
   {{0x44253768,0x2bdf0e4c,0xb8d005cd,0x66090db1}},	//   vel_, _प्या, _टी_, tgek,
   {{0x44253769,0x0f7c00a1,0xd04d03e3,0x7e6d376a}},	//   wel_, טרול, _kwaɓ, nhap,
   {{0x4425376b,0x66092d6d,0x61ef0072,0x20181307}},	//   tel_, rgek, dacl, yfri_,
   {{0x66090f7a,0x212b0150,0x752901c0,0x44251aab}},	//   sgek, dwch_, rwez, uel_,
   {{0x44250fd1,0x7e6d376c,0x224a0161,0x634a013c}},	//   rel_, khap, апни_, dəns,
   {{0x4425376d,0xd6ab2c66,0x2f3805aa,0x00000000}},	//   sel_, _صدام_, _rčg_, --,
   {{0xa4f709b4,0x7e6d00d1,0x212b00f0,0x00000000}},	//   _اکبر_, dhap, gwch_, --,
   {{0x64430088,0x316c007f,0x00000000,0x00000000}},	//   _unni, ądz_, --, --,
   {{0xe81b0096,0x1fb5376e,0xa0a3376f,0x749a021e}},	//   प्या_, зстр, фард, _דיספ,
   {{0x00ca11f8,0x7bd5029a,0x7e6d243d,0xf1bf0072}},	//   _клик_, _afzu, ghap, meán_,
   {{0x63a302ad,0xf1bf00e3,0xec7a2657,0x6da30bb4}},	// [2c40] _hynn, leán_, апа_, дита,
   {{0x63a33770,0x67210039,0x0c2300c2,0x3e6700aa}},	//   _kynn, _oplj, ммун, _võta_,
   {{0x49ca0fa5,0xdb0e0065,0x7e6d0201,0xddc4020a}},	//   ален_, _agbò, bhap, ghiţ,
   {{0x7e6d3771,0x63a33772,0x09e30396,0x6d4d008c}},	//   chap, _mynn, доцн, bxaa,
   {{0xb5fd0031,0x67d40379,0x522d0142,0x00000000}},	//   chši, полу, טואַ, --,
   {{0x6e36013f,0x3a260167,0x00000000,0x00000000}},	//   ldyb, seop_, --, --,
   {{0xdb0e0032,0x7d163773,0x61ef013c,0x63a313ea}},	//   _egbò, ltys, yacl, _nynn,
   {{0x6e363774,0xf1bf00e3,0x27ee0088,0x7bc7023b}},	//   ndyb, deán_, safn_, _zgju,
   {{0xceb3040a,0x7d163775,0x63a3026d,0x7afa04c8}},	//   ויה_, ntys, _aynn, _ættb,
   {{0x31e3009d,0x63a30150,0xc8660037,0xb8660dd0}},	//   पर्ध, _bynn, _بطري, _بارو,
   {{0x63a302e0,0x61ef3776,0xe3b8026a,0x7e6400c2}},	//   _cynn, tacl, ldız_, kkip,
   {{0x212b0150,0x63b50146,0x63a300f0,0x00000000}},	//   twch_, ýzna, _dynn, --,
   {{0xa2ca04a9,0x26cc3777,0x61ef0d54,0x00000000}},	//   _सूर्, _hudo_, racl, --,
   {{0x80dd00c7,0x26cc023b,0x212b0150,0x61ef028d}},	//   _বিদ্, _kudo_, rwch_, sacl,
   {{0x63a302e0,0x8f343778,0x7e6d3779,0x64580036}},	//   _gynn, мерц, thap, _iovi,
   {{0x26cc0188,0x645813a2,0xa195036c,0x60dd1a88}},	//   _mudo_, _hovi, _найч, ppsm,
   {{0x6458377a,0x7e6d377b,0xa3b600b6,0x00000000}},	// [2c50] _kovi, rhap, चेर_, --,
   {{0x6458031a,0x61ed377c,0x7e6d377d,0xc8a900c3}},	//   _jovi, _heal, shap, _चींट,
   {{0x6458377e,0x7e6d377f,0x61ed02e7,0x26cc3780}},	//   _movi, phap, _keal, _nudo_,
   {{0x64583781,0x60cd0010,0xf1af0557,0x7e640312}},	//   _lovi, _kuam, _घरान, ckip,
   {{0xcfbd0081,0x6d4b0149,0x60cd3782,0xa3ca030b}},	//   _অভিন, ågad, _juam, लखा_,
   {{0x61ed3783,0x26cc3784,0xd5e20139,0xdced0094}},	//   _leal, _budo_, _alò, nzač,
   {{0x26cc0580,0x25a90660,0xad9b0037,0x9a870077}},	//   _cudo_, _šal_, _gcúr, _дуал,
   {{0xdb1c0018,0x26cc034f,0x629d0850,0x7c353785}},	//   _ugrá, _dudo_, joso, _hazr,
   {{0x63a33786,0x656000f0,0x69c93787,0x49040037}},	//   _synn, gymh, _igee, _يوفق,
   {{0x68e90134,0x26cc3788,0xf1bf0037,0x1309007b}},	//   _iwed, _fudo_, teán_, бной_,
   {{0x61ed3789,0x7c35378a,0x6458378b,0xbddb00ee}},	//   _beal, _mazr, _dovi, _anèm,
   {{0xf1bf00e3,0x61ed378c,0x66d70134,0x7d1600c2}},	//   reán_, _ceal, _ụkwa, ytys,
   {{0xf1bf00e3,0x61ed378d,0x60cd009c,0x63a3378e}},	//   seán_, _deal, _cuam, _wynn,
   {{0x653a00c1,0x63a3378f,0x7c353790,0x09a90034}},	//   _לענד, _tynn, _nazr, _औरैय,
   {{0x629d20bb,0x69c93791,0x61ed3792,0xbbaa149b}},	//   boso, _ogee, _feal, _करेक,
   {{0x61ed0091,0x6458015c,0x644600d9,0x69c907f5}},	//   _geal, _zovi, ēkie, _ngee,
   {{0xf1bf00e3,0x60cd00dc,0x6458039f,0x7d160381}},	// [2c60] neál_, _guam, _yovi, utys,
   {{0x7e643793,0x69c906b0,0xeb9a0231,0x61ed3794}},	//   skip, _agee, биз_, _zeal,
   {{0xe8052065,0x7d163795,0x6d4b0149,0x68e93796}},	//   _राजा_, stys, ägar, _awed,
   {{0x765900a5,0x60cd023e,0x0ae90037,0xdce40a39}},	//   _nowy, _yuam, تركي_, jzić,
   {{0x7c350063,0x63a60034,0x00000000,0x00000000}},	//   _fazr, ękni, --, --,
   {{0xb8f41cd4,0x26cc0890,0xa3ab0096,0x2bdb261e}},	//   _सं_, _pudo_, _खरं_, मुदा,
   {{0x7522138c,0x629d3797,0xd6d70ae3,0x25c10092}},	//   _spoz, yoso, пты_, ərlə_,
   {{0x80dd00c7,0xfaa300d6,0xb17b01df,0x69c90172}},	//   _বিস্, _засо, dbån, _ggee,
   {{0x64583798,0x68e90150,0xb5fd01d3,0xf64f0037}},	//   _povi, _gwed, ukša, ائى_,
   {{0x26cc00c9,0x7d043799,0xb5fd01d3,0x61ed379a}},	//   _tudo_, iris, rkša, _seal,
   {{0x61ed05a7,0x60cd06ee,0xe61a0c43,0x7d04008a}},	//   _peal, _suam, _где_, hris,
   {{0x7d04379b,0xad9b002b,0xbddb02f1,0x60cd0154}},	//   kris, _ocúp, _enèj, _puam,
   {{0xf48705bc,0xe5342c37,0x386c02c6,0x645813a2}},	//   _کانی, _цель, _kldr_, _tovi,
   {{0x629d379c,0x7d04379d,0x61e0008b,0x55bb0327}},	//   soso, dris, ımla, _המדו,
   {{0xda0d05d4,0x25af379e,0x60c500aa,0x26c60239}},	//   _हालत_, _zzgl_, _vihm, _kioo_,
   {{0x7d04379f,0x7c350335,0x60cd37a0,0xe0df028d}},	//   fris, _sazr, _tuam, ppò_,
   {{0xe7cc007d,0x22490181,0x82341f11,0x786f004d}},	// [2c70] ाशाप, _inak_, _سريا, _høve,
   {{0xdfd10037,0xdb1c02c3,0x00000000,0x00000000}},	//   _جيد_, _ogrä, --, --,
   {{0xaac70a09,0x7d0437a1,0xde59004d,0x78bd0036}},	//   ستان, aris, _дані_, _èsvi,
   {{0x7d0437a2,0x7d180080,0x68e900a6,0x37e60081}},	//   bris, éasá, _pwed, _নাগর,
   {{0x20d300c3,0x3ea90212,0x786f01df,0x2616007a}},	//   _धूमध, mlat_, _løve, _भउजी_,
   {{0x3ea937a3,0xad9b0065,0x013800a1,0xc7a500d6}},	//   llat_, _adúg, פרות_, милк,
   {{0xe80e034c,0x12c70081,0x765937a4,0xb8f40b95}},	//   _सारा_, _শব্দ, _powy, _सू_,
   {{0xd8770979,0x645c37a5,0x386c0090,0x7afa01cd}},	//   _کارب, örin, _eldr_, _ætta,
   {{0xbddb022b,0xddcd0138,0xdce40a39,0x661b1088}},	//   _anèk, kiaž, rzić, rfuk,
   {{0x224937a6,0x2a6d37a7,0x25a60383,0x3ea9007b}},	//   _anak_, _hleb_, _dyol_, hlat_,
   {{0x3ea90484,0xa22a37a8,0x04ff0033,0x80dd0033}},	//   klat_, ожна_, ্বের_, _বিষ্,
   {{0x7d040088,0x1fc50081,0x2a6d0167,0xd04d37a9}},	//   yris, ্রাস, _jleb_, _kwaɗ,
   {{0x3ea937aa,0x66c7026a,0xbbaa09a0,0x13a700d1}},	//   dlat_, _fıkr, _कर्क, تنگی_,
   {{0x80dd0f71,0x224937ab,0x63850c58,0x7d0437ac}},	//   _বিশ্, _enak_, _огла, vris,
   {{0xe29f0088,0x4f9537ad,0x8fa301a0,0x3ea937ae}},	//   boð_, ерту, варе, flat_,
   {{0xe1ff1515,0xecea1bc1,0xe058001c,0x00000000}},	//   lkón_, ждал_, _کیست_, --,
   {{0x32d30028,0xe80e10e9,0xd12f001c,0xbea337af}},	// [2c80] _hãy_, _साला_, _نمي_, татк,
   {{0x645700b3,0x3ea900ee,0x3cf90131,0x3ac8013c}},	//   _òxid, alat_, _dvsv_, _aşpa_,
   {{0x3ea937b0,0x00000000,0x00000000,0x00000000}},	//   blat_, --, --, --,
   {{0x7d040b87,0xaca40174,0x3ea90428,0x224900dc}},	//   pris, _inọr, clat_, _xnak_,
   {{0x20d41d2d,0xaac5001c,0xbdfb0281,0x2bdf055c}},	//   _jäi_, رتمن, _برپا_, _प्वा,
   {{0xd6da37b1,0xbddb0113,0x186726d0,0x4c350012}},	//   оти_, _anèh, мачи_, _пэст,
   {{0xdca31728,0x32d30023,0x7a240154,0xdc370142}},	//   _рари, _nãy_, _pčtč, _קאלט_,
   {{0xa3c30851,0xa5341693,0x786f0f04,0x3ea037b2}},	//   ्शन_, енич, _røve, noit_,
   {{0x64c837b3,0x26c60a4b,0x6d4000d8,0x00000000}},	//   रदेश, _vioo_, _šmaj, --,
   {{0x83860077,0x22491e8d,0x80dd0033,0x25a60154}},	//   дыме, _snak_, _বিল্, _vyol_,
   {{0xd37a00d6,0x22490113,0x00000000,0x00000000}},	//   ючи_, _pnak_, --, --,
   {{0x05660012,0x32d30023,0xb5fd00c6,0x475900ae}},	//   _овен, _dãy_, nkšl, _эруя_,
   {{0xa2ca000c,0x3ea937b4,0xaca40134,0xd8380141}},	//   _संक्, vlat_, _anọr, _kač_,
   {{0xdbf307aa,0x9f430220,0x961d01d3,0x29060072}},	//   _işçi, majú_, miņa, iroa_,
   {{0x442c37b5,0xc0580f1e,0x4908009f,0xd838042d}},	//   med_, фія_, _समझो_, _mač_,
   {{0x442c37b6,0x3ea937b7,0xd8380154,0xc1150da5}},	//   led_, ulat_, _chčz_, _змиј,
   {{0x442c0150,0x9f430031,0x865b00ca,0xdfd50ae3}},	// [2c90] oed_, najú_, קדמי, _попы,
   {{0x3ea9030b,0xb5fd01d3,0x290637b8,0xa1f90103}},	//   slat_, ekšl, droa_, _بڑھا_,
   {{0x2a6d023e,0x9f4337b9,0x5ba70ed7,0x29062c6f}},	//   _pleb_, hajú_, фраз, eroa_,
   {{0x442c37ba,0xdd140038,0x9f430220,0x22990146}},	//   hed_, _súťa, kajú_, téky_,
   {{0x26de008f,0x442c37bb,0xf1a50557,0x644a02ac}},	//   _atto_, ked_, _गुमन, _onfi,
   {{0x442c37bc,0x7d0d063f,0x9f430220,0x201137bd}},	//   jed_, muas, dajú_, ngzi_,
   {{0x442c004f,0x7d0d37be,0x46a5261f,0x626b01c2}},	//   ded_, luas, накв, nƙos,
   {{0xbb4800bf,0x2a7f03a9,0x442c01ee,0x290601ff}},	//   _تلفن_, _umub_, eed_, broa_,
   {{0x442c37bf,0x2bc30b94,0x79a707c8,0x7d0d00da}},	//   fed_, _वृता, _црве, nuas,
   {{0xe4510080,0x442c37c0,0x3ea00167,0x291a00ae}},	//   اضة_, ged_, zoit_, ăpat_,
   {{0xe28609b9,0x4e0f030b,0x7d0d37c1,0x69c400c6}},	//   елни, िलाई_, huas, žiet,
   {{0x7d0d048e,0x644a37c2,0x9f4337c3,0x442c00bc}},	//   kuas, _enfi, bajú_, aed_,
   {{0x764b0068,0x3e6e003e,0x442c37c4,0x3ea037c5}},	//   _ingy, _nýta_, bed_, voit_,
   {{0x2bdf097c,0x442c260b,0xa2ca18ff,0xa06a013f}},	//   _प्ला, ced_, _सूक्, чага_,
   {{0x3ea00e22,0x62580131,0x00000000,0x00000000}},	//   toit_, _mãoz, --, --,
   {{0x6e2d37c6,0x7d0d0051,0xbea32972,0x68fb010a}},	//   geab, fuas, гаск, _ovud,
   {{0x628637c7,0x3ea037c8,0x7d0d37c9,0x1c460f80}},	// [2ca0] miko, roit_, guas, ннам,
   {{0x628637ca,0x69db37cb,0xc19b0327,0x3ea000fc}},	//   liko, _afue, _משפי, soit_,
   {{0x9f430220,0x961d00d9,0xb5fd01d3,0x68fb0361}},	//   zajú_, ziņa, ekšm, _avud,
   {{0xfce637cc,0x628637cd,0x442c37ce,0x290637cf}},	//   _помо, niko, zed_, troa_,
   {{0xa967123a,0xd83802dd,0xaca40294,0x442c37d0}},	//   ница_, _pač_, _arụs, yed_,
   {{0x9f430181,0x628637d1,0x29060a00,0x442c00a1}},	//   vajú_, hiko, rroa_, xed_,
   {{0x628637d2,0x442c0054,0x7bce37d3,0x68fb06b0}},	//   kiko, ved_, _igbu, _evud,
   {{0x442c37d4,0x628637d5,0x9f430031,0x68e20668}},	//   wed_, jiko, tajú_, ppod,
   {{0x442c004f,0x628637d6,0xdb1c0076,0xf09f00b3}},	//   ted_, diko, _ngrú, dràn_,
   {{0x6aa201a2,0x9980013f,0x9f430220,0x764b37d7}},	//   loof, žių_, rajú_, _engy,
   {{0x442c37d8,0x628637d9,0xdb1c002b,0x7bce0134}},	//   red_, fiko, _agrú, _mgbu,
   {{0x442c37da,0x628637db,0x99890220,0x961d00e8}},	//   sed_, giko, žať_, piņa,
   {{0x442c00a1,0x7bce37dc,0x7bdc0052,0x38c60139}},	//   ped_, _ogbu, _ofru, _gírì_,
   {{0x741300cd,0x6aa201d0,0x41a500b6,0xc0581536}},	//   _موها, hoof, _गुणस, ніс_,
   {{0x02a737dd,0x5334117a,0x62860ab1,0xc90d030b}},	//   _прим, _рейт, biko, _सम्म_,
   {{0x7bce37de,0x7d0d37df,0x7bdc37e0,0x628637e1}},	//   _agbu, tuas, _afru, ciko,
   {{0x6e2d1c5d,0xbbeb0037,0x9f4a0131,0x7e62007b}},	// [2cb0] reab, كرام_, rabá_, öopa,
   {{0x6e2d37e2,0x21290167,0xf8b80023,0xed040103}},	//   seab, _ipah_, _nhĩ_, اولپ,
   {{0x68fb0039,0x20010188,0x7d0d024a,0x7afc0128}},	//   _svud, _idhi_, suas, _cvrt,
   {{0x7d0d063f,0x7bce0129,0x636b0103,0x212900de}},	//   puas, _egbu, lönö, _kpah_,
   {{0x7d0d0036,0xb5fd00c6,0x5fd5142e,0x62580231}},	//   quas, ukšm, _दलाल, _pãoz,
   {{0x628637e3,0x00000000,0x00000000,0x00000000}},	//   ziko, --, --, --,
   {{0x62862767,0xdb1505aa,0x394400b3,0xa6951009}},	//   yiko, _egzò, _erms_, криј,
   {{0x628637e4,0xf1650032,0x212937e5,0x6edc033b}},	//   xiko, _ayọ̀_, _opah_, _učbe,
   {{0x58d500d6,0x69c437e6,0x62860f06,0xa2cb0bf5}},	//   _розт, žier, viko, _संज्,
   {{0x446531f6,0x2bb80378,0x58d408c3,0x290f37e7}},	//   твов, _अरमा, _софт, muga_,
   {{0xe29a37e8,0x628637e9,0xfbd20054,0x63aa02ad}},	//   дан_, tiko, יתי_, _cyfn,
   {{0x200137ea,0x63aa0178,0x00000000,0x00000000}},	//   _adhi_, _dyfn, --, --,
   {{0x628637eb,0xa56400e3,0x290f37ec,0x867a00d7}},	//   riko, _مدون, nuga_, _קרנו,
   {{0x291d0051,0x290f058f,0xe804007f,0x00000000}},	//   itwa_, iuga_, रणया_, --,
   {{0x8fa6016e,0x63aa0150,0x290f37ed,0xb21b08ca}},	//   таве, _gyfn, huga_, rnær,
   {{0x7bdc37ee,0x291d06a3,0x290f00aa,0x2bb802d5}},	//   _sfru, ktwa_, kuga_, _अरबा,
   {{0xc5f2193b,0x290f37ef,0x6f1c00d8,0x6284007f}},	// [2cc0] ידן_, juga_, strc, _imio,
   {{0x20040138,0x1f6637f0,0xf0ba0504,0xa2d800b6}},	//   ėmis_, _аком, _تابش_, _नंम्,
   {{0x78a337f1,0xdbde0139,0x00000000,0x00000000}},	//   donv, _bíòd, --, --,
   {{0x290f0517,0xe8df0134,0xc98637f2,0x00000000}},	//   fuga_, _erọn_, кули, --,
   {{0x6aa237f3,0x290f37f4,0x78a337f5,0x00000000}},	//   roof, guga_, fonv, --,
   {{0x7afc37f6,0xa3c30f53,0xa7fc0511,0x3a240124}},	//   _tvrt, ्शा_, _alır, _wbmp_,
   {{0x7c3c0fab,0x6d460995,0x39440131,0x7afc09ac}},	//   _iarr, _hrka, _wrms_, _uvrt,
   {{0x290f3289,0x6d4602ef,0x7c3c293f,0x3e6e00d4}},	//   buga_, _krka, _harr, _mýto_,
   {{0x7c3c37f7,0x291d0034,0x08c60792,0xe60f001c}},	//   _karr, ctwa_, _абан, زشي_,
   {{0x7c3c03f3,0x628437f8,0x25e20789,0x6d46007e}},	//   _jarr, _amio, _ट्री_, _mrka,
   {{0x7c3c377b,0xd25112eb,0xd7a9152c,0x64a30396}},	//   _marr, مند_, _चुपच, раќа,
   {{0x7c3c02a7,0x6d4637f9,0xa77b006e,0x00000000}},	//   _larr, _orka, _קראפ, --,
   {{0x955300cd,0x518437fa,0x660237fb,0x316d0328}},	//   _نخوا, аура, _idok, áez_,
   {{0x8cd60251,0x8c080081,0x3e7500d6,0x258401d3}},	//   _बढ़ो, র্তন_, _måte_, rīlī_,
   {{0x54331850,0x443c022e,0x6d4637fc,0xdef8002d}},	//   _ضرور, _iav_, _arka, кыт_,
   {{0x443e37fd,0x443c37fe,0x3cfe000f,0x6d460995}},	//   ldt_, _hav_, _लिखे_, _brka,
   {{0x80dd00c7,0x443c0197,0x2129063f,0x961d00d9}},	// [2cd0] _বিক্, _kav_, _upah_, ziņo,
   {{0x443e37ff,0x7c3c2dad,0x290f092f,0x443c16fc}},	//   ndt_, _carr, vuga_, _jav_,
   {{0x7c3c3800,0x443c01fa,0x6d463801,0x443e3802}},	//   _darr, _mav_, _erka, idt_,
   {{0x443c3803,0x7c3c10f0,0x66023804,0x9984013f}},	//   _lav_, _earr, _ndok, _namų_,
   {{0x7c3c3805,0xe8df00de,0x443c3806,0x78a33807}},	//   _farr, _trọn_, _oav_, tonv,
   {{0x443c0b4b,0x7c3c1164,0x290f3808,0x443e0126}},	//   _nav_, _garr, ruga_, jdt_,
   {{0x6d460220,0x290f3809,0x6e3d380a,0x291d380b}},	//   _zrka, suga_, _kasb, stwa_,
   {{0x443e0126,0x7e6d380c,0x7c3c380d,0xc1e32172}},	//   edt_, nkap, _zarr, _क्लब_,
   {{0x9a84380e,0x6e3d380f,0xaca30174,0x7c3c3810}},	//   _турл, _masb, _nrịb, _yarr,
   {{0x443c006c,0x649d0472,0x66020294,0x6284036b}},	//   _cav_, nèix, _edok, _smio,
   {{0x443c0197,0x46152b38,0x7e6d3811,0xf7700397}},	//   _dav_, _موار, kkap, _وام_,
   {{0xe0c900c1,0x6e3d3812,0x6d03218b,0x443e01cb}},	//   _זײ_, _nasb, _लिंग_, adt_,
   {{0x81ac0081,0x321e0034,0x443e0072,0xfbc3030b}},	//   কেন_, ęty_, bdt_, वेतम,
   {{0x4095131b,0x443c3813,0x66020146,0x2c7602b6}},	//   арст, _gav_, _zdok, _kæde_,
   {{0x7c3c0044,0x656900f9,0x6d4605db,0x9f580216}},	//   _rarr, lyeh, _srka, marë_,
   {{0x7e6d3814,0x7c3c3815,0x44270063,0x6aa90095}},	//   gkap, _sarr, _hbn_, _nkef,
   {{0x0c261a77,0x443c0197,0x261b0101,0x61463816}},	// [2ce0] лман, _yav_, _यानी_, _сепа,
   {{0x443c0d7d,0xf54f0134,0x7c3c3817,0x786f01df}},	//   _xav_, _bụzi_, _qarr, _søvn,
   {{0x7c3c3818,0x645c00aa,0x6e3d007e,0x16030096}},	//   _varr, örii, _fasb, ळणार_,
   {{0x6d46077e,0x998d00a5,0xe3c50081,0x7c3c3819}},	//   _trka, _oceń_, _এভাব, _warr,
   {{0x7c3c381a,0x442703ab,0x6abb0188,0x0d830829}},	//   _tarr, _obn_, _dhuf, _глян,
   {{0x61f6381b,0x4427381c,0x60d600f9,0x98a30a54}},	//   _leyl, _nbn_, _muym, биче,
   {{0x6d44381d,0x9f58023b,0xbddb00ee,0x6e3d0027}},	//   lvia, darë_, _inèr, _yasb,
   {{0x443c381e,0x9b9300e3,0x7ae3381f,0xfaa63820}},	//   _sav_, _الفت, ínte, _сабо,
   {{0x443c3821,0x6d440472,0xd94314fb,0x442710e9}},	//   _pav_, nvia, _лети, _bbn_,
   {{0xd5c004dd,0x443c022e,0x443e0629,0x19b91e20}},	//   शेषज, _qav_, udt_, _русь_,
   {{0x443e3822,0x5fa4007d,0x7e6d06a8,0x61f63823}},	//   rdt_, _खुलल, ykap, _beyl,
   {{0x201a02a1,0x66023824,0x673a0dd9,0xd7f80023}},	//   _acpi_, _udok, _istj, _xoăn_,
   {{0x443c3825,0x6d440181,0x9f510146,0x257a0065}},	//   _tav_, jvia, razí_, _dàlé_,
   {{0x443c3826,0x60d60367,0x6d440031,0x83660037}},	//   _uav_, _duym, dvia, _مدبل,
   {{0xb4c00176,0xb4c2009f,0x7e6d3827,0x80d50557}},	//   ंगी_, ्दी_, tkap, _यूरे,
   {{0xe80e07e2,0x4ea7004b,0x228b0139,0x76403828}},	//   _साझा_, урга, _dòkè_, ndmy,
   {{0xb8042ebd,0x6e3d3829,0x38bb0313,0x5d5502b3}},	// [2cf0] रणाम_, _vasb, lêre_, шкат,
   {{0x7e6d382a,0x673a00aa,0x6e3d1030,0x9ed90cba}},	//   skap, _ostj, _wasb, _имот_,
   {{0x649d0472,0x6e3d00dc,0x38bb0313,0x228b0032}},	//   rèix, _tasb, nêre_, _gòkè_,
   {{0xb4c2382b,0x6e3d0167,0x61f600a7,0xbddb00ee}},	//   ्दु_, _uasb, _xeyl, _enèr,
   {{0x673a0090,0xa3ab030b,0xc27c006e,0x2c760537}},	//   _astj, _कुन_, ערדי, _sæde_,
   {{0x1bd40a67,0x7d0d382c,0x41c70b2b,0x00000000}},	//   _горя, mras, रेयस, --,
   {{0x9f580052,0x442705db,0x1a650504,0x6aa90090}},	//   varë_, _rbn_, _پیشی_, _tkef,
   {{0x9a87197f,0x00000000,0x00000000,0x00000000}},	//   _сугл, --, --, --,
   {{0xb4c2382d,0x7d0d382e,0x9f5800dd,0xb4c00592}},	//   ्दू_, nras, tarë_, ंगू_,
   {{0x03250b1b,0xddc40138,0x61f6382f,0x38bb084e}},	//   адон, nkiš, _seyl, fêre_,
   {{0x7d0d3830,0xe1ff00a5,0x3a3f3831,0xe70b0214}},	//   hras, nków_, _kaup_, _ستان_,
   {{0x80dd0f71,0x614602e3,0x216a00d6,0x6d440138}},	//   _বিজ্, аема, вими_, yvia,
   {{0xe2970ee6,0x9f583832,0x201a0042,0x442700fe}},	//   рая_, maré_, _pcpi_, _tbn_,
   {{0xd46615de,0x6d440451,0x442700dc,0x26cf3833}},	//   _више_, vvia, _ubn_, _higo_,
   {{0x26cf3834,0x6e240036,0x7d0d3835,0x00000000}},	//   _kigo_, tfib, eras, --,
   {{0x26cf006d,0xddc93836,0xe1ff0034,0x29000138}},	//   _jigo_, _šošt, dków_, šiai_,
   {{0x7d0d3837,0x291f023e,0xac863671,0x26cf037a}},	// [2d00] gras, _nqua_, агал, _migo_,
   {{0xd12f00d0,0x26cf3838,0x0eb8009d,0x6d443839}},	//   _کمی_, _ligo_, _आठवड, rvia,
   {{0x7d0d383a,0xdddd0018,0x2abc0a43,0x64411e03}},	//   aras, _első, híbe_, idli,
   {{0x6da6004d,0x64410167,0x9f58034f,0x00000000}},	//   _вима, hdli, jaré_, --,
   {{0x44e90b0b,0x7d0d383b,0x2900001f,0x2240383c}},	//   _nº_, cras, éia_, _maik_,
   {{0x2018383d,0x37062c37,0x26cf0085,0x3eb200c2}},	//   ngri_, ачив, _aigo_, llyt_,
   {{0x26cf383e,0x291f028d,0x9f5800b3,0xb17b059a}},	//   _bigo_, _equa_, faré_, lbåt,
   {{0x2240383f,0x644102e2,0xeb9700d6,0x26cf0344}},	//   _naik_, edli, _тис_, _cigo_,
   {{0x26cf1f84,0xd5b73840,0x644101cb,0x00000000}},	//   _digo_, ись_, fdli, --,
   {{0xb4c00067,0xb4c224eb,0x38bb057a,0x20cf0090}},	//   ंगे_, ्दे_, têre_, _ażin_,
   {{0x22402c09,0x3946013f,0x22520808,0x3e750149}},	//   _baik_, lvos_, _bnyk_, _låta_,
   {{0xc5f000c7,0x38bb0313,0x7d0d3841,0xe81c0285}},	//   _টাকা_, rêre_, yras, _नाडा_,
   {{0x22400063,0x3946002b,0xd5b02ce3,0xe1ff007f}},	//   _daik_, nvos_, _عفت_, zków_,
   {{0x83f8188d,0x53343842,0x27fc01df,0x7d0d3843}},	//   _секс_, _гект, navn_, vras,
   {{0x06fd00b6,0x22403844,0x3eb200f3,0xcf150033}},	//   žívá_, _faik_, flyt_, াব্দ_,
   {{0x27fc0c08,0x2c190096,0x2a64022b,0x00000000}},	//   havn_, _पाहू_, _nomb_, --,
   {{0xddc40335,0xdb1c0034,0x6d40033b,0x66d50138}},	// [2d10] tkiš, _ogró, _šmar, _iške,
   {{0xe1ff0034,0x61fd1a4a,0x9f580623,0xa3aa24f3}},	//   tków_, lasl, zaré_, _खडा_,
   {{0x1da73845,0x7d0d3846,0x3a3f0154,0x7e9901f9}},	//   _कुरत, sras, _paup_, _مندر_,
   {{0x7d0d3847,0xa3e60c16,0xde590426,0x7e55010d}},	//   pras, युत_, _самі_, _انحص,
   {{0x39490fb6,0x0dcb00c9,0x26cf3848,0x64413849}},	//   ías_, _јуни_, _rigo_, ydli,
   {{0x26cf384a,0xb4c2030b,0xb4c00e52,0x00000000}},	//   _sigo_, ्दो_, ंगो_, --,
   {{0xb4c2033a,0x61fd02a7,0x261b009d,0x9f58384b}},	//   ्दै_, kasl, _यादी_, taré_,
   {{0x2f9800ca,0x61fd01d3,0x2018080e,0x3ea900ce}},	//   יכון_, jasl, zgri_, noat_,
   {{0x26cf22e7,0x880709f4,0x9f582e56,0xa3c909c4}},	//   _vigo_, _نظام, raré_, लेन_,
   {{0x26c40036,0x26cf0a4b,0x66d505db,0x2abc0076}},	//   ammo_, _wigo_, _aške, ríbe_,
   {{0x6441384c,0x69cb0bf5,0xa25b0161,0x9f58384d}},	//   rdli, _तृती, rmôn, paré_,
   {{0x2721310d,0x6f15384e,0x625a384f,0x7d0200c6}},	//   món_, duzc, урор_, šosi,
   {{0x27213850,0xa5091a18,0x5a9a0142,0x200c0231}},	//   lón_, _села_, רשרא, ódio_,
   {{0x645c3851,0x00000000,0x00000000,0x00000000}},	//   örit, --, --, --,
   {{0x27210933,0xb21b052f,0x224000dc,0xdee63852}},	//   nón_, dhæf, _taik_, соби,
   {{0x61fd0307,0x27210072,0x394600c6,0xbda60037}},	//   casl, ión_, yvos_, محذو,
   {{0x61e43853,0xed573854,0x27213855,0x00000000}},	// [2d20] _ifil, бот_, hón_, --,
   {{0xa3ab3856,0x27213857,0xb17b0572,0x290f0141}},	//   कअप_, kón_, rbåt, drga_,
   {{0x27213858,0xdb1c00ee,0x5f4602fc,0xfbc30ff9}},	//   jón_, _agrò, _انجل, वेलम,
   {{0x27213859,0xa3c90096,0x82d6006e,0xef22007f}},	//   dón_, लेय_, צונג_, ążę_,
   {{0x19581402,0x186a385a,0xceb40092,0x92e30081}},	//   ралы_, лади_, mlə_, _ফটো_,
   {{0xfce3385b,0x2721385c,0x6e362040,0x3946385d}},	//   _хоро, fón_, leyb, rvos_,
   {{0x3946385e,0x27210fb6,0x61e4385f,0xa3c90296}},	//   svos_, gón_, _ofil, लेम_,
   {{0xceb40092,0x20cf00bd,0x27fc066a,0x2d800036}},	//   nlə_, _ażil_, savn_, ozie_,
   {{0x2d803860,0xb5fd00d9,0x61fd0103,0x7e663861}},	//   nzie_, ekšs, vasl, _mokp,
   {{0xd6d206f6,0xb8653862,0x27213863,0x61fd0167}},	//   _فقط_, _والو, bón_, wasl,
   {{0xceb40092,0x27210af3,0xd5b200cd,0x61fd3864}},	//   klə_, cón_, _کفش_, tasl,
   {{0x9c8700b6,0x27240129,0x7cff0065,0x290000c6}},	//   _kočá, _ịnwe_, _jàrá, šiau_,
   {{0x61e4002b,0xb5fd00c6,0x64a60ad8,0xa3c903b3}},	//   _dfil, rkšt, _лада, लेब_,
   {{0x2d800d1b,0x61e43865,0x644d01c2,0x61fd3866}},	//   dzie_, _efil, _ɗaik, sasl,
   {{0x93fb00f5,0x61fd3867,0x61e40150,0x4fc435c8}},	//   _גלוי, pasl, _ffil, зста,
   {{0x5f941e54,0xa1951031,0x00000000,0x00000000}},	//   чист, _майч, --, --,
   {{0x272111ce,0x2d58249c,0x628f226a,0x261b0285}},	// [2d30] zón_, бить_, mico, _यासी_,
   {{0xf21f0336,0x9d181110,0x6f153868,0xaae70037}},	//   _भाड़_, софт_, puzc, مسؤو,
   {{0x272103be,0xb5fd0087,0xb21b003e,0xddcf020a}},	//   xón_, ljše, rhæf, _focş,
   {{0x7d160124,0xdb1f04c8,0x290f05db,0x27210143}},	//   buys, _ávís, trga_, vón_,
   {{0xae1a0130,0xd5a609e5,0xb5fd033b,0x786f00f3}},	//   _דורכ, _آف_, njše, _høvi,
   {{0x272106cb,0xd7fb0036,0x628f020a,0x00000000}},	//   tón_, ууд_, hico, --,
   {{0x32090188,0x628f3869,0x00000000,0x00000000}},	//   _oday_, kico, --, --,
   {{0x2721386a,0x628f042d,0xb5fd01d3,0xb4d13613}},	//   rón_, jico, ekšr, वद्_,
   {{0x6499036f,0x272106cb,0x00000000,0x00000000}},	//   итор_, són_, --, --,
   {{0x27210610,0x61e4386b,0x4489129c,0x730500d6}},	//   pón_, _sfil, рбон_, опоз,
   {{0x628f132d,0xe7ef009d,0x320933aa,0xceb40092}},	//   fico, _घ्या_, _bday_, ylə_,
   {{0xd57521f4,0x628f386c,0xf1bf037a,0xe29726fd}},	//   _муль, gico, rfán_, жаю_,
   {{0x2a3a006e,0xceb4013c,0x00000000,0x00000000}},	//   בערמ, vlə_, --, --,
   {{0x201e2ba2,0x661b2c70,0x753b0027,0x00000000}},	//   üti_, lguk, mwuz, --,
   {{0xceb40092,0x7e660270,0x64430a05,0xdee31e46}},	//   tlə_, _pokp, _iani, доси,
   {{0xee3a07ed,0x2d800062,0x38b200ae,0x394d386d}},	//   јна_, tzie_, râri_, _ores_,
   {{0x6443386e,0xa3c30336,0x7fd600f7,0xceb401d4}},	// [2d40] _kani, ्शक_, _міні, rlə_,
   {{0xa3bd0378,0x2d800d6d,0x6fde02d5,0x6ee30174}},	//   _आरा_, rzie_, _मलिं, ọbat,
   {{0xe9da2f93,0x6a86386f,0x68e93870,0x7e660113}},	//   аке_, олжа, _ated, _tokp,
   {{0x64433871,0x9c8700b6,0x394d1868,0x00000000}},	//   _lani, _počá, _bres_, --,
   {{0x81ac00c7,0x394d3872,0xa3c90096,0xdb0700b6}},	//   কের_, _cres_, लेत_, _vyjá,
   {{0x644334b2,0xb9023873,0xd90d00cd,0xc17300a1}},	//   _nani, _नं_, ایل_, וחד_,
   {{0x394d3874,0xe3a70177,0xd6d732e3,0x8b230a28}},	//   _eres_, _آر_, оты_, _одре,
   {{0x628f3875,0x64433876,0x395d023e,0x661b3877}},	//   xico, _aani, bxws_, gguk,
   {{0x7d043878,0x64433879,0xd90d0470,0xd49a125f}},	//   nsis, _bani, _مین_, иро_,
   {{0x6443387a,0x7d04387b,0xe46a387c,0xa25b016d}},	//   _cani, isis, ршил_, rmôm,
   {{0x628f387d,0x7d04387e,0x00000000,0x00000000}},	//   tico, hsis, --, --,
   {{0x7d04387f,0xdb213880,0xd377013f,0x95ca1d7b}},	//   ksis, étét, ючы_, _кула_,
   {{0x628f3881,0x66003633,0xe1ff3882,0x66d50138}},	//   rico, mamk, raó_, _iška,
   {{0x628f2733,0x64433883,0x6600008a,0xdfd8008f}},	//   sico, _gani, lamk, жът_,
   {{0x628f3884,0x81ac0081,0x44e03885,0x7d043886}},	//   pico, কেল_, _hò_, esis,
   {{0x44e03887,0x7c2e3888,0x66000010,0x2a7d023e}},	//   _kò_, _abbr, namk, xhwb_,
   {{0xd9040814,0x7d040256,0xbe750065,0xdddd0034}},	// [2d50] _جی_, gsis, _aṣàl, _posł,
   {{0x44e03889,0x6600388a,0xfc330037,0x6443388b}},	//   _mò_, hamk, بحر_, _xani,
   {{0x44e0388c,0x68e9388d,0x6600388e,0x442e061d}},	//   _lò_, _sted, kamk, _mbf_,
   {{0x66000808,0x7c2e08b9,0x787d022b,0x00000000}},	//   jamk, _ebbr, _mève, --,
   {{0x44e002f1,0x6600388f,0x81cd0033,0x2d9c026a}},	//   _nò_, damk, শুর_, şver_,
   {{0xbca500e3,0x68e90220,0x3e7c00b6,0xb5fd01d3}},	//   _رمزي, _vted, _víte_, ekšp,
   {{0xf77100b1,0x644308a9,0x68e900a5,0xb902007a}},	//   عات_, _rani, _wted, _नू_,
   {{0x394d3890,0x44e03891,0x9f5a022b,0x6d4f0995}},	//   _tres_, _bò_, _depè_, _krca,
   {{0x64433892,0x44e03893,0x798200a5,0x6d4f0124}},	//   _pani, _cò_, czow, _jrca,
   {{0x44e00d79,0x629d3894,0x628d0294,0xc4822cbf}},	//   _dò_, éron, _amao, ельк,
   {{0xf1a90132,0x2292013f,0xa3ab121d,0x32460805}},	//   _עס_, eška_, _कुश_, пенг,
   {{0x6443117e,0xe29a0d6f,0x44e03895,0x7d043896}},	//   _wani, сам_, _fò_, ysis,
   {{0x44e01610,0x64433897,0xbbb8000d,0xa7fc026a}},	//   _gò_, _tani, _अर्क, _alıy,
   {{0xf09f1b27,0x15420e3a,0x64430350,0x787d014b}},	//   dràs_, _чешм, _uani, _fève,
   {{0x1fb53898,0x44e0022b,0x00000000,0x00000000}},	//   дстр, _zò_, --, --,
   {{0x3e6e0088,0x7d043899,0x6d4f389a,0x71a628bb}},	//   _nýtt_, tsis, _brca, _найз,
   {{0xed57389b,0x44e0028d,0x6d4f009c,0x3202028a}},	// [2d60] пот_, _xò_, _crca, maky_,
   {{0x7d04389c,0x99dd0220,0xe058001c,0x320200d4}},	//   rsis, _raňa, _بیست_, laky_,
   {{0x2baf009f,0xbddb03a9,0xf09f00b3,0x6d4f0233}},	//   _जुदा, _kaèl, aràs_, _erca,
   {{0x81ac0081,0x32020146,0xfaa304a1,0x7d04389d}},	//   কেঃ_, naky_, нахо, psis,
   {{0x9f580428,0x2fda0063,0x6d4f00c4,0xbddb0113}},	//   larà_, _kgpg_, _grca, _maèl,
   {{0x44e002b4,0x79820034,0x91bb00ca,0x00000000}},	//   _rò_, rzow, זמני, --,
   {{0x44e0389e,0xa3ab00af,0x9f5805fe,0x6600389f}},	//   _sò_, _कुल_, narà_, tamk,
   {{0x44e038a0,0x32020146,0x7e640085,0x00000000}},	//   _pò_, jaky_, njip, --,
   {{0xa3c9000c,0x1dbe0213,0x787d0154,0x00000000}},	//   लेस_, ्धित, _sève, --,
   {{0x628d10f0,0xa3e602d5,0x22920087,0x660038a1}},	//   _smao, युं_, vška_, samk,
   {{0xd25112eb,0x44e00649,0x9f58015e,0x00000000}},	//   نند_, _wò_, jarà_, --,
   {{0x44e00d79,0x9f5805fe,0xa75b00ca,0x11d90037}},	//   _tò_, darà_, _לדבר, توحة_,
   {{0xc05b00d6,0x41c70034,0x442e38a2,0x29060095}},	//   бів_, रेंस, _tbf_, nsoa_,
   {{0x26de38a3,0x229238a4,0x98bf0995,0x9f5800ee}},	//   _kuto_, rška_, _vruć_, farà_,
   {{0xb5fd03f1,0x645838a5,0x9f5805fe,0x6d4f00cc}},	//   ljša, _invi, garà_, _srca,
   {{0x81ac0081,0x26de0435,0x644838a6,0xbddb00ee}},	//   কেই_, _muto_, lddi, _gaèl,
   {{0x2d5802fd,0x26de38a7,0xb5fd0087,0x442c38a8}},	// [2d70] пить_, _luto_, njša, ofd_,
   {{0x644819c2,0x9f5805fe,0xf09f0428,0x62960094}},	//   nddi, barà_, rràs_, ézov,
   {{0x200338a9,0x9f5805fe,0x64480150,0x629d38aa}},	//   maji_, carà_, iddi, onso,
   {{0x2ea802e8,0x6d4f08a9,0x629d004d,0x200309c0}},	//   ककृत, _trca, nnso, laji_,
   {{0x9f5822a4,0x6d4f00ae,0x6458225b,0x60d70062}},	//   mará_, _urca, _onvi, _kixm,
   {{0x26de38ab,0x200338ac,0x660b005c,0x9f580165}},	//   _buto_, naji_, _sdgk, lará_,
   {{0xa6c92b19,0x6d4d28ac,0x60df38ad,0x47d00081}},	//   олка_, lvaa, _luqm, _স্বী,
   {{0x200338ae,0x9f581946,0x442c01c0,0xa3c224eb}},	//   haji_, nará_, efd_, ्धन_,
   {{0x6d4d38af,0x200338b0,0x442c05db,0x9f58002b}},	//   nvaa, kaji_, ffd_, iará_,
   {{0x200338b1,0xd90d0018,0x629d0b8e,0x2b430090}},	//   jaji_, _میچ_, enso, _ksjc_,
   {{0xaca30294,0x9f580428,0x3e7c003e,0x06d70033}},	//   _nnọc, xarà_, _líta_, _সবকি,
   {{0x645838b2,0x9f5838b3,0x644838b4,0x68fb0174}},	//   _envi, jará_, addi, _kwud,
   {{0x9f5822bf,0xaca30294,0x5155002d,0x26de09ac}},	//   dará_, _anọc, нтру, _zuto_,
   {{0x9f5805fe,0x200338b5,0x6e2d01c0,0x764938b6}},	//   tarà_, gaji_, efab, ldey,
   {{0x4aad007d,0xa3c9048a,0x752938b7,0x6d4d2e08}},	//   टकाव, लेश_, ltez, evaa,
   {{0x9f5838b8,0x764938b9,0x22920117,0x6d4d02ac}},	//   gará_, ndey, mško_, fvaa,
   {{0x200338ba,0x75292af9,0xdb0e030b,0x9f5805fe}},	// [2d80] baji_, ntez, _vybí, sarà_,
   {{0x69db38bb,0x7e7d009c,0xfbd2029e,0x9f580428}},	//   _ague, _elsp, نتا_, parà_,
   {{0xaec60743,0xaca40174,0x9f5822a4,0x2292389a}},	//   _обол, _haịr, bará_, nško_,
   {{0x9f581f9f,0x99dd025b,0xed5a38bc,0x6f1c0d30}},	//   cará_, _daňo, _дом_, murc,
   {{0x64481a2e,0x764938bd,0xaca400ac,0xa96707ed}},	//   yddi, ddey, _asụs, мица_,
   {{0x29060933,0xd6ea1121,0x3ead0117,0x69c0033b}},	//   rsoa_, офил_, čete_, _vzme,
   {{0x29060396,0x7bdc38be,0x68fb063d,0x00000000}},	//   ssoa_, _igru, _ewud, --,
   {{0x2003068d,0xc95602fd,0x00000000,0x00000000}},	//   zaji_, _отзы, --, --,
   {{0x6f1c38bf,0x66d500c6,0x26de0113,0x00000000}},	//   hurc, _iškl, _wuto_, --,
   {{0x9f5838c0,0x26de030b,0x1620009d,0x64480d19}},	//   zará_, _tuto_, _यावर_, uddi,
   {{0xd62a1c47,0x644838c1,0xa3c90096,0x26de00f9}},	//   _може_, rddi, लेल_, _uuto_,
   {{0x6f1c02e2,0x20030051,0x9f580558,0x68e038c2}},	//   durc, waji_, xará_, _kumd,
   {{0x2003068d,0x9f5822bf,0x752900ae,0x786f02b6}},	//   taji_, vará_, ctez, _iøvr,
   {{0xddcd1100,0xc058018a,0x656f01bf,0x7bdc00cd}},	//   jkaš, міс_, äche, _ngru,
   {{0x9f58132d,0x26c638c3,0xf54800ac,0x6f1c01c2}},	//   tará_, _khoo_, _hụ_, gurc,
   {{0x4ea42de0,0x7bdc38c4,0x6d4d1237,0x200338c5}},	//   вруа, _agru, tvaa, saji_,
   {{0x9f582c90,0xdd94055b,0xf5480134,0x200321ef}},	// [2d90] rará_, ваты, _jụ_, paji_,
   {{0x31560054,0xf5480129,0x6d4d38c6,0x9f5822bf}},	//   _ניתן_, _mụ_, rvaa, sará_,
   {{0x9f581f84,0x6f1c00ae,0x752938c7,0x6d4d38c8}},	//   pará_, curc, ztez, svaa,
   {{0xb4ca0b94,0x387e0036,0x6d4d029a,0x7d1638c9}},	//   लगु_, _altr_, pvaa, brys,
   {{0x224938ca,0x80180688,0xd90f09e5,0xf54838cb}},	//   _maak_, _عزیز_, شیا_, _nụ_,
   {{0x2b43015e,0x22490381,0x26c6026d,0x68e00565}},	//   _tsjc_, _laak_, _ahoo_, _dumd,
   {{0x7afc0150,0x38c90018,0x200100bc,0x7c3001f9}},	//   _gwrt, _ہائی_, _mehi_, ékrő,
   {{0x26c638cc,0xf54838cd,0x06093097,0x752938ce}},	//   _choo_, _bụ_, чник_, ttez,
   {{0xf5480028,0x2a7f0009,0x68e003e3,0x76490233}},	//   _cụ_, _ilub_, _gumd, rdey,
   {{0x752938cf,0x2a7f01bb,0x291d38d0,0xf5480019}},	//   rtez, _hlub_, muwa_, _dụ_,
   {{0xa3c90b89,0xe8d600a1,0x291d38d1,0xf7700281}},	//   लें_, _נוער_, luwa_, _پال_,
   {{0xbbdc000f,0x25a00128,0x2292191d,0x7529020a}},	//   _बल्क, _žile_, rško_, ptez,
   {{0xf5482e5c,0x70ab0034,0x26cd1fc2,0x20010634}},	//   _gụ_, चकूल, mmeo_, _behi_,
   {{0xd11c17ff,0x2a6d38d2,0x38a90031,0x6f1c38d3}},	//   भूषण_, _loeb_, túry_, turc,
   {{0xc7b207a6,0x2baf00af,0x2a7f01d4,0x291d38d4}},	//   ָבן_, _जुला, _olub_, huwa_,
   {{0x291d1a7e,0x9f5c38d5,0x68330dea,0xb21b02b6}},	//   kuwa_, _því_, lıdı, lhæn,
   {{0xafe62ff8,0xf8af09c3,0x291d38d6,0xe3b8026a}},	// [2da0] _попл, टवाय, juwa_, ngın_,
   {{0x64571f84,0x22490126,0xb21b052f,0x291d38d7}},	//   _óxid, _zaak_, nhæn, duwa_,
   {{0xddcd1419,0x3ce5009f,0x386c0072,0x22490167}},	//   rkaš, _झूठे_, _rodr_, _yaak_,
   {{0x09e638d8,0x2a7f38d9,0x7d1638da,0xa3c20096}},	//   ходн, _club_, prys, ्धत_,
   {{0xaca40129,0x291d38db,0x3ea038dc,0xe297006e}},	//   _abụr, guwa_, mnit_, עכנט_,
   {{0x6d4638dd,0x3b0a1456,0x3ea038de,0xf5480294}},	//   _iska, _него_, lnit_, _rụ_,
   {{0x3ea0023b,0x26c6023e,0xdca3007e,0x638638df}},	//   onit_, _phoo_, _сари, _méné,
   {{0x3ea015bd,0x291d006d,0xfd550174,0x940500a7}},	//   nnit_, buwa_, _nkaọ, milə_,
   {{0x22490665,0x3ea038e0,0xb21b052f,0x672a38e1}},	//   _raak_, init_, fhæn, stfj,
   {{0xf54800ef,0x22490185,0xfd550294,0x638638df}},	//   _vụ_, _saak_, _akaọ, _néné,
   {{0x7ae92c0a,0x26c61423,0x224938e2,0xd764001c}},	//   _četk, _thoo_, _paak_, _جنای,
   {{0x6d4638e3,0x09d400c7,0xf54800de,0x877b006e}},	//   _oska, _হ্যা, _tụ_, _מאבי,
   {{0x22490ab2,0x6386025a,0x3ea002c6,0x7c3e38e4}},	//   _vaak_, _béné, dnit_, kepr,
   {{0x638603a9,0xf1c70034,0x7c3e17d2,0x660238e5}},	//   _céné, रेगन, jepr, _heok,
   {{0x443e0052,0x6d4638e6,0x9f34004d,0x22490a9f}},	//   met_, _aska, лері, _taak_,
   {{0x644a38e7,0x20010113,0x291d1114,0x626726a0}},	//   _hafi, _wehi_, yuwa_, _سابق,
   {{0x644a38e8,0xdb0e025b,0x7c3e0218,0xad9b38e9}},	// [2db0] _kafi, _rybá, fepr, _adúr,
   {{0x638604ea,0x64840013,0x3ea038ea,0x319c00ca}},	//   _géné, _dòig, anit_, _מבחנ,
   {{0x6d4603f3,0x7f4500dd,0xa3c2303f,0x291d0044}},	//   _eska, _ushq, ्धि_, wuwa_,
   {{0x443e38eb,0x644a1114,0x291d38ec,0xd99900e3}},	//   het_, _lafi, tuwa_, ونات_,
   {{0x443e38ed,0xd94508c3,0x61ed0051,0x27ec0063}},	//   ket_, тели, _mfal, _bfdn_,
   {{0x443e38ee,0xa3c20714,0x291d38ef,0x2c1e0034}},	//   jet_, ्धा_, ruwa_, _पाएं_,
   {{0x443e38f0,0x291d38f1,0x94240092,0x61ed0150}},	//   det_, suwa_, _ötən_, _ofal,
   {{0x81ac0081,0x644a0032,0x291d0bb6,0x6d460313}},	//   কেট_, _aafi, puwa_, _yska,
   {{0x443e38f2,0x644a38f3,0x26cd2d07,0xe5710037}},	//   fet_, _bafi, rmeo_, شطة_,
   {{0x443e085d,0xf9900604,0x61ed38f4,0x644a0188}},	//   get_, _طبق_, _afal, _cafi,
   {{0x03a50097,0x644a38f5,0x68330511,0x4e2100b6}},	//   тино, _dafi, rıdı, यलाई_,
   {{0x7c3e00a5,0x68330511,0x638600fd,0xe1ff01cd}},	//   zepr, sıdı, _séné, sjón_,
   {{0x443e38f6,0x644a1f90,0x64840441,0x638600fd}},	//   bet_, _fafi, _bòid, _péné,
   {{0x764b0068,0x61ed02ad,0x644a38f7,0x6484009c}},	//   _hagy, _efal, _gafi, _ròig,
   {{0x764b38f8,0x7c3e2241,0x6386020d,0x3ea038f9}},	//   _kagy, vepr, _véné, tnit_,
   {{0x644a38fa,0x940500a7,0x00000000,0x00000000}},	//   _zafi, vilə_, --, --,
   {{0x764b00fb,0x7c3e38fb,0x3ea038fc,0x644a38fd}},	// [2dc0] _magy, tepr, rnit_, _yafi,
   {{0x644a008a,0x3ea038fe,0x711b00c1,0x2bc616e2}},	//   _xafi, snit_, _קויפ, _वरदा,
   {{0x290d0012,0x7c3e38ff,0x6d4600a5,0xa3d10557}},	//   _avea_, repr, _wska, वधि_,
   {{0x764b00fb,0x443e3900,0x7c3e3901,0x6d4601c2}},	//   _nagy, zet_, sepr, _tska,
   {{0x443e3902,0x94050092,0x6d463903,0x442700eb}},	//   yet_, silə_, _uska, _ocn_,
   {{0x66023904,0x443e3905,0x68ed3906,0x270c00d2}},	//   _seok, xet_, íada, těn_,
   {{0x443e02fe,0x644a0a55,0x764b3907,0x37d50081}},	//   vet_, _rafi, _bagy, _স্বর,
   {{0x6e243908,0x443e3909,0x4427390a,0xddc60154}},	//   ngib, wet_, _acn_, _lakō,
   {{0x443e0bb0,0x7ae900e9,0x48e602ec,0x4427390b}},	//   tet_, _četi, _розв, _bcn_,
   {{0x443e390c,0x442700ee,0x61ed0036,0x545300c2}},	//   uet_, _ccn_, _sfal, авьт,
   {{0x443e390d,0x8c1b0130,0x261b009d,0xd6cf0ff7}},	//   ret_, וויי, _याची_, _вт_,
   {{0x443e3903,0x92580084,0x644a03e1,0xa3e60569}},	//   set_, вают_, _wafi, युज_,
   {{0x443e390e,0x644a1114,0x3e750212,0xf1c40094}},	//   pet_, _tafi, _mått_, _ruší_,
   {{0x443e01e5,0x1c1e0490,0x843800e3,0x74140018}},	//   qet_, _पागल_, _أكثر_, _صوبا,
   {{0xf2c7107a,0x61fb0653,0x66c50103,0x764b0172}},	//   _исин, ðuls, lóka, _yagy,
   {{0x6e242a8c,0x61ed0051,0xaee30032,0x2ebf1efb}},	//   ggib, _ufal, _aiṣe, ्षेत,
   {{0x51870c10,0x6aa212b1,0x5d550fe9,0xfd7400d3}},	// [2dd0] _шука, dnof, ыкат, алтэ,
   {{0x1acb0c16,0x041400c7,0x673a390f,0x6e240172}},	//   िष्ठ, ত্রী_, _optj, agib,
   {{0x7640007b,0xc61a0033,0x290d15cd,0x787d022b}},	//   kemy, থ্যা_, _svea_, _sèvo,
   {{0xb21b052f,0xdea10103,0x6aa202ac,0x00000000}},	//   skæf, _ایری, gnof, --,
   {{0x76403910,0x66ea0034,0x0d6400e5,0x66c50e67}},	//   demy, _ręka, _кърм, jóka,
   {{0xfaf30241,0xb4ac030b,0x7d0d3911,0x66d50138}},	//   _نثر_, कको_, msas, _iški,
   {{0x3e750572,0x44271333,0xe73900d3,0x7d0d36ea}},	//   _fått_, _rcn_, хей_, lsas,
   {{0x3e75038b,0x9f513912,0x7bc70877,0x7d0d3913}},	//   _gått_, lazó_, _izju, osas,
   {{0x764b3914,0xdd1203a3,0x955500e3,0xb5fd033b}},	//   _vagy, _müşt, اخبا, ljšk,
   {{0x764b010a,0x2292033b,0x7c253915,0x6e241d67}},	//   _wagy, mški_, nghr, zgib,
   {{0xe29a15e9,0x7c250076,0x764b010a,0x6d44007f}},	//   еан_, ighr, _tagy, zwia,
   {{0xad9b3916,0x7d0d3917,0x95551d28,0x6d443918}},	//   _reún, ksas, _مختا, ywia,
   {{0x6484009c,0xc8710139,0x9f583919,0x4427020b}},	//   _dòib, _ko̟_, mbré_, _tcn_,
   {{0x628600dd,0x20cf0090,0x659a0266,0xd378007f}},	//   shko, _bżiq_, _אינק, być_,
   {{0xe29a1880,0xa3c93245,0x26dd391a,0xa3ab3845}},	//   _пак_, लेख_, _kiwo_, _कुच_,
   {{0x6441391b,0x44e90d79,0x26dd0113,0x539a0327}},	//   leli, _kú_, _jiwo_, _ריקו,
   {{0x44e9391c,0x7d0d0256,0xa3e7382d,0x6284391d}},	// [2de0] _jú_, gsas, _भला_, _ilio,
   {{0x6441391e,0x44e90649,0x629d025b,0x764000a5}},	//   neli, _mú_, érov, zemy,
   {{0x44e9391f,0x66093920,0x61e93921,0x644100d3}},	//   _lú_, kaek, žele, ieli,
   {{0xa3ab3922,0x644108a3,0x200a3923,0xaca40174}},	//   _कुछ_, heli, labi_, _krịs,
   {{0x44e93924,0xd37800a5,0x7d0d3925,0x62840239}},	//   _nú_, zyć_, csas, _mlio,
   {{0x7ae900e9,0x200a27d3,0x64413926,0x2242003d}},	//   _četv, nabi_, jeli, hekk_,
   {{0x64413927,0xd6da3928,0x09b50081,0x76403929}},	//   deli, нти_, জেলা, temy,
   {{0x44e9392a,0x26dd0d2a,0x644132d7,0x66c50103}},	//   _bú_, _ciwo_, eeli, tóka,
   {{0x6441392b,0xd49a392c,0x7640392d,0x200a392e}},	//   feli, ерн_, remy, kabi_,
   {{0x6441392f,0x27f7000d,0x62840010,0x44e93930}},	//   geli, čení_, _alio, _dú_,
   {{0xd7ef00e3,0x44e90220,0x6284009c,0x200a0d2a}},	//   _ركن_, _eú_, _blio, dabi_,
   {{0x62840441,0x7d0d3931,0x75200051,0x0cb009c4}},	//   _clio, ysas, pumz, जकुम,
   {{0x44e9187e,0x628401ec,0x518413a4,0xd378007f}},	//   _gú_, _dlio, бура, syć_,
   {{0x6441020e,0x200a3932,0x224d3933,0x20050155}},	//   celi, gabi_, žek_, úli_,
   {{0x447b0130,0x1ee700cd,0xdfd50ab3,0xe80c07d5}},	//   _אנגע, اوری_, ровы, _सजना_,
   {{0x628407bc,0x7d0d3934,0xf3130dce,0xe3130dce}},	//   _glio, tsas, _ابوظ, _ابوب,
   {{0xe21400ab,0xd83800d4,0xddc600c6,0x320b0133}},	// [2df0] _طبيع, _obč_, _pokš, macy_,
   {{0x7d0d3935,0x2292033b,0x320b007f,0xb21b0537}},	//   rsas, vški_, lacy_, skæd,
   {{0x62840084,0x9f51037a,0x645e009c,0x66d500c6}},	//   _ylio, razó_, _òpiu, _iškv,
   {{0x64413936,0xa3c90635,0x7c250037,0xdb1c0052}},	//   zeli, लेट_, sghr, _zyrë,
   {{0x44250150,0x64413937,0x7ae9033b,0xdb1c0206}},	//   ygl_, yeli, _četu, _vzrá,
   {{0x44e90d79,0x7e6d007a,0xfc67008f,0x0715166f}},	//   _rú_, ljap, _съмн, афия,
   {{0x44e93938,0xb5fd0087,0x26dd3939,0x00000000}},	//   _sú_, ljši, _piwo_, --,
   {{0x6441393a,0x7f3c00c1,0xd8380154,0x200a393b}},	//   weli, געהו, _ebč_, zabi_,
   {{0xc48519e8,0x26c300d9,0xe8df00de,0xb5fd033b}},	//   илик, ējo_, _trốn_, njši,
   {{0x99840080,0x7ae700dd,0x44e900de,0x6284152f}},	//   _الكو, _kujt, _vú_, _slio,
   {{0x62662de9,0x200a393c,0x6abb0172,0x6aa900f3}},	//   авна, vabi_, _kkuf, _kjef,
   {{0x44e9393d,0xe29a393e,0xc5d502ec,0x6723393f}},	//   _tú_, там_, _кіль, munj,
   {{0x273100ef,0x644130da,0x672302e7,0x200a3940}},	//   _hơn_, peli, lunj, tabi_,
   {{0xe3b000cd,0x69c90350,0x057400d1,0x224200f3}},	//   _کره_, _mzee, _دامد, sekk_,
   {{0x672306ee,0x200a3941,0xb4c3034d,0xb4c10f42}},	//   nunj, rabi_, ्षी_, ंती_,
   {{0x6284068d,0x200a3942,0x7e6d0167,0x39490094}},	//   _ulio, sabi_, gjap, ťasy_,
   {{0xb2bb00a1,0x61e43943,0x6146001f,0x4d661b29}},	// [2e00] _במקר, _igil, _тепа, шкав,
   {{0x6723063d,0xc5d70081,0x6abb3944,0xf8a50281}},	//   kunj, _সভাপ, _akuf, _رک_,
   {{0xf1bf0830,0x0b4617e3,0xa3c90096,0x657b0027}},	//   ngán_, рнен, लेच_, hyuh,
   {{0x53360130,0xb4c12235,0x67230580,0x7e6d1175}},	//   ינען_, ंतु_, dunj, cjap,
   {{0x656f01bf,0x68460c3f,0x186a1c0e,0xe6da01cd}},	//   ächl, инда, кади_, ðsíð,
   {{0xfb2600cd,0xaca40174,0x57f31fdb,0x6abb019f}},	//   _پرسپ, _krọs, општ, _ekuf,
   {{0x3cec0455,0x27310019,0xa7b832e3,0x67233945}},	//   _अंडे_, _cơn_, ылку_, gunj,
   {{0x66c50102,0x2baf0775,0x61e43946,0xfaa63947}},	//   sókn, _जुटा, _ngil, _табо,
   {{0x320b3948,0x657b00f9,0x3e7c0206,0x54b800e5}},	//   vacy_, gyuh, _cíti_, лгия_,
   {{0x37b20033,0x7ae000da,0x229200c6,0x00000000}},	//   টেগর, _himt, išku_, --,
   {{0x9473054f,0x7ae03949,0x0eb6074c,0x00000000}},	//   تديا, _kimt, ंवाड, --,
   {{0x48fd000d,0x22820032,0x9f61020d,0x7ae000bd}},	//   रीको_, _dóko_, _épée_, _jimt,
   {{0x64a61553,0x320b394a,0xe693015a,0xe29801b3}},	//   _када, racy_, _بلند, раў_,
   {{0x653b0341,0x61e4394b,0x69c017e1,0x27240294}},	//   _סעוד, _egil, _myme, _ịnye_,
   {{0xa3b709b4,0x9e070c3f,0xddc60034,0xcebb0291}},	//   _پاور_, ичал, _nakł, вља_,
   {{0x33db00ca,0xdc0f045f,0x2904010a,0x7ae0394c}},	//   _בחוד, ाण्ड_, _owma_, _nimt,
   {{0x629d394d,0x7e6d13ce,0x291d0169,0x78b80537}},	// [2e10] miso, rjap, xrwa_, kovv,
   {{0xfd4d00ef,0x91bc00a1,0x629d394e,0x6abb038c}},	//   _khoả, _במחי, liso, _skuf,
   {{0x69c0394f,0x7ae00167,0x39f40134,0x60990018}},	//   _ayme, _bimt, _ịzọ_, _لنکس_,
   {{0x672330ff,0x69c0057a,0xbddb01dc,0x7ae00381}},	//   vunj, _byme, _daèr, _cimt,
   {{0x27310019,0x69c00150,0xc879078e,0x00000000}},	//   _sơn_, _cyme, _huşi_, --,
   {{0x6723048e,0x6c8500e3,0x6d9e0090,0x291d18fe}},	//   tunj, _السم, _dħaħ, rrwa_,
   {{0x629d3950,0x3e7c02c6,0x7ae03951,0x00000000}},	//   kiso, _síti_, _fimt, --,
   {{0x9aa500bf,0x6abb0060,0x7ae0013f,0xe51800b7}},	//   _امرو, _ukuf, _gimt, _दिशि_,
   {{0xddc600a5,0x1fd4039d,0x69c00150,0x69c90a4b}},	//   _zakł, _दण्ड, _gyme, _uzee,
   {{0xd8740080,0xb4c33952,0x61e43953,0x5f180034}},	//   _والب, ्षे_, _sgil, _फिल्_,
   {{0xdb1c0257,0x7ae0023e,0x657b2375,0xf1d00d61}},	//   _pyré, _yimt, syuh, _सृजन,
   {{0x68e13954,0x629d3955,0xbb3a0266,0xeb3a006e}},	//   _hild, giso, נערי, נערש,
   {{0x68e10400,0x940c00a7,0x61e40090,0x00000000}},	//   _kild, hidə_, _vgil, --,
   {{0x037909e5,0x68e109aa,0xa3b2009f,0x44fb0072}},	//   _محبت_, _jild, _झुक_, _iª_,
   {{0x629d3956,0x44fb002b,0x03a20036,0x61e91656}},	//   biso, _hª_, _нишо, žela,
   {{0x681b01d3,0x6e3b037a,0x0206007e,0x68e9014b}},	//   lādē, _ñubl, _узин, _oued,
   {{0x6ab9009c,0x7ae00138,0x0dca11c0,0x648401f7}},	// [2e20] dowf, _rimt, улай_, _mòin,
   {{0x7ae93957,0x7ae03958,0x44fb3959,0x7e210789}},	//   _četr, _simt, _mª_, यलॉग_,
   {{0xb5fd0087,0x394d00b3,0x22520154,0x6f6300d3}},	//   ljšu, _ases_, _kayk_, _евэз,
   {{0x69c0058a,0x7f3b00c1,0x09d10033,0x68e913ea}},	//   _pyme, _געטו, িশনা, _bued,
   {{0x68e1395a,0x7ae0023e,0xbcfb0139,0x391300d6}},	//   _bild, _vimt, _aréf, змір,
   {{0xb4c306ed,0x69c0135f,0x629d395b,0xbcfb003e}},	//   ्षो_, _vyme, ziso, _bréf,
   {{0x68e1395c,0x394d08a8,0xd6d00b05,0xbb860037}},	//   _dild, _eses_, وقت_, _الأي,
   {{0xdd080038,0x44f42ac0,0x994c0220,0x5678098e}},	//   _môže, опис, môže_, рбия_,
   {{0x68e9395d,0xbcfb0032,0x6484009c,0xd5ba022a}},	//   _gued, _eréf, _dòin, ыск_,
   {{0x68e10088,0x046633ca,0x44fb002b,0x629d0178}},	//   _gild, стим, _dª_, wiso,
   {{0x629d395e,0x44fb0072,0x00000000,0x00000000}},	//   tiso, _eª_, --, --,
   {{0x25a90335,0x85030d5b,0xe7f80ff9,0xc879044c}},	//   _žale_, _کوون, ुरवा_, _ruşi_,
   {{0x787d0c56,0x68e10233,0xe1ff395f,0xc50a0037}},	//   _sèvi, _yild, rbó_, _إتصل_,
   {{0x629d3960,0x68e1008a,0xfd4d0019,0xc879044c}},	//   siso, _xild, _thoả, _puşi_,
   {{0x443c374d,0x66d50138,0xe7f006eb,0xe43700ca}},	//   _ibv_, _iškr, _चलना_, _הרוח_,
   {{0x9df91a0e,0x6e943961,0x00000000,0x00000000}},	//   рнат_, пису, --, --,
   {{0xe29f0102,0x5c7505cb,0x7e2100aa,0x00000000}},	// [2e30] mið_, олат, यलौग_, --,
   {{0xe29f0102,0x68e93962,0xa3cf0ccb,0x7c2e0350}},	//   lið_, _rued, _शरम_, _ccbr,
   {{0xda7b0f1e,0xe80c0251,0x68e93963,0x7bda0146}},	//   ляд_, _सज़ा_, _sued, _útul,
   {{0x68e931f9,0x02c90336,0x66f10029,0xe29f0088}},	//   _pued, रतिभ, _nāka, nið_,
   {{0x68e93964,0x68e13965,0x3ea93966,0xa9693967}},	//   _qued, _pild, mnat_, рила_,
   {{0x46f53968,0xbcfb025a,0x68e111bc,0x26c4028d}},	//   очит, _préf, _qild, elmo_,
   {{0xe29f0682,0x68e13969,0x3ea9396a,0xf7710192}},	//   kið_, _vild, onat_, ظات_,
   {{0x3ea9396b,0xa3bc00c3,0x68e1396c,0x442e396d}},	//   nnat_, _आड़_, _wild, _acf_,
   {{0xe29f003e,0x68e1396e,0x9425129c,0x394d396f}},	//   dið_, _tild, омпе, _uses_,
   {{0x6d5d08a9,0x3ea93970,0x443c0231,0x00000000}},	//   _mrsa, hnat_, _cbv_, --,
   {{0xe29f0102,0x3ea93971,0x37ab1acb,0x52aa327e}},	//   fið_, knat_, _стан_, ивом_,
   {{0x6d4f3972,0xe29f0102,0x442e02e5,0x6d5d3973}},	//   _osca, gið_, _ecf_, _orsa,
   {{0xa5093974,0x3ea900b6,0x442e00b3,0xbbc63856}},	//   _тела_, dnat_, _fcf_, _वर्क,
   {{0x39400092,0xbcfb0113,0x70b40ff9,0x00000000}},	//   çisi_, _mréd, ंकेल, --,
   {{0x6d5d3975,0xafe30565,0x935800ae,0xe3d70033}},	//   _arsa, дорл, _грыу_, _দ্রব,
   {{0x3ea93976,0x6d5d02fa,0xd1322259,0xbddb0154}},	//   gnat_, _brsa, _قمع_, _obèd,
   {{0x660b0068,0x3ce30126,0x9f490220,0x6d5d009c}},	// [2e40] _megk, _bijv_, _škôl_, _crsa,
   {{0x85210b86,0x660b0018,0x3ea93094,0xa7fc0367}},	//   _मिनट_, _legk, anat_, _anın,
   {{0x6d5d3977,0x6d4f3978,0xbddb2502,0x2a640063}},	//   _ersa, _esca, _abèd, _pnmb_,
   {{0x6d4f00b3,0xfaa33979,0x00000000,0x00000000}},	//   _fsca, махо, --, --,
   {{0xbcfb397a,0x82d7006e,0x3ea0397b,0x00000000}},	//   _créd, קונג_, miit_, --,
   {{0x3ea0397c,0xb4b3000f,0x66f101d3,0x100a278e}},	//   liit_, झको_, _sāka, वरिश_,
   {{0xbcfb04d4,0x443c007e,0x8cb90287,0xa3de1e05}},	//   _prég, _rbv_, ्तरो, _दृढ_,
   {{0xbcfb00fd,0x9f582df7,0x3ea0397d,0x7bce30d9}},	//   _fréd, laró_, niit_, _izbu,
   {{0xe29f01cd,0x2d800d0a,0x442e014b,0x6484009c}},	//   við_, nyie_, _pcf_, _fòil,
   {{0x6fc0009d,0x7a4001cd,0xf7460b9e,0x3ea0010a}},	//   _शुभं, _fátæ, _мезо, hiit_,
   {{0xe29f0682,0xa3cf397e,0x249e397f,0xbcfb1e7d}},	//   tið_, _शरण_, ritm_, _trég,
   {{0x442e0090,0x81af0033,0x00000000,0x00000000}},	//   _wcf_, _করব_, --, --,
   {{0xe29f0682,0x3ea9030b,0x443c01cb,0x61e9195e}},	//   rið_, vnat_, _tbv_, želo,
   {{0xe29f0088,0xf8ca0e4c,0x66d500d8,0x00000000}},	//   sið_, ितिय, _uškr, --,
   {{0x3f850074,0xc05802ec,0x64483980,0x4fc4067f}},	//   álu_, ція_, medi, дста,
   {{0x64483981,0x3ea007ac,0xe29804f5,0x442c3982}},	//   ledi, giit_, _мај_, lgd_,
   {{0x3ea93983,0x442c01c0,0x7bce0095,0x98ca0034}},	// [2e50] rnat_, ogd_, _azbu, िताए,
   {{0x64483984,0x442c3985,0x3e7c04c8,0x6d5d2a4e}},	//   nedi, ngd_, _sítt_, _vrsa,
   {{0x20113986,0x442c3987,0xa8010143,0x3ea93988}},	//   mazi_, igd_, _íñig, pnat_,
   {{0xbcfb3989,0x6d5d080e,0x6448398a,0x628f00fe}},	//   _préd, _trsa, hedi, nhco,
   {{0x6d4f00d3,0x6d5d398b,0x7d010139,0x660b0313}},	//   _usca, _ursa, _dárò, _regk,
   {{0x644803ce,0xbcfb04ea,0x20112e60,0x1fdf0033}},	//   jedi, _crée, nazi_, _ব্যস,
   {{0x6448398c,0x6d4d398d,0x3e7c01ab,0x00000000}},	//   dedi, lwaa, _títt_, --,
   {{0x6e2d398e,0x2011398f,0x442c029a,0xbcfb0076}},	//   ngab, hazi_, egd_, _tréd,
   {{0x20113990,0x64483991,0x6d4d3992,0x6484009c}},	//   kazi_, fedi, nwaa, _eòim,
   {{0x20113993,0x68fb0124,0xa3cf22a3,0x660b3994}},	//   jazi_, _itud, _शरद_, _wegk,
   {{0x6d4d026d,0x395f0479,0xe7f00034,0x660b0113}},	//   hwaa, _hrus_, _चलता_, _tegk,
   {{0x6d4d3995,0x442c0ab2,0x395f3996,0x64480072}},	//   kwaa, agd_, _krus_, aedi,
   {{0x76490694,0x64483997,0x6f1500a5,0x3ea00e22}},	//   meey, bedi, eszc, viit_,
   {{0x64482b75,0x6d4d3998,0x20110c69,0x7649008a}},	//   cedi, dwaa, gazi_, leey,
   {{0x6e2d01bf,0x66f101d3,0x3ea03999,0x7529020a}},	//   fgab, _māko, tiit_, luez,
   {{0x88d10081,0x6d4d399a,0x7649399b,0x628f399c}},	//   াদিক, fwaa, neey, chco,
   {{0x6d4d399d,0x2011399e,0x9f5805fe,0x395f023e}},	// [2e60] gwaa, bazi_, taró_, _nrus_,
   {{0x31370054,0x66f100d9,0x3ea0399f,0x76490188}},	//   _צריך_, _nāko, siit_, heey,
   {{0x395f39a0,0x307b00a1,0x7649008a,0x68fb083e}},	//   _arus_, _האינ, keey, _atud,
   {{0x316039a1,0x7bce39a2,0x66c501cd,0xcee9010d}},	//   _kriz_, _vzbu, bóki, _گرین_,
   {{0x7649008a,0x442c0f63,0x9f5839a3,0xb9e3004d}},	//   deey, ygd_, paró_, ніши,
   {{0x644803be,0x7d160381,0x752901ff,0x648d00da}},	//   xedi, msys, duez, _lúib,
   {{0x68fb39a4,0xbb430b2e,0x7d160973,0xa7370037}},	//   _etud, _перк, lsys, كثير_,
   {{0xd90d1e49,0x20111b24,0x64480150,0x76490188}},	//   _چین_, zazi_, wedi, geey,
   {{0x64480b88,0x7d1639a5,0x201139a6,0x395f0b97}},	//   tedi, nsys, yazi_, _grus_,
   {{0x6aa20051,0x6f150034,0xc9170089,0x672314f3}},	//   liof, yszc, _מחמת_, brnj,
   {{0x442c0126,0x644839a7,0x201139a8,0x6d4d01c0}},	//   rgd_, redi, vazi_, zwaa,
   {{0x644839a9,0x201139aa,0xa25b0257,0x7649008c}},	//   sedi, wazi_, plôm, ceey,
   {{0x201139ab,0x644839ac,0x7aee01fa,0xd627004d}},	//   tazi_, pedi, _lubt, _хоче_,
   {{0xe521000d,0xe4d7001c,0x7d1607ee,0xe3af0281}},	//   _मिति_, _فونت_, dsys, ئری_,
   {{0x201139ad,0x543b00c1,0x643b00ca,0x31600062}},	//   razi_, _לעגא, _העונ, _eriz_,
   {{0x6d4d39ae,0x8c090033,0x201139af,0x62862271}},	//   twaa, _লাইন_, sazi_, ckko,
   {{0x6e2d39b0,0x31600218,0xbc79141b,0x201139b1}},	// [2e70] rgab, _griz_, обах_, pazi_,
   {{0x6d4d39b2,0x6e2d39b3,0x787d00fd,0x7982008c}},	//   rwaa, sgab, _lèvr, dyow,
   {{0x81af00c7,0x6d4d39b4,0x1a6509b4,0x628d1523}},	//   _করি_, swaa, ویسی_, _klao,
   {{0x7aee0472,0x7649008a,0x22593502,0xfbd000e3}},	//   _dubt, xeey, ndsk_, اتك_,
   {{0x6d4d02e7,0x81df0081,0x2d4d00cb,0x224b042c}},	//   qwaa, দুর_, _uže_, ieck_,
   {{0x81af0f71,0x7649332c,0x224b39b5,0xbcfb39b6}},	//   _করা_, weey, heck_, _eréc,
   {{0xe73939b7,0x764939b8,0x7aee008c,0x44f203a8}},	//   цей_, teey, _gubt, _aâ_,
   {{0x61e900cb,0x395f06dd,0xbcfb0220,0x656400e7}},	//   želj, _trus_, _gréc, _šiha,
   {{0xb3450396,0x395f18c4,0x76490694,0x394400dc}},	//   _opçã, _urus_, reey, _gpms_,
   {{0x212b0146,0xdeff003d,0x76493634,0xb21b02b6}},	//   duch_, ċċju_, seey, skæl,
   {{0x78a30087,0x628d0503,0xdc38006e,0x00000000}},	//   minv, _blao, לאזט_, --,
   {{0x7649008a,0x316039b9,0x628d152f,0x75290174}},	//   qeey, _priz_, _clao, puez,
   {{0x752908ec,0x628602fd,0x628d033c,0x00000000}},	//   quez, rkko, _dlao, --,
   {{0x62860006,0x92ae0081,0x648d0076,0x629f0415}},	//   skko, কতে_, _dúic, _emqo,
   {{0x23d10034,0x81df0081,0x224b39ba,0xf486010d}},	//   _हरिद, দুল_, beck_, _زاوی,
   {{0x212b39bb,0x628d152f,0xad9b0146,0x7aee01c2}},	//   buch_, _glao, _neús, _rubt,
   {{0x6da3002d,0xec7a1d5c,0xe8df0139,0x7aee39bc}},	// [2e80] вита, опа_, _apọn_, _subt,
   {{0x7aee023e,0x79820051,0x7d1610a5,0x78a3057a}},	//   _pubt, vyow, rsys, jinv,
   {{0xbcfb04ea,0x00000000,0x00000000,0x00000000}},	//   _préc, --, --, --,
   {{0x8b651823,0x1e8332df,0x49ca14cc,0x00000000}},	//   عالم, _алюм, олен_, --,
   {{0xd91000cd,0x7bc701cd,0x00000000,0x00000000}},	//   ایط_, _eyju, --, --,
   {{0x787d020d,0x6aa239bd,0x00000000,0x00000000}},	//   _sèvr, siof, --, --,
   {{0xfaa60450,0x44f200ae,0x93bc020a,0x212b007f}},	//   _жаво, _sâ_, ngăt, zuch_,
   {{0xdb0e0034,0x7c3e02ac,0xdced0233,0x96341b42}},	//   _wybó, lfpr, nyağ, хниц,
   {{0xbcfb03a9,0xfaa30284,0xfbb00a43,0x00000000}},	//   _kréa, _рато, _করিত, --,
   {{0x337422ee,0xb8662ce3,0x628d01f7,0x20070231}},	//   егор, _تارو, _slao, _ônix_,
   {{0xd25108ba,0xe8ca0096,0x628d009c,0x224b02db}},	//   هند_, ितीच, _plao, teck_,
   {{0x68e839be,0x6d4602b6,0x212b042c,0x32671ac7}},	//   _hidd, _opka, tuch_, фтов,
   {{0x68e839bf,0x656f01bf,0x224b0ec6,0x628d00c4}},	//   _kidd, ächt, reck_, _vlao,
   {{0x55770130,0x212b39c0,0x3dcd003d,0x68e8052e}},	//   _קעגן_, ruch_, _ġew_, _jidd,
   {{0x6d4639c1,0x212b01bf,0x27ec01b9,0x9f3400f3}},	//   _apka, such_, _mgdn_, кері,
   {{0x443e39c2,0x68e826c7,0x645839c3,0xbcfb0113}},	//   lft_, _lidd, _havi, _aréa,
   {{0x645839c4,0x7bca01bf,0xbcfb0037,0x61ed39c5}},	// [2e90] _kavi, üfun, _bréa, _igal,
   {{0xbcfb04ea,0x645800cb,0x443e02e2,0x68e808e8}},	//   _créa, _javi, nft_, _nidd,
   {{0x443e39c6,0x645839c7,0x78a300c2,0xbcfb0037}},	//   ift_, _mavi, vinv, _dréa,
   {{0x64580c56,0x69dd0146,0x41d30965,0x656201c8}},	//   _lavi, _úsek, _सरास, _oroh,
   {{0xaca30174,0xdb1c0579,0x61ed39c8,0x7e7d024a}},	//   _abục, _vyrá, _mgal, _iosp,
   {{0xbcfb0080,0x68e839c9,0x443e0ab2,0x764239ca}},	//   _gréa, _cidd, jft_, _aboy,
   {{0x68e80150,0x65620027,0x78a339cb,0xf0940327}},	//   _didd, _aroh, rinv, כנס_,
   {{0x61ed39cc,0x443e0126,0x68e80150,0x645831e8}},	//   _ngal, eft_, _eidd, _aavi,
   {{0x443e27ce,0x7e7d0052,0xd838022b,0x7ae80383}},	//   fft_, _mosp, _imčn_, _èdta,
   {{0xe1fa06ec,0x645839cd,0x61ed39ce,0x65620364}},	//   ूर्ण_, _cavi, _agal, _droh,
   {{0x645839cf,0x7ae90138,0x53c900d6,0x3d160557}},	//   _davi, _kiet, ягом_, _पौने_,
   {{0x7e7d00d9,0x60c50167,0x656f0364,0x68e839d0}},	//   _nosp, _akhm, ächs, _zidd,
   {{0x7ae939d1,0x81e80033,0xdbdb0139,0x00000000}},	//   _miet, মুন_, _lààk, --,
   {{0x7ae939d2,0x61ed39d3,0x68e8008c,0xb8020285}},	//   _liet, _egal, _xidd, रुपम_,
   {{0xb4cb39d4,0x64430090,0x7ae901ff,0xdc1200a7}},	//   लती_, _ibni, _oiet, xşıd,
   {{0x7ae939d5,0x64580941,0x139a00a1,0x765b0193}},	//   _niet, _zavi, _מבצע, nduy,
   {{0x7e7d0eff,0x753b39d6,0x69c939d7,0xbcfb39d8}},	// [2ea0] _dosp, ntuz, _nyee, _préa,
   {{0xe0d239d9,0x6ab807e2,0x645839da,0x7ae901c8}},	//   _حزب_, इक्र, _xavi, _aiet,
   {{0x7ae939db,0xa09b00c1,0x69c93634,0xcb090120}},	//   _biet, _זייט, _ayee, дхід_,
   {{0x68e839dc,0x7ae900d9,0x7e7d39dd,0xc33200a1}},	//   _sidd, _ciet, _gosp, רוא_,
   {{0x290d01c2,0xe9470018,0x64430034,0x443e238c}},	//   _cwea_, ٹرنی, _obni, yft_,
   {{0x7ae90f5a,0x6443009e,0x00000000,0x00000000}},	//   _eiet, _nbni, --, --,
   {{0x7ae939de,0x645839df,0x0cbe2a45,0x7d0439e0}},	//   _fiet, _ravi, ्तीम, lpis,
   {{0x645839e1,0xd6d70761,0xddcd01ac,0x7d040084}},	//   _savi, нты_, ljaš, opis,
   {{0x645839e2,0xa90a00ab,0x7ae30cad,0x7d0439e3}},	//   _pavi, _ريال_, ïnte, npis,
   {{0xd91b0054,0x443e01bf,0x81af0033,0x7ae939e4}},	//   _מומל, uft_, _করল_, _ziet,
   {{0x443e39e5,0x64580a39,0x22952a6e,0x61ed0063}},	//   rft_, _vavi, виня, _pgal,
   {{0x273a00dd,0x645839e6,0x0cbe0d7e,0x656239e7}},	//   mën_, _wavi, ्तुम, _troh,
   {{0x273a00dd,0xd25100bf,0x1a9b00c1,0x69c9022e}},	//   lën_, هنگ_, ליטע, _xyee,
   {{0x7e7d39e8,0xbcfb0154,0x81c50081,0x21240037}},	//   _sosp, _brén, ৌশল_, ámha_,
   {{0x273a01e5,0xd90400fb,0x6e671bec,0x7e7d39e9}},	//   nën_, _گی_, нтаж, _posp,
   {{0x41de007d,0x61ed39ea,0xd13b35c1,0x00000000}},	//   नेहस, _ugal, _ехо_, --,
   {{0xd90414df,0x273a00dd,0x7ae939eb,0xdd94055b}},	// [2eb0] _دی_, hën_, _riet, гаты,
   {{0x7ae939ec,0x273a00dd,0xe802030b,0x387e0141}},	//   _siet, kën_, रुमा_, _notr_,
   {{0x7ae939ed,0x273a00dd,0x7e7d39ee,0x69c900f9}},	//   _piet, jën_, _tosp, _syee,
   {{0xed5100fb,0x386c02ef,0x273a023b,0xe52100b7}},	//   _پھر_, _andr_, dën_, _मिलि_,
   {{0x7ae939ef,0xe8f80426,0x273a0126,0xddcd042d}},	//   _viet, елі_, eën_, bjaš,
   {{0x07a53574,0xad9b0139,0xaca30174,0x26c62190}},	//   калн, _afúg, _kpọb, _akoo_,
   {{0x7ae939f0,0x273a00dd,0x648d0088,0x6b830149}},	//   _tiet, gën_, _búin, ängd,
   {{0xdddd00d9,0xd90c04c6,0x648d0076,0x48d10033}},	//   _nosū, _کیو_, _cúin, াদের,
   {{0x648d00e3,0x81b001c2,0x387e0147,0x00000000}},	//   _dúin, _keɓe, _fotr_, --,
   {{0xb4cb0f73,0x753b39f1,0x7659084e,0x273a0216}},	//   लते_, rtuz, _wawy, bën_,
   {{0x7d042619,0x273a023b,0x648d0076,0x2a7f05aa}},	//   zpis, cën_, _fúin, _koub_,
   {{0xddcd0995,0x61f90031,0x753b0062,0x00000000}},	//   zjaš, _čalú, ptuz, --,
   {{0xe29739f2,0x660939f3,0x22b600e8,0x00000000}},	//   тая_, mbek, gāka_, --,
   {{0xbcfb39f4,0x9103002d,0x93450114,0x26cd0143}},	//   _prén, рпре, _анке, lleo_,
   {{0x3f8c0146,0x00000000,0x00000000,0x00000000}},	//   ádu_, --, --, --,
   {{0x7d0403ce,0xbcfb2676,0xe3e800c1,0x2eeb0154}},	//   tpis, _créo, _אַפֿ, _cicf_,
   {{0xdee339f5,0x7bd5008f,0x273a00dd,0x1ea900b9}},	// [2ec0] роти, _azzu, zën_, رافي_,
   {{0x0cbe05d4,0xbcfb2299,0x7d04005a,0x225e00d9}},	//   ्तेम, _trén, rpis, ētku_,
   {{0x201839f6,0x91f6000f,0x7dd80139,0x6609112f}},	//   mari_, _इलाज_, _búsí, kbek,
   {{0x201839f7,0x273a00dd,0x7d0420d1,0x85210285}},	//   lari_, vën_, ppis, _मिंट_,
   {{0xdb0e0212,0x2a7f0383,0x7bd50172,0xc02f0023}},	//   _nybö, _doub_, _ezzu, _điếu_,
   {{0x273a074a,0xd90d00d0,0xfc0339f8,0xb4cb0096}},	//   tën_, سیم_, _впро, लतो_,
   {{0xdca31bb8,0xdb1c017a,0x7529083e,0x201801c8}},	//   _тари, _byrå, erez, iari_,
   {{0x273a01e5,0x201839f9,0x6b830924,0x66090af0}},	//   rën_, hari_, änge, gbek,
   {{0x644139fa,0x273a01e5,0xd9460831,0xa3e409c4}},	//   ffli, sën_, _јези, पेन_,
   {{0x201839fb,0x3eb20084,0x29060449,0x273a023b}},	//   jari_, hnyt_, mpoa_, pën_,
   {{0xf4fc0294,0x752939fc,0xbddb0113,0x273a0052}},	//   _dịịr, arez, _abèl, qën_,
   {{0x26cd1c9a,0x201339fd,0x26c60239,0x558a1da9}},	//   cleo_, _sexi_, _ukoo_, _обем_,
   {{0x7529060b,0x20181cc0,0x85761454,0x290601ff}},	//   crez, fari_, _جدائ, npoa_,
   {{0x4ec40081,0x26c439fe,0xf366322c,0x9f35224a}},	//   ্দোল, lomo_, _атин, легі,
   {{0xbcfb00fd,0x78ad020d,0x14b111d7,0x2ca300bd}},	//   _préo, éavi, ीकरण, _rmjd_,
   {{0x26c439ff,0xe802088d,0x5eb43a00,0x00000000}},	//   nomo_, रुता_, айст, --,
   {{0x20183a01,0x00000000,0x00000000,0x00000000}},	// [2ed0] bari_, --, --, --,
   {{0x26c401af,0x3219109b,0x00000000,0x00000000}},	//   homo_, lasy_, --, --,
   {{0x26c410bd,0x00000000,0x00000000,0x00000000}},	//   komo_, --, --, --,
   {{0x3e04008f,0x00000000,0x00000000,0x00000000}},	//   _вярв, --, --, --,
   {{0xbcfb128f,0x3ea93a02,0xf9900037,0x26c43a03}},	//   _krém, miat_, يبه_, domo_,
   {{0x3ea93a04,0x75293a05,0x47593a06,0x99d40cd2}},	//   liat_, vrez, ерия_, جتما,
   {{0xb6a514f8,0x66091090,0x46a500e5,0x2bc804c9}},	//   ликл, tbek, лакв, _ауто_,
   {{0x75293a07,0x20183a08,0x26c43a09,0x3ea93a0a}},	//   trez, zari_, gomo_, niat_,
   {{0xd415280f,0x20183a0b,0x59b7000f,0x66093a0c}},	//   льны, yari_, _आखिर, rbek,
   {{0x130902fd,0x75293a0d,0x66093a0e,0x3ea9020a}},	//   нной_, rrez, sbek, hiat_,
   {{0x3eb202fd,0x26cd14e2,0x64413a0f,0xb63507e8}},	//   ynyt_, pleo_, rfli, _مفاع,
   {{0x26c42eac,0x64413a10,0xbcfb00fd,0xfbd200ca}},	//   como_, sfli, _prél, מתי_,
   {{0x3ea93a11,0xe56e0831,0x64410364,0x648401ec}},	//   diat_, _уз_, pfli, _còis,
   {{0x03190080,0x291f0051,0x50b5004c,0xbcfb020d}},	//   _كتبت_, _mvua_, ассу, _crém,
   {{0x20183a12,0x3ea915c7,0x291d0350,0x00000000}},	//   rari_, fiat_, hswa_, --,
   {{0xbcfb0139,0xe3b001c3,0x41c50129,0xc332021e}},	//   _erém, _بره_, ụsị_, _הוה_,
   {{0xcbb00f71,0x8d662787,0xa3e7000c,0xdb150094}},	// [2ee0] _করেছ, ывае, _मृत_, _vyzý,
   {{0x219b021e,0x20181175,0x0dc7016a,0x7af50634}},	//   _נביא, qari_, улуй_, _buzt,
   {{0x3ea93a13,0x26c40051,0x4b260277,0x1bba0037}},	//   biat_, yomo_, умев, رائع_,
   {{0x3ea9396a,0x7b200146,0x648d0037,0x291d010a}},	//   ciat_, _náuš, _súil, fswa_,
   {{0xa9670aeb,0x19580fe9,0x229202c6,0x648401b9}},	//   лица_, талы_, ušky_, _mòir,
   {{0x6e363a14,0x62960052,0xbddb0154,0x3219007f}},	//   lgyb, ëzoj, _obèj, zasy_,
   {{0x7af503f3,0x26c43a15,0x38cb00d1,0x290601c8}},	//   _guzt, tomo_, راهی_, spoa_,
   {{0x212003ce,0x7f3b00c1,0x212b0150,0x31b50129}},	//   _ovih_, געקו, yrch_, ụzi_,
   {{0x26c43a16,0xa8360068,0xddc403e5,0xbddb0139}},	//   romo_, _معاش, jjiż, _abèj,
   {{0xb99300e3,0x26c4359c,0x212b0146,0xb80a0037}},	//   _الكب, somo_, vrch_, _أيام_,
   {{0x61ea00a7,0x64840441,0x22b600e8,0xdce400e8}},	//   əllə, _sòis, gāko_, dziļ,
   {{0x64840441,0x925800c2,0x7bce0f5a,0x6b8100ee}},	//   _còir, гают_, _mybu, _àlge,
   {{0x3ea93a17,0x32193a18,0xbddb022b,0x648401b9}},	//   viat_, rasy_, _ebèj, _dòir,
   {{0xe3a400cd,0x859b00a1,0x92b50081,0x22b601d3}},	//   _پشتی, _אשדו, ঝতে_, bāko_,
   {{0x7ae20149,0x32193a18,0xbcfb001c,0x648401ec}},	//   kmot, pasy_, _gréj, _fòir,
   {{0x5e5800d6,0x6e360167,0x648401b5,0xa3e42647}},	//   лися_, ggyb, _tòis, पेण_,
   {{0xbcfb2831,0x7af501ff,0x00000000,0x00000000}},	// [2ef0] _trém, _suzt, --, --,
   {{0x3ea90e64,0xe1ff3a19,0x61e9033b,0x28a922e8}},	//   siat_, lcó_, žels, _औषधि,
   {{0x3ea93a1a,0x75eb0018,0x3d1b0139,0x29043a1b}},	//   piat_, _közü, _bàwá_, _atma_,
   {{0x291d05bd,0x7ae23a1c,0xe1ff034f,0x60c70052}},	//   tswa_, gmot, ncó_, lojm,
   {{0x2249072f,0x81b00022,0x00000000,0x00000000}},	//   _mbak_, _keɓa, --, --,
   {{0x60c7023b,0xf7713a1d,0x00000000,0x00000000}},	//   nojm, قاب_, --, --,
   {{0x96950095,0x7ae210f4,0x3d1b0139,0xdd0e0233}},	//   ириш, bmot, _fàwá_, _kışl,
   {{0x31690d1b,0xada60220,0x068524ec,0xa3de02c6}},	//   _oraz_, slúž, ргин, _běží_,
   {{0x60c73a1e,0xef190034,0x04190033,0x3a743a1f}},	//   kojm, ąży_, _দাবী_, _ултр,
   {{0x66f10029,0x6aab0f04,0xbcfb3a20,0x22490113}},	//   _sāku, ligf, _arék, _abak_,
   {{0x212003ce,0xe29a1940,0x798b0150,0x290000ae}},	//   _svih_, ван_, lygw, ţiat_,
   {{0x91e60752,0x31690131,0x61fa02c6,0x22b600e8}},	//   ионе, _braz_, ětlo, rāko_,
   {{0x6f05009b,0xfd650174,0x7d090216,0x75eb013c}},	//   _athc, rosọ, _çesh, _dözü,
   {{0x661b3a21,0x7ae20335,0x224900f9,0xbcfb0032}},	//   lauk, zmot, _ebak_, _erék,
   {{0x44fb0665,0x23760421,0x316901ff,0xafe61aad}},	//   _hê_, _نمود_, _eraz_, ровл,
   {{0x44fb0019,0x316902f1,0x75eb03a3,0x394d01ee}},	//   _kê_, _fraz_, _gözü, _opes_,
   {{0x394d022e,0x6e363a22,0x31693a23,0x62960350}},	// [2f00] _npes_, rgyb, _graz_, _ilyo,
   {{0x661b3a24,0x44fb0019,0x6e360150,0xb7b50139}},	//   hauk, _mê_, sgyb, _gẹg,
   {{0x66f10029,0x44fb3a25,0xf1aa22a0,0x661b3a26}},	//   _māks, _lê_, _चेतन, kauk,
   {{0x661b3a27,0x7bce0146,0x6b830149,0x628400ee}},	//   jauk, _vybu, änga, _joio,
   {{0x661b3a28,0x44fb3a29,0x7bce0034,0x09b01115}},	//   dauk, _nê_, _wybu, जपेय,
   {{0x62843a2a,0x6aab009c,0x00000000,0x00000000}},	//   _loio, aigf, --, --,
   {{0xe7e1007a,0xc1d30374,0x44fb0131,0x6296083e}},	//   गेला_, _सर्ग, _aê_, _olyo,
   {{0x44fb00de,0x62840451,0x35463a2b,0x60c70052}},	//   _bê_, _noio, ахов, zojm,
   {{0x7d060063,0x44fb0131,0x66f101d3,0x672105db}},	//   _jtks, _cê_, _sākt, _evlj,
   {{0x44fb3a2c,0x75eb008e,0x07a63617,0x62960517}},	//   _dê_, _sözü, _казн, _alyo,
   {{0x62840231,0x316902c6,0x57fb0142,0x60c71136}},	//   _boio, _sraz_, _סלאו, vojm,
   {{0x6284009c,0x661b0085,0x44fb3a2d,0x3169044c}},	//   _coio, cauk, _fê_, _praz_,
   {{0x66023a2e,0x60c7023b,0xe1ff3a2f,0x628f0381}},	//   _ifok, tojm, rcó_, rkco,
   {{0x62963a30,0xe1ff3a31,0x00000000,0x00000000}},	//   _elyo, scó_, --, --,
   {{0x60c73a32,0x443c05fe,0xd4c500e3,0x4ea73a33}},	//   rojm, _icv_, _اغني, араа,
   {{0x3169001f,0x60c7023b,0x6284338f,0x00000000}},	//   _traz_, sojm, _goio, --,
   {{0x44fb00fe,0x6602039f,0x00000000,0x00000000}},	// [2f10] _xê_, _mfok, --, --,
   {{0x70550de1,0xcc740291,0x7d020076,0x00000000}},	//   _اندا, огућ, íosa, --,
   {{0x6a1700e3,0x6aab3a34,0x394d3a35,0x443c044c}},	//   لبشر, tigf, _spes_, _mcv_,
   {{0x752200cc,0x99d90037,0x00000000,0x00000000}},	//   _ovoz, هواء_, --, --,
   {{0x661b1855,0x7afb031a,0x644a007f,0x00000000}},	//   vauk, _čutu, _obfi, --,
   {{0x88c800d6,0x66020139,0x6d5d3a36,0xfc67008f}},	//   алів_, _afok, _issa, _тъмн,
   {{0xfbe51348,0x44fb040c,0x661b3a37,0xbb8500e3}},	//   _প্রত, _sê_, tauk, _الزي,
   {{0xbcfb3a38,0xcfb800ca,0x66f101d3,0x78a600c6}},	//   _préh, ילוי_, _sāks, _įkve,
   {{0x661b3a39,0x6aa91775,0x443c037a,0xbcfb0076}},	//   rauk, _imef, _bcv_, _bréi,
   {{0x661b0029,0x44fb3a3a,0xbcfb0428,0x75221912}},	//   sauk, _vê_, _créi, _dvoz,
   {{0x661b0084,0xe6430491,0xbcfb00da,0x660200bd}},	//   pauk, şmış, _dréi, _ffok,
   {{0xc7b200ca,0x44fb3a3b,0x6d5d3a3c,0x76950139}},	//   _צבא_, _tê_, _ossa, _fáya,
   {{0xd6c600bf,0x75222461,0xe3b10100,0x6aa93a3d}},	//   _امنی, _gvoz, ترک_, _mmef,
   {{0xbcfb0037,0x409523b9,0xba3d00d2,0x6ab306eb}},	//   _gréi, орст, _smůl, ंचुर,
   {{0xdfd200e3,0x6d5d3a3e,0x661900bd,0x6ab7023a}},	//   سير_, _assa, _kewk, _अदूर,
   {{0xb21b052f,0x6abb00e7,0xed5a3a3f,0x00000000}},	//   skær, _njuf, лоб_, --,
   {{0xa2c51fb4,0x6b833a40,0x4427061d,0x0c2626fd}},	// [2f20] रवर्, ängn, _kdn_, йман,
   {{0x6aa90051,0xa3ab0557,0x8db5004d,0x44273a41}},	//   _amef, _गधा_, істі, _jdn_,
   {{0x6d5d3a42,0x0b461bec,0x69db037a,0xa3db00a4}},	//   _essa, снен, _azue, ढेच_,
   {{0x32022f8a,0xc3320327,0xfe9400d1,0x00000000}},	//   ncky_, לוב_, _بیرج, --,
   {{0x442714f3,0x14c70179,0xda650190,0x823b006e}},	//   _odn_, रकाण, تالي, רענצ,
   {{0x6aa90294,0xddcd0092,0x6d44023e,0xc7b00103}},	//   _emef, ldaş, mtia, وڑا_,
   {{0x6d443a43,0x9f58034f,0xb8ff09a1,0x656b044c}},	//   ltia, mbró_, _धी_, _argh,
   {{0xddcd008e,0x201a3a44,0x7e643a45,0xaa433a46}},	//   ndaş, _lepi_, ndip, _несл,
   {{0x6d443a47,0x44273a48,0x661d01cd,0xbcfb3a49}},	//   ntia, _bdn_, ðska, _préi,
   {{0x201a0113,0xb4c234fd,0x81ae0033,0x6d443a4a}},	//   _nepi_, ंवे_, কথা_, itia,
   {{0x6d443a4b,0x0ec81926,0xddcd04a8,0x00000000}},	//   htia, लवाड, kdaş, --,
   {{0x6d44113a,0x442703c3,0xbddb0139,0x00000000}},	//   ktia, _edn_, _gbèw, --,
   {{0xbcfb00e3,0xad9b3a4c,0x7e643a4d,0x6d44023e}},	//   _tréi, _afún, ddip, jtia,
   {{0x443c037a,0x201a3a4e,0x6d5d01ff,0xbcfb0231}},	//   _ucv_, _cepi_, _rssa, _uréi,
   {{0x201a14b1,0xbc690018,0xddcd00a7,0x6d4f0231}},	//   _depi_, یجئے_, fdaş, _spca,
   {{0x644818f0,0x00000000,0x00000000,0x00000000}},	//   lfdi, --, --, --,
   {{0x7bdc00dc,0x6d4401fa,0xad9b0065,0xead00032}},	// [2f30] _azru, gtia, _efún, _jẹun_,
   {{0x1dba0285,0x00000000,0x00000000,0x00000000}},	//   _इशरत, --, --, --,
   {{0x69c00694,0xd9f91102,0x6d443a4f,0x00000000}},	//   _axme, анец_, atia, --,
   {{0x70551aaa,0x629d020b,0xe80b00c3,0x201a0f09}},	//   _انگا, nhso, सुना_, _zepi_,
   {{0xa92400d6,0x2bdb04f1,0xbcfb0143,0x6d44078e}},	//   зділ, _भरवा, _arév, ctia,
   {{0x200300a5,0x18692efb,0x2bd9010d,0xd709231c}},	//   ncji_, раки_, _نازک_, анке_,
   {{0x7d0d3a50,0xbcfb0113,0x00000000,0x00000000}},	//   lpas, _préw, --, --,
   {{0x442708d3,0x6aa92822,0x7d0d1242,0xdd090206}},	//   _sdn_, _umef, opas, _môžt,
   {{0x20030067,0x7d0d3a51,0x3a3f00b3,0xe9e50131}},	//   kcji_, npas, _icup_, ãºdo_,
   {{0x8d5c0327,0x3e6f007b,0xc3251cf2,0x00000000}},	//   רכזי, _yötä_, омок, --,
   {{0x6d4402a7,0x68fb00c2,0xbddb0139,0xddcd028e}},	//   ztia, _huud, _ibèu, ydaş,
   {{0x201a14c4,0x7d0d0449,0x68fb3a52,0x6d4400eb}},	//   _sepi_, kpas, _kuud, ytia,
   {{0x7d0d029a,0x68fb3a53,0x656b0076,0x00000000}},	//   jpas, _juud, _urgh, --,
   {{0x68fb0006,0xa06a013f,0x442702db,0x00000000}},	//   _muud, шага_, _udn_, --,
   {{0xaac91592,0x6b8311d0,0x7d0d3a54,0x68fb3a55}},	//   िकाक, ängl, epas, _luud,
   {{0x6d443a56,0x527624c0,0x61f601df,0x35ce034c}},	//   ttia, _фуку, _ugyl, _हुड़,
   {{0x201a063f,0x7d0d1d11,0xddcd0092,0x649600d3}},	// [2f40] _tepi_, gpas, rdaş, _mâin,
   {{0x3a3f00b3,0x40960a54,0xec77100c,0xd9100103}},	//   _acup_, _фрит, опу_, ہیر_,
   {{0x6d443a57,0x7d0d15d8,0xaec600ae,0x67230141}},	//   stia, apas, _мбол, jsnj,
   {{0x7bdc0146,0x6d443a58,0x2e6a0012,0x68fb3a59}},	//   _vzru, ptia, _тимп_, _buud,
   {{0x18740c10,0xc98300c2,0x764900f0,0xc7b814f3}},	//   згля, дущи, dfey, _međe_,
   {{0xf72a1995,0xbcfb3a5a,0x24870c56,0x67230b14}},	//   аций_, _prév, _nonm_, fsnj,
   {{0xab273a5b,0x7bdc3a5c,0x00000000,0x00000000}},	//   _мора_, _uzru, --, --,
   {{0xf5261be2,0xc7b800e7,0x649600ae,0x22400063}},	//   офон, _neđe_, _câin, _ncik_,
   {{0x7e9b0341,0x22b601d3,0x20030034,0x24870383}},	//   יסקו, cāki_, ycji_, _bonm_,
   {{0x7afc3a5d,0x60c200e3,0x22403a5e,0x394633f4}},	//   _kurt, _íomh, _acik_, mtos_,
   {{0x3160022b,0x7afc3a5f,0xc60601b3,0xa3e406eb}},	//   _asiz_, _jurt, _дзей, पें_,
   {{0x39460138,0x929401b3,0x28a62397,0xdce40117}},	//   otos_, даюц, कोरि, dvič,
   {{0x394608ec,0x28df0354,0x7afc1b60,0xfd4e0134}},	//   ntos_, _पीडि, _lurt, rikọ,
   {{0x39463a60,0xc0cb3a61,0x6ab7058f,0xf8ca009f}},	//   itos_, руме_, _अद्र, ाकिय,
   {{0x7d0d0036,0x14c711d7,0xeeab3a62,0x2003007f}},	//   wpas, रकरण, атак_, rcji_,
   {{0x7d0d3a63,0x394624e5,0xc33300a1,0x539b00ca}},	//   tpas, ktos_, _חוק_, _כיוו,
   {{0x7afc0a00,0x3ebe003e,0x7d0d2459,0x2003007f}},	// [2f50] _aurt, étta_, upas, pcji_,
   {{0x21393a64,0x68fb3a65,0xc0580120,0x00000000}},	//   mush_, _ruud, _дію_, --,
   {{0x68fb3a66,0x7afc3a67,0xdce40146,0x2a6401c2}},	//   _suud, _curt, cvič, _bamb_,
   {{0x68fb0006,0x7d0d3a68,0xbcfb06fc,0x67380dd9}},	//   _puud, ppas, _brét, duvj,
   {{0xa9693a69,0x21393a6a,0x2a6400b3,0xbcfb020d}},	//   сила_, nush_, _damb_, _crét,
   {{0x7afc3a6b,0xacfa00ca,0x22b601d3,0x26cf007e}},	//   _furt, _להשכ, rāki_, _skgo_,
   {{0x7afc3a6c,0x2a6607ac,0x8cba0285,0x649600ae}},	//   _gurt, bdob_, ्वरो, _pâin,
   {{0xbcfb0682,0x213900dd,0xba770adb,0x395f023e}},	//   _frét, kush_, _باست, _tsus_,
   {{0x39463a6d,0x395f32c3,0xc7b8049c,0xbcfb2a6b}},	//   ctos_, _usus_, _ređe_, _grét,
   {{0x7afc026a,0x65693a6e,0x00000000,0x00000000}},	//   _yurt, rveh, --, --,
   {{0x61f100a7,0x27070023,0x00000000,0x00000000}},	//   ədlə, _qđnd_, --, --,
   {{0x21390085,0x2487022b,0x00000000,0x00000000}},	//   fush_, _wonm_, --, --,
   {{0xe80200b6,0x24870383,0x00000000,0x00000000}},	//   रुका_, _tonm_, --, --,
   {{0xdce41b6a,0x03a500d3,0x648d0076,0x2ec41677}},	//   tvič, _нило, _cúit, वक्त,
   {{0x39460018,0x09b80096,0x66de023b,0xdee63a6f}},	//   ztos_, _अश्य, lëka, зови,
   {{0x394600c6,0x21393a70,0x22403a71,0x90460113}},	//   ytos_, bush_, _ucik_, _کنده,
   {{0x7afc3a72,0xf5390220,0xd00f0018,0x67380dd9}},	// [2f60] _surt, nuť_, ئلہ_, zuvj,
   {{0x7afc10de,0xc1730089,0x2a640d19,0xe1ff06cb}},	//   _purt, _נחת_, _samb_, ndón_,
   {{0xbcfb00fd,0x7afc0092,0xf53900d4,0x6ffb1777}},	//   _brés, _qurt, huť_, _להיפ,
   {{0xbcfb00fd,0x37d10033,0xdb2300d2,0x00000000}},	//   _prét, াধার, írán, --,
   {{0x39463a73,0x2bac0285,0x90a500d1,0x649600fc}},	//   utos_, _टेरा, _رحیم, _bâil,
   {{0x98a3185c,0x7afc183f,0x22b600e8,0x00000000}},	//   ниче, _turt, māku_, --,
   {{0xfbc30426,0x7afc01c0,0x2a643a74,0x22b601d3}},	//   _збро, _uurt, _tamb_, lāku_,
   {{0x39463a75,0xb9020081,0xbddb3a76,0xdb1c0034}},	//   ptos_, _নং_, _ibèr, _wyró,
   {{0x7e663a77,0xf7f601f9,0xbcfb03a9,0x00000000}},	//   _makp, _فساد, _urét, --,
   {{0x3ebf033b,0xb82700ae,0x213911bc,0x00000000}},	//   čuti_, _ноуз_, vush_, --,
   {{0x62351a57,0x2259066a,0x00000000,0x00000000}},	//   мену, tesk_, --, --,
   {{0x0bb70796,0x5187007b,0x00000000,0x00000000}},	//   ללים_, пуга, --, --,
   {{0x5bb909a1,0xcfaa0081,0x22593a78,0x5fd2009f}},	//   _आश्व, _খুলন, resk_, _दुबल,
   {{0x212d030b,0xa3b400d6,0x65623a79,0xd4673a7a}},	//   šeho_, _облі, _isoh, _ниче_,
   {{0x4fc40ce5,0xc7b800fe,0x00000000,0x00000000}},	//   еста, _gdđt_, --, --,
   {{0x443e3a7b,0x9ed907bf,0x3ea0078e,0x00000000}},	//   lgt_, імат_, ghit_, --,
   {{0x7e663a7c,0xbcfb0032,0x443e01c0,0x22b600e8}},	// [2f70] _dakp, _arér, ogt_, gāku_,
   {{0x645a3a7d,0x443e01b4,0x6728029b,0xa2c5045f}},	//   neti, ngt_, _ovdj, रवक्,
   {{0xbcfb04ea,0x443e365f,0x9e1500d6,0x46cc3542}},	//   _prés, igt_, _одні, ावाह,
   {{0xd36600bf,0x7c3e01c0,0x629d0052,0xd9990037}},	//   _یه_, agpr, ëroh, ينات_,
   {{0x22b601d3,0x67020294,0xbddb05aa,0x65620079}},	//   cāku_, _ọkpa, _ebèr, _nsoh,
   {{0x443e0ab2,0xbcfb1022,0x648d033c,0x00000000}},	//   jgt_, _frér, _lúir, --,
   {{0x645a3a7e,0xbcfb3a7f,0x656205bd,0xbddb0065}},	//   deti, _trés, _asoh, _gbèr,
   {{0x443e3a80,0x22b600d9,0x672805db,0xa3e71677}},	//   egt_, nākt_, _dvdj, _मृग_,
   {{0xdddd00a5,0x3a2d0113,0x645a3a81,0x00000000}},	//   _hasł, _idep_, feti, --,
   {{0x443e3a82,0x73053a83,0x648d0037,0x3ea0023b}},	//   ggt_, мпоз, _rúis, zhit_,
   {{0x9c87030b,0xe1ff04d8,0x6562063d,0x648d033c}},	//   _začá, rdón_, _esoh, _búir,
   {{0xd5ae1e49,0x443e0ab2,0xe2970a2d,0x648d0037}},	//   افی_, agt_, даю_, _cúir,
   {{0x645a3a84,0x648d00e3,0x81b001c2,0xd00a007e}},	//   beti, _dúir, _keɓi, жеге_,
   {{0x645a3a85,0x7e663a86,0x9f4e1054,0x753b2f0f}},	//   ceti, _sakp, žník_, muuz,
   {{0x7e663a87,0x96e1030b,0x3ea03a88,0xff0700ae}},	//   _pakp, _पठाउ, thit_, деск_,
   {{0xdee300c2,0xdee61a9f,0xf1fa3a89,0x3d021179}},	//   воси, фоби, _بعثت_, _वंदे_,
   {{0x3ea01044,0x6fe7014b,0x00000000,0x00000000}},	// [2f80] rhit_, técé, --, --,
   {{0x62860039,0x3ea000dd,0xc7b8005f,0xb21b052f}},	//   ljko, shit_, _leđa_, hjæl,
   {{0x307b00a1,0x290d3a8a,0x3ea01e03,0x7c3e1cab}},	//   _ואינ, _atea_, phit_, rgpr,
   {{0x645a3a8b,0xe9da3a8c,0x3a2d078e,0x753b2d30}},	//   zeti, оке_, _cdep_, kuuz,
   {{0x443e09ce,0xbcfb0257,0x645a3a8d,0x6e2438bf}},	//   ygt_, _fréq, yeti, maib,
   {{0xf2bb152c,0x3a2d3a8e,0x6e240441,0x645a3a8f}},	//   _उद्घ, _edep_, laib, xeti,
   {{0x290d0072,0x36d42383,0x22b601d3,0x00000000}},	//   _etea_, нокр, nāks_, --,
   {{0xcfc00081,0x6e243a90,0xebe31ad1,0x769c0113}},	//   _ইরান, naib, _росп, _béya,
   {{0x645a3a91,0x2bbe030b,0xdddd0034,0x7ae3020a}},	//   teti, ्थवा, _zasł, înte,
   {{0x443e3a92,0x84e70037,0x00000000,0x00000000}},	//   ugt_, وفيق_, --, --,
   {{0x443e3a93,0xd6cf362f,0x6e2400a6,0xc7b800e7}},	//   rgt_, _ат_, kaib, _feđa_,
   {{0x645a0542,0x6e240da3,0x65621114,0x6b833a94}},	//   seti, jaib, _tsoh, ängi,
   {{0x7c2e215e,0x65960e5a,0x6e243a95,0xbcfb002b}},	//   _odbr, _تجار, daib, _asén,
   {{0xe3af2c6a,0x69b101e4,0x00000000,0x00000000}},	//   اری_, _आइसी, --, --,
   {{0xf363004b,0xbddb0139,0xceb40092,0xdfd8008f}},	//   _атын, _abèp, fiə_, дът_,
   {{0x76401df6,0x6e243a96,0xd5e20640,0x21290063}},	//   ngmy, gaib, _पराज, _tvah_,
   {{0x3d1a030b,0xbcfb020d,0x00000000,0x00000000}},	// [2f90] मीले_, _crép, --, --,
   {{0x66de0052,0x61e00233,0x22b600e8,0x442e014b}},	//   këko, ümle, sākt_, _jdf_,
   {{0x5a3511b7,0x6e243a97,0x3eb00076,0x9f45007b}},	//   енет, baib, últú_, älä_,
   {{0x6e243a98,0x6aa200f0,0x628d0131,0x442e0027}},	//   caib, ghof, _joao, _ldf_,
   {{0x49b800cd,0xc7b8007e,0x00000000,0x00000000}},	//   واهد_, _ređa_, --, --,
   {{0x2bbe09c4,0xf09f00ee,0xf7490076,0x00000000}},	//   ्थशा, mpàs_, كلتي_, --,
   {{0xb906000d,0x46f535a8,0x7c253a99,0xe7392790}},	//   _यी_, нчит, mahr, чей_,
   {{0x6aa20a3d,0x32c407e7,0x28df0179,0x05650291}},	//   chof, kıya_, _पीरि, евин,
   {{0x81b400c7,0x04b530cf,0x959905b6,0xe5710b9f}},	//   _জুন_, есня, ятку_, اطب_,
   {{0xb21b052f,0x442e05bd,0x7c252ce2,0x00000000}},	//   sjæl, _cdf_, nahr, --,
   {{0x032200ae,0x889a00ca,0x543500d1,0xe3b600ae}},	//   лдэн, _צבעי, ورگر, ебэ_,
   {{0x51f70068,0x753b0051,0x442e17f9,0x7c250063}},	//   کسپر, puuz, _edf_, hahr,
   {{0xbddb0257,0x442e0ac1,0x349501b3,0x6e243a9a}},	//   _scèn, _fdf_, _падр, vaib,
   {{0x92c200c7,0x442e3a9b,0x7c250364,0x6e242230}},	//   ্গে_, _gdf_, jahr, waib,
   {{0x6e243a9c,0x64413a9d,0x00000000,0x00000000}},	//   taib, mgli, --, --,
   {{0x66093a9e,0xbcfb025a,0x64413a9f,0x442e3aa0}},	//   ncek, _prép, lgli, _zdf_,
   {{0x7c2502dc,0x6e243aa1,0xed5700c9,0x64413aa2}},	// [2fa0] fahr, raib, нот_, ogli,
   {{0x64413aa3,0x6e243aa4,0x61e40201,0x7d040052}},	//   ngli, saib, _izil, rqis,
   {{0x20183aa5,0x6e240eac,0x2ef9009c,0x4425279c}},	//   mbri_, paib, _fisf_, ial_,
   {{0x44253aa6,0x2ebd0bd9,0x629d0138,0xfaa33aa7}},	//   hal_, ्कृत, ūrov, лахо,
   {{0x44253aa8,0x7d042ce7,0x7bc705b4,0x00000000}},	//   kal_, qqis, _exju, --,
   {{0x6cd600e3,0x6aa23aa9,0x7c2e052f,0xfbd10018}},	//   _أقسا, shof, _udbr, اتے_,
   {{0x442e3aaa,0x59dc000f,0xf09300a1,0x2bbe0096}},	//   _rdf_, _बरकर, רנו_, ्थळा,
   {{0x44253aab,0x61e409ac,0x64413aac,0x7d092ee8}},	//   eal_, _ozil, egli, _éesc,
   {{0x44253aad,0x00000000,0x00000000,0x00000000}},	//   fal_, --, --, --,
   {{0x44253aae,0x182800cd,0x337422ff,0x64413aaf}},	//   gal_, _آقای_, вгор, ggli,
   {{0x61e43ab0,0xc61f0033,0x5c37006e,0x00000000}},	//   _azil, _ধারা_, ערטן_, --,
   {{0x44253ab1,0x64413ab2,0x81b001c2,0x7c2500d4}},	//   aal_, agli, _leɓu, zahr,
   {{0x4425377c,0xa3e40179,0x672a004d,0x00000000}},	//   bal_, पेज_, lsfj, --,
   {{0x44253ab3,0x32c4020e,0x00000000,0x00000000}},	//   cal_, rıya_, --, --,
   {{0x7ea3007a,0xdfd52787,0x61e43ab4,0xbcfb0103}},	//   _lõpe, товы, _ezil, _esél,
   {{0x7c2501bf,0x6b8100ee,0x32c4020e,0x00000000}},	//   wahr, _àlgi, pıya_, --,
   {{0x661d0102,0xa2ce0fdd,0x2d581476,0x20183ab5}},	// [2fb0] ðski, सवर्, нить_, bbri_,
   {{0x6ac90c3c,0x2d87150a,0xc60d2a24,0xc7b800e7}},	//   िक्र, ćne_, _सभ्य_, _neđo_,
   {{0x212b2b84,0x2be60096,0xf09f015e,0x00000000}},	//   lsch_, _करणं_, spàs_, --,
   {{0x44253ab6,0xc5fe00e8,0x00000000,0x00000000}},	//   zal_, šējo_, --, --,
   {{0x212b0924,0x68fa1a4a,0x44253ab7,0x64413ab8}},	//   nsch_, _bitd, yal_, ygli,
   {{0x7e6d3ab9,0x44253aba,0x212b01bf,0xa3c00f65}},	//   ldap, xal_, isch_, ंपा_,
   {{0x2bb80080,0x23cf3abb,0x6d4d3abc,0x46a508c3}},	//   _كافة_, _सुंद, ltaa, какв,
   {{0x7e6d03b4,0x6d4d010a,0x6b831d7e,0x752901c8}},	//   ndap, otaa, ängu, tsez,
   {{0x6d4d3abd,0x644102dc,0x068200ae,0x66093abe}},	//   ntaa, tgli, ргын, rcek,
   {{0xd90d00bf,0x97a71104,0x75293abf,0x64413ac0}},	//   _هیچ_, _прел, rsez, ugli,
   {{0x44253ac1,0x28b604a9,0x6d4d0084,0x64413ac2}},	//   ral_, _अगति, htaa, rgli,
   {{0xddc4002d,0x64410150,0x6d4d3ac3,0x7afb037a}},	//   ndiţ, sgli, ktaa, _jiut,
   {{0x7afb0103,0x6724007e,0x7ae9009c,0x00000000}},	//   _miut, ćije, _mhet, --,
   {{0x7e7d3ac4,0x44253ac5,0xe3b91c00,0x7afb3ac6}},	//   _ansp, qal_, _обл_, _liut,
   {{0x03a2004d,0xadc30139,0x7ae90062,0x03a50036}},	//   _вищо, _ibẹb, _ohet, _шико,
   {{0x7e6d019c,0x6d4d1f43,0x212b042c,0xa2d300a4}},	//   gdap, ftaa, bsch_, ठवण्,
   {{0x6d4d3ac7,0x61e40415,0x00000000,0x00000000}},	// [2fc0] gtaa, _uzil, --, --,
   {{0x7afb0465,0xeb9a0231,0x7e7d02f1,0x7c3b03e3}},	//   _aiut, миз_, _ensp, _ɓurg,
   {{0x6d4d026d,0x8fa63ac8,0xfd1f026e,0x0b463ac9}},	//   ataa, _ране, _ewì_, тнен,
   {{0x7ae93aca,0x7afb0990,0x78a13acb,0x6d4d008a}},	//   _chet, _ciut, _allv, btaa,
   {{0x6d4d3acc,0x7ae901b5,0x7ceb01bf,0xd9540e00}},	//   ctaa, _dhet, dürf, انتخ,
   {{0xf77226a0,0xaca40174,0x7ae3029a,0x69db03a8}},	//   لاع_, _kpọs, ïntr, _dyue,
   {{0x7afb3acd,0x6b8309b5,0xb6c6028d,0x00000000}},	//   _fiut, ängt, ксий, --,
   {{0x7afb3ace,0xe6cc0971,0x3ce63acf,0x61fb00c6}},	//   _giut, ावेज, _जीते_, žuli,
   {{0xceb3004f,0xe9d73ad0,0xc1e1007f,0x00000000}},	//   ייה_, _акт_, _नरेग, --,
   {{0x68fa04ee,0xb4cc3ad1,0xb86512eb,0x00000000}},	//   _uitd, लवे_, _مامو, --,
   {{0xa2953ad2,0x387e0012,0x290404f9,0x83fc0ea3}},	//   гані, _intr_, _huma_, jeđe,
   {{0x29042bc2,0x7bdc0332,0x26c0013f,0x387e0063}},	//   _kuma_, _myru, čios_, _hntr_,
   {{0x29043ad3,0xe5341736,0x386c3ad4,0xaca43ad5}},	//   _juma_, _сель, _kadr_, _apọs,
   {{0x212b1489,0x29043ad6,0x7ceb3ad7,0x2ebd1678}},	//   rsch_, _muma_, mürg, ्क्त,
   {{0x29043ad8,0xff040423,0x63ad01c2,0x7e6d07ac}},	//   _luma_, иятн, _ƙane, tdap,
   {{0x6d4d0084,0x5f94017b,0x2904057a,0x63b60022}},	//   ttaa, шист, _ouma_, _ƙanƙ,
   {{0xdef813a4,0x7e6d3ad9,0x29040396,0x7afb3ada}},	// [2fd0] тыр_, rdap, _numa_, _riut,
   {{0x6d4d3adb,0x7ae93adc,0x7afb3add,0x80c10081}},	//   rtaa, _shet, _siut, _শীর্,
   {{0x6d4d3ade,0x50b81f0b,0x7afb3adf,0x5f953051}},	//   staa, _جديد_, _piut, _синт,
   {{0x6d4d0496,0x26c60239,0x83fc007e,0x29040381}},	//   ptaa, _njoo_, ceđe, _buma_,
   {{0x386c3ae0,0x8d840e05,0x7d020076,0x3a243ae1}},	//   _badr_, _курд, íost, _demp_,
   {{0x98e500e3,0x7ae900a1,0x6b8309b5,0xe8f8004d}},	//   دكتو, _whet, ängs, влі_,
   {{0x0058040a,0x224901e8,0x3a240072,0xe7d10033}},	//   דשות_, _ocak_, _femp_, াধ্য,
   {{0xdb24054f,0x69c9006c,0x629d029a,0xd75601c3}},	//   _úsái, _txee, jkso, اليت_,
   {{0xb5fd0ea3,0xdced00c4,0x59b70d7a,0x78b80172}},	//   ješe, hvač, _अधिर, bivv,
   {{0x2a7f0d7d,0x34853ae2,0x20010019,0x22492253}},	//   _hnub_, угог, _nghi_, _acak_,
   {{0x947500bf,0x6f03002b,0x00000000,0x00000000}},	//   ندگا, _énch, --, --,
   {{0x2001028d,0x97a40cfc,0xaad3142e,0x7ceb042c}},	//   _aghi_, _трул, तविक, bürg,
   {{0x661b33a5,0xd4680281,0x83fc007e,0x00000000}},	//   mbuk, رحیم_, veđe, --,
   {{0x9103051b,0x55ba00a1,0x661b3ae3,0x629d3ae4}},	//   спре, _אמנו, lbuk, ëror,
   {{0x2d8f1680,0x3f9e025b,0xb4c11117,0x4f953ae5}},	//   ägen_, átu_, ्की_, арту,
   {{0x661b3ae6,0xa3c00285,0x00000000,0x00000000}},	//   nbuk, ंपर_, --, --,
   {{0x83fc03ce,0x394d006c,0x661b0239,0xecea3ae7}},	// [2fe0] ređe, _nqes_, ibuk, едал_,
   {{0xf0663ae8,0x29043ae9,0x2a7f00f9,0x661b0167}},	//   _скоп, _ruma_, _anub_, hbuk,
   {{0xeb970231,0xddd40034,0x7ceb071d,0x00000000}},	//   лиф_, _łańc, dürd, --,
   {{0x094a1e11,0x386c03e3,0x7524026a,0x7bdc3aea}},	//   ечки_, _sadr_, _çizg, _vyru,
   {{0x5f76010d,0x38a20088,0x78b8049c,0x82d7006e}},	//   _شاگر, _aðra_, tivv, נונג_,
   {{0x4b260fba,0x386c3aeb,0x2ee00abd,0x2a6d01c8}},	//   _معرف, _qadr_, llif_, _eaeb_,
   {{0xd6d03a89,0x3a243763,0xc1e106eb,0x00000000}},	//   يقت_, _temp_, _नर्ग, --,
   {{0xa53417e9,0x661b3aec,0x29043aed,0x6b830149}},	//   анич, gbuk, _tuma_, ånge,
   {{0x656d00e7,0x6e260095,0xb4c13aee,0x883600d3}},	//   _šahr, _mekb, ्कू_, _бэец,
   {{0xd5630465,0xb8820094,0xf429007b,0xa3c01179}},	//   стъп, čísl, viää_, ंपल_,
   {{0x2ee0008e,0x661b3aef,0x00000000,0x00000000}},	//   klif_, bbuk, --, --,
   {{0x753b0036,0x6e260abf,0x66e30a3a,0x26df0231}},	//   bruz, _nekb, _лоха, cluo_,
   {{0x629d05a3,0xc05b02ec,0x753b2ad4,0x66023af0}},	//   rkso, нів_, cruz, _igok,
   {{0x6fd60455,0xdced0995,0xf4840d7f,0x00000000}},	//   _मुहू, tvač, _خاصی, --,
   {{0x7d063af1,0xb5fd3af2,0x60d50c6f,0x00000000}},	//   _auks, reše, rozm, --,
   {{0x7d063af3,0xdced0094,0x75222711,0x6e2000bc}},	//   _buks, rvač, _kwoz, _õmbl,
   {{0xa3b8009d,0x6e2624e7,0xb5fd033b,0x7ceb042c}},	// [2ff0] _घेत_, _dekb, peše, hüre,
   {{0x7d06023b,0x75220172,0x00000000,0x00000000}},	//   _duks, _mwoz, --, --,
   {{0x70fa00ca,0xdce40a39,0x7ae3044c,0x60fa00ca}},	//   _שהתח, zvić, înto, _שהתק,
   {{0x66020e7a,0x7ceb3af4,0xc33300ca,0xa3be0442}},	//   _ngok, würd, מוע_, _ेशन_,
   {{0xa969021c,0x7ceb03e0,0x645806ce,0x3ea90076}},	//   тила_, türd, _obvi, mhat_,
   {{0xe7393af5,0x7c87055b,0x3ea90103,0x660206b0}},	//   век_, _суме, lhat_, _agok,
   {{0x75223af6,0x07a53af7,0x7ceb173c,0x661b1a4a}},	//   _awoz, райн, rürd, tbuk,
   {{0x753b3af8,0x7d060847,0x3ea93af9,0x75223afa}},	//   truz, _yuks, nhat_, _bwoz,
   {{0x661b10dd,0x7e6f0441,0x78470018,0xca481f11}},	//   rbuk, _macp, _مضام, _حلقه_,
   {{0x753b3afb,0x660202a7,0xb4c1277c,0x00000000}},	//   rruz, _egok, ्के_, --,
   {{0xe2860cd7,0x61e101d4,0x23cf04f1,0x7522022b}},	//   ални, əlli, _सुखद, _ewoz,
   {{0x753b08a9,0x25b600cd,0x6d5d3afc,0x644a02a1}},	//   pruz, اهید_, _opsa, _ecfi,
   {{0x6e263afd,0xcad600a1,0x3ea92501,0x6fdb09c3}},	//   _rekb, שורת_, dhat_, _मुबं,
   {{0x7c2700b6,0x7d063afe,0x00000000,0x00000000}},	//   _nejr, _ruks, --, --,
   {{0x7d063aff,0x6d5d05d5,0x8c240081,0xbcfb0146}},	//   _suks, _apsa, _পালন_, _fréz,
   {{0x44273b00,0xa3ea007d,0x3ea93b01,0x6d5d0b14}},	//   _hen_, _मरत_, ghat_, _bpsa,

   {{0xcbe20f71,0x44273b02,0x0c2616bd,0xec4a1e20}},	// [3000] _বলেছ, _ken_, иман, кзал_,
   {{0x4427000d,0xac833ae2,0x7d0609ac,0x25ad3b03}},	//   _jen_, огул, _vuks, izel_,
   {{0x442700a1,0x6e263b04,0x80a60260,0x9f4c007b}},	//   _men_, _tekb, _ممکن, ädä_,
   {{0x44272ba9,0x3ea93b05,0x7d063b06,0xad9b0032}},	//   _len_, chat_, _tuks, _igún,
   {{0x7c27052f,0x6d5d01e9,0x44273b07,0x7e640a4b}},	//   _fejr, _gpsa, _oen_, meip,
   {{0xb4c13b08,0xddcd020a,0x7ceb3b09,0x7e643b0a}},	//   ्को_, leaş, türe, leip,
   {{0x25ad3b0b,0x6d44020a,0xb4c100b6,0x00000000}},	//   ezel_, luia, ्कै_, --,
   {{0x83fc0ea3,0x3ea03b0c,0x442701ff,0xdc2e0092}},	//   jeđa, nkit_, _aen_, _yığm,
   {{0xe8fa13c7,0xc7b80218,0x74c6008f,0x6d44044c}},	//   _ала_, _međi_, ищож, nuia,
   {{0x44273b0d,0x7ae23b0e,0x3ea90103,0xed5700ca}},	//   _cen_, llot, zhat_, סביר_,
   {{0x44270856,0x63ad0d2a,0x7b1302a1,0x7ae20036}},	//   _den_, _ƙana, _għud, olot,
   {{0x44273b0f,0x96fa2ba0,0x6b810850,0x6d440350}},	//   _een_, _شعار_, _álge, kuia,
   {{0x44273b10,0xad9b0065,0x7ae20036,0x20d70037}},	//   _fen_, _agún, ilot, لتسج,
   {{0x44270c3e,0x7ae20415,0xbddb0139,0x3ea900d7}},	//   _gen_, hlot, _gbèy, what_,
   {{0x442c3b11,0xb5fd3b12,0x3ea93b13,0xdc2e04a8}},	//   mad_, meša, that_, _sığm,
   {{0x442703f3,0x93fb0130,0x7c273b14,0x442c0d18}},	//   _zen_, _בלוי, _sejr, lad_,
   {{0x442700bf,0x3ea93b15,0xad9b0af0,0xfd7400ae}},	// [3010] _yen_, rhat_, _egún, олтэ,
   {{0x442c0b6a,0x3ea93b16,0x3d1d0139,0x3ea007ac}},	//   nad_, shat_, _aáwò_, akit_,
   {{0x7c27052f,0x644800a6,0x3d1d0065,0x25ad3b17}},	//   _vejr, igdi, _báwò_, zzel_,
   {{0x442c3b18,0xdd910068,0x3ea03b19,0x7ae23b1a}},	//   had_, _فوج_, ckit_, glot,
   {{0x777a0a00,0x8d870fd5,0x6d4400ae,0x6d5d3b1b}},	//   _artx, _тунд, cuia, _upsa,
   {{0x442c05a7,0x6e2d0694,0xb5fd0ea3,0x81e90081}},	//   jad_, laab, ješa, _বলা_,
   {{0x442c3b1c,0x442738ff,0xb5fd0039,0xf773001c}},	//   dad_, _ren_, deša, تاش_,
   {{0x44273b1d,0x6e2d0283,0x25ad3b1e,0x442c03a8}},	//   _sen_, naab, tzel_, ead_,
   {{0xddc60b27,0x442c3b1f,0xcfe409c4,0x777a01ff}},	//   _kakš, fad_, _गर्भ_, _ertx,
   {{0x442c3b20,0x4427023b,0x3ea00634,0x3eb90063}},	//   gad_, _qen_, zkit_, _lmst_,
   {{0xe29a3b21,0x4dde033a,0xc62600c7,0x6e2d3b22}},	//   ган_, _कुनै_, _যারা_, kaab,
   {{0x44273b23,0x6e2d0188,0x7c3b03e3,0x64481183}},	//   _wen_, jaab, _ɓura, agdi,
   {{0x442c3b24,0x83fc077e,0x442700ca,0xc7b8007e}},	//   bad_, ređa, _ten_, _ređi_,
   {{0x442c3b25,0x7cf000aa,0xb5fd049c,0x395f0113}},	//   cad_, märg, ceša, _mpus_,
   {{0x628f00b3,0x8fa323b9,0x00000000,0x00000000}},	//   bjco, паре, --, --,
   {{0x539a040a,0x76493b26,0x42261278,0xb226159a}},	//   _תיקו, ngey, _удив, _умил,
   {{0x395f023e,0x3ea03b27,0x7e643b28,0x628400da}},	// [3020] _npus_, rkit_, reip, _inio,
   {{0x62963b29,0x3ea03b2a,0xbcfb0139,0x6d440b3b}},	//   _hoyo, skit_, _apéb, ruia,
   {{0x395f3b2b,0x2d8f052f,0x6e2d332c,0x62963b2c}},	//   _apus_, øger_, baab, _koyo,
   {{0x442c0542,0x6e2d008a,0x6b830212,0x62963b2d}},	//   zad_, caab, ånga, _joyo,
   {{0x442c3b2e,0x6d441fa4,0x629604f3,0x7cf000aa}},	//   yad_, quia, _moyo, järg,
   {{0x7ae216b4,0x28f83b2f,0x307a00c1,0x442c0188}},	//   slot, шель_, ראַנ, xad_,
   {{0x442c3b30,0x7ae23b31,0xfd640134,0xd6da249b}},	//   vad_, plot, yerị, лти_,
   {{0x442c3b32,0xe6660bd5,0x62963b33,0xfd4d00ac}},	//   wad_, стко, _noyo, _nchị,
   {{0x442c3b34,0xb5fd02ef,0xb21b0170,0x4ab900ae}},	//   tad_, teša, kjær, _туря_,
   {{0xfd4d0129,0x26dd0134,0x62843b35,0x3f7800c4}},	//   _achị, _ekwo_, _anio, _oču_,
   {{0x442c3b36,0x62960821,0xdbe6030b,0x6e2d399b}},	//   rad_, _boyo, _करोड_, yaab,
   {{0x442c3b37,0x6e2d008a,0x6569235f,0xb5fd0218}},	//   sad_, xaab, bweh, mešn,
   {{0xb5fd3b38,0x629603a9,0x39463b39,0x611402c6}},	//   peša, _doyo, nuos_, vělý,
   {{0x224d3b3a,0x6e2d2834,0x442c3b3b,0x3e750134}},	//   żek_, waab, qad_, _ụt_,
   {{0x6e2d3b3c,0xdbf1030b,0xe45700c1,0x6aa20381}},	//   taab, _přím, _ליגט_, kkof,
   {{0x6296006d,0x62840441,0x7cf003bd,0x00000000}},	//   _goyo, _gnio, härd, --,
   {{0x38ab038c,0x6e2d332c,0xd83802ef,0x998d0106}},	// [3030] _høre_, raab, _elči_, _odeš_,
   {{0x39462027,0x38ab01c5,0xa3cc00a5,0x6e2d332c}},	//   duos_, _køre_, _रखा_, saab,
   {{0x395f002d,0x62960010,0xb5fd0ea3,0xce95013d}},	//   _spus_, _yoyo, ješn, _данъ,
   {{0x38ab00d6,0xdb080103,0x6e2d0188,0x00000000}},	//   _møre_, álás, qaab, --,
   {{0xc7b803ce,0xddc602dd,0x2bd90251,0x39463b3d}},	//   _među_, _takš, _बुरा, guos_,
   {{0x7cf00149,0x61ed2822,0x88c8004d,0x58d40aca}},	//   gärd, _mzal, блів_, почт,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa23b3e,0x61ed3b3f,0x66f2016c,0x06093b40}},	//   ckof, _ozal, мпју, шник_,
   {{0x1a6800d0,0x76490694,0x5fdb2ebd,0xf99300e3}},	//   _دینی_, rgey, _मुसल, _عبر_,
   {{0x65693b41,0x62963b42,0xb5fd007e,0xd8380141}},	//   rweh, _soyo, bešn, _gdč_,
   {{0x61ed3b43,0x97a73b44,0x62663407,0x6569042c}},	//   _azal, _урал, овна, sweh,
   {{0x38ab02b6,0x26dd05bd,0x00000000,0x00000000}},	//   _døre_, _ukwo_, --, --,
   {{0x7cf00f3a,0x629617f9,0x6abb06b0,0x00000000}},	//   läre, _voyo, _mmuf, --,
   {{0x2ee204f8,0x03a5186d,0x628400a5,0x38ab0400}},	//   पत्त, _мило, _wnio, _føre_,
   {{0x38ab0021,0x7cf00704,0x61ed3b45,0x2bd908d4}},	//   _gøre_, näre, _ezal, _बुला,
   {{0xb5fd3b46,0x62843b47,0x6f1c02ef,0x00000000}},	//   nešo, _unio, rprc, --,
   {{0x85f600c1,0xe1ff0610,0x7cf002db,0x00000000}},	// [3040] ַמעס_, león_, häre, --,
   {{0x6aa90032,0x61e4026a,0x6abb16da,0x7cf03b48}},	//   _alef, _iyil, _amuf, käre,
   {{0xbcfb04ea,0x7cf03b49,0x8b6a0084,0x643a00c1}},	//   _spéc, värd, риев_, שעענ,
   {{0x6aa93b4a,0xb5fd0087,0x61e4010a,0x39463b4b}},	//   _clef, ješo, _kyil, tuos_,
   {{0xe8fa090f,0x7ceb013c,0x00000000,0x00000000}},	//   алд_, süra, --, --,
   {{0x98a30e38,0x7cf00149,0x2d54007a,0x2a660da7}},	//   миче, färe, mäe_, seob_,
   {{0xf09307a6,0xfaa60138,0xb86500e3,0x59a8030b}},	//   ונג_, _даво, ثانو, कनहर,
   {{0x60dc005a,0x96343b4c,0xb5fd3b4d,0x38ab00f2}},	//   horm, чниц, rešn, _røre_,
   {{0x61e40f03,0x6d560d5f,0x60dc0103,0x394600fc}},	//   _nyil, ntya, korm, quos_,
   {{0xb5fd12bf,0x59c006ed,0x81e90081,0x5fbc0dba}},	//   pešn, _शेयर, _বলল_, ोपाल,
   {{0x61ed1feb,0x60dc3b4e,0x61e40415,0x00000000}},	//   _szal, dorm, _ayil, --,
   {{0x2bbd099d,0xddcd00ae,0x61e40027,0x00000000}},	//   ्पता, ndaţ, _byil, --,
   {{0x672d0106,0x61e405bd,0x00000000,0x00000000}},	//   ćaje, _cyil, --, --,
   {{0x60dc03e3,0x6ab7052c,0x61ed0146,0xd8380383}},	//   gorm, _आग्र, _vzal, _elčv_,
   {{0x09b706e4,0xb4e6009d,0x78800220,0x61e405ea}},	//   _अध्य, पती_, _závä, _eyil,
   {{0x9d153b4f,0x645a04c8,0x00000000,0x00000000}},	//   здач, lfti, --, --,
   {{0x61ed3b50,0x6d560270,0x5fdb014e,0x61e40103}},	// [3050] _uzal, gtya, _मुरल, _gyil,
   {{0x645a3b51,0x63770139,0x6aa93b52,0xb5fd02c6}},	//   nfti, _ẹnu, _slef, dešl,
   {{0xd7df009d,0x7cf0042c,0x6d560172,0x00000000}},	//   _पुढच, färb, atya, --,
   {{0x9fbf0094,0x00000000,0x00000000,0x00000000}},	//   nčím_, --, --, --,
   {{0xa92400d6,0x0dc80396,0x67280078,0x6aa90052}},	//   дділ, _дури_, _awdj, _vlef,
   {{0x279517e3,0x645a01c0,0x7cf03b53,0x21293b54}},	//   зшир, jfti, täre, _mwah_,
   {{0x65623b55,0x248900de,0x386701df,0x320901ee}},	//   _apoh, _đam_, renr_, _ogay_,
   {{0x32090028,0x6abb2767,0x9fbf0031,0x645a3b56}},	//   _ngay_, _umuf, jčím_, efti,
   {{0x60dc026a,0x645a00f0,0xb5fd0094,0x7cf03b57}},	//   yorm, ffti, rešo, säre,
   {{0x3209019c,0x00000000,0x00000000,0x00000000}},	//   _agay_, --, --, --,
   {{0x60dc1895,0x61e40332,0x3a2d00a1,0x290521d2}},	//   vorm, _syil, _keep_, _iila_,
   {{0x216a008f,0x29053b58,0x60dc211d,0x45dc0134}},	//   бими_, _hila_, worm, ịpụ_,
   {{0x29051ee3,0xb7bc0029,0x00000000,0x00000000}},	//   _kila_, _reģi, --, --,
   {{0x320900f9,0x2d5400aa,0x29052cef,0x657b0169}},	//   _egay_, väe_, _jila_, mvuh,
   {{0x29053b59,0xd00f1d28,0x212900d1,0xa3b80096}},	//   _mila_, الف_, _ewah_, _घेऊ_,
   {{0x60dc2f7d,0x539a00ca,0xf772006e,0xafe30e2d}},	//   sorm, _ליצו, עקן_, хосл,
   {{0x60dc1d11,0xa11300e3,0xdb0d0031,0x290d0154}},	// [3060] porm, _كويت, ľkým, _nuea_,
   {{0x290534e1,0xb17b0341,0xf8a509b4,0x6d563b5a}},	//   _nila_, _פטיר, _شک_, rtya,
   {{0x309b00a1,0x6d563086,0xda0a0037,0xeaaf0103}},	//   _השימ, stya, مياه_, گٹن_,
   {{0x29053b5b,0xf1e10378,0x3a2d02a1,0x7ceb2814}},	//   _aila_, _गुड़_, _ceep_, büro,
   {{0xbefa000f,0x6e240517,0x3a2d3b5c,0xceb3006e}},	//   ्दीन_, mbib, _deep_, _ניש_,
   {{0x290501e5,0x6e24004d,0x7ceb020e,0xa3cc00aa}},	//   _cila_, lbib, nürl, _रखल_,
   {{0x36d43b5d,0x38cb110a,0x29053b5e,0x56941eac}},	//   мокр, حانی_, _dila_, дайт,
   {{0x6e24010a,0x6d440f18,0x7c2e0d18,0x7ceb04a8}},	//   nbib, oria, _hebr, hürl,
   {{0x290501ce,0xd9432549,0x9c83033b,0x7c2e1a3a}},	//   _fila_, _пети, ščet, _kebr,
   {{0x2905005a,0x6d443b5f,0x3a2d029a,0x691c026a}},	//   _gila_, iria, _zeep_, rçeğ,
   {{0x6d443b60,0x7ceb026a,0x645a3b61,0x995601d3}},	//   hria, dürl, rfti, kļūt_,
   {{0x290523a7,0xa3bd0034,0x6d443b62,0x00000000}},	//   _zila_, _इधर_, kria, --,
   {{0x867b00a1,0xc50a00e3,0x6d442cf8,0x51870291}},	//   _לראו, _اتصل_, jria, чуна,
   {{0x6d443b63,0x200c2d5a,0x7ceb026a,0xbcfb0328}},	//   dria, ždin_, gürl, _apén,
   {{0x712709b4,0x443c0451,0x442e0090,0x6d443b64}},	//   _کربل, _idv_, _ief_, eria,
   {{0xdce400e9,0x442e0102,0x6e240256,0x2129010a}},	//   dviđ, _hef_, gbib, _twah_,
   {{0x7c2e3b65,0x1df8055b,0x6d443b66,0x5c991402}},	// [3070] _bebr, зеты_, gria, окая_,
   {{0xd01103ef,0x7c2e3b67,0x442e3b68,0x7eaa0146}},	//   _جلد_, _cebr, _jef_, _výpa,
   {{0xdced084f,0x7c2e3b69,0x6e24083e,0x29050113}},	//   hvać, _debr, bbib, _rila_,
   {{0x29053b6a,0x442e3b6b,0x3f5700a7,0x00000000}},	//   _sila_, _lef_, mçu_, --,
   {{0x29051098,0x6d44016d,0x63ad01c2,0x3f5700a7}},	//   _pila_, cria, _ƙank, lçu_,
   {{0x7c2e3b6c,0x26f72a06,0x442e3b6d,0x2ee93b6e}},	//   _gebr, ुद्र_, _nef_, llaf_,
   {{0xb8f50d39,0x3f573b6f,0x67020134,0x6b8302b6}},	//   _हद_, nçu_, _ọkaa, ængd,
   {{0x443c19a7,0x7c2e3b70,0x7c250037,0xaa580831}},	//   _adv_, _zebr, lbhr, _нису_,
   {{0x29053b71,0x442e3b72,0xa91d00cc,0x7cf0173a}},	//   _tila_, _bef_, _brže, lära,
   {{0x6e2409ac,0x443c0381,0xb5fd2174,0x2ee90364}},	//   zbib, _cdv_, lešk, hlaf_,
   {{0x62030253,0x443c02dd,0x765b0193,0x3246004b}},	//   ətlə, _ddv_, pfuy, менг,
   {{0x7d070ab2,0x7c250a6c,0x7ceb0491,0x6d443b73}},	//   _lijs, hbhr, dürm, yria,
   {{0x7ceb36be,0x27e001e8,0x6f0601c2,0x443c3b74}},	//   türl, ğine_, _rikc, _fdv_,
   {{0x1dd8000f,0x7d070381,0x27e02cda,0x442e3b75}},	//   _भुगत, _nijs, şine_, _gef_,
   {{0x7c2e3b76,0xdee608b4,0x9103016c,0xd007002d}},	//   _rebr, дови, тпре, дере_,
   {{0xb5fd0dd9,0x7d0f2730,0x26cd0072,0x442e3b77}},	//   ješk, _bucs, nneo_, _zef_,
   {{0x7c2e3b78,0xed5700c9,0x7d070126,0xd00f0018}},	// [3080] _pebr, мот_, _bijs, الہ_,
   {{0x6f06225c,0x6d443b79,0x10a6002d,0x6e243b7a}},	//   _wikc, rria, _цион, sbib,
   {{0xddcd3b7b,0xbddb03a9,0x7d073b7c,0x7cf00212}},	//   rdaš, _adèd, _dijs, gära,
   {{0x7d0f3b7d,0x6d443b7e,0x20180036,0x7c251ac3}},	//   _fucs, pria, lcri_, abhr,
   {{0x26cd0307,0x7c2e3b7f,0x2d8f02c3,0xd83805db}},	//   dneo_, _tebr, äget_, _loče_,
   {{0xfbd907e2,0xab2a013d,0x7d070629,0x442505db}},	//   _बुकम, _мога_, _gijs, jbl_,
   {{0xfc030012,0x443c00fd,0xd838033b,0xb5fd0117}},	//   _апро, _rdv_, _noče_, bešk,
   {{0x442e3b80,0x6b8301c5,0x20070031,0x26cd0036}},	//   _sef_, ænge, _únie_, gneo_,
   {{0x443c084f,0xa91d0106,0x672d077e,0xae0102d5}},	//   _pdv_, _prže, ćaja, लेपन_,
   {{0x442e3b81,0x75243b82,0x83fc0995,0xdced00c4}},	//   _qef_, _çizm, leđi, rvać,
   {{0x7eb100d6,0x442e3b83,0xf7720037,0xa91d3b84}},	//   _håpe, _vef_, _جاء_, _vrže,
   {{0xe5c63b85,0x38ab01df,0xa50a193d,0x36360504}},	//   _осло, _jørn_, _деда_, _آراس,
   {{0xa30800fb,0x26c43b86,0xa91d033b,0xbefa030b}},	//   _کرتے_, mimo_, _trže, ्दैन_,
   {{0x39461379,0xd8381d95,0x7ceb3b87,0x25b0008b}},	//   iros_, _foče_, türm, ıllı_,
   {{0x7d070126,0x4fc43b88,0x2d823b89,0x00000000}},	//   _rijs, вста, _arke_, --,
   {{0x26c43b8a,0x2d8200e7,0x3f573b8b,0x39463b8c}},	//   nimo_, _brke_, rçu_, kros_,
   {{0x2fdf00a5,0xb5fd0087,0x2d582c37,0x7d070216}},	// [3090] ług_, vešk, мить_, _pijs,
   {{0x3f81025b,0x26c42a78,0x26cd3b8d,0x00000000}},	//   _trhu_, himo_, zneo_, --,
   {{0x38ab0021,0x26c4013f,0x39463b8e,0x92c30081}},	//   _børn_, kimo_, eros_, ্তী_,
   {{0x26c401b3,0x2d8200cc,0x7d0701c0,0xdd9510e0}},	//   jimo_, _frke_, _wijs, _замы,
   {{0x39463b8f,0xe1ff0018,0x2d82015c,0xb5fd0234}},	//   gros_, deók_, _grke_, rešk,
   {{0x7cf03b90,0x99d400cd,0x7b6707e3,0xa3c02397}},	//   pära, ختما, _отбе, ूपा_,
   {{0xc87803e0,0x5b1405b8,0x83fc0095,0x6d4d28b4}},	//   _dağ_, _амст, beđi, luaa,
   {{0x394611ce,0x3ea93b91,0x26c40138,0xb5fd3b92}},	//   bros_, nkat_, gimo_, leši,
   {{0x26cd3b93,0x3a3f02e7,0x2f150572,0xf50523f9}},	//   rneo_, _idup_, _låg_, нзио,
   {{0xb5fd05d5,0x03250097,0x26cd0307,0x3a3f005c}},	//   neši, ндон, sneo_, _hdup_,
   {{0x26c43b94,0x3ea93b95,0xc2c600e3,0x7cf00212}},	//   bimo_, kkat_, فيدي, kärn,
   {{0x7cf00222,0x614629db,0x6d4d3b96,0xc5d5097a}},	//   järn, нема, kuaa, _піль,
   {{0x7e6d00ae,0xc878008b,0xb5fd3b97,0xa3de02c6}},	//   deap, _yağ_, keši, _měří_,
   {{0xb5fd0ea3,0x0ef82fbd,0x6d4d3b98,0xd83805db}},	//   ješi, ंग्स_, duaa, _toče_,
   {{0xb4bd02e8,0x7ea30006,0x645c05fe,0xb4cb009d}},	//   ीची_, _lõpu, òrie, रची_,
   {{0x3ea93b99,0x7eaa025b,0x291f0134,0x2018078e}},	//   gkat_, _výpo, _otua_, scri_,
   {{0xac860fd5,0x291f022e,0xf1bf0143,0x00000000}},	// [30a0] нгал, _ntua_, lbán_, --,
   {{0x26c4063d,0x3946016c,0x21200090,0x201a0231}},	//   zimo_, vros_, _itih_, _ufpi_,
   {{0x291f3b9a,0x2d8f1683,0x23670063,0x205700ca}},	//   _atua_, äger_, _jpnj_, _אייל_,
   {{0x3946132d,0x26c40b0b,0xc87807aa,0x3ea93b9b}},	//   tros_, ximo_, _sağ_, ckat_,
   {{0x26c43b9c,0x83fc04a3,0xf5390181,0xada3004b}},	//   vimo_, ređi, jsť_, _баял,
   {{0x39460cb6,0x672d175b,0x200705fe,0x7eb1004d}},	//   rros_, ćajn, _únic_, _våpe,
   {{0xcb673b9d,0x2d803b9e,0xf5390031,0x7d090036}},	//   _паре_, lvie_, esť_, _èesa,
   {{0x6e363b9f,0x2d800036,0x224001dc,0x2b4700d2}},	//   nayb, ovie_, _ndik_, ánce_,
   {{0x26c43ba0,0x7ae231e8,0x2d802f8a,0xceb300ca}},	//   rimo_, moot, nvie_, טיה_,
   {{0x22400d2c,0x7ae23ba1,0xd5e20174,0xed5700ca}},	//   _adik_, loot, _anọ, עביר_,
   {{0x26c416dc,0xd6cf01b6,0x1cb700ca,0x3ea93ba2}},	//   pimo_, _бт_, גליל_, ykat_,
   {{0x7ae23ba3,0x7ceb020e,0x3ea901c8,0x00000000}},	//   noot, türk, xkat_, --,
   {{0x64a63ba4,0x24582a6a,0x2f150572,0x7eaa0146}},	//   _пада, _жаль_, _såg_, _výpl,
   {{0x2ed90569,0x2bd91fe6,0x92c30081,0x0cc40033}},	//   भक्त, _बुझा, ্তে_, ্তুত,
   {{0x7e6d00d3,0x7ae23ba5,0x30a4008f,0x3ea93ba6}},	//   teap, koot, уряв, tkat_,
   {{0x6d4d0673,0x2f15298b,0x00000000,0x00000000}},	//   tuaa, _våg_, --, --,
   {{0x628d0010,0xdce400a5,0xb5fd3ba7,0xfd130192}},	// [30b0] _inao, zwią, teši, اجر_,
   {{0x3ea93ba8,0x2f150212,0x6d4d0381,0x7e6d3ba9}},	//   skat_, _tåg_, ruaa, seap,
   {{0x6e363baa,0xb5fd0aa0,0x6d4d0329,0xceb400a7}},	//   bayb, reši, suaa, bhə_,
   {{0x3ea90052,0x9f960796,0x60c701cb,0x629f009e}},	//   qkat_, _סדרה_, lijm, _joqo,
   {{0x628d3bab,0x6d4d01cb,0xa3de02c6,0x2d80009c}},	//   _mnao, quaa, _věří_, cvie_,
   {{0xf7710391,0xf7451d54,0x68420131,0xa25b0231}},	//   لاب_, веко, анша, diôm,
   {{0x6a151553,0xd7fb00ae,0x00000000,0x00000000}},	//   _амбу, чуд_, --, --,
   {{0x629f0694,0x7ae23bac,0x7cf00324,0x0cc40033}},	//   _noqo, coot, härl, ্তৃত,
   {{0x7cf007ee,0x70030174,0x00000000,0x00000000}},	//   kärl, ọchu, --, --,
   {{0xb4bd2b71,0x628d3bad,0x27e000ae,0xb4cb0096}},	//   ीचे_, _anao, şina_, रचे_,
   {{0x629f0694,0x21200542,0x68e33bae,0x394f1f53}},	//   _boqo, _stih_, mond, lugs_,
   {{0x68e30863,0x83fc0fa3,0x9f5e0206,0x00000000}},	//   lond, jeđu, ätí_, --,
   {{0x645c05fe,0x6a3a00ca,0x629f0188,0x7cf002c3}},	//   òric, וגרפ, _doqo, färl,
   {{0x64a23baf,0x68e33bb0,0x7cf00324,0x628d00ee}},	//   _ваша, nond, gärl, _enao,
   {{0xafe608d1,0x20cd02ef,0x7ae23634,0x7e561b7a}},	//   товл, džid_, yoot, ктац,
   {{0x661b1160,0x68e33bb1,0xfe43160b,0x7ae20188}},	//   ncuk, hond, инсо, xoot,
   {{0xec7a0f32,0x753b3bb2,0x21200063,0xada3004b}},	// [30c0] мпа_, nsuz, _utih_, аатл,
   {{0x31370054,0xa3d517ff,0x2d803bb3,0x68e33bb4}},	//   _שנים_, _सखा_, rvie_, jond,
   {{0x7ae23bb5,0x83fc0d62,0xfe46007b,0xda7a00e5}},	//   toot, beđu, _инно, дял_,
   {{0x0a67016c,0x20070206,0xbb430ed4,0x4420044c}},	//   врши_, _únia_, рецк, _și_,
   {{0x90cb01e9,0x7ae23bb6,0x38653bb7,0x00000000}},	//   _vvрv, root, _bblr_, --,
   {{0x68e33bb8,0x91bb00a1,0x48d00081,0x7524026a}},	//   gond, ומני, িত্র, _çizi,
   {{0xb8ea099d,0x2a7d023e,0x7ae22eec,0x98a30291}},	//   _लग_, bdwb_, poot, рије,
   {{0x38b03bb9,0x7d1b0042,0xfaa33bba,0xcb67002d}},	//   _dàra_, _éusc, _касо, _шасе_,
   {{0xa91d3bbb,0x44200d2a,0x628d009c,0xfaa33bbc}},	//   _trža, _ƙi_, _rnao, _тато,
   {{0x68e30e04,0xd8383bbd,0x7cf00212,0x629f063d}},	//   cond, _foča_, kärm, _soqo,
   {{0x7cf00149,0x62350805,0x92590152,0xbcfb3bbe}},	//   värl, лену, нант_, _spék,
   {{0xa91d02e6,0x02a73051,0xf8d2023a,0x66e3004d}},	//   _mržn, тром, _तदुप, _коха,
   {{0x61f600a5,0x290c0d2a,0xc6490037,0xc05b004d}},	//   _czyl, _kida_, _أجمل_, мів_,
   {{0x290c06a3,0x75220dd5,0x63ad01c2,0x629f3bbf}},	//   _jida_, _itoz, _ƙant, _woqo,
   {{0x290c3bc0,0xb4de007d,0xcfa4002d,0x403400c2}},	//   _mida_, थकी_, ашти, ресс,
   {{0x68e33bc1,0x628d068d,0x32551121,0x6b81037a}},	//   zond, _unao, _свир, _álgi,
   {{0x83fc005f,0x68e33bc2,0x00000000,0x00000000}},	// [30d0] ređu, yond, --, --,
   {{0x6adb20cd,0xb5fd0291,0x61ed3bc3,0x5f950221}},	//   यक्र, mešt, _iyal, _биот,
   {{0x68e30ab2,0xddc4013f,0x6aa0039f,0x7642008c}},	//   vond, reiš, _bomf, _odoy,
   {{0x68e301a2,0x7b64362f,0x6e950582,0x61ed3bc4}},	//   wond, ртфе, _симу, _kyal,
   {{0x68e33bc5,0x290c3bc6,0xb5fd1056,0x75220294}},	//   tond, _bida_, nešt, _ntoz,
   {{0x290c0188,0x61ed3bc7,0x6d5d00bd,0x394f066a}},	//   _cida_, _myal, _iqsa, rugs_,
   {{0xf0940105,0x290c3bc8,0xdce400a5,0x57a40291}},	//   ינס_, _dida_, jwię, ишћа,
   {{0x68e33bc9,0x7cf00fc4,0xf77000cd,0xe57919d4}},	//   sond, järj, تاه_, ези_,
   {{0x68e304ea,0xb5fd0292,0x61ed3bca,0x7e7d3bcb}},	//   pond, ješt, _nyal, _masp,
   {{0x290c27e8,0x68e3067d,0x38ab01df,0x2d8409ac}},	//   _gida_, qond, _mørk_, _šmek_,
   {{0x7afb0a55,0x61ed3bcc,0x75220134,0x7e7d00ae}},	//   _khut, _ayal, _etoz, _oasp,
   {{0x7e7d3bcd,0xe29a2529,0x290c08c5,0x61ed0517}},	//   _nasp, хам_, _zida_, _byal,
   {{0x78a13bce,0xfdbe0033,0x20cd0b14,0x63ad03e3}},	//   _kolv, _আড্ড, džib_, _ƙans,
   {{0xdddd00a5,0x438500e3,0x61ed02f1,0x7eaa00d8}},	//   _obsł, _ملتق, _dyal, _týpk,
   {{0x7ae93bcf,0x61ed3bd0,0x2b180ccb,0x7afb13e1}},	//   _oket, _eyal, _बंधु_, _ohut,
   {{0x7e7d3bd1,0x7ea3007a,0x7ae90174,0x00000000}},	//   _casp, _sõpr, _nket, --,
   {{0x61ed18cb,0x0d8600c6,0x7e7d3bd2,0x7c353bd3}},	// [30e0] _gyal, ылан, _dasp, _bezr,
   {{0x7cf03bd4,0xddc60618,0xa91d0d62,0x7e7d0037}},	//   märk, _takž, _pržn, _easp,
   {{0x7afb3bd5,0x290c3bd6,0x5f761f11,0xa91d00c4}},	//   _bhut, _rida_, _صادر, _bržo,
   {{0xe9da31f6,0x290c3bd7,0x7afb3bd8,0xbae502ec}},	//   нке_, _sida_, _chut, ацій,
   {{0x290c00e1,0x5a33004d,0x7afb3bd9,0x64433bda}},	//   _pida_, сніт, _dhut, _odni,
   {{0xa91d011d,0x7ae93bdb,0x7d1b0131,0x7afb01ff}},	//   _tržn, _eket, _éusa, _ehut,
   {{0x69dc00a5,0x65790063,0x7d0e0188,0x3b0d0090}},	//   _śred, _aswh, _iibs, _fieq_,
   {{0xd6d71402,0x7afb152f,0xd7c30096,0x00000000}},	//   лты_, _ghut, _वेळच, --,
   {{0xbcfb00e3,0x45d40a28,0x290c00f3,0x7bd9020a}},	//   _spéi, ропс, _tida_, ăbuţ,
   {{0xb5fd0291,0x63a8038c,0x7ea3007a,0x78a13bdc}},	//   vešt, tydn, _lõpp, _golv,
   {{0x61ed005c,0x7d0e0154,0x00000000,0x00000000}},	//   _syal, _mibs, --, --,
   {{0x7d0e009e,0x63a813cd,0x644305db,0xd8380141}},	//   _libs, rydn, _edni, _kočo_,
   {{0xf486013f,0x61ed010a,0x7d0e01b9,0x75222ae7}},	//   _буйн, _qyal, _oibs, _utoz,
   {{0x26c6006c,0xaca30174,0xb5fd362c,0x7e7d01d3}},	//   _hmoo_, _kwụb, rešt, _sasp,
   {{0xa3cb0034,0x3ea2029a,0x387e07c4,0x80b61c05}},	//   _रेप_, _bokt_, _matr_, _उतरे,
   {{0x4ea43bdd,0x7d0e009c,0x9f5e0206,0x00000000}},	//   бруа, _aibs, ätá_, --,
   {{0x7e7d1711,0x26c60134,0xdd9400c2,0x61ed019f}},	// [30f0] _vasp, _mmoo_, баты, _uyal,
   {{0x7e7d3bde,0x80d30081,0x27e000b6,0x7d0e03a8}},	//   _wasp, _দীর্, řiny_, _cibs,
   {{0x7afb01b5,0x672d0e94,0x3ea20381,0x78a13a10}},	//   _phut, ćajk, _fokt_, _rolv,
   {{0x78a13bdf,0x8f9a00f5,0xa3c300b6,0x2f0b0032}},	//   _solv, _סירי, náší_, _dògì_,
   {{0x6e2d3be0,0x78a13be1,0xaca30174,0x7bdc0063}},	//   mbab, _polv, _awụb, _exru,
   {{0x07a50465,0x6e2d3be2,0x6b830149,0x64de009d}},	//   иалн, lbab, ångs, नकोश,
   {{0x78a13be3,0x7afb3be4,0x6d4d05c2,0x6447034f}},	//   _volv, _thut, lraa, ójim,
   {{0xd83800e7,0x75451a0c,0x6f0f02a1,0x7afb3be5}},	//   _fočo_, аниз, _jicc, _uhut,
   {{0x6d4d3be6,0x6f0f26ae,0x69db01ff,0x78a13be7}},	//   nraa, _micc, _uxue, _tolv,
   {{0x7eaa025b,0x99d40e5a,0x2a7f022e,0x336503a0}},	//   _výpi, _اتفا, _haub_, авог,
   {{0xf79903ef,0x2a7f01fa,0x6d4d3be8,0x00000000}},	//   _جناب_, _kaub_, hraa, --,
   {{0x6f0f3be9,0x6d4d3bea,0x7cf03224,0x8b0800b6}},	//   _nicc, kraa, tärk, mořá,
   {{0x2a7f01fa,0x7ceb0555,0x6e2d2c06,0x00000000}},	//   _maub_, nürs, dbab, --,
   {{0x6d4d3beb,0x2a7f022e,0x75290bfe,0x442c01ec}},	//   draa, _laub_, mpez, cbd_,
   {{0x6f0f3bec,0x6d4d008a,0x2d8f25e5,0x7cf023ce}},	//   _bicc, eraa, ågen_, särk,
   {{0xddc60067,0x6e2d0256,0x6f0f3bed,0x798903e3}},	//   _takż, gbab, _cicc, _orew,
   {{0x6f0f3bee,0x6d4d3bef,0x395f022e,0x23bb0065}},	// [3100] _dicc, graa, _nqus_, _fájé_,
   {{0x8c460467,0x6e2d0172,0x7eb100f3,0x00000000}},	//   реже, abab, _håpl, --,
   {{0x79891114,0x6f0f3bf0,0x6e2d3bf1,0x6d4d008c}},	//   _arew, _ficc, bbab, araa,
   {{0x2a7f01fa,0x6d4d3bf2,0x8b23004d,0x1dc72166}},	//   _caub_, braa, ідче, _रेवत,
   {{0x39403bf3,0x6f043bf4,0x79893bf5,0x2a7f0124}},	//   éis_, mmic, _crew, _daub_,
   {{0x6f0401f7,0x798900a5,0x7cf000c2,0xd5420139}},	//   lmic, _drew, käri, _lẹ́g,
   {{0xd6da3bf6,0xbb433bf7,0xd90d0688,0x798902ac}},	//   кти_, _мерк, ریم_, _erew,
   {{0xb4de0179,0x6f0401f7,0x2f1c0018,0x3869042d}},	//   थक्_, nmic, _míg_, đara_,
   {{0xbddb03a9,0x7989030a,0xd83805db,0x6f043bf8}},	//   _ndèl, _grew, _hočm_, imic,
   {{0x2a7f0197,0xd4061612,0xf8aa1c05,0x1beb00aa}},	//   _zaub_, ияни, _कविय, _जुडल_,
   {{0x6f0402e6,0xdddd00d9,0x7eb80161,0x6e2d36db}},	//   kmic, _pasū, _zípe, ybab,
   {{0xf2c73bf9,0x20cd013f,0x6f040542,0x2a7f023e}},	//   рсон, džia_, jmic, _xaub_,
   {{0x6f0403d6,0x6f0f013d,0x442c0167,0x6d4d026d}},	//   dmic, _ricc, pbd_, xraa,
   {{0x6d4d043e,0x3d1a0ed3,0x6f0f00e5,0xd838022b}},	//   vraa, _बढ़े_, _sicc, _alčz_,
   {{0x6f0f0465,0xd8381386,0x04040081,0x13a9001c}},	//   _picc, _meč_, _শ্রী_, _منوی_,
   {{0x5eb423a3,0x6d4d3bfa,0xd8382a22,0x6f040a39}},	//   ойст, traa, _leč_, gmic,
   {{0x2a7f3bfb,0x6e2d08d3,0x6f0f3bfc,0x672d0995}},	// [3110] _raub_, rbab, _vicc, ćaji,
   {{0x6d4d3bfd,0x2a7f006c,0xfbab00ae,0xa3cb1f88}},	//   rraa, _saub_, ктей_, _रेड_,
   {{0x2a7f0d7d,0x6d4d2d6d,0x200701b9,0x6f0f183b}},	//   _paub_, sraa, _àni_, _ticc,
   {{0x6e9518a9,0x6d4d01a2,0x38b90257,0x2a7f022e}},	//   _الحا, praa, _mère_, _qaub_,
   {{0xdced08a9,0xd8380335,0x6d4d0188,0xf1bf1de1}},	//   svađ, _beč_, qraa, nzá_,
   {{0x7ceb03e0,0x2d8b007e,0x00000000,0x00000000}},	//   rürs, _irce_, --, --,
   {{0x2a7f0197,0x79893bfe,0x00000000,0x00000000}},	//   _taub_, _wrew, --, --,
   {{0x7cf013ce,0x24890555,0x79893bff,0x00000000}},	//   väri, _şam_, _trew, --,
   {{0x798902a1,0x00000000,0x00000000,0x00000000}},	//   _urew, --, --, --,
   {{0x8b0800b6,0x67d51689,0x7cf03c00,0x9848002d}},	//   pořá, _лозу, täri, _вяца_,
   {{0x130a00c2,0x75293c01,0x74070033,0x00000000}},	//   лной_, spez, োর্ট_, --,
   {{0xfbd200a1,0x75293ab5,0x00000000,0x00000000}},	//   לתי_, ppez, --, --,
   {{0xd46907ed,0xf8db0034,0xd5e20065,0x7cf002c3}},	//   _биле_, _बदाय, _gbò, märv,
   {{0x7cf02a3c,0xd7f100fe,0x00000000,0x00000000}},	//   päri, _kỹ_, --, --,
   {{0xf412004f,0x2d8b3c02,0x38b9020d,0xa91d05db}},	//   _צפה_, _arce_, _gère_, _bržk,
   {{0x93243a1d,0x2d8b05db,0xd7f100fe,0xe3b03c03}},	//   _برون, _brce_, _mỹ_, _تره_,
   {{0xbea311a1,0xa3cb0251,0xdce600d9,0xddea001c}},	// [3120] чатк, _रेत_, _apkā, ارزه_,
   {{0xc5f20341,0x7cf002c3,0xed573c04,0x00000000}},	//   לדן_, härv, соф_, --,
   {{0x7f860080,0xd83829f9,0x9f5e00c2,0xdee61a9f}},	//   _الجن, _reč_, ätä_, _гони,
   {{0x93bc002d,0xba160081,0x7cf0032c,0xd83800d4}},	//   mbăt, ার্ড_, järv, _seč_,
   {{0x2fd70260,0xd838033b,0xa3a90096,0x00000000}},	//   _نوید_, _peč_, _गॅस_, --,
   {{0x3ea7002d,0xd7fa016a,0x52a50455,0x48e3013d}},	//   _într_, луй_, _ऑक्स, почв,
   {{0xd8382782,0xf1bf0068,0x6d563c05,0x7c3e3c06}},	//   _več_, zzá_, luya, mapr,
   {{0xc6f80284,0x7c3e3c07,0x00000000,0x00000000}},	//   јних_, lapr, --, --,
   {{0x948600d3,0xe8fa0582,0x20cd007e,0xe9da1469}},	//   бынд, _бла_, džin_, _ска_,
   {{0x38b93c08,0xb866110a,0x44383c09,0xb5fd0206}},	//   _père_, _دارو, úr_, rešp,
   {{0xaca40294,0xd251212c,0x6d563c0a,0x2cb83c0b}},	//   _adịr, وند_, huya, _mlrd_,
   {{0x6d563c0c,0x7c3e3c0d,0xddcd00d3,0x3f8501cd}},	//   kuya, hapr, neaţ, ælum_,
   {{0x9c830b27,0x7cf001bf,0x7c3e3c0e,0x00000000}},	//   ščit, läru, kapr, --,
   {{0xc0c83c0f,0x9a290023,0x6d560270,0x661d0031}},	//   бусе_, _mươi_, duya, ľske,
   {{0x443e3c10,0xaab80d0b,0xbcfb025a,0xb4d40096}},	//   mat_, _आतंक, _opér, सची_,
   {{0xd25100fb,0x38ab038c,0x3ea0023b,0xff07084c}},	//   _کچھ_, _hørt_, gjit_, сягн,
   {{0x38ab052f,0xdd9401b6,0x22493c11,0x9c393c12}},	// [3130] _kørt_, паты, _idak_, ипат_,
   {{0x645a24b8,0xbcfb3c13,0xd9990103,0x00000000}},	//   ngti, _apér, ینات_, --,
   {{0x443e00d3,0xbcfb01dc,0xea193c14,0x00000000}},	//   iat_, _spés, ажеш_, --,
   {{0x443e3c15,0x6d563c16,0x2d8b015c,0xa91d00c4}},	//   hat_, buya, _trce_, _hrži,
   {{0x443e3c17,0x7c3e019f,0x99673c18,0x5d330018}},	//   kat_, bapr, стел, _رہائ,
   {{0x443e3c19,0x02c6009d,0xac183c1a,0x22040113}},	//   jat_, _लग्न, _гору_, lèhé_,
   {{0x443e3c1b,0xf5220294,0x3eb9003e,0x6fcf0714}},	//   dat_, _rịọr, _klst_, _हेमं,
   {{0x22493c1c,0x645a3c1d,0xbddb03a9,0xa525016d}},	//   _ndak_, egti, _ndèk, омид,
   {{0x99d40080,0x21293653,0x93bc044c,0x00000000}},	//   _فتكا, _ntah_, zbăt, --,
   {{0x443e3c1e,0xe4c502ec,0x20cd013f,0x00000000}},	//   gat_, ійни, džio_, --,
   {{0x7cf000c2,0x22490063,0x03a53c1f,0x3eb92c18}},	//   märt, _bdak_, цино, _olst_,
   {{0xae090775,0x7c3e3c20,0x91a00294,0x22493c21}},	//   वधान_, zapr, _ndị_, _cdak_,
   {{0x443e06e1,0xe5a529db,0x672d08a9,0x7c3e00f9}},	//   bat_, _фили, ćaju, yapr,
   {{0x443e3c22,0xbf020be4,0x6ab5009f,0xd83805db}},	//   cat_, लग्न_, ंसुर, _ročk_,
   {{0xa91d0f72,0x3f8c0146,0x7c3e3c23,0x224902a1}},	//   _drži, ídu_, vapr, _fdak_,
   {{0x765b3c24,0x93bc00d3,0x7c3e0167,0x41eb0174}},	//   nguy, rbăt, wapr, ụsọ_,
   {{0x27e00b88,0x62963c25,0x3ea00063,0x62843c26}},	// [3140] ğini_, _inyo, rjit_, _iaio,
   {{0x27e03c27,0x6296023e,0x62863c28,0x62843c29}},	//   şini_, _hnyo, ldko, _haio,
   {{0x7c3e3c2a,0x62840062,0x220401dc,0xddcd044c}},	//   rapr, _kaio, bèhé_, teaţ,
   {{0x443e3c2b,0x62863c2c,0x7c3e3c2d,0xed5a3974}},	//   zat_, ndko, sapr, _ком_,
   {{0x62841379,0x443e3c2e,0x88e61278,0xe894141b}},	//   _maio, yat_, ожде, заль,
   {{0x443e3c2f,0x5fcf0034,0x62843c30,0xceb40092}},	//   xat_, _हेडल, _laio, lkə_,
   {{0x443e3c31,0x6d443c32,0x629600ac,0x994900a5}},	//   vat_, lsia, _onyo, góły_,
   {{0x7c3c3c33,0x9a290019,0xd8383c34,0x7c29007e}},	//   _herr, _tươi_, _moči_, _đeri,
   {{0x443e3c35,0x7c3c02fd,0xd8380117,0x644e0231}},	//   tat_, _kerr, _loči_, óbio,
   {{0x443e3c36,0x62963c37,0xc9d5001c,0xa3c302c6}},	//   uat_, _anyo, _عملک, láří_,
   {{0x7c3c3c38,0x6d440332,0x62843c39,0xaca40129}},	//   _merr, hsia, _baio, _ndọr,
   {{0x6b83052f,0x7c3c3c3a,0x672d1912,0x212900f9}},	//   ængi, _lerr, ćajt, _ptah_,
   {{0x443e3c3b,0xf1c5009d,0xaca40174,0xd25100cd}},	//   pat_, _लेखन, _adọr, ونگ_,
   {{0x443e3c3c,0x843800e3,0x62963c3d,0x69c201c0}},	//   qat_, _اكثر_, _enyo, izoe,
   {{0x6d461f60,0x224909a4,0x6d4421f7,0x78a802b6}},	//   _avka, _tdak_, esia, _modv,
   {{0x76403c3e,0x62840558,0x99840090,0xd8380357}},	//   namy, _gaio, _bemż_, _doči_,
   {{0x7c3c3c3f,0x443c3c40,0xa91d02e6,0x6d443c41}},	// [3150] _berr, _kev_, _trži, gsia,
   {{0x7c3c3c42,0x2d893c43,0x7640023f,0xd8383bbd}},	//   _cerr, rvae_, hamy, _foči_,
   {{0x7eaa025b,0x443c3c44,0x76403c45,0x6d440302}},	//   _výpr, _mev_, kamy, asia,
   {{0x0f7a0130,0x7cf00003,0x6d44023e,0x70550281}},	//   _פארב, färs, bsia, _بنگا,
   {{0x7c3c3c46,0x6b8e0078,0x7640343c,0xdb050103}},	//   _ferr, _erbg, damy, gyhá,
   {{0x443c022e,0x7c3c01b0,0x3f810052,0x315800ca}},	//   _nev_, _gerr, _kshu_, קיון_,
   {{0xe7390084,0xda351ad1,0x78a8015c,0xdb23001c}},	//   щей_, _невы, _dodv, _آوری,
   {{0x7d1d3c47,0x7c3c0a00,0x76403c48,0x7c253c49}},	//   _kuss, _zerr, gamy, lchr,
   {{0x62843c4a,0x7cf000c2,0x7d1d3c4b,0x44290d2a}},	//   _raio, märr, _juss, _ƙa_,
   {{0x443c01bb,0x7d1d3c4c,0x6aa90126,0x7c3c3c4d}},	//   _cev_, _muss, _hoef, _xerr,
   {{0x7d1d0f2f,0x62840036,0x6d443c4e,0xf8b2021e}},	//   _luss, _paio, zsia, _רשב_,
   {{0x6d440150,0x443c0090,0x6e3d01ce,0x7c253bf8}},	//   ysia, _eev_, _nesb, hchr,
   {{0x361a0105,0x443c3c4f,0x34953c50,0x5ec30081}},	//   _הונד, _fev_, _надр, ্কাই,
   {{0x7e6f00c4,0x6abb00b3,0x6284024a,0x6aa90381}},	//   _abcp, _lluf, _waio, _loef,
   {{0x64413c51,0x7d1d3c52,0xdfd200e3,0x6abb3c53}},	//   mali, _auss, رير_, _oluf,
   {{0x7c3c2f7c,0x7d1d3c54,0x7d150029,0x6d440006}},	//   _serr, _buss, _aizs, tsia,
   {{0x7c3c3c55,0x6d443c56,0x6e3d3c57,0x6e2404d8}},	// [3160] _perr, usia, _desb, rcib,
   {{0x6abb3c58,0x6e243c59,0x443c04de,0x6d440133}},	//   _aluf, scib, _xev_, rsia,
   {{0xd838005f,0x6e3d0113,0x6d443c5a,0x6619010a}},	//   _uoči_, _fesb, ssia, _ogwk,
   {{0x64413c5b,0xe80f143d,0x7c3c0078,0x7d1d3c5c}},	//   hali, ाधना_, _werr, _fuss,
   {{0x64411c04,0x7c3c3c5d,0x44273c5e,0xe0df00b3}},	//   kali, _terr, _ofn_, cròs_,
   {{0x64413c5f,0x69c20505,0x81be0081,0x2d823c60}},	//   jali, rzoe, _আশা_, _iske_,
   {{0x6abb3c61,0xf09300a1,0xa3cb0971,0x76403c62}},	//   _fluf, תנו_, _रेल_, tamy,
   {{0x443c3c63,0x69cd2a45,0xdbc731e8,0x7d1d3c64}},	//   _sev_, _देवी, töör, _yuss,
   {{0x64413c65,0x443c01fa,0x764005bd,0x4427084e}},	//   fali, _pev_, ramy, _bfn_,
   {{0x64413c66,0x443c022e,0x76403c67,0x7d090036}},	//   gali, _qev_, samy, _èest,
   {{0x443c006c,0x61e4124d,0x81aa0081,0x764005bd}},	//   _vev_, _axil, _গেল_, pamy,
   {{0x6441032c,0x201a0042,0x443c023e,0x3267007b}},	//   aali, _agpi_, _wev_, чтов,
   {{0x64413c68,0x443c3c69,0x6e3d3c6a,0xfbc40033}},	//   bali, _tev_, _resb, ্থিত,
   {{0x64a301b3,0x6e3d3c6b,0x20cd00d2,0xc0c800d3}},	//   _пача, _sesb, mžik_, пусе_,
   {{0x7d1d3c6c,0x7f943c6d,0x2d823c6e,0x6e3d0167}},	//   _suss, нарх, _aske_, _pesb,
   {{0x67270103,0x33db00ca,0x7d150342,0x39463c6f}},	//   _éjje, _לחוד, _sizs, ksos_,
   {{0x3d17009f,0x7c253c70,0xd83800c4,0x7cf002c3}},	// [3170] _भूखे_, tchr, _hoču_, värr,
   {{0xad9b0a43,0xc1bc00a1,0x3f81023e,0x6aa902ac}},	//   _azúc, _למחש, _tshu_, _soef,
   {{0x09aa00c7,0x7d150018,0x2d8206a3,0x7c253c71}},	//   _খেলা, _vizs, _eske_, rchr,
   {{0x7d1d1d19,0x7c253c72,0x64413c73,0xc33300a1}},	//   _tuss, schr, zali, תוף_,
   {{0x64413c74,0x6f1e00cc,0x0ef902d5,0x69343c75}},	//   yali, _zupc, ंतीस_, енчу,
   {{0x64410092,0x20cd0095,0x6aa92ad7,0xd83e0117}},	//   xali, džik_, _woef, ščna_,
   {{0x238c030b,0x66e53c76,0x6aa90227,0x98a200e5}},	//   _něj_, мока, _toef, тище,
   {{0x2bd3007a,0x7e6d0072,0x44270381,0xa56200d1}},	//   _धेया, nfap, _sfn_, چگون,
   {{0x26c301b3,0xc6480037,0x7d090036,0x44250063}},	//   ėjo_, سجيل_, _èess, tcl_,
   {{0x3a3f1570,0xa91d00d4,0x00000000,0x00000000}},	//   _heup_, _držt, --, --,
   {{0x68e40076,0x61f600c2,0x291f0350,0x00000000}},	//   éide, _syyl, _huua_, --,
   {{0xe29a3c77,0x80d00455,0x216a0084,0x291f0051}},	//   цам_, डोने, оими_, _kuua_,
   {{0xf6520327,0x44271421,0x291f00bc,0x22423c78}},	//   _יצא_, _tfn_, _juua_, rakk_,
   {{0x64413c79,0xd83800e7,0x6ada0469,0x29190113}},	//   qali, _foču_, _भद्र, _ésau_,
   {{0xdce4003d,0x291f00aa,0xbef90096,0x29053c7a}},	//   stiċ, _luua_, ंतून_, _mhla_,
   {{0x61f60084,0x61e40634,0x61370129,0x01ef0129}},	//   _tyyl, _txil, ụlag, ụrụn,
   {{0xf1bf17dc,0x65693c7b,0x3eab030a,0xdd9207e8}},	// [3180] lcán_, nteh, _doct_, خوذ_,
   {{0x315707a6,0x24870c56,0xec773c7c,0x2905063d}},	//   _קיין_, _janm_, мпу_, _nhla_,
   {{0x24870c56,0x224001af,0x9a861894,0x38b00441}},	//   _manm_, _keik_, дулл, _màrt_,
   {{0x21200332,0xa3d4074c,0x248705aa,0x38b0009c}},	//   _kuih_, _सेफ_, _lanm_, _làrt_,
   {{0x397a1857,0x2905009c,0x2d8200cb,0x39463c7d}},	//   تصاد_, _bhla_, _uske_, usos_,
   {{0x3a263625,0x22402e7b,0x212000dc,0x248702f1}},	//   scop_, _leik_, _muih_, _nanm_,
   {{0x39461c77,0xdb83079c,0x212003a9,0xcb6700d3}},	//   ssos_, _игри, _luih_, _оаре_,
   {{0x81c400c7,0x38c8110a,0xf52637f0,0x66de00d9}},	//   _এখন_, _کاری_, мфон, rīko,
   {{0x78663c7e,0x248702f1,0xe5c600c2,0xe4e6004d}},	//   _оказ, _banm_, ьско, дінн,
   {{0x090300ae,0x00000000,0x00000000,0x00000000}},	//   _апун, --, --, --,
   {{0xb86503ef,0x24870154,0x366a0f21,0x61fa00a7}},	//   _سالو, _danm_, _мажо_, ətli,
   {{0x212023b0,0x63c400c4,0x929401b3,0xe6930076}},	//   _buih_, _đunđ, ваюц, _للمد,
   {{0x24870c56,0xf5b6110a,0xf1bf0a43,0x21200113}},	//   _fanm_, _تصاد, acán_, _cuih_,
   {{0xfd4f0023,0x66023c7f,0x2d80007f,0x00000000}},	//   _triế, _izok, dwie_, --,
   {{0xc58800ef,0x46b23c80,0x00000000,0x00000000}},	//   _hồ_, _जवाह, --, --,
   {{0x38690995,0x0efb0285,0x6e36084e,0x2487022b}},	//   đari_, ्षेस_, gbyb, _zanm_,
   {{0xfd1f2eac,0x3a3f0227,0x248705aa,0x7cf03c81}},	// [3190] _quì_, _reup_, _yanm_, tärp,
   {{0xc58800de,0x22400381,0x00000000,0x00000000}},	//   _mồ_, _zeik_, --, --,
   {{0xc58800de,0x50d40037,0xf429007b,0x6e360565}},	//   _lồ_, _جزير, lkää_, bbyb,
   {{0x527c006e,0x6f06009c,0x0dcb0cf5,0x290501b9}},	//   ַנוא, _ghkc, _дуги_, _shla_,
   {{0x5e5600c1,0x6f0d006d,0x394900e3,0x66020079}},	//   _אירע_, mmac, éas_, _nzok,
   {{0x6f0d3c82,0xb06600c2,0x6b8302b6,0x7ceb042c}},	//   lmac, _ikää, ængs, hürz,
   {{0x66023c83,0x7ceb3c84,0x20cd14f3,0xf7710076}},	//   _azok, kürz, ržih_, اات_,
   {{0xc58800de,0xf42900c2,0x291f00aa,0x6569093e}},	//   _bồ_, kkää_, _tuua_, tteh,
   {{0xa3d40378,0x98753c85,0x22403c86,0x788801d3}},	//   _सेब_, _плац, _reik_, _būvē,
   {{0x65693c87,0x6f0d3c88,0x290508e1,0x79580208}},	//   rteh, hmac, _uhla_, _цифр_,
   {{0x65693c89,0x6f0d3c8a,0xccf200a1,0xc6a70012}},	//   steh, kmac, רכי_, _орди,
   {{0x87b600c1,0x24870063,0xe7b6006e,0x6f0d0381}},	//   _אלעס_, _wanm_, _אהער_, jmac,
   {{0x463a07a6,0xa3d4007a,0xf1bf0037,0xa484001c}},	//   _זענע, _सेठ_, scán_, رجین,
   {{0x73e50465,0x67213c8b,0x30750084,0x7f5c1a4a}},	//   _полз, _kulj, кусс, turq,
   {{0x91030e58,0x22400063,0x2120366c,0xf8520031}},	//   упре, _teik_, _wuih_, ížiť_,
   {{0x2d800034,0x67213c8c,0xdce416aa,0xbddb0113}},	//   twie_, _mulj, rtič, _ndès,
   {{0x6721003d,0xf38900de,0x8277006e,0x00000000}},	// [31a0] _lulj, _hả_, _טעקע_, --,
   {{0x9f863c8d,0x26df00cc,0x6f0d3c8e,0x6c860037}},	//   _згод, hnuo_, amac, علام,
   {{0x26df005f,0x6e46215f,0x395d01c0,0x103b00ca}},	//   knuo_, _пенз, euws_, _מגיע,
   {{0xe60700e3,0x6da60cba,0x7c3b0234,0x6f0d041c}},	//   _مش_, _зима, _đure, cmac,
   {{0xd6d000d0,0xda6500e3,0x7ae33c8f,0xb0d70ccb}},	//   یقت_, ضاني, énta, _डगमग,
   {{0x98a3185c,0x7d09028d,0x67d40a29,0x38b90154}},	//   личе, _èesp, колу, _fèrm_,
   {{0x66023c90,0xfce33c91,0x38b00441,0x00000000}},	//   _szok, _соро, _bàrr_, --,
   {{0x67213c92,0x26df00cb,0x7d1b1da6,0x00000000}},	//   _dulj, gnuo_, _èusc, --,
   {{0xe8ca002d,0x00000000,0x00000000,0x00000000}},	//   _егал_, --, --, --,
   {{0xa2a302d5,0x6721009e,0x38b0009c,0xf38900fe}},	//   गाभ्, _fulj, _eàrr_, _bả_,
   {{0xf38900ef,0x6f0d3c93,0x38b001b9,0x2259007b}},	//   _cả_, ymac, _fàrr_, мины_,
   {{0x26df14f3,0x9f5e0206,0xf429007b,0x00000000}},	//   cnuo_, ätý_, tkää_, --,
   {{0x672100e7,0xe0df015e,0x290e015e,0x00000000}},	//   _zulj, bsòl_, omfa_, --,
   {{0x271e0294,0x645c0131,0x13f4008f,0x6f0d01cb}},	//   _ọnya_, órid, _изля, wmac,
   {{0x6f0d3c94,0xbddb0113,0xf38900fe,0x00000000}},	//   tmac, _ndèr, _gả_, --,
   {{0x75220a4b,0x61e200c6,0x00000000,0x00000000}},	//   _kuoz, _žole, --, --,
   {{0x7c3b02ef,0x98830031,0x75220138,0x60d51175}},	// [31b0] _đurb, víľu_, _juoz, pizm,
   {{0x6f0d3c95,0x26df0995,0x00000000,0x00000000}},	//   smac, znuo_, --, --,
   {{0xc4d300c1,0xf38900de,0x00000000,0x00000000}},	//   נגע_, _xả_, --, --,
   {{0x59d200a5,0x6721042d,0x764200e1,0x00000000}},	//   _देहर, _rulj, _neoy, --,
   {{0x672102fd,0x41b31462,0x79820270,0xd8f5001c}},	//   _sulj, ुनिस, gwow, پزشک,
   {{0xdb2303ed,0x3ea93c96,0x9dd600a1,0xb9120134}},	//   _موسی, ljat_, _יורק_, monụ_,
   {{0x26df042d,0xf09422fe,0xb8d90096,0x07a53c97}},	//   tnuo_, טנס_, _चव_, тайн,
   {{0x3ea93c98,0x59d21152,0xf1b30789,0x75220036}},	//   njat_, _देवर, ुनान, _buoz,
   {{0xceb40c6a,0x39153c99,0x26df0335,0xf38900fe}},	//   טיק_, _амар, rnuo_, _sả_,
   {{0x26df0106,0x2246031a,0x67213c9a,0x3ea9007b}},	//   snuo_, _žok_, _tulj, hjat_,
   {{0x3fdc0081,0x3ea902ef,0xa3cb009f,0x26df09ac}},	//   _ধর্ষ, kjat_, _रेख_, pnuo_,
   {{0x3ea9009e,0x6d5f0060,0xf38900de,0xe2973c9b}},	//   jjat_, kuqa, _vả_, ваю_,
   {{0xcb120130,0x20d600d6,0x3ea93c9c,0x752201c2}},	//   ילט_, вівс, djat_, _guoz,
   {{0xf3890019,0x3ea900b3,0x3e7c020b,0x00000000}},	//   _tả_, ejat_, _ật_, --,
   {{0x7eb80db4,0x10a32636,0xddca0034,0x6443034b}},	//   _hípi, ширн, łoży, _ieni,
   {{0x20cd0138,0x394d11dc,0xdc340206,0xa2a30d75}},	//   džiu_, _oves_, rúčk, गाण्,
   {{0x64433c9d,0xd83e0146,0xa7fc020e,0xe0d20a85}},	// [31c0] _keni, áčka_, _acıl, _نزد_,
   {{0x644326f7,0x3ea9007b,0x00000000,0x00000000}},	//   _jeni, ajat_, --, --,
   {{0x394d08ec,0x7eb83c9e,0xd83e033b,0xaa4634df}},	//   _aves_, _lípi, ščka_, веел,
   {{0x644327cd,0x79820034,0xdb2101f9,0x656b0090}},	//   _leni, twow, átás, _oqgh,
   {{0x3eab0146,0x20cd015c,0x7e9b00ca,0xa2a31462}},	//   žitá_, rživ_, _חסכו, गात्,
   {{0x798200a5,0x64433b77,0x6abd02d5,0x2d920169}},	//   rwow, _neni, ्फॉर, mvye_,
   {{0xf6e62cc1,0x7d1b0036,0x36d40095,0x00000000}},	//   кцин, _èusa, локр, --,
   {{0x7e643c9f,0xd6d70761,0x7b0300bc,0x00000000}},	//   ngip, кты_, lõun, --,
   {{0x64433ca0,0x7ae2019f,0x2d9206a3,0x75220036}},	//   _beni, mnot, nvye_, _quoz,
   {{0xd90e09b4,0xe7ed2235,0x64433ca1,0x7ae23ca2}},	//   _بیت_, _चुका_, _ceni, lnot,
   {{0x7d1c3ca3,0x64433ca4,0x9f4f0511,0x645c0428}},	//   _mirs, _deni, ünüz_, òriq,
   {{0x7ae23ca5,0x41e70f1e,0x394d3ca6,0x7d1c0216}},	//   nnot, віга, _yves_, _lirs,
   {{0xb356037f,0x7d1c01cb,0x00000000,0x00000000}},	//   ریکا_, _oirs, --, --,
   {{0x61e200c4,0x00000000,0x00000000,0x00000000}},	//   _žolc, --, --, --,
   {{0x64483ca7,0x251b13b6,0x92951d57,0x442e02b1}},	//   madi, _קווא, _байц, _iff_,
   {{0x64433ca8,0x7d1c064b,0xaf3400cd,0x7c2e3ca9}},	//   _zeni, _airs, شرفت, _afbr,
   {{0x7ae20897,0x644306d7,0x3ea93caa,0x7d1c3cab}},	// [31d0] dnot, _yeni, rjat_, _birs,
   {{0x3e530028,0x64433cac,0x27e900ae,0x64483cad}},	//   ệt_, _xeni, şani_, nadi,
   {{0x5a352249,0x7d1c3cae,0xaca30174,0x64480428}},	//   гнет, _dirs, _ntụb, iadi,
   {{0x941500c1,0x628f0d4d,0x7ae23caf,0x2bc200c0}},	//   אַנד_, ndco, gnot, वैधा,
   {{0x7d1c0054,0x442e0054,0x69cd31f4,0xaca30134}},	//   _firs, _off_, _देखी, _atụb,
   {{0x64483cb0,0x7c342ec2,0x7ae200c2,0x656000f9}},	//   jadi, _верх, anot, dumh,
   {{0x64483cb1,0xccf200ca,0x8af90092,0x6d4d1973}},	//   dadi, _לכך_, _atəş, lsaa,
   {{0x6e2d3cb2,0xb5fd00d9,0x38b903a9,0xe1ff00b3}},	//   ncab, egša, _mèri_, nfós_,
   {{0x64483cb3,0x6d4d3cb4,0x6f1d078c,0xc8670399}},	//   fadi, nsaa, _misc, _атеи,
   {{0x64483cb5,0x6f1d3cb6,0x6443023b,0x7d1c0188}},	//   gadi, _lisc, _qeni, _xirs,
   {{0x64433cb7,0x3246037e,0x442e0324,0x628f01cb}},	//   _veni, ленг, _dff_, fdco,
   {{0x644302dc,0x6d4d3cb8,0x68ed0080,0x442e3cb9}},	//   _weni, ksaa, éadf, _eff_,
   {{0x6443275a,0x645c132d,0x64483cba,0x442c03a9}},	//   _teni, óric, badi, bcd_,
   {{0x6f1d0080,0x64483cbb,0x6d4d3cbc,0x644301df}},	//   _aisc, cadi, dsaa, _ueni,
   {{0x1fb537fa,0xd36e0037,0x7d1c0072,0x6d4d3cbd}},	//   астр, _فهو_, _rirs, esaa,
   {{0x63bc038c,0x6d4d057a,0x7c3b0b18,0x7d1c3cbe}},	//   ørne, fsaa, _đura, _sirs,
   {{0xed5700c9,0x7d1c00bf,0x7e643cbf,0x6da33cc0}},	// [31e0] лот_, _pirs, rgip, бита,
   {{0x6f1d240a,0x7ff600e3,0x76490085,0x28b8045f}},	//   _eisc, _مسجا, haey, _अवधि,
   {{0x7d1c39c1,0xad9b0a43,0x7ae23cc1,0x79893cc2}},	//   _virs, _ayúd, tnot, _asew,
   {{0x6e2d158e,0x7d1c01bf,0xeafa0604,0x1dd50096}},	//   ccab, _wirs, ررات_, _ठेवत,
   {{0x7d1c3cc3,0x7ae23cc4,0x2d84025a,0x64483cc5}},	//   _tirs, rnot, _ème_, yadi,
   {{0x7ae23cc6,0xb6050095,0x2cb1033b,0x6448026d}},	//   snot, _mišč, _gozd_, xadi,
   {{0x644839e1,0x9cd7040a,0xe3a71487,0x442c0124}},	//   vadi, _עולה_, _ار_, vcd_,
   {{0x64483cc7,0x442e0b18,0x41b40179,0x65aa0291}},	//   wadi, _sff_, ँहास, етог_,
   {{0xceb30327,0x442c3cc8,0xbddb0154,0x00000000}},	//   מיה_, tcd_, _neèl, --,
   {{0x33743cc9,0x3a0931bb,0x00000000,0x00000000}},	//   агор, _شکنی_, --, --,
   {{0x64483cca,0xd6d90034,0x442e3ccb,0x00000000}},	//   radi, bił_, _vff_, --,
   {{0x64483ccc,0x291e3ccd,0x6d4d008a,0xd6d90034}},	//   sadi, _hita_, ysaa, cił_,
   {{0x291e3cce,0x6f1d0451,0x64483ccf,0x442e3cd0}},	//   _kita_, _risc, padi, _tff_,
   {{0x1be40455,0x6f1d3cd1,0x291e3cd2,0x64480188}},	//   कपाल_, _sisc, _jita_, qadi,
   {{0x291e3cd3,0x40340084,0x248e00dc,0x226a007b}},	//   _mita_, сесс, _iafm_, ätkö_,
   {{0xf1a70d9b,0x291e3cd4,0x6d4d3cd5,0x59c42397}},	//   _брон, _lita_, tsaa, वनार,
   {{0x2d580686,0x272a3cd6,0xe9050023,0x6f1d34d2}},	// [31f0] лить_, _lùn_, _lượ, _visc,
   {{0x6d4d3cd7,0x6e2d0328,0x0f3500cd,0x5fd60034}},	//   rsaa, scab, _نکرد, _डेवल,
   {{0x6d4d3cd8,0x6f1d3cd9,0xbc071612,0x711a0796}},	//   ssaa, _tisc, учай, _שותפ,
   {{0x6f1d00e3,0x291e3cda,0x4fd600a1,0x69cb3cdb}},	//   _uisc, _aita_, _כותב_, tzge,
   {{0x18692f00,0x68450077,0x291e3cdc,0x4ab609a1}},	//   вали_, анла, _bita_, _अकरव,
   {{0x272a3cdd,0xd6d90034,0x2d990610,0xbebb02ac}},	//   _bùn_, wił_, _irse_, _diëe,
   {{0x291e3cde,0xa3d41cff,0x00000000,0x00000000}},	//   _dita_, _सेल_, --, --,
   {{0xca48054f,0x272a3cdf,0x2d990a39,0x291e3ce0}},	//   _ملفه_, _dùn_, _krse_, _eita_,
   {{0x7afb3ce1,0x291e3ce2,0x7989063d,0x7ac4349e}},	//   _ikut, _fita_, _usew, _усре,
   {{0x291e3ce3,0x272a0065,0xd6d9007f,0x04b50927}},	//   _gita_, _fùn_, sił_, рсия,
   {{0x645c0161,0x7ae90120,0x7afb0172,0xd5a3001c}},	//   ória, _kjet, _kkut, _گلشی,
   {{0x2d8b02ef,0x60c5005c,0xb6050087,0x95d900c2}},	//   _osce_, _alhm, _pišč, _идет_,
   {{0x7afb0010,0x2611320a,0x7ae900dd,0x98d90179}},	//   _mkut, देशी_, _mjet, _भगाए,
   {{0x7ae90292,0x6ac23245,0xaca40129,0x63ba0537}},	//   _ljet, _शत्र, _kwụs, bytn,
   {{0x7afb3ce4,0x2d8b0036,0x2d9921d8,0x32090154}},	//   _okut, _asce_, _arse_, _ezay_,
   {{0x5de6261f,0xf1c20117,0x7afb3ce5,0xb6050117}},	//   ажба, tišč_, _nkut, _tišč,
   {{0x1c461803,0xa2a311b5,0x00000000,0x00000000}},	// [3200] инам, गार्, --, --,
   {{0x7ae93ce6,0xf1c20117,0x91bb00ca,0x3b960284}},	//   _ajet, rišč_, _סמיי, ијет,
   {{0x0c7900c6,0x2d8b00e5,0x60dc3ce7,0xe1ff3ce8}},	//   ысты_, _esce_, mirm, ngón_,
   {{0x291e3ce9,0x2bda009d,0x78a105aa,0x60dc0367}},	//   _sita_, _येणा, _anlv, lirm,
   {{0x7ae90292,0x3f9a2650,0xa2c700a4,0xed57008f}},	//   _djet, _hrpu_, ासत्, _коя_,
   {{0x60dc3cea,0xd8f700d6,0x7afb3944,0xd90d010d}},	//   nirm, анії_, _ekut, فیق_,
   {{0x291e3ceb,0x3cf50096,0x7ae90052,0x1c0a00a4}},	//   _vita_, ्तरे_, _fjet, _वरिल_,
   {{0x7ae903dd,0x12c100c7,0x7eb80018,0x291e3cec}},	//   _gjet, _উদ্দ, _típu, _wita_,
   {{0x291e3ced,0x2bda009d,0xe4a63cee,0x7c290367}},	//   _tita_, _येता, арно, _şeri,
   {{0xd49a06d5,0x291e00d3,0xe90500fe,0x00000000}},	//   три_, _uita_, _tượ, --,
   {{0x60dc3cef,0x92950b1b,0x224b3cf0,0x332001ee}},	//   dirm, банц, tack_, _biix_,
   {{0x63ba3cf1,0x81c301d3,0xd5e20032,0x5693004d}},	//   rytn, ņēmi, _gbo̟, _маєт,
   {{0x60dc3cf2,0x20b4000f,0xd53409b4,0x3a240483}},	//   firm, ुसंध, _افتخ, _mgmp_,
   {{0x26c6023e,0x60dc3cf3,0x7c3b077e,0x224b042c}},	//   _hloo_, girm, _đuro, sack_,
   {{0xb5e800c7,0x232715de,0xd43700c1,0xc5e80033}},	//   _পরিচ, _који_, _דרוק_, _পরিপ,
   {{0xa2d602d5,0x3a240063,0x61ed01e9,0x67280113}},	//   मोद्, _ngmp_, _txal, _mudj,
   {{0x60dc3cf4,0x67280357,0x32090233,0x26c60350}},	// [3210] birm, _ludj, _uzay_, _mloo_,
   {{0x7afb0891,0x7ae90dd9,0x60dc3cf5,0x2d990580}},	//   _skut, _sjet, cirm, _vrse_,
   {{0x443e02e2,0x68f83cf6,0x7ae90f52,0x67280113}},	//   ibt_, dovd, _pjet, _nudj,
   {{0x2129048e,0x66e800b6,0x8f9a00ca,0x00000000}},	//   _kuah_, děko, _עירי, --,
   {{0x7ae93cf7,0x3a240072,0x2d8b007e,0xe9f8004d}},	//   _vjet, _dgmp_, _usce_, анці_,
   {{0xe8f8013a,0x67283cf8,0xb4d5009f,0x22490133}},	//   алі_, _budj, _सगे_, _leak_,
   {{0x7ae9074a,0x26c600f9,0xdced0146,0x8aa73cf9}},	//   _tjet, _bloo_, ntač, _крад,
   {{0x7afb0e7a,0x7ae93cfa,0x79800174,0x443e3cfb}},	//   _ukut, _ujet, _ịweg, ebt_,
   {{0x6eba007d,0x33200188,0x60dc00a7,0x2eaa006e}},	//   _एकसु, _riix_, yirm, רשפּ,
   {{0x212109a4,0x7b2c0555,0x799b0065,0x60dc0072}},	//   _nihh_, _oğul, _iruw, xirm,
   {{0x80ab2a45,0xaca30294,0x67283cfc,0x60dc071d}},	//   ञाने, _adịc, _gudj, virm,
   {{0x212910dd,0x799b0113,0xe1ff0143,0x1b7a006e}},	//   _buah_, _kruw, rgón_, נטרע,
   {{0x60dc3cfd,0x443e0222,0xd36e00cd,0x21290113}},	//   tirm, bbt_, وهی_, _cuah_,
   {{0x2d890085,0xdce4007e,0x7af93cfe,0x753b3cff}},	//   dwae_, mtić, howt, mpuz,
   {{0xbea60aeb,0xe29a3d00,0x60dc3d01,0x4f953d02}},	//   бавк, _бай_, rirm, орту,
   {{0xc2460752,0x2a6d01fa,0x2bc6049d,0x93bc044c}},	//   _уник, _nceb_, लनसा, rcăt,
   {{0x6da33d03,0xe8df3d04,0x60dc3d05,0x93bc00ae}},	// [3220] пита, _awọn_, pirm, scăt,
   {{0x308600e3,0x0ffa0037,0x81b10033,0x00000000}},	//   _الدف, _معجب_, _টেক_, --,
   {{0x799b3d06,0x20290031,0x93bc044c,0x00000000}},	//   _aruw, átiť_, lcăr, --,
   {{0x799b3d07,0x24853d08,0xdce40234,0xc33200ca}},	//   _bruw, helm_, ktić, פוד_,
   {{0x6728239f,0x6f043d09,0xdce40d62,0xa3d9121d}},	//   _sudj, mlic, jtić, _ठेस_,
   {{0x6f043d0a,0x62863d0b,0x67280449,0x799b03a9}},	//   llic, heko, _pudj, _druw,
   {{0x68f803e5,0x35d0009f,0x38cb015a,0x6f043c59}},	//   rovd, _तेज़, دانی_, olic,
   {{0x62862c00,0x2bb5007d,0x6f0402e2,0x9f5f00fd}},	//   jeko, ंहरा, nlic, érée_,
   {{0x645c0396,0x62862525,0x6f043d0c,0x799b1044}},	//   ório, deko, ilic, _gruw,
   {{0x67280068,0x6f0402e2,0x212902e7,0x443e0364}},	//   _tudj, hlic, _ruah_, ubt_,
   {{0x6f043d0d,0x236509ac,0x443e3d0e,0x22493d0f}},	//   klic, gulj_, rbt_, _peak_,
   {{0x62860b7c,0xd5a4015a,0x21293d10,0x21210085}},	//   geko, _ولای, _puah_, _sihh_,
   {{0x6f043d11,0xc05b00d6,0x7ae30610,0x6f1600d4}},	//   dlic, лів_, énti, dmyc,
   {{0xf61700a1,0x6f04225b,0x40341ca5,0x66023d12}},	//   _החדש_, elic, зерс, _iyok,
   {{0x6f043d13,0x62863d14,0xf4870421,0x21290167}},	//   flic, beko, _دانی, _wuah_,
   {{0x6f043d11,0x66020283,0x212917b6,0x62863d15}},	//   glic, _kyok, _tuah_, ceko,
   {{0xdced16ac,0xd04e00a7,0x22640094,0x67220b21}},	// [3230] stač, hibə, šské_, _mioj,
   {{0xddd000ae,0x660200d8,0x00000000,0x00000000}},	//   ţeşt, _myok, --, --,
   {{0x66020361,0x6d460078,0x799b03a9,0x6f0f01b9}},	//   _lyok, _ewka, _sruw, _thcc,
   {{0x799b3d16,0x99991cf2,0x660236d8,0x00000000}},	//   _pruw, икет_, _oyok, --,
   {{0x645815f4,0x66023d17,0xd8253a3f,0x00000000}},	//   _odvi, _nyok, одли, --,
   {{0x47590020,0x98a202b3,0x62863d18,0xdce4007e}},	//   ария_, дише, zeko, vtić,
   {{0xe7390084,0x66023d19,0x16a93d1a,0x62863d1b}},	//   шей_, _ayok, ивки_, yeko,
   {{0x2ee902ad,0x64583d1c,0x66023d1d,0x62860634}},	//   nnaf_, _advi, _byok, xeko,
   {{0x62863d1e,0x644a05c4,0xb8830220,0x785b01d3}},	//   veko, _befi, _príč, tāvē,
   {{0x753b3d1f,0x644a030a,0xdce40880,0xead20139}},	//   rpuz, _cefi, rtić, _lẹ̀_,
   {{0x62863d20,0xdce400e9,0x6f04346f,0x66020502}},	//   teko, stić, ylic, _eyok,
   {{0x24853d21,0x644a0065,0x6722037a,0x64583d22}},	//   selm_, _eefi, _gioj, _edvi,
   {{0x412a29b7,0xe56e13a4,0x644a002b,0x349508f9}},	//   рого_, _юз_, _fefi, _мадр,
   {{0x644a3d23,0x7e7d01bf,0x764b0103,0xa06a07ed}},	//   _gefi, _absp, _hegy, јава_,
   {{0x6f0402dc,0x64413d24,0x68e400e3,0x93bc00d3}},	//   tlic, mbli, éidi, scăr,
   {{0xee3a1d62,0xf41200a1,0x752302e2,0x764b0018}},	//   рна_, _קפה_, _hinz, _jegy,
   {{0x6f043d25,0x764b0068,0x5d6a00a9,0x64413d26}},	// [3240] rlic, _megy, ризм_, obli,
   {{0x764b0068,0x4427005a,0x81c20081,0x64412271}},	//   _legy, _jgn_, ্পদ_, nbli,
   {{0x6f043d27,0x61fb03e5,0x25bf00dc,0xead20d79}},	//   plic, żult, hyul_, _fẹ̀_,
   {{0x75233d28,0x764b3d29,0x44270167,0x7c2911bc}},	//   _linz, _negy, _lgn_, _şert,
   {{0x6722167e,0x44273d2a,0x2d8f02b6,0x00000000}},	//   _rioj, _ogn_, æget_, --,
   {{0x764b0085,0x25bf0fa0,0x9c130174,0x44273d2b}},	//   _aegy, dyul_, _nọwo, _ngn_,
   {{0x764b3d2c,0x68ed0037,0x64413d2d,0x67220314}},	//   _begy, éada, dbli, _pioj,
   {{0x35b41e54,0x752b0113,0x38600511,0xd04e00a7}},	//   збир, _bugz, şir_, ribə,
   {{0xd04e01d4,0x94aa1994,0x2cb8007a,0x2db700c1}},	//   sibə, атна_, _kord_, ַלטן_,
   {{0x75233d2e,0x2cb802fe,0x64411030,0x7c3b0b18}},	//   _cinz, _jord_, gbli, _đurk,
   {{0x4427383f,0x2cb8160e,0x764b0103,0x9c130032}},	//   _dgn_, _mord_, _fegy, _dọwo,
   {{0x752302dc,0x04fc00c7,0x050a0081,0x44270ac1}},	//   _einz, ীদের_, রদের_, _egn_,
   {{0x64413d2f,0xead20649,0x75231cb2,0x66de01d3}},	//   bbli, _rẹ̀_, _finz, lūko,
   {{0x64580021,0x2cb83d30,0x644a00c4,0x00000000}},	//   _udvi, _nord_, _uefi, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4427029a,0x7e7d03a9,0x00000000,0x00000000}},	//   _zgn_, _qbsp, --, --,
   {{0x2cb83d31,0x00000000,0x00000000,0x00000000}},	// [3250] _bord_, --, --, --,
   {{0x44270072,0x75233d32,0xf1bf034f,0x2cb83d33}},	//   _xgn_, _xinz, scás_, _cord_,
   {{0xd0f83d34,0xfe700018,0x2d823d35,0xfbab01b6}},	//   ंकरण_, عدہ_, _epke_, штай_,
   {{0x6ffa00ca,0x25bf01c2,0x6e960103,0x3eb40206}},	//   _להתפ, yyul_, _فلپا, ľatá_,
   {{0x64410150,0x2cb83d36,0x764b0361,0xd9453d37}},	//   ybli, _ford_, _regy, чели,
   {{0x752b029a,0x3eb93d38,0x00000000,0x00000000}},	//   _rugz, _host_, --, --,
   {{0x3eb93d39,0x26cd0a4b,0x442702ac,0xad9b0103}},	//   _kost_, theo_, _rgn_, _ezút,
   {{0x7e6d3d3a,0x75233d3b,0x64410154,0xa7fc020e}},	//   ngap, _sinz, wbli, _acıs,
   {{0x3eb90054,0x95550080,0x764b0018,0x44270085}},	//   _most_, أخبا, _vegy, _pgn_,
   {{0xe73300e3,0x64413d3c,0x3eb900ca,0x26cd037a}},	//   _قصص_, ubli, _lost_, sheo_,
   {{0x64413d3d,0xe29a1104,0x3eb90126,0x764b0018}},	//   rbli, бан_, _oost_, _tegy,
   {{0x29073d3e,0x75233d3f,0x64413d40,0x3eb900e8}},	//   llna_, _winz, sbli, _nost_,
   {{0x44273d41,0x26110557,0x75233d42,0x59bd0d61}},	//   _tgn_, देखी_, _tinz, ्निर,
   {{0x97421419,0x659a0105,0x27310af0,0x859a00ca}},	//   šćen, _לינק, _kán_, _לשנו,
   {{0x3f5704f9,0x3eb93d43,0x27310220,0x8fa30a7c}},	//   għu_, _bost_, _ján_, наре,
   {{0x7e6d1e16,0x2731003e,0x3eb935ad,0xa3d402d5}},	//   ggap, _mán_, _cost_, _सेट_,
   {{0x2731173b,0x2ee0008a,0x62960eac,0x00000000}},	// [3260] _lán_, riif_, _iayo, --,
   {{0x62961d11,0x7e6d00f9,0x273100fe,0x3dd2007f}},	//   _hayo, agap, _oán_, rzyw_,
   {{0x3eb93d44,0x62963d45,0x65690131,0x2d8f02b6}},	//   _fost_, _kayo, hueh, æger_,
   {{0x2fc51484,0x2cb800a1,0xfe420103,0xb4c800b7}},	//   ølge_, _word_, _سکری, _ईत्_,
   {{0xe8940a18,0x673a0063,0x62963d46,0x200e0880}},	//   даль, _sttj, _mayo, šlić_,
   {{0x273100ef,0x62963d47,0xddc4007f,0x6d560967}},	//   _bán_, _layo, raiń, msya,
   {{0xd6da2983,0x27310019,0xaa460da5,0x6d560113}},	//   йти_, _cán_, _невл, lsya,
   {{0x987802dd,0x7c3b1386,0x62963d48,0x27313d49}},	//   _išči_, _đuri, _nayo, _dán_,
   {{0x6d563d4a,0x7ae23d4b,0xa3d42dfd,0xad9b01f9}},	//   nsya, miot, _सेज_, _nyúl,
   {{0x7ae23d4c,0x38c80260,0x62962783,0x2731109d}},	//   liot, _باری_, _aayo, _fán_,
   {{0x27313d4d,0x62963d4e,0x6d56063f,0x78a834c9}},	//   _gán_, _bayo, hsya, _indv,
   {{0xddc400d9,0x629601af,0x6d563d4f,0x7ae23d50}},	//   maiņ, _cayo, ksya, niot,
   {{0x64a63d51,0x629602c9,0x3eb93d52,0x78ba0094}},	//   _нада, _dayo, _rost_, _kotv,
   {{0x760b0130,0xf8be0557,0xc8be1687,0x3eb90036}},	//   _פּאַ, ्सिय, ्सिट, _sost_,
   {{0x3eb90054,0x2005003e,0x78ba3d53,0x62963d54}},	//   _post_, æli_, _motv, _fayo,
   {{0x62960256,0x7ae201ff,0x00000000,0x00000000}},	//   _gayo, jiot, --, --,
   {{0x7e6d3d55,0xa2aa0176,0x3eb93d56,0x00000000}},	// [3270] rgap, टार्, _vost_, --,
   {{0xb035036a,0xddd601f9,0x00000000,0x00000000}},	//   _юнош, ggyő, --, --,
   {{0xa3e20455,0x6296170c,0x316c0034,0x29070146}},	//   _नेम_, _yayo, ądze_, vlna_,
   {{0x27313d57,0xd8380383,0xd6c60246,0x61e20138}},	//   _rán_, _afč_, _شق_, _žoli,
   {{0x27310af0,0x00000000,0x00000000,0x00000000}},	//   _sán_, --, --, --,
   {{0x27310146,0xf7710246,0x00000000,0x00000000}},	//   _pán_, ناب_, --, --,
   {{0xb905009f,0x690d002b,0x78ba0094,0x00000000}},	//   _पग_, búen, _dotv, --,
   {{0x7ae23d58,0x78a83d59,0x27310023,0xd838022b}},	//   ciot, _endv, _ván_, _efč_,
   {{0x62963d5a,0x7827012b,0xbbdd2172,0x2d9f00d4}},	//   _rayo, _فعال, _मधुक, _šuej_,
   {{0x27313d5b,0x62963d5c,0x78ba02e5,0xddc4004b}},	//   _tán_, _sayo, _gotv, ngiš,
   {{0xb4cd007d,0x62963d5d,0x00000000,0x00000000}},	//   _रती_, _payo, --, --,
   {{0x91e611f8,0x6d56008c,0xe1ff007f,0x00000000}},	//   доме, ysya, ngów_, --,
   {{0xdc0a148e,0x6abb1022,0x00000000,0x00000000}},	//   _वर्ड_, _mouf, --, --,
   {{0x7ae23d5e,0x62963d5f,0xf99200ca,0x6abb014b}},	//   ziot, _wayo, דרך_, _louf,
   {{0x62963d60,0x6aa90381,0x7b0300bc,0xf4b60504}},	//   _tayo, _onef, nõus, _تشنگ,
   {{0x68e33d61,0x6d560113,0x7ae20072,0x28a40285}},	//   hind, tsya, xiot, _गोनि,
   {{0x7ae23d62,0x00000000,0x00000000,0x00000000}},	// [3280] viot, --, --, --,
   {{0x6d563d63,0x6aa9030a,0x3cfa00a5,0x68e33d64}},	//   rsya, _anef, ्तें_, jind,
   {{0x6d56005c,0xb4fa00c1,0x6abb00fd,0x7ae23d65}},	//   ssya, קלער, _bouf, tiot,
   {{0x6d560124,0x78ba0094,0x6abb3d66,0x00000000}},	//   psya, _sotv, _couf, --,
   {{0x68e33d67,0x78ba2188,0x7ae23d68,0xe8fa1469}},	//   find, _potv, riot, олд_,
   {{0x68e33d69,0x7ae30610,0x97a62657,0x2004013c}},	//   gind, éntr, дрил, əmir_,
   {{0xad9b0018,0x2a7d01fa,0x6abb1022,0xda660076}},	//   _nyúj, bfwb_, _fouf, _ياري,
   {{0x6abb014b,0x656d0031,0x00000000,0x00000000}},	//   _gouf, _ťaha, --, --,
   {{0x68e33d6a,0x69d6030b,0x78ba0231,0x00000000}},	//   bind, _मेची, _totv, --,
   {{0x68e33d6b,0x78a82dfc,0x6abb02c6,0x20050f81}},	//   cind, _undv, _zouf, ülik_,
   {{0x6abb0381,0x00000000,0x00000000,0x00000000}},	//   _youf, --, --, --,
   {{0xe76906cf,0x658702c3,0x00000000,0x00000000}},	//   _رحمن_, örhå, --, --,
   {{0x471b0142,0xbddb0139,0xf4930a85,0x98a4078e}},	//   _וואג, _leèr, رشید, _gumă_,
   {{0x660f01bf,0x3cfa0034,0x00000000,0x00000000}},	//   ücke, ्तों_, --, --,
   {{0xdfd510e0,0x261a0285,0xad9b01f9,0x00000000}},	//   ховы, मेरी_, _gyúj, --,
   {{0x68e33d6c,0x00000000,0x00000000,0x00000000}},	//   zind, --, --, --,
   {{0xa3e204a9,0x68e33d6d,0x9d153d6e,0x229f0139}},	// [3290] _नेत_, yind, едач, _ẹkú_,
   {{0x6abb1bc4,0x68e33d6f,0xee3f0031,0xddc40138}},	//   _souf, xind, _iným_, ugiš,
   {{0x3a3c0129,0xf09200ca,0xa2d62918,0x6abb3d70}},	//   _ịgụ_, _גני_, मोक्, _pouf,
   {{0x68e33d71,0x9c130174,0x6fae000d,0x00000000}},	//   wind, _bọro, ीहरू, --,
   {{0x690d0072,0x66e802c6,0x69af00a4,0x00000000}},	//   búel, něku, ंमधी, --,
   {{0x7b0300aa,0x3f870131,0x00000000,0x00000000}},	//   tõus, _ânus_, --, --,
   {{0x68e33d72,0x6abb3d73,0x98a4020a,0x00000000}},	//   rind, _touf, _sumă_, --,
   {{0x68e33d74,0x6aa9037a,0x00000000,0x00000000}},	//   sind, _unef, --, --,
   {{0x68e33d75,0x320900f9,0x00000000,0x00000000}},	//   pind, _nyay_, --, --,
   {{0x974202e6,0x68e33d76,0x39143d77,0x00000000}},	//   šćan, qind, _амур, --,
   {{0xe29a3d78,0x32090694,0x28ac022d,0x2905009e}},	//   пан_, _ayay_, चारि, _ikla_,
   {{0xe29a2ca3,0xd0550092,0xdce401e8,0x63bc0149}},	//   чам_, mizə, ktiğ, ärna,
   {{0xa2d60176,0xcb122252,0x00000000,0x00000000}},	//   मोग्, טלט_, --, --,
   {{0x657b0a4b,0x00000000,0x00000000,0x00000000}},	//   mtuh, --, --, --,
   {{0x657b3d79,0x394d0154,0x60c101cd,0x3f160161}},	//   ltuh, _lwes_, ölma, еќат,
   {{0x22010174,0x670f00b6,0x11680d7f,0x66ce0139}},	//   ụsịl, ातिक_, _قلبی_, _kùka,
   {{0x657b3d7a,0x7c3b0092,0x25790c56,0x29050063}},	// [32a0] ntuh, _şura, nèl_, _okla_,
   {{0xfa150081,0x657b0350,0x26cf03a8,0x00000000}},	//   িশাল_, ituh, _llgo_, --,
   {{0x225207ac,0x0b46008f,0x612b009e,0x00000000}},	//   _keyk_, хнен, _iżla, --,
   {{0x657b0d1f,0xb4bc0285,0x68e100eb,0x29050233}},	//   ktuh, _इक्_, _amld, _akla_,
   {{0x28ac04dd,0x19943d7b,0x6284052a,0xd8380154}},	//   चालि, таля, _mbio, _ončt_,
   {{0x26cf0d9f,0xd90d00d0,0x257906a3,0x02cc1006}},	//   _algo_, قیق_, dèl_, ासुन,
   {{0x56943d7c,0x662500a7,0x628400ee,0x00000000}},	//   вайт, ərkə, _obio, --,
   {{0xd6d70084,0x290505aa,0x20d400bc,0xba530d59}},	//   еть_, _ekla_, _häid_, _منفع,
   {{0x88861510,0x6d443d7d,0x16370037,0xa9670a52}},	//   _плаж, npia, رسية_, _пита_,
   {{0x62843d7e,0x20d400aa,0x6d4400c6,0x00000000}},	//   _abio, _jäid_, ipia, --,
   {{0x6284009c,0xe2f90120,0x02cc00a4,0x00000000}},	//   _bbio, дені_, ासून, --,
   {{0x28a400aa,0x25793d7f,0x00000000,0x00000000}},	//   _गोति, bèl_, --, --,
   {{0x248c0167,0x6eba1981,0x00000000,0x00000000}},	//   pedm_, _एकजु, --, --,
   {{0x2ec900e2,0x628400f9,0xe8170179,0x00000000}},	//   रस्त, _ebio, धेका_, --,
   {{0x43943d80,0x00000000,0x00000000,0x00000000}},	//   _райс, --, --, --,
   {{0xdce401e8,0x442e0113,0x752a3d81,0x6e9400ae}},	//   ttiğ, _hgf_, _hifz, лису,
   {{0xb8160081,0x6d443d82,0x442e0131,0xd9e009a1}},	// [32b0] াশিত_, gpia, _kgf_, _खेलत_,
   {{0x629d3d83,0x62840034,0x3a2d0072,0x66e703a9}},	//   ldso, _zbio, _sgep_, _kèkè,
   {{0x37e50081,0xdce40233,0x00000000,0x00000000}},	//   _পুনর, stiğ, --, --,
   {{0x257914b1,0x7b2c01e8,0x29050146,0x394d0270}},	//   yèl_, _ağus, _skla_, _pwes_,
   {{0x7bc506e1,0x6f0d3d84,0x629d3d85,0xdb080103}},	//   syhu, mlac, idso, ílás,
   {{0x25790c56,0x013800ca,0x00000000,0x00000000}},	//   vèl_, ערות_, --, --,
   {{0x628f0063,0x6f0d0527,0x973c00c4,0x00000000}},	//   keco, olac, _prća, --,
   {{0x25793d86,0x6f0d3d87,0x442e02b6,0xd05500a7}},	//   tèl_, nlac, _agf_, rizə,
   {{0x629d0150,0x98a400c6,0x394d01dc,0x2d4f007f}},	//   ddso, _sumą_, _uwes_, nże_,
   {{0x6f0d3d88,0x657b3d89,0x257906a3,0xa3e200aa}},	//   hlac, rtuh, rèl_, _नेह_,
   {{0x657b3d8a,0xe7b50dce,0x6f0d3d8b,0x25fd269c}},	//   stuh, _جماد, klac, _लडकी_,
   {{0x2d4f0067,0x6f0d0220,0x6e3d02ef,0x628f3d8c}},	//   kże_, jlac, _nfsb, geco,
   {{0x69d93d8d,0x76493d8e,0x443c0120,0x64480b6a}},	//   nzwe, mbey, _ffv_, bbdi,
   {{0x442e01bf,0x61431b60,0x6f0d0076,0x672b0052}},	//   _ggf_, рера, elac, _higj,
   {{0x225200f9,0x6d440150,0xd0071055,0xb4bf14e5}},	//   _teyk_, wpia, вере_, ीसी_,
   {{0x6f0d3d8f,0x76493d8e,0x672b0188,0x7b2c00a7}},	//   glac, nbey, _jigj, _oğur,
   {{0xed570303,0xf65200c1,0x65690eac,0x672b3d90}},	// [32c0] кот_, יצן_, nreh, _migj,
   {{0x672b01e5,0x6f0d1519,0xa3c80251,0x315700c1}},	//   _ligj, alac, लैक_, _שיין_,
   {{0x6f0d3d91,0x79893d92,0x6d443d93,0xd83808c5}},	//   blac, _apew, spia, _jače_,
   {{0x6d441612,0xd94608f2,0x0ea930a8,0x6f0d1909}},	//   ppia, веди, _चोपड, clac,
   {{0xd9100814,0x6448008c,0x69d90381,0x00000000}},	//   میر_, ybdi, gzwe, --,
   {{0x8c433d94,0x65692a0d,0x7d070113,0x7b2c020a}},	//   _вере, dreh, _gkjs, _eşua,
   {{0x20d400aa,0xfce32e0f,0x00000000,0x00000000}},	//   _käib_, _торо, --, --,
   {{0x25a9191d,0x628f0072,0x00000000,0x00000000}},	//   _šala_, xeco, --, --,
   {{0x65693d95,0x80d300c7,0x628f3d96,0x672b023b}},	//   greh, _সদস্, veco, _digj,
   {{0x39462733,0xe4a6355b,0x81b80033,0x63bc12cd}},	//   mpos_, трио, চনা_, ärno,
   {{0xd4970ab3,0xdced0542,0x394633f4,0x6f0d2aef}},	//   тры_, stać, lpos_, ylac,
   {{0x290e0150,0xdce42ad5,0x20d400bc,0x00000000}},	//   llfa_, drič, _näib_, --,
   {{0x6f0d04a3,0x629d3d97,0x2738020b,0x00000000}},	//   vlac, rdso, _hén_, --,
   {{0x39460fb6,0xd3a600d3,0x27383d98,0x443c0231}},	//   ipos_, _арип, _kén_, _ufv_,
   {{0x4fc40fe9,0x628f0131,0xd83800c4,0xf429007b}},	//   аста, peco, _gače_, rjää_,
   {{0xb27500c2,0x25a63d99,0x2738066a,0x00000000}},	//   _слиш, _krol_, _mén_, --,
   {{0x6f0d3d9a,0x1be802d5,0x27383d9b,0xddc60383}},	// [32d0] rlac, _टेबल_, _lén_, _lekņ,
   {{0xdce40d12,0x26050378,0xe7e3007a,0x22593d9c}},	//   brič, _हँसी_, _कइला_, lask_,
   {{0x6f0d1b17,0x273800de,0x09bd0473,0x1fe10033}},	//   plac, _nén_, ्न्य, _মুরস,
   {{0x69d902e2,0x6d5d3d9d,0x25a60206,0x00000000}},	//   tzwe, _tvsa, _orol_, --,
   {{0x99851be8,0x39463d9e,0xda780686,0xf9852458}},	//   التو, gpos_, тях_, угло,
   {{0x69d91743,0x27383d9f,0x672b0383,0x00000000}},	//   rzwe, _bén_, _sigj, --,
   {{0xe81e1349,0x27380080,0x66e5002d,0x660b00dc}},	//   येला_, _cén_, лока, _sygk,
   {{0x386907aa,0x3946023e,0x65690103,0x25a63da0}},	//   şar_, bpos_, treh, _brol_,
   {{0x273801c0,0x28a40e19,0x25a60234,0x3a3f00b3}},	//   _eén_, _गोवि, _crol_, _ifup_,
   {{0x7b2c0740,0x6f04002b,0x25a60154,0x65693da1}},	//   _uğur, zoic, _drol_, rreh,
   {{0x27383da2,0x0326007e,0x42ea3da3,0x25a60233}},	//   _gén_, лдон, емно_, _erol_,
   {{0x65693da4,0x216a02ec,0x61463da5,0x25a60072}},	//   preh, ними_, лема, _frol_,
   {{0x7d050052,0xd469002d,0xca7a006e,0x6f043da6}},	//   kohs, _зиле_, ענשט, voic,
   {{0x273801dc,0xdce43da7,0x19b600ca,0x044228b9}},	//   _yén_, trič, אפשר_, _лешн,
   {{0xf45600f5,0x2d993da8,0x2d8b3da9,0x22590062}},	//   _עיקר_, _asse_, _apce_, bask_,
   {{0x94420103,0x00000000,0x00000000,0x00000000}},	//   _پھین, --, --, --,
   {{0x6f042bc0,0x3dc90124,0xceb400a7,0x00000000}},	// [32e0] roic, gyaw_, lmək_, --,
   {{0xdce4011d,0x6ea410e9,0x5b3600ae,0x85030bd9}},	//   prič, _चोरु, гэду, रकिट_,
   {{0x2d9900c9,0xe7e302e8,0x160a009f,0x3dc90270}},	//   _esse_, _केला_, _हुनर_, ayaw_,
   {{0xa3c80251,0x394600f9,0x2d860161,0xdd1200d9}},	//   लैट_, tpos_, çoes_, _kļūs,
   {{0x9f060068,0xaca40134,0xaa570190,0x39463daa}},	//   _لوگو, _atụs, الها_, upos_,
   {{0x307a00c1,0xceb400a7,0xfce60161,0x3ea03177}},	//   גאַנ, kmək_, _сого, ldit_,
   {{0x39463dab,0xf72a002d,0xb8ec32ec,0x2d803dac}},	//   spos_, нций_, _लव_, ltie_,
   {{0x3ea0074a,0x27383dad,0x25a636a2,0x9634249b}},	//   ndit_, _vén_, _prol_, шниц,
   {{0x2d803dae,0xb8ea0081,0xe8fa3daf,0x225900f2}},	//   ntie_, _লগ_, _зла_, vask_,
   {{0x2738002b,0x3ea03db0,0x7d7b00ca,0xf36400d3}},	//   _tén_, hdit_, עניו, аӂин,
   {{0xa9230579,0x8cd90034,0x3160020a,0x00000000}},	//   ížen, फोटो, _aviz_, --,
   {{0x57fb00a1,0x81e60081,0x2d803db1,0x26cd037a}},	//   _אלבו, _বুধ_, ktie_, ckeo_,
   {{0x225900c6,0x31352458,0xf1ab0076,0x00000000}},	//   rask_, регр, راحه_, --,
   {{0x3160022b,0x22403db2,0x63bc09af,0xe7b60033}},	//   _dviz_, _efik_, ørns, জনীয,
   {{0xde59004d,0xdfd800e5,0x00000000,0x00000000}},	//   каві_, гът_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdc553db3,0x7d1c009c,0x645a0634,0x00000000}},	// [32f0] ивањ, _bhrs, oati, --,
   {{0x443e3db4,0x7d1c009c,0x28a4007f,0x00000000}},	//   nct_, _chrs, _गोलि, --,
   {{0x5a351e54,0x2d803db5,0x316002ef,0x25e609c3}},	//   анет, atie_, _zviz_, _जेसी_,
   {{0xf991010d,0x3dc90270,0x64a60096,0x2d80009c}},	//   قبت_, pyaw_, _कोसळ, btie_,
   {{0x2d803db6,0x629f3db7,0x50b800d0,0xbebb1183}},	//   ctie_, _maqo, _شدید_, _diët,
   {{0xb4c33db8,0x645a3db9,0x25a9033b,0x20d400aa}},	//   _एके_, jati, _šalo_, _käia_,
   {{0x645a26df,0x9854004d,0x00000000,0x00000000}},	//   dati, стіш, --, --,
   {{0x05653dba,0x16a900c2,0x443e00ae,0x629f3dbb}},	//   авин, твии_, ect_, _naqo,
   {{0x645a0193,0x63410029,0x057600e3,0xe61900e5}},	//   fati, _mēne, لمية_, ъди_,
   {{0xc4823dbc,0x7aeb3dbd,0x645a3dbe,0x2ed20e19}},	//   ольк, ligt, gati, _सत्त,
   {{0x29073dbf,0x629f2e10,0x69cb3dc0,0x394000ae}},	//   mona_, _baqo, lyge, ţist_,
   {{0x29073dc1,0xceb401d4,0x443e3dc2,0xf770006f}},	//   lona_, rmək_, act_, _رام_,
   {{0xa91d0138,0xb21b0537,0x443e02ac,0x00000000}},	//   _apži, sfæn, bct_, --,
   {{0x645a3dc3,0x03a50a8d,0x29073dc4,0x7aeb3dc5}},	//   cati, _вико, nona_, higt,
   {{0xb21b01c5,0xd8380039,0x7aeb019c,0x7e5625e7}},	//   lfæl, _jača_, kigt, итац,
   {{0xe51900af,0x29073dc6,0x799b3dc7,0x765b019c}},	//   _नीति_, hona_, _osuw, nauy,
   {{0x3ea03dc8,0x7aeb3dc9,0xee370b7b,0x6b810212}},	// [3300] rdit_, digt, рну_, _älgj,
   {{0x2d803dca,0x29073dcb,0xb4c32337,0x38653dcc}},	//   rtie_, jona_, _एको_, _ndlr_,
   {{0xa7fc07d1,0x2d803dcd,0xad9b0042,0x799b06bd}},	//   _adın, stie_, _axúd, _asuw,
   {{0x645a2c34,0x2d803dce,0x201a01c8,0x0a6700e5}},	//   zati, ptie_, _izpi_, арши_,
   {{0x692600d3,0xaca40294,0x660f01bf,0xbebb0f5a}},	//   амда, _agụr, ückl, _viët,
   {{0x29070990,0x645a3dcf,0xd83800d8,0x00000000}},	//   gona_, xati, _bača_, --,
   {{0x645a3dd0,0xe0b7006e,0x030602d5,0x7aeb3dd1}},	//   vati, ילסט_, रवाह_, bigt,
   {{0x645a3dd2,0xf102030b,0xd8380095,0x79b70018}},	//   wati, लकुद_, _dača_, _چھوڑ_,
   {{0x29073dd3,0x01cb0081,0x386502a4,0x4af900ae}},	//   bona_, _লেনদ, _fdlr_, _сэря_,
   {{0x29073dd4,0x79820350,0x6aa03dd5,0x62863dd6}},	//   cona_, mtow, _hamf, efko,
   {{0x645a3dd7,0x6aa01114,0xb4d609c3,0x9f45026a}},	//   rati, _kamf, _सती_, çlü_,
   {{0x645a1809,0x6d4602e6,0x629f0090,0xd05c00a7}},	//   sati, _otka, _qaqo, mirə,
   {{0xc05b0a8d,0x79820067,0x645a3dd8,0xf102045f}},	//   ків_, ntow, pati, लकूद_,
   {{0x645a3dd9,0x629f3cc5,0x6aa0039f,0x41e814fb}},	//   qati, _waqo, _lamf, рфюм_,
   {{0x251b0105,0x6d461dfc,0x64580029,0x629f0167}},	//   _שווא, _atka, _ievi, _taqo,
   {{0x798200a5,0x64583dda,0x6aa03ddb,0x00000000}},	//   ktow, _hevi, _namf, --,
   {{0x29073ddc,0x040b0033,0x7aeb3ddd,0x00000000}},	// [3310] yona_, হেদী_, vigt, --,
   {{0x40950080,0x64583dde,0xd05c0092,0x2e3d0139}},	//   _الدر, _jevi, kirə, _báfó_,
   {{0x2907116a,0xd00800c9,0x645802ef,0x7aeb3ddf}},	//   vona_, _веќе_, _mevi, tigt,
   {{0x290c00a6,0xd05c0092,0x69cb0212,0x68e80150}},	//   _akda_, dirə, tyge, _amdd,
   {{0x7aeb3de0,0x6aa03de1,0x18690e1d,0x66d50094}},	//   rigt, _damf, гали_, _náka,
   {{0x64583de2,0x7aeb3de3,0x76420139,0x270f0d88}},	//   _nevi, sigt, _afoy, ात्र_,
   {{0x29073de4,0x6aa003e3,0x79820034,0x7aeb2005}},	//   rona_, _famf, atow, pigt,
   {{0x20d402fd,0x29073de5,0x66d5026e,0x60c50365}},	//   _näin_, sona_, _báka, _lohm,
   {{0x7ae93de6,0x64583de7,0x27380019,0x799b3de8}},	//   _imet, _bevi, _lĩnh_, _usuw,
   {{0x6aa03de9,0x04b500c2,0xa91d0138,0x7ae90063}},	//   _zamf, ссия, _apžv, _hmet,
   {{0x7ae902dd,0xd6db0284,0x656010e4,0x65620231}},	//   _kmet, _итд_, asmh, _evoh,
   {{0x7afb010a,0x6aa000b3,0x98a5078e,0x00000000}},	//   _jjut, _xamf, _filă_, --,
   {{0x4545006f,0x7ae90129,0x68e802ad,0x64a53dea}},	//   _انتق, _mmet, _ymdd, _гала,
   {{0x05b809b4,0x7afb0995,0x64583deb,0x6ac4074c}},	//   _خدمت_, _ljut, _gevi, _वक्र,
   {{0x66d50871,0x96db030b,0x7ae93dec,0x690d0072}},	//   _záka, _बताउ, _omet, lúes,
   {{0x6458039f,0x7afb3ded,0x79820034,0x63120033}},	//   _zevi, _njut, ytow, _সংকট_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3320] --, --, --, --,
   {{0x7afb3dee,0x7ae93def,0x6aa03df0,0x6441255f}},	//   _ajut, _amet, _samf, ncli,
   {{0x7ae90036,0xa09b021e,0x2fd0020a,0x00000000}},	//   _bmet, _גייט, ângă_, --,
   {{0x765902e0,0xdbd00618,0x291e3df1,0x79820381}},	//   _newy, _užív, _shta_, ttow,
   {{0xe3a707d9,0x78a100d9,0x6d463df2,0x798203e3}},	//   _کر_, _balv, _utka, utow,
   {{0x7ae93df3,0x79820067,0x6cd60192,0x398005fe}},	//   _emet, rtow, _اقسا, ròs_,
   {{0x64583df4,0xf09300a1,0x79823df5,0x76590185}},	//   _revi, פנה_, stow, _bewy,
   {{0x6458020e,0x3ea20ec9,0xe81e0034,0xd6d7163d}},	//   _sevi, _jakt_, येगा_, йты_,
   {{0x7ae316b4,0x64580085,0x3ea20f63,0x00000000}},	//   ënte, _pevi, _makt_, --,
   {{0x78a13df6,0xd49a115a,0x7afb0087,0xe73a00ae}},	//   _galv, ури_, _zjut, _беж_,
   {{0x387e1ee3,0xa68616d9,0x24181ad1,0x20d400c2}},	//   _ictr_, _глед, роны_, _päin_,
   {{0x64430088,0x7659057a,0x690d002b,0xd83805db}},	//   _efni, _gewy, búes, _kačo_,
   {{0x61200ce3,0xa6a90781,0x64583df7,0x98ac0383}},	//   köld, _خالق_, _tevi, _lidč_,
   {{0x64a33df8,0x273800ef,0x673a3df9,0x7e7d00e7}},	//   _нача, _cũng_, _kutj, _scsp,
   {{0x673a3dfa,0x273800de,0xfd5d0134,0x3ea23dfb}},	//   _jutj, _dũng_, bazị, _bakt_,
   {{0x2bac0be4,0x27380019,0xfbdf0081,0xd5e20139}},	//   घटना, _vĩnh_, _বুঝত, _gbọ,
   {{0x60c53dfc,0x628d0112,0x673a023b,0xe1670452}},	// [3330] _tohm, _ibao, _lutj, _ادبي,
   {{0x273800de,0xbcfb00fd,0xa7fc0367,0x673a0313}},	//   _tĩnh_, _evén, _adım, _outj,
   {{0x3ea23dfd,0x9e3500c6,0x7afb0078,0x00000000}},	//   _fakt_, _менч, _pjut, --,
   {{0x78a10d63,0xd83805db,0x6441037a,0x6e9506cf}},	//   _salv, _bačo_, zcli, _بلحا,
   {{0x78a102fd,0x1a68110a,0x5d79006e,0x628d0076}},	//   _palv, صیلی_, _דאָק, _mbao,
   {{0xd90f00d0,0x6d4d0fc4,0x3ea23dfe,0xe8f8097a}},	//   ریا_, mpaa, _zakt_, блі_,
   {{0x78a13dff,0x940500a7,0x6d4d3e00,0x00000000}},	//   _valv, belə_, lpaa, --,
   {{0x7ae93e01,0x7afb00e9,0x2ca30b14,0x78a11044}},	//   _umet, _ujut, _hajd_, _walv,
   {{0x78a13e02,0x6d4d3e03,0x2a7f00b3,0xe5a53a46}},	//   _talv, npaa, _icub_, ципи,
   {{0x33653e04,0x98f709b4,0xaf010081,0x5fc9034d}},	//   овог, _اثرا, ্ষিণ_, रहाल,
   {{0x2ca30068,0x64413e05,0x765902ac,0x00000000}},	//   _majd_, rcli, _tewy, --,
   {{0xc5d5116d,0xc0490341,0x64411e62,0x6b850150}},	//   _міль, _יז_, scli, ithg,
   {{0x80b50081,0x3ea20149,0x628d009c,0x66d535ba}},	//   ুসন্, _rakt_, _dbao, _háko,
   {{0xceb400a7,0x273105db,0x3ea23e06,0x6d4d0381}},	//   hmət_, _kšno_, _sakt_, dpaa,
   {{0x61203e07,0x3ea23e08,0x7ce90092,0x273800de}},	//   völd, _pakt_, _görə, _vũng_,
   {{0xa3e2397e,0xee3f01cd,0x63ae0537,0x715a18d4}},	//   _नेट_, _snýr_, æbne, _крос_,
   {{0x6d4d2846,0xceb40092,0x2ca3009e,0x3ea22fe3}},	// [3340] gpaa, dmət_, _bajd_, _vakt_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeb9a3e09,0x3ea20f05,0x6d4d010a,0x00000000}},	//   рие_, _takt_, apaa, --,
   {{0x66dc3e0a,0x094a17e9,0xc9aa1d64,0xb4d606eb}},	//   _kéke, ачки_, ивее_, _सत्_,
   {{0x673a3e0b,0x00000000,0x00000000,0x00000000}},	//   _sutj, --, --, --,
   {{0xb50306ed,0x83fc0106,0x765d0088,0x6f160b6a}},	//   रकोप_, lađe, ðsyn, llyc,
   {{0xd6da2c3b,0xcb670012,0x00000000,0x00000000}},	//   ити_, _маре_, --, --,
   {{0x83fc02e6,0x758a3e0c,0xd5661ca5,0x00000000}},	//   nađe, асов_, отоп, --,
   {{0x6b600076,0x7c3901f9,0x66d5003e,0x7b2c0345}},	//   _fágá, _ábrá, _tákn, _oğuz,
   {{0x394903be,0x673a0052,0x00000000,0x00000000}},	//   íase_, _tutj, --, --,
   {{0xc7a60012,0x00000000,0x00000000,0x00000000}},	//   _фиек, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66d50897,0x64a61a53,0x16110ff9,0x00000000}},	//   _záko, _мада, _डुपर_, --,
   {{0x7ce90092,0x7ce00ba1,0x00000000,0x00000000}},	//   _törə, _hörf, --, --,
   {{0x7ce03e0d,0x40342ca4,0xceb40092,0xadc40032}},	//   _körf, дерс, ymət_, _ifẹs,
   {{0x66d50074,0x83fc1419,0x73081454,0x6d4d0abf}},	//   _nákl, gađe, _وقوف_, tpaa,
   {{0x3f9e003e,0xdce60233,0x67220350,0x00000000}},	// [3350] ætur_, _askı, _mhoj, --,
   {{0x2001023e,0x6d4d3e0e,0xfbab00ae,0x00000000}},	//   _txhi_, rpaa, итей_, --,
   {{0x6d4d3e0f,0x6b850124,0x6d403e10,0x309a00ca}},	//   spaa, uthg, _éman, _השתמ,
   {{0xb5fd02dd,0x6d4d0084,0x6b850178,0xdced02c8}},	//   laše, ppaa, rthg, mrač,
   {{0xdce703e0,0x31793e11,0xceb400a7,0x2ca30090}},	//   şlıc, nusz_, rmət_, _tajd_,
   {{0xe7393e12,0x67223e13,0x9d18008f,0xed560266}},	//   бек_, _ahoj, _моят_, _מבשר_,
   {{0x672220bb,0xd3780995,0x7b640110,0x00000000}},	//   _bhoj, juć_, _отте, --,
   {{0xadc40032,0x6f0d3e14,0x31793e15,0x6722007f}},	//   _afẹs, noac, kusz_, _choj,
   {{0xa2bf2a09,0xe5710037,0x80cc00b7,0x7ce0042c}},	//   षान्, رطة_, _सकले, _dörf,
   {{0x66d50871,0xdced0074,0x6f0d01af,0xb5fd0fa3}},	//   _zákl, krač, hoac, jaše,
   {{0x7ce00222,0xd3780106,0x6602063d,0x130a0b2f}},	//   _förf, guć_, _exok, йной_,
   {{0xf8bd0081,0xdced0087,0xbddb05aa,0x27210206}},	//   _অতিথ, drač, _afèm, fóne_,
   {{0x171a0130,0x14a6009d,0x67293e16,0x83fc0335}},	//   _פונע, _कोकण, mmej, vađe,
   {{0xb5fd02ef,0xdced0094,0x25af05db,0x6120042c}},	//   gaše, frač, _irgl_, wölb,
   {{0x24670103,0x6023235c,0x7ce03e17,0x63bc02c3}},	//   _című_, едра, _hörg, ärnt,
   {{0xee3a3e18,0x660f0364,0x00000000,0x00000000}},	//   сна_, ückw, --, --,
   {{0x83fc02e6,0x7ce03e19,0x6f1602c3,0x672900bc}},	// [3360] rađe, _jörg, rlyc, imej,
   {{0x83fc042d,0x7ce00088,0xdced00d4,0xb8860220}},	//   sađe, _mörg, brač, _kríž,
   {{0x6f0d0933,0x67290113,0x00000000,0x00000000}},	//   boac, kmej, --, --,
   {{0xdce40039,0x67293e1a,0x63ae0537,0x00000000}},	//   krić, jmej, åbni, --,
   {{0xdce400e7,0x7ae31030,0xd378007f,0xd91005bc}},	//   jrić, ënta, zuć_, نیر_,
   {{0xdce408a9,0x9c130174,0x2b58016d,0x00000000}},	//   drić, _bọdo, _twrc_, --,
   {{0xb8f43e1b,0x27210220,0xa09b0266,0xd90d0281}},	//   _हक_, zóne_, מיסט, جیل_,
   {{0xb8d31179,0x35b4008d,0xfaa33e1c,0xd3780234}},	//   _जो_, дбир, _пасо, vuć_,
   {{0x186a13c9,0xe9da007e,0x00000000,0x00000000}},	//   _гази_, _ука_, --, --,
   {{0x656f3e1d,0xb4d600a5,0x07a63e1e,0xc7a60686}},	//   ácha, ससे_, _назн, _низк,
   {{0x67223e1f,0x7b373360,0x224d0634,0x6f0d3e20}},	//   _thoj, _ućut, ñeko_, yoac,
   {{0x66020a00,0x7ce00212,0xd7ef0037,0xdced033b}},	//   _txok, _förg, _حكم_, vrač,
   {{0x7ce00149,0xaca40065,0xbcfb00b6,0x6f0d00ae}},	//   _körd, _awọs, _svém, voac,
   {{0x63bc0212,0x33580012,0x00000000,0x00000000}},	//   ärns, _дакэ_, --, --,
   {{0xbebb01e5,0xb5fd04fa,0x0f1b00e3,0x7ce00704}},	//   _dhën, raše, مغرب_, _mörd,
   {{0x59be1349,0x7ce00222,0x290e0139,0x80c102d5}},	//   ्हार, _lörd, hofa_, रॉजे,
   {{0xdd940138,0x00000000,0x00000000,0x00000000}},	// [3370] наты, --, --, --,
   {{0x81e60081,0xdced00e7,0xa1150037,0xbcfb0a7f}},	//   _বুক_, prač, _زوجت, _tvém,
   {{0x6ce4004d,0x6f0d3e21,0xc4d3021e,0x00000000}},	//   хіте, poac, עגע_, --,
   {{0x386c20bb,0x2ee000f0,0xdb230421,0xb5fd00c4}},	//   _addr_, chif_, روشی, našc,
   {{0x290e2f05,0x7ce0227a,0x00000000,0x00000000}},	//   fofa_, _börd, --, --,
   {{0x008a00c1,0x7ff4001c,0xdce4031a,0x00000000}},	//   ַרפֿ, _آسیا, vrić, --,
   {{0x7ce00491,0x917a00fe,0x9be40120,0x00000000}},	//   _dörd, _mất_, _зітк, --,
   {{0xdce42f54,0x3169020a,0x00000000,0x00000000}},	//   trić, _ovaz_, --, --,
   {{0x7ce03114,0x2d893e22,0x2a6d0131,0xf99000d1}},	//   _förd, ntae_, _ideb_, _مبل_,
   {{0x7ce008bb,0x67293e23,0xbddb0154,0x3ea93e24}},	//   _görd, smej, _afèk, hdat_,
   {{0xf7700f43,0x31693e25,0xb7d51850,0x00000000}},	//   _مان_, _avaz_, _تقاب, --,
   {{0xbebb01e5,0x25a90995,0xa2842c31,0x00000000}},	//   _shën, _šalu_, ریخو, --,
   {{0x7ce001bf,0x3ea90212,0x82360421,0x917a0023}},	//   _höre, ddat_, بردا, _bất_,
   {{0xbddb0154,0x224900b3,0xda2010e9,0x00000000}},	//   _efèk, _efak_, _बरसत_, --,
   {{0x25ad00aa,0x00000000,0x00000000,0x00000000}},	//   lvel_, --, --, --,
   {{0x394d00e7,0xef1a0426,0x3f6800a7,0xf41200ca}},	//   _otes_, іма_, rğu_, _שפה_,
   {{0xbebb00dd,0x394d006c,0x2d8900f9,0x25ad01cb}},	// [3380] _thën, _ntes_, gtae_, nvel_,
   {{0x2ee03e26,0x3ea601d3,0x62840154,0x66dc01dc}},	//   shif_, žot_, _hcio, _méka,
   {{0x4f260aeb,0x66dc030b,0x26dd0283,0x7ce002c3}},	//   _одоб, _léka, _olwo_, _rörd,
   {{0x657b007b,0xaca40af0,0x83fc2f54,0xd8380117}},	//   kuuh, _ifọr, nađa, _tačk_,
   {{0xd00f037f,0x290e3e27,0xe8942917,0xd9433e28}},	//   _ملی_, tofa_, еаль, вечи,
   {{0x83fc0106,0xd838007e,0x7ce00233,0x7e640271}},	//   hađa, _kači_, _böre, laip,
   {{0xd8382c0a,0x394d3e29,0xb9063e2a,0x778a00a7}},	//   _jači_, _etes_, _पत_, _təxm,
   {{0x7e641d66,0x356a007b,0x657b06b0,0x00000000}},	//   naip, орон_, fuuh, --,
   {{0x66dc0113,0xa5341b60,0xd49a044b,0x00000000}},	//   _céka, ннич, орн_, --,
   {{0x7ce00003,0x29180018,0x38cb0068,0xe0df0c56}},	//   _före, _óra_, _والی_, npòt_,
   {{0x7ce03e2b,0x7e643e2c,0x917a0023,0xc1c700d2}},	//   _göre, kaip, _rất_, रङ्ग,
   {{0x83fc02e6,0xeb9100c1,0x7ae23e2d,0x7e643e2e}},	//   gađa, אָך_, nhot, jaip,
   {{0x51843e2f,0xaca40065,0x6d44022e,0x660f0364}},	//   кура, _afọr, jqia, ückt,
   {{0x7ce00233,0x78a83e30,0x301503fc,0x00000000}},	//   _yöre, _jadv, едгр, --,
   {{0x83fc0039,0x3ea90a9f,0xb5fd0106,0x644a0078}},	//   bađa, tdat_, maša, _iffi,
   {{0xb5fd0a9e,0x62840037,0x2249026a,0x6e9400d3}},	//   laša, _gcio, _ufak_, кису,
   {{0x78ba1db2,0x3ea93e31,0x7ae203a9,0xd838007e}},	// [3390] _ontv, rdat_, dhot, _dači_,
   {{0x78a83e32,0xb9120174,0x00000000,0x00000000}},	//   _nadv, rinụ_, --, --,
   {{0x3a751e46,0x394d00b3,0x00000000,0x00000000}},	//   елер, _stes_, --, --,
   {{0x7ce00149,0x628f0451,0x7ae20167,0xdbdc01cd}},	//   _röre, nfco, ghot, ráða,
   {{0x644a3e33,0x672d0220,0x7ce03e34,0x2721003e}},	//   _offi, ňajk, _söre, jóna_,
   {{0x8d5a028c,0x66dc0d7f,0x443c345f,0xf7710037}},	//   _מכשי, _réka, _ngv_, هاب_,
   {{0x7ce0070a,0x7ae23e35,0x629d3e36,0xfd640129}},	//   _förb, bhot, keso, karị,
   {{0x644a3e37,0x7ae2015b,0xbcfb030b,0xdb070088}},	//   _affi, chot, _svéh, _frjá,
   {{0x91ee0789,0x25ad3e38,0x00000000,0x00000000}},	//   _चेंज_, uvel_, --, --,
   {{0x62843e39,0x25ad3e3a,0x7ce03e3b,0x443c00fd}},	//   _scio, rvel_, _töre, _cgv_,
   {{0x6abb3e3c,0x39893e3d,0x9475001c,0x2af300aa}},	//   _knuf, lús_, ودگا, _आगाँ_,
   {{0x629d3e3e,0x644a3e3f,0x660f01bf,0x78a800c4}},	//   geso, _effi, ücks, _zadv,
   {{0xa4d502ec,0x39893e40,0x443c3e41,0x83fc015c}},	//   _поді, nús_, _fgv_, rađa,
   {{0x628b0149,0x83fc33db,0xbebb023b,0x64a237f2}},	//   _ögon, sađa, _dhëm, _баша,
   {{0x629d3e42,0x39893e43,0x6d4f3e44,0xfd640174}},	//   beso, hús_, _atca, barị,
   {{0x629d3e45,0xbea30284,0x62840a39,0x76490233}},	//   ceso, ласк, _ucio, ncey,
   {{0x7e643e46,0x1d262a61,0xbddb0113,0x55890847}},	// [33a0] raip, емам, _ngèd, _çığı,
   {{0x6d440063,0x3157006e,0x67390090,0x6abb030a}},	//   rqia, _ריין_, _liwj, _anuf,
   {{0x7ae23e47,0x7e643e48,0x2721374a,0xd838049c}},	//   thot, paip, zóna_, _tači_,
   {{0xca261e79,0x69c20634,0xb21b01cd,0x6aa903a8}},	//   нфли, txoe, mfær, _caef,
   {{0x7ae23e49,0xb21b34da,0x78a83e4a,0x00000000}},	//   rhot, lfær, _padv, --,
   {{0x97a63e4b,0x7ae23e4c,0x3d1800bc,0x00000000}},	//   ерил, shot, _बीचे_, --,
   {{0x7a3635f8,0x7ae23e4d,0x629d00dd,0xf76f0286}},	//   _bütü, phot, yeso, ماي_,
   {{0xdb0701cd,0x656902db,0x00000000,0x00000000}},	//   _trjá, fseh, --, --,
   {{0x948600ae,0x8cc402d5,0x1a9b006e,0x2a6600f9}},	//   нынд, रापो, _צימע, maob_,
   {{0xdce40039,0x629d3e4e,0x00000000,0x00000000}},	//   ksič, weso, --, --,
   {{0xb5fd3e4f,0x629d3e50,0xbebb0052,0x6ee300aa}},	//   raša, teso, _shëm, _hõbe,
   {{0xb5fd0039,0x1db20096,0x15eb007a,0x925800c2}},	//   mašn, ीमात, _जेकर_, нают_,
   {{0xb5fd0580,0x25a000e5,0x443c145c,0x00000000}},	//   lašn, _èil_, _tgv_, --,
   {{0x644a3e51,0x00000000,0x00000000,0x00000000}},	//   _uffi, --, --, --,
   {{0x629d3e52,0xfd640129,0x61203e53,0x70d100aa}},	//   peso, parị, möll, _सकील,
   {{0x629d0052,0x612000c2,0x539b00ca,0x7bc101b9}},	//   qeso, löll, _זיהו, _àlui,
   {{0xb27400c2,0x781d1024,0x00000000,0x00000000}},	// [33b0] _слыш, _फर्क_, --, --,
   {{0xb5fd0995,0x6abb01d0,0x6aa90167,0x612000c2}},	//   kašn, _snuf, _saef, nöll,
   {{0xb5fd03ce,0xf09200ca,0x9f4b007b,0xe0df00b3}},	//   jašn, _דני_, ömät_, spòs_,
   {{0xb5fd00e9,0xf41300c1,0xd8380995,0x61203e54}},	//   dašn, אפע_, _jaču_, höll,
   {{0x61203e55,0x6d4f0103,0x00000000,0x00000000}},	//   köll, _utca, --, --,
   {{0x2d993e56,0x66d5003e,0x6aa90a4b,0x2be10179}},	//   _ipse_, _jákv, _waef, पनदा,
   {{0x39891d32,0x66e50915,0x3f4709a1,0x00000000}},	//   sús_, кока, _jõu_, --,
   {{0x65693e57,0x66dc03a9,0x6abb0350,0x00000000}},	//   tseh, _déko, _unuf, --,
   {{0x06091b60,0xd3780034,0xd6ce0037,0x66dc03a9}},	//   ьник_, erć_, تقي_, _tékn,
   {{0x8cc409c3,0x656901bf,0x66d5003e,0x7b2c020a}},	//   रायो, rseh, _nákv, _uşur,
   {{0x65692a0d,0x25a6022b,0x2d990167,0xd838007e}},	//   sseh, _esol_, _lpse_, _baču_,
   {{0x05210081,0x7c3a01cd,0x614600ae,0x6d590174}},	//   নদের_, _útre, кема, ̣waa,
   {{0xe7300241,0x3329008c,0x00000000,0x00000000}},	//   _اصل_, _dhax_, --, --,
   {{0x6d403e58,0xfd6600de,0xb21b3e59,0x20d40f06}},	//   _émai, _thuầ, tfær, _näit_,
   {{0x2d993e5a,0x26cf3e5b,0x6f630161,0x00000000}},	//   _apse_, _kogo_, иврз, --,
   {{0xf7720130,0x26cf00c9,0xb21b3e5c,0x33290078}},	//   יקל_, _jogo_, rfær, _ghax_,
   {{0x26cf015c,0xb21b01df,0xbedc0139,0x8c463671}},	// [33c0] _mogo_, lgæn, _aṣàw, везе,
   {{0x317b0089,0xb21b0088,0x81160103,0xe0580103}},	//   _קרימ, pfær, _جذبا, _سیرت_,
   {{0x3eab00a1,0xd00a3612,0x6ee300aa,0x2a660270}},	//   _fact_, _цене_, _sõbe, taob_,
   {{0x68e10149,0x290502ef,0x26cf033b,0x66dc3e5d}},	//   _alld, _ajla_, _nogo_, _réko,
   {{0x66dc03a9,0x62960172,0x66e80139,0x00000000}},	//   _dékl, _mbyo, _lèkù, --,
   {{0x3ea03e5e,0x7ce00149,0x3f9a0167,0xbcfb0139}},	//   leit_, _föra, _kppu_, _ewéb,
   {{0x7ce00149,0x26cf3e5f,0xa3c30363,0x2d80020a}},	//   _göra, _bogo_, yšší_, luie_,
   {{0x81e800c7,0xeb0d0d88,0x3ea001ec,0x20d400aa}},	//   _যখন_, िकृत_, neit_, _käis_,
   {{0x66d50074,0xd9461f0d,0x26cf2b5b,0x2d803e60}},	//   _náku, _рези, _dogo_, nuie_,
   {{0x3ea03e61,0x70d105a7,0x80d10034,0x22400063}},	//   heit_, _सकेल, _सकें, _agik_,
   {{0x3ea002e2,0x26cf02a8,0x83fc2c57,0x6296010a}},	//   keit_, _fogo_, rađo, _bbyo,
   {{0x26cf3e62,0x6120007b,0x8cc419af,0x00000000}},	//   _gogo_, söll, राडो, --,
   {{0x3944359d,0xdb210068,0x316d0257,0x2a640167}},	//   _jums_, ítés, éez_, _memb_,
   {{0x3944359d,0xab653e63,0x104b00c2,0x62960283}},	//   _mums_, ngüí, ьями_, _ebyo,
   {{0xd8380029,0x6018036a,0xdb0e0231,0x645a0350}},	//   _taču_, воря_, _arbí, mbti,
   {{0x26cf08a8,0x7ce03e64,0x2a640113,0x386701c2}},	//   _xogo_, _röra, _nemb_, zanr_,
   {{0x1df82787,0x9f3400f3,0xa4a60032,0x2d80010a}},	// [33d0] веты_, реті, _gbòò, guie_,
   {{0x09be00c3,0x00000000,0x00000000,0x00000000}},	//   ्हैय, --, --, --,
   {{0x3ea002e2,0x66d50146,0x645a3e65,0x644f007f}},	//   beit_, _záku, ibti, ścig,
   {{0x2d800a29,0xeb0d0096,0x7b180072,0x39440a84}},	//   buie_, िकेत_, díus, _bums_,
   {{0xadf002e8,0x26cf3e66,0xeab0071c,0xddcd007f}},	//   _घेऊन_, _rogo_, تعل_, ngaż,
   {{0x9b450391,0x7ce009b5,0x8cc4007f,0x53c20285}},	//   _منسو, _hörn, राणो, षमाश,
   {{0x7ce00068,0x26cf3b03,0x61200212,0x0b8800f6}},	//   _körn, _pogo_, följ, _исти_,
   {{0xbb840080,0x394400ee,0x05a9004d,0x00000000}},	//   _خلفي, _fums_, евий_, --,
   {{0xeb1f0096,0x04451165,0xb5fd3e67,0x88830018}},	//   बतीत_, лепн, rašo, _نیشن,
   {{0x3ea002e2,0x645e007a,0x68e13e68,0x70d21024}},	//   zeit_, _õpil, _ulld, _हवेल,
   {{0x69d9185a,0x7b180072,0xdce401d3,0x3ea001f9}},	//   lywe, cíus, nsiā, yeit_,
   {{0x799b0174,0x645a3e69,0xe1ff3e6a,0xb21b0537}},	//   _kpuw, abti, raón_, rgæn,
   {{0x69d93e6b,0x765b0193,0x3ea03e6c,0xcb120266}},	//   nywe, mbuy, veit_, מלט_,
   {{0x3ea002e2,0x657b0239,0x61430ad8,0x00000000}},	//   weit_, mruh, сера, --,
   {{0x3ea01db2,0xdee6336f,0xba200455,0x7ce00088}},	//   teit_, гови, _बर्फ_, _börn,
   {{0xeabe0081,0x7e55355b,0x2d803e6d,0xceb40092}},	//   _আত্ম, итуц, tuie_, lməz_,
   {{0x3ea03e6e,0xb21b052f,0x5185001f,0x00000000}},	// [33e0] reit_, ngæl, _куќа, --,
   {{0x3f9a0167,0x69d93e6f,0x44273e70,0x2d803e71}},	//   _tppu_, dywe, _kzn_, ruie_,
   {{0x7ce00149,0x78ae0161,0x2d803e72,0x28c70861}},	//   _förn, _óbvi, suie_, लानि,
   {{0x62863e73,0x657b3e74,0x298a1f3e,0x20d400aa}},	//   ngko, kruh, еско_, _täis_,
   {{0xf54800ef,0xceb30341,0x442700e7,0x645a0188}},	//   _mục_, _פיש_, _lzn_, ybti,
   {{0x6f043e75,0xf5480019,0x657b1054,0xb5fd3e76}},	//   lnic, _lục_, druh, rašl,
   {{0x6f042392,0x6d463e77,0xebe63e78,0x69d9010a}},	//   onic, _huka, _совп, aywe,
   {{0x6f043e79,0x6d463e7a,0xa3c900a3,0x39441ee2}},	//   nnic, _kuka, ोहन_, _tums_,
   {{0x442701d4,0x1a063e7b,0x6f043e7c,0x634802c6}},	//   _azn_, _спам, inic, _pěno,
   {{0x6d463e7d,0x6f043e7e,0x44f400d6,0x6aa23e7f}},	//   _muka, hnic, рпос, leof,
   {{0xd4970fdf,0x6d463e80,0x92593e81,0x6f040357}},	//   уры_, _luka, кант_, knic,
   {{0xf5480019,0x51870752,0x6aa22514,0x657b0117}},	//   _cục_, луга, neof, bruh,
   {{0x6f042188,0xf5480028,0x7ae3029a,0x76420169}},	//   dnic, _dục_, ënti, _igoy,
   {{0x6f043e82,0x28c7152c,0x6562039f,0x00000000}},	//   enic, लायि, _iwoh, --,
   {{0xc4f70089,0x6f0401af,0x6d4623ff,0x4035107a}},	//   _תמוז_, fnic, _auka, ревс,
   {{0x6d463e83,0xf5480023,0xdce40a39,0x656205bd}},	//   _buka, _gục_, driđ, _kwoh,
   {{0x644f00a5,0x6d4608d3,0x70550068,0xbddb0139}},	// [33f0] ście, _cuka, _پنجا, _afèr,
   {{0x6d463e84,0xeb0d022d,0x6f04028d,0x3e7b0af0}},	//   _duka, िक्त_, anic, _bàtà_,
   {{0x6d463e85,0xfff900d0,0x6e953e86,0x7f591eac}},	//   _euka, _شکست_, _кину, _шанс_,
   {{0xdced0039,0x7ce00212,0x3f83001c,0x76423e87}},	//   krać, _föro, muju_, _ngoy,
   {{0xaca30174,0x09d80081,0x6d46392d,0x7ce03e88}},	//   _agục, _দেবা, _guka, _körl,
   {{0x26181161,0x02e20b7f,0xd36615ae,0x69d90665}},	//   _पड़ी_, _पत्न, _وه_, rywe,
   {{0x3f831084,0x6d460044,0x3f9101e9,0x65623e89}},	//   nuju_, _zuka, ntzu_, _awoh,
   {{0x6d4601e8,0x2b4d02c6,0x657b3e8a,0x65620079}},	//   _yuka, _čech_, truh, _bwoh,
   {{0xdced0095,0xc9870859,0xbcfb02c6,0xf548020b}},	//   grać, _љуби, _uvés, _rục_,
   {{0x3f8308a9,0x81cb0081,0xb4650848,0x63b8374d}},	//   kuju_, লনা_, школ, _brvn,
   {{0x3f8302e6,0x78a33e8b,0x02c62777,0x657b3e8c}},	//   juju_, menv, айно, sruh,
   {{0xdced215e,0x3f8304a3,0x63b800cb,0x657b08ac}},	//   brać, duju_, _drvn, pruh,
   {{0x62863e8d,0x41a7246d,0x78c40103,0x614602f3}},	//   rgko, авян_, _átvé, рега,
   {{0x6d463e8e,0x6f040067,0x412a08d1,0x44273e8f}},	//   _ruka, wnic, того_, _tzn_,
   {{0xf5480028,0x527609f2,0x3f8301ac,0x7e663e90}},	//   _tục_, _купу, guju_, _pekp,
   {{0xb5fd04fa,0xdb0e3e91,0x66d50146,0x78a33e92}},	//   jašk, _orbá, _zákr, henv,

   {{0x7ce00222,0xee3a1d7b,0x5d6a3e93,0x78a3354c}},	// [3400] _förl, тна_, тизм_, kenv,
   {{0x6f040d95,0x6d46042d,0xccc300c2,0x3f831177}},	//   snic, _vuka, обуй, buju_,
   {{0x3f8304a3,0x307b00a1,0x6f043e94,0x6d460022}},	//   cuju_, _באינ, pnic, _wuka,
   {{0xe9da1894,0x41b312eb,0x2ee93e95,0xf5480023}},	//   кке_, _امیر, chaf_, _lụa_,
   {{0x26cd00cc,0x7ce03e96,0x6aa22514,0x64430034}},	//   djeo_, _hörm, reof, _ogni,
   {{0xdced0039,0x78a33e97,0x6aa20076,0x307a006e}},	//   vrać, genv, seof, דאַנ,
   {{0xe3a70979,0x96f81cf2,0xb5fd0234,0xf6e605da}},	//   _بر_, лект_, bašk, ицин,
   {{0xd6d700c2,0x64433e98,0xe72f0452,0xdced031a}},	//   иты_, _agni, وصي_, trać,
   {{0x3f8303ce,0x645e00bc,0x78a33e99,0x7ae30231}},	//   zuju_, _õpik, benv, ênte,
   {{0x63b8000d,0x83fc0106,0x0d9700ca,0x3eb2007b}},	//   _prvn, lađi, סכים_, hdyt_,
   {{0x66e60b73,0x7ce00212,0xbddb01dc,0x00000000}},	//   _кожа, _rörl, _ngèn, --,
   {{0x83fc0039,0xdced08a9,0x3f830e94,0x32673e9a}},	//   nađi, prać, vuju_, штов,
   {{0xbddb3e9b,0xf8da009f,0xe4e600d6,0x7d1c0094}},	//   _agèn, _बकाय, _війн, _okrs,
   {{0x3f8329cb,0x3d100034,0x00000000,0x00000000}},	//   tuju_, ़कों_, --, --,
   {{0x438400e3,0x2ee902ad,0x533510e8,0x644f00a5}},	//   _العق, thaf_, _лект, ścic,
   {{0x2fcd02e6,0x643b00d7,0x2d9202ac,0x3f9101c8}},	//   ćeg_, _בעונ, ftye_, rtzu_,
   {{0x3f8304a3,0xb5fd02dd,0x7ce00103,0x78a33e9c}},	// [3410] suju_, vašk, _törl, yenv,
   {{0x7ce00222,0x3f830039,0xfd10071c,0xa2bf0179}},	//   _förm, puju_, وجل_, षाक्,
   {{0x7ce00702,0xb5fd3e9d,0x78a33e9e,0x01340037}},	//   _görm, tašk, venv, _بعيد,
   {{0x83fc1197,0x00000000,0x00000000,0x00000000}},	//   gađi, --, --, --,
   {{0x78a33e9f,0x26cd00e7,0x00000000,0x00000000}},	//   tenv, vjeo_, --, --,
   {{0x315800a1,0xac191502,0x7e6d01d0,0x612000ce}},	//   סיון_, _богу_, laap, töli,
   {{0x3a871736,0x4878116d,0xb5fd0995,0x78a33ea0}},	//   _вызв, рсія_, maši, renv,
   {{0x78a32e84,0xb5fd1419,0xfc4a0037,0xa3ba034c}},	//   senv, laši, _tríú_, घिन_,
   {{0x6d4d0188,0x78a33ea1,0x25b93ea2,0x00000000}},	//   nqaa, penv, ísl_, --,
   {{0x7e6d3ea3,0xb5fd3ea4,0x6444026a,0x26cd04e9}},	//   haap, naši, _şiir, sjeo_,
   {{0x7ce0070a,0x7e6d3ea5,0x26cd00e7,0xc2c60037}},	//   _börj, kaap, pjeo_, ميدي,
   {{0xc0490089,0x4735086a,0x778a013c,0x00000000}},	//   _טז_, _унес, _təxr, --,
   {{0xb5fd031a,0x29073bf8,0x7ce00212,0x6353044c}},	//   kaši, onna_, _sörm, _sănd,
   {{0x64430138,0x270c00b6,0x2ee000d2,0xb5fd2f54}},	//   _ugni, měna_, नस्त, jaši,
   {{0xa355177a,0x1fb53ea6,0x29073ea7,0x6353020a}},	//   _اختص, остр, inna_, _băne,
   {{0xe9ff0019,0x70160c9c,0xf54800de,0x630600cd}},	//   _ngắn_, _दुःख_, _mụn_, _دوبل,
   {{0xb5fd0106,0x270c02c6,0x00000000,0x00000000}},	// [3420] faši, něna_, --, --,
   {{0xad9b0072,0xee373ea8,0x7ce000c2,0x2d92057a}},	//   _axús, сну_, _törm, rtye_,
   {{0x3ea6017b,0xaf0a006f,0x7d1c00c4,0x6d4d041c}},	//   _линг, _مقدم_, _vkrs, aqaa,
   {{0x7ce01b8d,0x29073ea9,0x26180096,0x8f9b2252}},	//   _körk, enna_, _पडली_, _גיטי,
   {{0x83fc005f,0xb5fd0fa3,0xceb40092,0xdce40034}},	//   rađi, baši, mdə_, esią,
   {{0x7ce00cec,0xceb40092,0x83fc042d,0x7d1c0e94}},	//   _mörk, ldə_, sađi, _ukrs,
   {{0x6ecc1d69,0xd83805db,0x69cf0231,0x00000000}},	//   हापु, _obče_, _àcen, --,
   {{0xceb4025c,0x2907054f,0x973c0ea3,0x2d803eaa}},	//   ndə_, anna_, _opće, orie_,
   {{0xceb300a1,0x2cb101c2,0x2d80037a,0x1dc812f2}},	//   ליה_, _yazd_, nrie_, रमित,
   {{0x628d00e3,0x2d803eab,0x92c50081,0x33742cd8}},	//   _scao, irie_, _এতে_, огор,
   {{0xceb401d4,0x53353eac,0x3cf00034,0xd6cf116a}},	//   kdə_, жент, _इतने_, _ет_,
   {{0x2d80171d,0x1dc81e05,0x00000000,0x00000000}},	//   krie_, रमात, --, --,
   {{0x656f00e3,0x7e6d0dd8,0x644f00a5,0xceb40092}},	//   ácht, vaap, ścia, ddə_,
   {{0x1c0800aa,0x7e6d3620,0x00000000,0x00000000}},	//   वपाल_, waap, --, --,
   {{0xb5fd3ead,0x7ae23eae,0x2d803eaf,0xceb4013c}},	//   vaši, kkot, erie_, fdə_,
   {{0x7ce00222,0x3f7308a9,0x25ec009f,0x2d8001df}},	//   _förk, rću_, आईपी_, frie_,
   {{0x29073eb0,0x7ce00828,0xb5fd0335,0x7e6d3eb1}},	// [3430] ynna_, _görk, taši, raap,
   {{0x5c750077,0x9c47061b,0x6d4d008c,0x61150120}},	//   ілет, схал, rqaa, _єдну,
   {{0x2d803eb2,0x28c70179,0x7e6d3eb3,0xfb84013f}},	//   arie_, लासि, paap, зычн,
   {{0x2d80002d,0x291e3eb4,0x7ae20167,0x271200aa}},	//   brie_, _akta_, gkot, डकोर_,
   {{0xb5fd0b14,0x60d701ff,0xf54800fe,0x2d80044c}},	//   paši, _koxm, _sụn_, crie_,
   {{0xb4d7007d,0x6eea0181,0xfe730018,0x92c50033}},	//   _सवे_, _výbe, _بدھ_, _এতো_,
   {{0x60dc0089,0x2aa00154,0xddc40138,0x28da152c}},	//   רקונ, _bčbč_, maiš, _बकरि,
   {{0xba7703ed,0xe5790aeb,0x83fc0106,0x290c007e}},	//   _داست, ази_, nađu, _ejda_,
   {{0x7ae90b88,0x7afb3eb5,0x00000000,0x00000000}},	//   _ilet, _imut, --, --,
   {{0xceb40092,0xdced080e,0xbddb03a9,0x69c600c4}},	//   zdə_, ksač, _ngèm, _škeg,
   {{0x7ae93eb6,0x130a0084,0xceb400a7,0x33f5004d}},	//   _klet, иной_, ydə_, ючис,
   {{0xdb1c025a,0x7afb00bd,0xceb4013c,0x92f60120}},	//   _arrê, _jmut, xdə_, ічні,
   {{0x7ce00222,0x7afb3eb7,0x635300ae,0x25a9028d}},	//   _förh, _mmut, _bănc, _èal_,
   {{0x7ae93eb8,0x7ae22d07,0xa0672156,0x66dc0139}},	//   _llet, zkot, жара_, _déku,
   {{0x48e13b30,0x7ae90d80,0xceb40092,0x7afb0a15}},	//   _कवनो_, _olet, tdə_, _omut,
   {{0xbebb01e5,0x2d803eb9,0x7ce0007b,0x83fc00cc}},	//   _shër, trie_, _törk, gađu,
   {{0xceb40253,0x163600c1,0x2c260033,0x2d80014b}},	// [3440] rdə_, ַנער_, _বলেই_, urie_,
   {{0x2d803eba,0xd83e0146,0x7afb3ebb,0xdd8f0604}},	//   rrie_, íčka_, _amut, ئول_,
   {{0xa09b00c1,0x7ae93ebc,0xb5fd0995,0x27213ebd}},	//   _דייט, _blet, mašu, lónu_,
   {{0x2d803ebe,0xb5fd0087,0xdce40335,0x639a006e}},	//   prie_, lašu, ksić, יסענ,
   {{0xdb210018,0xbebb023b,0x7ae905db,0x69cf014b}},	//   ítás, _thër, _dlet, _àcel,
   {{0x7ae93ebf,0x3a2d0b18,0x7afb3ec0,0xb5fd0138}},	//   _elet, _dzep_, _emut, našu,
   {{0x7ae93ec1,0xd90d0688,0x3f68013c,0x00000000}},	//   _flet, دیل_, nşu_, --,
   {{0x7c2e3ec2,0x00000000,0x00000000,0x00000000}},	//   _izbr, --, --, --,
   {{0x29000161,0xe4a61087,0xc8960284,0x9f9f014b}},	//   éias_, орно, _мржњ, réée_,
   {{0x07a63ec3,0x79820ee8,0xb5fd007e,0xb4e43ec4}},	//   _мазн, mrow, jašu, नसे_,
   {{0xd6da00cd,0xb6cc0555,0x66dc03a9,0x28c700c3}},	//   _پوشش_, çüsü, _séku, लारि,
   {{0x7c2e0167,0xfc4600b6,0x27210031,0x61200103}},	//   _mzbr, šího_, fónu_, zölt,
   {{0xc6491823,0x26c6008a,0x00000000,0x00000000}},	//   _اجمل_, _inoo_, --, --,
   {{0x3a2400f9,0x7c2e0094,0xbcfb0065,0x7ce009a8}},	//   _mymp_, _ozbr, _ewéj, _föri,
   {{0x291c00d3,0x270c02c6,0x386c00eb,0x00000000}},	//   iova_, něno_, _medr_, --,
   {{0x291c3ec5,0xa3c91179,0x79823ec6,0x9f050037}},	//   hova_, ोहर_, krow, أورو,
   {{0x61200068,0x83fc02e6,0xdd94013f,0x3d943715}},	// [3450] tölt, rađu, маты, митр,
   {{0x7ae91484,0xb5fd04a3,0x613202b6,0x79820034}},	//   _slet, mašt, gæld, drow,
   {{0xf092004f,0xb5fd03ce,0x22490167,0xddc40138}},	//   _אני_, lašt, _kgak_, raiš,
   {{0x26c60174,0x79820034,0x224900dc,0x00000000}},	//   _nnoo_, frow, _jgak_, --,
   {{0x386c02ef,0x79823ec7,0x7ae900d8,0x00000000}},	//   _bedr_, grow, _vlet, --,
   {{0x3ea93ec8,0xe8f816dd,0xf54800de,0x4dda00ca}},	//   leat_, олі_, _cụm_, _החשו,
   {{0xf77100e3,0x98a200d6,0x27210146,0x7ae90078}},	//   ءات_, хище, zónu_, _tlet,
   {{0x7afb092f,0x2249100b,0xdce400a5,0xf1cb3ec9}},	//   _umut, _ngak_, dsię, ामान,
   {{0x291c1419,0xe81b0835,0xb5fd02ef,0xdce4007f}},	//   bova_, _पुरा_, jašt, esię,
   {{0x224906ee,0x291c3eca,0xceb400a7,0x3ea93ecb}},	//   _agak_, cova_, llət_, heat_,
   {{0x644f00a5,0x2a6d006c,0x3ea9007b,0x394d2b18}},	//   ścio, _keeb_, keat_, _hues_,
   {{0x21210167,0x27210031,0xe29a20f8,0x394521ad}},	//   _akhh_, tónu_, щам_, _hils_,
   {{0x2a6d023e,0x21330023,0x3ea90dd8,0x00000000}},	//   _meeb_, _bhxh_, deat_, --,
   {{0xd47900c1,0x2a6d0a86,0x55ba00ca,0xa7fc0342}},	//   _האַל, _leeb_, _למנו, _adıy,
   {{0xa3cc0782,0xb5fd389a,0xe016121d,0x20130072}},	//   रमण_, rašu, _दुखद_, _cxxi_,
   {{0x2a6d006c,0xc7b200c1,0x20050428,0x27213ecc}},	//   _neeb_, עבן_, úlia_, pónu_,
   {{0x6da322ee,0x0d860077,0x25ad3ecd,0x394d3ece}},	// [3460] нита, ялан, nwel_, _nues_,
   {{0x394533f1,0xdb1c00fd,0x6d230291,0xd7bd280b}},	//   _nils_, _irré, едуз, ्माच,
   {{0x613201c5,0xeb9a2ce9,0x6ecc030b,0x7ac6008f}},	//   ræld, сие_, हादु, зсле,
   {{0x2a6d01bb,0x3ea90090,0x3f8a019c,0x79820034}},	//   _ceeb_, ceat_, mubu_, trow,
   {{0x25ad0126,0x3f983ecf,0x27210072,0x3f8a3ed0}},	//   jwel_, ltru_, hóns_, lubu_,
   {{0x394d0990,0xd90d09e5,0xdb070088,0xed573daf}},	//   _dues_, لیق_, _brjó, _хор_,
   {{0x3f98016a,0x2a6d006c,0x7c2e3ed1,0x386c3229}},	//   ntru_, _feeb_, _uzbr, _vedr_,
   {{0x291c3ed2,0x798200a5,0x7d1e0149,0x4ad00be4}},	//   sova_, prow, lops, _सचिव,
   {{0x291c042d,0x39453ed3,0xa53423b8,0x994a109d}},	//   pova_, _fils_, мнич, _طلال_,
   {{0x3f8a3ed4,0xb5fd14f3,0x27210072,0x69c00120}},	//   kubu_, vašt, fóns_, _irme,
   {{0x7ce0070a,0x2a6d0197,0xf8b30089,0x27210042}},	//   _förv, _yeeb_, _רשע_, góns_,
   {{0x2a6d01bb,0xdb0e015e,0x69c00d94,0xb5fd0559}},	//   _xeeb_, _arbú, _krme, tašt,
   {{0x37ae0081,0x67223ed5,0x41c40fe9,0x00000000}},	//   _কপির, _ikoj, нёра, --,
   {{0xa63b00a1,0xb5fd1056,0x2347001c,0x7d1e00e7}},	//   _הגדר, rašt, _کليپ_, jops,
   {{0x7d1e0479,0x2721002b,0x672206b0,0x37de0033}},	//   dops, cóns_, _kkoj, _ভেতর,
   {{0xdb150042,0xb5fd0fa3,0x7bc100c6,0x00000000}},	//   _orzá, pašt, _šluo, --,
   {{0xceb401d4,0x634802c6,0x3ea93ed6,0x67220a4b}},	// [3470] vlət_, _věnu, reat_, _mkoj,
   {{0x6eea025b,0x3ea93ed7,0x2a6d01fa,0x394d00fd}},	//   _výba, seat_, _seeb_, _rues_,
   {{0x2a6d023e,0x3ea93ed8,0x3f98078e,0x00000000}},	//   _peeb_, peat_, ctru_, --,
   {{0x394d14e2,0x628f0060,0x2a6d3ed9,0x39453eda}},	//   _pues_, ngco, _qeeb_, _sils_,
   {{0x272122e7,0x6f0d3edb,0x394d3edc,0x394501d3}},	//   zóns_, mnac, _ques_, _pils_,
   {{0xa3cc033a,0xa3be000d,0x394d025a,0x47593edd}},	//   रमा_, ीमा_, _vues_, ория_,
   {{0x2a6d3ede,0xceb40092,0x25ad02a1,0xbcfb0065}},	//   _teeb_, mlər_, wwel_, _atég,
   {{0x6d473edf,0x645801c5,0xceb40092,0x6d4f3ee0}},	//   _hija, _afvi, llər_, _kuca,
   {{0x6d4f002d,0x6d473ee1,0xa2d100a8,0x69c03af2}},	//   _juca, _kija, धान्, _grme,
   {{0x7ce01d10,0x6d4f008a,0xceb401d4,0x6f0d3ee2}},	//   _föru, _muca, nlər_, hnac,
   {{0x6d4f3ee3,0x7ce00018,0xd90c0281,0x6f0d13c5}},	//   _luca, _törv, _دیو_, knac,
   {{0x6d5d3ee4,0x272103be,0xdced0491,0x6f0d3ee5}},	//   _otsa, róns_, yrağ, jnac,
   {{0x2360005f,0xceb401d4,0x6d5d006c,0x6d4f3ee6}},	//   _čije_, klər_, _ntsa, _nuca,
   {{0x6d473ee7,0x67293ee8,0x3f980078,0x6f0d3ee9}},	//   _nija, llej, ttru_, enac,
   {{0x6d5d3eea,0x614308b4,0xceb40092,0x6d4f084e}},	//   _atsa, тера, dlər_, _auca,
   {{0x6d4f3eeb,0x6f0d3eec,0xdced00c4,0xbfc300e5}},	//   _buca, gnac, drađ, ъбск,
   {{0x442702e0,0x3f983eed,0x6d47125d,0xddcd07aa}},	// [3480] _hyn_, stru_, _bija, rbaş,
   {{0x3e6c00ef,0x6d4f3eee,0x6f0d3eef,0x6e2b02e2}},	//   ết_, _duca, anac, ügba,
   {{0xdced02e6,0x6d473ef0,0x7d1e1a36,0x6d4f3ef1}},	//   građ, _dija, rops, _euca,
   {{0x442717a7,0x673b00a5,0x7d1e26d2,0xdced026a}},	//   _myn_, jmuj, sops, prağ,
   {{0xceb401d4,0x6d473ef2,0x4427286f,0x67293ef3}},	//   blər_, _fija, _lyn_, dlej,
   {{0x6f040350,0x764b083e,0xdced042d,0x76590313}},	//   liic, _aggy, brađ, _afwy,
   {{0x67290890,0xb8d60ef8,0x6288013f,0x44273ef4}},	//   flej, _जस_, ėdoj, _nyn_,
   {{0xd6d00080,0x67290087,0x2cb83199,0x6d4f0314}},	//   اقة_, glej, _hard_, _yuca,
   {{0x9f453ef5,0x948600ae,0x7ce00222,0x2cb83ef6}},	//   álé_, мынд, _fört, _kard_,
   {{0x6f0d00a5,0x764b0517,0x2cb8007e,0x44273ef7}},	//   znac, _eggy, _jard_, _byn_,
   {{0x442702ad,0x6ef101c5,0x2cb80078,0x7ce00f3a}},	//   _cyn_, _håbe, _mard_, _hörs,
   {{0x44270150,0x96633ef8,0x2d4d015c,0xceb40092}},	//   _dyn_, _акце, _užeg_, zlər_,
   {{0xdced0995,0xceb400a7,0x290e028d,0x66d500d4}},	//   zrađ, ylər_, onfa_, _náky,
   {{0x44273ef9,0x6d4f1ee5,0x6ef10537,0x34942569}},	//   _fyn_, _ruca, _måbe, _чакр,
   {{0x6d473efa,0x44273efb,0xe8df0023,0x6f040188}},	//   _rija, _gyn_, _cuộn_, fiic,
   {{0x6d473efc,0x6d4f00e9,0x2cb80a9f,0x7cf23efd}},	//   _sija, _puca, _aard_, _lærd,
   {{0xceb40092,0x9df9261f,0x5067008f,0x44273efe}},	// [3490] tlər_, чнат_, _отна, _zyn_,
   {{0x6f0d3eff,0x2cb83f00,0x798b0193,0xf54800de}},	//   snac, _card_, vugw, _bụi_,
   {{0xceb40253,0x6d473f01,0x67200dd9,0x673b0034}},	//   rlər_, _vija, komj, ymuj,
   {{0x7ce03f02,0x6d471bdf,0xceb40092,0x7e7d02b6}},	//   _börs, _wija, slər_, _udsp,
   {{0xa969021c,0x6d5d0ec9,0x6d473f03,0x67203f04}},	//   чила_, _utsa, _tija, domj,
   {{0x798b3f05,0x2cb83f06,0xa3be00aa,0x3eb90703}},	//   rugw, _gard_, ँटा_, _hast_,
   {{0xddc600d9,0x3eb93f07,0x6729007a,0x25a600ee}},	//   _iekš, _kast_, tlej, _apol_,
   {{0x7ce03f08,0xe9ff0023,0x44273f09,0x3eb905db}},	//   _förs, _ngần_, _ryn_, _jast_,
   {{0x7ce03f0a,0x7cf201c5,0x99670426,0x673b1670}},	//   _tört, _færd, _італ, rmuj,
   {{0x67bb0e25,0x4427057a,0x644e0335,0x67293f0b}},	//   _واضح_, _pyn_, žbin, slej,
   {{0xc20900a1,0x67293f0c,0x232a1486,0xddc60995}},	//   _פה_, plej, зони_, _mekš,
   {{0x7af9008e,0xbebb023b,0x2a7f02a1,0xddd601f9}},	//   _çatı, _skën, _jdub_, zgyű,
   {{0x44273f0d,0x7cf213c8,0x35a500e5,0x00000000}},	//   _wyn_, _hære, _чалг, --,
   {{0x7cf2052f,0x26dd03a9,0xa3cc0469,0x44273f0e}},	//   _kære, _howo_, रमश_, _tyn_,
   {{0x6ee300aa,0x8fa3120a,0x3eb93f0f,0x7cf20120}},	//   _lõbu, ларе, _bast_, _jære,
   {{0x6eea0074,0x26dd1a7b,0x3eb93f10,0x75210036}},	//   _výbo, _jowo_, _cast_, lolz,
   {{0x7cf21484,0x395f022e,0x62960193,0x6f040fae}},	// [34a0] _lære, _ntus_, _icyo, riic,
   {{0xdd8f0f43,0x6f04009c,0x26dd3f11,0x3eb93f12}},	//   صوم_, siic, _lowo_, _east_,
   {{0x3eb93f13,0xaca40134,0x395f00d1,0x61e63f14}},	//   _fast_, _nzụr, _atus_, lykl,
   {{0x3eb93f15,0x7cf201df,0x60de3f16,0x395f3f17}},	//   _gast_, _særd, _hopm, _btus_,
   {{0x2cb83f18,0xe8943f19,0xaca40294,0x7ce00149}},	//   _tard_, валь, _azụr, _dörr,
   {{0x7cf2038c,0x6ef1052f,0xf5480023,0x290e0328}},	//   _bære, _våbe, _tụi_, unfa_,
   {{0x7ce00222,0x25a61c74,0x09d80081,0x7cf201c5}},	//   _förr, _spol_, _দেখা, _værd,
   {{0x8f9b193b,0x61e601b3,0xbb431b77,0x26dd00a4}},	//   ליצי, kykl, _беск, _cowo_,
   {{0x55063f1a,0xd251001c,0x26dd00d1,0x60de0313}},	//   ечна, یند_, _dowo_, _oopm,
   {{0xfd4d0174,0xdb1501bf,0x644d0491,0x61e60138}},	//   _aghị, _erzä, _şair, dykl,
   {{0xccf30054,0x26dd0065,0x67200350,0x00000000}},	//   רכת_, _fowo_, pomj, --,
   {{0xf1bf035d,0x26dd01dc,0x78ba01f9,0x00000000}},	//   tvá_, _gowo_, _hatv, --,
   {{0x3eb93f1b,0x250b0103,0x78ba3f1c,0xdbdc0065}},	//   _rast_, _کرنی_, _katv, _láàm,
   {{0x31353f1d,0x75210428,0x3eb90313,0xf1bf0231}},	//   тегр, colz, _sast_, rvá_,
   {{0x78ba3f1e,0x3ea02f7d,0x3eb900a1,0x00000000}},	//   _matv, ffit_, _past_, --,
   {{0x78ba3f1f,0x61e63f20,0x7cf22c03,0xbbbc007f}},	//   _latv, bykl, _nærb, ोमैक,
   {{0x7d250018,0x2ee901c2,0xbddb0113,0x3eb93f21}},	// [34b0] نفرن, rkaf_, _ngèt, _vast_,
   {{0x645a3f22,0x2ee93f23,0xfd4e0174,0x3eb93f24}},	//   ncti, skaf_, lekọ, _wast_,
   {{0x3eb93f25,0x7cf201df,0x7d053f26,0x00000000}},	//   _tast_, _bærb, rihs, --,
   {{0xc01c0019,0x9980026a,0x3f7a00ca,0x0f7a0142}},	//   _lược_, çiş_, _קארס, _קארב,
   {{0x442b00de,0x7cf213c8,0x26dd1a3a,0x7538020b}},	//   ́c_, _sære, _rowo_, _ohvz,
   {{0x7cf201df,0x315800ca,0xe9ff020b,0x09e20120}},	//   _pære, עיון_, _ngấn_, рошн,
   {{0x61e63f27,0x8aa701b3,0xac183f28,0x26dd0154}},	//   zykl, _прад, _зору_, _powo_,
   {{0x78a402e6,0x7cf20856,0x645a002d,0x2a7f008a}},	//   điva, _være, ecti, _udub_,
   {{0x23601419,0x7ce03f29,0x78ba0095,0x940b00a7}},	//   _čija_, _körp, _fatv, əcə_,
   {{0x78ba3f2a,0x61e63f2b,0x25bf0313,0xdff102d5}},	//   _gatv, vykl, rvul_, घनाद_,
   {{0xc6e702ec,0x6abb02dc,0x4ac60455,0xc01c0019}},	//   _підп, _kauf, _रोडव, _dược_,
   {{0x29073f2c,0xe1ff3f2d,0x61e600c6,0x9a120294}},	//   lina_, rbón_, tykl, pọtụ,
   {{0x399b001f,0x95e90018,0x98be020a,0x00000000}},	//   nês_, _تباہ_, _uită_, --,
   {{0x6abb25ea,0x2d89057a,0x61e600c6,0xe1ff0103}},	//   _lauf, drae_, rykl, mból_,
   {{0x61e6325f,0x657b3f2e,0xe1ff01f9,0x2907010a}},	//   sykl, lsuh, lból_, iina_,
   {{0x29073f2f,0xe1f21574,0x3f84042d,0xbddb03a9}},	//   hina_, _نسخ_, čmu_, _ngès,
   {{0x29073f30,0x60de3f31,0x657b3f32,0x3ea001f9}},	// [34c0] kina_, _topm, nsuh, rfit_,
   {{0x98be013f,0xa3d50034,0xee370b7b,0x7e76029a}},	//   _kitą_, _सपा_, тну_, sayp,
   {{0x290702e6,0x644f00a5,0x7e763f33,0x6abb3f34}},	//   dina_, ściw, payp, _bauf,
   {{0xe1ff0018,0x2d893f35,0x78ba01d3,0x29072a7a}},	//   kból_, brae_, _satv, eina_,
   {{0x78ba22bb,0x29073f36,0x7ce00149,0xd9970103}},	//   _patv, fina_, _förp, نخوا_,
   {{0x97a600be,0xc8780233,0x00000000,0x00000000}},	//   врил, _boğa_, --, --,
   {{0x6abb171f,0x8b2629af,0x28c70179,0x27e700f3}},	//   _fauf, _адве, लाजि, gynn_,
   {{0xa3d50b94,0x1ae33f37,0x399b0161,0x8c1b040a}},	//   समन_, _косм, bês_, _חולי,
   {{0x29073f38,0x399b0396,0x81e70081,0x78ba3f39}},	//   bina_, cês_, _যেন_, _tatv,
   {{0x6abb007f,0xfd4e0129,0x00000000,0x00000000}},	//   _zauf, wekọ, --, --,
   {{0xd25100cd,0x69c21507,0x7ae0019f,0x2b9c0031}},	//   ینگ_, lvoe, _komt, níc_,
   {{0x69dd0231,0x7ae0033c,0x00000000,0x00000000}},	//   _àsec, _jomt, --, --,
   {{0x69c20db1,0x394c3f3a,0x7ae3016d,0x213a009c}},	//   nvoe, _kids_, ênti, _bhph_,
   {{0x55770130,0x7ae03f3b,0x2d89057a,0xf54800fe}},	//   _יעדן_, _lomt, vrae_, _cụt_,
   {{0xa3cc009f,0xbddb03a9,0x394c30e1,0xcebb0284}},	//   _रपट_, _ngèr, _mids_, мља_,
   {{0x394c3f3c,0x2d893f3d,0x200c0220,0x69c21570}},	//   _lids_, trae_, údia_, kvoe,
   {{0x29073f3e,0x6abb3f3f,0x69c2029a,0x00000000}},	// [34d0] yina_, _rauf, jvoe, --,
   {{0x290722e7,0x2d89002b,0x2c7c00b6,0xcc0b1f11}},	//   xina_, rrae_, vádí_, وزان_,
   {{0xa3d50b94,0x99d4001c,0x6aa20d2a,0x69c201d0}},	//   समय_, یتها, ffof, evoe,
   {{0x7ae03f40,0x29073f41,0xbcfb0037,0x3f913f42}},	//   _comt, wina_, _dtéa, muzu_,
   {{0xdcef01d4,0x29073f43,0xdb0e0072,0x69c2057a}},	//   şdır, tina_, _arbó, gvoe,
   {{0xdb1c00b3,0x613202b6,0x693436bf,0x6abb0350}},	//   _errà, jæll, анчу, _wauf,
   {{0x6abb3f44,0x65620f20,0x3f91008b,0x273a0052}},	//   _tauf, _atoh, nuzu_, kënd_,
   {{0x29073f45,0xe1ff0103,0x7bc702a1,0x69c205c2}},	//   sina_, tból_, _irju, bvoe,
   {{0x613202b6,0xfec50033,0x2b4d024a,0xc98700f6}},	//   fæll, _একাধ, _iiec_, _јуби,
   {{0x394c3f46,0x29073f47,0x7cf2003e,0x893800ae}},	//   _gids_, qina_, _kæra, _апус_,
   {{0xe29a25e7,0xe1ff0103,0x29053f48,0xf54800fe}},	//   нан_, sból_, _imla_, _rụt_,
   {{0x68e13f49,0x6562023b,0xdb150042,0x3f913f4a}},	//   _hold, _ftoh, _arzú, duzu_,
   {{0x68e13f4b,0x26cf3f4c,0xdbe70081,0x7cf200d6}},	//   _kold, _ingo_, _গেমস_, _læra,
   {{0x68e100e7,0x293500c1,0x3f913f4d,0xd5ac0103}},	//   _jold, טאָן_, fuzu_, _کہی_,
   {{0x68e13f4e,0x44240177,0x3f910a00,0x3439006e}},	//   _mold, _پروف, guzu_, _אײַע,
   {{0x6ee30006,0x2b9c030b,0x52763f4f,0x69c600c4}},	//   _sõbr, víc_, _суку, _škem,
   {{0x7bc700cd,0xa2d13f50,0x7ae01c3e,0xf5480023}},	// [34e0] _arju, धार्, _romt, _tụt_,
   {{0x69ba0034,0x7ae03f51,0x59c7023a,0x612002db}},	//   _एनबी, _somt, लिनर, hölz,
   {{0xb09b0105,0xa2d81efb,0x409b00c1,0xdb1c266c}},	//   _אייר, याप्, _אביס, _arrá,
   {{0x69c204ee,0x3cf00096,0xdb0e00b3,0x29050565}},	//   tvoe, _इतके_, _arbò, _amla_,
   {{0x2b9c0363,0x68e13f52,0x2b4d3f53,0x18743f54}},	//   síc_, _bold, _diec_, агля,
   {{0x69c2043e,0x26cf3f55,0x2905009c,0x3eb200f9}},	//   rvoe, _ango_, _cmla_, leyt_,
   {{0x7ae03f56,0x68e13f57,0x69c204e2,0x2d923f58}},	//   _tomt, _dold, svoe, luye_,
   {{0x6d4e3f59,0x69c2000b,0xeb1f0285,0xe97600d1}},	//   _hiba, pvoe, यकृत_, _مهرد,
   {{0x6d4e2ac5,0xa2d80be4,0x589600cd,0x2d920193}},	//   _kiba, यान्, _مجاز, nuye_,
   {{0x6d4e3f5a,0x68e13f5b,0x26cf0361,0xdced007e}},	//   _jiba, _gold, _engo_, rsać,
   {{0x6d4e3f5c,0x2d9202a4,0x3eb200f9,0xc6250033}},	//   _miba, huye_, keyt_, মেলা_,
   {{0x6d4e3f5d,0x973c0292,0x68e13f5e,0x2d921937}},	//   _liba, _opći, _zold, kuye_,
   {{0x68e1008e,0x62840150,0x7c2e3f5f,0x6d4e01ff}},	//   _yold, _ddio, _lybr, _oiba,
   {{0x6d4e1a8b,0x68e10072,0x3f9101e9,0xbcfb3f60}},	//   _niba, _xold, tuzu_, _atén,
   {{0xe44f3f61,0x7c2e057e,0x43941af8,0x96a10285}},	//   _عضو_, _nybr, _тайс, क्वॉ,
   {{0x6d4e283d,0x63600134,0x3f913f62,0xaf373160}},	//   _aiba, _ịnwa, ruzu_, ارست,
   {{0x6d4e3f63,0x2d920193,0xdd950077,0x5c75249b}},	// [34f0] _biba, guye_, разы, илат,
   {{0x2d873f64,0x6d4e3f65,0x2b4d3918,0xd7b40096}},	//   čne_, _ciba, _siec_, ंबाच,
   {{0x6d4e3f66,0x68e10042,0xaa553cc0,0x8f353f67}},	//   _diba, _rold, авеш, _венц,
   {{0x2d923f68,0x6d4e0a00,0xdd950b91,0x7c2e030a}},	//   buye_, _eiba, _камы, _dybr,
   {{0x68e13f69,0x2b4d00de,0x442e3f6a,0x81e70033}},	//   _pold, _viec_, _lyf_, _যেত_,
   {{0x6d4e3f6b,0x68e11a4a,0x2b4d0034,0x00000000}},	//   _giba, _qold, _wiec_, --,
   {{0x68e13348,0xe3e400c7,0x46f53f6c,0xa2d8030b}},	//   _vold, _ফেসব, ичит, याम्,
   {{0x95851339,0x6d4e3dd3,0x9a120134,0x68e13f6d}},	//   алие, _ziba, pọpụ, _wold,
   {{0x68e13f6e,0xe5761ad1,0x19590109,0x6d4e1937}},	//   _told, азы_, _разы_, _yiba,
   {{0xb3a901e8,0x6d4e0072,0x69c90381,0x00000000}},	//   _çıkı, _xiba, _iree, --,
   {{0xfd5e0134,0xb4e50096,0x2d920193,0x53a50dd8}},	//   _bayọ, _नवी_, zuye_, шанб,
   {{0xb6c900fb,0x69c93f6f,0x26cf024a,0x442e03a8}},	//   _جائے_, _kree, _ungo_, _dyf_,
   {{0x956730cf,0x69c90167,0x7f5700fd,0x2d4d05db}},	//   _съед, _jree, _auxq, _ržen_,
   {{0x672401ac,0x2d920193,0x200c0031,0x65693f70}},	//   čije, vuye_, údio_, mpeh,
   {{0x6aa93f71,0x442e030a,0x00000000,0x00000000}},	//   _obef, _gyf_, --, --,
   {{0xe8df0028,0x539a040a,0x6d4e1c7b,0x2d920193}},	//   _muốn_, _סיפו, _siba, tuye_,
   {{0xed570303,0x9f453f72,0x69c9023e,0x98a5022b}},	// [3500] иот_, álá_, _nree, _aklč_,
   {{0x2d923f73,0xfd5e0174,0x6ef102b6,0x6aa93f74}},	//   ruye_, _zayọ, _håbl, _abef,
   {{0x1d1902ec,0xeb9a23a3,0x6d4e0010,0x2d920193}},	//   ують_, тие_, _viba, suye_,
   {{0x7c2e0343,0xfaa60dc0,0x6d4e3f75,0x69c93f76}},	//   _vybr, радо, _wiba, _bree,
   {{0x7c2e00a5,0x2a690610,0xc33300ca,0x69c93f77}},	//   _wybr, ñaba_, קוד_, _cree,
   {{0x6f163f78,0xa3d5030b,0x69c93f79,0x6aa9039f}},	//   lnyc, समा_, _dree, _ebef,
   {{0xe8df0019,0xc60e0285,0x69c90361,0x2d803f7a}},	//   _cuốn_, ाप्य_, _eree, lsie_,
   {{0x6f163f7b,0x69c93f7c,0x6b8300d3,0x6aa90065}},	//   nnyc, _free, ânge, _gbef,
   {{0x2d803f7d,0x69c93f7e,0x1dc9055c,0x3f5c020b}},	//   nsie_, _gree, रियत, _líu_,
   {{0x44f432d3,0x2d803f7f,0x3f5c0072,0x00000000}},	//   спос, isie_, _oíu_, --,
   {{0x3f5c3f80,0x44382ca7,0x2d800e4b,0xcc572252}},	//   _níu_, år_, hsie_, יסיק_,
   {{0xe5a628b9,0x2d800665,0x6f1600a5,0x442e0185}},	//   _види, ksie_, jnyc, _vyf_,
   {{0x6f163430,0x2d800220,0x23690146,0x442e0150}},	//   dnyc, jsie_, _čaje_, _wyf_,
   {{0xddcf00ae,0x00000000,0x00000000,0x00000000}},	//   _lecţ, --, --, --,
   {{0x75280034,0x6353020a,0x00000000,0x00000000}},	//   modz, _bănu, --, --,
   {{0x27210244,0xa2d8030b,0x75283f81,0xc299022f}},	//   fóny_, याण्, lodz, _ских_,
   {{0x7cf200f2,0x6353044c,0x2d80010a,0x25ec007f}},	// [3510] _værn, _dănu, gsie_, आईटी_,
   {{0xeb1f1117,0x6aa90036,0x6d8a0018,0x6f16007f}},	//   यक्त_, _sbef, املہ_, anyc,
   {{0x6f1600a5,0x2d803f82,0x7cf23f83,0x00000000}},	//   bnyc, asie_, _tærn, --,
   {{0x69c93f84,0x752800a5,0xd64e0174,0x2b58028d}},	//   _pree, hodz, _kọdụ_, _durc_,
   {{0xa2d8022d,0xe1ff308b,0x7cf23f85,0x7f3a00a1}},	//   यात्, nzó_, _kærl, _תערו,
   {{0x69c901a2,0x6f0d3f86,0xb4e5009d,0x00000000}},	//   _vree, liac, _नवे_, --,
   {{0x6fd70455,0x69c90a88,0x3f5c0023,0x00000000}},	//   डमिं, _wree, _xíu_, --,
   {{0x6f0d3f87,0x6d450a1b,0x660d003e,0x7cf23f88}},	//   niac, lmha, _þakk, _lærl,
   {{0x9f4e004d,0xd64e0174,0x00000000,0x00000000}},	//   _åfå_, _nọdụ_, --, --,
   {{0x6f1617b5,0x6d450099,0x6f0d3f89,0x25ec0179}},	//   znyc, nmha, hiac, आईजी_,
   {{0x27210146,0xf8b3009f,0x65690d12,0x6f0d39a8}},	//   zóny_, ंजीप, speh, kiac,
   {{0xd64e0294,0x8a140018,0x61320088,0x6595004b}},	//   _bọdụ_, _اظہا, mæli, _гаду,
   {{0xe2970084,0x6f160220,0xd64e0134,0x636000ac}},	//   щая_, vnyc, _rọgụ_, _ịnta,
   {{0xd46602ec,0x6f1600a5,0x2a7d01bb,0x6146261f}},	//   _лише_, wnyc, hawb_, сега,
   {{0x33951823,0xc2ea00b1,0x6f163f8a,0x43850cc8}},	//   _العز, _معظم_, tnyc, _البق,
   {{0x09bd0f71,0xd64e0174,0x2d800abf,0x8364071c}},	//   _আপনা, _fọdụ_, tsie_, _بدول,
   {{0xac8601b6,0x0dca01b6,0x829700a1,0x7f4404c1}},	// [3520] йгал, ылай_, _הדפס_, rmiq,
   {{0x2d80182a,0xddcf00d3,0x5c5623b8,0x3f5c003e}},	//   rsie_, _secţ, стаф, _tíu_,
   {{0x2d803f8b,0xb5fd01b3,0xf536006e,0x6f0d3f8c}},	//   ssie_, rašy, צטער_, biac,
   {{0x6f0d0e4d,0x2d803f8d,0x6d450a02,0x27210094}},	//   ciac, psie_, amha, póny_,
   {{0x0854004d,0xfe4600d3,0x98a5009e,0x00000000}},	//   овлю, _ынмо, _silġ_, --,
   {{0x6eea0146,0x6d45152f,0x2b583f8e,0xd83a00ae}},	//   _výbu, cmha, _turc_, лэй_,
   {{0x37061612,0x00000000,0x00000000,0x00000000}},	//   йчив, --, --, --,
   {{0xe8df0019,0xe807009d,0x75280034,0xfb16015a}},	//   _buồn_, _वेळा_, wodz, _اورج,
   {{0x25af0027,0x186a3a6f,0xe8df020b,0x00000000}},	//   _cpgl_, _бази_, _cuồn_, --,
   {{0x6f0d3f8f,0xe29f01cd,0x00000000,0x00000000}},	//   ziac, miði_, --, --,
   {{0x63a502e2,0x7cf20939,0x75282ac2,0x4789004d}},	//   _ähnl, _nærm, rodz, _всім_,
   {{0x7cf21484,0x083b00c1,0xe7373f90,0xe61a004d}},	//   _særl, _געבל, _лех_, _йде_,
   {{0x798200a5,0x15620174,0x2d4d0307,0x26c300d9}},	//   nsow, _fọọa, _džej_, ējot_,
   {{0x290e3f91,0xe3b20037,0x2b460031,0x00000000}},	//   nifa_, _فرع_, ňoch_, --,
   {{0x6f0d3f92,0xff290037,0x7cf200f2,0xf04400d3}},	//   tiac, لكسي_, _værl, зэто,
   {{0x877b0341,0x290e0350,0x79820034,0x8c000033}},	//   טאלי, hifa_, ksow, ্থান_,
   {{0x28b902b0,0x290e3f93,0x75b60096,0xed5b0281}},	// [3530] _इसलि, kifa_, _अनोळ, اشرت_,
   {{0x6f0d0038,0x6d453f94,0x59c702d5,0x2295001c}},	//   siac, umha, लिसर, _الکس,
   {{0x6d453f95,0x6f0d3f96,0x25a43f97,0x2d4d00cc}},	//   rmha, piac, html_, _užem_,
   {{0x539b00a1,0x6d450a02,0xf2d400c1,0x5a350e96}},	//   ריאו, smha, ּעס_, онет,
   {{0xb2bc00c1,0x6f1d01cb,0x443c0381,0x00000000}},	//   טמאר, _ijsc, _lzv_, --,
   {{0x2a7d023e,0x00000000,0x00000000,0x00000000}},	//   sawb_, --, --, --,
   {{0x7982010a,0x0a6b0b36,0x00000000,0x00000000}},	//   asow, _брзи_, --, --,
   {{0x0565355b,0x46e900ae,0xfd4c0294,0xdce400e8}},	//   овин, рдин_, _obiọ, mpiā,
   {{0xa2d81efb,0x3ea90150,0xa8a73f98,0x290e0172}},	//   यास्, ifat_, _грек, bifa_,
   {{0x6724007e,0xa2a70285,0xa25b0231,0x00000000}},	//   čija, ट्स्, udôn, --,
   {{0x28150080,0x443c007e,0x6ef83f99,0x00000000}},	//   _بواس, _czv_, _líba, --,
   {{0x4acf2ebd,0xe29a3f9a,0xa2d10285,0x26c300e8}},	//   _सोमव, шам_, धाग्, ējos_,
   {{0x9f4c00b6,0xb5c900d1,0x98a7007f,0x00000000}},	//   ádí_, _خوشم_, alną_, --,
   {{0x2d4d0095,0x6eea02c6,0x00000000,0x00000000}},	//   _džek_, _nýbr, --, --,
   {{0xc44700cd,0x3ea93f9b,0x7ce00103,0x00000000}},	//   _دیدن_, ffat_, _törz, --,
   {{0x9f590103,0x7cf200f3,0x00000000,0x00000000}},	//   ázás_, _værm, --, --,
   {{0x236003ce,0x6da30012,0x82fa0688,0xec7a2549}},	// [3540] _čiji_, мита, _مرکز_, ипа_,
   {{0xa2d800a4,0x00000000,0x00000000,0x00000000}},	//   याव्, --, --, --,
   {{0xdee63f9c,0x60d7006e,0x00000000,0x00000000}},	//   _дони, _וויא_, --, --,
   {{0x3f983f9d,0x49ca2f11,0xa25b0031,0x798229da}},	//   muru_, илен_, jdôl, tsow,
   {{0x3f980d17,0x290e3f9e,0x3a200233,0x00000000}},	//   luru_, tifa_, çip_, --,
   {{0xf772300d,0x7cf201c5,0xe29f003e,0x28f7007b}},	//   واع_, _mærk, riði_, жешь_,
   {{0x290e3f9f,0x31a40103,0xa3cd1358,0x7cf20537}},	//   rifa_, höz_, रिफ_, _lærk,
   {{0x78ad0106,0x27e00039,0x290e3fa0,0xa3cd2f74}},	//   đava, ćin_, sifa_, रिन_,
   {{0x26c20181,0x3f983fa1,0x7cf20ac9,0x75d40076}},	//   ľko_, huru_, _nærk, سيدا,
   {{0x3f983fa2,0x69c00068,0x26c23fa3,0x32020031}},	//   kuru_, _isme, žko_, dzky_,
   {{0x7e643fa4,0x3f983fa5,0xdb1c03a9,0x4acf0096}},	//   kcip, juru_, _asré, _सोडव,
   {{0x7ae20167,0x3f983fa6,0x46d10034,0x443c00d8}},	//   njot, duru_, _दोपह, _vzv_,
   {{0x332b00f3,0x68e81d4a,0x443c020b,0x31a40847}},	//   rocx_, _kodd, _wzv_, göz_,
   {{0x3f983fa7,0x443c3fa8,0xf9931777,0x3f91007f}},	//   furu_, _tzv_, ורש_, trzu_,
   {{0x3f982f3e,0x443c2d5a,0x290c0270,0x3f85014b}},	//   guru_, _uzv_, _mmda_, élu_,
   {{0x69c0077e,0x37bc0081,0x68e82084,0x2560022b}},	//   _osme, _অপার, _lodd, _kòl_,
   {{0xa2d8077d,0x316901c2,0x7cf2003e,0x69ba0b42}},	// [3550] यार्, _utaz_, _gærk, _शैली,
   {{0x3f983fa9,0x68e800f0,0x629d00f2,0x25600154}},	//   buru_, _nodd, lgso, _mòl_,
   {{0xa3cd0f77,0x69c03faa,0x3f9802a4,0xb3a90233}},	//   रिय_, _asme, curu_, _çıtı,
   {{0x629d12f5,0x7bce3fab,0xae0c3fac,0x60c500c2}},	//   ngso, _drbu, _सेवन_, _hahm,
   {{0x7e7d0b4b,0x68e83fad,0x7cfb078e,0x00000000}},	//   _iesp, _bodd, _cîrc, --,
   {{0x91bc00a1,0x68e80e8e,0x7cf20400,0xa3cd1fb4}},	//   ימדי, _codd, _nærh, रिम_,
   {{0x20031b12,0x69c03fae,0x6d5d3faf,0x68e83fb0}},	//   nzji_, _esme, _husa, _dodd,
   {{0x6d5d3fb1,0x7e7d3fb2,0x6b830610,0x25600383}},	//   _kusa, _jesp, ángu, _bòl_,
   {{0x3f983fb3,0x6d553fb4,0x68e80178,0xbcfb01dc}},	//   zuru_, _kiza, _fodd, _atéi,
   {{0x6d5d3fb5,0x7afb0102,0x7e7d0c56,0x60c5042c}},	//   _musa, _hlut, _lesp, _nahm,
   {{0x6d5d3fb6,0x7ae93fb7,0xd91a0327,0x256001b9}},	//   _lusa, _koet, _פועל, _eòl_,
   {{0xf7700f03,0x6d5d1097,0x25600154,0x883a0796}},	//   _شام_, _ousa, _fòl_, _התעו,
   {{0x7ae90505,0x7cf301e8,0x256002f1,0x60c5044c}},	//   _moet, _kırı, _gòl_, _bahm,
   {{0x7cf201c5,0x3f983fb8,0x6d553fb9,0x7ae9007a}},	//   _værk, turu_, _niza, _loet,
   {{0x7afb3fba,0x6d5d3fbb,0xd9b8099d,0x7999061d}},	//   _olut, _ausa, _इन्ट, huww,
   {{0xdee33f37,0x3f983fbc,0x6d553fbd,0x7ae900eb}},	//   носи, ruru_, _aiza, _noet,
   {{0x6d553fbe,0x7e7d39bc,0x60c53fbf,0xae0c0789}},	// [3560] _biza, _desp, _fahm, _सेशन_,
   {{0x3f983fc0,0xdd8f0cd2,0x6d5d3fc1,0x7afb3fc2}},	//   puru_, اول_, _dusa, _alut,
   {{0x46bd009d,0x7ae93fc3,0x68e80150,0x7afb01bf}},	//   ्याह, _boet, _rodd, _blut,
   {{0x7e7d35a5,0x68e83fc4,0x6d5d3fc5,0x7ae93fc6}},	//   _gesp, _sodd, _fusa, _coet,
   {{0x6d5d3fc7,0x63820018,0x6d553fc8,0x7ae20084}},	//   _gusa, _kíná, _fiza, rjot,
   {{0x6d5502a7,0x7bce084f,0x7e7d00a5,0x7afb3fc9}},	//   _giza, _trbu, _zesp, _elut,
   {{0x7afb3fca,0x6d5d02dc,0x7cf23fcb,0xf76f00cd}},	//   _flut, _zusa, _næri, هاي_,
   {{0x67241197,0x6d551632,0x799900dc,0x39bd05aa}},	//   čijo, _ziza, buww, _fňs_,
   {{0x69c03fcc,0x6d5d008a,0xbcfb2bc0,0x7cf3008b}},	//   _usme, _xusa, _stéi, _fırı,
   {{0x7ae93fcd,0x63610134,0x765900f0,0x9f453fce}},	//   _zoet, _ịnap, _egwy, álú_,
   {{0xa2950426,0x256006a3,0x92953fcf,0x229500ae}},	//   мані, _wòl_, манц, миня,
   {{0x6b650138,0x60c53fd0,0x883b00ca,0x2560022b}},	//   _jėga, _sahm, _פתאו, _tòl_,
   {{0x236008a9,0x68420065,0x6b6500c6,0x69c2097c}},	//   _čiju_, _fídí, _mėga, लिटी,
   {{0x6d5d3fd1,0x0cc70081,0x26c60350,0x7cf201cd}},	//   _rusa, _শক্ত, _haoo_, _færi,
   {{0x6d5d048e,0x6d553fd2,0x443a0028,0x387e3fd3}},	//   _susa, _riza, _áp_, _metr_,
   {{0x6d5d06e1,0x539b00a1,0x6d553fd4,0xf8b91b79}},	//   _pusa, _היהו, _siza, _इस्प,
   {{0x7e7d3fd5,0x6d55334c,0x5d551fb3,0x7ae9057a}},	// [3570] _vesp, _piza, дкат, _roet,
   {{0x7afb3fd6,0x7ae93fd7,0x81fc00ca,0x6d5511bc}},	//   _slut, _soet, _להחז, _qiza,
   {{0x7afb3fd8,0x7e7d3fd9,0x7ae93fda,0xfe700018}},	//   _plut, _tesp, _poet, ئدہ_,
   {{0x6d553fdb,0xa3cd0851,0x6d5d3fdc,0xbcfb020d}},	//   _wiza, रित_, _tusa, _suéd,
   {{0x7ae904ee,0xa2a53fdd,0x6d5d3fde,0x99890181}},	//   _voet, _कान्, _uusa, ťaž_,
   {{0xbcfb1ba6,0x7cf300a7,0x78ad0095,0x76960555}},	//   _quéd, _qırı, đavo, yüyü,
   {{0x7ae93fdf,0x7afb03a9,0x00000000,0x00000000}},	//   _toet, _tlut, --, --,
   {{0x628d0037,0x8cdb007f,0x7afb3fe0,0x00000000}},	//   _ndao, नावो, _ulut, --,
   {{0x7cf304d6,0x917a00fe,0x387e03a8,0xdbd700ce}},	//   _tırı, _mật_, _fetr_, sääv,
   {{0x628d020a,0x838900ba,0xf8700206,0x00000000}},	//   _adao, обов_, čším_, --,
   {{0xccf20105,0x6ef8255b,0x7a430139,0xd7c100bc}},	//   דכי_, _bíbl, _fìtí, _शनिच,
   {{0x395f00aa,0x52b80179,0xc878026a,0x76960367}},	//   _kuus_, इजेस, _doğu_, rüyü,
   {{0x64a53fe1,0xa06a00c6,0xf54800fe,0xe60e2a59}},	//   _жала, жага_, _lụy_, _рд_,
   {{0x7cf20430,0x395f09a1,0x00000000,0x00000000}},	//   _hærv, _muus_, --, --,
   {{0x2d8f034f,0x225f00e7,0xfe7f02ac,0x8fa30566}},	//   ágen_, žuka_, _beï_, каре,
   {{0x98bf0078,0x6ef8037a,0x00000000,0x00000000}},	//   _ftuħ_, _víbo, --, --,
   {{0x395f040c,0xccc63fe2,0xe1ff0610,0x31260859}},	// [3580] _nuus_, мбай, lcón_, _одиг,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1ff3539,0x25bf02db,0xa2a5023a,0x00000000}},	//   ncón_, hwul_, _काम्, --,
   {{0x31603fe3,0x7cf23fe4,0xa2d42171,0x200c0031}},	//   _kuiz_, _nærv, _बोम्, údiu_,
   {{0x7bda2e85,0x387e030b,0x31600161,0x094a2c22}},	//   _štud, _petr_, _juiz_, очки_,
   {{0xa2a5030b,0x31600063,0x8b660503,0xbcfb3fe5}},	//   _काभ्, _muiz_, _يازم, _stév,
   {{0xb9060251,0x31603fe6,0x6b6307cb,0xdca33fe7}},	//   _बच_, _luiz_, _акса, _шари,
   {{0x3ea00f83,0x8c4311f8,0x758a0084,0x260f0403}},	//   ngit_, _ресе, осов_, _तेही_,
   {{0xb8f40081,0x395f3fe8,0x00000000,0x00000000}},	//   _হক_, _guus_, --, --,
   {{0x33740b21,0x628d009c,0xbcfb014b,0x7c22044c}},	//   нгор, _sdao, _tuée, şoru,
   {{0x38cb00d0,0x00000000,0x00000000,0x00000000}},	//   _باقی_, --, --, --,
   {{0x26cb0281,0x395f3fe9,0x7d0b01f9,0x00000000}},	//   _وطنی_, _yuus_, égsz, --,
   {{0xe70709b4,0x5573224a,0x98a700e8,0xe7e4203b}},	//   _تسلی, _агіт, lonā_, _कपडा_,
   {{0x672d0106,0xdb053a49,0x7cf2003e,0x02a30065}},	//   čaje, rthé, _kæru, _iyọọ,
   {{0x40343fea,0xd5c800de,0xe1f90138,0xdb05020d}},	//   верс, _hề_, šų_, sthé,
   {{0x3ea01193,0xd5c80023,0xceb80284,0x7e76084e}},	//   ggit_, _kề_, мљу_, gbyp,
   {{0x7cf23feb,0x9f340120,0x3cd500ae,0x917a00fe}},	// [3590] _læru, теті, нжас, _vật_,
   {{0x3d94062a,0xd5c8020b,0x00000000,0x00000000}},	//   тифр, _mề_, --, --,
   {{0x67223fec,0xd5c80023,0x395f3fed,0x98a700e8}},	//   _ojoj, _lề_, _suus_, jonā_,
   {{0xbcfb0257,0xdced0307,0x6ef100f2,0x76420372}},	//   _québ, mpač, _påbu, _ozoy,
   {{0x38c40138,0xd8380154,0xd5c80023,0x31600072}},	//   kūrė_, _ayč_, _nề_, _xuiz_,
   {{0x7f4d00a7,0x270c02c6,0x7cf23200,0x63600134}},	//   lmaq, měny_, _bæru, ịnye,
   {{0x6d4700e7,0x2d4d0095,0x38c40138,0x76420372}},	//   _ihja, _džet_, dūrė_, _azoy,
   {{0xa3cd0be4,0xd5c800de,0x7c220092,0x395f00b7}},	//   रिस_, _bề_, ğort, _tuus_,
   {{0x79a43fee,0x2d893fef,0xc8ab008f,0xe619276f}},	//   _архе, nsae_, _мъже_, яди_,
   {{0x6b650138,0x613202b6,0x5a4400ae,0xd5c8020b}},	//   _jėgo, jælp, _рэса, _dề_,
   {{0x260f0f78,0x7642039f,0x00000000,0x00000000}},	//   _तेरी_, _ezoy, --, --,
   {{0xe1ff167e,0x67220052,0xa2a506e4,0x1ddf0d7a}},	//   rcón_, _gjoj, _काण्, नमात,
   {{0x6d470084,0x3afa006e,0x31603ff0,0xe1ff26e0}},	//   _ohja, פּטע, _quiz_, scón_,
   {{0x64a53ff1,0xdbd713ce,0xdce400c4,0x673b3ff2}},	//   _чака, _käär, mpić, lluj,
   {{0x6d4b00c6,0xd5e20139,0xdbd70f06,0x00000000}},	//   įgal, _ifó, _jäär, --,
   {{0xdbd713e3,0x64433ff3,0xa3be3ff4,0x6d473ff5}},	//   _määr, _izni, ुटर_, _ahja,
   {{0x62861114,0xa2a50d88,0xdce601d3,0x531b0089}},	// [35a0] mako, _कात्, _atkā, _מוקצ,
   {{0x62863ff6,0xa2d8030b,0x3e7e00fe,0x2f2100c6}},	//   lako, याक्, ắt_, bėgo_,
   {{0xbcfb016d,0x6d470052,0x907b00ca,0x00000000}},	//   _suéc, _dhja, _מטיי, --,
   {{0xed5a3ff7,0x4427034f,0xbcfb003e,0x98a702c6}},	//   _ном_, _mxn_, _stét, plně_,
   {{0xddcd00d3,0x260f063e,0x00000000,0x00000000}},	//   rbaţ, _तेली_, --, --,
   {{0x62863ff8,0xb866001c,0x6f043ff9,0xd838022b}},	//   hako, راتو, lhic, _pyč_,
   {{0x8c433e04,0xddcd0335,0x629a0138,0x673b034f}},	//   _бере, mbaš, ėtoj, fluj,
   {{0xd5e20065,0xa6aa0037,0xcf9300ca,0x7791001c}},	//   _afó, سابق_, אטה_, شیها,
   {{0x644300dc,0xa92607bf,0xe56f00d1,0x00000000}},	//   _azni, _здал, یطی_, --,
   {{0xd5c8011b,0x81e60081,0xc42a1c00,0x753a01e9}},	//   _về_, পনা_, зюме_, ultz,
   {{0x442700fe,0x5c970142,0x00000000,0x00000000}},	//   _cxn_, עכטע_, --, --,
   {{0x6aa23ffa,0x62863ffb,0xa2d8030b,0xd5c800fe}},	//   ngof, gako, याग्, _tề_,
   {{0x6f0401b5,0x394e00ee,0x00000000,0x00000000}},	//   dhic, omfs_, --, --,
   {{0xa3cd3ffc,0x248500ee,0x7cf2052f,0x656f3ffd}},	//   रिश_, calm_, _mærs, íche,
   {{0x62862f9a,0xa2d80a30,0x442700de,0xddcd00e7}},	//   bako, याख्, _gxn_, dbaš,
   {{0x6f043ffe,0x643b00a1,0x9f603fff,0x69dd0072}},	//   ghic, _מעונ, árás_, _áseg,
   {{0xdd9400c6,0x3d9414f8,0x7f4d00a7,0x25f60ee0}},	// [35b0] латы, литр, rmaq, एनटी_,
   {{0xac274000,0xbcfb0139,0xbebb0052,0x69c202ac}},	//   нфек, _atér, _gjën, dwoe,
   {{0x2d890090,0x6f040441,0x65620381,0x69c202ac}},	//   ssae_, bhic, _luoh, ewoe,
   {{0x9e1500f7,0x6f044001,0x59bf045f,0xb6cc0555}},	//   _адмі, chic, _एनआर, çülü,
   {{0xdb1c0018,0xdbd70329,0x2d8b007e,0xab640034}},	//   _arró, _säär, _uvce_, ężar,
   {{0x62864002,0xdbd712f1,0xbcfb0a61,0x00000000}},	//   zako, _päär, _etér, --,
   {{0x62864003,0x7cf23229,0xdce4007f,0xd52d0139}},	//   yako, _vært, jpię, _lọ́y,
   {{0xdbd7198c,0x7cf20102,0x98b601d3,0x69c202ac}},	//   _väär, _færs, īgās_, bwoe,
   {{0xe7f30c3c,0xdb1c0081,0xdb0e00ee,0x7cf20537}},	//   _अथवा_, _erró, _esbó, _tært,
   {{0x673b07c0,0x62864004,0xd9551ac9,0x7cf2003e}},	//   sluj, wako, _شناخ, _hærr,
   {{0xe29a0f16,0x62864005,0xdce41912,0x232a1720}},	//   ман_, tako, spić, дони_,
   {{0x64430074,0x4612015a,0x7bd500d8,0x069b01f9}},	//   _vzni, اویر, _mrzu, _رخصت_,
   {{0x62864006,0x24854007,0x656201c2,0x9f4502c6}},	//   rako, palm_, _guoh, álý_,
   {{0x62864008,0xf4871a6d,0xdd920260,0x26cd0a61}},	//   sako, _чудн, یوز_, ldeo_,
   {{0x6f044009,0x25ad400a,0xa0670095,0x9f4500d4}},	//   thic, ltel_, таса_, šlý_,
   {{0x7cf201cd,0x7b111515,0x32330129,0x0b130033}},	//   _nærr, sťuj, ụnụ_, িকুল_,
   {{0x6609067d,0x7bd5400b,0xc2c90037,0x3ea601d3}},	// [35c0] nzek, _arzu, _سبيل_, ļot_,
   {{0x672426dd,0x6f04400c,0xbcfb00fd,0x7bd50034}},	//   čiji, shic, _stér, _brzu,
   {{0xe0fb0341,0x26180557,0x6ef8400d,0x6f04400e}},	//   _חליל, _बेनी_, _líbi, phic,
   {{0xe6bd009d,0xdb1c05fe,0x00000000,0x00000000}},	//   ्योज, _arrò, --, --,
   {{0xe894400f,0x62844010,0xa2a50be4,0x7bd54011}},	//   галь, _meio, _कास्, _erzu,
   {{0x66090029,0x69c21507,0x7cf20c08,0x26dd06a3}},	//   dzek, rwoe, _værs, _anwo_,
   {{0x7cf24012,0x38cb0688,0xebe30070,0x25ad4013}},	//   _færr, بانی_, _корп, etel_,
   {{0x6d5c4014,0x3e860138,0xdb1c015e,0xbcfb020d}},	//   _hira, būtų_, _errò, _utér,
   {{0x6f030012,0x28e200a5,0xa5341c47,0x7bd5007f}},	//   _înce, पादि, лнич, _zrzu,
   {{0x6d5c4015,0x672d04a3,0xc796004b,0x62840231}},	//   _jira, čaja, _арды, _aeio,
   {{0xdc9b0089,0x4c9b00ca,0x25ad4016,0x00000000}},	//   וייל, וביו, atel_, --,
   {{0x6d5c4017,0x656200c2,0x7c3c01ab,0x200a0357}},	//   _lira, _tuoh, _myrr, dzbi_,
   {{0x659400d3,0x25ad2df7,0x62840062,0x66090034}},	//   _салу, ctel_, _deio, czek,
   {{0xa2a5114d,0x00000000,0x00000000,0x00000000}},	//   _काव्, --, --, --,
   {{0x5433110a,0xa43800d6,0x6e951510,0xa1580c06}},	//   _پرور, _язку_, ливу, тару_,
   {{0x6d5c4018,0x216700c2,0xbcfb0487,0x78ad00e7}},	//   _aira, _итог, _cuén, đavi,
   {{0x23693fa3,0x00000000,0x00000000,0x00000000}},	// [35d0] _čaji_, --, --, --,
   {{0x6d5c0188,0x63600134,0xdb05315d,0x7c3c030a}},	//   _cira, _ịnya, rthí, _byrr,
   {{0xa2d80454,0x6d5c4019,0x2d4d08c5,0x7c3c0150}},	//   याच्, _dira, _džep_, _cyrr,
   {{0x6d5c401a,0xbddb0113,0x443c0383,0xd25900e8}},	//   _eira, _nyèg, _myv_, žņu_,
   {{0x6d5c401b,0x99150c10,0x7bd500a5,0x25ad401c}},	//   _fira, лькі, _wrzu, xtel_,
   {{0x6d5c401d,0x7c3c0102,0x7bc701ce,0xe0d50142}},	//   _gira, _fyrr, _tsju, רײַ_,
   {{0x6e3d02ad,0x7c3c0150,0x98a716c3,0x2618167f}},	//   _hysb, _gyrr, joną_, _बेबी_,
   {{0x660903f3,0x25ad401e,0x7e6d06ee,0x27e91419}},	//   tzek, ttel_, ncap, ćan_,
   {{0x25ad401f,0x6d5c008a,0x26cd0143,0x25fe1efb}},	//   utel_, _yira, rdeo_, शैली_,
   {{0x66094020,0x2ed0000f,0x25ad4021,0x6d5c4022}},	//   rzek, _हफ्त, rtel_, _xira,
   {{0x25ad4023,0x66090018,0x2907033f,0x7e6d0167}},	//   stel_, szek, mhna_, kcap,
   {{0x7f5d0090,0x6ef82c68,0x16140e4c,0x00000000}},	//   _nisq, _tíbi, _तेवर_, --,
   {{0xa2a506e4,0xe4c8110a,0x7e6d0381,0x62841497}},	//   _कार्, ربین_, dcap, _veio,
   {{0x361a0130,0xa2d4046e,0x256900e3,0xf592082c}},	//   _אונד, _बोर्, _iúl_, _الوج,
   {{0x7f5d4024,0x6026013d,0x6d5c4025,0x69c9009c}},	//   _bisq, удва, _rira, _lsee,
   {{0xbcfb4026,0x7e6d3d99,0x69c94027,0x00000000}},	//   _stép, gcap, _osee, --,
   {{0x25694028,0x7f5d4029,0xa06a402a,0xd7f80019}},	// [35e0] _júl_, _disq, _папа_, _ngăn_,
   {{0x6d5c402b,0xee37402c,0x2907033b,0x7e6d0036}},	//   _qira, уну_, jhna_, acap,
   {{0x6d5c402d,0x9f5800dd,0x290701b5,0x65690052}},	//   _vira, nyrë_, dhna_, hqeh,
   {{0x6d5c238f,0x7e6d0451,0x00000000,0x00000000}},	//   _wira, ccap, --, --,
   {{0x6d5c402e,0x427b00c1,0x98a7402f,0xa3ca009f}},	//   _tira, גאנג, zoną_, _रैन_,
   {{0xa3e3000d,0xbebb00dd,0xa3d60f53,0x63a14030}},	//   नमा_, _njëj, सिम_, kuln,
   {{0xc5f10f71,0xa2a51abf,0x69c94031,0x9f580052}},	//   _জেলা_, _काल्, _esee, jyrë_,
   {{0xa6f400ae,0xa2d43212,0xb6f40859,0xdbd200bc}},	//   рзиш, _बोल्, рзиј, _müür,
   {{0x948600ae,0xe9da02ec,0x443c13c8,0xfaf700ca}},	//   лынд, _яка_, _syv_, _עצמי_,
   {{0x38c80177,0x2907030b,0x78ad0031,0x661d01cd}},	//   _جاری_, chna_, ľový, úska,
   {{0x4c9b00c1,0x78ad0094,0x00000000,0x00000000}},	//   עשטע, žový, --, --,
   {{0x69dd0072,0x395e1648,0xa2a50096,0x00000000}},	//   _ásec, _hits_, _काळ्, --,
   {{0x7f5d025a,0x925800c2,0x0eab00c3,0x395e0b87}},	//   _risq, лают_, _छाबड, _kits_,
   {{0xbcfb037a,0x98a70138,0xbebb0052,0x443c4032}},	//   _cuél, poną_, _gjëj, _tyv_,
   {{0x395e0db1,0x7e6d00b3,0xffe40db2,0x53a81115}},	//   _mits_, tcap, бютн, _कमिश,
   {{0x2bc8009d,0x7f5d1a4a,0x395e3ece,0x7cf200f2}},	//   रबना, _qisq, _lits_, _særp,
   {{0x7e6d0da3,0x2d8f0018,0x7f5d18ae,0x9d154033}},	// [35f0] rcap, ége_, _visq, адач,
   {{0x395e0428,0x22490f5a,0x00000000,0x00000000}},	//   _nits_, _izak_, --, --,
   {{0x1cb80190,0xa3cd099d,0x69c906b0,0x9c47018a}},	//   طالب_, रिए_, _ssee, ухал,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd010b88,0x7cdb00d9,0x6b650138,0x09e51ff9}},	//   ştır, _pārē, _mėgi, ролн,
   {{0x69c90087,0x395e01d3,0x6ce7036c,0x00000000}},	//   _vsee, _cits_, _сіме, --,
   {{0x80ad1179,0x395e4034,0xbebb023b,0x25690076}},	//   _जाने, _dits_, _njëk, _súl_,
   {{0xb8fc4035,0x49754036,0x69c90d7d,0x29074037}},	//   _तो_, _влас, _tsee, shna_,
   {{0x09b80241,0x290700e7,0x5586022a,0x395e00d7}},	//   _مطلع_, phna_, абым_, _fits_,
   {{0x63a14038,0x9f58023b,0xe787224a,0x3eab00dc}},	//   tuln, tyrë_, _будо, _lcct_,
   {{0xd8740e25,0x04453e04,0x29054039,0x28e21b92}},	//   _طالب, ренн, _illa_, पारि,
   {{0x216a0978,0x25690018,0x28d92235,0x69cf0072}},	//   кими_, _túl_, _योति, _áces,
   {{0x63a13c17,0x26cf403a,0xe2970761,0x61462a3b}},	//   suln, _iago_, шая_, иема,
   {{0x81b800c7,0x26cf403b,0x8467008f,0xd61800cd}},	//   ছিল_, _hago_, _съде, _حتما_,
   {{0x26cf403c,0x224901c8,0xbddb0113,0x3f16001f}},	//   _kago_, _ezak_, _nyèb, аќат,
   {{0x26cf403d,0x8236001c,0x2caa0167,0x52760131}},	//   _jago_, _پربا, _scbd_, _туку,
   {{0x29051c73,0xa3cd04f8,0x6da6403e,0x8d760bf4}},	// [3600] _olla_, रिक_, риза, شاءا,
   {{0x80ad3ad1,0xef86403f,0xaefb009c,0x40960c59}},	//   _जाये, _клоп, _ciùb, _трит,
   {{0x24870c3e,0x6cd3177a,0x8ca7086d,0x28a91bc3}},	//   _menm_, تقلا, _चारो, च्छि,
   {{0x29054040,0x26cf4041,0xbebb023b,0xa3d61c0a}},	//   _alla_, _nago_, _njëh, सित_,
   {{0x395e4042,0x6f0300d3,0x28e21388,0x2b5f01ec}},	//   _pits_, _înca, पालि, _diuc_,
   {{0x89da09b4,0x26cf0af0,0xdb050076,0x32aa0ff9}},	//   _یوزر_, _aago_, rthá, _काऽऽ,
   {{0xb8ce3ad1,0x26cf0256,0xf09300ca,0x370600c2}},	//   _का_, _bago_, קנה_, ичив,
   {{0xd6d74043,0x29054044,0x8f9b0341,0x395e4045}},	//   ать_, _ella_, דיקי, _wits_,
   {{0x26cf02a7,0x6ed6007f,0xa96a0451,0xf5260451}},	//   _dago_, _zębó, _риза_, ифон,
   {{0x62960172,0x00000000,0x00000000,0x00000000}},	//   _adyo, --, --, --,
   {{0x80c52a24,0x26cf0042,0x224003a9,0x291c4046}},	//   ाजसे, _fago_, _ayik_, miva_,
   {{0x291c4047,0x26cf4048,0xe61a1a57,0x236700c4}},	//   liva_, _gago_, _иде_, _dunj_,
   {{0x26c44049,0x8b570089,0x7bda09ac,0x5067008f}},	//   memo_, ייטס_, _štul, итва,
   {{0x291c404a,0x26c4404b,0x26cf404c,0x2487022b}},	//   niva_, lemo_, _zago_, _genm_,
   {{0x26cf0af0,0x5f941728,0xaefb01b9,0x00000000}},	//   _yago_, жист, _niùc, --,
   {{0x2fcd00a5,0x6d4e404d,0x224901c8,0xaefb01f7}},	//   łego_, _ahba, _tzak_, _siùb,
   {{0x2249026a,0x291c404e,0x00000000,0x00000000}},	// [3610] _uzak_, kiva_, --, --,
   {{0x61fd404f,0xe1ff00a5,0xd65700a1,0x00000000}},	//   mysl, wców_, שימת_, --,
   {{0x7055001c,0x2618007a,0x5238010d,0x9f3504a1}},	//   _دندا, _बेसी_, _مسیح_, _гені,
   {{0xf21c000f,0xaefb01b9,0x6e3202c6,0x2a64078e}},	//   _पेड़_, _diùc, _žebř, _cgmb_,
   {{0x26cf4050,0xa9c700d3,0x66e500b6,0xe1ff007f}},	//   _rago_, рсек, कासक_, rców_,
   {{0x291c0036,0x31694051,0x3ea94052,0x7c280095}},	//   giva_, _muaz_, lgat_, _ždre,
   {{0x26cf2c90,0x260f05d4,0xb3a901d4,0x29050216}},	//   _pago_, _तेजी_, _çıxı, _vlla_,
   {{0x3ea94053,0x656f1054,0xaacf0557,0x06c9004d}},	//   ngat_, ícho, _सोचक, угий_,
   {{0x291c4054,0x98c71d3f,0x6abb0134,0xa3a90096}},	//   biva_, _всел, _ibuf, गून_,
   {{0xdb1c04ea,0x00000000,0x00000000,0x00000000}},	//   _aprè, --, --, --,
   {{0x2bda00a5,0x26cf4055,0x26c40027,0x3ea9084e}},	//   णिया, _tago_, bemo_, kgat_,
   {{0x442e01af,0x26c41100,0x6ef80143,0x05170033}},	//   _dxf_, cemo_, _líbr, ঠকের_,
   {{0x6abb0134,0x61fd00c6,0x2487022b,0x00000000}},	//   _mbuf, gysl, _tenm_, --,
   {{0x463a006e,0xdb1c05aa,0x7bda4056,0x00000000}},	//   _גענע, _eprè, _štum, --,
   {{0xa3cd04a9,0xd0074057,0x6abb4058,0xdee64059}},	//   रिओ_, бере_, _obuf, бови,
   {{0x291c08a9,0x98a700a5,0x3ea9405a,0x0e66405b}},	//   ziva_, ronę_, ggat_, скан,
   {{0xc27b00a1,0x10a600d6,0xaefb01ec,0x657b00ce}},	// [3620] _גרפי, _липн, _siùc, npuh,
   {{0x26c4405c,0x6abb405d,0x00000000,0x00000000}},	//   zemo_, _abuf, --, --,
   {{0xcfea0979,0x26c40193,0x69db0113,0x290200e8}},	//   _صفحه_, yemo_, _arue, _ēka_,
   {{0xfaa61a54,0x69db0519,0xb4e4023a,0xe60713c3}},	//   садо, _brue, _पच्_, _فش_,
   {{0xd9463974,0x3157015a,0xd91a0805,0xda650076}},	//   беди, _خلیج_, льк_, زاني,
   {{0x26c4405e,0x6abb405f,0x7f444060,0x69db4061}},	//   wemo_, _ebuf, lliq, _drue,
   {{0x291c4062,0x26c402a4,0x2a6900c4,0x7d1e4063}},	//   riva_, temo_, žaba_, mips,
   {{0xa3d6143d,0xc6f84064,0x69db0709,0x7d1e4065}},	//   सिस_, рних_, _frue, lips,
   {{0x26c44066,0x69db4067,0x291c4068,0x27fc020b}},	//   remo_, _grue, piva_, syvn_,
   {{0x26c44069,0x7d1e0270,0xbf0500af,0x69c00090}},	//   semo_, nips, _रत्न_, _ipme,
   {{0x261804f1,0xdb1c406a,0x201e406b,0x7bda0357}},	//   _बेरी_, _apré, útil_, _štuj,
   {{0xa3cd009f,0x61fd007b,0xdb1c0503,0x7d1e047e}},	//   रिज_, tysl, _bpré, hips,
   {{0x7d1e406c,0x66e53ec9,0x3ea9406d,0x00000000}},	//   kips, कारक_, vgat_, --,
   {{0x2d92057a,0xf1273f19,0x7642406e,0x61fd16ea}},	//   dsye_, сьмо, _iyoy, rysl,
   {{0x24b700a1,0x7642056c,0xa2d40966,0x753a25a8}},	//   _ההון_, _hyoy, _बोक्, motz,
   {{0x69c0043e,0x3ea900d3,0x76420361,0xda080096}},	//   _opme, ugat_, _kyoy, वनात_,
   {{0x7bdc406f,0xd0d5013d,0xa3d600c3,0x644f0034}},	// [3630] _arru, _допъ, सिव_, ęcie,
   {{0x8c674070,0x753a0062,0x6abb0036,0x764206b0}},	//   стад, notz, _sbuf, _myoy,
   {{0x69c00029,0x7f444071,0xbc4b32e3,0x6f0300ae}},	//   _apme, bliq, учае_, _înco,
   {{0x69db14e2,0x672d4072,0x753a01e9,0x657b00c2}},	//   _prue, čajk, hotz, ypuh,
   {{0x6f0d0514,0xe1ff4073,0x7bdc0a00,0x753a01e9}},	//   mhac, nyó_, _erru, kotz,
   {{0xf7710192,0x6f0d0231,0x4fb40281,0x20110036}},	//   واب_, lhac, _بصیر, ozzi_,
   {{0x7642006d,0x628f1b21,0x77624074,0x3786008f}},	//   _ayoy, kaco, _biox, общо_,
   {{0x6d454075,0x69db0856,0x6abb4076,0x764206b0}},	//   llha, _true, _ubuf, _byoy,
   {{0xd6294077,0x76420027,0x9f4a014b,0x77624078}},	//   ропе_, _cyoy, ômée_, _diox,
   {{0x26d90220,0x753a01e9,0xe3b905cb,0xdb0517a5}},	//   ôsob_, gotz, або_, sthä,
   {{0x02c60e38,0x76421b99,0x657b0d67,0x60c70034}},	//   ойно, _eyoy, spuh, dejm,
   {{0x7bda4079,0x628f407a,0x6d45407b,0x7d1e028a}},	//   _štuk, gaco, hlha, zips,
   {{0x6f0d407c,0x32040146,0x2d4d192a,0x67290fee}},	//   dhac, ámy_, _džez_, mnej,
   {{0x6729407d,0x320c007f,0x627e007f,0x00000000}},	//   lnej, ądy_, dłoż, --,
   {{0x656b407e,0x6b65013f,0xbf050e50,0x61431166}},	//   _hugh, _mėgs, रसून_, фера,
   {{0x6f0d00ac,0x656b0239,0x6729407f,0xa3d64080}},	//   ghac, _kugh, nnej, सिर_,
   {{0x65634081,0x80a50018,0x20110036,0xae1a0285}},	// [3640] _kinh, _کمپن, azzi_, _नेशन_,
   {{0x65634082,0x644325c5,0xdca308d9,0x61fb042c}},	//   _jinh, _kyni, дафи, äule,
   {{0x65634083,0x7d1e4084,0x7f444085,0x656b4086}},	//   _minh, rips, pliq, _lugh,
   {{0xe9da4087,0x65633a2c,0x6f0d4088,0x67294089}},	//   ике_, _linh, chac, jnej,
   {{0x6d450150,0x7762002b,0x75280206,0x656301ff}},	//   blha, _riox, yndz, _oinh,
   {{0x628f408a,0x1d0a249c,0xf8060084,0x65633fe6}},	//   zaco, _теги_, жчин, _ninh,
   {{0xe3a7037f,0xeb971602,0x7bdc0a00,0x656b009c}},	//   _تر_, _мир_, _urru, _augh,
   {{0x656b408b,0x65630634,0x67290117,0x60c7408c}},	//   _bugh, _ainh, gnej, zejm,
   {{0x6563408d,0x6443408e,0x628f408f,0x3cf80486}},	//   _binh, _ayni, vaco, _korv_,
   {{0xa3d604dd,0x2b460428,0x32d700de,0x656b4090}},	//   सिल_, lloc_, _ủy_, _dugh,
   {{0x65634091,0x64430150,0x67294092,0x628f4093}},	//   _dinh, _cyni, bnej, taco,
   {{0x65634094,0x67290181,0x644301b7,0x753a0a00}},	//   _einh, cnej, _dyni, sotz,
   {{0x628f0891,0x7d1c00e7,0x65634095,0x753a4096}},	//   raco, _omrs, _finh, potz,
   {{0x656312ff,0x628f4097,0x6720024a,0x00000000}},	//   _ginh, saco, limj, --,
   {{0x6f0d117b,0x20054098,0x60c74099,0x6443409a}},	//   thac, áli_, rejm, _gyni,
   {{0xe7f21085,0x3eaf0364,0x2b4600ae,0x63a8033b}},	//   _अपना_, ügt_, jloc_, mudn,
   {{0x20051ff3,0x6d45063d,0x63a8161f,0xbcfb037a}},	// [3650] šli_, tlha, ludn, _muév,
   {{0x67292052,0x6563409b,0x7c2809ac,0x61e0003e}},	//   znej, _xinh, _ždra, æmle,
   {{0x63a80087,0xa2a505d6,0x290e024a,0x67200350}},	//   nudn, _काञ्, dhfa_, kimj,
   {{0xddcd409c,0x7d1c010a,0xfbde0231,0x00000000}},	//   mbaž, _emrs, _drª_, --,
   {{0x67291b30,0x63a80923,0xed5b015a,0x6f1d0037}},	//   vnej, hudn, _نشست_, _imsc,
   {{0x656b409d,0xb17c040a,0x69dd0072,0x7cfb044c}},	//   _rugh, סטור, _ásem, _vîrs,
   {{0xa2ac02e8,0x6729409e,0x3d00009d,0x656b3c59}},	//   _झाल्, tnej, _शकते_, _sugh,
   {{0x656b17c4,0x63a8409f,0x2b4640a0,0x69cc0179}},	//   _pugh, dudn, cloc_, _दैवी,
   {{0x644340a1,0x672940a2,0x65630161,0x00000000}},	//   _syni, rnej, _pinh, --,
   {{0x672940a3,0xe61602e3,0x656b40a4,0x239500e8}},	//   snej, яды_, _vugh, tāj_,
   {{0x656340a5,0x6f1d0126,0x628d009c,0x656b0134}},	//   _vinh, _omsc, _beao, _wugh,
   {{0x644340a6,0x798910df,0x656b40a7,0x00000000}},	//   _vyni, _kwew, _tugh, --,
   {{0x55e5007e,0x65633a2c,0x64430067,0x9f5e02c6}},	//   _холб, _tinh, _wyni, átí_,
   {{0x63a840a8,0x79892d30,0x6f1d033c,0x00000000}},	//   budn, _mwew, _amsc, --,
   {{0x6f0408c5,0xbebb023b,0xdee640a9,0x9f5e00b6}},	//   tkic, _njës, пови, ští_,
   {{0x7d1c0995,0xdce60b18,0x752101c2,0x1b010033}},	//   _smrs, _vukč, lilz, লোতে_,
   {{0x6f0400cc,0x79890172,0x57b80285,0x00000000}},	// [3660] rkic, _nwew, _आह्ह, --,
   {{0x6f0440aa,0x600a065c,0xe81c00aa,0x00000000}},	//   skic, _гном_, _भइला_, --,
   {{0x798940ab,0x5fe00cd5,0xe0fb0327,0x7f46007b}},	//   _awew, _पछिल, _הליל, _неож,
   {{0x79890361,0xd5bd0285,0x00000000,0x00000000}},	//   _bwew, ्बाज, --, --,
   {{0xd94616d0,0x2b460036,0xda1600aa,0x49731acf}},	//   педи, rloc_, _देखत_, еліс,
   {{0x2d8040ac,0xfe6f0018,0xed5700c2,0x6b510d2d}},	//   mpie_, _لگے_, _ноя_, våge,
   {{0x2b4601af,0xab640364,0x798940ad,0x2ca70143}},	//   ploc_, grüß, _ewew, ónde_,
   {{0x290e0051,0x63a8169c,0x6b5129fb,0x320200ce}},	//   shfa_, vudn, tåge, kyky_,
   {{0x96340938,0xceb3006e,0xb6c80018,0x798922fd}},	//   ьниц, גיח_, ماکے_, _gwew,
   {{0x63a80078,0xf7780090,0xa2a502c6,0x00000000}},	//   tudn, _erħa_, _काङ्, --,
   {{0x533540ae,0x68e802b6,0xa84a0037,0x290c3177}},	//   дент, _indd, _الام_, _ilda_,
   {{0x63a80e46,0x68fa40af,0xddcd044c,0x00000000}},	//   rudn, _hotd, ncaţ, --,
   {{0xaefb01f7,0xc6930266,0x752140b0,0x00000000}},	//   _diùl, _נאס_, bilz, --,
   {{0xbebb00dd,0xd625096a,0x6f1d40b1,0x2572030a}},	//   _njër, _تعمي, _smsc, _iâl_,
   {{0x4fc440b2,0xdb1c40b3,0x94bb00ca,0x2d800313}},	//   нста, _aprí, _המות, epie_,
   {{0xdb1c0037,0xaefb0441,0xdb0501cd,0x2b5e022b}},	//   _bprí, _giùl, sthú, _ètch_,
   {{0x69dd0161,0xf1b1052c,0xe3b8008b,0xfe701f11}},	// [3670] _àsex, _जमिन, ltı_, ادف_,
   {{0x4d98022a,0x291e0027,0x68fa042c,0xa3b00285}},	//   якую_, _nmta_, _notd, टंप_,
   {{0xe3b803a3,0xe4ed045f,0x9f55004d,0xbddb0065}},	//   ntı_, जाति_, _овоч, _iyèm,
   {{0xf1b1000f,0x290c40b4,0x6f1d0364,0xa3d40179}},	//   _जमान, _alda_, _umsc, _हनन_,
   {{0xeab00037,0xa9f900b6,0x00000000,0x00000000}},	//   اعم_, ्नेछ_, --, --,
   {{0xd04501d4,0xe3b80587,0xbebb00dd,0x3e7c00b6}},	//   _sahə, ktı_, _gjër, rátů_,
   {{0xb8d50aa6,0x60d7008c,0x32020146,0x7b080103}},	//   _झा_, _maxm, zyky_, ártó,
   {{0xe579090f,0xfbd200a1,0x290c40b5,0x68e8052f}},	//   ози_, _בתל_, _elda_, _endd,
   {{0x7ae940b6,0x00000000,0x00000000,0x00000000}},	//   _inet, --, --, --,
   {{0x7afb043e,0x320200d4,0x25720178,0x61e205db}},	//   _hout, vyky_, _dâl_, _šolo,
   {{0x7afb0c56,0xbcfb0487,0x7ae91d7f,0x00000000}},	//   _kout, _hués, _knet, --,
   {{0x6f03002d,0x7afb0084,0x2d9905db,0x320200d4}},	//   _înch, _jout, _ovse_, tyky_,
   {{0x60d70092,0x68e80150,0xd706004d,0x7afb40b7}},	//   _baxm, _yndd, _інше_, _mout,
   {{0x6606004d,0x7afb40b8,0xbcfb037a,0x672d09ac}},	//   økke, _lout, _mués, čaju,
   {{0x7ae901e9,0xdb1c0220,0xa0671b4b,0x5043001f}},	//   _onet, _sprí, дара_, верб,
   {{0x7afb40b9,0x7ae9010a,0x7dd80103,0x00000000}},	//   _nout, _nnet, júsá, --,
   {{0x60d700e0,0xddc60034,0x88c502c6,0x00000000}},	// [3680] _faxm, _szkł, _změř, --,
   {{0x7ae901ea,0x2d8038da,0x51f70103,0x6da3117c}},	//   _anet, rpie_, _آسٹر, тифа,
   {{0x7afb25f9,0x6286023e,0x8e862d06,0x3eb3007b}},	//   _bout, obko, _огне, äntö_,
   {{0xe51d40ba,0x7afb40bb,0xbcfb2b12,0x7ae900fc}},	//   योति_, _cout, _suét, _cnet,
   {{0x7afb40bc,0xfe420068,0xb17b01c5,0xddcd020a}},	//   _dout, _شکری, rvåg, rcaţ,
   {{0x7ae940bd,0xe3b800a7,0xbebb0052,0xddcd044c}},	//   _enet, ytı_, _ujër, scaţ,
   {{0x7afb40be,0xe3b80092,0x3320002b,0x3b0a00ae}},	//   _fout, xtı_, _omix_, _дево_,
   {{0x7afb2239,0x7ae940bf,0xd7570037,0xb905077d}},	//   _gout, _gnet, وجيا_, _बो_,
   {{0x68fa40c0,0xa3b040c1,0x34942b36,0x88c502c6}},	//   _totd, टून_, напр, _směř,
   {{0x7afb0c56,0xe3b801e8,0xbcfb00e1,0x29070212}},	//   _zout, ttı_, _huér, ckna_,
   {{0x7afb40c2,0x2be1049d,0x60d70188,0x48eb00c3}},	//   _yout, फिया, _raxm, चारो_,
   {{0xe3af0159,0x38630018,0xe3b8008b,0x257200f0}},	//   گری_, _újra_, rtı_, _tâl_,
   {{0x672d0087,0x332003a9,0xe3b80342,0x6f03020a}},	//   čajt, _dmix_, stı_, _înci,
   {{0xe3af00d0,0xe3b8026a,0xb51d0e28,0x00000000}},	//   دری_, ptı_, योदय_, --,
   {{0x628607ee,0x2c750065,0x00000000,0x00000000}},	//   bbko, _lúdó_, --, --,
   {{0xdcc70c3c,0xa3db00aa,0x80bf02d5,0xae1a00aa}},	//   रज्ञ, ठिर_, _लॉरे, _नइखन_,
   {{0xa3d6277c,0x7afb40c3,0x5d5540c4,0x98be022b}},	// [3690] सिक_, _rout, екат, _aktč_,
   {{0x7afb40c5,0x224906a8,0x2fd30042,0x7ae940c6}},	//   _sout, _iyak_, _tsxg_, _snet,
   {{0x7afb40c7,0xfe7000fb,0x28d90b76,0x3b0d0216}},	//   _pout, ادہ_, _योगि, _pleq_,
   {{0xd6d90034,0x3f83003d,0x80bb24eb,0x22490dc2}},	//   koła_, mpju_, श्रे, _kyak_,
   {{0x7ae90087,0x7bda0095,0x01340d7f,0x7afb40c8}},	//   _vnet, _štut, _سعید, _vout,
   {{0x2369022e,0xc98440c9,0xe8f8116d,0xe9d840ca}},	//   _liaj_, туци, млі_, ькі_,
   {{0x7afb40cb,0xf7451cda,0x5ed20033,0xbcfb037a}},	//   _tout, неко, হারে, _fuér,
   {{0x23690197,0x7ae940cc,0xbcfb00fd,0x224923ad}},	//   _niaj_, _unet, _guér, _oyak_,
   {{0x0565002d,0x00000000,0x00000000,0x00000000}},	//   нвин, --, --, --,
   {{0xf80702fd,0x00000000,0x00000000,0x00000000}},	//   _очен, --, --, --,
   {{0x8cc12ebd,0x2249026a,0x6e290117,0x644f007f}},	//   र्यो, _ayak_, _žebl, ęcio,
   {{0x23690197,0x672d153a,0x628600d2,0x00000000}},	//   _ciaj_, čajs, ubko, --,
   {{0x64a540cd,0xe60e40ce,0x00000000,0x00000000}},	//   _зала, _сд_, --, --,
   {{0x261805d4,0x80bb000c,0x656f3e1d,0x224940cf}},	//   _बेटी_, श्ले, íchu, _dyak_,
   {{0x79820034,0x3e750294,0x00000000,0x00000000}},	//   zpow, _ụta_, --, --,
   {{0xdb1c025b,0xdcba1757,0x15e300c3,0x00000000}},	//   _oprá, ैज्ञ, _कछार_, --,
   {{0x6da31525,0xada30131,0x7bc740d0,0x8cc1023a}},	// [36a0] лита, латл, _apju, र्भो,
   {{0x02c1397e,0x00000000,0x00000000,0x00000000}},	//   ष्ठभ, --, --, --,
   {{0x1ee80018,0x7ac627a5,0x25ad034f,0xbcfb00fd}},	//   _ہوگی_, есле, huel_, _puér,
   {{0xbcfb283f,0x25ad09a4,0x60dc0e94,0xaca40065}},	//   _quér, kuel_, ldrm, _iyọr,
   {{0x61e22cea,0xdced03e5,0x00000000,0x00000000}},	//   _šolj, ssaġ, --, --,
   {{0x6b510149,0x2a6d0139,0x25ad40d1,0x3eb2004b}},	//   råga, _egeb_, duel_, lgyt_,
   {{0xfaa601b3,0xb766166f,0x00000000,0x00000000}},	//   _паво, нтий, --, --,
   {{0x61e40d79,0xd90e0281,0x00000000,0x00000000}},	//   _oril, _گیت_, --, --,
   {{0x25ad40d2,0x6d5e00da,0xc5260161,0x00000000}},	//   guel_, ompa, еќни, --,
   {{0xe9d700d6,0x6b9c0880,0x3a23067f,0x00000000}},	//   _яку_, _kvrg, _смуг, --,
   {{0x66e621b4,0xdb1c000d,0x22491d49,0xf8b30796}},	//   _пожа, _zprá, _syak_, _תשע_,
   {{0x61e440d3,0x20180063,0x6b9c0381,0x00000000}},	//   _bril, dzri_, _mvrg, --,
   {{0x236940d4,0x69060102,0xaca40065,0x3f57020d}},	//   _viaj_, _aðei, _ayọr, nçue_,
   {{0x2eeb00fd,0x61e440d5,0x6b9c05db,0x00000000}},	//   _sncf_, _dril, _ovrg, --,
   {{0x2369022e,0x61e40d80,0xb4ac1376,0xe9ff0019}},	//   _tiaj_, _eril, गली_, _khảo_,
   {{0x61e440d6,0x22490270,0x1c1e00a4,0x6d5e00ce}},	//   _fril, _tyak_, _येइल_, empa,
   {{0x6722068d,0x6ca70938,0x31720113,0x22490113}},	// [36b0] _mmoj, ереж, _guyz_, _uyak_,
   {{0x63a840d7,0x656a0078,0x00000000,0x00000000}},	//   ordn, _jifh, --, --,
   {{0xdb1c0871,0x6e2a00a7,0x7bda21f7,0x61e40234}},	//   _sprá, _əlbə, _štur, _zril,
   {{0xa5a10034,0x644a058f,0x6d5e40d8,0x00000000}},	//   _खिलौ, _myfi, ampa, --,
   {{0x25ad00fd,0x0ab403c5,0x644a40d9,0x00000000}},	//   xuel_, احمد, _lyfi, --,
   {{0x7f4d1175,0x67220065,0xbb850037,0x7bcb00ae}},	//   llaq, _amoj, _للسي, ăgub,
   {{0xe739075f,0x644a2708,0x58940037,0x00000000}},	//   мек_, _nyfi, اجهز, --,
   {{0x25ad40da,0xe9ff0023,0xb88302c6,0xa3e40469}},	//   tuel_, _chảo_, _svíč, निन_,
   {{0x6f0300ae,0xaefb01b5,0x6b6c0233,0x6d470090}},	//   _încu, _ciùi, _işga, _kkja,
   {{0x25ad167e,0xaefb01b9,0x80ad277c,0x69c940db}},	//   ruel_, _diùi, _जागे, _ipee,
   {{0x63a800cc,0x644a0150,0x25ad40dc,0x7e7d0a60}},	//   grdn, _cyfi, suel_, _ofsp,
   {{0x644a40dd,0x00000000,0x00000000,0x00000000}},	//   _dyfi, --, --, --,
   {{0x25ad40de,0x1c1e02e8,0x6d5e3dc0,0x63a80167}},	//   quel_, _येईल_, ympa, ardn,
   {{0x7e7d40df,0xe5a20221,0x64a5243c,0x691401b9}},	//   _afsp, _тиши, _рака, _gàed,
   {{0x21671a18,0x764b0150,0x644a00f0,0x00000000}},	//   тири_, _hygy, _gyfi, --,
   {{0x61e440e0,0x69c90137,0x8464008f,0x05c50285}},	//   _tril, _opee, _съче, _वहाब,
   {{0x61e4002d,0x69c9023e,0x0e66302e,0x6b9c0335}},	// [36c0] _uril, _npee, ткан, _svrg,
   {{0xc006120a,0xdced00a7,0x776b063d,0x6aa00537}},	//   _апок, rpağ, _ligx, _sdmf,
   {{0xeb9740e1,0x7d030149,0x6b510149,0x69c90032}},	//   вих_, önsa, rågn, _apee,
   {{0xfaa61fc4,0x776b063d,0x00000000,0x00000000}},	//   тадо, _nigx, --, --,
   {{0xceb30130,0x827700c1,0x99d30076,0x00000000}},	//   _דיר_, דענע_, لتوا, --,
   {{0x92ce0081,0x6b5840e2,0x8cc10be4,0x3f57020d}},	//   রায়_, díge, र्दो, rçue_,
   {{0xdbcc0088,0xc01000de,0xaefb01ec,0x69c940e3}},	//   _góða, _đuổi_, _siùi, _epee,
   {{0xceb40092,0x95d818c6,0x94050092,0x63a814f3}},	//   ciət_, едит_, qalə_, vrdn,
   {{0x948600ae,0xb0b200c3,0x5b3500ae,0x00000000}},	//   кынд, _जांग, _сэру, --,
   {{0xb4ac2183,0x6ad20f53,0x44f40114,0x2bc90c22}},	//   गले_, _ससुर, упос, _रहमा,
   {{0xe9ff0028,0x929540e4,0xd6cf2569,0x00000000}},	//   _thảo_, ланц, _кт_, --,
   {{0xdb9b00f5,0x6722068d,0xf62640e5,0x762600ae}},	//   וסטר, _umoj, _идео, _имез,
   {{0x69dd01cd,0x26c60139,0x644a0313,0x833403a0}},	//   _áset, _iboo_, _wyfi, рнях,
   {{0x349440e6,0xdb05020d,0x00000000,0x00000000}},	//   _сакр, rrhé, --, --,
   {{0xe7e524eb,0x7f4d009e,0x40350396,0x75280325}},	//   किया_, tlaq, уевс, midz,
   {{0xb7db0341,0x6d4740e7,0x752840e8,0xfcd90018}},	//   וקלי, _skja, lidz, کارڈ_,
   {{0x2d8f025a,0x7e55004d,0x7f4d0abd,0x26c6024a}},	// [36d0] ège_, уває, rlaq, _mboo_,
   {{0x752811bc,0x48bd0033,0x9d1400d3,0xe9ff020b}},	//   nidz, _আফ্র, адуч, _nhạo_,
   {{0x69c940e9,0x7a0a01d3,0xf1bf0850,0x7f4d014b}},	//   _spee, _lētā, ltá_, plaq,
   {{0x7b3c0106,0x6b510212,0x6f1604f8,0xee840b2f}},	//   jčud, rågo, chyc, _выро,
   {{0xf1bf40ea,0x8d8703bf,0x7b13016d,0x752811bc}},	//   ntá_, _шунд, _açuc, kidz,
   {{0x6f0d40eb,0x26c6010a,0xb4ac0096,0xf1bf0131}},	//   lkac, _aboo_, गलो_, itá_,
   {{0xf77106f6,0x6d4511a3,0x3158006e,0x00000000}},	//   حات_, moha, דיגן_, --,
   {{0x6d4540ec,0xdb0500e3,0x6f0d40ed,0x6b580850}},	//   loha, rthó, nkac, tíge,
   {{0x7528005c,0x645c003e,0x00000000,0x00000000}},	//   fidz, ýrin, --, --,
   {{0x6b5840ee,0x7c2804e9,0xe6160ed4,0x6f0d0113}},	//   ríge, _ždri, удь_, hkac,
   {{0xc2090796,0x6f0d01c2,0xf1bf0131,0x00000000}},	//   _צה_, kkac, etá_, --,
   {{0xa77a00c1,0x26c60294,0xd83800d3,0x00000000}},	//   _טרעפ, _gboo_, _рэу_, --,
   {{0xa3d3110f,0x6d4540ef,0x672940f0,0xe5a50f32}},	//   _सैर_, koha, miej, _сили,
   {{0x6d4540f1,0x3ea2005c,0x6729013f,0xf487235c}},	//   joha, _sdkt_, liej, _рудн,
   {{0x37c300c7,0x26dd1114,0x6d450498,0x66090018}},	//   ্মকর, _kawo_, doha, lyek,
   {{0x672940f2,0x26dd006d,0x26df0138,0x25bf00ae}},	//   niej, _jawo_, nduo_, otul_,
   {{0x25bf0012,0x660940f3,0xecea2922,0xceb40092}},	// [36e0] ntul_, nyek, ндал_, rgə_,
   {{0x62960eac,0x25bf00ae,0x98a70138,0xa3c732c9}},	//   _heyo, itul_, monė_, _उहा_,
   {{0x6729007f,0x4aaa2a84,0x25bf40f4,0xa25b0231}},	//   kiej, екен_, htul_, nfôn,
   {{0x26dd40f5,0xa3e424eb,0x6f0d21cb,0x2fda0027}},	//   _nawo_, नित_, ckac, _ispg_,
   {{0x6d4540f6,0xe81c0034,0x25bf2acb,0x672940f7}},	//   boha, _भेजा_, jtul_, diej,
   {{0x26dd40f8,0x6d450035,0x6f0300d3,0xdb1c0212}},	//   _aawo_, coha, _încr, _sprä,
   {{0x6d5c40f9,0x26dd40fa,0x25bf020a,0x60de3177}},	//   _ihra, _bawo_, etul_, _mapm,
   {{0x758a036a,0x75280034,0xf1bf0094,0x25bf020a}},	//   нсов_, widz, ytá_, ftul_,
   {{0x26dd40fb,0x163440fc,0xe9ff0023,0x8cc10be5}},	//   _dawo_, репя, _thạo_, र्वो,
   {{0x88bc030b,0x00000000,0x00000000,0x00000000}},	//   _změn, --, --, --,
   {{0x25bf00ae,0xdb1e023b,0x752840fd,0x629640fe}},	//   atul_, jtpë, ridz, _beyo,
   {{0xa3a9000f,0x667600e3,0x660940ff,0x6d454100}},	//   गंज_, _إدار, byek, zoha,
   {{0x25bf002d,0x6d5c2516,0x6d4511b9,0x6296022b}},	//   ctul_, _ohra, yoha, _deyo,
   {{0x60de4101,0x863700ca,0x26dd4102,0xf1bf4103}},	//   _capm, _גאדג_, _zawo_, rtá_,
   {{0x6d45001f,0xf1bf0244,0xe47b00a1,0x26dd4104}},	//   voha, stá_, _ארוכ, _yawo_,
   {{0x64584105,0xfe730308,0x6d454106,0x6296250c}},	//   _izvi, صدر_, woha, _geyo,
   {{0x6f0d4107,0x6d454108,0x6d5c0a1b,0xcec002c6}},	// [36f0] rkac, toha, _bhra, ířat_,
   {{0xb0b20067,0x6d5c03ea,0x67290138,0x6f0d4109}},	//   _जाएग, _chra, ziej, skac,
   {{0x62960010,0x3a751da3,0x2d5400bc,0x6d5c410a}},	//   _yeyo, алер, mäel_, _dhra,
   {{0x98a9005f,0x6d45410b,0x8c643ad0,0x8d771b71}},	//   đač_, soha, студ, _ماسا,
   {{0x60de0b88,0x6d5c02bc,0x39a70315,0x25bf00ae}},	//   _yapm, _fhra, ушев, xtul_,
   {{0x6d5c0a02,0x26dd410c,0xbebb0052,0x00000000}},	//   _ghra, _sawo_, _njëz, --,
   {{0xdb1c1c82,0x67290138,0xb8cd00bc,0xa8021e6b}},	//   _språ, tiej, _कय_, şınl,
   {{0x88bc00b6,0x66090113,0x661b01e9,0xaefb01b9}},	//   _uměn, tyek, tzuk, _dhùg,
   {{0x6296410d,0x672900c6,0xa8a713c9,0x45353031}},	//   _reyo, riej, _брек, ихот,
   {{0x25bf002d,0x661b0a40,0x6296410e,0x67291c8a}},	//   rtul_, rzuk, _seyo, siej,
   {{0x25bf0012,0x661b0067,0x26dd1098,0x47d50037}},	//   stul_, szuk, _tawo_, _خيار,
   {{0x25bf0012,0x3947410f,0xb17b0149,0x232a05c7}},	//   ptul_, lons_, rvån, томи_,
   {{0x80df0081,0xbbd1063c,0xaefb01b9,0x00000000}},	//   মান্, सबुक, _liùs, --,
   {{0x39474110,0x66060084,0x25ad0220,0x361a0266}},	//   nons_, äkke, mrel_, _בונד,
   {{0x5f064111,0xdfd200e3,0x6e3d0113,0x1e9600d3}},	//   азва, غير_, _axsb, ирар,
   {{0x1e863d03,0x6d5c4112,0x394700fd,0x60de4113}},	//   рлам, _shra, hons_, _wapm,
   {{0xa156013d,0x60de4114,0x6d5c4115,0x1d2614e8}},	// [3700] _външ, _tapm, _phra, амам,
   {{0xdca64116,0x39474117,0x2fdf007f,0xfe7f00fc}},	//   ражи, jons_, ługa_, _naïf_,
   {{0x60c30103,0x61e64118,0x00000000,0x00000000}},	//   _önma, lvkl, --, --,
   {{0xdee60284,0x25ad0537,0x00000000,0x00000000}},	//   _томи, krel_, --, --,
   {{0x6d5c01f5,0x39474119,0xd90d09b4,0xaefb01b9}},	//   _thra, fons_, کیل_, _shùg,
   {{0x97a60ed8,0x6d5c411a,0x3947411b,0x00000000}},	//   арил, _uhra, gons_, --,
   {{0xf0930054,0xeb970cc0,0x81cc0033,0x320b007f}},	//   חנו_, _вис_, রটি_, zycy_,
   {{0xbb430012,0xa3e409a0,0x7bdb00ca,0xaefb009c}},	//   _деск, निस_, _בקלו, _hiùr,
   {{0xc6f70fdf,0x394700ee,0x140e0179,0xbddb014b}},	//   рных_, bons_, ान्ह_, _hyèr,
   {{0x7ae2411c,0x81cc0033,0x7ae0411d,0xd90e0470}},	//   ldot, রটা_, _hamt, _زیب_,
   {{0x2f150212,0x69c2318e,0x7ae21894,0x3c770327}},	//   _låga_, ltoe, odot, יתים_,
   {{0x7ae2411e,0xaefb01b9,0x64580141,0x320b007f}},	//   ndot, _liùr, _vzvi, tycy_,
   {{0x69c2411f,0x273a00e8,0x7ae219db,0x00000000}},	//   ntoe, cīna_, idot, --,
   {{0x29c20028,0x7ae200c2,0x2d050096,0x7ae04120}},	//   _mưa_, hdot, _शकेल_, _lamt,
   {{0x753d0068,0x64584121,0x69c20084,0x7ae24122}},	//   észe, _uzvi, htoe, kdot,
   {{0x7ae04123,0x69c24124,0x00000000,0x00000000}},	//   _namt, ktoe, --, --,
   {{0x629d4125,0x39470257,0x7ae24126,0x7bdc4127}},	// [3710] maso, yons_, ddot, _asru,
   {{0x39474128,0x30a74129,0x6abb412a,0xaefb01ec}},	//   xons_, _трив, _scuf, _ciùr,
   {{0x39470257,0xaefb01f7,0x7ae00415,0x25ad0206}},	//   vons_, _diùr, _bamt, zrel_,
   {{0x629d00f9,0x06ac00c7,0x7ae000dc,0x28c40469}},	//   naso, ক্তি, _camt, ल्सि,
   {{0xa2bc20cd,0x3947412b,0xa6be0033,0x394c0361}},	//   ष्ट्, tons_, ্যায়, _bkds_,
   {{0x629d412c,0x88bc030b,0x29c200de,0x69340231}},	//   haso, _uměl, _dưa_, ончу,
   {{0x3947412d,0xb8ff412e,0xbddb022b,0x00000000}},	//   rons_, _तस_, _tyès, --,
   {{0x4975321c,0x7ae0013f,0x3947412f,0x7ae24130}},	//   _глас, _gamt, sons_, cdot,
   {{0x629d4131,0x394740b7,0x69c204c3,0x263e0134}},	//   daso, pons_, ctoe, ịon_,
   {{0x7ae04132,0x25ad4133,0x273a00e8,0x00000000}},	//   _zamt, rrel_, rīna_, --,
   {{0xe29a282a,0x04452e9e,0x94070092,0x7ae04134}},	//   лан_, сенн, _yenə_, _yamt,
   {{0x29054135,0x2d851b30,0x68e132a7,0x59bb02d5}},	//   _hola_, _člen_, _hald, _ईमार,
   {{0x68e14136,0x29051a36,0x29c20019,0x33290d6e}},	//   _kald, _kola_, _xưa_, _dmax_,
   {{0x61e202dd,0x68e300dd,0x70b20096,0xc5f200ca}},	//   _šols, ndnd, जलेल, _מדד_,
   {{0x8cca034c,0x09d405cd,0x29054137,0xb4b3009d}},	//   स्फो, _धन्य, _mola_, टली_,
   {{0x290507ac,0x629d0610,0x69c24138,0xaefb01b9}},	//   _lola_, caso, ytoe, _siùr,
   {{0x60d500e7,0x7ae002b6,0x63a3010a,0xaefb009c}},	// [3720] bezm, _ramt, _hvnn, _piùr,
   {{0x7ae04139,0x290502a7,0x2f15320e,0xaefb01ec}},	//   _samt, _nola_, _våga_, _chùb,
   {{0x7ae004a3,0x940c01d4,0x2360023e,0xaefb01ec}},	//   _pamt, fadə_, _khij_, _dhùb,
   {{0xb21b003e,0x2b5f00de,0x9b2516dd,0x3329413a}},	//   mbær, _chuc_, офіл, _xmax_,
   {{0x68e1413b,0x29051fe2,0xd910037f,0x59f8413c}},	//   _bald, _bola_, ویر_, реля_,
   {{0x69c2413d,0xd94300c2,0xa802026a,0x7ae0413e}},	//   rtoe, печи, şıml, _wamt,
   {{0x69c21897,0x2905413f,0x629d4140,0x6d4e0078}},	//   stoe, _dola_, yaso, _ikba,
   {{0xdc3700c1,0x69c218f0,0x6f0605db,0x98bc00c6}},	//   _האלט_, ptoe, _jokc, dovą_,
   {{0x68e14141,0x6b584142,0x80df0081,0x629d4143}},	//   _fald, lígo, মাত্, vaso,
   {{0x68e14144,0x28c40789,0x629d4145,0x6f0603e3}},	//   _gald, ल्शि, waso, _lokc,
   {{0x629d4146,0x8cca0034,0x24584147,0x06e00033}},	//   taso, स्यो, рань_, ভাবি,
   {{0x23a9000f,0x2360022e,0x68e101e9,0x2d05009f}},	//   _किरद, _chij_, _zald, _शक्ल_,
   {{0x629d05f9,0x29054148,0xdcef00d3,0x7d03238c}},	//   raso, _yola_, _jucă, önsk,
   {{0x463b00c1,0x629d0a00,0x777a01e9,0xd7dc0096}},	//   _געדע, saso, _kutx, _मनाच,
   {{0xaac81e5e,0x629d4149,0x4ac804f8,0x5f940012}},	//   रभाक, paso, रभाव, зист,
   {{0x6d4e414a,0x777a303d,0x80df0033,0x9f550120}},	//   _akba, _mutx, মাধ্, івач,
   {{0x246e00a7,0x777a01c8,0x3f9e01cd,0xaefb009c}},	// [3730] ləm_, _lutx, átur_, _phùb,
   {{0xe29f0088,0x61ed3f91,0xfe7f00fc,0x00000000}},	//   lað_, _iral, _saïd_, --,
   {{0x2905414b,0x2b5f00de,0xf2dc0033,0x61ed0031}},	//   _rola_, _phuc_, ধারণ, _hral,
   {{0x61ed0335,0xe29f0102,0xdcef00ae,0x6b58414c}},	//   _kral, nað_, _bucă, sígn,
   {{0x290503be,0x7c872f0c,0x99d700e3,0x68e1414d}},	//   _pola_, _губе, إتصا, _pald,
   {{0x68e133bc,0xa9690097,0x777a414e,0x27ec009c}},	//   _qald, шила_, _butx, _brdn_,
   {{0x68e1414f,0xe29f0088,0x29054150,0x2b5f00de}},	//   _vald, kað_, _vola_, _thuc_,
   {{0x68e14151,0x7bc536e4,0x777a28fd,0x05a93c75}},	//   _wald, mthu, _dutx, авий_,
   {{0x68e103f3,0x7bc54152,0xe57602e3,0x2905023b}},	//   _tald, lthu, озы_, _tola_,
   {{0xb4b34153,0x79894154,0xdb1c01df,0x628406a2}},	//   टले_, _itew, _sprø, _sfio,
   {{0x61ed4155,0x7bc54156,0x777a02a7,0x394000e3}},	//   _aral, nthu, _gutx, éise_,
   {{0x61ed103b,0xe29f003e,0x7bc54157,0x6aa90090}},	//   _bral, gað_, ithu, _jdef,
   {{0x64a535ca,0x61ed009c,0x7bc54158,0x00000000}},	//   _дала, _cral, hthu, --,
   {{0xd5674159,0xe3b1415a,0x7bc5415b,0x00000000}},	//   _утеп, _قرب_, kthu, --,
   {{0xe7ec1349,0xa06a415c,0x61ed415d,0x2360023e}},	//   झिया_, рава_, _eral, _thij_,
   {{0x61ed415e,0x6aa90239,0xb21b338b,0x79890172}},	//   _fral, _ndef, rbær, _otew,
   {{0x61ed415f,0x6d4300d4,0x6e294160,0x00000000}},	// [3740] _gral, čnan, _žebr, --,
   {{0x27161cff,0x6aa90139,0x7d070a39,0xdb050094}},	//   _तत्र_, _adef, _cojs, vrhá,
   {{0x8b2600d6,0x6f060085,0x79890169,0x672b0120}},	//   одже, _tokc, _atew, _omgj,
   {{0xa802026a,0x39ea2636,0xb066007b,0xdb0500d4}},	//   şıkl, идео_, _enää, trhá,
   {{0x6aa902ad,0x2d4f05fe,0xa3bb0034,0x3ea04161}},	//   _ddef, gües_, इंड_, mait_,
   {{0x3ea04162,0xed570f00,0xf1bf0018,0xd8381c54}},	//   lait_, _моя_, szág_, _leče_,
   {{0xfbc34163,0xd7fa0a29,0x79890172,0x7bc5020b}},	//   _обро, рул_, _etew, cthu,
   {{0x3ea04164,0xc6f84064,0xd8380344,0x00000000}},	//   nait_, сних_, _neče_, --,
   {{0xe29f0088,0xb17b004d,0xb0ca269c,0xdcee4165}},	//   vað_, rvåk, िभाग, _libč,
   {{0x61ed00dd,0x38c80688,0xdb210018,0x38cb0260}},	//   _rral, _داری_, ütör, _نامی_,
   {{0xe29f0102,0x06ac0081,0x00000000,0x00000000}},	//   tað_, ক্ষি, --, --,
   {{0x066500bf,0x246e01d4,0x61ed4166,0x8cca218b}},	//   _کامپ, rəm_, _pral, स्तो,
   {{0x3ea04167,0xe29f0088,0x36362876,0x41e402b7}},	//   dait_, rað_, _براس, міра,
   {{0x7bc500f0,0xe29f003e,0x25a60381,0x752a039f}},	//   ythu, sað_, _ivol_, _umfz,
   {{0xbbc9033a,0x7d0702dd,0xe29f003e,0x3ea000fd}},	//   _रहेक, _rojs, pað_, fait_,
   {{0x61ed4168,0x06ac0081,0xd6ac0081,0x61e917d2}},	//   _tral, ক্রি, ক্রয, åels,
   {{0x61ed4169,0x3f570233,0x753a0634,0x00000000}},	// [3750] _ural, lçuk_, ontz, --,
   {{0x7bc5416a,0xa2c10714,0x00000000,0x00000000}},	//   tthu, _वाड्, --, --,
   {{0x3ea0416b,0x7d07161f,0x753a01e9,0x7bc5416c}},	//   bait_, _vojs, intz, uthu,
   {{0x7d070034,0x61291528,0x776200fe,0x00000000}},	//   _wojs, džli, _nhox, --,
   {{0x7bc518f0,0x7d0701fa,0xa3e12dfd,0xe1ff00ee}},	//   sthu, _tojs, _नैन_, nxó_,
   {{0x92d70033,0x7762063d,0x0904018a,0x00000000}},	//   সায়_, _ahox, мпін, --,
   {{0x4809416d,0x00000000,0x00000000,0x00000000}},	//   сейн_, --, --, --,
   {{0x753a0a00,0x7b3c007e,0x6aa9108e,0x656802ac}},	//   entz, nčul, _udef, emdh,
   {{0x64460dea,0xd838389a,0x80dc0789,0x79890169}},	//   şkil, _reče_, _फसले, _utew,
   {{0x58bb00b1,0x6e20007a,0xe5763c9b,0x3ea0416e}},	//   _خارج_, _ümbe, язь_, zait_,
   {{0x6d890038,0xd8380433,0x3ea0416f,0x76754170}},	//   _hľad, _peče_, yait_, _елеф,
   {{0x96b84171,0x62810034,0x753a0634,0x776202a1}},	//   _душу_, ślon, antz, _ghox,
   {{0x3ea04172,0xd8381100,0x2131005c,0x2bd2052c}},	//   vait_, _veče_, fizh_, _सहभा,
   {{0x645d0253,0xeb1802d5,0xdd920068,0xeb082748}},	//   əsin, _दत्त_, ہور_, _वक्त_,
   {{0x3ea04173,0x2fd3002b,0x4421040f,0xd25901d3}},	//   tait_, _cpxg_, _åh_, ļņa_,
   {{0x673b4174,0x7769037a,0x0d860d62,0xdd924175}},	//   nnuj, nmex, злан, فور_,
   {{0x3ea04176,0xfe434177,0xb2bb00a1,0xc3330796}},	// [3760] rait_, енто, _המפר, _רוח_,
   {{0x3ea04178,0x00000000,0x00000000,0x00000000}},	//   sait_, --, --, --,
   {{0x3ea04179,0xa3e4417a,0xc0470023,0x307b00ca}},	//   pait_, निए_, _mượn_, _לאינ,
   {{0x63be00d6,0xc0470023,0x707600d1,0x00000000}},	//   _åpne, _lượn_, _واگذ, --,
   {{0xceb307a6,0x673b015c,0xd6c30081,0x80df0033}},	//   _איר_, dnuj, ্যায, মার্,
   {{0xf806004d,0x6e24417b,0x00000000,0x00000000}},	//   зчин, mzib, --, --,
   {{0x48fe00a3,0x00000000,0x00000000,0x00000000}},	//   लाबो_, --, --, --,
   {{0x1ae3417c,0x753d0103,0x673b12c5,0x00000000}},	//   _посм, észn, gnuj, --,
   {{0x6e24417d,0xbb4316bd,0xa9260231,0x00000000}},	//   nzib, _четк, _едал, --,
   {{0x47d40081,0x6b5102c3,0x6e24010a,0x753a0062}},	//   থিবী, bågs, izib, untz,
   {{0x4ae00096,0xa2c1087c,0x753a01ff,0x00000000}},	//   _नसाव, _वाद्, rntz, --,
   {{0x1dac417e,0xf6e500d6,0x6aa20051,0x394e417f}},	//   _चिंत, _оцін, naof, lofs_,
   {{0x6f043723,0x87250037,0x9f470113,0x00000000}},	//   djic, _تعلم, _éné_, --,
   {{0x98a700d3,0x6e244180,0xdc03023c,0xe3af01f9}},	//   mină_, dzib, _sčít, خری_,
   {{0x3d00084a,0xaefb0441,0x6aa20239,0x98a7020a}},	//   राने_, _dhùn, kaof, lină_,
   {{0x63ba0489,0x6d43033b,0x643b00ca,0x394e02db}},	//   mutn, čnam, _לעונ, hofs_,
   {{0xa3e40469,0xa2a20251,0x6aa20161,0x7b3c4181}},	// [3770] निक_, _ख़त्, daof, rčul,
   {{0xf1b20034,0x673b103b,0xdb1c0034,0x5d54002d}},	//   _जितन, znuj, _opró, екут,
   {{0x6e2406b0,0x00000000,0x00000000,0x00000000}},	//   azib, --, --, --,
   {{0xdb05023b,0x6f164182,0x5a350cb0,0xdc0300d8}},	//   mshë, ckyc, мнет, _učít,
   {{0xdb1c0018,0x63ba0146,0x67200052,0x98a7044c}},	//   _apró, hutn, dhmj, jină_,
   {{0x63ba005a,0xe9d8084c,0xdb1c0037,0xd6d90034}},	//   kutn, які_, _bpró, weł_,
   {{0x1bd44183,0xdb05023b,0x62860212,0x67d2001f}},	//   _поря, nshë, ycko, воју,
   {{0x63ba005c,0xe61930cf,0x629f4184,0x7b3c0e43}},	//   dutn, жди_, _neqo, hčuj,
   {{0x98a700d3,0x77691550,0x3dc9003d,0x98bc02c6}},	//   gină_, rmex, ntaw_, nově_,
   {{0x3d000251,0xe6c42a6c,0xdb05023b,0x799b0af0}},	//   राये_, češć, kshë, _iwuw,
   {{0x2d540006,0xdb05023b,0x78a34185,0xe3b6002d}},	//   päev_, jshë, manv, мбэ_,
   {{0x57270192,0x799b0134,0x3dc94186,0x47354187}},	//   _عراق, _kwuw, ktaw_, _юнес,
   {{0x3d0003b3,0xdb05023b,0x98a700ae,0xaefb0023}},	//   रामे_, eshë, cină_, _phùn,
   {{0x63ba0c71,0xdb05023b,0xdb1c0364,0x98bc02c6}},	//   butn, fshë, _sprü, dově_,
   {{0x06e00081,0x63ba0063,0x6f160031,0x2ab40af0}},	//   ভারি, cutn, tkyc, _júbà_,
   {{0xdbd90396,0x799b4188,0xd00f0103,0x3f8c00e8}},	//   nçõe, _owuw, گلہ_, īdu_,
   {{0xd8381711,0xdbd91097,0xaefb00de,0x6aa2028d}},	// [3780] _meča_, içõe, _thùn, vaof,
   {{0x61e44189,0x6f160031,0x5d671d64,0xd8380141}},	//   _isil, skyc, диум_, _leča_,
   {{0x6f660396,0x0aea004c,0xb6a30023,0x799b0372}},	//   _овоз, ждей_, _phầ, _awuw,
   {{0x60dc418a,0x7c650241,0xdb1c0154,0xddcb3402}},	//   lerm, رالل, _aprò, žišk,
   {{0xa2c10789,0xdb1c0034,0x2baa009f,0x2f1c0af0}},	//   _वास्, _spró, _चटका, _gíga_,
   {{0xa91d0335,0x98a700ae,0x7d030212,0xeb9a05cb}},	//   _nužd, vină_, önst, _миг_,
   {{0x38cb0814,0xd83800cc,0x799b083e,0x61e4010a}},	//   تانی_, _beča_, _ewuw, _lsil,
   {{0x60dc418b,0x61e4418c,0x8cca201e,0x98a7020a}},	//   herm, _osil, स्रो, tină_,
   {{0x60dc1888,0x75d400e3,0x61e4010a,0x00000000}},	//   kerm, ريدا, _nsil, --,
   {{0x2fdf0067,0x63ba08d3,0xdbd90161,0x60dc004d}},	//   ługi_, tutn, açõe, jerm,
   {{0x61e4418d,0x290c0124,0x291e00c2,0x60dc418e}},	//   _asil, _ioda_, _ilta_, derm,
   {{0x68e8418f,0x290c005f,0x7980090d,0x63ba02e7}},	//   _hadd, _hoda_, _kumw, rutn,
   {{0x60dc1763,0x63ba03ce,0x68e84190,0x6aa0063f}},	//   ferm, sutn, _kadd, _memf,
   {{0x79803304,0xdb0500dd,0x68e84191,0x60dc4192}},	//   _mumw, tshë, _jadd, germ,
   {{0x68e80702,0x61e44193,0x7b3c1420,0x63ba0063}},	//   _madd, _esil, rčuj, qutn,
   {{0xc3280080,0xdb0500dd,0x290c4194,0x3dc9003d}},	//   _يكون_, rshë, _loda_, ttaw_,
   {{0x645802fd,0x68fa043e,0x8d790037,0xdb050052}},	// [3790] _hyvi, _ontd, سماء_, sshë,
   {{0x290c4195,0x68e80517,0x60dc4196,0xa91d1b32}},	//   _noda_, _nadd, cerm, _kuže,
   {{0x3dc94197,0xa3e4167f,0x60c50154,0x691401ec}},	//   staw_, निट_, _ichm, _gàei,
   {{0x160e33c5,0xbebb023b,0x290c009c,0xfbd0001c}},	//   िहार_, _emër, _aoda_, شتم_,
   {{0x68e81ed1,0x290c4198,0x3f814199,0x19591402}},	//   _badd, _boda_, _huhu_, пады_,
   {{0x41b200a5,0x290c0755,0x3f81007a,0x02dc030b}},	//   _जिसस, _coda_, _kuhu_, _बस्न,
   {{0xa91d015c,0xa92701d3,0x3f81419a,0x6aa024dd}},	//   _ružd, _režī, _juhu_, _femf,
   {{0x78a30517,0x68fa01bf,0x59b109c3,0x290c01ff}},	//   sanv, _entd, ुंदर, _eoda_,
   {{0x7afb419b,0x290c419c,0xb9b506fa,0xdbd90161}},	//   _inut, _foda_, _سماع, rçõe,
   {{0x68e824ae,0x290c419d,0x7afb0146,0x7ae900c2}},	//   _gadd, _goda_, _hnut, _haet,
   {{0x60dc0c8b,0x3f81419e,0x7afb2548,0x29c90487}},	//   verm, _nuhu_, _knut, lúa_,
   {{0x78a1419f,0x61e401af,0x60c541a0,0x8c1a00a1}},	//   _helv, _psil, _achm, פורי,
   {{0xa2c1000c,0x68e841a1,0x60dc41a2,0x29c90fb6}},	//   _वार्, _yadd, term, núa_,
   {{0x7ae900e3,0x3f8103e3,0xafe6107a,0x61e40117}},	//   _laet, _buhu_, ногл, _vsil,
   {{0x69cb41a3,0xf484098a,0xb4ab0096,0x6a76026a}},	//   htge, _ручн, गणी_, _küfü,
   {{0xdee341a4,0xe45600c1,0x60dc41a5,0x61e441a6}},	//   лоси, _איצט_, serm, _tsil,
   {{0xc69200c1,0x69c9023e,0xf772006e,0x733b006e}},	// [37a0] טאן_, _nqee, רקן_, _מעקס,
   {{0x7afb14e6,0x798002a4,0xafe61553,0x69cb042c}},	//   _anut, _rumw, _зоол, dtge,
   {{0x68e841a7,0x69c90063,0x6aa02cf8,0x7980343c}},	//   _radd, _aqee, _pemf, _sumw,
   {{0x6d5541a8,0x7ae941a9,0x61220181,0x79800270}},	//   _ekza, _caet, _dôle, _pumw,
   {{0x7ae90150,0xb17b040f,0x78a141aa,0x2bd209c4}},	//   _daet, lvår, _belv, _सहवा,
   {{0x68e82062,0x6122016d,0x7ae901ff,0x78a10350}},	//   _qadd, _fôle, _eaet, _celv,
   {{0xa2c1018b,0xb90814e5,0x78a10429,0x9d4322de}},	//   _वाल्, _बस_, _delv, _серд,
   {{0x68e841ab,0x8b6600bf,0x7ae941ac,0x765902ad}},	//   _wadd, _سازم, _gaet, _bywy,
   {{0x290c132d,0xa84a00d0,0x78a10018,0x68e841ad}},	//   _toda_, _کلام_, _felv, _tadd,
   {{0x3c2503f3,0x2d8241ae,0xb17b0149,0x3ea241af}},	//   _vзvv_, _muke_, kvår, _lekt_,
   {{0x7d0e41b0,0x929541b1,0x2d820158,0x332001ce}},	//   _mobs, канц, _luke_, _blix_,
   {{0x60c502e2,0x64580146,0x332041b2,0x3f570428}},	//   _schm, _vyvi, _clix_, nçut_,
   {{0x3f8126f7,0x6e3b0220,0xd24400d3,0x7d0e00f9}},	//   _suhu_, _ľubo, гэри, _oobs,
   {{0xd5b90565,0x7d0e0090,0x3f8128b4,0x00000000}},	//   _ісі_, _nobs, _puhu_, --,
   {{0xdfd8013d,0x332000ee,0xbf1c08d4,0x6b580072}},	//   нът_, _flix_, नसून_, lígu,
   {{0x2d8241b3,0x611807e7,0x6122020d,0x33200131}},	//   _buke_, _ağlı, _rôle, _glix_,
   {{0x2d8202ef,0xe7e20034,0x5d550cba,0x29070034}},	// [37b0] _cuke_, _कैसा_, вкат, yjna_,
   {{0x2d821bc8,0x7ae941b4,0xe6dd00af,0x7afb169c}},	//   _duke_, _saet, _मस्ज, _snut,
   {{0x2369023e,0x7ae941b5,0x78a100aa,0xe3b8071d}},	//   _khaj_, _paet, _relv, nrı_,
   {{0x78a141b6,0x26c601fa,0x29c904d8,0x6122016d}},	//   _selv, _ncoo_, túa_, _vôle,
   {{0x7afb0e43,0x00000000,0x00000000,0x00000000}},	//   _vnut, --, --, --,
   {{0x69cb0418,0x88bc00b6,0x7ae900f0,0x29c941b7}},	//   rtge, _směr, _waet, rúa_,
   {{0x69cb41b8,0x7ae941b9,0x29c91ba6,0x2d5402db}},	//   stge, _taet, súa_, päer_,
   {{0xf77104f4,0x26c60575,0xadc40065,0x78a11044}},	//   جات_, _ccoo_, _akẹr, _welv,
   {{0x49750aa8,0x9fb6030b,0x99d40246,0x645c41ba}},	//   _алас, vřít_, _متلا, ürin,
   {{0xe97533c6,0x26c60036,0x2ca30090,0x64bd023a}},	//   _شهاد, _ecoo_, _jejd_, ्भेश,
   {{0xa91d1419,0xecc62231,0xa80203e0,0x3f57020d}},	//   _tužb, र्टफ, şırl, nçus_,
   {{0x76590150,0x6f0f0451,0x23690383,0xf1bf0143}},	//   _tywy, _nocc, _chaj_, rzán_,
   {{0xf1bf016d,0x3ea20381,0x00000000,0x00000000}},	//   guá_, _rekt_, --, --,
   {{0x2d8202e6,0x2bd2009f,0x3ea241bb,0x2ca30090}},	//   _ruke_, _सहला, _sekt_, _nejd_,
   {{0x2d820a75,0x10a341bc,0x6f0f008f,0x28c90179}},	//   _suke_, рисн, _bocc, _रानि,
   {{0x2d820bb6,0x6f0f41bd,0x2216022a,0xdcf5022b}},	//   _puke_, _cocc, _афор, _dizč,
   {{0x6da6021c,0x6f0f008f,0x3ea200d6,0xb17b0212}},	// [37c0] тиза, _docc, _vekt_, rvår,
   {{0x2a7f009c,0xb17b0212,0x3ea201cb,0x6f0f033c}},	//   _agub_, svår, _wekt_, _eocc,
   {{0x7c2901c2,0xa7fc008b,0x00000000,0x00000000}},	//   _ƙera, _azın, --, --,
   {{0x6f0f00e5,0x98a716c3,0x61f60324,0x2d8241be}},	//   _gocc, minę_, _kryl, _tuke_,
   {{0x98a7402f,0x7d0e3079,0x00000000,0x00000000}},	//   linę_, _tobs, --, --,
   {{0x6f0f0451,0x25bf41bf,0x7b3c0095,0xb227003e}},	//   _zocc, duul_, jčuv, _hræð,
   {{0x6a8641c0,0xb8da0252,0xec773097,0x98a70138}},	//   _алба, _आए_, _апр_, ninę_,
   {{0x6d5e41c1,0x2ca341c2,0x2fda0063,0xd7f7020f}},	//   llpa, _zejd_, _mppg_, туш_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe29a0028,0xa8020092,0x660f0149,0xfe7f0428}},	//   _đưa_, şıql, äcka, _raïm_,
   {{0x2369022e,0x918200de,0x337541c3,0xfe7f00b3}},	//   _phaj_, yện_, лгор, _saïm_,
   {{0x61f6038c,0x98a700c6,0xe3b80233,0xf1bf0231}},	//   _bryl, dinę_, rrı_, tuá_,
   {{0x6f0f008f,0x2b460031,0xba9b00ca,0xd05d013c}},	//   _rocc, čoch_, וסכי, əyən,
   {{0x6f0f41c4,0x2f150572,0x61f60178,0x6d5e0629}},	//   _socc, _lågt_, _dryl, jlpa,
   {{0x23690197,0xb4be0490,0x443a00aa,0x6f0f0036}},	//   _thaj_, इली_, _äp_, _pocc,
   {{0x5eb408d8,0x20070428,0x6d5e09ec,0xa91d00c4}},	//   ийст, _ànim_, elpa, _muža,
   {{0x6ca70699,0x2ca305db,0x00000000,0x00000000}},	// [37d0] вреж, _pejd_, --, --,
   {{0x672200dd,0x98a716d7,0xdb170072,0xaefb01b9}},	//   _lloj, binę_, ruxí, _mhùi,
   {{0x6f0f008f,0xb2270088,0x28c90179,0xa91d0880}},	//   _tocc, _fræð, _राबि, _nuža,
   {{0x3f57020d,0x27f902c6,0xb22701cd,0x6d5e058f}},	//   rçus_, _čsn_, _græð, alpa,
   {{0x3ea941c5,0x6eba00ca,0x271f278e,0x2ca30090}},	//   maat_, _אזרח, _बतौर_, _tejd_,
   {{0xeb930dd0,0x3ea93ba3,0x672241c6,0x18692b94}},	//   _نظر_, laat_, _aloj, нали_,
   {{0x98a20084,0xb8db3aee,0x3d00023a,0xa3e100b6}},	//   щище, _अय_, रारे_, _नैं_,
   {{0x3ea912ea,0xa6e541c7,0xa91d2392,0xaefb0441}},	//   naat_, ужил, _duža, _bhùi,
   {{0x8cca0be4,0xaefb01b5,0xe57941c8,0x656a0503}},	//   स्को, _chùi, нзи_, _bhfh,
   {{0x3ea941c9,0xaefb0441,0x49900103,0x00000000}},	//   haat_, _dhùi, _بیور, --,
   {{0x672241ca,0x25bf0188,0x656a01b9,0x656f02c6}},	//   _floj, suul_, _dhfh, ůcho,
   {{0x15f51e53,0x61f60149,0x6b581d32,0x212f0174}},	//   _مستح, _pryl, lígr, _įgha_,
   {{0x3ea941cb,0x6d4706b0,0xddd40206,0xba3d02c6}},	//   daat_, _ojja, _ťažn, _zdůr,
   {{0x64a541cc,0x25ad2fe8,0x98a7013f,0x672200e7}},	//   _сака, msel_, tinę_, _zloj,
   {{0x25ad41cd,0x3ea941ce,0x201e41cf,0x63ba0234}},	//   lsel_, faat_, áti_, crtn,
   {{0xa3b817ff,0x543a00c1,0x61f641d0,0x3ea941d1}},	//   _चित_, _רעקא, _tryl, gaat_,
   {{0x201e41d2,0x25ad41d3,0x3d0017ad,0x98a700c6}},	// [37e0] šti_, nsel_, राले_, sinę_,
   {{0x319b0105,0xb19b0341,0x25ad0eb3,0x527b006e}},	//   _רבינ, _רייכ, isel_, _אנפא,
   {{0xf5360130,0x69db0890,0xeb9a0b91,0x25e500a5}},	//   נטער_, _apue, хие_, _जैसी_,
   {{0x25ad41d4,0x3ea941d5,0xa91d0995,0x6d470361}},	//   ksel_, caat_, _ruža, _ejja,
   {{0x99d300e3,0xa91d0138,0x2c780b14,0x291c007e}},	//   متوا, _suža, dždž_, tkva_,
   {{0x5f260033,0xe9730190,0x7ba62259,0x20051d21}},	//   _যদিও_, مهند, _مصرم, ålig_,
   {{0xd90d00cd,0x25ad3155,0xdce60138,0x6d431b32}},	//   بیل_, esel_, _sukė, čnat,
   {{0xc6f841d6,0xa2ba397e,0x63ba00c4,0x25ad1044}},	//   тних_, ्लफ्, vrtn, fsel_,
   {{0x25ad0429,0x7ae241d7,0x00000000,0x00000000}},	//   gsel_, meot, --, --,
   {{0xa91d0995,0x80d61344,0x7ae241d8,0x2956013d}},	//   _tuža, म्मे, leot, _събр,
   {{0xa3bb0789,0x7d570089,0x613400a7,0x69c200f0}},	//   इंग_, רייד_, _gülə, luoe,
   {{0x23a5007d,0xa91d02c8,0xf1bf0103,0xaefb01b9}},	//   _खबरद, _južn, szám_, _thùi,
   {{0xa5960465,0x3ea90313,0x25ad41d9,0xa2d90285}},	//   _срещ, vaat_, csel_, _फॉण्,
   {{0xa2c1034d,0x98a700b6,0x53c40034,0xf0e80109}},	//   _वाक्, dině_, लंदश, льск_,
   {{0x3ea93ab1,0x753a41da,0xceb40092,0x7ae21e2d}},	//   taat_, mitz, rkən_, keot,
   {{0x753a16c8,0xa91d03c6,0x3e07008f,0x93fb00ca}},	//   litz, _nužn, лязв, _טלוי,
   {{0x3ea941db,0x7bdc41dc,0xdb1e0257,0x7ae241dd}},	// [37f0] raat_, _apru, cupé, deot,
   {{0x753a0990,0x3ea941de,0xd7f800d3,0x628f0095}},	//   nitz, saat_, _oră_, lcco,
   {{0x3ea941df,0x69db0365,0x00000000,0x00000000}},	//   paat_, _spue, --, --,
   {{0x753a0a00,0x3ea9010a,0x7f4405fe,0x25ad41e0}},	//   hitz, qaat_, cniq, ysel_,
   {{0xa91d02e6,0x6f0d41e1,0x753a0a00,0x00000000}},	//   _dužn, mjac, kitz, --,
   {{0x6f0d02e6,0x7a2a0103,0xe8f804a1,0x25ad41e2}},	//   ljac, _söté, ллі_, vsel_,
   {{0x753a0a00,0xd7052a6e,0x6d570231,0x6d4500fe}},	//   ditz, изки, moxa, mnha,
   {{0x6f0d41e3,0x6d573521,0x25ad41e4,0xa2c10473}},	//   njac, loxa, tsel_, _वाग्,
   {{0xd7060084,0x6e2d41e5,0x25ad41e6,0x88c70286}},	//   рные_, nzab, usel_, _متال,
   {{0x25ad41e7,0x753a01e9,0x6d450734,0x628800b6}},	//   rsel_, gitz, nnha, ědom,
   {{0xe29a22ee,0x612b0018,0x8cca41e8,0x6d4541e9}},	//   кан_, _külf, स्टो, inha,
   {{0x68e341ea,0x6f0d08a9,0x249808bb,0xf7700604}},	//   lend, jjac, ırma_, _فان_,
   {{0x6f0d1100,0x753a20a3,0xe5a50036,0x68e30239}},	//   djac, bitz, _тили, oend,
   {{0x68e341eb,0xa91d0220,0x6d4541ec,0x629d0270}},	//   nend, _mužo, jnha, abso,
   {{0x2bb10067,0x8fa607c6,0x68fc058a,0x68e341ed}},	//   jąc_, рабе, _órde, iend,
   {{0x68e341ee,0x63bc41ef,0x2bb1007f,0x2bc900a4}},	//   hend, árne, dąc_, ांना,

   {{0x661b27c8,0xa91d005f,0x63a30150,0x91e60e3a}},	// [3800] nyuk, _ružn, _hwnn, _топе,
   {{0x68e3254d,0xf1bf0103,0x7f44023b,0x61e90233}},	//   jend, zzák_, sniq, çele,
   {{0x68e341f0,0xa3bb0455,0x7ae241f1,0x661b1a8e}},	//   dend, इंट_, teot, hyuk,
   {{0x753a02a7,0x6f0d00a5,0x661b0517,0x7c4400e7}},	//   zitz, cjac, kyuk, _čurć,
   {{0x2bd241f2,0x272a0019,0xdcfc0078,0xe8940d72}},	//   _सहका, _hùng_, _jirċ, баль,
   {{0x68e30c40,0x8b9641f3,0x661b07ac,0xa91d14f3}},	//   gend, _врач, dyuk, _dužo,
   {{0x8c430978,0xa91d0039,0x753a41f4,0x398b09af}},	//   _дере, _tužn, vitz, _eøs_,
   {{0x6d5c0087,0x753a41f5,0xd83800e7,0x272a00fe}},	//   _hkra, witz, _ječi_, _mùng_,
   {{0x753a41da,0x272a00de,0x55062c95,0xa53400d3}},	//   titz, _lùng_, ачна, йнич,
   {{0xd8380307,0x63a3010a,0x3d090336,0x612b173c}},	//   _leči_, _bwnn, साये_, _zülf,
   {{0x753a41f6,0x6e2d41f7,0xb0aa0034,0x78a801d3}},	//   ritz, zzab, करनग, _iedv,
   {{0x753a41f8,0xd6d900a5,0x48fe030b,0x612b00aa}},	//   sitz, koły_, लाको_, _külg,
   {{0x78a80068,0xf5940080,0x6d5c41f9,0x6d450150}},	//   _kedv, _التج, _okra, ynha,
   {{0x78a800e9,0x272a0023,0x753d0103,0x62840062}},	//   _jedv, _bùng_, észt, _egio,
   {{0x272a00ef,0x4ea70396,0xaad700b6,0x4ad71677}},	//   _cùng_, ираа, ण्डक, ण्डव,
   {{0x68e341fa,0x272a00ef,0x6d5c41fb,0x78a841fc}},	//   zend, _dùng_, _akra, _ledv,
   {{0x68e341fd,0xdceb1c74,0x8cc20f78,0x5f1800a4}},	// [3810] yend, šičk, _लाखो, _नवर्_,
   {{0x61ed41fe,0xa91d0181,0x6e2d41ff,0x68e34200}},	//   _isal, _ružo, rzab, xend,
   {{0x68e34201,0x6d454202,0x6d5702e5,0xee870ae3}},	//   vend, rnha, roxa, _выго,
   {{0x68e34203,0x28c9009d,0xddd4033b,0xa3a802d5}},	//   wend, _राहि, žašk, खीय_,
   {{0xe91900d6,0xaefb0441,0x61ed00bd,0x3be8013c}},	//   лоді_, _dhùt, _jsal, _eşq_,
   {{0xf1bf22a4,0x61ed4204,0x98a2079c,0xa2d902d5}},	//   irá_, _msal, пише, _फॉस्,
   {{0xe7393f1a,0xf1bf4205,0x60da00bc,0x67294206}},	//   лек_, hrá_, õtmi, thej,
   {{0x61ed4207,0x7bc54208,0xf1bf0088,0x6d5c00b6}},	//   _osal, muhu, krá_, _zkra,
   {{0x612b0068,0x68e34209,0x7bc50706,0x661b01c2}},	//   _küld, pend, luhu, uyuk,
   {{0x6aa926f1,0xb8fc00c7,0xf1bf420a,0x6729023f}},	//   _heef, _তো_, drá_, shej,
   {{0x61ed420b,0x6aa9420c,0x661b06e1,0x7bc5420d}},	//   _asal, _keef, syuk, nuhu,
   {{0x798134b0,0x2c4103e3,0x272a0023,0xad9b026e}},	//   _hilw, _mɗd_, _rùng_, _irúf,
   {{0x61ed0068,0xd838420e,0x7bc5420f,0x753d0068}},	//   _csal, _reči_, huhu, észs,
   {{0x6aa9043e,0x7bc54210,0xd83805db,0x660600f3}},	//   _leef, kuhu, _seči_, åkke,
   {{0x79814211,0x61ed4212,0xf1bf2218,0xd8380087}},	//   _milw, _esal, ará_, _peči_,
   {{0xf1bf4213,0x272a0019,0x1e864214,0x6aa93b89}},	//   brá_, _vùng_, слам, _neef,
   {{0x2fdf00ae,0xc5880023,0x1d8a0037,0xd348001c}},	// [3820] ăuga_, _lồn_, ائري_, _میگه_,
   {{0x272a0019,0x23db04f8,0x25bf1124,0xdca6049f}},	//   _tùng_, _बहाद, irul_, сажи,
   {{0x6aa94215,0x25bf02fa,0xb53a00c1,0xd838033b}},	//   _beef, hrul_, נגעש, _teči_,
   {{0xaefb01ec,0x798100eb,0x78a8298b,0x25bf084e}},	//   _dhùs, _ailw, _sedv, krul_,
   {{0x28c93abb,0x3ea04216,0xad9b0065,0x79814217}},	//   _राशि, mbit_, _arúf, _bilw,
   {{0x25bf4218,0x6d5c17bb,0xc5880023,0x612b071d}},	//   drul_, _ukra, _bồn_, _güld,
   {{0x93bc00d3,0x6ab70081,0x25bf00ae,0xc5880023}},	//   nzăt, _ইউরো, erul_, _cồn_,
   {{0x6aa90ab2,0xa3ab417a,0xbc1b00a1,0x6d890b14}},	//   _geef, गठन_, _גולש, _džaf,
   {{0xc6f71119,0x79814219,0xa91d0106,0xe9a3016c}},	//   сных_, _filw, _mužj, _натп,
   {{0xb6060106,0xa2c10af1,0x73d8421a,0xd90e0421}},	//   vršć, _वाङ्, адор_, _سیب_,
   {{0x3ea03642,0x25bf020a,0xaefb01b9,0x61ed421b}},	//   kbit_, arul_, _mhùr, _ssal,
   {{0x3f82001c,0x25bf421c,0x25080504,0xf1bf421d}},	//   _niku_, brul_, ارکی_, trá_,
   {{0x25bf00ae,0xd7570037,0xad9b0065,0x3ea02c28}},	//   crul_, _النت_, _irúg, dbit_,
   {{0xa2d9110f,0xecc700a5,0x3f820065,0xdcfc3360}},	//   _फॉर्, _लाइफ, _aiku_, _birč,
   {{0x7d1512fb,0x653b00a1,0x61ed0063,0x00000000}},	//   _rozs, _תעוד, _wsal, --,
   {{0x61ed1114,0x3f820063,0xa91d0dd9,0xdcfc022b}},	//   _tsal, _ciku_, _ružm, _dirč,
   {{0x61ed421e,0x9c8700e3,0x6aa93ed7,0x3f82023b}},	// [3830] _usal, مشاه, _reef, _diku_,
   {{0x7bc5068d,0xd131110a,0x25e00006,0x612b0342}},	//   tuhu, _آمد_, _कहनी_, _büle,
   {{0xaefb01f7,0x25bf00dc,0x3ea0421f,0x00000000}},	//   _dhùr, zrul_, bbit_, --,
   {{0x7bc54220,0x79814221,0xd9f91d64,0x25a60113}},	//   ruhu, _silw, инец_, _owol_,
   {{0xd8382c57,0x7bc54222,0xbddb05fe,0x79810167}},	//   _meču_, suhu, _exèr, _pilw,
   {{0x2d9902fd,0x92e500c7,0xad9b0032,0x3f8200e7}},	//   _itse_, নায়_, _arúg, _ziku_,
   {{0x25a600f9,0x2d8b0022,0x612b026a,0xd7094223}},	//   _awol_, _huce_, _güle, инке_,
   {{0xf38900ef,0x25bf00d3,0x2d830052,0xd83800c4}},	//   _bản_, trul_, _hije_, _neču_,
   {{0x2d8b03d6,0xf38900de,0x2d834224,0xe61600c2}},	//   _juce_, _cản_, _kije_, жды_,
   {{0x451907e3,0xc58800de,0x2d831709,0x25a6022b}},	//   рция_, _tồn_, _jije_, _dwol_,
   {{0x2d8b4225,0xd83801ac,0x25bf005c,0xe7dd0789}},	//   _luce_, _beču_, srul_, _महिप,
   {{0x2d9900aa,0x25bf044c,0x00000000,0x00000000}},	//   _otse_, prul_, --, --,
   {{0x2d99006c,0x6d890220,0xfe7f4226,0x3f824227}},	//   _ntse_, _uľah, _maïs_, _riku_,
   {{0x2d8302e6,0x3f821ee3,0xe7dd10e9,0xf992040a}},	//   _nije_, _siku_, _महाप, ורך_,
   {{0x33292977,0x3ea04228,0x3f8200e7,0x2905171f}},	//   _flax_, tbit_, _piku_, _mnla_,
   {{0xf3890019,0x6d4b4229,0xfd4e0294,0x2d8b1ee5}},	//   _hảo_, égan, bakọ, _buce_,
   {{0xe7e9000f,0x3f820088,0x612b422a,0x2d8b0022}},	// [3840] झौता_, _viku_, _süle, _cuce_,
   {{0x2d8b422b,0xe0da037e,0x3ea0422c,0x3f8203a9}},	//   _duce_, _тво_, sbit_, _wiku_,
   {{0x98780038,0x2d83422d,0x3f6a13c0,0xc61634d8}},	//   _páči_, _dije_, _вино_, _तथ्य_,
   {{0x27f8003e,0x3eab0090,0xbddb00ee,0x612b0847}},	//   _árni_, _gect_, _exèq, _gülb,
   {{0xe8943288,0x6f06422e,0xc3330089,0x2b4d00e7}},	//   паль, _inkc, ווא_, _djec_,
   {{0x2d830154,0x26dd294f,0x25a60078,0x00000000}},	//   _gije_, _abwo_, _rwol_, --,
   {{0xb8f2422f,0xf38900ef,0xf72a0f8d,0x26dd010a}},	//   _वा_, _sản_, иций_, _bbwo_,
   {{0x4b3400cd,0x2d834230,0x29054231,0x25a60113}},	//   _عکاس, _zije_, _enla_, _pwol_,
   {{0xf38900ef,0x7afd4232,0xad9b0503,0x00000000}},	//   _bảo_, _ósta, _grúd, --,
   {{0x61300003,0x01d00033,0xd838007e,0x37e64233}},	//   _hälf, িবাদ, _seču_, _мозг,
   {{0xd7ef00e3,0xad9b0653,0x2cfb006e,0xfd4e0129}},	//   _لكل_, _trúg, בליא, wakọ,
   {{0x51874234,0x78ba22d4,0xf3890023,0x39900139}},	//   жува, _hdtv, _tản_, _kàs_,
   {{0x69c24235,0x00000000,0x00000000,0x00000000}},	//   nroe, --, --, --,
   {{0x2d8b00b6,0x3eab21d8,0x98bc0138,0x395c01d3}},	//   _ruce_, _sect_, rovė_, novs_,
   {{0x28d2007d,0x69c24236,0x2d8b4237,0x656f00fd}},	//   _सानि, hroe, _suce_, îche,
   {{0x2bc9009d,0x6d4e00e7,0x2d834238,0x2d8b4239}},	//   ांसा, _ajba, _sije_, _puce_,
   {{0x395c01d3,0xa8020342,0xd08700d3,0x35c20285}},	// [3850] kovs_, ğıyl, _мыни, _शिफ़,
   {{0x2d8b08a9,0xf3890023,0x459b006e,0xa8020342}},	//   _vuce_, _xảo_, יסמע, şıyl,
   {{0x2d8b1114,0xd251001c,0x2d830052,0xea980129}},	//   _wuce_, _زنگ_, _vije_, _ịhụn,
   {{0xa4a50139,0x39900441,0x63b51f20,0xad9b0031}},	//   _afọ̀, _bàs_, ázni, _prúd,
   {{0x69c201a2,0x2b4d023b,0x8cd82fbd,0x3990423a}},	//   groe, _vjec_, न्हो, _càs_,
   {{0xa91d2d5a,0x3990016d,0x6aa2010a,0x201e042c}},	//   _kuži, _dàs_, abof, ätig_,
   {{0xa91d00c4,0xb886003e,0x00000000,0x00000000}},	//   _juži, _svíþ, --, --,
   {{0x69c2112f,0xa3bb423b,0x399001b5,0xf38900fe}},	//   broe, ेंस_, _fàs_, _sảo_,
   {{0x3d000096,0xad9b0031,0x6abb423c,0xa91d00d8}},	//   राचे_, _hrúb, _iduf, _luži,
   {{0xc5880019,0x799b423d,0xa8a7423e,0xd83805db}},	//   _gồm_, _ituw, _фрак, _pečt_,
   {{0x59f8002d,0xdb1e00d4,0x7bd70634,0x00000000}},	//   _леӂя_, lupá, ntxu, --,
   {{0x26dd092f,0x91e60859,0xd6d9007f,0x7bd701ff}},	//   _ubwo_, поме, biła_, itxu,
   {{0x6d890038,0x6130007a,0xf3890023,0xf8d2110d}},	//   _zľav, _jälg, _tảo_, _सामय,
   {{0x867a0054,0xa91d0477,0x3dc90124,0x25e008d4}},	//   _פרסו, _buži, duaw_, _कहती_,
   {{0x645c00bc,0x00000000,0x00000000,0x00000000}},	//   ürit, --, --, --,
   {{0xa91d03ce,0x799b06b0,0x62960350,0xdb1e3f96}},	//   _duži, _otuw, _ufyo, kupá,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3860] --, --, --, --,
   {{0x61e4026e,0x6abb423f,0x4d630396,0xd00f0018}},	//   _ipil, _aduf, екув, خلہ_,
   {{0x711b0130,0xa7fc008e,0x28d20c8c,0x799b083e}},	//   _הויפ, _ayın, _साबि, _atuw,
   {{0x6d892cea,0x61e40063,0x00000000,0x00000000}},	//   _džab, _kpil, --, --,
   {{0x61300212,0xc33300ca,0xe8fa2a59,0xa91d00d8}},	//   _välf, עוד_, йлд_, _zuži,
   {{0x612b0006,0x672b003e,0x27fe0063,0x61e44240}},	//   _küla, _algj, _prtn_, _mpil,
   {{0xfaa64241,0xd7fa002d,0x3d090d75,0x8b660470}},	//   _наво, сул_, सारे_, _فارم,
   {{0xf38900ef,0x96ea4242,0x69c204e2,0x61e44243}},	//   _cảm_, ська_, proe, _opil,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63bc0094,0x00000000,0x00000000,0x00000000}},	//   árno, --, --, --,
   {{0x61e44244,0xd6d9007f,0x00000000,0x00000000}},	//   _apil, siła_, --, --,
   {{0xa91d4245,0x61e40503,0x00000000,0x00000000}},	//   _ruži, _bpil, --, --,
   {{0x637f00d9,0xa91d013f,0xf67a001c,0xd709074c}},	//   _jūni, _suži, _امشب_, वारथ_,
   {{0x6b9c00cc,0x6d5e0106,0x28df0179,0xf67b0796}},	//   _otrg, jopa, प्पि, _האדמ,
   {{0x6d5e4246,0x04db00ca,0xbe9a06c0,0x80ce077d}},	//   dopa, _הקול, _ọhụr, _तारे,
   {{0x65680212,0x657a01cb,0x00000000,0x00000000}},	//   lldh, lmth, --, --,
   {{0xbf1d0454,0x78830018,0x3200022b,0x9259002d}},	// [3870] _नवीन_, _kívü, _griy_, _фапт_,
   {{0xa91d00e9,0x63520a84,0xfc46035d,0x6d5e4247}},	//   _tuži, māna, čína_, gopa,
   {{0x799b0629,0xa02200bc,0xad9b0503,0x612b04a8}},	//   _stuw, ööta, _brúc, _güla,
   {{0xceeb0281,0x7bd70634,0x201e05cc,0xad9b00da}},	//   _اردن_, rtxu, ätie_, _crúc,
   {{0xa2c01687,0x6d5e4248,0x6b9c0141,0x273100fe}},	//   _वयस्, bopa, _etrg, _háng_,
   {{0x5d8500d0,0x61304249,0xad9b424a,0x00000000}},	//   _زلزل, _välg, _trúb, --,
   {{0x81e30081,0x6e2000aa,0xe7390f1a,0x77f702d5}},	//   নটি_, _ümbr, жей_, ंटेक_,
   {{0x6604424b,0x28d20179,0x7f4d02a1,0x6568424c}},	//   _šika, _साथि, nnaq, eldh,
   {{0x2731424d,0x80ce02d5,0x0609004d,0x799b1bbd}},	//   _láng_, _ताले, інок_, _utuw,
   {{0x7aeb01bf,0x69cb0198,0x81e30033,0x05760037}},	//   legt, muge, নটা_, ومية_,
   {{0x61e42eb8,0xa3a8009d,0x69cb424e,0x69d901bf}},	//   _spil, खील_, luge, ltwe,
   {{0xe297088c,0x6130007a,0x6d5e424f,0x274303a9}},	//   маю_, _mäle, zopa, _dènè_,
   {{0x69d94250,0x69cb1124,0x6d5e0051,0x7bc501bf}},	//   ntwe, nuge, yopa, hrhu,
   {{0xafe61675,0x212c0076,0x69d94251,0x3860020a}},	//   могл, ódh_, itwe, şire_,
   {{0xe0d2001c,0x69cb246c,0x35d300c3,0x6d5e4252}},	//   _یزد_, huge, _दमड़, vopa,
   {{0xa91d042d,0x27310019,0xf41200a1,0xdbc6007a}},	//   _gužv, _dáng_, _יפו_, _köög,
   {{0x61e44253,0x6b9c2af0,0x0d860077,0xb7d4026e}},	// [3880] _upil, _strg, длан, _iṣed,
   {{0x417600cd,0xa06a1824,0x28d2058f,0x69d9042c}},	//   _تابس, _мапа_, _साधि, dtwe,
   {{0x6d5e4254,0x5fe24255,0x6130070a,0x69cb0d62}},	//   ropa, _पहिल, _väld, euge,
   {{0x69d925c0,0x4a464256,0x6d5e4257,0x6130042c}},	//   ftwe, мнев, sopa, _wäld,
   {{0xceb31777,0x6d5e4258,0x63763859,0x28c9030b}},	//   _שיש_, popa, mánd, _राखि,
   {{0xfbc6344a,0x63763d87,0xdd87008f,0x7bc3037a}},	//   _обго, lánd, _обяд_, ánuc,
   {{0xa91d0138,0xa2cf00b6,0x69d9112f,0x9992007f}},	//   _nužu, _थाल्, atwe, ódła_,
   {{0xc5880028,0x63760610,0x657a023e,0x69cb39af}},	//   _hồi_, nánd, wmth, buge,
   {{0x6e244259,0xbb430b1b,0x69d90034,0x6376002b}},	//   nyib, _ретк, ctwe, iánd,
   {{0xb7d40065,0x7769425a,0x272a009c,0x63760143}},	//   _aṣed, alex, _gùnn_, hánd,
   {{0xa3a80006,0xd6cf425b,0xc58800de,0x7f4d013c}},	//   खीं_, _ит_, _mồi_, ynaq,
   {{0x3d050067,0x7d1c025a,0xaefb0032,0x79880270}},	//   _होने_, _lors, _akùn, _hidw,
   {{0x27310028,0x7d1c01a2,0x660f0149,0x63760610}},	//   _sáng_, _oors, äckt, dánd,
   {{0x7d1c0a8d,0x6602425c,0x63880c56,0x61fd052f}},	//   _nors, _irok, tènè, rvsl,
   {{0xc58800de,0x69cb01bf,0xdfd8008f,0x63760072}},	//   _nồi_, zuge, мът_, fánd,
   {{0x63760610,0x15f200aa,0x7bc50094,0x27310023}},	//   gánd, _अनार_, vrhu, _váng_,
   {{0x171b0130,0xbf1f0251,0x93780241,0x6e240166}},	// [3890] קומע, _यकीन_, _تصور_, gyib,
   {{0x7d1c0df3,0xc58800de,0xad9b0072,0x6602425d}},	//   _cors, _bồi_, _crúa, _mrok,
   {{0xe3b80f28,0xe1ff034f,0x63760143,0xdb1e0329}},	//   nsı_, lvó_, bánd, kupä,
   {{0x0f2700d6,0x66020a00,0x637604d8,0x69cb425e}},	//   _цьом, _orok, cánd, tuge,
   {{0x7d1c4012,0x7aeb425f,0xdddd00a5,0x798800bd}},	//   _fors, regt, _wysł, _bidw,
   {{0x69cb4260,0x7d1c4261,0x69d93e8b,0xad9b00e1}},	//   ruge, _gors, rtwe, _grúa,
   {{0x6d4500a6,0x66024262,0x3d05009f,0x69cb2c94}},	//   miha, _arok, _होये_, suge,
   {{0x6d454263,0xf7712ba0,0x66024264,0xe6193496}},	//   liha, دات_, _brok, зди_,
   {{0x798800bd,0x2cb101f9,0xdb050ac9,0x00000000}},	//   _fidw, _kezd_, dshø, --,
   {{0x6f1d4265,0x6d454266,0xf3890028,0x63760610}},	//   _losc, niha, _hải_, zánd,
   {{0x6b890018,0x9346055b,0x66024267,0x6e361f6d}},	//   _kieg, енне, _erok, zzyb,
   {{0x65954268,0x66020170,0xdbc600bc,0x63760042}},	//   _заду, _frok, _töög, xánd,
   {{0x6b894269,0x6d45426a,0x63a10094,0xf38900fe}},	//   _mieg, kiha, spln, _mải_,
   {{0x6b89426b,0x412a00d6,0x2bd00557,0x6d450a4b}},	//   _lieg, чого_, _हमला, jiha,
   {{0xdee6426c,0xd466426d,0x63760fb6,0xd007426e}},	//   нови, _пише_, tánd, нере_,
   {{0xc58800ef,0x6729426f,0x6f1d4270,0x6b894271}},	//   _rồi_, nkej, _cosc, _nieg,
   {{0xee3a10fb,0xdcf40039,0x6d45026e,0x612b4272}},	// [38a0] чна_, šačk, fiha, _küll,
   {{0x7d1c008a,0xa91d025b,0x98a7013f,0x63760610}},	//   _qors, _mužs, minė_, sánd,
   {{0x7d1c02dc,0x6f1d4273,0x7988005c,0x6b894274}},	//   _vors, _fosc, _ridw, _bieg,
   {{0x28d24275,0x7f44008a,0x6b894276,0xb605033b}},	//   _साहि, qiiq, _cieg, _košč,
   {{0x7d1c1842,0x6b892d13,0x63761de7,0xf38a0019}},	//   _tors, _dieg, cáne, _cải_,
   {{0x66040146,0x44254277,0xf38a0023,0xc5880023}},	//   _šiko, kyl_, _dải_, _tồi_,
   {{0xfc1a2ce3,0xb60505db,0x00000000,0x00000000}},	//   _عقرب_, _lošč, --, --,
   {{0x28d21432,0x6b890090,0x44254278,0x98a700c6}},	//   _सावि, _gieg, dyl_, kinė_,
   {{0x2d8a0d15,0x65610131,0x612b013c,0x7988009e}},	//   _kibe_, folh, _büll, _tidw,
   {{0x442503a8,0x645d0092,0x65614279,0x6b89427a}},	//   fyl_, əsiz, golh, _zieg,
   {{0x290c0a75,0x61f60429,0xd5c20eeb,0x38610364}},	//   _inda_, _asyl, _शिवज, ührt_,
   {{0x291e427b,0xb60500e7,0x2d8a019f,0x6d45427c}},	//   _hota_, _bošč, _libe_, ziha,
   {{0x291e042b,0xe5a30231,0x6d451937,0x8c240081}},	//   _kota_, _бичи, yiha, _যেমন_,
   {{0x656100c9,0x2d8a427d,0x291e427e,0x612b0491}},	//   colh, _nibe_, _jota_, _güll,
   {{0xb4be1fbb,0xf2b00081,0x291e427f,0x6f1d0220}},	//   ेली_, _কারণ, _mota_, _posc,
   {{0x6d45195f,0x63764280,0x628d0e94,0x98a70138}},	//   wiha, táne, _ugao, binė_,
   {{0x290c02e6,0x6d453734,0x6b894281,0x6d894282}},	// [38b0] _onda_, tiha, _rieg, _džan,
   {{0x63760094,0x6b894283,0xf38a0019,0x612b007a}},	//   ráne, _sieg, _rải_, _külm,
   {{0x6d453b99,0x6b894284,0x63ba254d,0x6f1d4285}},	//   riha, _pieg, nstn, _tosc,
   {{0x290c06db,0x6d4506e1,0x6b89003d,0xb4be00c0}},	//   _anda_, siha, _qieg, ेलु_,
   {{0x291e4286,0x6b8900d9,0x290c00dc,0x3ea94287}},	//   _bota_, _vieg, _bnda_, mbat_,
   {{0xf38a00de,0x18690b57,0x291e4288,0x290c0167}},	//   _vải_, мали_, _cota_, _cnda_,
   {{0x6b892751,0x63ba4289,0xd5e20065,0x9c65001c}},	//   _tieg, jstn, _ayò, _شهرو,
   {{0x3d05428a,0x290c428b,0xf38a0028,0x06090848}},	//   _होते_, _enda_, _tải_, дник_,
   {{0xb4be000f,0x6729005a,0xceb40341,0x3f8b428c}},	//   ेलू_, rkej, ניץ_, _micu_,
   {{0x7afb428d,0x69db039f,0x3f8b005f,0x4425428e}},	//   _haut, _ique, _licu_, tyl_,
   {{0x7afb428f,0x3ea900f9,0xa2d60569,0x65610103}},	//   _kaut, kbat_, _भाद्, rolh,
   {{0x7afb4290,0x39474291,0x98a701b3,0x26c30138}},	//   _jaut, lins_, tinė_, ėjos_,
   {{0x7afb4292,0x65610131,0x291e0027,0x612b4293}},	//   _maut, polh, _yota_, _tüll,
   {{0x660601c5,0x3dc94294,0x7afb1537,0x39472f7c}},	//   ække, draw_, _laut, nins_,
   {{0xa0671dde,0x612b4295,0x3f8b06e3,0x98a70138}},	//   вара_, _gülm, _bicu_, sinė_,
   {{0x6d550095,0x2d8a4296,0x63880139,0x3f8b0234}},	//   _ajza, _sibe_, _dènì, _cicu_,
   {{0x3dc94297,0x2d8a4298,0x3f672436,0x1e8636bf}},	// [38c0] graw_, _pibe_, тито_, тлам,
   {{0x39474299,0xad9b429a,0xed570284,0xef1f058f}},	//   jins_, _trún, воу_, _eoü_,
   {{0x69db429b,0x7afb429c,0xf1bf2897,0x3ea9429d}},	//   _aque, _baut, nyán_, bbat_,
   {{0x291e0472,0x7afb0b30,0x66040094,0x3f8b429e}},	//   _sota_, _caut, _šikm, _gicu_,
   {{0x7fe20c8c,0x291e429f,0x2b460037,0x394742a0}},	//   _पहुँ, _pota_, rioc_, fins_,
   {{0xdca342a1,0x7afb03a9,0x394742a2,0x63ba0034}},	//   _вари, _eaut, gins_, ystn,
   {{0x291e42a3,0x7afb0257,0x8c46002d,0x6b6642a4}},	//   _vota_, _faut, _реве, _аква,
   {{0x7afb42a5,0x8a061d7b,0x39470332,0x332042a6}},	//   _gaut, _избе, ains_, _noix_,
   {{0x291e42a7,0xae050336,0xc6f70761,0x7ae242a8}},	//   _tota_, रियन_, тных_, mfot,
   {{0xb4be4275,0x394742a9,0x94180161,0x00000000}},	//   ेले_, cins_, ежот_, --,
   {{0x3cfa00a5,0x3320015e,0x7bde42aa,0x7afb0350}},	//   _उसने_, _boix_, ntpu, _yaut,
   {{0x63ba42ab,0x46a6008f,0x63760103,0x332000ee}},	//   rstn, _радв, vánc, _coix_,
   {{0x9ad30134,0x61300324,0x201e007b,0x63ba0120}},	//   lịch, _säla, ätin_, sstn,
   {{0x7bde0ad4,0x00000000,0x00000000,0x00000000}},	//   ktpu, --, --, --,
   {{0x5ea40081,0x332039da,0x7ae21e71,0x3ea9019c}},	//   _ওয়ে, _foix_, kfot, tbat_,
   {{0x3ea93653,0x6376030b,0x394742ac,0xaad10d77}},	//   ubat_, ránc, zins_, _हाइक,
   {{0x3ea942ad,0x7afb42ae,0x3f93008a,0x9ad300ac}},	// [38d0] rbat_, _raut, _wuxu_, hịch,
   {{0x394742af,0x7afb42b0,0x637642b1,0x612b0491}},	//   xins_, _saut, mána, _mülk,
   {{0x7afb42b2,0x637642b3,0xc3160033,0x3158006e}},	//   _paut, lána, াসরি_, _ביזן_,
   {{0x5a350832,0x7ae242b4,0x60db00e7,0x629d0103}},	//   лнет, gfot, đumu, ncso,
   {{0x394742b5,0xa2d6110f,0x212100f9,0xa3d402d5}},	//   tins_, _भास्, _kohh_, िंड_,
   {{0x7afb42b6,0x4cad0033,0xe8f807bf,0x78b80172}},	//   _waut, _চাকু, клі_, gavv,
   {{0x7afb42b7,0x394742b8,0xf74542b9,0xdcfc3df1}},	//   _taut, rins_, леко, _sirć,
   {{0x394742ba,0x236901fa,0xde8f0134,0x98bc00d3}},	//   sins_, _nkaj_, _aịza_, tivă_,
   {{0x21210167,0x394742bb,0x63760103,0x4a55097a}},	//   _oohh_, pins_, jána, _скас,
   {{0x637642bc,0xdb1c0154,0x273142bd,0x386c03a8}},	//   dána, _avrè, _dána_, _fydr_,
   {{0x6b9542be,0x98bc020a,0xa34a0cc6,0x00000000}},	//   _juzg, sivă_, езна_, --,
   {{0x2579025a,0x6b9542bf,0x11d6224a,0x69cb42c0}},	//   dèle_, _muzg, лігр, orge,
   {{0xaad1000f,0x9f5e42c1,0x33200257,0xe60e28f1}},	//   _हाईक, ítí_, _voix_, _уд_,
   {{0xb602030b,0x399942c2,0x661d01ce,0x00000000}},	//   čátk, _mès_, øsku, --,
   {{0x74d842c3,0x399942c4,0x3d170592,0x69cb0364}},	//   _मातृ, _lès_, नाने_, hrge,
   {{0x69c4000f,0x6d8926dd,0x26f10285,0xad9b01cd}},	//   _रिली, _džam, _अघोर_, _trúl,
   {{0xc69200c1,0x80b30081,0x3f800131,0x7ae2224d}},	// [38e0] מאן_, _জার্, rmiu_, vfot,
   {{0xc8d2055e,0xe6d002c6,0x23b70b86,0xfca91454}},	//   _साइट, _सञ्ज, _आबाद, نامو_,
   {{0xa3bb0f78,0x5aca19a0,0x7c3b03e3,0x80aa0296}},	//   ेंट_, елем_, _ƙura, _ज्ये,
   {{0x2ca735f8,0xda7a00c2,0xeafa0018,0x3999022b}},	//   ında_, нял_, عرات_, _bès_,
   {{0x82d70130,0x59f842c5,0xb17b09ce,0xe3a709b4}},	//   רונג_, теля_, ståe, _گر_,
   {{0x3999025a,0x7ae21a7a,0x27310094,0xd765001c}},	//   _dès_, sfot, _rána_, ینوی,
   {{0xe3a707c3,0xd90d1e49,0x69cb0371,0x8b951b60}},	//   _در_, ظیم_, arge, _вруч,
   {{0xb8cb00a5,0x399942c6,0x2cba0124,0x27310094}},	//   _क्_, _fès_, lapd_, _pána_,
   {{0xa53442c7,0x290f0037,0x6b8242c8,0x63a3010a}},	//   инич, álaí_, mmog, _atnn,
   {{0x46a4034d,0x236942c9,0x598300c2,0xad9b034f}},	//   _ग्रह, _skaj_, _глуб, _brúj,
   {{0xd6c40e8c,0xb893054f,0x245800d6,0x6b950072}},	//   _نمای, _المع, тань_, _xuzg,
   {{0x80d7244d,0x27ec0085,0x926b0db2,0x257900fd}},	//   _बाहे, _ipdn_, ерга_, vèle_,
   {{0x96b90f1e,0xa19501b6,0x637d03a9,0xde8f0174}},	//   _руху_, рагч, héng, _gịya_,
   {{0x98a70039,0x63760cc8,0x257900fd,0xe3af0018}},	//   čići_, rána, tèle_, _کرو_,
   {{0x629d00fb,0x09d11e05,0x6722022e,0x63760018}},	//   pcso, _सम्य, _kooj, sána,
   {{0x6722008a,0x637d03a9,0x613042ca,0x6376119e}},	//   _jooj, déng, _häll, pána,
   {{0x6b820995,0x61300222,0x612b00aa,0xad9b0032}},	// [38f0] dmog, _käll, _lüli, _irúk,
   {{0x627c0054,0x61301d2d,0x61ed42cb,0x399902f1}},	//   _אנחנ, _jäll, _ipal, _rès_,
   {{0x5b27147c,0x768b026a,0xbc07013f,0x60c5033c}},	//   льда, _köyü, ычай, _idhm,
   {{0x61ed0134,0x612b00a7,0x399905aa,0x00000000}},	//   _kpal, _sülh, _pès_, --,
   {{0x99d70080,0x6d4b03be,0x69cb42cc,0xf9c727c9}},	//   اتصا, égas, urge, ущен,
   {{0xa4f3009d,0x637d42cd,0x6b820036,0x61ed42ce}},	//   _असेच_, lénd, amog, _mpal,
   {{0xad9b0d79,0xd8b800b9,0x6d470090,0x672201ee}},	//   _orúk, ادها_, _imja, _booj,
   {{0x637d167e,0x399902f1,0xd709007b,0x291801b5}},	//   nénd, _tès_, тние_, _òran_,
   {{0x7d120103,0x8579001f,0x7ae90372,0x672242cf}},	//   _újsá, ксот_, _ibet, _dooj,
   {{0x60c500fe,0x635200e8,0x660601cd,0x00000000}},	//   _ndhm, māni, ækka, --,
   {{0x768b01d4,0xf7700281,0x61ed42d0,0xad9b01ab}},	//   _böyü, _کال_, _apal, _brúk,
   {{0xe28642d1,0x60c50037,0x273b0032,0xb60200b6}},	//   илни, _adhm, _dànù_, čárk,
   {{0x7ae90c67,0x61300924,0x99800181,0x7bc342d2}},	//   _mbet, _fäll, šiť_, ánuj,
   {{0x6130070a,0x25bf0808,0x64a500a0,0xdb0500fd}},	//   _gäll, msul_, _така, sphè,
   {{0xa06a04c9,0x80d7046e,0x7ae942d3,0x6722006c}},	//   тава_, _बारे, _obet, _yooj,
   {{0x63761125,0x752302c6,0x67220188,0x6d470350}},	//   máno, _honz, _xooj, _amja,
   {{0x7dc600bf,0x25bf002d,0x63760018,0xd17600ae}},	// [3900] شقان, nsul_, láno, _выны,
   {{0x127b00c1,0x02b60096,0xa2a242d4,0x00000000}},	//   _באפע, _अजुन, कुर्, --,
   {{0xc5f242d5,0xf5360130,0x752342d6,0x63761f20}},	//   _अन्य_, סטער_, _monz, náno,
   {{0x25bf007a,0x637d42d7,0x79a63051,0x305b0327}},	//   ksul_, cénd, арке, _ידיד,
   {{0x6b8242d8,0x672242d9,0x680001f9,0x00000000}},	//   rmog, _rooj, kájá, --,
   {{0x637d0575,0x6722007a,0x6b8242da,0xed5a002d}},	//   méne, _sooj, smog, _рог_,
   {{0xd7fa0a29,0x02b60096,0x9ad30174,0x4aba00ae}},	//   тул_, _अजून, sịah, _аузя_,
   {{0x3ea042db,0x61300149,0xab2702b3,0x25bf0113}},	//   ncit_, _säll, _коса_, fsul_,
   {{0x66e20386,0x25bf019c,0x94aa08f9,0xe8fa037e}},	//   क्षक_, gsul_, ктна_, _ила_,
   {{0x96a60455,0x612b42dc,0xb4d000b6,0x768b013c}},	//   _ट्रॉ, _tüli, षले_, _söyü,
   {{0x61ed42dd,0xa41400c7,0x75233e56,0x6d8902ef}},	//   _spal, ান্য_, _donz, _džah,
   {{0x61ed11e1,0x3dc00270,0x320942de,0x637d01f9}},	//   _ppal, ksiw_, _pray_, kéne,
   {{0x613002fd,0x15a7008f,0xa3d4178d,0x6d400138}},	//   _täll, _къщи_, िंह_, _įman,
   {{0x752342df,0xf1bf0037,0xf669001c,0x59c90521}},	//   _gonz, rsá_, _صحنه_, _रिसर,
   {{0x637d03be,0x757b0266,0xd48f42e0,0xdb05020d}},	//   ténd, _שטופ, _фр_, sphé,
   {{0x6130032c,0x7523037a,0x656842e1,0x3f8f003e}},	//   _jälj, _zonz, lodh, ögu_,
   {{0x442c42e2,0x637d42e3,0x443e042c,0x81f901f9}},	// [3910] lyd_, rénd, lzt_, _صفدر_,
   {{0xb9120174,0x40350aa8,0x60c50350,0x9d14002d}},	//   renụ_, _геос, _udhm, одуч,
   {{0x443e42e4,0x656f020d,0x442c030a,0x00000000}},	//   nzt_, îchi, nyd_, --,
   {{0x2731025b,0x63760018,0x635201d3,0x65680b8c}},	//   _ráno_, jánl, tāni, hodh,
   {{0x98a522be,0x2cb80120,0x442c00f0,0x25790113}},	//   биле, _ferd_, hyd_, hèla_,
   {{0x63a40074,0x3eb9038c,0x9f5a02f1,0x6e2d02a4}},	//   _činn, _hest_, _aspè_, myab,
   {{0x013800a1,0x2d9942e5,0x59c9009f,0x7523028d}},	//   שרות_, _huse_, _रिवर, _ronz,
   {{0x3eb91f83,0x442c0150,0x00580327,0x25a600dc}},	//   _jest_, dyd_, ישות_, _btol_,
   {{0x6e2d42e6,0x3eb938f0,0xd7060084,0x7523028d}},	//   nyab, _mest_, сные_, _ponz,
   {{0xf99006f6,0x442c02e0,0x25bf002d,0xd7e702ec}},	//   _قبل_, fyd_, rsul_, _відо,
   {{0x442c42e7,0x3cfa00a5,0x2d9142e8,0x3eb90428}},	//   gyd_, _उससे_, _mize_, _oest_,
   {{0xe6950080,0x25bf2048,0x63760181,0x7523010a}},	//   _الإد, psul_, ráno, _wonz,
   {{0x656842e9,0x7523010a,0x2d99023b,0x98a70138}},	//   bodh, _tonz, _nuse_, ninį_,
   {{0x753a365f,0xa0a3008f,0x63761125,0x2d9142ea}},	//   chtz, зард, páno, _nize_,
   {{0x3eb942eb,0x251a00a1,0x1dda0d77,0x61432cad}},	//   _best_, _תוצא, यूनत, чера,
   {{0xdd9200e3,0x637d0103,0x2d910062,0x98a700c6}},	//   كور_, téne, _aize_, kinį_,
   {{0x613002fd,0x2d9142ec,0x2cb842ed,0x3ea042ee}},	// [3920] _jälk, _bize_, _perd_, rcit_,
   {{0x3eb90006,0x3ea042ef,0x2d910031,0x98a700c6}},	//   _eest_, scit_, _cize_, dinį_,
   {{0x417607d9,0xdd8f2761,0x3eb942f0,0x2cb842f1}},	//   _پاکس, روم_, _fest_, _verd_,
   {{0x2cb842f2,0x2ca10049,0x6e2d0435,0xfe053e2a}},	//   _werd_, achd_, byab, रिशस_,
   {{0x2d91022b,0x6130007b,0x7c3e0103,0x660d00c6}},	//   _fize_, _nälk, szpr, _šakn,
   {{0x6130070a,0x6f0442f3,0xada342f4,0x2d91010a}},	//   _sälj, ldic, _харл, _gize_,
   {{0xb9000d1b,0xa7fc07aa,0xa09b006e,0xf1bf01f9}},	//   _था_, _ayır, ניקט, tyák_,
   {{0x6f040133,0x629607ac,0x96341a17,0xaac50076}},	//   ndic, _ngyo, жниц, _وتقن,
   {{0x613042f5,0x442c02e0,0x612b42f6,0x6f040441}},	//   _välj, wyd_, _kült, idic,
   {{0x443e02d6,0x442c0665,0x00000000,0x00000000}},	//   tzt_, tyd_, --, --,
   {{0x78ba00d9,0x656842f7,0x673b019f,0x00000000}},	//   _ietv, rodh, bhuj, --,
   {{0x442c42f8,0x443e01bf,0x6aa242f9,0xa3d7009f}},	//   ryd_, rzt_, ncof, ाढ़_,
   {{0x66760f43,0x443e297d,0x78ba013f,0x69c20185}},	//   _ادار, szt_, _ketv, nsoe,
   {{0x3eb90006,0x70d3009d,0x2d9942fa,0x6d5c0113}},	//   _sest_, तलेल, _ruse_, _njra,
   {{0x403406c4,0xdbf1030b,0x3f9a1a3a,0x889b006e}},	//   перс, _příj, _cupu_, רבלי,
   {{0x2d9142fb,0x6e2d42fc,0x2d9942fd,0x6d5c42fe}},	//   _size_, tyab, _puse_, _ajra,
   {{0x3eb942ff,0x7f4d4300,0x612b0233,0x2d910113}},	// [3930] _vest_, riaq, _bült, _pize_,
   {{0x78ba4301,0x3eb900a1,0x6e2d26fc,0x52740037}},	//   _netv, _west_, ryab, _عايز,
   {{0x6e951167,0x6e2d02e7,0x3eb94302,0x2a9e0134}},	//   _мину, syab, _test_, _ịba_,
   {{0x2d910079,0x98a7013f,0x2d99044c,0x00000000}},	//   _wize_, tinį_, _tuse_, --,
   {{0x7ccb01d3,0x69c200d1,0x00000000,0x00000000}},	//   tērē, gsoe, --, --,
   {{0x527c00c1,0x612b4303,0x98a70138,0xc27c0266}},	//   אנדא, _gült, rinį_, ארדי,
   {{0xe80905cd,0xb8f10096,0x78ba0031,0x612b4304}},	//   विधा_, _वय_, _detv, _hüls,
   {{0x3d17412e,0x612b0018,0x661b01e9,0xdb2305f8}},	//   नावे_, _küls, txuk, öräl,
   {{0x78ba4305,0x673b4306,0x7bd74307,0xa3cb0d75}},	//   _fetv, rhuj, luxu, _लिह_,
   {{0x28e00782,0x61300222,0xe8090455,0x6f0413e8}},	//   _नायि, _välk, विदा_, zdic,
   {{0xe8551a37,0x09be0033,0x2bd100c3,0x7981039f}},	//   _بناد, _উৎপা, _हिफा, _ihlw,
   {{0x3f9a0106,0x799b0239,0x78ba007e,0x00000000}},	//   _rupu_, _kuuw, _zetv, --,
   {{0x4ade086d,0xbebb057a,0x3cfa030b,0x3f9a4308}},	//   फ्टव, _voël, _उसले_, _supu_,
   {{0xb17b0222,0x3f9a4309,0x799b024a,0x00000000}},	//   stån, _pupu_, _muuw, --,
   {{0x6609430a,0xa2e6008f,0x5f06430b,0x6abb00fd}},	//   lvek, _дойд, озва, _oeuf,
   {{0x637d430c,0x6f04009c,0x6abb430d,0x28e022a0}},	//   rénc, udic, _neuf, _नाभि,
   {{0x25ad0085,0x799b083e,0x6376430e,0x7981019f}},	// [3940] npel_, _nuuw, hánk, _ohlw,
   {{0x3f9a00ac,0x637d0257,0xbd83097a,0x27312e92}},	//   _tupu_, ména, дгук, _bánk_,
   {{0x273803a9,0x64410364,0x61e60ab8,0xb53a006e}},	//   _léna_, nzli, ltkl, סגעש,
   {{0xfa250081,0x78ba430f,0x7981039f,0x69c24310}},	//   _মেইল_, _setv, _ahlw, tsoe,
   {{0x394e025a,0xe8fa1543,0x6aa22f10,0x3d05007a}},	//   tifs_, илд_, rcof, _होके_,
   {{0x69c20665,0x97a620f9,0x6abb084e,0x6d5c4311}},	//   rsoe, орил, _eeuf, _ujra,
   {{0x3d17000f,0x394e0257,0x78ba4312,0x644100c4}},	//   नारे_, rifs_, _vetv, jzli,
   {{0xa2d610e9,0x64410063,0x394e00fd,0x61e61e95}},	//   _भाग्, dzli, sifs_, ktkl,
   {{0x99890128,0x5b210018,0xdb1e0072,0xdb054313}},	//   šaš_, _سہول, supó, tshö,
   {{0x2bd1320a,0x6b9c4314,0x27310023,0x637d16e7}},	//   _हिमा, _kurg, _lánh_, déna,
   {{0x66e641cc,0x6b9c4315,0x60dc0b14,0x29ff0034}},	//   _можа, _jurg, dgrm, ałać_,
   {{0x6b9c4316,0xe3af09b4,0x3b060090,0xad9b2a19}},	//   _murg, کری_, ndoq_, _krút,
   {{0x637d2bb7,0x7ae00063,0xe4da001c,0x6b9c4317}},	//   géna, _mcmt, _نوشت_, _lurg,
   {{0xa3b502d5,0x3cf60034,0x3ebf14f3,0xa2b90285}},	//   _चौक_, ीयों_, _žut_, _्यक्,
   {{0x27310019,0x2f1900c2,0x6b9c00aa,0x3d05009f}},	//   _bánh_, бовь_, _nurg, _होगे_,
   {{0x27310019,0x2fcd08c5,0x213a4318,0x637d03a9}},	//   _cánh_, čeg_, _elph_, béna,
   {{0x3d17030b,0x68f801fa,0x6edc09c3,0xd2510dd0}},	// [3950] नाले_, kevd, _फारु, _سند_,
   {{0xdfdb0020,0x63a403ce,0x2fd84319,0xe6b70775}},	//   _към_, _činj, burg_, _इज्ज,
   {{0x6b9c21ba,0x92dd0033,0xdc98004d,0xe4e20eeb}},	//   _curg, ড়ী_, івці_, _खानि_,
   {{0xdd9513a4,0x6b9c431a,0x2001431b,0x63761f20}},	//   _намы, _durg, _ishi_, vánk,
   {{0x6d580fa3,0xe9d804a1,0x7e7d00e8,0x6b9c030a}},	//   čvar, жкі_, _uzsp, _eurg,
   {{0x3f89431c,0x5ef30134,0x6376291d,0x68f800bc}},	//   lmau_, _ịhọọ, tánk, gevd,
   {{0x6b9c431d,0x6abb0364,0x00000000,0x00000000}},	//   _gurg, _teuf, --, --,
   {{0x6376431e,0x613008a3,0x7bc5431f,0x96230081}},	//   ránk, _väli, mshu, _বেগম_,
   {{0xe61600ce,0x59d200aa,0x6b9c4320,0xb0dc0961}},	//   зды_, _सियर, _zurg, _बालग,
   {{0x80d7110f,0x644102e2,0x69d94321,0x63764322}},	//   _बागे, tzli, muwe, pánk,
   {{0x69d94323,0x3f890063,0x29ff0034,0x66090120}},	//   luwe, kmau_, słać_, svek,
   {{0x29054324,0x64414325,0x33290381,0x660900d6}},	//   _hala_, rzli, _coax_, pvek,
   {{0x29054326,0x200101c2,0x7bc50a83,0x69d94327}},	//   _kala_, _ashi_, hshu, nuwe,
   {{0x29074328,0x27310019,0x29fd0181,0x2fd84329}},	//   ndna_, _sánh_, _mňa_, turg_,
   {{0x29050954,0x69d9432a,0xb4d70096,0x61e613c5}},	//   _mala_, huwe, िली_, stkl,
   {{0x2905008a,0x69d9432b,0x7bc50bc6,0x6e960037}},	//   _lala_, kuwe, dshu, سلطا,
   {{0x0e6305d8,0x6b9c432c,0x2905020a,0x3eb202c3}},	// [3960] ектн, _surg, _oala_, rbyt_,
   {{0x69d9432d,0x2905432e,0xa91c0220,0xee374064}},	//   duwe, _nala_, _ohľa, чну_,
   {{0xc2f10081,0x69d901c0,0xad9b432f,0xa09b0266}},	//   য়ারি_, euwe, _brús, _לייט,
   {{0x23a100a5,0x29074330,0x6b9c026a,0x3d0c00c3}},	//   _mój_, edna_, _vurg, _डोरे_,
   {{0x29054331,0x63760fb6,0x6b9c4332,0x28e002d5}},	//   _bala_, gáni, _wurg, _नादि,
   {{0x6b9c4333,0x29fd0181,0x6f0608d3,0x6d894334}},	//   _turg, _dňa_, _hakc, _džas,
   {{0x6d4e4335,0xad9b221e,0x7c650e25,0x3b0a0da5}},	//   _imba, _frús, _قافل, _лево_,
   {{0x29074336,0xceb40092,0x29052e6a,0x5694098a}},	//   adna_, nbə_, _eala_, майт,
   {{0xb0dc0e50,0x20dc40c1,0x29054337,0x63760fb6}},	//   _बांग, _बांध, _fala_, cáni,
   {{0xaa3b00ca,0x637d2c85,0x00000000,0x00000000}},	//   _התמח, génn, --, --,
   {{0xd6cf0457,0x3f894338,0xa438224a,0x6d4e4339}},	//   _пт_, ymau_, ізму_, _mmba,
   {{0x66e30bd9,0x6d4e2745,0x66e6433a,0xe80902d5}},	//   _गायक_, _lmba, _хода, विरा_,
   {{0x6d4e2cf8,0x95860036,0x5187433b,0x2905433c}},	//   _omba, _елде, зува, _yala_,
   {{0x92dd0081,0x6602433d,0xf61700ca,0x0cd70033}},	//   ড়ে_, _isok, _מחדש_, _হস্ত,
   {{0x9f5a00b3,0x6f06433e,0x69d90364,0x00000000}},	//   _espí_, _bakc, zuwe, --,
   {{0x6d4e1a7e,0xaf04433f,0x5f940ba4,0x637d4340}},	//   _amba, нчук, еист, méno,
   {{0x3f8900f0,0x6f064341,0x4d980fe9,0x2907008c}},	// [3970] rmau_, _dakc, зкую_, ydna_,
   {{0x7bc54342,0x2bd1009f,0x66020350,0x00000000}},	//   tshu, _हिदा, _msok, --,
   {{0x629a030b,0xd251110a,0x3d0c0096,0xad9b34b6}},	//   ětov, _سنگ_, _डोळे_, _prús,
   {{0x63760328,0x6d4e4343,0x660201e9,0x69d92a49}},	//   táni, _emba, _osok, tuwe,
   {{0x29054344,0x66d60233,0x920d023a,0xdd914345}},	//   _pala_, zükü, िटिज_, _لوح_,
   {{0x63764346,0x6d4e005c,0x29054347,0x7bc54348}},	//   ráni, _gmba, _qala_, pshu,
   {{0x29074349,0x6602434a,0x63760143,0x00000000}},	//   rdna_, _asok, sáni, --,
   {{0x2905434b,0x05a902ec,0xeab30037,0x2b4d0072}},	//   _wala_, овий_, _سعر_, _umec_,
   {{0x6d89084f,0x290532a7,0x05b900cd,0xa3df009d}},	//   _užas, _tala_, زگشت_, धून_,
   {{0xb4d74255,0x98a50154,0x629b00c6,0x53c9372a}},	//   िले_, _kolč_, žuol, огом_,
   {{0xa3d41362,0x7d070941,0x637d1054,0x6602434c}},	//   िंग_, _majs, rénn, _esok,
   {{0x7d07031a,0x00000000,0x00000000,0x00000000}},	//   _lajs, --, --, --,
   {{0xe56e0465,0xceb4013c,0x00000000,0x00000000}},	//   _аз_, vbə_, --, --,
   {{0x6594125f,0x00000000,0x00000000,0x00000000}},	//   _зачу, --, --, --,
   {{0x6f0608d3,0x10a3434d,0xafe3434e,0xd007032d}},	//   _pakc, тисн, корл, мере_,
   {{0x672b072f,0x26df38d6,0xf1bf01f9,0x00000000}},	//   _jogj, nguo_, gyás_, --,
   {{0x63a400e9,0x6f06434f,0xb60601cd,0x7d074350}},	// [3980] _čini, _vakc, mráð, _bajs,
   {{0x6aa90032,0x672b023b,0xe60705bc,0x00000000}},	//   _afef, _logj, _یش_, --,
   {{0x711b00c1,0x69c906b0,0x672b029a,0x3b0600c6}},	//   _וויפ, _avee, _oogj, _lūpų_,
   {{0x3cfa0067,0x6ea5009f,0x28e02065,0x973c031a}},	//   _उसके_, _कलयु, _नाहि, _kuće,
   {{0xd9461839,0x636803a3,0x6d4e005c,0x61300212}},	//   меди, mınd, _tmba, _fält,
   {{0x6d4e4351,0x63680702,0xb4d7000d,0x7d074352}},	//   _umba, lınd, िलो_, _gajs,
   {{0x61300222,0x315700c1,0x69da009f,0xb4d7030b}},	//   _häls, ויסן_, _नमकी, िलै_,
   {{0x63680702,0x6d8900cc,0x85a60396,0x2d9800d7}},	//   nınd, _užar, мјод, _hire_,
   {{0x2d984353,0xd379042d,0x63ad0095,0x672b0052}},	//   _kire_, nuće_, _čana, _dogj,
   {{0x637d0094,0x63680555,0x6d5e01ce,0x00000000}},	//   téno, hınd, nnpa, --,
   {{0x2d984354,0x443819a3,0x9980013f,0x672b0103}},	//   _mire_, ár_, šių_, _fogj,
   {{0x2d984355,0x2bd10abe,0x66024356,0xd3790106}},	//   _lire_, _हिसा, _tsok, kuće_,
   {{0xd37903ce,0x636803a3,0xad9b0139,0xa50a0b99}},	//   juće_, dınd, _asún, _меда_,
   {{0xd3790039,0x26c44357,0x2d9802a7,0xe44f12eb}},	//   duće_, lamo_, _nire_, اضی_,
   {{0xa3cb1f83,0x63681f8a,0x4fc43d7b,0xa1940231}},	//   _लिए_, fınd, кста, тарч,
   {{0x26c44358,0x2d981c5d,0x660d4359,0x63680b12}},	//   namo_, _aire_, _šaki, gınd,
   {{0xd37902e6,0x8af70092,0x2d98435a,0x7d07009e}},	// [3990] guće_, şəkk, _bire_, _pajs,
   {{0x2d98435b,0x26c4435c,0x00000000,0x00000000}},	//   _cire_, hamo_, --, --,
   {{0x2d98435d,0x8af934f8,0x6130322d,0x63680491}},	//   _dire_, знес_, _vält, bınd,
   {{0x26c4435e,0xf38a0019,0x2d98070b,0x6d5e435f}},	//   jamo_, _bảy_, _eire_, anpa,
   {{0x26c44360,0xad9b00e3,0x63763f2d,0x61304361}},	//   damo_, _grúp, mánt, _tält,
   {{0x63764362,0xd122143d,0xde1600c1,0x3ea94363}},	//   lánt, मायण_, _אַלץ_, lcat_,
   {{0xb9070006,0x3f991144,0x7c3b03e3,0x28e04364}},	//   _भा_, _kisu_, _ƙuru, _नारि,
   {{0x3ea94365,0x26c44366,0x9ac70103,0x6e29007f}},	//   ncat_, gamo_, _آگاہ_, _żeby,
   {{0x29d50c5e,0x3f990234,0x31710103,0x59c91024}},	//   _سياس, _misu_, kozz_, _रिटर,
   {{0x9a842cbf,0x14254367,0x6368008b,0x06820077}},	//   _русл, едом, zınd, ыгын,
   {{0x26c44368,0x63680511,0x973c00e7,0x61f600f3}},	//   bamo_, yınd, _suće, _spyl,
   {{0x3f9903ce,0x26c40fbd,0x636800a7,0x3ea94369}},	//   _nisu_, camo_, xınd, jcat_,
   {{0xf38a0019,0xb6060088,0x15f300bc,0x00000000}},	//   _xảy_, rráð, _अहिर_, --,
   {{0x6e200472,0xb6060088,0x25d600c1,0xd3790357}},	//   _àmbi, sráð, _נוצן_, vuće_,
   {{0x63680dea,0x3f99005c,0x2d9800fd,0xe46500bc}},	//   tınd, _bisu_, _rire_, ööde_,
   {{0x6d5e01af,0x539a00ca,0x61300212,0x2ba300a3}},	//   wnpa, _ציפו, _päls, _ओढ़ा,
   {{0x636808f5,0x3dc922d4,0x3171436a,0x2d98436b}},	// [39a0] rınd, gsaw_, bozz_, _pire_,
   {{0x6368436c,0x59c90251,0x26c43282,0x61300212}},	//   sınd, _रिजर, zamo_, _väls,
   {{0xf5360130,0x2d9806a3,0xd3794072,0xeb9a436d}},	//   עטער_, _vire_, suće_, чие_,
   {{0x3ea9436e,0x20570130,0x2bd119af,0x27310072}},	//   ccat_, _טייל_, _हिरा, _máns_,
   {{0x2d98436f,0x00000000,0x00000000,0x00000000}},	//   _tire_, --, --, --,
   {{0x26c40b33,0xf8061372,0xdbc700aa,0xf38a00fe}},	//   wamo_, ечин, _rööv, _vảy_,
   {{0x26c44370,0x777b0956,0xd90d001c,0x69dd2452}},	//   tamo_, flux, تیل_, _åsen,
   {{0x62840036,0x14dd00b6,0xf4150033,0x00000000}},	//   _ozio, _माउण, াহার_, --,
   {{0x26c44371,0xbb43055b,0x6e242ad9,0x00000000}},	//   ramo_, _сетк, nxib, --,
   {{0xa3cb0da9,0x7ae24372,0xd90d010d,0x61fb016d}},	//   _लिख_, lgot, _وین_, çulm,
   {{0x6284013d,0x7bde4373,0x26c44374,0x25bd0090}},	//   _azio, nupu, pamo_, _ewwl_,
   {{0x7ae24375,0xdbc700aa,0x799a0079,0x6edc0835}},	//   ngot, _tööv, _hitw, _फागु,
   {{0x7bde08d3,0x799a4376,0x00000000,0x00000000}},	//   hupu, _kitw, --, --,
   {{0xa4d402ec,0x7bde4377,0xde8f0174,0x3f99007a}},	//   _рокі, kupu, _dịla_, _sisu_,
   {{0x628400ac,0x799a4378,0x3ea930ea,0x3f994379}},	//   _ezio, _mitw, tcat_, _pisu_,
   {{0x799a437a,0x3f99009e,0x69c10285,0x00000000}},	//   _litw, _qisu_, रीडी, --,
   {{0x3ea9437b,0x3f99437c,0x63760674,0xa9230206}},	// [39b0] rcat_, _visu_, ránt, úžko,
   {{0xceeb00bf,0x3ea9437d,0xfd610019,0x3dc932dd}},	//   _کردن_, scat_, _huyế, rsaw_,
   {{0x3f99437e,0x60c7437f,0x9c190037,0x3ea93177}},	//   _tisu_, majm, بياء_, pcat_,
   {{0x7ae20484,0x60c74380,0x5b241e20,0x799a0239}},	//   ggot, lajm, льча, _aitw,
   {{0x799a4381,0x6f1d0632,0xd7f800d3,0xf7711ac9}},	//   _bitw, _insc, _apă_, یاب_,
   {{0x7ae201e9,0x799a0154,0xfd6100fe,0x00000000}},	//   agot, _citw, _luyế, --,
   {{0xd9421bc1,0x63682ddc,0x7bde4382,0x629f063d}},	//   рещи, nınc, cupu, _ogqo,
   {{0x78b8010a,0x629f0372,0xe6193d77,0x60c707c0}},	//   abvv, _ngqo, дди_, hajm,
   {{0x7b644383,0xd7060084,0x64480181,0x3b64008f}},	//   _стре, тные_, ezdi, _сърв,
   {{0x2bd809d0,0x6f0d3d0c,0xdb050364,0x6368026a}},	//   _डिमा, hdac, sphä, kınc,
   {{0x6f1d4384,0x69cb4385,0x67d40e05,0x87d40286}},	//   _onsc, lsge, _боху, _مغنا,
   {{0x69d904e2,0x63680555,0xdd0200c4,0x6f0d2e32}},	//   orwe, dınc, _čuči, jdac,
   {{0xad9b4386,0x799a0193,0xe8091462,0x6f0d4387}},	//   _asúm, _yitw, विका_, ddac,
   {{0x6f1d02e2,0x69cb4388,0x60c706c6,0x67294389}},	//   _ansc, isge, gajm, ljej,
   {{0x69d901bf,0x7f4400fd,0x6d5701ff,0x6f0d0381}},	//   hrwe, thiq, dixa, fdac,
   {{0xd36f00e3,0x973c03c6,0x6729438a,0x66f90be4}},	//   _وهو_, _kuća, njej, ्यटक_,
   {{0xdca61352,0x63a30b6a,0x7f44023b,0x7bde0294}},	// [39c0] вази, _hunn, rhiq, wupu,
   {{0x63a3438b,0x7bde438c,0xc8e00557,0x6f1d01c0}},	//   _kunn, tupu, _नाइट, _ensc,
   {{0x7c96438d,0x40d90130,0x7f44025a,0x823600d0}},	//   трац, _אַרײ, phiq, _سرکا,
   {{0x6b89438e,0x799a438f,0x7bde4339,0x673b4390}},	//   _cheg, _sitw, rupu, jkuj,
   {{0x7bde4391,0x8b650f43,0x63a34392,0x69cb4385}},	//   supu, دالم, _lunn, gsge,
   {{0x4973013a,0x7bde37b7,0x6d4501bf,0x14dd0096}},	//   аліс, pupu, chha, _मागण,
   {{0x6b9b1e3f,0x69cb057a,0x63a30f18,0x307a006e}},	//   _fiug, asge, _nunn, ואַנ,
   {{0x6b9b0465,0x60c701ac,0x799a0193,0x26c20d79}},	//   _giug, zajm, _witw, úko_,
   {{0xe9a60465,0xd379005f,0x25f4030b,0x3d170096}},	//   _разп, juća_, ्बधी_, नाचे_,
   {{0x799a0305,0x973c3c92,0xd3792461,0x63680367}},	//   _uitw, _duća, duća_, yınc,
   {{0x291e0694,0x63a30013,0x637d16e7,0x290c4393}},	//   _inta_, _cunn, léni, _iada_,
   {{0x290c4394,0xfd610028,0x63a34395,0x5453008f}},	//   _hada_, _quyế, _dunn, рвют,
   {{0xd379005f,0x63a30167,0xa5f80284,0xd5b000d1}},	//   guća_, _eunn, _челу_, _افت_,
   {{0x63a34396,0xf8b405a7,0x290c4397,0x63680345}},	//   _funn, ुरिय, _jada_, tınc,
   {{0x63a34398,0x290c4399,0xfd610028,0x60c74238}},	//   _gunn, _mada_, _tuyế, rajm,
   {{0xf1a71352,0x6f0d3e79,0x88bc00b6,0xe3af1f11}},	//   _ирон, udac, _hněd, _برو_,
   {{0x6f0d439a,0xc29902ec,0x291e1a3a,0x6d57439b}},	// [39d0] rdac, _яких_, _onta_, tixa,
   {{0x290c2733,0x63a3439c,0x4fc70a7c,0x50b7439d}},	//   _nada_, _yunn, _исма, _अभिष,
   {{0x4035439e,0x290e0150,0x69c00090,0x636803e0}},	//   _сенс, ddfa_, _awme, lına,
   {{0x41c400d0,0x291e439f,0x69cb43a0,0x6f1d0691}},	//   _حقیق, _anta_, tsge, _unsc,
   {{0x290c43a1,0x637d3b42,0x195904d9,0x61ef43a2}},	//   _bada_, géni, нады_, ntcl,
   {{0x69cb43a3,0xc4bd0081,0x60c502a1,0x61ed02a1}},	//   rsge, _ইঞ্জ, _jehm, _mqal,
   {{0x6d55008e,0x60c543a4,0xf7f50182,0x6b8943a5}},	//   _imza, _mehm, استد, _theg,
   {{0x61ed0372,0x80dc00c7,0x60c543a6,0x291e00dc}},	//   _oqal, ম্প্, _lehm, _enta_,
   {{0x290c43a7,0x63a332a7,0x672943a8,0x637d1de7}},	//   _fada_, _sunn, rjej, céni,
   {{0x290c0b4b,0x60c502e2,0xc98743a9,0x63a343aa}},	//   _gada_, _nehm, _руби, _punn,
   {{0x61ed43ab,0xf2850032,0x36d500d3,0x7e7d00f2}},	//   _aqal, _ibẹ̀_, _боер, _lysp,
   {{0xc65400cd,0x63a343ac,0x3f4700bc,0x07090076}},	//   افیک, _vunn, _jõud_, _سيتي_,
   {{0x973c00e9,0xf7700f43,0x290c43ad,0xde8f06c0}},	//   _kućn, _بال_, _yada_, _dịka_,
   {{0x06e31161,0xa11609e5,0x63a343ae,0xd3790880}},	//   _गाँव_, دوست, _tunn, ruća_,
   {{0xd37943af,0xa067182e,0xd6d9007f,0x61ed0415}},	//   suća_, гара_, wiły_, _eqal,
   {{0x6d550e69,0x2eb519e8,0xff0700ae,0x7e7d02ac}},	//   _amza, исус, леск_, _bysp,
   {{0x60c543b0,0x637d03be,0x332002a1,0x61ed039f}},	// [39e0] _fehm, xéni, _inix_, _gqal,
   {{0x6464013f,0x7e7d43b1,0x00000000,0x00000000}},	//   štiš, _dysp, --, --,
   {{0x06e343b2,0xdd8f00e3,0x9f5e43b3,0xdb1e007b}},	//   _गांव_, أول_, ító_, yspä,
   {{0x290c00e9,0xbda600d0,0xbae500d6,0x6d550415}},	//   _sada_, _محسو, ицій, _emza,
   {{0x290c43b4,0x00000000,0x00000000,0x00000000}},	//   _pada_, --, --, --,
   {{0x290c43b5,0x637d020d,0xdca343b6,0xbebb0f5a}},	//   _qada_, réni, _гари, _hoëp,
   {{0x8c4643b7,0x290c43b8,0x2a9e0174,0xb8cc00b7}},	//   _севе, _vada_, _ịbu_, _गल_,
   {{0x290c0694,0x7d0e43b9,0x47341339,0xa817001c}},	//   _wada_, _habs, рнис, اتور_,
   {{0xa3e607e2,0x261102d5,0x660d00e7,0xdb1e3341}},	//   यून_, तिषी_, _šakr, rspä,
   {{0x291e43ba,0x290c010a,0x7d0e026d,0xa9760da5}},	//   _unta_, _uada_, _jabs, _субј,
   {{0x24980149,0xb9930037,0x60c543bb,0x3f8000c6}},	//   ärm_, _اللب, _rehm, kliu_,
   {{0x9295060b,0xdc3b006e,0x7d0e43bc,0x918200fe}},	//   ианц, געטר, _labs, yễn_,
   {{0x60c503cf,0x36361850,0x00000000,0x00000000}},	//   _pehm, _حراس, --, --,
   {{0x973c0995,0x61ef18ef,0xc693021e,0x00000000}},	//   _kućo, rtcl, _פאס_, --,
   {{0xdfd8008f,0xe81700c3,0x68f50233,0x7e7d0365}},	//   лът_, थिया_, _özde, _sysp,
   {{0x7d0e00f9,0xaefb0139,0x63680342,0x774b0139}},	//   _aabs, _ijùk, pına, _kábọ,
   {{0x5d5535ca,0x6e99007e,0x61ed019f,0x3f4700bc}},	// [39f0] акат, твар_, _uqal, _nõue_,
   {{0x7d0e008a,0x7ae943bd,0x7e7d0146,0x00000000}},	//   _cabs, _scet, _vysp, --,
   {{0x7e7d0034,0x63ad007e,0x3ea643be,0x81b70033}},	//   _wysp, _čank, žota_, _চটি_,
   {{0xb17b0149,0x681c00ae,0x00000000,0x00000000}},	//   fråg, _mădă, --, --,
   {{0x36de009f,0x6f0f0036,0xfbd10285,0x2bd100c3}},	//   _गाड़ी_, _iacc, _हिकम, _हिका,
   {{0x26c9084f,0x6d550201,0x27380139,0x00000000}},	//   _žao_, _umza, _ménu_, --,
   {{0xb17b0501,0xe7310037,0x6f0f1b61,0x27380065}},	//   mråd, قصة_, _kacc, _lénu_,
   {{0xadc4026e,0x25a60167,0xb17b0073,0x6f0f43bf}},	//   _amẹr, _buol_, lråd, _jacc,
   {{0x6f0f43c0,0x75451146,0x00000000,0x00000000}},	//   _macc, иниз, --, --,
   {{0x6f0f43c1,0x7d0e008a,0x5a34315f,0x25a600f9}},	//   _lacc, _xabs, _унут, _duol_,
   {{0xd46943c2,0x336639f8,0x39450653,0xc8671ac8}},	//   тине_, ивог, _ills_, _стаи,
   {{0x6f0f43c3,0xa3ab04f1,0xad9b0072,0x17f80037}},	//   _nacc, _कंठ_, _crúz, _حركة_,
   {{0xf77043c4,0x6d8943c5,0xa3e6097c,0xb17b43c6}},	//   _عام_, _džaz, यूब_, kråd,
   {{0xd379005f,0xa06a01b3,0xe04643c7,0x6b5700ac}},	//   vrće_, вага_, анги, ụgha,
   {{0xd47900c1,0x7d0e43c8,0x1fb50426,0x0fd91402}},	//   _באַל, _rabs, йстр, льты_,
   {{0x6f0f43c9,0x7d0e43ca,0x33200d07,0x24a7004b}},	//   _cacc, _sabs, _unix_, šumą_,
   {{0xee3743cb,0x2a7f023e,0x6f0f209a,0xdcf5022b}},	// [3a00] ант_, _nyub_, _dacc, _ekzč,
   {{0x7d0e0694,0x8cb61ac8,0xb17b43cc,0x3f8043cd}},	//   _qabs, рсач, står, sliu_,
   {{0x6f0f013d,0x6c4a03ef,0x2a7f0533,0xd3790095}},	//   _facc, خلاف_, _ayub_, srće_,
   {{0x394543ce,0xa3e602e8,0x3dc2016d,0x00000000}},	//   _alls_, यंत_, _twkw_, --,
   {{0x7d0e0197,0x637d43cf,0xdca61312,0x201a00c4}},	//   _tabs, mént, _ваги, _hrpi_,
   {{0x6f0402dc,0x6f0f1cb2,0xb4cf00b7,0xa3e606eb}},	//   leic, _zacc, षणो_, यूड_,
   {{0xed57430b,0x2a7f03a9,0x25a60036,0xe758004d}},	//   _тор_, _eyub_, _suol_, ликі_,
   {{0x39450472,0x681c00ae,0x00000000,0x00000000}},	//   _ells_, _rădă, --, --,
   {{0x48e643d0,0x758a0aca,0x00000000,0x00000000}},	//   _возв, ксов_, --, --,
   {{0x236901ac,0x98a30012,0x25a600e5,0x6b8243d1}},	//   _sjaj_, _дифе, _vuol_, llog,
   {{0xc8b501b6,0xd6c400cd,0x6b8243d2,0x636811bc}},	//   _ысты, _همای, olog, rınn,
   {{0x6b8243d3,0x395c0b85,0x00000000,0x00000000}},	//   nlog, livs_, --, --,
   {{0x6f0f43d4,0x05b4006f,0x6b8243d5,0x6f0443d6}},	//   _racc, _امتح, ilog, deic,
   {{0xd5fb0054,0x6f0f43d7,0x67220146,0x5067384f}},	//   _ספור, _sacc, _hnoj, атба,
   {{0x6f0f008f,0x6b820124,0x6f040076,0x201a14f3}},	//   _pacc, klog, feic, _crpi_,
   {{0xddc400a5,0xf8b4030b,0x637d020d,0xc49b0266}},	//   dził, ुरुप, ténu, _בשות,
   {{0x212100de,0xb17b040f,0x2d81039f,0x7bde01cb}},	// [3a10] _tnhh_, tråd, tlhe_, erpu,
   {{0x6f0f006d,0x6b8243d8,0x00000000,0x00000000}},	//   _wacc, elog, --, --,
   {{0x6f0f43d9,0x6b820150,0xb17b0073,0x6368026a}},	//   _tacc, flog, rråd, kınl,
   {{0x637d0610,0xb17b0c96,0x59d50037,0x6f0f0537}},	//   cént, sråd, مغتر, _uacc,
   {{0x63680702,0xf8b40034,0x7bde43da,0xde6400e5}},	//   dınl, ुरूप, arpu, _дърп,
   {{0xdb070222,0x2aad43db,0x186925d7,0x261a00b6}},	//   _stjä, _bóbó_, лали_, बिनी_,
   {{0x98f41790,0xdb090364,0xf9901b71,0x1bd421b6}},	//   تثنا, _gieß, ذبه_, _моря,
   {{0x6b82015e,0x7d050063,0x2ee943dc,0x00000000}},	//   clog, lehs, ngaf_, --,
   {{0x7afb43dd,0xe5790832,0x6d472f54,0x00000000}},	//   _ibut, лзи_, _klja, --,
   {{0x6f0402e2,0x394505fe,0x672243de,0xa3c80557}},	//   zeic, _ulls_, _enoj, _लौह_,
   {{0x6d470218,0x6f040350,0x00000000,0x00000000}},	//   _mlja, yeic, --, --,
   {{0x6722011d,0x6f04002b,0x7d050113,0x00000000}},	//   _gnoj, xeic, hehs, --,
   {{0xb5a71f0d,0xd77400e3,0x7afb43df,0x6f0443e0}},	//   _трей, _بالع, _mbut, veic,
   {{0x67220d94,0x6f040364,0x660943e1,0x2bd843e2}},	//   _znoj, weic, mwek, _डिला,
   {{0x637d09e9,0x7afb43e3,0x6f0400d9,0x63680491}},	//   tént, _obut, teic, lınm,
   {{0x6d4743e4,0x27ea052f,0x66090a4b,0x04930139}},	//   _alja, _åbne_, owek, _lẹkọ,
   {{0x6f0402d6,0x660943e5,0x637d00cd,0x63680740}},	// [3a20] reic, nwek, rént, nınm,
   {{0x637d03be,0x6f040441,0xc7b80357,0x660943e6}},	//   sént, seic, _hrđe_, iwek,
   {{0x63680b88,0x61e643e7,0x7afb010a,0x6f040364}},	//   yınl, lukl, _bbut, peic,
   {{0xf09300a1,0x660943e8,0x63680092,0xba2600ae}},	//   _מנת_, kwek, xınl, йдек,
   {{0xceb307a6,0x6b8243e9,0xb3470396,0x61e643ea}},	//   _מיר_, rlog, luçõ, nukl,
   {{0x7afb43eb,0xa7b843ec,0xe91807bf,0x00000000}},	//   _ebut, алку_, рокі_, --,
   {{0x6c36172a,0x6d5e43ed,0xd7fa0036,0x395c0212}},	//   _افزا, mipa, уул_, rivs_,
   {{0x6d5e34e1,0x61e643ee,0xa3e60f35,0x3eb20072}},	//   lipa, kukl, यंस_, ncyt_,
   {{0x61e643ef,0xfa6a00ae,0x3f4700bc,0x6368020e}},	//   jukl, _саак_, _jõua_, rınl,
   {{0x61e643f0,0x636803e0,0xf8ac034c,0x7afb0052}},	//   dukl, sınl, _चलिय, _zbut,
   {{0xa3ab0251,0x439543f1,0x1616034c,0xdd7b0142}},	//   _कूद_, жанс, तिहर_, רטיל,
   {{0xdc9b0130,0x6d5e43f2,0xb3470161,0x2be00b3f}},	//   טייל, hipa, duçõ, _पटना,
   {{0x6d5e43f3,0x98ac0d77,0x9ad40294,0xf8ac30a8}},	//   kipa, _चलाए, yịny, _चलाय,
   {{0x067b0130,0x6d5e43f4,0xe3af12eb,0xdb000052}},	//   _ענגל, jipa, بری_, _bimë,
   {{0x6d5e43f5,0x657a43f6,0xd48f43f7,0x656f43f8}},	//   dipa, moth, _хр_, éche,
   {{0x3ceb43f9,0x7eb9013d,0x657a43fa,0x6d4700cc}},	//   _चाहे_, ргас_, loth, _slja,
   {{0x171b0130,0x6d4700e9,0x61e601e8,0x7d050092}},	// [3a30] נומע, _plja, cukl, tehs,
   {{0x657a09c7,0x628d1820,0x973c007e,0x4c4b0b2f}},	//   noth, _izao, _bućk, ляем_,
   {{0x443e43fb,0xfbd000cd,0x7d0543fc,0xb347016d}},	//   nyt_, فتن_, rehs, cuçõ,
   {{0xdb000154,0x7d05042c,0x2001063d,0x6d5e075c}},	//   _jimè, sehs, _iphi_, aipa,
   {{0x657a019f,0x443e43fd,0x6d5e43fe,0x6d4705db}},	//   koth, hyt_, bipa, _tlja,
   {{0x7ff400bf,0x6d4743ff,0xa3d80096,0x6e201de1}},	//   _بسیا, _ulja, ाळा_, _ámba,
   {{0x61e6026a,0x7c3e039f,0x443e007b,0x657a0632}},	//   zukl, cypr, jyt_, doth,
   {{0x7afb092f,0x59c6000d,0x443e4400,0xe7392796}},	//   _ubut, रीहर, dyt_, реи_,
   {{0xdb1c0088,0x05a60084,0x63aa01bf,0xa3e60789}},	//   _evró, овый_, _aufn, यूस_,
   {{0x61e60995,0xd3790039,0x58d40686,0x66094401}},	//   vukl, vrća_, _ноут, rwek,
   {{0xf6d500d6,0xd8474402,0xe29f003e,0x00000000}},	//   _діля, _ухап, veða_, --,
   {{0xf7700080,0x61e64403,0x27e701b5,0x6d5e4404}},	//   _كان_, tukl, munn_, zipa,
   {{0xdb1e01df,0xdb0030ea,0x1539001c,0x6d4b01d3}},	//   rspø, _dimè, _پزشک_, īgaj,
   {{0x443e109b,0x29074405,0x31af07aa,0xa3e602d5}},	//   byt_, nena_, _düz_, यूह_,
   {{0xa0a34406,0x61e64407,0x48fb030b,0x628d02f1}},	//   дард, sukl, ल्यो_, _ezao,
   {{0x776904c7,0x29074408,0xb3470161,0x61e64409}},	//   nnex, hena_, ruçõ, pukl,
   {{0x2907440a,0x98a5007f,0x00000000,0x00000000}},	// [3a40] kena_, _wolę_, --, --,
   {{0x63a4007a,0xf1b900b6,0x98ac020a,0x320d0233}},	//   _hiin, íše_, _modă_, çeye_,
   {{0x63a4440b,0x6d5e440c,0xbc6a0018,0xf81e007f}},	//   _kiin, ripa, جمان_, ążkę_,
   {{0x6d5e440d,0x31af0511,0x7f4d037a,0x7c3e02ac}},	//   sipa, _yüz_, chaq, rypr,
   {{0x63a4440e,0xdb00440f,0x657a019f,0xad9b0103}},	//   _miin, _jimé, yoth, _csús,
   {{0x63a413e1,0xceb400a7,0x27e700f3,0x6d5e0216}},	//   _liin, lcə_, funn_, qipa,
   {{0x98be00d3,0xa7fc00a7,0x27310103,0x27e74410}},	//   _altă_, _axır, _hány_, gunn_,
   {{0x44200871,0x63a44411,0x96340cf5,0xceb401d4}},	//   _či_, _niin, зниц, ncə_,
   {{0x55061119,0x62840063,0x657a24f9,0xcf9300ca}},	//   очна, _nyio, toth, וטה_,
   {{0x63764412,0x443e4413,0xb6030031,0x88bc00b6}},	//   mány, tyt_, úšaj, _zněn,
   {{0xd6cf4414,0xad1b00c1,0x27310103,0xceb40092}},	//   _от_, בויר, _lány_, kcə_,
   {{0x74ba04dd,0x443e4415,0x657a4416,0x63b52347}},	//   _श्रृ, ryt_, soth, ízna,
   {{0xd37914f3,0x63a4388f,0x657a4417,0xdb9b0341}},	//   nući_, _diin, poth, יסטר,
   {{0x443e4418,0x66024419,0x63b800de,0x657a0201}},	//   pyt_, _ipok, _ttvn, qoth,
   {{0x63a40012,0xb4d6000c,0x63760103,0x40350497}},	//   _fiin, िणी_, hány, чевс,
   {{0x3cfd000d,0x2907441a,0x63a411b9,0x66020294}},	//   र्ने_, zena_, _giin, _kpok,
   {{0xd37903ce,0x2907441b,0xdb00441c,0x764003a8}},	// [3a50] jući_, yena_, _gimé, nymy,
   {{0xd37902e6,0x2907441d,0x7f4d441e,0x63a42d30}},	//   dući_, xena_, shaq, _ziin,
   {{0x764000f0,0xd7a90034,0x92ad0033,0x4ab9441f}},	//   hymy, _चूंच, গরী_, буля_,
   {{0x6d5c3fe3,0xa3cc063e,0x29074420,0x66024421}},	//   _emra, शीय_, wena_, _opok,
   {{0xd37904a3,0x776900dc,0x63760103,0xdb000143}},	//   gući_, vnex, gány, _ximé,
   {{0xe8174422,0x00000000,0x00000000,0x00000000}},	//   थिला_, --, --, --,
   {{0x29070454,0x6d450201,0x644d03e3,0xe7390036}},	//   rena_, mkha, _ƙaim, йек_,
   {{0x27e74423,0x3f57003d,0x6d45311b,0x6d5c0094}},	//   runn_, għux_, lkha, _zmra,
   {{0x29074424,0x77690078,0x63a44425,0x764003a8}},	//   pena_, rnex, _riin, gymy,
   {{0x63a44426,0x6d454427,0x69c9010a,0x34390037}},	//   _siin, nkha, _iwee, مسجد_,
   {{0xa3e609d0,0xdb004428,0x66024429,0x63a413e1}},	//   यूल_, _simé, _epok, _piin,
   {{0xd874048f,0x69c9442a,0xd7fa00ca,0x6d45041c}},	//   _غالب, _kwee, _להעל, hkha,
   {{0x63a4442b,0x69c9010a,0x6d450565,0x00000000}},	//   _viin, _jwee, kkha, --,
   {{0x25bf442c,0xd1320018,0x55ba00ca,0xc7b80357}},	//   mpul_, رمز_, _המסו, _hrđa_,
   {{0x6561442d,0x3d0f0034,0x63a4442e,0x6023002e}},	//   milh, ड़ने_, _tiin, ндра,
   {{0x0eaa08a1,0x6aa9442f,0x64414430,0x69c906b0}},	//   скай_, _ngef, myli, _owee,
   {{0x69c90294,0x6d5c0063,0xc7b80095,0x248e007e}},	// [3a60] _nwee, _pmra, _mrđa_, _zzfm_,
   {{0xd379005f,0x65610161,0x98ac0138,0x63760103}},	//   vući_, nilh, _kodą_, vány,
   {{0x31570132,0x644102ad,0x913b00ca,0x69c9083e}},	//   _זיין_, nyli, _העיק, _awee,
   {{0x6da62cad,0x69c90361,0x6e200042,0xeb974431}},	//   _нима, _bwee, _ámbo, пих_,
   {{0x6d4501c2,0xf38d0142,0x00000000,0x00000000}},	//   bkha, בראָ, --, --,
   {{0x6d5c0aba,0xd37900cc,0x69c901af,0x63760103}},	//   _umra, rući_, _dwee, rány,
   {{0x65614432,0x06e30081,0x69c9083e,0x66024433}},	//   dilh, _মসজি, _ewee, _spok,
   {{0xf1be0d61,0xddc401d3,0x85b80b31,0x00000000}},	//   ्ठान, rziņ, олис_, --,
   {{0x75382052,0xeb97075f,0xbebb0629,0x69c94434}},	//   _povz, _хит_, _poëz, _gwee,
   {{0x73d82b79,0xdb0700f3,0x2c00007a,0x661d0537}},	//   одор_, _stjø, _ईहां_, æska,
   {{0x764002fd,0x69c901c0,0xa2be0096,0x656f020d}},	//   symy, _zwee, _व्ह्, écha,
   {{0xc7b3040a,0x6d4b01d3,0x394c0076,0xaacc00a8}},	//   _טבע_, īgai, _hlds_, ारिक,
   {{0x7afd4435,0x66024436,0xf8d02fc2,0xf1bf00d2}},	//   _öste, _upok, _सजाय, upá_,
   {{0x3f824437,0xad9b0328,0x61e00103,0x92ad0033}},	//   _akku_, _apún, ámla, গরে_,
   {{0x7d1502dd,0x34fb00ca,0x4acc0096,0xdb1e0076}},	//   _razs, _ההוד, ाराव, nspó,
   {{0x35d10251,0x8f34065c,0x9f3401ce,0xa3e6007f}},	//   _दौड़, несц, несі, यूः_,
   {{0xc4340068,0x6d451c7a,0x02c31462,0x00000000}},	// [3a70] _رکھت, tkha, _व्यभ, --,
   {{0x9d144438,0x00000000,0x00000000,0x00000000}},	//   ндуч, --, --, --,
   {{0x6d452ada,0x661b16aa,0x69c94439,0x69ca2231}},	//   rkha, zvuk, _swee, सीसी,
   {{0x7fd6040a,0x6d45443a,0xd5dd0336,0x395e443b}},	//   _קורס_, skha, _मिलज, _amts_,
   {{0x6441443c,0x9f4302c6,0x63760072,0x2bce0966}},	//   zyli, nují_, ránx, हीबा,
   {{0x3f890150,0x6739443d,0xba740421,0xc7b809ac}},	//   llau_, _sowj, رانت, _srđa_,
   {{0x6561001f,0x3f890150,0x9f4300b6,0x2d830052}},	//   vilh, olau_, hují_, _ikje_,
   {{0x69c9396c,0xf0940341,0xeab00037,0x9f4302c6}},	//   _twee, ענק_, _معك_, kují_,
   {{0x50bf000f,0xa8a70b1e,0x6561443e,0xd3792461}},	//   ्राष, _ерек, tilh, nuću_,
   {{0x25bf443f,0x9f4300b6,0x044527a5,0x3f894440}},	//   rpul_, dují_, деон, hlau_,
   {{0x65614432,0x3f890325,0x25bf05c2,0x661b0e22}},	//   rilh, klau_, spul_, svuk,
   {{0x8c1a00a1,0x3cfd009d,0x65610131,0x66e30032}},	//   קורי, र्ते_, silh, _dìkà,
   {{0xd3790106,0xa3b2000f,0x7e69033b,0xe5e6001c}},	//   juću_, _झूठ_, _žepn, _قزوی,
   {{0x59e0009d,0x2242004d,0x26cf01e9,0x66e30139}},	//   _निसर, rykk_, _hego_, _fìkà,
   {{0xb4e91fbb,0x00000000,0x00000000,0x00000000}},	//   यली_, --, --, --,
   {{0x60c10dea,0x26cf0067,0xdb07034f,0x9f4300b6}},	//   ılma, _jego_, _bují, bují_,
   {{0xd1ba2761,0xd3790995,0x88bc00b6,0x2fcd0ac3}},	// [3a80] _بابا_, guću_, _sněm, ćega_,
   {{0x3eb90088,0x00000000,0x00000000,0x00000000}},	//   _efst_, --, --, --,
   {{0x3f890d32,0x201c0103,0xfb820103,0x25a7022b}},	//   blau_, _évi_, نگری, _minl_,
   {{0x26cf02e6,0x0b464441,0x6e291e4d,0x3f820d2a}},	//   _nego_, ьнен, _šebe, _ukku_,
   {{0x3dcb03a8,0x00000000,0x00000000,0x00000000}},	//   _gwcw_, --, --, --,
   {{0xe8944442,0xc983166f,0x4acc00c3,0xdb0e0216}},	//   наль, кущи, ारहव, _kubë,
   {{0x9f4300b6,0x26cf4443,0xb9061073,0x59e01677}},	//   zují_, _bego_, _भय_, _निवर,
   {{0x26cf0558,0x628800a7,0xa6144444,0x261a00bc}},	//   _cego_, ədov, емич, बिली_,
   {{0x6a831ad1,0xe9d73097,0xe4e6004d,0x26cf008c}},	//   _алта, _окт_, мінн, _dego_,
   {{0x4a5700a1,0x69c218f0,0x9f4300b6,0x26cf0188}},	//   _חשמל_, mpoe, vují_, _eego_,
   {{0xdb004445,0x61e61f6d,0x973c02f7,0x3f8900f0}},	//   _limí, erkl, _suću, ylau_,
   {{0xf6d61e49,0x26cf00c4,0x25af3fe4,0x9f4302c6}},	//   _آزاد, _gego_, _fugl_, tují_,
   {{0x51874446,0x25af0d62,0xa2db0f35,0x69c21cab}},	//   дува, _gugl_, पृष्, npoe,
   {{0x9f4302c6,0x7e690141,0x00000000,0x00000000}},	//   rují_, _žepo, --, --,
   {{0x1fa74447,0x3f890178,0x26cf05bd,0xdb000503}},	//   драг, tlau_, _yego_, _aimí,
   {{0x2bd807e2,0x5f943a7a,0x9f580c56,0x2d83004d}},	//   _डिजा, вист, ntrè_, _skje_,
   {{0x2005030b,0xd2520018,0x88bc00b6,0x3f894448}},	// [3a90] ůli_, _منٹ_, _vněj, rlau_,
   {{0x30153e04,0x9f4a028d,0x00000000,0x00000000}},	//   _здор, hubè_, --, --,
   {{0xd3794072,0x99490220,0x2b4d4449,0x69c2444a}},	//   suću_, núť_, _plec_, epoe,
   {{0x309a0054,0x6d4e444b,0xceeb001c,0xc07a00fe}},	//   _משתמ, _elba, _بردن_, _lượm_,
   {{0x9f5a003e,0x26cf444c,0x6f0d444d,0x6eba0796}},	//   _uppá_, _rego_, meac, _מזרח,
   {{0x6f0d0a21,0x681300a7,0xdb0e01dc,0x26cf444e}},	//   leac, _hədə, _lubè, _sego_,
   {{0x26cf0db4,0x7c84444f,0x6813013c,0x00000000}},	//   _pego_, _ауте, _kədə, --,
   {{0x6f0d4450,0xac94163d,0x2d810031,0x00000000}},	//   neac, _расш, lohe_, --,
   {{0x681301d4,0x6abb0134,0xb17b1842,0x3989003e}},	//   _mədə, _ifuf, trål, húsi_,
   {{0xe00f1152,0x6f0d10f0,0xb4e9030b,0x26cf00dc}},	//   ाबाद_, heac, यले_, _wego_,
   {{0x26cf0d1b,0x6368026a,0x78ac0146,0x69d931fc}},	//   _tego_, kınt, ňové, lswe,
   {{0x91e61312,0x81d70081,0x59c61da8,0x681300a7}},	//   номе, _সহজ_, रीकर, _nədə,
   {{0x6f0d328f,0x69d94451,0x15f30034,0x2d814452}},	//   deac, nswe, _आमिर_, kohe_,
   {{0x69d931ae,0x463a006e,0x00000000,0x00000000}},	//   iswe, _מענע, --, --,
   {{0xf1dc07e2,0x6f0d00e3,0x6abb0129,0x681300a7}},	//   _बिकन, feac, _ofuf, _bədə,
   {{0x6f0d4453,0xd2520391,0x6fe100aa,0xa3c80cce}},	//   geac, _منع_, _फिरं, _लौट_,
   {{0x9f584454,0xdb000161,0x3f80020a,0x00000000}},	// [3aa0] ntré_, _limã, roiu_, --,
   {{0xa3e3009f,0x98a5022b,0x69d918f0,0x6abb270d}},	//   _फटा_, _anlč_, dswe, _afuf,
   {{0xdd8f1be8,0xd91000cd,0xc17300a1,0x69d90313}},	//   حول_, ییر_, _תחת_, eswe,
   {{0x6f0d009b,0x3ce64455,0x2d660065,0x69d910ef}},	//   ceac, şov_, _bíeè_, fswe,
   {{0x05d40096,0xdcfc01d3,0x69d94456,0x2d810079}},	//   _धबधब, _ekrā, gswe, bohe_,
   {{0x69c24457,0x6abb4458,0x48fb0c38,0x6d4e01b9}},	//   rpoe, _efuf, ल्लो_, _ulba,
   {{0x2d9802dc,0x69c219fb,0x69d90313,0x6abb010a}},	//   _ihre_, spoe, aswe, _ffuf,
   {{0xa84700e3,0x9f58003e,0x3ea601d3,0x69c24459}},	//   عليم_, ftré_, žotu_, ppoe,
   {{0x3cfd0455,0x6b82445a,0xdb00009c,0xdb0e30ea}},	//   र्वे_, moog, _iimà, _rubè,
   {{0x6b820006,0x672b2cfc,0xdb000428,0xa9670012}},	//   loog, _engj, _himà, _зиуа_,
   {{0xd49802ec,0xdb1c0143,0x6f0d0239,0x35f700d1}},	//   ької_, _atré, yeac, ورید_,
   {{0x290e445b,0x6b8234bb,0x88bc00b6,0xd5ba00d3}},	//   lefa_, noog, _sněh, _еск_,
   {{0xf20402e3,0x60d500e7,0x6cf002d5,0xd46a31bb}},	//   ляро, tazm, _चांग_, تحکم_,
   {{0x290e03a8,0x6b82445c,0x291c445d,0xdb1c00da}},	//   nefa_, hoog, ndva_, _dtré,
   {{0x6f0d0fab,0x60d50e9e,0xdb07034f,0x746700e5}},	//   teac, razm, _lujá, _пръв_,
   {{0x681301d4,0x6b82445e,0x69c00e94,0x69d91849}},	//   _qədə, joog, _otme, yswe,
   {{0x6f0d445f,0x62354460,0xf1a733ed,0x7bdc01e8}},	// [3ab0] reac, _репу, _прон, _avru,
   {{0x6f0d4450,0x4ea42cbf,0x290e01c2,0x00000000}},	//   seac, урса, jefa_, --,
   {{0x41b7000f,0x2fd900e3,0x69c04461,0xceb40092}},	//   _इंडस, _توجد_, _atme, mdən_,
   {{0x69d94462,0xeab0012b,0x6b824463,0xdb070669}},	//   tswe, معه_, goog, _bujá,
   {{0xdb070102,0x61fd4464,0xdb004465,0x9f43016d}},	//   _stjó, ntsl, _dimà, cujá_,
   {{0xceb40253,0xfbd3012b,0x69d907e6,0x2d98009c}},	//   ndən_, _متر_, rswe, _ghre_,
   {{0xe7391227,0x69c00b88,0x6b820f51,0xac9400c6}},	//   дей_, _etme, boog, _барш,
   {{0x7bc5019f,0x6abb0239,0x7c3a4466,0x69d901d0}},	//   mphu, _ufuf, _àtra, pswe,
   {{0xceb40092,0x57240037,0x998d078e,0x00000000}},	//   kdən_, طريق, _greş_, --,
   {{0x637d0068,0xdb0e4467,0xe3b911db,0xdb00016d}},	//   mény, _rubé, мбо_, _timã,
   {{0x9f584468,0x290518f6,0x79830270,0x7bc50023}},	//   stré_, _ibla_, monw, nphu,
   {{0x069900e3,0x61fd4469,0x3fc80018,0x672b446a}},	//   _قناة_, ftsl, ہدری_, _ungj,
   {{0x20d600d6,0xceb400a7,0xe2973842,0x00000000}},	//   ківс, fdən_, каю_, --,
   {{0x6e20446b,0xf8d1152c,0xdb0902ac,0x79830169}},	//   _ámbi, हरिय, _bieë, nonw,
   {{0x61fd112f,0x998f00c6,0x00000000,0x00000000}},	//   atsl, lygų_, --, --,
   {{0xa3e609c3,0x290e1518,0xdb0e0143,0xdb0902ac}},	//   _पित_, zefa_, _tubé, _dieë,
   {{0x8fa3121c,0xfe4330da,0x27380103,0xceb400a7}},	// [3ac0] рате, анто, _pénz_, bdən_,
   {{0x64450006,0x63ae0037,0xf29700ca,0x9f430131}},	//   _ühis, _úiné, _בכפר_, rujá_,
   {{0x6b82446c,0x69c002a1,0x00000000,0x00000000}},	//   toog, _stme, --, --,
   {{0xb4ae009f,0xa3e63ec4,0x2738446d,0x1b9a0037}},	//   _कल्_, यूट_, _fény_, ذئاب_,
   {{0x637d0103,0x6b82446e,0x79830150,0x290e446f}},	//   gény, roog, fonw, tefa_,
   {{0x7bc534fa,0xf80600d6,0x3ea600e8,0x00000000}},	//   bphu, вчин, žots_, --,
   {{0x9d1b00c1,0x290e4470,0x7d1c0037,0x00000000}},	//   _קולט, refa_, _iars, --,
   {{0xe7e30251,0x290e4471,0xceb40092,0xd05600a7}},	//   _गिरा_, sefa_, zdən_, übəs,
   {{0x7d1c4472,0x68ed0018,0x69c00120,0xbb433968}},	//   _kars, ándé, _utme, _тетк,
   {{0xf1dc417a,0xdcfe14f3,0x7e690117,0xe7ea0096}},	//   _बिजन, kopč, _žepk, _टिपा_,
   {{0x2955008f,0xe2f9004d,0x26174473,0xceb4013c}},	//   _сътр, нені_, _बैठी_, vdən_,
   {{0x7d1c0c2e,0x61fd0578,0x7bdb00a1,0xb17b0ec9}},	//   _lars, ttsl, וקטו, pråk,
   {{0x7d1c01e9,0xa3e60a35,0xceb40092,0x00000000}},	//   _oars, यूज_, tdən_, --,
   {{0x70bf022d,0x7d1c4474,0x61ef042d,0xa2c50033}},	//   ्रेल, _nars, rucl, ্লেখ,
   {{0xceb401d4,0xd37b0cd7,0x224d18f9,0xdfd8013d}},	//   rdən_, _очи_, šek_, кът_,
   {{0xd43700a1,0x65684475,0x3eaf0f04,0x0ccb1178}},	//   _ירוק_, lidh, øgt_, िर्म,
   {{0xe3b800a7,0x680a00a7,0x60c2020a,0x644801b6}},	// [3ad0] lqı_, _hədd, _şome, lydi,
   {{0x7d1c4476,0xbebb01e5,0x2b8e0074,0x637d0018}},	//   _cars, _anët, lých_, vény,
   {{0x7d1c4477,0x6ca70a28,0x2ca74478,0x63ad4479}},	//   _dars, траж, änd_, _kian,
   {{0x2b8e0897,0x7d1c01b9,0x6568447a,0x63b500b6}},	//   ných_, _ears, hidh, ízni,
   {{0x7d1c447b,0x63ad447c,0xe1ff0fa6,0x64480150}},	//   _fars, _mian, ntó_, hydi,
   {{0x7d1c447d,0x656800dd,0x2b8e025b,0x6f1d447e}},	//   _gars, jidh, hých_, _hasc,
   {{0x2b8e0c01,0xccf20054,0xb8cb1462,0x6f1d3a23}},	//   kých_, _לכם_, _गण_, _kasc,
   {{0xe619247a,0x63ad447f,0x44294480,0x6568029a}},	//   еди_, _nian, _ča_, eidh,
   {{0x2b8e0146,0x6b9b4481,0x7d1c4482,0xe1ff0103}},	//   dých_, _ihug, _yars, jtó_,
   {{0x6f1d4483,0x28ac000d,0x63ad00bc,0xc9840fec}},	//   _lasc, _चलचि, _aian, _кухи,
   {{0x63ad013d,0x628d30ef,0x645a00c6,0x2d4402c3}},	//   _bian, _ayao, gzti, _köer_,
   {{0x6f1d4484,0xc7b200a1,0x63ad4485,0x18a4004d}},	//   _nasc, _הבא_, _cian, _таєм,
   {{0x63ad159d,0x65680010,0xbbe00d75,0xd6d9007f}},	//   _dian, bidh, _पट्क, mał_,
   {{0xe00f02d5,0x660b0063,0xf8c60c9c,0x6b9b009c}},	//   ाबंद_, _ipgk, रुपय, _lhug,
   {{0xdee636c9,0x63ad4486,0x1fb54487,0x2b8e0094}},	//   лови, _fian, истр, bých_,
   {{0x63ad4488,0xd6d90034,0x2f5515db,0x6d4300c2}},	//   _gian, nał_, атус, önan,
   {{0x7d1c4489,0xdd92006f,0xe1ff058a,0x6e9300e3}},	// [3ae0] _pars, مور_, ctó_, ملفا,
   {{0xdca6448a,0x7d1c448b,0x4427448c,0x6b9b448d}},	//   гази, _qars, _krn_, _ahug,
   {{0x6f1d0d63,0xd6d9007f,0xb605448e,0x00000000}},	//   _fasc, kał_, _hašč, --,
   {{0x7d1c448f,0x6b9b00e3,0x7afd0e74,0xb60505db}},	//   _wars, _chug, _östl, _kašč,
   {{0x298a1121,0x673b0c27,0x7d1c4490,0xa96a0095}},	//   нско_, djuj, _tars, нида_,
   {{0xc27b00c1,0xb6050087,0x6b890174,0x6f1d13be}},	//   ערסי, _mašč, _ekeg, _zasc,
   {{0x37aa4491,0x8b96129e,0x6e24028d,0xb6050141}},	//   нтин_, _брач, lvib, _lašč,
   {{0xdb0e2347,0x6b9b009c,0x673b0216,0x7bde4492}},	//   _kubí, _ghug, gjuj, mspu,
   {{0x2b8e0c01,0x63ad4493,0x64484494,0x6e24057a}},	//   vých_, _rian, wydi, nvib,
   {{0x64482c94,0x7bde0063,0xe3b800a7,0x645a042c}},	//   tydi, ospu, tqı_, tzti,
   {{0x65684495,0x2b8e0074,0x33752dd8,0x291e00d3}},	//   ridh, tých_, игор, _iata_,
   {{0x291e4496,0xb605050d,0x76490193,0xd49700c6}},	//   _hata_, _bašč, byey, ыры_,
   {{0x291e4497,0x2b8e0074,0x645a0068,0x63ad4498}},	//   _kata_, rých_, szti, _vian,
   {{0xd3790995,0xe1ff4499,0xe69300e3,0x6f1d02db}},	//   vrću_, rtó_, _الهد, _sasc,
   {{0x291e449a,0xe1ff449b,0x6f040e66,0x44270270}},	//   _mata_, stó_, ffic, _grn_,
   {{0x2f1814fa,0x7bde038c,0x291e449c,0xa3b9245a}},	//   лось_, dspu, _lata_, _अंत_,
   {{0x59e00d77,0xdb0e037a,0x7bde3412,0x628d0350}},	// [3af0] _निगर, _cubí, espu, _uyao,
   {{0x6b9b449d,0x291e449e,0x6f1d01bf,0xd6d90034}},	//   _shug, _nata_, _wasc, zał_,
   {{0xb6050b27,0xc17400a1,0x6f1d449f,0x656f00fd}},	//   _zašč, _לחץ_, _tasc, échi,
   {{0xfbd000bf,0xf2960af0,0x291e00b7,0x4c94007b}},	//   ستم_, _abẹ́_, _aata_, щихс,
   {{0x291e44a0,0x245b0139,0x00000000,0x00000000}},	//   _bata_, _kámé_, --, --,
   {{0xd6d90067,0xed510068,0x186944a1,0x291e44a2}},	//   wał_, _بھر_, кали_, _cata_,
   {{0x6b9b0a21,0x291e44a3,0xd6d90034,0xbd050065}},	//   _thug, _data_, tał_, _eléè,
   {{0x5ba430da,0x25ae01b9,0x6b9b44a4,0x6b890027}},	//   _груз, _aifl_, _uhug, _ukeg,
   {{0x291e44a5,0x442744a6,0xdb0e0072,0xd6d9007f}},	//   _fata_, _srn_, _xubí, rał_,
   {{0x056544a7,0x291e44a8,0xd6d900a5,0xb6050335}},	//   рвон, _gata_, sał_, _rašč,
   {{0x281500cd,0x00000000,0x00000000,0x00000000}},	//   _خواس, --, --, --,
   {{0xe81b000f,0x291e1114,0x25ee0096,0xf3f10294}},	//   _भैया_, _zata_, _आमची_, rụ_,
   {{0x291e44a9,0x26cd0143,0x44270167,0xeb3a006e}},	//   _yata_, mbeo_, _wrn_, דערש,
   {{0x64a544aa,0x4427031a,0xdb15023b,0x3c05009f}},	//   _кала, _trn_, _buzë, _रहूँ_,
   {{0xa0a644ab,0x442744ac,0xdb1c003e,0xdb0e0328}},	//   равд, _urn_, _strí, _subí,
   {{0x6d552034,0xcc360068,0xaec61c0f,0xb605033b}},	//   _alza, یراع, рбал, _tašč,
   {{0x6f04158e,0x2baf04f1,0x3dc900f9,0xdc3c033b}},	// [3b00] rfic, _जंजा, gpaw_, ršča,
   {{0x6f041168,0x6e240143,0x7bde44ad,0x7afb44ae}},	//   sfic, rvib, tspu, _acut,
   {{0x60dc44af,0x161c0251,0x3dc907ac,0x6f0400b3}},	//   marm, _बैनर_, apaw_, pfic,
   {{0x291e02e6,0x60dc44b0,0x7bde44b1,0xdb1c00ae}},	//   _sata_, larm, rspu, _strâ,
   {{0x32020094,0xda631ff9,0x7bde0365,0x00000000}},	//   ntky_, овци, sspu, --,
   {{0x60dc0088,0x3f921df6,0x07e644b2,0xa3e60285}},	//   narm, llyu_, ацим, _पिल_,
   {{0xa8a3008f,0xb8de3aee,0x20560142,0x00000000}},	//   орък, _इल_, ייַל_, --,
   {{0x291e0a75,0xab7400cd,0xdb07003e,0x36d40291}},	//   _wata_, _انرژ, _stjö, љопр,
   {{0x291e0194,0x60dc44b3,0x00000000,0x00000000}},	//   _tata_, karm, --, --,
   {{0x60dc44b4,0xe4a644b5,0x00000000,0x00000000}},	//   jarm, ирно, --, --,
   {{0x60dc44b6,0x33200472,0x3cfe1bc3,0x32020031}},	//   darm, _baix_, _लाने_, etky_,
   {{0x680a01d4,0x3d061492,0x98be0154,0x60dc009c}},	//   _tədb, स्ते_, _motč_, earm,
   {{0x60dc44b7,0x60c2020a,0xdb0e00b3,0x98be0154}},	//   farm, _şoma, _mubà, _lotč_,
   {{0x224b0149,0x32d500fe,0xa18701b3,0x00000000}},	//   ryck_, ấy_, рымл, --,
   {{0x32021515,0x656f020d,0x657d0103,0x9f430206}},	//   atky_, èche, éshe, mujú_,
   {{0x9f430031,0x6447007b,0x09d70033,0xa85700ca}},	//   lujú_, äjie, _সমসা, בילה_,
   {{0x236906a3,0x60dc44b8,0x5d5500d3,0xd2513a89}},	// [3b10] _imaj_, barm, бкат, _رند_,
   {{0x60dc44b9,0x7afb00d3,0x9f430031,0x91a000fe}},	//   carm, _scut, nujú_, _trí_,
   {{0x92d90081,0x63b80027,0x98bc02c6,0x3cfd44ba}},	//   ালী_, _juvn, skvě_, र्गे_,
   {{0x9f430220,0x21210167,0x98be022b,0x09ce0033}},	//   hujú_, _hahh_, _dotč_, _রমজা,
   {{0x9f430031,0x600c01f9,0xe9f80120,0x00000000}},	//   kujú_, _tömö, инці_, --,
   {{0xe8f8004d,0xdcfc007f,0x2bd9015a,0x3f4700bc}},	//   илі_, _okrę, _مارک_, _tõus_,
   {{0x9f430031,0x315800ca,0x9f58037a,0x236905aa}},	//   dujú_, שיון_, ltrá_, _omaj_,
   {{0x21210899,0x32020094,0x7afb0a39,0x00000000}},	//   _lahh_, ytky_, _ucut, --,
   {{0xd4d900f7,0x60dc44bb,0x80dd0081,0x9f5844bc}},	//   льні_, yarm, _বান্, ntrá_,
   {{0x21210167,0x453544bd,0x60dc00a7,0x6d41009c}},	//   _nahh_, схит, xarm, _òlad,
   {{0xb8950080,0x60dc44be,0x2b9c030b,0x332044bf}},	//   _الاع, varm, síce_, _paix_,
   {{0x60dc44c0,0x21212ce8,0x63b814f3,0xdb0e1f20}},	//   warm, _aahh_, _duvn, _kubá,
   {{0x9f430220,0xdb1c0034,0xa5093a5b,0x6d90007b}},	//   bujú_, _zwró, _бела_, säai,
   {{0x32020146,0x9f430031,0xa06a065c,0x00000000}},	//   rtky_, cujú_, гага_, --,
   {{0x3202025b,0x2121005c,0x03a60859,0x63b802a1}},	//   stky_, _dahh_, _лико, _guvn,
   {{0x394507ac,0xdb1c0094,0xdb020313,0x249844c1}},	//   _lols_, _otrá, rmoë, ürme_,
   {{0xf1bf01f9,0x7bc700c6,0x00000000,0x00000000}},	// [3b20] lván_, _atju, --, --,
   {{0x2369042d,0x61e4039f,0xf1b50285,0xdb1c01f7}},	//   _zmaj_, _ivil, ंदरन, _strà,
   {{0xdb1c44c2,0x61e41a08,0xbc6a001c,0x69cb02ac}},	//   _atrá, _hvil, دمان_, epge,
   {{0x9f430220,0xd1043ec9,0x7bc300ee,0xa3cc0caf}},	//   zujú_, श्रण_, ínua, शीट_,
   {{0x212100ec,0x39453d56,0x98be05aa,0x00000000}},	//   _yahh_, _bols_, _wotč_, --,
   {{0x39452f7c,0x6f160063,0xdb1c0076,0x636f05aa}},	//   _cols_, leyc, _dtrá, _kònè,
   {{0xa3f20f71,0x9f430220,0x3d1400aa,0x39453bcb}},	//   _জন্য_, vujú_, ड़ीं_, _dols_,
   {{0xb8ef0101,0x00000000,0x00000000,0x00000000}},	//   _व्_, --, --, --,
   {{0x9f430206,0xdcfc007f,0x00000000,0x00000000}},	//   tujú_, _skrę, --, --,
   {{0xb9960080,0xa3b92a24,0x394544c3,0xe82002d5}},	//   _الطب, _अंश_, _gols_, _मनपा_,
   {{0x61e444c4,0xdb1c00b6,0x9f430031,0x290c009e}},	//   _avil, _ztrá, rujú_, _ibda_,
   {{0x75e10174,0x04630fe9,0x9f430206,0x00000000}},	//   _ịzer, ятым, sujú_, --,
   {{0xc6960018,0x926b235c,0x9f430031,0xd70700d3}},	//   _اشاع, урна_, pujú_, _ынце_,
   {{0x92d90081,0x602302c6,0x6602063d,0x00000000}},	//   ালে_, jímá, _iqok, --,
   {{0xf48400bf,0xc8cf02d5,0x672201c2,0x79540139}},	//   _باشی, _स्फट, _kaoj, _làwo,
   {{0xe7f00efd,0x3d062235,0x21210449,0x00000000}},	//   _घटना_, स्से_, _wahh_, --,
   {{0x93bc00ae,0x518701b6,0x00000000,0x00000000}},	// [3b30] zvăl, _гуна, --, --,
   {{0x6ca744c5,0x00000000,0x00000000,0x00000000}},	//   бреж, --, --, --,
   {{0xdb1c272c,0xd251037f,0x61e444c6,0xdb0e0669}},	//   _strá, _رنگ_, _zvil, _subá,
   {{0x39453f40,0x33fb0142,0x66020372,0x6bd40076}},	//   _sols_, רהאנ, _oqok, ستمر,
   {{0x394544c7,0xd94544c8,0x6ab800d4,0x22a40113}},	//   _pols_, жели, _šafá, mèké_,
   {{0x680a00a7,0x00000000,0x00000000,0x00000000}},	//   _səda, --, --, --,
   {{0x394533dd,0xf990012b,0xddd600a5,0x66020372}},	//   _vols_, ربه_, czył, _aqok,
   {{0x6d4744c9,0x290c03e5,0x9b581e6d,0x58940037}},	//   _hoja, _ebda_, _лист_, أجهز,
   {{0x6d4744ca,0x28f9002d,0x8579001f,0x9f5e014b}},	//   _koja, _везь_, исот_, îté_,
   {{0x6b8b44cb,0xe5691d3f,0xf1bf0018,0x6a140018}},	//   logg, риод_, tván_, _عبقر,
   {{0x61e4013d,0x6d4744cc,0xe787078b,0x998402a3}},	//   _svil, _moja, _лудо, _علمو,
   {{0x6d4744cd,0x6722023e,0x6b8b057a,0xd2aa1110}},	//   _loja, _gaoj, nogg, икне_,
   {{0x84e544ce,0x05740421,0xf1bf037a,0x66020372}},	//   _долж, _کاند, sván_, _gqok,
   {{0x412a08d1,0x28cf3ec9,0x6d4744cf,0x85a70284}},	//   шого_, _स्मि, _noja, _ујед,
   {{0x75230239,0x06ae0033,0x6b8b06b0,0x00000000}},	//   _ianz, ছুদি, kogg, --,
   {{0x7ae9092f,0x75230193,0x61e402fe,0x69c9083e}},	//   _ndet, _hanz, _tvil, _otee,
   {{0x6d470542,0xee3a2249,0x752344d0,0x92e900ab}},	// [3b40] _boja, шна_, _kanz, _طريق_,
   {{0x90c31cb1,0x3d140034,0x7ae944d1,0x752301c8}},	//   _обье, ड़ें_, _adet, _janz,
   {{0x752344d2,0x69c90517,0x3a2d00bf,0x6d4744d3}},	//   _manz, _atee, _arep_, _doja,
   {{0x752311ce,0xeb970084,0x6b8b057a,0x409b00ca}},	//   _lanz, оих_, gogg, _כביס,
   {{0xada6007e,0x6a160adb,0x3a2d007e,0x7ae944d4}},	//   _мамл, تبار, _crep_, _ddet,
   {{0x7ae944d5,0x6d47031a,0xe7ea0613,0xe91804a1}},	//   _edet, _goja, афик_, сокі_,
   {{0xd83a004b,0xd7f000e3,0x6b8b44d6,0x69c944d7}},	//   рэл_, ركة_, bogg, _etee,
   {{0x752344d8,0xdb1c1cd2,0xfb5600cd,0x00000000}},	//   _aanz, _stræ, _بپرد, --,
   {{0x752344d9,0x3a2d44da,0xd04e00a7,0x7791001c}},	//   _banz, _grep_, rabə, ریها,
   {{0x752344db,0x70b902e8,0x98a62383,0x94aa08f9}},	//   _canz, _आलेल, _дизе, итна_,
   {{0x75233f3d,0x661b0172,0x4cbb00d7,0x00000000}},	//   _danz, awuk, יזיו, --,
   {{0x80dd0033,0xaab10179,0xd04e013c,0x00000000}},	//   _বাধ্, ुँचक, qabə, --,
   {{0xa2bc1bc3,0xe57a00d3,0x2ee00357,0x00000000}},	//   _एलर्, _кзд_, daif_, --,
   {{0x752302e2,0xd5af01ce,0x3d140034,0x3cea02ac}},	//   _ganz, _іс_, ड़ों_, _ndbv_,
   {{0x2099163d,0x4f6b001f,0xab620233,0x09d700a4}},	//   сквы_, ашам_, şüyo, _डब्य,
   {{0x7523068d,0x6d4744dc,0x99920220,0x6d5e00f9}},	//   _zanz, _soja, ždňa_, ehpa,
   {{0x7c2e44dd,0x75230a75,0x3eaf02e2,0xdcbb00d6}},	// [3b50] _arbr, _yanz, ägt_, аще_,
   {{0x80f5055b,0xdd910308,0x442e3f28,0x657a042c}},	//   _эпох, روا_, _krf_, nnth,
   {{0x5b151d62,0x6d470fee,0x69c9019e,0x657a1844}},	//   змет, _voja, _stee, inth,
   {{0x501a004f,0x3a2d44de,0x795d0113,0x442e44df}},	//   _פורו, _prep_, _mèwe, _mrf_,
   {{0x7f3a0327,0x6d47007e,0x6b8b0313,0x7c2e0364}},	//   _הערו, _toja, rogg, _erbr,
   {{0x6b8b44e0,0x6d5e0364,0x6e20016d,0xf771015a}},	//   sogg, chpa, _âmba, کات_,
   {{0x6b8b00e5,0x752344e1,0x00000000,0x00000000}},	//   pogg, _ranz, --, --,
   {{0x752344e2,0x657a44e3,0x3a2d00d1,0x69c9083e}},	//   _sanz, enth, _trep_, _ttee,
   {{0x28cf0e4c,0x442e44e4,0x61e9031a,0x752344e5}},	//   _स्थि, _arf_, šelj, _panz,
   {{0xf770300f,0x442e07ee,0x00000000,0x00000000}},	//   _یان_, _brf_, --, --,
   {{0x752344e6,0xb97a00c1,0xccf200c1,0xe79600d1}},	//   _vanz, _פרעז, עכט_, _کالک,
   {{0x752344e7,0x889a00a1,0x63760087,0x28cf00a3}},	//   _wanz, _הבעי, kšne, _स्ति,
   {{0x752344e8,0xd2520018,0x442e44e9,0xb6ba0266}},	//   _tanz, رنس_, _erf_, _הצני,
   {{0x75230239,0x442e020a,0x6f0f03a8,0x00000000}},	//   _uanz, _frf_, _abcc, --,
   {{0x2f56007e,0x8fa60dde,0x2ee00350,0x00000000}},	//   птас, заве, taif_, --,
   {{0x9f580052,0x26dd0032,0x00000000,0x00000000}},	//   murë_, _jewo_, --, --,
   {{0x2ee000e3,0x26dd0134,0x63a444ea,0x317144eb}},	// [3b60] raif_, _mewo_, _ihin, bizz_,
   {{0x629601c2,0x62840167,0xceb400a7,0xc00644ec}},	//   _iyyo, _ixio, ddət_, _епок,
   {{0xa3de3516,0x61e60572,0x63a444ed,0x00000000}},	//   दीप_, lskl, _khin, --,
   {{0xeb9a0084,0xaefb0139,0x88d80033,0xc6d60033}},	//   щие_, _alùf, _সাইক, _সঞ্চ,
   {{0x63a444ee,0x61e602c3,0x60de0167,0x98be00ae}},	//   _mhin, nskl, _kepm, _notă_,
   {{0xe8941211,0xdb1c0003,0x9f580052,0xddd6007f}},	//   маль, _strä, kurë_, rzyń,
   {{0x55f800c7,0xada341c8,0xa6ca0065,0x7c2e00c4}},	//   _অনেক_, _чарл, _fọlá, _urbr,
   {{0x963417e9,0x442e00e7,0x63a400fe,0x9f580216}},	//   дниц, _rrf_, _nhin, durë_,
   {{0xa3de09d0,0xbb3b00a1,0x80dd0081,0x26dd0167}},	//   दीन_, _פעמי, _বাস্, _dewo_,
   {{0x63a444ef,0x61e60973,0x442e0131,0x26dd0065}},	//   _ahin, dskl, _prf_, _eewo_,
   {{0x63a444f0,0xb4bc1ab1,0x6d5c0113,0x657a44f1}},	//   _bhin, _अली_, _mlra, rnth,
   {{0x63a444f2,0x7ae20051,0xdb1c02c3,0x00000000}},	//   _chin, naot, _uträ, --,
   {{0x63a40694,0xb7e0000c,0x442e01ff,0x46a311fb}},	//   _dhin, _गौतम_, _wrf_, _зацв,
   {{0x63b6061d,0x442e0131,0x6d4a238c,0x647444f3}},	//   _eiyn, _trf_, öfal, _оглу,
   {{0xd5a500cd,0x442e0063,0x3171003d,0x7ae244f4}},	//   _تلوی, _urf_, rizz_, kaot,
   {{0x63a444f5,0x6d5c1144,0xa2de0096,0x7ae20f18}},	//   _ghin, _alra, परण्, jaot,
   {{0x7ae2019c,0xceb400a7,0x00000000,0x00000000}},	// [3b70] daot, ddəs_, --, --,
   {{0x6d5c009c,0x6ca7008f,0xa25b00fc,0x00000000}},	//   _clra, преж, ncôm, --,
   {{0x8c190c5e,0xdb1c44f6,0x00000000,0x00000000}},	//   تيار_, _kurè, --, --,
   {{0x63a40052,0x00000000,0x00000000,0x00000000}},	//   _xhin, --, --, --,
   {{0x539c00a1,0x6f0d44f7,0x00000000,0x00000000}},	//   זיאו, mfac, --, --,
   {{0x6f0d44f8,0x34db1152,0x92d90033,0x26dd0113}},	//   lfac, _मजेद, ালয়_, _sewo_,
   {{0x29c20682,0xdb1c0501,0x28de0251,0xb8e5022d}},	//   _eða_, _strå, _नजरि, _एल_,
   {{0x6f0d02dc,0x803800a1,0x752d01c2,0x6d451e95}},	//   nfac, לנוע_, _ɗazu, ljha,
   {{0x63a444f9,0x629a0034,0x09d70033,0x6abb0079}},	//   _rhin, ętok, _সমকা, _iguf,
   {{0x63a444fa,0xdb1c02cd,0x9f580052,0x00000000}},	//   _shin, _aurè, turë_, --,
   {{0x68e344fb,0x63a444fc,0xceb40092,0x00000000}},	//   mand, _phin, ndər_, --,
   {{0x68e31556,0xe29a44fd,0xdb0a0031,0x468e06c0}},	//   land, жам_, _šnúr, ịtị_,
   {{0xa3b91e9f,0x27e020e4,0xdb1c03a9,0x6f0d44fe}},	//   _अंक_, ćine_, _durè, dfac,
   {{0x63a4342f,0xa3e60557,0x10a63574,0xf65200ca}},	//   _whin, _पिच_, дигн, _בצד_,
   {{0x63a40054,0x660944ff,0x6f0d4500,0x68e34501}},	//   _thin, ltek, ffac, iand,
   {{0x7e7b4502,0x67294503,0xe82000c3,0x63a44504}},	//   _župa, ndej, _मनसा_, _uhin,
   {{0xdd920678,0x80dd00c7,0x66094505,0x68e32fa2}},	// [3b80] نور_, _বার্, ntek, kand,
   {{0x68e34506,0x66094507,0x6abb0512,0x672902c6}},	//   jand, itek, _aguf, hdej,
   {{0x68e34508,0x6f0d0124,0x7e644509,0x7ae200bc}},	//   dand, bfac, szip, taot,
   {{0x6729450a,0xaefb009c,0x25ee33dc,0x610f01f9}},	//   jdej, _clùd, _इटली_, _tőlü,
   {{0x68e3450b,0xdb1c014b,0x6ffe078e,0x00000000}},	//   fand, _juré, _făcî, --,
   {{0x68e3450c,0x6da61bd8,0x7ae2033c,0x660900d6}},	//   gand, _цига, saot, dtek,
   {{0xa3b909c4,0x6609450d,0xd79400e5,0x9f58014b}},	//   _अंग_, etek, никъ, euré_,
   {{0xdca3450e,0x61e93e67,0x1f5b006e,0xf772450f}},	//   _раси, šeli, ַדיא, ضاع_,
   {{0xf8cf022d,0x66093182,0x9f450af0,0x28cf022d}},	//   _स्वय, gtek, élé_, _स्वि,
   {{0x7afd4510,0x7ae00212,0x7bdc0113,0x6f0d014b}},	//   _östr, _hemt, _kwru, zfac,
   {{0x291c4511,0x69c04512,0xdb1c2e00,0x6f0d0178}},	//   meva_, _hume, _auré, yfac,
   {{0x69c04513,0x291c4514,0xdb1c00b3,0x672900b3}},	//   _kume, leva_, _buré, cdej,
   {{0x69c04515,0x394c01d3,0x442c01c8,0xdb1c00fc}},	//   _jume, _kods_, svd_, _curé,
   {{0x69c04516,0x291c4517,0xdb1c025a,0xceb40092}},	//   _mume, neva_, _duré, ydər_,
   {{0x69c04518,0x394c4519,0x00000000,0x00000000}},	//   _lume, _mods_, --, --,
   {{0x7ae0451a,0xaefb0139,0x291c451b,0x69c0451c}},	//   _nemt, _amùr, heva_, _oume,
   {{0x68e3451d,0x69c0451e,0xf1a70095,0x6f0d451f}},	// [3b90] yand, _nume, _орон, rfac,
   {{0x291c20e4,0x6e2d4520,0x61fd4521,0x4fc7090f}},	//   jeva_, rvab, musl, _осма,
   {{0x291c4522,0x66090a00,0x6e2d4523,0x77a50072}},	//   deva_, ztek, svab, lóxe,
   {{0x68e34524,0x69c04525,0x395e4526,0xe7f40096}},	//   wand, _bume, _alts_, ींना_,
   {{0x68e34527,0x395e022b,0xdb1c002b,0x7ae04528}},	//   tand, _blts_, _xuré, _demt,
   {{0x69c04529,0x7c3a037d,0x291c00aa,0xb4e800b7}},	//   _dume, _štre, geva_, यणो_,
   {{0x7ae00bab,0xdb000072,0x61fd452a,0xa7b50291}},	//   _femt, _cimó, husl, нсиј,
   {{0x69c0452b,0x491b000d,0x9f58452c,0x61fd452d}},	//   _fume, _यसको_, turé_, kusl,
   {{0x68e3452e,0x69c0452f,0x67294530,0xe6160ae3}},	//   pand, _gume, rdej, еды_,
   {{0x66094531,0x291c4532,0x7bc80257,0x61fd4533}},	//   rtek, ceva_, _éduc, dusl,
   {{0x66094534,0x9f5800fd,0x69c04535,0xdb1c014b}},	//   stek, suré_, _zume, _suré,
   {{0x68e14536,0x66094537,0xdb1c4538,0xd6d9007f}},	//   _held, ptek, _puré, ykły_,
   {{0x7e7b4539,0x68e1453a,0x63220081,0x61fd00aa}},	//   _župn, _keld, যালয়_, gusl,
   {{0x68e11f63,0x2b5f015e,0xade300aa,0x00000000}},	//   _jeld, _lluc_, गठनन_, --,
   {{0x0396453b,0x68e1453c,0x332901ee,0xd4790142}},	//   _прия, _meld, _faax_, _מאַל,
   {{0x200505fe,0x2d83453d,0x291c00cc,0x61fd028e}},	//   àlia_, _ajje_, zeva_, busl,
   {{0xc7b20105,0x291c0092,0x77a50072,0xe1ff0143}},	// [3ba0] רבן_, yeva_, cóxe, lzón_,
   {{0x2cbc004d,0x7ae0453e,0x8d760037,0x68e1219b}},	//   øvd_, _semt, راءا, _neld,
   {{0x69c0453f,0xdee61602,0x291c4540,0xe1ff167e}},	//   _sume, _пони, veva_, nzón_,
   {{0xb4bc02d5,0xaca40134,0x2d83010a,0xe1ff002b}},	//   _अल्_, _nrụr, _ejje_, izón_,
   {{0x291c4541,0x68e14542,0xdb00167e,0x395e0167}},	//   teva_, _beld, _simó, _plts_,
   {{0xaca40129,0xd9431e9e,0x680a0092,0x68e100e1}},	//   _arụr, лечи, _hədi, _celd,
   {{0xdca3090f,0x291c4543,0x7bce0149,0x7ae04544}},	//   _бари, reva_, _utbu, _temt,
   {{0x69c04545,0x6d4e4546,0x59dd030b,0x68e100aa}},	//   _tume, _hoba, नीहर, _eeld,
   {{0x291c4547,0x68e14548,0xe7e000c3,0x00000000}},	//   peva_, _feld, _गौरा_, --,
   {{0x68e14549,0x6d4e454a,0xdb002bb5,0x61fd00bc}},	//   _geld, _joba, _timó, vusl,
   {{0x6d4e454b,0x23600126,0x2498052f,0x98a400aa}},	//   _moba, _blij_, ærm_, _ओरिए,
   {{0x61fd454c,0x68e1454d,0x5fb40378,0x680a00a7}},	//   tusl, _zeld, ंगफल, _nədi,
   {{0x3f800034,0xe1ff0072,0x28ac0d61,0x7d1e02ac}},	//   dniu_, azón_, टेरि, keps,
   {{0x7d1e08a9,0x6d4e454e,0x3f800034,0x77a50072}},	//   jeps, _noba, eniu_, róxe,
   {{0x7d1e454f,0xa0c40037,0x61fd4550,0x680a00a7}},	//   deps, ايفو, susl, _bədi,
   {{0x5f940317,0x2d870087,0x61fd4551,0xc49b00ca}},	//   гист, čnem_, pusl, _משות,
   {{0x6d4e4552,0x2b9c02c6,0xc0cb00ae,0x00000000}},	// [3bb0] _boba, mích_, _нуне_, --,
   {{0x61ed4553,0x2b9c02c6,0x313514a4,0x00000000}},	//   _ival, lích_, _реор, --,
   {{0x5f0c0789,0xe802030b,0xdea10470,0xe1ff037a}},	//   _डॉक्_, रूमा_, _چیزی, luó_,
   {{0x2b9c000d,0x68e14554,0x7c3a00c4,0xe0d000d1}},	//   ních_, _seld, _štrc, _پزی_,
   {{0xaa584555,0x68e101d3,0xdd910246,0x05b20034}},	//   ницу_, _peld, _نوح_, ीदाब,
   {{0x6d4e4556,0x61ed039f,0x00000000,0x00000000}},	//   _goba, _mval, --, --,
   {{0x68e13200,0x7c84044b,0x013800ca,0xf81300d1}},	//   _veld, _буте, תרות_, استگ,
   {{0x6d4e0067,0x2b9c00b6,0x3dc20027,0x68e132a8}},	//   _zoba, jích_, _yukw_, _weld,
   {{0x27e003ce,0x68e14557,0x6d4e0adf,0x59f820f8}},	//   ćina_, _teld, _yoba, _петя_,
   {{0xdb1c0939,0x236000e7,0xe1ff037a,0x38cb0231}},	//   _strø, _slij_, duó_, _хуан_,
   {{0x61ed4558,0x7e7b0234,0x00000000,0x00000000}},	//   _aval, _župl, --, --,
   {{0x2cb00092,0xe1ff2243,0x795d0113,0x00000000}},	//   ündə_, rzón_, _kèwo, --,
   {{0x2d870181,0x63660072,0x98a5022b,0x2d930062}},	//   čnej_, _lóng, _malč_, koxe_,
   {{0x61ed4559,0x00000000,0x00000000,0x00000000}},	//   _dval, --, --, --,
   {{0xdee64036,0x6d4e455a,0xc0e3455b,0x4909030b}},	//   кови, _roba, роск, _सानो_,
   {{0x2b9c0343,0x93fa040a,0xa2c30c8c,0x680a0092}},	//   cích_, _חלקי, रखण्, _qədi,
   {{0x6d4e455c,0x672b00dd,0x442721c8,0xaec30e05}},	// [3bc0] _poba, _magj, _hsn_, рбул,
   {{0x672b023b,0x3f800138,0x44270063,0x645c13c8}},	//   _lagj, sniu_, _ksn_, ørig,
   {{0x61ed04a3,0x2721250d,0x6faa0831,0x61420032}},	//   _zval, _मसूर_, _овог_, _ẹlé,
   {{0x7d1e455d,0x4427455e,0x00000000,0x00000000}},	//   seps, _msn_, --, --,
   {{0xa96a0424,0x2b9c0146,0x6d4e323e,0x298a0a52}},	//   мида_, níci_, _toba, мско_,
   {{0x2b9c00b6,0x44270094,0x38c8015a,0x672b0381}},	//   zích_, _osn_, راتی_, _aagj,
   {{0x8c430235,0xebe3455f,0x2d9800e7,0x317b00a1}},	//   _кере, _восп, _ikre_, ורסמ,
   {{0x6f044560,0x59dd0b89,0x00000000,0x00000000}},	//   ngic, _नौकर, --, --,
   {{0xdb1c4561,0x692600c9,0x672b01c0,0x8f9b0327}},	//   _jurí, _имаа, _dagj, ויקי,
   {{0x6b820344,0x201a4562,0x73d80290,0x2b9c00d4}},	//   lnog, _oppi_, ндор_, díci_,
   {{0x44274563,0x2b9c1054,0x00000000,0x00000000}},	//   _csn_, tích_, --, --,
   {{0xe1ff0487,0x25600139,0x187700ca,0x6e2402a4}},	//   tuó_, _dòla_, _בעבר_, kwib,
   {{0x2b9c0037,0x228700d3,0x201a00bc,0xddd60034}},	//   rích_, тунг, _appi_, rzyś,
   {{0x6600005a,0x3cfe1f77,0x28c6102d,0x6b8200f0}},	//   mumk, _लागे_, रुचि, hnog,
   {{0x4fc44564,0xa18401b3,0xdb1c3062,0x6faf0557}},	//   иста, рыял, _aurí, ंगलू,
   {{0x2d9800f9,0x6f040036,0x636600e1,0x672b008c}},	//   _akre_, ggic, _cónd, _xagj,
   {{0x63660890,0x6b82005f,0x61ed4565,0x6600005c}},	// [3bd0] _dónd, dnog, _uval, numk,
   {{0x7c3a0542,0x63660314,0x80dd0081,0xdb1c26e0}},	//   _štra, _póng, _বাক্, _durí,
   {{0x6b8202ad,0xdb1c00b3,0x98a505aa,0x7f4f00fc}},	//   fnog, _eurí, _palč_, _tocq,
   {{0x4ea701b3,0xfe700018,0x66004566,0x636605b4}},	//   _арга, حدہ_, kumk, _gónd,
   {{0x2ee902e7,0xad9b0072,0x98a505aa,0x00000000}},	//   maaf_, _opúx, _valč_, --,
   {{0x776208a8,0x02a30174,0x2ee92b2d,0xdb1c00ae}},	//   _alox, _arịọ, laaf_, _curâ,
   {{0x87b900ae,0x672b0216,0x6b820128,0x00000000}},	//   нуит_, _pagj, bnog, --,
   {{0x6c310103,0x2ee94567,0x5629022f,0x66000350}},	//   _پہچا, naaf_, ежим_, fumk,
   {{0xdb1c08a8,0x66004568,0x225902b6,0xda162c31}},	//   _xurí, gumk, jysk_, _مسلک,
   {{0x77624569,0x2ee9456a,0x2560009c,0x2259007f}},	//   _elox, haaf_, _pòla_, dysk_,
   {{0x672b0103,0x00000000,0x00000000,0x00000000}},	//   _tagj, --, --, --,
   {{0x67200fa3,0xe611001c,0x201e0233,0x63760234}},	//   cemj, _هشت_, çtim_, ršno,
   {{0x06b10081,0x36340281,0x00000000,0x00000000}},	//   _ট্রি, _پرنس, --, --,
   {{0x6e202226,0x44270350,0xa5090859,0x3f99047e}},	//   _âmbi, _tsn_, _чека_, _aksu_,
   {{0xb4df1fbb,0x4427456b,0x63660072,0x2b9c00b6}},	//   तरी_, _usn_, _pónd, síci_,
   {{0x80d42a06,0x6e3b09ac,0xdb1c00b3,0x26cd456c}},	//   _ब्रे, _šuba, _purí, nceo_,
   {{0x2246074e,0x6b820106,0x8fa336f2,0x0d86456d}},	// [3be0] _çok_, vnog, сате, глан,
   {{0x6e24456e,0x8c46456f,0x636600ee,0xab5d02a1}},	//   rwib, лезе, _dóne, _jiżf,
   {{0x201a003e,0xadf005e4,0x44250150,0x6b820357}},	//   _uppi_, _चिकन_, nwl_, tnog,
   {{0xe5131344,0xdb1c4570,0xb4df058f,0x67d100e8}},	//   त्ति_, _turí, तरु_, _mājd,
   {{0x32020181,0xf1bf2e16,0xb17b00f3,0x00000000}},	//   nuky_, lvár_, rsåv, --,
   {{0x75210018,0x6b820268,0x63664571,0x082a007b}},	//   jelz, snog, _jónb, еции_,
   {{0x8d631e58,0x6d5e0294,0xd7fa00d3,0x27e0007e}},	//   _увре, mkpa, хул_, ćino_,
   {{0x998d00d3,0x1754008f,0x660001d3,0x6fb4009f}},	//   _preţ_, рвия, tumk, ंगिं,
   {{0x28cf0455,0xe4e6036c,0x67204572,0x9f58037a}},	//   _स्कि, лінн, remj, ltró_,
   {{0x752104aa,0xf1bf4573,0x7c22007f,0x80d405cd}},	//   gelz, kvár_, łoru, _ब्ले,
   {{0x9f58058a,0x0d9700a1,0xa3de02d5,0x23794574}},	//   ntró_, רכים_, दीं_, tisj_,
   {{0x78a820e4,0x3d140c9c,0x43954575,0xdb1c00ee}},	//   _izdv, न्ते_, рамс, _jurà,
   {{0xa77b00c1,0x27ee0036,0x9f5800ee,0xd7930076}},	//   _אראפ, lsfn_, durà_, _النخ,
   {{0x04750103,0x313516e6,0xa4d4018a,0x6d5e0381}},	//   ائیگ, шегр, _токі, jkpa,
   {{0xe3b0037f,0x657a4576,0x65680a1b,0xdb1c2159}},	//   تری_, mith, mhdh, _strý,
   {{0x657a4577,0xaf370504,0x6d5e0629,0xdc0a0033}},	//   lith, درست, ekpa, রবাস_,
   {{0x63ad4578,0xccfb0831,0x657a2e6a,0x1df80ae3}},	// [3bf0] _ihan, еће_, oith, леты_,
   {{0x637602dd,0x657a2e39,0x81e80081,0x49090336}},	//   jšnj, nith, মূহ_, _साधो_,
   {{0x2ca70bab,0x63ad4579,0xab5d003d,0x645a1ba7}},	//   ånd_, _khan, _jiżg, nyti,
   {{0x20030918,0xbe050068,0x657a457a,0x799a12ff}},	//   muji_, _پوسٹ, hith, _aktw,
   {{0x63ad457b,0x657a457c,0xd8380154,0x61ef457d}},	//   _mhan, kith, _arč_, nscl,
   {{0x657a00dd,0x63ad457e,0x645a457f,0xdb1c00b3}},	//   jith, _lhan, kyti, _eurà,
   {{0x5ba70636,0x63ad4580,0x657a4581,0x3158040a}},	//   _браз, _ohan, dith, ריון_,
   {{0x63ad0028,0x7bd502a7,0x61fd4582,0x657a00f0}},	//   _nhan, _itzu, krsl, eith,
   {{0x9f4c4583,0xa3e70455,0x7bc74584,0x7aeb4585}},	//   édé_, मीन_, _huju, magt,
   {{0x7bc74586,0xb4df33d9,0x63ad023f,0x7aeb1b06}},	//   _kuju, तरे_, _ahan, lagt,
   {{0x64a54587,0x7bc70496,0x63ad4588,0x257b0139}},	//   рана, _juju, _bhan, _aálè_,
   {{0x63ad4589,0x7bc7458a,0x7aeb458b,0x257b0065}},	//   _chan, _muju, nagt, _bálè_,
   {{0x63ad458c,0x657a019f,0x55e500ae,0x7bc7458d}},	//   _dhan, bith, _толб, _luju,
   {{0x2907458e,0x657a458f,0x63ad0150,0x32020146}},	//   ngna_, cith, _ehan, ruky_,
   {{0x6b9b0a15,0x7bc70533,0xafe64590,0x7aeb0009}},	//   _okug, _nuju, робл, kagt,
   {{0x63ad4591,0x7aeb4592,0x6b9b4593,0xab5d0078}},	//   _ghan, jagt, _nkug, _jiżd,

   {{0x539b00a1,0x7aeb0185,0x7bd500ee,0xf1bf01f9}},	// [3c00] _ביקו, dagt, _atzu, rvár_,
   {{0x63ad4594,0x7bc74595,0x6b890113,0x6b9b01b2}},	//   _zhan, _buju, _ajeg, _akug,
   {{0x0c262dd1,0xf0aa1ad1,0x80dd0033,0x6d5e4596}},	//   рмен, _школ_, _বাচ্, rkpa,
   {{0x657a0060,0x9f580428,0x6d5e00bc,0x61e44597}},	//   zith, rtró_, skpa, _kwil,
   {{0x9f581863,0x657a0201,0x6b89023b,0x69d900f9}},	//   stró_, yith, _djeg, gpwe,
   {{0x61e40010,0xdb1c3884,0xb4df023a,0x28f700c2}},	//   _mwil, _durá, तरो_, аешь_,
   {{0x68ea4598,0x657a063d,0x7bc74599,0x26c2138c}},	//   rafd, vith, _guju, žkom_,
   {{0x7aeb008a,0x2ca7459a,0x68ea10ad,0xb8fd0034}},	//   cagt, ünde_, safd, _थ्_,
   {{0x63ad02ad,0x657a0076,0x765b0124,0x200300b6}},	//   _rhan, tith, gyuy, zuji_,
   {{0xa90600bf,0x7bc011b9,0x998d00c4,0x63bf00a7}},	//   _خبرن, _himu, _treš_, _siqn,
   {{0x657a0080,0x7bc0459b,0x4438459c,0x61e403e3}},	//   rith, _kimu, ír_, _awil,
   {{0x68e8459d,0x657a459e,0x645a459f,0x61e40154}},	//   _hedd, sith, ryti, _bwil,
   {{0x7bc045a0,0x645a45a1,0x27e90106,0x02a30174}},	//   _mimu, syti, ćane_, _trọọ,
   {{0x63ad0180,0x7e6d0087,0x61e401dc,0x61ef0381}},	//   _whan, vzap, _dwil, rscl,
   {{0x68e8345d,0x63ad45a2,0x9692001c,0xdb1e00b6}},	//   _medd, _than, _دیکش, _švýc,
   {{0x7bc745a3,0x63ad45a4,0x7bc00193,0x68e845a5}},	//   _ruju, _uhan, _nimu, _ledd,
   {{0x7a1a00d9,0xba010081,0x68e80150,0x61e400f0}},	// [3c10] nātā, _এন্ড_, _oedd, _gwil,
   {{0x6b9b45a6,0x68e80517,0x7bc7061d,0x7aeb0313}},	//   _skug, _nedd, _puju, wagt,
   {{0x63660068,0x6b890344,0x7bc00435,0x5c07008f}},	//   _hóna, _pjeg, _bimu, ряза,
   {{0x41c400cd,0x9f58028d,0x7bc03590,0x6d4a02c3}},	//   _دقیق, strò_, _cimu, öfar,
   {{0x1959013f,0x7bc745a7,0x7bc03f66,0xab5d45a8}},	//   лады_, _wuju, _dimu, _niże,
   {{0x7bc74263,0x98ac03a3,0x63660143,0x7a1a01d3}},	//   _tuju, _aldı_, _móna, dātā,
   {{0x7aeb1331,0x680a0092,0x68e80150,0x63663274}},	//   pagt, _sədr, _dedd, _lóna,
   {{0xbb850080,0x9b941bd1,0x6b9b26f6,0xab5d02a1}},	//   _الري, _дисц, _ukug, _biże,
   {{0x68e80150,0x290c01c2,0x16390037,0xa762008f}},	//   _fedd, _fcda_, اسبة_, якъд,
   {{0x6d5502f1,0x7bc045a9,0xe1ff45aa,0x3a2d0167}},	//   _joza, _zimu, dró_, _isep_,
   {{0xd05c0092,0xaefb0139,0x69c90167,0x61e403a8}},	//   barə, _alùm, _huee, _swil,
   {{0x69c145ab,0x6d410088,0x60c545ac,0xd05c0092}},	//   _hile, _ólaf, _aghm, carə,
   {{0x69c145ad,0xe1ff0fa6,0x636600e3,0x7ae945ae}},	//   _kile, gró_, _cóna, _meet,
   {{0x6d5500d9,0x7ae945af,0x863600c1,0xd00a0307}},	//   _noza, _leet, _לאנג_, леге_,
   {{0x05740241,0x201e45b0,0xa06745b1,0xab5d009e}},	//   _باند, ïti_, бара_, _miżb,
   {{0x69c145b2,0xa3e70179,0x637645b3,0xe1ff45b4}},	//   _lile, मीण_, kšni, bró_,
   {{0xee3a45b5,0x69c10091,0x6b99008a,0x7bc045b6}},	// [3c20] ына_, _oile, dowg, _rimu,
   {{0x7bc045b7,0xd05c0092,0xa3de1115,0xab5d0090}},	//   _simu, zarə, दीक_, _niżb,
   {{0x68e845b8,0xd5c80019,0x3a2d0194,0xd05c0092}},	//   _redd, _nền_, _asep_, yarə,
   {{0x387a01d4,0x69c145b9,0x68e845ba,0x8fc50100}},	//   _üzrə_, _aile, _sedd, _گزین,
   {{0x7ae92caa,0x6d550072,0x7bc00350,0x00000000}},	//   _deet, _foza, _vimu, --,
   {{0xdd9211a2,0x6d5545bb,0x69c145bc,0xe6e0074c}},	//   _روز_, _goza, _cile, नर्ज,
   {{0x7bc00655,0x69c1091a,0x2c1c00c3,0x7ae9084e}},	//   _timu, _dile, _नहिं_, _feet,
   {{0x69c10049,0x2d9a45bd,0x7ae945be,0x26df45bf}},	//   _eile, lope_, _geet, gbuo_,
   {{0x6d5506b0,0x09e30077,0xb4c00285,0x00000000}},	//   _yoza, _нотн, ंख्_, --,
   {{0x8e5700c1,0xd05c00a7,0xdb1c0233,0x3d0b0096}},	//   צייג_, sarə, _burç, ालये_,
   {{0xe60f12eb,0x680a00a7,0x6eff0032,0x7ae9083e}},	//   وشی_, _tədq, _jàbà, _yeet,
   {{0x69c145c0,0xe1ff45c1,0x2d9a29ea,0xab5d0090}},	//   _zile, tró_, hope_, _tiże,
   {{0xc7970068,0x363600e3,0x86c30037,0x2d9a45c2}},	//   _اپنا_, _دراس, _عيون, kope_,
   {{0x69c145c3,0xe1ff45c4,0x7c2e02ac,0x00000000}},	//   _xile, rró_, _osbr, --,
   {{0x6d5545c5,0x67d101d3,0x6b99008c,0xe3c9020b}},	//   _roza, _kāja, yowg, _hằn_,
   {{0x442e45c6,0x9f0501c3,0x2e4b00e5,0x00000000}},	//   _isf_, تورو, лязо_, --,
   {{0x67d10029,0x7ae945c7,0xa2a045c8,0x31350a7c}},	// [3c30] _māja, _reet, _गुप्, _депр,
   {{0x7ae945c9,0x443c45ca,0x6eff0139,0x2d9a0a4b}},	//   _seet, _krv_, _bàbà, gope_,
   {{0x6d5500e9,0x69c145cb,0x7ae945cc,0x442e45cd}},	//   _voza, _rile, _peet, _jsf_,
   {{0x442e45ce,0xcf27001c,0x443c0231,0x80b500a4}},	//   _msf_, _اردي, _mrv_, ंधीं,
   {{0x6d550022,0x7c2e45cf,0x7ae900aa,0xe1ff0034}},	//   _toza, _esbr, _veet, rzów_,
   {{0x7ae945d0,0xe1ff0034,0x98be0154,0x6eff0032}},	//   _weet, szów_, _entč_, _fàbà,
   {{0x02fb303f,0x69c145d1,0xa2a0052c,0x7ae945d2}},	//   ्लाह_, _vile, _गुन्, _teet,
   {{0xf7710192,0x3f8902e0,0x23cf06ed,0x09d80081}},	//   بات_, nnau_, _संबद, _সিরা,
   {{0x14da13b4,0x442e02e5,0x645c1484,0x69c145d3}},	//   _म्हण, _asf_, ørin, _tile,
   {{0x2bb91860,0xe5790237,0x69c145d4,0x442e0314}},	//   ेदवा, рзо_, _uile, _bsf_,
   {{0x443c0085,0xa34a1510,0x2369020a,0xdce50206}},	//   _crv_, азна_, _blaj_, kohľ,
   {{0x2bd00cce,0x80a30096,0x443c0141,0xbddb0513}},	//   _तूफा, _गरजे, _drv_, _krèd,
   {{0x3dd9023e,0xe7960018,0xe2970b2f,0x00000000}},	//   _ntsw_, _بالک, жая_, --,
   {{0x6f1d02e2,0xfd520174,0x200c0428,0x3f8900f0}},	//   _absc, _dajụ, àdio_, enau_,
   {{0x3f8900f0,0x3ea245d5,0x3d100285,0x2481042c}},	//   fnau_, _sykt_, _ढाबे_, _ähm_,
   {{0x3f89030a,0x2087004d,0xa3de00aa,0x00000000}},	//   gnau_, ійти_, दीओ_, --,
   {{0x27e003ce,0xbea345d6,0xee37376f,0x2d9a45d7}},	// [3c40] ćini_, датк, онт_, tope_,
   {{0x6f1d45d8,0x443c0063,0x4c8600e5,0x63a645d9}},	//   _ebsc, _yrv_, олзв, llkn,
   {{0x7ac643f7,0x2d9a45da,0x5aca083c,0x00000000}},	//   осле, rope_, алем_, --,
   {{0xeb9a261d,0x8cda0789,0x3e70025a,0xd1160c22}},	//   шие_, _प्रो, _côté_, द्रण_,
   {{0x094a3715,0xee372ec2,0xbddb0472,0x7f460415}},	//   ички_, _дня_, _crèd, _inkq,
   {{0x7d000065,0x394505bd,0x00000000,0x00000000}},	//   _dárà, _cnls_, --, --,
   {{0xdca30a99,0xd90d001c,0x984a3ac9,0xb22701cd}},	//   _жари, ایم_, ряла_, _kvæð,
   {{0x3b071121,0x7bde00c2,0x290000ae,0xeb9745db}},	//   _месо_, mppu, şia_, _дис_,
   {{0x27e9005f,0x5986001f,0x7bde007b,0x758a007b}},	//   ćana_, _длаб, lppu, исов_,
   {{0x29180013,0x02e3030b,0xd6e20081,0x7ae245dc}},	//   _ùra_, पर्न, _যাওয, lbot,
   {{0x3f8902ad,0x236945dd,0x32020220,0x291e01ee}},	//   ynau_, _plaj_, erky_, _ibta_,
   {{0x926b1caf,0x443c0141,0x29d00139,0x442e302e}},	//   арга_, _vrv_, _kàa_, _vsf_,
   {{0x81d30081,0x236900c4,0x442e0350,0x29d00032}},	//   হীন_, _vlaj_, _wsf_, _jàa_,
   {{0x443c0141,0x386f03e0,0x61f600c6,0xab5d009e}},	//   _trv_, _ömrü_, _dvyl, _miża,
   {{0xd5c80028,0x75280181,0xd24e0260,0x443c015e}},	//   _mềm_, medz, نچی_, _urv_,
   {{0xa8570327,0xd5b801d3,0x75283751,0xa11500d1}},	//   חילה_, lmā_, ledz, _کودت,
   {{0x3f8900f0,0x636600d4,0xd83805aa,0x00000000}},	// [3c50] rnau_, _zóno, _syčl_, --,
   {{0x8c670037,0x752845de,0x7e7b0218,0x7ae202ac}},	//   يطان, nedz, _žups, ebot,
   {{0x25690220,0x9ad80174,0x9c130174,0xa3de0096}},	//   _júla_, _ịrụg, pọmk, दीच_,
   {{0x7ae245df,0xa2a0049d,0x29d00032,0xab5d00bd}},	//   gbot, _गुड्, _bàa_, _biża,
   {{0xd9452a84,0x00000000,0x00000000,0x00000000}},	//   зели, --, --, --,
   {{0xab5d0078,0x6e2d45e0,0x88bc02c6,0xae5a0327}},	//   _diża, mwab, _oběd, _הכשר,
   {{0x77a50933,0x6d4745e1,0x7ae20451,0x6e3b00e7}},	//   lóxi, _inja, bbot, _šubh,
   {{0xdb1c45e2,0x6f0d45e3,0x75e00134,0xe1ff002b}},	//   _strö, ngac, _ịzac, nzós_,
   {{0x70a819af,0x6d470095,0x7afb04ff,0x77a5266c}},	//   _गर्ल, _knja, _idut, nóxi,
   {{0x7ac400f3,0xaefb01ec,0x69db0062,0xa5090291}},	//   _істе, _dlùi, _itue, љена_,
   {{0x04453e04,0x03a6276c,0x6e2d45e4,0x3a3f0117}},	//   ченн, зино, hwab, _hrup_,
   {{0x6e2d45e5,0xb4ab0980,0x25e80096,0xd6b601f3}},	//   kwab, _खरी_, चीही_, _کشمک,
   {{0xe7c4009f,0x6b8b07ac,0xaefb01ec,0x6d470415}},	//   _लूटप, ingg, _glùi, _onja,
   {{0xb2270088,0xe20b003e,0x63660094,0x763a006e}},	//   _svæð, _stóð_, _tóno, _לענג,
   {{0xa0672972,0x64a2198a,0x67d101d3,0x660945e6}},	//   пара_, _паша, _mājo, luek,
   {{0x6d4745e7,0xdfcf00e3,0x10a3004d,0x7afb19a2}},	//   _anja, طيك_, хисн, _ndut,
   {{0x77a503be,0x26c21d63,0x66090062,0x20030117}},	// [3c60] góxi, žkov_, nuek, arji_,
   {{0x2d810193,0x7afb1ee5,0x672945e8,0x6b8b00f9}},	//   gihe_, _adut, heej, engg,
   {{0xa0a6002d,0xdd8f00e3,0x69db3782,0xdb0901ec}},	//   _ханд, دول_, _atue, _bheà,
   {{0x7f4a1574,0x6d4745e9,0xe3c90019,0x8025015a}},	//   _الحق_, _enja, _nằm_, _کریم,
   {{0x7ae245ea,0x201845eb,0xf8dd000d,0x200a0772}},	//   rbot, ltri_, नुभय, lubi_,
   {{0xdb1545ec,0x6d470559,0x6b8b00f9,0x22400113}},	//   _buzó, _gnja, angg, _mrik_,
   {{0x201845ed,0xd83a01b6,0x200a45ee,0x75281a61}},	//   ntri_, сэл_, nubi_, vedz,
   {{0x95d80084,0x6a860e05,0x67290134,0xe3c90023}},	//   одит_, _елба, geej, _cằm_,
   {{0x3a3f45ef,0x7bce10e3,0x201845f0,0x79ca0781}},	//   _grup_, _hubu, htri_, _طواف_,
   {{0x7bce1a8b,0x6b8245f1,0x201845f2,0x200a45f3}},	//   _kubu, liog, ktri_, kubi_,
   {{0x75280029,0x63660088,0xd5b80029,0x439545f4}},	//   redz, _tónl, rmā_, данс,
   {{0x98ac0029,0xd5b800d9,0x224045f5,0x7bce21e9}},	//   _gadā_, smā_, _brik_, _mubu,
   {{0x27e004eb,0x7bce45f6,0xdb1c0af0,0xd24400d3}},	//   ćinu_, _lubu, _burú, нэри,
   {{0xdb090037,0x35b30c10,0x25820032,0x22400537}},	//   _mheá, _збір, _délè_, _drik_,
   {{0x7bce34bf,0x200a07c0,0x443a45f7,0x3a240167}},	//   _nubu, gubi_, _ép_, _lpmp_,
   {{0x26c20146,0xee3f00b6,0x77a545f8,0x6b820a4b}},	//   žkou_, _prý_, tóxi, jiog,
   {{0x6f0d2adf,0x6d47005c,0x22400063,0x7bdc01d3}},	// [3c70] rgac, _pnja, _grik_, _atru,
   {{0xdb1c0143,0x77a5065b,0x853c00c6,0x6e2d0512}},	//   _gurú, róxi, klėm, rwab,
   {{0x69db038c,0x200a028d,0x7bce45f9,0x5b15235c}},	//   _stue, cubi_, _cubu, дмет,
   {{0x23cf000c,0x7bce45fa,0xbddb00fd,0xdb090503}},	//   _संसद, _dubu, _crèc, _bheá,
   {{0xcf5600a1,0x3a3f0092,0xe3c900fe,0xdb090503}},	//   _חברת_, _qrup_, _rằm_, _cheá,
   {{0x98a50a54,0x23c40139,0xa3b40be5,0xdb090503}},	//   миле, _kèjì_, _जीन_, _dheá,
   {{0xb4ab009d,0x7bce45fb,0x27e9042d,0x999f0103}},	//   _खरे_, _gubu, ćano_, éről_,
   {{0xeafb0688,0x3a3f45fc,0x6b8245fd,0xbddb2322}},	//   _درست_, _trup_, ciog, _grèc,
   {{0x61fb005f,0x7bd200d9,0x672945fe,0x98ad00a7}},	//   šulj, ējuš, reej, ınıb_,
   {{0xdce70117,0x7bce05bd,0x66090083,0x00000000}},	//   _oljč, _yubu, ruek, --,
   {{0x7983063d,0xe3c900fe,0x6fb00285,0x66090062}},	//   minw, _tằm_, ंतमू, suek,
   {{0x798345ff,0x92ec0033,0x22404600,0x889a00ca}},	//   linw, কল্প_, _prik_, _ובעי,
   {{0x0caa000c,0xf7700dd0,0x2ef20063,0x200a0174}},	//   _कर्म, _حال_, vayf_, wubi_,
   {{0xd5bb059b,0x201828e3,0x200a4601,0x6b82203f}},	//   _усе_, ttri_, tubi_, ziog,
   {{0x7f5a0396,0x8fa64602,0xa0a305cb,0xa06a4603}},	//   ојат_, даве, вард, цава_,
   {{0x7bce4604,0x22404605,0x200a4606,0x20184607}},	//   _rubu, _trik_, rubi_, rtri_,
   {{0x63a44608,0x7bce4609,0x1da90251,0x8fa32c13}},	// [3c80] _ikin, _subu, कतंत, тате,
   {{0xdd8f071c,0xab5d0090,0x7bce460a,0xe0d700ae}},	//   لوق_, _biżo, _pubu, _овь_,
   {{0x3a240063,0x63a40062,0xdb090076,0xfe710103}},	//   _spmp_, _kkin, _sheá, ندے_,
   {{0x61e9002d,0xab5d009e,0x20050a7f,0xdaaa460b}},	//   ţele, _diżo, álie_, овед_,
   {{0x63a40a4b,0x7bce460c,0xbbc500d1,0x7983246c}},	//   _mkin, _wubu, رآمو, finw,
   {{0x7bce460d,0x6b82013f,0x7c3a460e,0x63a40124}},	//   _tubu, siog, _štru, _lkin,
   {{0xa3ae0336,0x7bdc460f,0xa2a00f78,0x7bce0270}},	//   कता_, _utru, _गुस्, _uubu,
   {{0x9634064f,0xc6f840e1,0x6d5c226a,0x96ea084c}},	//   ениц, чних_, _hora, цька_,
   {{0x7e644610,0x00000000,0x00000000,0x00000000}},	//   nyip, --, --, --,
   {{0x63a44611,0xa3cf1161,0xb4e8110f,0x6d5c440d}},	//   _akin, _वंश_, बरे_, _jora,
   {{0x7bda025a,0xb4de00a5,0x69c8008c,0xd87607e8}},	//   _étud, _तभी_, _iide, _غائب,
   {{0x63b602ad,0x6d5c4612,0x69c60976,0xddcd00ae}},	//   _chyn, _lora, ादकी, nzaţ,
   {{0x69c84613,0x63a40124,0x67220af0,0x6d5c424c}},	//   _kide, _dkin, _iboj, _oora,
   {{0x63a44614,0x6d5c4615,0x69c84616,0x7642026e}},	//   _ekin, _nora, _jide, _iroy,
   {{0x69c84617,0x3ead00e7,0xb9120134,0x00000000}},	//   _mide, _šet_, wanụ_, --,
   {{0x69c84618,0x75384619,0xab5d003d,0x6d5c461a}},	//   _lide, _havz, _riżo, _aora,
   {{0x6d5c461b,0x69c80a6c,0x443e017a,0xbddb009c}},	// [3c90] _bora, _oide, lvt_, _brèa,
   {{0x69c8461c,0xbddb009c,0xb9120134,0x75380090}},	//   _nide, _crèa, ranụ_, _javz,
   {{0x7538461d,0x2ca7052f,0x3cde034c,0x61ed0350}},	//   _mavz, ænd_, गड़े_, _hwal,
   {{0x6d5c0037,0x69c8461e,0x2b490a06,0x443e00f3}},	//   _eora, _aide, ñac_, ivt_,
   {{0x6d5c461f,0x69c803f3,0xb4bb00b7,0xaefb01b5}},	//   _fora, _bide, _अण्_, _dlùt,
   {{0x6d5c4620,0x61ed21de,0x75381b30,0x67220032}},	//   _gora, _mwal, _navz, _aboj,
   {{0x69c82e67,0x76424621,0x61ed0502,0x3158006e}},	//   _dide, _aroy, _lwal, ויגן_,
   {{0x69c84622,0x76424623,0x61ed4624,0x23b20103}},	//   _eide, _broy, _owal, kája_,
   {{0x69c84625,0x63b602ad,0x76424626,0x61ed0129}},	//   _fide, _rhyn, _croy, _nwal,
   {{0x69c84627,0x6d5c4628,0xe57600d3,0x63660328}},	//   _gide, _xora, езь_, _ióni,
   {{0x809f07e2,0x61ed4629,0x98141a13,0xa2c20be4}},	//   _खुले, _awal, _لبنا, रेन्,
   {{0x7bc9462a,0xe29a462b,0x61ed0517,0x67220065}},	//   _jieu, зам_, _bwal, _gboj,
   {{0x7bc9025a,0x7642462c,0x998d0141,0xc7b21777}},	//   _mieu, _groy, _mrež_, _עבד_,
   {{0x7bc9462d,0x61ed462e,0x6aa90036,0x661b462f}},	//   _lieu, _dwal, _myef, mtuk,
   {{0x7f5d0fb6,0x61ed083e,0xdfd200e3,0x1fb60c2b}},	//   _bosq, _ewal, اير_, есар,
   {{0x7bc926f1,0xe29a0020,0x6d5c4630,0x7538141f}},	//   _nieu, _най_, _sora, _zavz,
   {{0x6d5c4631,0x661b113a,0xdd92012b,0x61ed4632}},	// [3ca0] _pora, ntuk, هور_, _gwal,
   {{0xa3b405d4,0x6d5c0694,0x661b4633,0xd29b00a1}},	//   _जीत_, _qora, ituk, _משפט,
   {{0x6aba007d,0x6d5c4634,0xaacb0c13,0x261900de}},	//   ेश्र, _vora, िशंक, hèo_,
   {{0x69c84635,0xeb974636,0x673b00a5,0x79810150}},	//   _side, них_, jduj, _amlw,
   {{0x6d5c4637,0x69c84638,0x7bc94639,0x63660328}},	//   _tora, _pide, _dieu, _cóni,
   {{0x61fb3916,0x4427463a,0x443e0b6a,0x26190113}},	//   áuli, _opn_, yvt_, dèo_,
   {{0x7dc9013f,0xc7c618e4,0x8b96463b,0x213a009c}},	//   _užsa, нсии, _зрач, _maph_,
   {{0xfaa6463c,0x7642463d,0x35e6463e,0x69c8463f}},	//   _забо, _proy, нцов, _wide,
   {{0xf6521e56,0x69c80d3e,0xadc30019,0x64434640}},	//   ائع_, _tide, _hoạc, _arni,
   {{0x44270167,0xdcfc00c4,0x61ed0027,0x78a80f5a}},	//   _bpn_, _omrč, _rwal, _tydv,
   {{0x644304a3,0xddcd1912,0x661b01e9,0x6ea2277c}},	//   _crni, izaš, atuk, _कुसु,
   {{0x67224641,0x4427005c,0x64432bcb,0x395e01e9}},	//   _uboj, _dpn_, _drni, _hots_,
   {{0x44274642,0x2a66022e,0x6366002b,0xbddb020d}},	//   _epn_, nyob_, _xóni, _arèn,
   {{0x44270a39,0x6b820294,0x644305db,0x2572014b}},	//   _fpn_, ọgha, _frni, _bâle_,
   {{0xd3a73277,0x395e025a,0xb9100134,0xbddb01dc}},	//   _прип, _mots_, _selụ_, _crèn,
   {{0x61ed4643,0xbddb0113,0x395e4644,0xa2aa0096}},	//   _twal, _drèn, _lots_, _घरच्,
   {{0x7bc94645,0x2a66023e,0xab5d00bd,0x4427020a}},	// [3cb0] _rieu, jyob_, _fiżj, _zpn_,
   {{0x7bc94646,0x673b0a39,0x63b300c6,0x00000000}},	//   _sieu, zduj, šenė, --,
   {{0x661b0a00,0x6366037a,0x7bc9020d,0x7f5d4647}},	//   ztuk, _sóni, _pieu, _tosq,
   {{0xb5fd00d2,0x00000000,0x00000000,0x00000000}},	//   dyšn, --, --, --,
   {{0x239600d9,0x7bc90257,0x72ec006e,0xe9d80138}},	//   nāja_, _vieu, פֿאַ, екі_,
   {{0x395e43a2,0x2f3f0174,0x67394648,0x333b02a1}},	//   _cots_, _ọghi_, _sawj, _laqx_,
   {{0xdd940450,0x27950e05,0x01380327,0x7bc90023}},	//   _сары, кшир, גרות_, _tieu,
   {{0x661b4649,0x636641b7,0x6ed502d5,0x7d070032}},	//   ttuk, _tóni, युचु, _férà,
   {{0x2b4d464a,0x645c464b,0xd5c800fe,0x1a5b0037}},	//   _inec_, ärin, _lều_, _عشرة_,
   {{0x661b464c,0x893400bf,0x4427464d,0x395e015e}},	//   rtuk, _معما, _ppn_, _gots_,
   {{0x661b464e,0x3d190592,0x213a464f,0xa2e60450}},	//   stuk, _पाने_, _raph_, конд,
   {{0x64430087,0x395e0154,0x661b4650,0x00000000}},	//   _vrni, _zots_, ptuk, --,
   {{0xdcfc0147,0xa2f200c3,0xd2f21115,0xbddb0113}},	//   _smrč, _अजीज_, _अजीब_, _srèn,
   {{0x44272ba1,0x64434651,0x3ceb0034,0xb9dd0134}},	//   _tpn_, _trni, टरों_, _ụọ_,
   {{0x10a64652,0x64434653,0x44274654,0xab5d009e}},	//   тивн, _urni, _upn_, _viżj,
   {{0xd00f1dec,0x20050a0d,0x20044655,0x032600d3}},	//   تلف_, ália_, čmi_, _рдин,
   {{0x0e632c22,0x64414656,0xab5d009e,0x00000000}},	// [3cc0] актн, lvli, _tiżj, --,
   {{0x6d8b00d9,0x5bca1ae6,0x2b4d0090,0xf0664657}},	//   kļau, िद्व, _anec_, _акоп,
   {{0x6ea2143d,0x5f060848,0x395e0a88,0xceea004d}},	//   _कुरु, _изна, _rots_, _одне_,
   {{0x395e41f4,0x67d101d3,0x26cf001c,0x645e014b}},	//   _sots_, _gāji, _nggo_, _àpie,
   {{0x395e0472,0x2fc04658,0xdbdf4571,0x394c01c2}},	//   _pots_, mmig_, _bíót, _pnds_,
   {{0xfce34659,0x6609465a,0xc27b00ca,0x3d19110d}},	//   _воро, drek, ורני, _पाये_,
   {{0x395e05fe,0x6d4e465b,0x6609465c,0xdead01c2}},	//   _vots_, _inba, erek, ddaƙ,
   {{0xf09317f5,0x473419ff,0x466a2ff8,0x00000000}},	//   ינו_, унис, дром_, --,
   {{0x395e16c8,0x6609465d,0x6d4e010a,0x644103a9}},	//   _tots_, grek, _knba, evli,
   {{0xb5fd02c6,0x26cf0f5a,0xf1c700d4,0xceb30142}},	//   myšl, _eggo_, čáku_, סיז_,
   {{0x6ab20aa6,0x660902a7,0x64411570,0x00000000}},	//   _जरुर, arek, gvli, --,
   {{0x23960029,0x6609465e,0x66e620da,0x68f8059a}},	//   tāja_, brek, _рода, lavd,
   {{0x51870ba9,0x2d8f0018,0x6d8b0034,0x7d0335ba}},	//   вува, égek_, nżac, ónsk,
   {{0xaefb0139,0x2fcb00c4,0xd83800d4,0x68f8465f}},	//   _alùp, _sicg_, _ksč_, navd,
   {{0x843800e3,0xa3b44660,0xb4de030b,0x61e6084e}},	//   _أكبر_, _जीव_, तडी_, apkl,
   {{0x6ab20d0b,0x6d4e4661,0x63660b66,0x2fc00eac}},	//   _जरूर, _anba, _bónu, gmig_,
   {{0x27e90106,0x68f81528,0x7c3a0a39,0x1df80b2f}},	// [3cd0] ćani_, kavd, _štrp, кеты_,
   {{0xdcb10023,0x9be7004d,0x8afd00d2,0x00000000}},	//   _ở_, відк, _moře, --,
   {{0x9f58058a,0x6acb397e,0x00000000,0x00000000}},	//   guró_, िश्र, --, --,
   {{0x20114662,0x09cb009d,0x6d4e4663,0xc47700ca}},	//   muzi_, ाद्य, _enba, כתבו_,
   {{0x20114664,0x3f894665,0xd838022b,0xab5d0090}},	//   luzi_, miau_, _asč_, _jiżi,
   {{0x3f894666,0xdb1c4667,0x0d64008f,0xab5d02a1}},	//   liau_, _zurü, _късм, _miżi,
   {{0xb8db1e93,0x2011359c,0x8bc716a1,0xdb1c00b3}},	//   _घर_, nuzi_, _асад, _curó,
   {{0x3f8902ad,0x80bf0033,0x2b4d05db,0x61fd02ac}},	//   niau_, ্ডপ্, _unec_, kssl,
   {{0xdb1c4668,0x09dd0081,0x7bd54669,0xadc40065}},	//   _euró, _ঠিকা, _huzu, _arẹs,
   {{0x6609466a,0x7bd5466b,0x3f890150,0x2011466c}},	//   rrek, _kuzu, hiau_, kuzi_,
   {{0x7854037f,0x7bd5466d,0x3f890138,0x2011466e}},	//   _نیوز_, _juzu, kiau_, juzi_,
   {{0x91e62b49,0x7bd5466f,0x36d500c9,0x20114670}},	//   ломе, _muzu, _содр, duzi_,
   {{0x660505af,0x2ed90081,0x3f890150,0x7bd50f4c}},	//   _спла, তরাষ, diau_, _luzu,
   {{0x20110283,0xbddb0257,0xe4e7004d,0xab5d009e}},	//   fuzi_, _crèm, _рідн, _diżi,
   {{0x5f060465,0x20114671,0x00000000,0x00000000}},	//   лзва, guzi_, --, --,
   {{0x3f8908a1,0x63660042,0xab5d0078,0x61e64672}},	//   giau_, _cónt, _fiżi, ppkl,
   {{0x7bd54673,0x200a02ef,0x539b00ca,0x00000000}},	// [3ce0] _auzu, srbi_, _ריפו, --,
   {{0x61e40c56,0x7bd54674,0x20110517,0xee370138}},	//   _itil, _buzu, buzi_, ыну_,
   {{0x711b07a6,0x3f894675,0xbb4630cf,0x63660076}},	//   _אויפ, biau_, лежк, _fónt,
   {{0x7bd50a00,0x3f894676,0x63664677,0x00000000}},	//   _duzu, ciau_, _tónu, --,
   {{0x25a54678,0xe918224a,0x00000000,0x00000000}},	//   koll_, волі_, --, --,
   {{0x6d4e4679,0xd8380146,0x63a60124,0x9f580036}},	//   _unba, _psč_, hokn, curò_,
   {{0xebe3467a,0x68f8467b,0x63a6467c,0x63660088}},	//   _госп, ravd, kokn, _jóns,
   {{0x7c9300e3,0x61e4467d,0xdb1c0154,0x68f81f60}},	//   _الفص, _otil, _eurò, savd,
   {{0x7bd5467e,0x853c00c6,0x7bc2145c,0xd8380383}},	//   _zuzu, klėt, mmou, _pyčs_,
   {{0x7bd5467f,0x7bc20c86,0x3f890138,0x201112e6}},	//   _yuzu, lmou, ziau_, yuzi_,
   {{0x61e44680,0x7c290284,0xa2c209c4,0xb9190174}},	//   _atil, _ćerk, रेस्, hafụ_,
   {{0x7bc206a3,0xaca40294,0x61e4010a,0x20114681}},	//   nmou, _arịr, _btil, vuzi_,
   {{0x388e0253,0x3f890138,0x25a50212,0xbddb4682}},	//   _hər_, viau_, boll_, _prèm,
   {{0x7bc24683,0x3f890150,0x61e900ae,0xdb09009c}},	//   hmou, wiau_, ţelo, _dheù,
   {{0x21310154,0x77620694,0x63a64684,0x3f890150}},	//   rezh_, _koox, bokn, tiau_,
   {{0x20110193,0x63a64685,0x7bd54686,0x61e43a78}},	//   ruzi_, cokn, _ruzu, _ftil,
   {{0x8cf50b99,0x3f894687,0x51874688,0xae0c02d5}},	// [3cf0] изац, riau_, _буна, िंगन_,
   {{0x3f894689,0x66cb013c,0x7bc201af,0x98ac0034}},	//   siau_, _hökü, emou, _wadę_,
   {{0xe1ff0018,0x3f89409a,0xbddb0113,0x66cb0555}},	//   lsó_, piau_, _krèk, _kökü,
   {{0x224901c5,0x25b20789,0x6d58468a,0x00000000}},	//   _krak_, ुगुण, övar, --,
   {{0xe9ff0019,0xe1ff468b,0xfaa50b1b,0x7af901c2}},	//   _trận_, nsó_, јало, rawt,
   {{0x22490995,0xab5d00bd,0xd94539f8,0xdb2305bc}},	//   _mrak_, _niżv, реки, _گوری,
   {{0x25a53206,0xe73919a5,0x22490113,0x776201ee}},	//   voll_, вей_, _lrak_, _boox,
   {{0x16390037,0x66e5468c,0x00000000,0x00000000}},	//   نسخة_, јопа, --, --,
   {{0x7762008c,0x6b8b0172,0x00000000,0x00000000}},	//   _doox, migg, --, --,
   {{0x4585468d,0x6b8b468e,0x27050028,0x79c806fa}},	//   ргов, ligg, ồn_, _موقف_,
   {{0x61e426a4,0x47350b57,0xf1c8030b,0x224906e1}},	//   _stil, _внес, ntář_, _arak_,
   {{0x2249277a,0x03a61785,0x53a6468f,0x78f00af0}},	//   _brak_, римо, рамб, _iṣẹj,
   {{0x25a54690,0x66cb026a,0x27e90a9e,0x63a64691}},	//   poll_, _dökü, ćanu_, rokn,
   {{0xa2c20469,0xa5090636,0x69c30037,0x63a64692}},	//   रेष्, _река_, nmne, sokn,
   {{0x69c34693,0x224901c8,0xa2e6004b,0x6ab20285}},	//   imne, _erak_, _койд, _जर्र,
   {{0x6840030b,0x224902a1,0x26df03e3,0x7fd50565}},	//   ládá, _frak_, ncuo_, сірі,
   {{0xa2c24694,0x7de50192,0x433b006e,0xe1ff0018}},	// [3d00] रेश्, مسلم, _יעקב, csó_,
   {{0xab5d003d,0x01fb006e,0xc1740044,0x5fb80096}},	//   _miżu, _שפיל, _buɗe_, _आठवल,
   {{0x22490c7e,0x7bc2022b,0xc1740022,0x6b8b028d}},	//   _zrak_, tmou, _cuɗe_, figg,
   {{0x69c34695,0x6b8b4696,0x29054697,0x65630090}},	//   emne, gigg, _adla_, _lonh,
   {{0x69c30085,0xaca4026e,0x7bc2226a,0x00000000}},	//   fmne, _irọr, rmou, --,
   {{0x99f500d6,0x65634698,0x645c31e8,0xf806232c}},	//   сяці, _nonh, ärik, ачин,
   {{0xa9671e6e,0xd83a00d3,0x3157006e,0xdb1c003e}},	//   рија_, тэл_, ייסן_, _furð,
   {{0xb9170129,0xab5d0034,0x7c2e4699,0xcb670d62}},	//   _kedụ_, _biżu, _ipbr, _касе_,
   {{0xba29029e,0xae0c0455,0x6563469a,0x7c29042d}},	//   _مسلم_, िंटन_, _bonh, _ćeri,
   {{0x656300c9,0x66cb03e0,0x5bc40294,0xab5d02a1}},	//   _conh, _sökü, _ịchị_, _diżu,
   {{0xe2f900d6,0x3cf80124,0xa73900e7,0x3d1900bc}},	//   лені_, _merv_, ščaš, _पासे_,
   {{0xb6a60131,0xe1ff0103,0x69cf0956,0xe3b9013c}},	//   _киел, tsó_, _écer, atın_,
   {{0x52140938,0x363600cd,0xdb1b0113,0x2ee00072}},	//   одят, _خراس, _dhuè, dcif_,
   {{0x7c2e469b,0xdd1a003d,0x3d100f35,0xd5af004d}},	//   _opbr, għżu, ालों_, _єс_,
   {{0xb4d2009d,0x657a00e3,0xe1ff469c,0x2249469d}},	//   वशी_, mhth, ssó_, _wrak_,
   {{0xc17403e3,0x853c0138,0x644a009e,0xe1ff037a}},	//   _ruɗe_, plės, _irfi, psó_,
   {{0xdef800c6,0x63ad469e,0x3eaf469f,0x22493d7d}},	// [3d10] рыс_, _ikan, ægt_, _urak_,
   {{0xdcf90678,0x201e05fe,0x442e00dc,0x657a0023}},	//   افات_, àtic_, _kpf_, nhth,
   {{0x9f35224a,0x63ad0517,0x0dc8376e,0x442e039f}},	//   _лені, _kkan, рути_, _jpf_,
   {{0xe4570130,0x3d19007a,0x442e0131,0xe9a8001c}},	//   ייבט_, _पावे_, _mpf_, یدون_,
   {{0x6b8b46a0,0x24530134,0xe3b90092,0x443c46a1}},	//   rigg, _ịme_, ytın_, _lsv_,
   {{0x443c0501,0xab5d03e5,0x63ad0124,0x6b8b46a2}},	//   _osv_, _riżu, _lkan, sigg,
   {{0x66022801,0x63ad46a3,0x7e6d46a4,0x656302ef}},	//   _avok, _okan, lyap, _ronh,
   {{0x65630396,0x09e60081,0x69dc0631,0x63ad46a5}},	//   _sonh, _নিরা, _črev, _nkan,
   {{0x9f5e46a6,0x6b8946a7,0x7e6d1a8e,0x443c00d9}},	//   été_, _imeg, nyap, _asv_,
   {{0x63ad46a8,0x657a46a9,0x442e0063,0x66e700c3}},	//   _akan, ghth, _bpf_, _ट्रक_,
   {{0x442e0161,0x64a546aa,0xe3b90491,0x68401983}},	//   _cpf_, сана, rtın_, rádá,
   {{0xc16900ca,0x48ff00b6,0x7e6d010a,0x00000000}},	//   _אח_, रणको_, kyap, --,
   {{0x644a46ab,0x6b890129,0x657a0527,0x999f0e4b}},	//   _erfi, _mmeg, bhth, _zruš_,
   {{0x63ad46ac,0x657a46ad,0x1ddb00a5,0x7e6d46ae}},	//   _ekan, chth, _बढ़त, dyap,
   {{0xe1f200cd,0x6602033b,0x6e2f0154,0xafe646af}},	//   _کسب_, _zvok, _apcb, собл,
   {{0x43931fdb,0x63ad0113,0x6b9b024a,0x00000000}},	//   _најс, _gkan, _njug, --,
   {{0x6ea2030b,0xa3dd0096,0xa3b43aee,0x7c3c01ff}},	// [3d20] _कुखु, _थंड_, _जीए_, _ssrr,
   {{0x6b9b46b0,0x3202408f,0x442e4096,0x6b8946b1}},	//   _ajug, msky_, _ypf_, _ameg,
   {{0x0c26064f,0xa06a007e,0x320246b2,0xfbd20602}},	//   смен, _сана_, lsky_, ستا_,
   {{0xeafa2296,0x8afd030b,0xef2101d3,0x61f602ac}},	//   ارات_, _pořa, _ceļā_, _kwyl,
   {{0x320246b3,0xa96a3974,0x6b9b0072,0x298a1c47}},	//   nsky_, лида_, _djug, лско_,
   {{0x6b890129,0x2d8f0018,0x6b9b0174,0x7c3346b4}},	//   _emeg, éget_, _ejug, ñerí,
   {{0x764b0150,0x660246b5,0xbddb0113,0x2d8a039f}},	//   _argy, _svok, _brèw, _imbe_,
   {{0x442e46b6,0xbddb03a9,0x7f4446b7,0x9b960037}},	//   _rpf_, _crèw, ndiq, _الرت,
   {{0x657a010b,0xda630cba,0x671900c3,0x320200d4}},	//   thth, _евти, _धारक_, jsky_,
   {{0x442e46b8,0x32020fb9,0x2c0d0096,0x6e2401ab}},	//   _ppf_, dsky_, ांचं_, itib,
   {{0x320246b9,0x672000aa,0x6e240063,0x78ba01d3}},	//   esky_, _यापक_, htib, _uztv,
   {{0x6e2446ba,0x4c9b00c1,0xf1da030b,0x29f60034}},	//   ktib, רשטע, _यूहन, oła_,
   {{0xe5a643a9,0x3d1900a3,0x2d8a0051,0x0ea7417e}},	//   _лиди, _पाले_, _ombe_, _कुंड,
   {{0x443c46bb,0x61f600f0,0xab5d02a1,0x98a700c6}},	//   _tsv_, _dwyl, _jiżr, seną_,
   {{0x7dc901b3,0x442e015e,0xc05816dd,0xab5d0090}},	//   _užsi, _upf_, біт_, _miżr,
   {{0x63ad0b33,0x2d8a46bc,0x44ce0092,0x7e6d026a}},	//   _ukan, _ambe_, mə_, tyap,
   {{0x320f0068,0x61f602ad,0x44ce0092,0x6e2406a8}},	// [3d30] _így_, _gwyl, lə_, gtib,
   {{0x6b890138,0x68fa0537,0x29f60034,0x69dc007a}},	//   _smeg, _netd, dła_, _पढ़ी,
   {{0x44ce0253,0x7f44008c,0x88bc02c6,0x29f6007f}},	//   nə_, bdiq, _uběh, eła_,
   {{0x291e46bd,0xe3b9026a,0x7bc0007f,0x2d8a46be}},	//   _acta_, ktım_, _chmu, _embe_,
   {{0x2d8f0018,0x2bb800e3,0x29f60034,0xdb26001c}},	//   éges_, حالة_, gła_, تونی,
   {{0x6ea22674,0x98be0511,0xbddb00fd,0x69dc05db}},	//   _कुटु, _altı_, _brèv, _čret,
   {{0x6d5546bf,0x29f600a5,0x6d450aa9,0x6b9b320e}},	//   _inza, ała_, mdha, _tjug,
   {{0x44ce01d4,0x060907b3,0x6b8946c0,0x6d4546c1}},	//   də_, аник_, _umeg, ldha,
   {{0xe5793f67,0x96b90f1e,0xa2cb030b,0x200500cb}},	//   изи_, шуку_, सेम्, šlih_,
   {{0x6d450979,0x7afb02dc,0x320246c2,0x68fa0092}},	//   ndha, _heut, vsky_, _getd,
   {{0x7afb46c3,0x69c1332f,0xbddb00fd,0x24800022}},	//   _keut, _ihle, _grèv, _ƙima_,
   {{0x7c2546c4,0x61f60150,0x320246c5,0x69db46c6}},	//   ithr, _pwyl, tsky_, _kuue,
   {{0x32040074,0xbb3a006e,0x7afb46c7,0xeb3a006e}},	//   émy_, בערי, _meut, בערש,
   {{0x7afb02e2,0x32020e4b,0x67290078,0xc17403e3}},	//   _leut, rsky_, lfej, _buɗa_,
   {{0x6d4500f0,0xafe3025d,0x7ae230e1,0x9f980139}},	//   ddha, досл, ycot, _fáìn_,
   {{0x6e2446c8,0x6d5546c9,0x2246037d,0x7c250441}},	//   ttib, _anza, _šoku_, dthr,
   {{0x61462357,0x69c146ca,0x20d601b3,0x7f4446cb}},	// [3d40] _депа, _ohle, _мінс, rdiq,
   {{0x6e2446cc,0x7f4400a7,0x3f8b00e7,0x20110b14}},	//   rtib, sdiq, _emcu_, brzi_,
   {{0x3a3f0113,0x0b461612,0x7afb46cd,0xdb0b016d}},	//   _asup_, жнен, _beut, mogê,
   {{0xab2a344d,0x201846ce,0x6d4546cf,0x7afb1032}},	//   рода_, muri_, adha, _ceut,
   {{0x201846d0,0x7afb0703,0x7c250091,0x6d450188}},	//   luri_, _deut, athr, bdha,
   {{0x69c146d1,0x44ce01d4,0xbddb0472,0xdb09033c}},	//   _chle, yə_, _prèv, _bheó,
   {{0x201846d2,0x29f600a5,0x307a00c1,0x69c103ea}},	//   nuri_, sła_, יאַנ, _dhle,
   {{0x44ce01d4,0x69c1019f,0x201800ae,0x386000e7}},	//   və_, _ehle, iuri_, ćir_,
   {{0x201846d3,0x7bdc46d4,0x69db0113,0x69c107bc}},	//   huri_, _huru, _guue, _fhle,
   {{0x7bdc46d5,0x201846d6,0x637f01e5,0xa2cb05a5}},	//   _kuru, kuri_, _këng, _सृष्,
   {{0x9cdb0130,0x7bdc46d7,0x224046d8,0x7afb46d9}},	//   יקיפ, _juru, _asik_, _yeut,
   {{0xc5f900c7,0x201846da,0x7bdc46db,0x883b00a1}},	//   _আমরা_, duri_, _muru, _כתבו,
   {{0x7bdc39a0,0x6d45008a,0x637f0052,0xd24400ae}},	//   _luru, ydha, _lëng, мэри,
   {{0x7c2546dc,0x201846dd,0x291c0138,0x98be0383}},	//   ythr, furi_, ngva_, _latč_,
   {{0x201846de,0xe9ff0019,0x44ce0092,0x67310120}},	//   guri_, _trần_, qə_, _åkjø,
   {{0x20030034,0x3a260131,0x65bd03a9,0x00000000}},	//   rsji_, ktop_, mèha, --,
   {{0x0ec5110f,0x7bdc46df,0x7e600428,0x7c2546e0}},	// [3d50] लेंड, _auru, _àmpl, wthr,
   {{0x7bdc46e1,0x201846e2,0x2b4646e3,0x3a3f0167}},	//   _buru, buri_, edoc_, _rsup_,
   {{0x20180012,0x6d4546e4,0x7afb46e5,0x2fc2009c}},	//   curi_, rdha, _peut, _fhkg_,
   {{0x7bdc46e6,0x23960029,0x7c2546e7,0xa2c21b79}},	//   _duru, tāji_, rthr, रेक्,
   {{0x69c146e8,0xdb0901f7,0xdb0b0052,0x2b4405db}},	//   _phle, _bheò, logë, _damc_,
   {{0x7bdc46e9,0x7c2546ea,0x6d450188,0xdb090441}},	//   _furu, pthr, qdha, _cheò,
   {{0xd0f800f5,0xdcfc08a9,0x637f00dd,0x7afb35d1}},	//   חמות_, _smrć, _kënd, _teut,
   {{0x3a3f00f9,0x3219109b,0x160609c4,0x00000000}},	//   _tsup_, kusy_, _शिखर_, --,
   {{0x201846eb,0x7bdc46ec,0xdb0901f7,0xbddb0154}},	//   zuri_, _zuru, _fheò, _irès,
   {{0x764902fd,0x637f023b,0x7bdc008a,0x69c10201}},	//   rvey, _lënd, _yuru, _uhle,
   {{0x20182a9a,0x7bdc008c,0xb5fd0094,0x7dc900c6}},	//   xuri_, _xuru, vyšu, _užsu,
   {{0x201846ed,0xddcd042d,0x442546ee,0x637f0216}},	//   vuri_, jzaž, rtl_, _nënd,
   {{0x201846ef,0xbebb00dd,0x1dbd0096,0x21380063}},	//   wuri_, _mbës, ्गात, terh_,
   {{0x201846f0,0x270c00c6,0x65bd00d1,0x00000000}},	//   turi_, rėnų_, bèha, --,
   {{0xdfd200e3,0x394546f1,0x645c01a5,0xaca40134}},	//   فيس_, _mals_, ärit, _kpụr,
   {{0x201846f2,0x32193a18,0x7bdc46f3,0xdb1b0076}},	//   ruri_, busy_, _ruru, _bhuí,
   {{0x201846f4,0x2240019c,0xd24f0037,0xdb0b1695}},	// [3d60] suri_, _usik_, _مني_, mogè,
   {{0xf1bf35ac,0x201846f5,0x7bdc46f6,0x645c0fbc}},	//   ltán_, puri_, _puru, årig,
   {{0x7bdc46f7,0x6bd60397,0x6ec000b6,0xf1bf0076}},	//   _quru, ستار, लेजु, otán_,
   {{0x7bdc46f8,0x8fa61f47,0x3a2601ce,0xdb090441}},	//   _vuru, _хаме, ttop_, _sheò,
   {{0x7bdc46f9,0x7c3b0e94,0x3f92431b,0x2b44020b}},	//   _wuru, _ćure, miyu_, _vamc_,
   {{0x7bdc46fa,0x239600d9,0x290201d3,0x3a2646fb}},	//   _turu, māju_, _ēkas_, rtop_,
   {{0x072004dd,0x3a2646fc,0xdca30cc6,0x39450324}},	//   _यादव_, stop_, _зари, _dals_,
   {{0x4c9b00ca,0xab27246b,0x3a2646fd,0x98a702c6}},	//   _הבלו, _носа_, ptop_, leně_,
   {{0xc6f71736,0x394546fe,0x239601d3,0xf1e100aa}},	//   чных_, _fals_, nāju_, _गूढ़_,
   {{0x998600d0,0xe3b90233,0x7dc900c6,0x00000000}},	//   _علاو, ptık_, _užst, --,
   {{0xb60301d3,0x00000000,0x00000000,0x00000000}},	//   ēšam, --, --, --,
   {{0x187700a1,0xbebb023b,0xe521030b,0x00000000}},	//   _מעבר_, _mbër, _माथि_, --,
   {{0x637f01e5,0x6fd61362,0xe9ff00de,0x95ca46ff}},	//   _rënd, _मंजू, _trấn_, _лука_,
   {{0x645c322d,0x76420065,0x46c900b6,0x239600e8}},	//   äris, _isoy, ाइरह, dāju_,
   {{0xdb1b00e3,0x753a4700,0x9f41033c,0x00000000}},	//   _shuí, metz, _athá_, --,
   {{0x637f00dd,0xa85700a1,0x753a41f8,0x290c0172}},	//   _qënd, הילה_, letz, _ldda_,
   {{0x63af1643,0x9d5500d0,0x2fc9057a,0x9f8a002b}},	// [3d70] mocn, وچست, rmag_, _añón_,
   {{0x61ed4701,0xdb0b4702,0x2fc94703,0x63af0031}},	//   _ital, mogé, smag_, locn,
   {{0xbddb3d7f,0x637f023b,0x3f924704,0xdb0b3f96}},	//   _près, _tënd, biyu_, logé,
   {{0x290c2667,0x3d190dba,0xdecb2cad,0x3f80020a}},	//   _adda_, _पाके_, _гугл_, chiu_,
   {{0xd9452cb3,0x3945027e,0x657d0052,0xd5b800e8}},	//   дели, _pals_, ëshk, klā_,
   {{0x99670084,0xbddb0257,0xeab000e3,0xa2c20789}},	//   ятел, _frèr, دعم_, रेट्,
   {{0x753a0a00,0x39454705,0x61ed0009,0x76420139}},	//   detz, _vals_, _ltal, _asoy,
   {{0x290c4706,0xe1ff4707,0x61ed4708,0x394518f0}},	//   _edda_, nyós_, _otal, _wals_,
   {{0x6d474709,0xa3d10251,0x3945470a,0x66150034}},	//   _kaja, वगन_, _tals_, ązko,
   {{0x6d47463d,0x656a01ec,0x753a01c8,0x7bcb0324}},	//   _jaja, _cofh, getz, lmgu,
   {{0x6d47470b,0x61ed470c,0x6fbf02e8,0x03a6470d}},	//   _maja, _atal, ्षां, дино,
   {{0x6d470c56,0x32090154,0x61ed009e,0x66e30065}},	//   _laja, _bvay_, _btal, _díkó,
   {{0xa509215f,0x753a0a00,0xf1bf470e,0xc447001c}},	//   _дела_, betz, rtán_, زیکن_,
   {{0x6d4700e9,0xdb0b0222,0xf1bf470f,0x661b4710}},	//   _naja, llgä, stán_, muuk,
   {{0x2bd90e72,0xdee63119,0x3f9e0131,0x661b4710}},	//   _बंगा, доби, étuo_, luuk,
   {{0xe29a1c91,0x23960029,0x64434711,0xe3b7008f}},	//   _май_, tāju_, _isni, _общ_,
   {{0x6d47060c,0x2d93305a,0x00000000,0x00000000}},	// [3d80] _baja, fixe_, --, --,
   {{0x7ae94712,0x6d474713,0xf1bf4714,0x4ab100a3}},	//   _afet, _caja, ntál_, _जड़व,
   {{0x6d474715,0x6ad6009d,0x7c3e029a,0x00000000}},	//   _daja, धश्र, uwpr, --,
   {{0x661b4716,0xeb974717,0xbddb03a9,0x64434718}},	//   kuuk, мих_, _isèn, _msni,
   {{0x6f0401b5,0x09e3067c,0x62864719,0x59f800d3}},	//   maic, вочн, nzko, челя_,
   {{0x644300e9,0x6d471084,0x7ae90396,0x6f040049}},	//   _osni, _gaja, _efet, laic,
   {{0x7ae9471a,0x00000000,0x00000000,0x00000000}},	//   _ffet, --, --, --,
   {{0x6f040013,0x6d472e32,0x8b95097a,0xdb1b009c}},	//   naic, _zaja, _зруч, _ghuà,
   {{0x753a0a00,0x6d4720ea,0x644300fc,0x661b0172}},	//   tetz, _yaja, _asni, guuk,
   {{0x6286471b,0x6f0401b5,0x61ed0113,0x28a9147f}},	//   dzko, haic, _rtal, _चुकि,
   {{0x6f04006d,0x753a0a00,0x63af161f,0x443e029a}},	//   kaic, retz, tocn, uwt_,
   {{0x753a02dc,0x93bd002d,0x6b82471c,0xdb0b471d}},	//   setz, ptăm, nhog, togé,
   {{0x6f04471e,0xf8e23d34,0x63af471f,0x16340ff7}},	//   daic, _पलाय, rocn, _челя,
   {{0x2d930231,0x6f04009c,0x00000000,0x00000000}},	//   xixe_, eaic, --, --,
   {{0x6d474720,0xdb0b0222,0x6f0410e4,0xd48f004d}},	//   _raja, llgå, faic, _рр_,
   {{0x6d474721,0x69dd0036,0x61ed083e,0x00000000}},	//   _saja, _èseg, _ttal, --,
   {{0x6d474722,0x61ed4723,0x62860034,0x5d5502b3}},	// [3d90] _paja, _utal, czko, нкат,
   {{0x20050068,0x71750037,0xdcbb00c2,0xc05b004d}},	//   ális_, _أهدا, още_, _дім_,
   {{0x6d474724,0x5b150fa5,0x2d933c39,0xa739077e}},	//   _vaja, емет, rixe_, ščiš,
   {{0x6d474725,0x6f044726,0x00000000,0x00000000}},	//   _waja, caic, --, --,
   {{0x34bb3d34,0x6d474727,0xa3c20e19,0x636600e1}},	//   _उर्द, _taja, ्गत_, _cóny,
   {{0xf7780090,0xda78007b,0xa803047e,0x00000000}},	//   _ruħa_, ьях_, _çıks, --,
   {{0xa3af1abf,0x7d05005c,0xb4bd34fd,0xad9b0065}},	//   कवा_, mahs, _आरे_, _awúg,
   {{0x661b0a15,0xf4240033,0x3eb900f2,0xdce705db}},	//   tuuk, ববার_, _kyst_, _mojč,
   {{0xeab306f6,0xf6511823,0x9f510018,0xb8e50033}},	//   _شعر_, ائب_, lszó_, _এল_,
   {{0x661b4728,0x3eb90231,0xb46516e6,0x44651e9e}},	//   ruuk, _myst_, екол, евов,
   {{0x5fdb0557,0x3eb9038c,0xf1bf4729,0x7ae4472a}},	//   _मंगल, _lyst_, rtál_, žite,
   {{0xf1bf0437,0x2fd9009c,0x22520f5a,0x6286042c}},	//   stál_, _nisg_, _pryk_, tzko,
   {{0x55591a53,0x59c402d5,0x628601ff,0x00000000}},	//   _надя_, _लीडर, uzko, --,
   {{0x23960029,0x6609063d,0x6286472b,0x6f040022}},	//   tājs_, msek, rzko, waic,
   {{0x2f561c16,0x6286472c,0xa06a24e4,0xa0a30ad8}},	//   нтас, szko, чава_, гард,
   {{0x2252052f,0xdce70220,0x2d910027,0x3eb9472d}},	//   _tryk_, _dojč, _amze_, _byst_,
   {{0x6f040049,0x539b0054,0x63a4472e,0x7c3b09ac}},	// [3da0] raic, _מיקו, _ijin, _ćura,
   {{0x6f040049,0xbd4600e3,0x660900c2,0x3eb92405}},	//   saic, عناي, isek, _dyst_,
   {{0x6b82472f,0x6f040a02,0x660900dc,0x26dd0517}},	//   thog, paic, hsek, _ogwo_,
   {{0xc05300a1,0x637f00dd,0x66094730,0x63660042}},	//   _עזר_, _këna, ksek, _cónx,
   {{0x63a4068d,0x6b820cad,0x7d054731,0x66094732}},	//   _mjin, rhog, bahs, jsek,
   {{0xe8943b4f,0x26dd4733,0xe29f003e,0x6b824734}},	//   каль, _agwo_, naða_, shog,
   {{0xc30b00c7,0xa3c24735,0x2c860065,0x6d5c4736}},	//   ষ্টি_, ्गा_, _dídé_, _inra,
   {{0x963437b1,0x189700e3,0x63a44737,0x1754036a}},	//   вниц, عضوة_, _njin, твия,
   {{0x940a0092,0xe72f1f11,0xfaa30aa8,0x637f0052}},	//   əmək_, صصي_, _бато, _nëna,
   {{0x63a44738,0x3d19009f,0x00000000,0x00000000}},	//   _ajin, _पाछे_, --, --,
   {{0x98be00d3,0xbddb0154,0x63a40231,0xe52100bc}},	//   _dată_, _asèl, _bjin, _मारि_,
   {{0x69da4739,0x6609473a,0x26dd010a,0x8afd02c6}},	//   _hite, bsek, _ggwo_, _poři,
   {{0x69da473b,0x201801e9,0x2fd900f0,0x98be020a}},	//   _kite, erri_, _risg_, _fată_,
   {{0x38c60139,0x63a4473c,0x659413a4,0x60de00fc}},	//   _gírí_, _ejin, _шалу, _cgpm,
   {{0x69da473d,0xf1bf0018,0x5f950396,0x3ebf042d}},	//   _mite, lták_, вивт, _šut_,
   {{0x63a400dd,0x6d5c473e,0x32553283,0x00000000}},	//   _gjin, _anra, _авир, --,
   {{0x69da473f,0x02a30134,0xa3e40c17,0xf1bf01f9}},	// [3db0] _oite, _kpọọ, _भूत_, nták_,
   {{0x69da4740,0xe1f003c5,0x9f510103,0x63bd4741}},	//   _nite, _اسي_, tszó_, llsn,
   {{0x7d054742,0x628e00cb,0xf9910281,0x320b007f}},	//   rahs, ćnoš, یبت_, lscy_,
   {{0x3f6702fd,0x69da0cc2,0x3eb94743,0x3b64008f}},	//   _чтоб, _aite, _tyst_, лъчв,
   {{0x69da4744,0xaa4500c2,0x3ebf0220,0xce5804d9}},	//   _bite, телл, _áut_, _заяц_,
   {{0x69da4745,0x7f4d4746,0xf1bf0103,0x37e50033}},	//   _cite, ldaq, dták_, _নববর,
   {{0x69da0d17,0xdb0b09e9,0x5ba70f1e,0xead10033}},	//   _dite, logí, _зраз, াডেম,
   {{0x70de152c,0x69da4747,0x7f4d2fee,0x66094748}},	//   _मल्ल, _eite, ndaq, tsek,
   {{0x69da4749,0x6e2d1647,0x63bd0036,0x00000000}},	//   _fite, ntab, dlsn, --,
   {{0x6609474a,0x63b61f40,0x69da0193,0x6e2d474b}},	//   rsek, _skyn, _gite, itab,
   {{0x290728cb,0x64a50b70,0xc984474c,0xd6ab001c}},	//   mana_, тана, _сути, _کدام_,
   {{0x2907474d,0xe29a474e,0x69da474f,0x91e606b2}},	//   lana_, дам_, _zite, коме,
   {{0x69c802fd,0x29074750,0xe29f003e,0x69da4751}},	//   _yhde, oana_, taða_, _yite,
   {{0x657a1e03,0x29070c40,0xc1740044,0x6b830052}},	//   ckth, nana_, _kuɗi_, ëngj,
   {{0x20184752,0x2907078e,0x04451cf2,0x6e2d06b0}},	//   urri_, iana_, _рейн, etab,
   {{0x29074753,0x63a40239,0x7e7600c2,0x645e0218}},	//   hana_, _ujin, tyyp, _špig,
   {{0x29074754,0x6e2d02c9,0xdb0b0328,0x6abb4755}},	// [3dc0] kana_, gtab, gogí, _nyuf,
   {{0x29074756,0x7bc90231,0x00000000,0x00000000}},	//   jana_, _aheu, --, --,
   {{0x29074757,0x69da4758,0x61e44759,0xe6be022d}},	//   dana_, _rite, _huil, _ऊर्ज,
   {{0x69da475a,0x798102ad,0x7bc901b5,0x61e4475b}},	//   _site, _allw, _cheu, _kuil,
   {{0x61e404ea,0xdb150018,0x69da475c,0x7bc9475d}},	//   _juil, óbál, _pite, _dheu,
   {{0x644f0b4b,0x61e4475e,0x69da1175,0x6d5c1cc0}},	//   ācij, _muil, _qite, _unra,
   {{0x69da475f,0x26c0013f,0xeb9a1102,0x7bc90013}},	//   _vite, _šio_, _жив_, _fheu,
   {{0x78ba0871,0xf1bf0018,0x69da4760,0x798125e1}},	//   _vytv, tták_, _wite, _ellw,
   {{0x29074761,0xe3b90b88,0x69da4762,0x09e60895}},	//   bana_, ktır_, _tite, _розн,
   {{0x69da04ee,0xf1bf0103,0x00000000,0x00000000}},	//   _uite, rták_, --, --,
   {{0x657a00dd,0xf4862064,0xf1bf4763,0xe81900bc}},	//   rkth, тупн, sták_, _धिया_,
   {{0x61e44764,0xaca40294,0xc8840511,0x6e2d00ce}},	//   _buil, _asịr, ışı_, ytab,
   {{0x81be00c7,0x61e44765,0x7ae00124,0xe5344766}},	//   েদন_, _cuil, _mgmt, _бель,
   {{0x657d00dd,0x61e40049,0xa3dd0336,0x3f823661}},	//   ësht, _duil, _थूक_, _alku_,
   {{0xb33b0396,0x394c0f04,0xf4840421,0x00000000}},	//   ança, _mads_, _حاشی, --,
   {{0x61e403ea,0x3dca010a,0xdcfe01d3,0xdce702c6}},	//   _fuil, _ahbw_, kipē, _pojď,
   {{0x6ed6007d,0x29074767,0xdfd8013d,0x61e44768}},	// [3dd0] _मृदु, yana_, тър_, _guil,
   {{0x29074769,0xbbcb000c,0x2249476a,0xdce701d3}},	//   xana_, िष्क, _isak_, _bojā,
   {{0x9f410113,0x61e4029a,0x7bc9009c,0x82b400d1}},	//   _luhé_, _zuil, _pheu, _محیط,
   {{0x2907476b,0x2613009d,0xc17401c2,0xdd0303e0}},	//   wana_, _दिली_, _ruɗi_, ırın,
   {{0x2907476c,0xee8700c2,0xde6400e5,0x916600fe}},	//   tana_, _рыно, _кърп, _sổ_,
   {{0x9aa40037,0x527c0266,0x394c00b3,0x2907476d}},	//   جمهو, ונדא, _cads_, uana_,
   {{0x2907476e,0x013800a1,0x7bc9476f,0xdd94004b}},	//   rana_, דרות_, _theu, _тары,
   {{0x29074770,0x394c4771,0x3869042d,0x7bc90231}},	//   sana_, _eads_, ćar_, _uheu,
   {{0x29072e87,0x645c1f60,0x394c0154,0x999f0090}},	//   pana_, årin, _fads_, _kruż_,
   {{0x61e424e7,0x394c01d3,0x8934071c,0x61e2020d}},	//   _ruil, _gads_, _نعما, _éoli,
   {{0x290500d9,0x9f600052,0x637f0216,0x61e42e6a}},	//   _iela_, ërës_, _cëno, _suil,
   {{0x2905070a,0x637f023b,0x888c006e,0xdb0b00b3}},	//   _hela_, _dëno, _קראַ, nogà,
   {{0x224900fb,0x61e44772,0x2d834773,0x2905007b}},	//   _csak_, _quil, _olje_, _kela_,
   {{0x29052e87,0x61e40371,0x869a006e,0x65944774}},	//   _jela_, _vuil, _אינז, _качу,
   {{0x29054775,0x224900dc,0xa3e7115b,0xa5da006e}},	//   _mela_, _esak_, _बढि_, _אַהי,
   {{0x61e410f0,0x8afd02c6,0x60c14304,0xe3b90847}},	//   _tuil, _mořs, ülma, stır_,
   {{0x1fa74776,0x733b00c1,0xdd2c0138,0xdb0b00b3}},	// [3de0] укти_, _טעקס, _vėži, dogà,
   {{0x29054777,0x5bdc04f8,0xe3b90233,0x00000000}},	//   _nela_, यद्व, ltıp_, --,
   {{0x661b2879,0x2d83033b,0xe1ff002b,0x823601f3}},	//   hruk, _dlje_, nxón_, _شرکا,
   {{0xd9cc1fbb,0x09e64778,0x501b00a1,0xa09b00c1}},	//   ाष्ट, годн, _אוטו, _טייט,
   {{0x2fc00c2e,0xf1a9001c,0xaca40032,0x394c4779}},	//   mlig_, _سایه_, _isọr, _pads_,
   {{0xfce30bb9,0x2905477a,0x661b2557,0x3cec0103}},	//   _горо, _cela_, druk, _üdv_,
   {{0x2905477b,0xdcfe01d3,0x6d4e010a,0x6f0605db}},	//   _dela_, sipē, _iaba, _kekc,
   {{0x6d4e477c,0xa3e705d4,0x2fc00c96,0xa6141c1b}},	//   _haba, _बढ़_, nlig_, амич,
   {{0x6d4e477d,0xc1740d2a,0x2905041b,0x030800c3}},	//   _kaba, _huɗu_, _fela_, _वज़ह_,
   {{0x6d4e31c7,0x163700e3,0x2905477e,0x2fc00013}},	//   _jaba, اسية_, _gela_, hlig_,
   {{0x6d4e477f,0xc44500cd,0x2fc04780,0xa81a2296}},	//   _maba, لیون_, klig_, _ستار_,
   {{0x6d4e4781,0x661b4782,0x2fc0422e,0x29050a00}},	//   _laba, bruk, jlig_, _zela_,
   {{0x2fc03696,0x51874783,0x2d9a02a4,0x2905405d}},	//   dlig_, гува, kipe_, _yela_,
   {{0x22494784,0xaca40065,0xa4d4097a,0x94d4002d}},	//   _vsak_, _asọr, _колі, _колц,
   {{0x2fc00ac9,0x00000000,0x00000000,0x00000000}},	//   flig_, --, --, --,
   {{0x2fc00c2e,0x5f944785,0x644a0078,0x6f060167}},	//   glig_, бист, _isfi, _cekc,
   {{0x645800e7,0x22494786,0x00000000,0x00000000}},	// [3df0] _hrvi, _usak_, --, --,
   {{0x6d4e4787,0x31352d89,0x8d7706f6,0x66024788}},	//   _caba, _теор, دارا, _mwok,
   {{0x6add1349,0x6d4e4789,0x2905063f,0xa2d90bf5}},	//   यश्र, _daba, _rela_, _नृत्,
   {{0x8f472f1f,0x645808c5,0x7ae40146,0xdb0b0103}},	//   _сход, _mrvi, žitn, fogá,
   {{0x290500c9,0x6d4e478a,0x660200ac,0xdb0b00b3}},	//   _pela_, _faba, _nwok, rogà,
   {{0x6d4e478b,0x2d8300cb,0x64582742,0x443c010a}},	//   _gaba, _ulje_, _orvi, _opv_,
   {{0x6602478c,0x2905478d,0xa3e40b89,0x442e0415}},	//   _awok, _vela_, _भूल_, _nqf_,
   {{0x6d4e478e,0x291b01d4,0x7d07478f,0x3f8900f0}},	//   _zaba, şqa_, _hejs, nhau_,
   {{0x6d4e4790,0x29054791,0x64584792,0x443c0085}},	//   _yaba, _tela_, _arvi, _apv_,
   {{0x6d4e4022,0x80bb009d,0x661b4793,0xe7ed09c3}},	//   _xaba, _शुभे, rruk, _चंपा_,
   {{0xa8a72f34,0x657d0052,0x00000000,0x00000000}},	//   _срак, ëshq, --, --,
   {{0xe72e4794,0x7f4f0451,0x661b03a9,0x443c0131}},	//   _ќе_, _nacq, pruk, _dpv_,
   {{0x2fc00bab,0x442e0090,0x3f8900f0,0x6602083e}},	//   vlig_, _eqf_, dhau_, _gwok,
   {{0x6f064795,0x7d07000d,0xbddb0154,0x2e2f0555}},	//   _sekc, _nejs, _erèz, düf_,
   {{0x2fc04796,0x6fb60190,0x637f0052,0x7f4f00fc}},	//   tlig_, لمسا, _mënj, _bacq,
   {{0x6d4e4797,0x43931009,0x00000000,0x00000000}},	//   _saba, _мајс, --, --,
   {{0x2fc04798,0x0e664799,0x93bd020a,0xaefb009c}},	// [3e00] rlig_, шкан, rtăt, _snùc,
   {{0x6d4e3ac5,0x2fc0479a,0x645e065b,0xbddb0154}},	//   _qaba, slig_, _ápic, _krèy,
   {{0x2d9a479b,0x6d4e0006,0x7d07479c,0x3f8901fa}},	//   ripe_, _vaba, _dejs, bhau_,
   {{0xfbc30d47,0x6d4e479d,0x2d9a0c56,0x3f89479e}},	//   обхо, _waba, sipe_, chau_,
   {{0x7ae40074,0x7d071419,0x2d9a479f,0x00000000}},	//   žito, _fejs, pipe_, --,
   {{0x2d9a00dd,0x93bd00d3,0x66020027,0xf1bf0031}},	//   qipe_, ntăr, _rwok, stáv_,
   {{0xdc670077,0x76590150,0xdca34444,0x2d9847a0}},	//   _кард_, _arwy, _дари, _imre_,
   {{0x69dd0036,0x765900f0,0x3f8000c6,0x66020383}},	//   _èsen, _brwy, nkiu_, _pwok,
   {{0xd0fb121d,0xe9da0231,0x765900f0,0x7bc202c6}},	//   ्रमण_, _ака_, _crwy, mlou,
   {{0x76590150,0x637f023b,0x00000000,0x00000000}},	//   _drwy, _gënj, --, --,
   {{0x2ec31827,0x7c3b077e,0xa2d917ad,0xc5730037}},	//   _शर्त, _ćurk, नेन्, تطيع,
   {{0x6458033b,0x06ea0285,0x765900f0,0x6e24024a}},	//   _vrvi, _ऑलिव_, _frwy, kuib,
   {{0x776247a1,0xdd2100d2,0x765900eb,0x00000000}},	//   _inox, _růži, _grwy, --,
   {{0x3f89030a,0x7bc200d2,0xa63b00d7,0x6e2401b9}},	//   whau_, hlou, _סגור, duib,
   {{0x7d0747a2,0x3f8902e0,0x74141ac9,0x443c47a3}},	//   _rejs, thau_, _اوبا, _upv_,
   {{0x04db00ca,0x93bd020a,0x661d0206,0x00000000}},	//   _בקול, drăg, šske, --,
   {{0x3f890150,0x6e2426ae,0x7bc247a4,0xea000023}},	// [3e10] rhau_, guib, dlou, _đếm_,
   {{0x78ad0491,0x7bc20042,0x93bd020a,0x7dd000ce}},	//   şavi, elou, ctăr, häsf,
   {{0x70550a09,0x637f023b,0x2dd80037,0xdcee05db}},	//   _انجا, _nënk, شبكة_, _gobč,
   {{0x2d98026a,0x6e2447a5,0x7bc21022,0x8b940120}},	//   _emre_, buib, glou, оріч,
   {{0x6f0d008a,0x7f3a00c1,0x2d8f00fd,0x6e241497}},	//   maac, _גערו, èges_, cuib,
   {{0x5d850192,0x776247a6,0x6f0d0188,0x7bc22cd5}},	//   _السل, _anox, laac, alou,
   {{0x7bc247a7,0xb4c23245,0xf1bf01f9,0x00000000}},	//   blou, ्धो_, ltás_, --,
   {{0x7bc247a8,0x6d4523b0,0xa76517a6,0x6f0d47a9}},	//   clou, leha, скид, naac,
   {{0xf1bf0103,0x6b830052,0x7c250094,0x3f9900c4}},	//   ntás_, ëngu, luhr, _mmsu_,
   {{0x27170028,0x6d4547aa,0xc97400e3,0x00000000}},	//   ển_, neha, _والث, --,
   {{0x61f647ab,0x04452917,0x6f0d024a,0x67200285}},	//   _styl, щенн, kaac, _याचक_,
   {{0x03a61612,0x6d4547ac,0x76590150,0x69c347ad}},	//   симо, heha, _trwy, llne,
   {{0xf66800cd,0x6d4547ae,0xd29a004d,0xf1bf01f9}},	//   _نحوه_, keha, утні_, jtás_,
   {{0x9f580314,0x3f9901c2,0x764947af,0x261c07ad}},	//   mpré_, _amsu_, mwey, _मिती_,
   {{0x64a247b0,0x656347b1,0x6f0d008a,0x6d4547b2}},	//   _наша, _innh, faac, deha,
   {{0x442547b3,0x93bd00d3,0x6e2447b4,0x3f9901ec}},	//   mul_, stăr, tuib, _cmsu_,
   {{0x44250a29,0x0d861469,0x93bd020a,0x76493bbf}},	// [3e20] lul_, блан, ptăr, nwey,
   {{0x6d450d50,0xbddb0065,0x442547b5,0x00000000}},	//   geha, _apèb, oul_, --,
   {{0x442547b6,0x98a70138,0x69c30031,0x5fc30285}},	//   nul_, menė_, dlne, _वीकल,
   {{0x6f0d01ee,0xf1bf47b7,0x442500d3,0x916600fe}},	//   caac, stát_, iul_, _hồ_,
   {{0x44250006,0x76490169,0x00000000,0x00000000}},	//   hul_, jwey, --, --,
   {{0x442547b8,0x7649008a,0x7c250332,0x7bc200b6}},	//   kul_, dwey, buhr, slou,
   {{0x6c860080,0x442547b9,0xa9671fdb,0x307a006e}},	//   _الأم, jul_, сија_, טאַנ,
   {{0xf1bf0181,0x69c347ba,0x65630178,0x35f411e8}},	//   ntár_, alne, _annh, опир,
   {{0x35f700cd,0xb4c2058f,0x7c3b14f3,0x764947bb}},	//   یرید_, ्ध्_, _ćuri, gwey,
   {{0x442547bc,0x00000000,0x00000000,0x00000000}},	//   ful_, --, --, --,
   {{0x442547bd,0x224000bf,0x290e3262,0x67010134}},	//   gul_, _apik_, mafa_, _ịkes,
   {{0xe29f0088,0x290e47be,0x29c90610,0x6b8247bf}},	//   laði_, lafa_, núan_, nkog,
   {{0x6d4547c0,0x00000000,0x00000000,0x00000000}},	//   yeha, --, --, --,
   {{0x442547c1,0xe29f0088,0x6f0d47c2,0x3d220034}},	//   bul_, naði_, waac, मलों_,
   {{0x44250012,0x6f0d47c3,0x6d450ac9,0x533547c4}},	//   cul_, taac, veha, _дейт,
   {{0x53a419e8,0x290e47c5,0x22400113,0xc4170103}},	//   _најб, hafa_, _fpik_, _اغوا_,
   {{0x6d4547c6,0x6f0d0188,0x63ad47c7,0xf1ab00cd}},	// [3e30] teha, raac, _ijan, _ماده_,
   {{0xae1e00a5,0xf1bf01f9,0x2d870220,0x9107002d}},	//   यंजन_, rtás_, óne_, _учид,
   {{0x6d4547c8,0xe29f01cd,0x290e1d51,0x69c30031}},	//   reha, daði_, dafa_, vlne,
   {{0x53c92b8a,0x6d45159d,0x79880113,0x637f023b}},	//   रतिश, seha, _aldw, _bëni,
   {{0x442547c9,0x2bb10067,0x76490694,0x290e47ca}},	//   zul_, jące_, xwey, fafa_,
   {{0x442547cb,0xe7ed0378,0x637f023b,0xb4e7245a}},	//   yul_, _चंदा_, _dëni, _भले_,
   {{0x442547cc,0x69dd0451,0x29c90042,0xb17c1777}},	//   xul_, _èsem, búan_, רטור,
   {{0xe61947cd,0x442547ce,0x63ad47cf,0xcb34008f}},	//   ади_, vul_, _njan, _несъ,
   {{0x69c30220,0x44252675,0x672947d0,0x290e47d1}},	//   plne, wul_, rgej, bafa_,
   {{0x442547d2,0xae1e0ff9,0x76490188,0x290e47d3}},	//   tul_, यूटन_, rwey, cafa_,
   {{0x61fd47d4,0x92e50081,0x63ad0090,0xf2c90089}},	//   epsl, _পড়ে_, _bjan, _סע_,
   {{0x44250a29,0x394734cb,0xc1690089,0x48f300b6}},	//   rul_, lens_, _בח_, ुरको_,
   {{0x442547d5,0x63ad47d6,0x0cc63ad1,0x996500b6}},	//   sul_, _djan, _वर्म, _můžu_,
   {{0x6b893bee,0x442547d7,0x39470501,0x2b9b0134}},	//   _lleg, pul_, nens_, ụcha_,
   {{0x6b9b0283,0xaf9a0829,0x6b8947d8,0x4425008c}},	//   _omug, атах_, _oleg, qul_,
   {{0x82a600d6,0x290e0383,0x6b890294,0x63ad0216}},	//   _майж, zafa_, _nleg, _gjan,
   {{0x1dc5110f,0x7ae4025b,0x22400167,0x394717c9}},	// [3e40] वतंत, žitk, _upik_, kens_,
   {{0x6b8947d9,0x6b9b47da,0x637f023b,0x39470ac9}},	//   _aleg, _amug, _rëni, jens_,
   {{0x394747db,0x29c90610,0xdee61e79,0xbddb0154}},	//   dens_, túan_, _мони, _asès,
   {{0x3947039f,0x00000000,0x00000000,0x00000000}},	//   eens_, --, --, --,
   {{0x290e47dc,0x28f80457,0x394747dd,0xade3009f}},	//   tafa_, бель_, fens_, _कंचन_,
   {{0x394747de,0x6b9b47df,0x29c9002b,0x2d9e0233}},	//   gens_, _emug, súan_, _öte_,
   {{0xda0b0251,0xe29f003e,0x00000000,0x00000000}},	//   सीबत_, raði_, --, --,
   {{0x290e47e0,0x645e47e1,0xdff20285,0xe29f04c8}},	//   safa_, _špio, _आंनद_, saði_,
   {{0x3cde05d6,0xbddb00fd,0xe29f01cd,0xdcee01d3}},	//   _कृते_, _isèr, paði_, _zobā,
   {{0x394747e2,0x63ad004d,0x2bb1007f,0xf7780078}},	//   cens_, _sjan, rące_, _ruħu_,
   {{0xa3e4000f,0x63ad47e3,0x290c0063,0x13f404d9}},	//   _भूख_, _pjan, _ieda_, язня,
   {{0x78ad0094,0xf7461b60,0x290c47e4,0x9f420052}},	//   ťový, _федо, _heda_, _dikë_,
   {{0xcb1300a1,0x753d0018,0x290c47e5,0xe3b90092}},	//   ולר_, ősza, _keda_, brın_,
   {{0x290c47e6,0xad9b0139,0x637f0052,0x76420065}},	//   _jeda_, _ewúj, _nënv, _ipoy,
   {{0xdfd500c2,0xcf9b0831,0x69d819fb,0x63ad47e7}},	//   зовы, аја_, imve, _tjan,
   {{0x290c47e8,0x63ad198d,0x2d8a00ae,0x521547e9}},	//   _leda_, _ujan, _albe_, _едит,
   {{0x39470257,0x645a017a,0x2d8a00d4,0x59ca47ea}},	// [3e50] yens_, lvti, _blbe_, ितार,
   {{0x63bd04a3,0x6b8947eb,0x320902ac,0xbddb0139}},	//   losn, _sleg, _iway_, _asèr,
   {{0x394747ec,0x6b8947ed,0x61ed033c,0xe1ff037a}},	//   vens_, _pleg, _hual, lpó_,
   {{0x61ed048e,0x39470185,0x2d8a0e78,0xd0fb0285}},	//   _kual, wens_, _elbe_, ्रवण_,
   {{0x61ed005a,0x290c47ee,0x645e47ef,0x61e547f0}},	//   _jual, _beda_, _špil, _kihl,
   {{0xaca30174,0x35cf009f,0x3947057a,0xa2ce09c4}},	//   _apục, _सीढ़, uens_, _सरस्,
   {{0x764214e2,0x39470e9f,0x290c47f1,0x98a701d3}},	//   _apoy, rens_, _deda_, menī_,
   {{0x6b9b092f,0x6d5547f2,0x394717d2,0x61ed47f3}},	//   _umug, _haza, sens_, _oual,
   {{0x6d5547f4,0x394747f5,0xd7060084,0x7ae900b3}},	//   _kaza, pens_, чные_, _iget,
   {{0xb9982787,0x9f42023b,0xd83b004c,0xdce70034}},	//   _двух_, _pikë_, _вэд_, _poję,
   {{0x6d5547f6,0x1b0e0081,0x320947f7,0xad9b0139}},	//   _maza, _হাতে_, _away_, _awúk,
   {{0x61ed0a02,0x3209022b,0x61b41f88,0x00000000}},	//   _bual, _bway_, ंक्ष, --,
   {{0x61ed47f8,0x69c10063,0x673b007e,0xe29f01cd}},	//   _cual, _kkle, mfuj, kaðu_,
   {{0x6d5547f9,0x61ed47fa,0x321e0146,0x61e502c6}},	//   _naza, _dual, čty_, _cihl,
   {{0x61e50090,0x3209020b,0x7ae901ff,0x98a700e8}},	//   _dihl, _eway_, _oget, denī_,
   {{0x7ae928f0,0x7ae40181,0x09a81d7d,0x130a00d3}},	//   _nget, žiti, _औद्य, _уний_,
   {{0x61ed47fb,0x0d860818,0x61e5063d,0x71a62657}},	// [3e60] _gual, план, _fihl, _наиз,
   {{0x6d5547fc,0x637f023b,0x6e360138,0x7ae947fd}},	//   _caza, _dënu, rtyb, _aget,
   {{0x6d5547fe,0x64430063,0x0b4647ff,0x80da0033}},	//   _daza, _jpni, знен, _ব্র্,
   {{0x261c05d4,0x290c05a7,0x7d0100ae,0xcb130096}},	//   _मिली_, _seda_, _pârâ, डणगड_,
   {{0x6f044800,0x3b0d0188,0x00000000,0x00000000}},	//   mbic, _deeq_, --, --,
   {{0x64434801,0x6d551a28,0x69c10167,0xe7ed009f}},	//   _opni, _gaza, _ckle, _चूहा_,
   {{0x8c434802,0xd90d00bf,0xf7721363,0x290c4803}},	//   _пере, شین_, فاظ_, _veda_,
   {{0x69c14804,0x6d554805,0x7d0e4806,0x290c4807}},	//   _ekle, _zaza, _hebs, _weda_,
   {{0x6d554808,0x290c4809,0x657801fa,0x6443480a}},	//   _yaza, _teda_, _povh, _apni,
   {{0x61eb0257,0x290c03a9,0xb33b016d,0x6d5500a7}},	//   _égli, _ueda_, diça, _xaza,
   {{0x61ed480b,0x6e2407e7,0x63bd480c,0x3633001c}},	//   _sual, hrib, tosn, وریس,
   {{0x637f00dd,0x60c50084,0x6e24480d,0x7d0e0d21}},	//   _nënt, _ryhm, krib, _lebs,
   {{0x61ed480e,0x63bd480f,0x6e240350,0x61e50329}},	//   _qual, rosn, jrib, _pihl,
   {{0xbddb1c27,0x26c61d0d,0x27e6009c,0x7dcb0233}},	//   _apèn, _iyoo_, _hion_, güsl,
   {{0x6d554810,0x27e60154,0x637f023b,0x63bd4811}},	//   _raza, _kion_, _bënt, posn,
   {{0x61ed4812,0xbddb00b3,0xb33b0131,0x9d090033}},	//   _tual, _asèp, biça, _লাইভ_,
   {{0x6d554813,0x2bb100a5,0x27e60a02,0x6e241f18}},	// [3e70] _paza, jąca_, _mion_, grib,
   {{0x6d5501d4,0x7d1c02ef,0x60c500c2,0x27e64814}},	//   _qaza, _cdrs, _tyhm, _lion_,
   {{0x645e0039,0x6d554815,0x6f040036,0x7dd0042c}},	//   _špij, _vaza, bbic, wäsc,
   {{0x69c1247d,0x6d554816,0x6e240e2a,0x27e60634}},	//   _skle, _waza, brib, _nion_,
   {{0x6e244817,0x6d554818,0x26c6023e,0x2fc94819}},	//   crib, _taza, _nyoo_, mlag_,
   {{0xd90f00fb,0x2fc9481a,0xbd450037,0x992b007b}},	//   ایا_, llag_, _تنسي, сюда_,
   {{0x236903ce,0x26c6481b,0x27e61d0c,0xdcf5022b}},	//   _onaj_, _ayoo_, _bion_, _jozč,
   {{0x69c10034,0x27e610e4,0x7d1c103b,0x25ac00c4}},	//   _wkle, _cion_, _zdrs, endl_,
   {{0x6f0f481c,0x645c33df,0x673b18c5,0x7dd01531}},	//   _mecc, ærin, rfuj, läsa,
   {{0x6f0f481d,0x2fc901bf,0x39150281,0x637f0f5a}},	//   _lecc, hlag_, _آواز, _oëns,
   {{0x637f023b,0x27e6481e,0x753d0103,0xa34a1f3e}},	//   _nëns, _fion_, őszo, озна_,
   {{0x7bda028d,0xb33b0231,0x22520324,0x00000000}},	//   _ètut, tiça, _psyk_, --,
   {{0x7ae4033b,0xe2970b2f,0x6e24013c,0x00000000}},	//   žitv, дая_, xrib, --,
   {{0x6f1d481f,0xb33b001f,0x27e60a00,0x00000000}},	//   _adsc, riça, _zion_, --,
   {{0x50b5160b,0x6f0f4820,0x91e33051,0x14d10ded}},	//   есту, _becc, торе, _हरिण,
   {{0x6f0f4821,0x201e0335,0x2fc94822,0x6f1d01c2}},	//   _cecc, štio_, glag_, _cdsc,
   {{0x6f044823,0x26c601bb,0x00000000,0x00000000}},	// [3e80] rbic, _xyoo_, --, --,
   {{0x6f044824,0x236908a9,0x6e240cd6,0x6f0f039f}},	//   sbic, _znaj_, rrib, _eecc,
   {{0x5f060581,0x2fc94825,0x6c4a0f43,0x51f609e5}},	//   _озна, blag_, تلاف_, _عسکر,
   {{0x6e244826,0x7d0e4827,0x7d050037,0x5aca001f}},	//   prib, _webs, abhs, олем_,
   {{0x25be034f,0x6e244828,0x9f5800b3,0x00000000}},	//   yotl_, qrib, mprà_, --,
   {{0x2fc000e3,0x6f0f0451,0x6d480146,0xdd920103}},	//   loig_, _zecc, ímač, _شوز_,
   {{0xa3c305cd,0xa2a506eb,0x4b260076,0x00000000}},	//   ्तम_, _चेन्, _يعرف, --,
   {{0x97a30ab3,0x44250141,0x00000000,0x00000000}},	//   крыл, drl_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c60a4b,0x44980120,0x00000000,0x00000000}},	//   _vyoo_, звою_, --, --,
   {{0x291e4829,0x27e6482a,0x88812c31,0x00000000}},	//   _idta_, _tion_, _میون, --,
   {{0xdcf50094,0xc6a61a17,0x00000000,0x00000000}},	//   _rozč, _орли, --, --,
   {{0x6f0f482b,0x44250227,0x00000000,0x00000000}},	//   _recc, arl_, --, --,
   {{0x6f0f1c40,0x02a30129,0x20180350,0x00000000}},	//   _secc, _nrụọ, fsri_, --,
   {{0x6f0f482c,0x656a00e3,0x403407ce,0x00000000}},	//   _pecc, _infh, керс, --,
   {{0x442c482d,0x9df91b4d,0x69ca042c,0x00000000}},	//   mud_, знат_, hlfe, --,
   {{0x442c482e,0x2fc90429,0x6f0f013d,0x2dd500d3}},	// [3e90] lud_, rlag_, _vecc, ежар,
   {{0x2fc947db,0x00000000,0x00000000,0x00000000}},	//   slag_, --, --, --,
   {{0x442c482f,0x2fc94830,0x00000000,0x00000000}},	//   nud_, plag_, --, --,
   {{0xad9b3e07,0x61fb00ae,0x291e01f9,0x09a700a4}},	//   _stúd, ţulu, _adta_, कच्य,
   {{0xa9690859,0xdbdc04c8,0xa2a532c9,0x656a009c}},	//   зила_, ráðn, _चेम्, _onfh,
   {{0x442c4831,0xac1916e6,0x7dd00212,0xdb0b0037}},	//   kud_, _ногу_, läsn, ingé,
   {{0xb8f717ff,0x442c2d96,0x1dbe0966,0x645c003e}},	//   _सर_, jud_, ्तरत, æril,
   {{0x442c4832,0xa2f90455,0x656a01b9,0xd7f80023}},	//   dud_, ंडोज_, _anfh, _trăn_,
   {{0xaad30cd5,0x6e2d0143,0x7afb18fd,0x00000000}},	//   _तरिक, nuab, _ifut, --,
   {{0xe5710037,0x7bcb4833,0x00000000,0x00000000}},	//   اطة_, llgu, --, --,
   {{0x4425009c,0x442c4834,0x29070087,0xd46937e8}},	//   url_, gud_, mbna_, чине_,
   {{0x7853013c,0x7f4d0231,0x00000000,0x00000000}},	//   _nəvə, jeaq, --, --,
   {{0x776b0201,0x4425028d,0xaefb01ec,0x7afb4835}},	//   _ingx, srl_, _gnùi, _mfut,
   {{0x442c0f05,0x201e0542,0x4425033b,0x6e2d09a1}},	//   bud_, štim_, prl_, duab,
   {{0x1beb0e72,0x25a54836,0xa0670291,0x2bb10034}},	//   _जंगल_, mill_, нара_, jąco_,
   {{0x3f8906ee,0x25a500b7,0xdb0000fc,0x00000000}},	//   gkau_, lill_, _emmê, --,
   {{0x63a609a4,0x78530092,0x60d900c6,0x4d66013f}},	// [3ea0] mikn, _dəvə, _įamž, нкав,
   {{0x63a64837,0x25a54838,0x7dc6010d,0xed5700ae}},	//   likn, nill_, رقان, ноу_,
   {{0x10a6004d,0x98a70138,0x62864839,0x776b039f}},	//   _чинн, denį_, lyko, _ongx,
   {{0x63a6025b,0x6e2d483a,0x3f89042c,0x00000000}},	//   nikn, buab, ckau_, --,
   {{0x6f6302fd,0x25a50088,0xf1bf0610,0x3b1f0090}},	//   _связ, kill_, irán_, _dduq_,
   {{0xdca6483b,0xf1bf00e3,0x442c483c,0x6f16026a}},	//   _заги, hrán_, yud_, layc,
   {{0x442c0092,0x63a6483d,0xfdbe0034,0xa37b0131}},	//   xud_, kikn, ्तीफ, lmõe,
   {{0x9fb80146,0x442c0b6a,0xca76007b,0x637f0216}},	//   _očí_, vud_, _пузы, _nënp,
   {{0x25a5483e,0xf1bf0890,0x63a6483f,0x569401b6}},	//   fill_, drán_, dikn, тапт,
   {{0x442c3245,0x628617b5,0x38c80260,0x16210789}},	//   tud_, dyko, _قاضی_, _मिरर_,
   {{0x46ea00c9,0xf1bf0328,0x63a64840,0x43952b79}},	//   _еден_, frán_, fikn, ванс,
   {{0x442c4841,0xaca40174,0xf1bf4842,0x9f97023b}},	//   rud_, _apịr, grán_, rçë_,
   {{0x321900fc,0x442c4843,0xb33b0072,0xdb9b00ca}},	//   ussy_, sud_, siço, לסטר,
   {{0x442c4844,0xf1bf4845,0x63a601cb,0x25a5009c}},	//   pud_, arán_, aikn, cill_,
   {{0xc4f707a6,0xf1bf4846,0xd48f1087,0x1048004d}},	//   _אזוי_, brán_, _ср_, няти_,
   {{0x6e2d4847,0x394e0d87,0x00000000,0x00000000}},	//   tuab, hefs_, --, --,
   {{0x28a72171,0xb1840094,0x3f8900c6,0x8d87007b}},	// [3eb0] _केनि, šťav, rkau_, нужд,
   {{0x224902e6,0x3f894848,0x6e2d0634,0xfd100037}},	//   _ipak_, skau_, ruab, مجم_,
   {{0x6f16025c,0x785300a7,0x00000000,0x00000000}},	//   bayc, _təvə, --, --,
   {{0xa3c30abe,0x28c400a5,0x20010201,0x501a00ca}},	//   ्ति_, _लुधि, _ithi_, _קורו,
   {{0x2fd900ec,0x4174001c,0x5edf0033,0x6e2d00fc}},	//   _ihsg_, _شایس, _ফ্রে, quab,
   {{0x7dcb00aa,0x63a60063,0xf2d4006e,0x00000000}},	//   küsi, zikn, נעס_, --,
   {{0xa3c307ad,0x62861671,0x25a51305,0xf4ff0139}},	//   ्ता_, zyko, vill_, _dẹlé_,
   {{0x9ff300c7,0xf7711823,0x22494849,0x7afb484a}},	//   _জবাব_, شاب_, _opak_, _ufut,
   {{0x25a51df0,0xe80d0ed3,0x63a6005f,0x995500d3}},	//   till_, _सबका_, vikn, _икац,
   {{0xb46500d6,0x62863e67,0x88e30033,0x2001019f}},	//   вкол, vyko, নুষক, _othi_,
   {{0x63a6113a,0x2001022e,0x2249484b,0x47352105}},	//   tikn, _nthi_, _apak_, _анес,
   {{0x62862f29,0x03a6484c,0xf8ae0113,0x25a5484d}},	//   tyko, тимо, _بکه_, sill_,
   {{0x63a6063f,0x25a5484e,0xf7700781,0x20010201}},	//   rikn, pill_, _دال_, _athi_,
   {{0x412a02ec,0x63a64685,0x6286484f,0x661b101e}},	//   ього_, sikn, ryko, msuk,
   {{0xed5200cd,0x2121037a,0x69c34850,0x62862e7f}},	//   یپر_, _ddhh_, ione, syko,
   {{0x62661278,0xe4e400d6,0x7e690433,0x3e52022b}},	//   _авиа, _січн, _šepa, _pņt_,
   {{0x69c34851,0x63a44852,0xee3a0a18,0x661b0060}},	// [3ec0] kone, _imin, ьна_, nsuk,
   {{0x69c302ec,0xdb000257,0x6e22007e,0x91e61e46}},	//   jone, _immé, šobo, _шопе,
   {{0x69c34853,0xad9b0139,0xa7fc0342,0x7dd002c3}},	//   done, _awús, _arın, säso,
   {{0x09ca09c4,0x661b31e8,0xa3d20c9c,0xf1bf00b6}},	//   ित्य, ksuk, वति_, hrál_,
   {{0x69c317d2,0xaefb009c,0x63a44854,0x661b0113}},	//   fone, _cnùu, _mmin, jsuk,
   {{0x3990009c,0x661b4855,0x00000000,0x00000000}},	//   _bàsa_, dsuk, --, --,
   {{0xa3d210e9,0x6da3251c,0x6d5c03e9,0x63a44856}},	//   वता_, _тира, _iara, _omin,
   {{0x368a0231,0x3d0a009d,0x63a400f9,0x7c3e0364}},	//   дсон_, िरके_, _nmin, mtpr,
   {{0x6d5c4857,0x69c34858,0x661b0fa0,0x3c3c0e4b}},	//   _kara, bone, gsuk, lív_,
   {{0x63a44859,0x69c3485a,0xe7ed02d5,0x55740cba}},	//   _amin, cone, _चूका_, угот,
   {{0x92af1348,0x6d5c0d18,0x7c3e485b,0x63a40063}},	//   _করে_, _mara, ntpr, _bmin,
   {{0x6d5c485c,0x22490063,0x69dd0036,0x661b0113}},	//   _lara, _ppak_, _èser, bsuk,
   {{0x6722485d,0x2bb30336,0x00000000,0x00000000}},	//   _idoj, ंचता, --, --,
   {{0x63a4485e,0x66020d79,0x7c3e0b84,0xf48431bb}},	//   _emin, _itok, ktpr, _مابی,
   {{0x25ab0257,0xdb1b00de,0xa5bd00c6,0xdb00014b}},	//   ècle_, _khuô, krųj, _emmé,
   {{0x69c3485f,0x6d5c0256,0x63a400a5,0x7e660113}},	//   zone, _aara, _gmin, _brkp,
   {{0x69c34860,0x93b800ca,0x6d5e029a,0x28c40285}},	// [3ed0] yone, _שלחו_, fdpa, _लुसि,
   {{0x63a44861,0xad9b0065,0x5c070f5f,0x7c3e01ce}},	//   _zmin, _awúr, вяда, ftpr,
   {{0x6d5c4862,0x20010060,0x7d170188,0x2619148e}},	//   _dara, _uthi_, raxs, _मौनी_,
   {{0x69c304ee,0x66023088,0xff043ff1,0x6d5c1ab6}},	//   wone, _otok, _вярн, _eara,
   {{0x6d5c4863,0x69da0b14,0xa3ab2f74,0x66024864}},	//   _fara, _bhte, _गगन_, _ntok,
   {{0x6d5c202c,0x64584865,0x644a02b6,0x7cf90032}},	//   _gara, _osvi, _opfi, _dúró,
   {{0x66024866,0x7c3e029a,0xe5fc0174,0x6ce4004d}},	//   _atok, ctpr, _rịịs, _віте,
   {{0xdb1b00de,0x69da00aa,0x69c30cd6,0x00000000}},	//   _chuô, _ehte, sone, --,
   {{0x6d5c4867,0x7f5d4868,0x644a4869,0x661b0270}},	//   _yara, _masq, _apfi, usuk,
   {{0x6d5c486a,0x63a4486b,0x69da097c,0xdb0b0076}},	//   _xara, _smin, _पीपी, ingí,
   {{0xc9840095,0x6b800372,0x661b486c,0x660207f5}},	//   _тути, _yomg, ssuk, _etok,
   {{0x7f5d00ee,0x7981486d,0x661b0e22,0xdcfc02a1}},	//   _nasq, _holw, psuk, _porċ,
   {{0x6d47460e,0x69da0d64,0x02de0034,0x15452c95}},	//   _obja, _yhte, नेंभ, _белм,
   {{0xf65200ca,0x00000000,0x00000000,0x00000000}},	//   _לצד_, --, --, --,
   {{0x7c3e486e,0xb18400b6,0x201e01f9,0x7f5d17bb}},	//   xtpr, šťov, éti_, _basq,
   {{0x6d47486f,0x63a44870,0x7f5d0257,0xd138007f}},	//   _abja, _umin, _casq, żą_,
   {{0x29c90314,0x0e66013f,0x7d154871,0x7981010a}},	// [3ee0] núas_, ыкан, _bezs, _oolw,
   {{0x6d5c4872,0x3c3c4873,0x7bc90154,0x79814874}},	//   _qara, tív_, _akeu, _nolw,
   {{0x6d5c4875,0x31570130,0x0c264876,0x7f5d002b}},	//   _vara, _גיין_, умен, _fasq,
   {{0x69da074a,0x6d5c4877,0xeb970acf,0x2f5600d6}},	//   _shte, _wara, лих_, _стос,
   {{0x6d5c4878,0x7bdb008a,0x79814879,0xab3100a7}},	//   _tara, _dhuu, _bolw, zıçı_,
   {{0x1db8110f,0xdd92487a,0x6d5c487b,0x443e487c}},	//   _आदित, _اوس_, _uara, ytt_,
   {{0x3f82487d,0x6b800b97,0x764b00c6,0x79811a6e}},	//   _koku_, _tomg, _apgy, _dolw,
   {{0x3f8202fd,0xf09300ca,0xdcfc0094,0x00000000}},	//   _joku_, מנו_, _morč, --,
   {{0x09360602,0xaab80eeb,0xa91c0220,0x853c0138}},	//   _مراج, _अशिक, _voľb, siėm,
   {{0xa2a509c3,0x79814494,0xaa9300e3,0x3f82487e}},	//   _चेष्, _golw, _الكث, _loku_,
   {{0x94d4487f,0x7e644880,0xdb1b00fe,0xdcfc0117}},	//   ронц, hvip, _thuô, _norč,
   {{0xdb0901e5,0xd4970a29,0x3f8207f5,0x7dcb4881}},	//   _vjeç, урь_, _noku_, lüst,
   {{0x66024882,0x7f5d00ee,0x395e058f,0x00000000}},	//   _utok, _rasq, _kats_, --,
   {{0xdcfc0d12,0xad9b0065,0x365b00ca,0xba000174}},	//   _borč, _atún, _נכונ, _ọọ_,
   {{0x6ab04883,0x7f5d4884,0x7d150103,0x3990009c}},	//   जपुर, _pasq, _rezs, _làso_,
   {{0x29c90102,0x998600b6,0x395e4885,0xe1f00e27}},	//   núar_, spoň_, _lats_, _کسي_,
   {{0xaaa43b08,0x61f62f1b,0x3f824886,0x7f5d24f9}},	// [3ef0] _खेलक, _guyl, _doku_, _vasq,
   {{0x442c01aa,0x7bc90313,0x7bdb4887,0x7dd002c3}},	//   ord_, _skeu, _shuu, näsh,
   {{0x7f5d05fe,0xdcfc0128,0x3f8201ff,0x7dcb0233}},	//   _tasq, _gorč, _foku_, düst,
   {{0xc8ff0789,0x442c152f,0x7981063d,0x6ab000bc}},	//   ॉर्म_, ird_, _solw, जपूर,
   {{0x6f0d383f,0xee871ad1,0xfe3500c1,0x79811d13}},	//   mbac, _сыно, _דאָך_, _polw,
   {{0x6f0d4888,0x940a00a7,0x395e00d7,0x6d47063d}},	//   lbac, şmək_, _cats_, _ubja,
   {{0x79810305,0x6f0d1e03,0x7bdb0167,0x201e007e}},	//   _volw, obac, _thuu, štiv_,
   {{0x2d8300c9,0x6f0d4889,0xf6250a51,0x7981488a}},	//   _hoje_, nbac, адио, _wolw,
   {{0x2d8303ce,0xe6161736,0x442c15b9,0xbb8400e3}},	//   _koje_, ады_, erd_, _القي,
   {{0x6f0d488b,0x2b5f023e,0x395e0428,0x7dd0347e}},	//   hbac, _hauc_, _gats_, väsk,
   {{0x04453e04,0xa3c300ec,0x7dcb01bf,0x645e488c}},	//   шенн, ्तं_, lüss, _špir,
   {{0x6266008d,0x2d83488d,0x6e2d488e,0xf1bf488f}},	//   авма, _loje_, krab, brák_,
   {{0x3f8212fb,0x442c4890,0x69da0f35,0xdcfc05db}},	//   _roku_, ard_, _पीडी, _sorč,
   {{0xdcfe00d9,0x48dc000d,0x6e2d4891,0xdcfc00e7}},	//   āvīg, गेको_, drab, _porč,
   {{0x6f0d4892,0x0cb000c7,0xc0e60a67,0x7dcb0364}},	//   fbac, _কর্ত, ровк, hüss,
   {{0xa3c3231e,0x64414893,0x28da0034,0x7e6400e7}},	//   ्तः_, mtli, येटि, tvip,
   {{0x2d8302e6,0x644101bf,0x66094894,0x0ee002d5}},	// [3f00] _boje_, ltli, npek, पेंड,
   {{0xd24f001c,0x27ef4895,0x64410313,0xe3b90233}},	//   _کنی_, _lign_, otli, brıs_,
   {{0x64414896,0x3f824897,0x6f0d0044,0xed570c06}},	//   ntli, _toku_, bbac, рох_,
   {{0xdb0b0161,0x64414898,0xab2a0399,0x395e0b97}},	//   ligê, itli, тода_, _sats_,
   {{0x395e282c,0x2360023e,0x644131da,0x2d83004b}},	//   _pats_, _maij_, htli, _foje_,
   {{0x64414899,0x236001fa,0x442c489a,0x2d83489b}},	//   ktli, _laij_, yrd_, _goje_,
   {{0x7dcb4303,0x6609489c,0x5b3600d3,0x98a5173c}},	//   rüst, epek, _вэзу, _balı_,
   {{0xf1bf19a3,0x2360023e,0x7dcb007a,0xddc4007f}},	//   nuár_, _naij_, süst, ywiś,
   {{0xd6d7489d,0x6441489e,0x00000000,0x00000000}},	//   ить_, etli, --, --,
   {{0x64411a02,0x80f514e5,0x6f0d0106,0x356a489f}},	//   ftli, _आलेख_, zbac, трин_,
   {{0x442c0126,0x291c0db4,0x6f0d48a0,0x660906a8}},	//   urd_, mava_, ybac, apek,
   {{0x291c48a1,0x236001bb,0x00000000,0x00000000}},	//   lava_, _caij_, --, --,
   {{0x9f4202fd,0x48fd000d,0xda1900a5,0xf1bf0103}},	//   _mikä_, रुको_, नीपत_, nság_,
   {{0x6e2d48a2,0x98a500a7,0x442c00d8,0x00000000}},	//   vrab, _zalı_, prd_, --,
   {{0x64410381,0x1fa736bf,0x2d8348a3,0xddcd007f}},	//   ctli, араг, _roje_, ywał,
   {{0x6e2d12f5,0xcf9815de,0x291c48a4,0xa3d20af1}},	//   trab, ају_, hava_, वतः_,
   {{0x2d830117,0x74d80033,0x00000000,0x00000000}},	// [3f10] _poje_, _সলিউ, --, --,
   {{0x6e2d48a5,0x6f0d48a6,0xf1bf0103,0x2b5f01d3}},	//   rrab, sbac, dság_, _sauc_,
   {{0x201e00b6,0x00000000,0x00000000,0x00000000}},	//   átit_, --, --, --,
   {{0x6e2d2f07,0xdea100cd,0x236001fa,0x3a752a59}},	//   prab, _فیزی, _xaij_, йлер,
   {{0xeab00190,0x6fc40096,0x644148a7,0x80a4001c}},	//   وعه_, वकरं, ztli, _همین,
   {{0x9f4202fd,0x27ef0054,0x98a5026a,0x21fd00fe}},	//   _eikä_, _sign_, _salı_, _mìh_,
   {{0x7c950080,0x6c850cd2,0x644148a8,0xdb0b02c3}},	//   _الأص, _الزم, xtli, dogö,
   {{0x5ba40978,0xd5e20139,0x9f970428,0x00000000}},	//   _друз, _arò, nçà_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x291c48a9,0x660948aa,0x660d0233,0x644132e8}},	//   cava_, rpek, _çakm, ttli,
   {{0x74ca0469,0x845800e5,0x64414304,0x00000000}},	//   _सुदृ, арят_, utli, --,
   {{0x644148ab,0x236001fa,0xad9b0088,0xdcfc01d3}},	//   rtli, _qaij_, _stúl, _morā,
   {{0x66050848,0xad9b026e,0x16210966,0x7dd80174}},	//   _упла, _atúm, _मिटर_, ụsir,
   {{0x637f01e5,0x9103008f,0x00000000,0x00000000}},	//   _mëny, зпре, --, --,
   {{0xdcfc0029,0x236001fa,0xf1bf01f9,0x00000000}},	//   _norā, _taij_, zság_, --,
   {{0xd00f0f43,0x291c2024,0xe3b903e0,0x4fa3008f}},	//   علق_, zava_, lsın_, писв,
   {{0xa3bd0251,0xdd8f0260,0xea0000de,0xdee32cf5}},	// [3f20] _आदत_, کول_, _đắm_, зоти,
   {{0x201e2710,0x291c1f32,0x627b006e,0x6e2b06f0}},	//   átis_, xava_, _ענינ, ágba,
   {{0x291c038f,0x2619009f,0xbddb05aa,0x0fda001c}},	//   vava_, _मौसी_, _apès, _مبحث_,
   {{0xf3f900c7,0x201e013f,0xf1bf01f9,0x00000000}},	//   _আবার_, štis_, tság_, --,
   {{0xe3b90e63,0xc6b20033,0x00000000,0x00000000}},	//   ksın_, _চর্চ, --, --,
   {{0x5d860037,0x7d960037,0xfce60e1d,0xf1bf01f9}},	//   _الآل, _السؤ, _гого, rság_,
   {{0xf1bf0018,0xc866008f,0x3ea048ac,0x00000000}},	//   sság_, стли, lzit_, --,
   {{0xbb430084,0x3f920085,0xf76f0604,0xc6f848ad}},	//   _неск, nkyu_, فاً_, шних_,
   {{0xf66a00cd,0xd6d000e3,0xdb0b014b,0x9f970231}},	//   احبه_, بقة_, digè, nçá_,
   {{0x8afd00b6,0x399948ae,0x7d1e48af,0x00000000}},	//   _vaře, _pèse_, naps, --,
   {{0x2ed5000d,0x69ca0a39,0x769e0139,0x07a60215}},	//   _दर्त, mofe, _bàyé, _лажн,
   {{0xc7f700a1,0x69ca48b0,0x7d1e48b1,0x4871001c}},	//   _הזאת_, lofe, haps, _آگوس,
   {{0x7d1e2bc3,0x2bc917ad,0xf6d648b2,0x00000000}},	//   kaps, िकता, _ازاد, --,
   {{0x69ca48b3,0x645c48b4,0x00000000,0x00000000}},	//   nofe, æris, --, --,
   {{0x251b0266,0xbddb020d,0x00000000,0x00000000}},	//   _גווא, _opèr, --, --,
   {{0xa3bd00af,0x398b13b9,0xd5b801d3,0x69ca48b5}},	//   _आदि_, _høst_, lnā_, hofe,
   {{0x63af211b,0x88bc030b,0x9f9700ee,0x00000000}},	// [3f30] micn, _sděl, rçà_, --,
   {{0xa3dd04a9,0x63af03ce,0x628f03a9,0x753a48b6}},	//   _तीत_, licn, myco, ngtz,
   {{0xa91c0220,0xdb0b48b7,0xc8a7148e,0xbddb01dc}},	//   _poľn, ligé, _केंट, _spès,
   {{0x63af0ca7,0x2d9802ef,0x93bd00d3,0x398b13c8}},	//   nicn, _elre_, crăt, _løst_,
   {{0x7f3a0130,0xa91c0181,0x0e0800ae,0x784a00a7}},	//   _דערו, _voľn, _гэси_, _rəva,
   {{0xa96917de,0x69ca48b8,0xbddb00b3,0x63af05db}},	//   рика_, gofe, _epèr, hicn,
   {{0x88bc030b,0xab95004d,0x00000000,0x00000000}},	//   _uděl, _диві, --, --,
   {{0x6d5748b9,0x91f90789,0xd5b801d3,0x77620113}},	//   lexa, ंदाज_, enā_, _caox,
   {{0x7bcb02e6,0x69ca016d,0x3b7800ae,0x2b4d033c}},	//   mogu, bofe, _уйтэ_, _ibec_,
   {{0x7bcb48ba,0xdb0b48bb,0x6d5713a9,0x05a900c2}},	//   logu, digé, nexa, рвой_,
   {{0xe3ba0084,0x320948bc,0x7dd0347e,0xe3b9008b}},	//   ибо_, _atay_, mäst, rsın_,
   {{0x3ce10d1b,0x6d570188,0x42ea48bd,0x77620090}},	//   _करने_, hexa, имно_, _gaox,
   {{0x63bd037a,0xdb0b014b,0x00000000,0x00000000}},	//   érna, rigè, --, --,
   {{0x7dd048be,0x6d570381,0x00000000,0x00000000}},	//   näst, jexa, --, --,
   {{0x7bcb007a,0x6d5748bf,0x2b4d0579,0x63af0335}},	//   kogu, dexa, _obec_, bicn,
   {{0x673b0094,0x656348c0,0x69ca0d6a,0x64430090}},	//   nguj, _hanh, zofe, _iqni,
   {{0x7bcb48c1,0x2a6d01fa,0x656301af,0x3f9900f9}},	// [3f40] dogu, _nreb_, _kanh, _dlsu_,
   {{0x65630022,0x5bd21d96,0x3ea0023b,0x00000000}},	//   _janh, तत्व, rzit_, --,
   {{0x7bcb48c2,0x7d1e48c3,0x656348c4,0x6f1f013c}},	//   fogu, raps, _manh, baqc,
   {{0x290548c5,0xa91c0220,0x656348c6,0xe800007f}},	//   _afla_, _poľo, _lanh, _लंबा_,
   {{0x6f040a39,0x7dd00212,0x6563020b,0xdcfc078e}},	//   mcic, fäst, _oanh, _coră,
   {{0x082a48c7,0x63af14f3,0xf8061a29,0x291a48c8}},	//   ации_, zicn, очин, úpa_,
   {{0x69ca3e35,0x7bcb0065,0x23ca1c83,0x7d1c1570}},	//   rofe, bogu, रवाद, _iers,
   {{0x7d1c1158,0x656301a2,0x69ca0aab,0x7e6900c4}},	//   _hers, _aanh, sofe, _šepi,
   {{0x7d1c48c9,0x65630396,0x63af0e94,0x2a6d02b6}},	//   _kers, _banh, vicn, _greb_,
   {{0x48e64163,0x7dd048ca,0x656348cb,0x7d1c48cc}},	//   _дозв, mäss, _canh, _jers,
   {{0x2cfb193b,0x63af00cc,0x7d1c48cd,0x7dd048ce}},	//   יליא, ticn, _mers, läss,
   {{0x6b8248cf,0x6f0401ac,0xf1bf030b,0x00000000}},	//   njog, jcic, hrát_, --,
   {{0x7988067d,0xf1bf0363,0x7d1c0b8e,0x3e4e00e8}},	//   _kodw, krát_, _oers, nētā_,
   {{0x656300c9,0x628f48d0,0x63af08a9,0xc87e0092}},	//   _ganh, ryco, sicn, şğul_,
   {{0x34941894,0x63af00cc,0x26000139,0x7bcb1801}},	//   _хайр, picn, _hòo_, yogu,
   {{0x672048d1,0x7d1c48d2,0x798848d3,0x23280284}},	//   namj, _aers, _lodw, _доћи_,
   {{0x7d1c48d4,0x63ad48d5,0x59ca0213,0x6d5748d6}},	// [3f50] _bers, _iman, ाकार, texa,
   {{0x7d1c48d7,0x93bd00d3,0x79880150,0x69da0034}},	//   _cers, crăr, _nodw, _पीली,
   {{0x6d5748d8,0x7d1c48d9,0x7dd00084,0x7bcb48da}},	//   rexa, _ders, väst, togu,
   {{0x7d1c1db2,0x6d5748db,0x6f040451,0x6d4e0283}},	//   _eers, sexa, ccic, _ebba,
   {{0x7d1c48dc,0x63ad48dd,0xea000019,0x79880415}},	//   _fers, _mman, _đảm_, _bodw,
   {{0xa3dd143d,0x7d1c48de,0x8dfa00a1,0x4e1600a1}},	//   _तीस_, _gers, _להשת, _מחשב_,
   {{0x63ad48df,0x78570159,0x7bcb48e0,0x319c00ca}},	//   _oman, تیاز_, pogu, שבונ,
   {{0x65630bb6,0x2a6d0baa,0xe61902e1,0x7d1c01bf}},	//   _sanh, _treb_, бди_, _zers,
   {{0x65630009,0x6f1d48e1,0x39640084,0x7d1c48e2}},	//   _panh, _mesc, össä_, _yers,
   {{0x63ad01a4,0x6f1d48e3,0x798848e4,0x6b890abf}},	//   _aman, _lesc, _godw, _hoeg,
   {{0x656302fd,0x5fbd3245,0x8afd00b6,0xb8d00033}},	//   _vanh, ्काल, _zařa, _টু_,
   {{0x6f1d48e5,0x8c490367,0x739a0cfc,0x6b8901d0}},	//   _nesc, maşı, стос_, _joeg,
   {{0x8c4903a3,0x63ad48e6,0x6b8948e7,0xc7b20796}},	//   laşı, _dman, _moeg, _אבא_,
   {{0x63ad48e8,0xf1bf48e9,0x64a548ea,0x6b9b1066}},	//   _eman, drás_, _нала, _llug,
   {{0x6f1d48eb,0x251a040a,0x6b9b48ec,0x6aa2028d}},	//   _besc, _הוצא, _olug, zzof,
   {{0x63ad48ed,0x6e2405bd,0x7d1c48ee,0x9f5a05f1}},	//   _gman, tsib, _sers, _kupé_,
   {{0x6f1d22d3,0x59cb000c,0x6e2448ef,0x88d10081}},	// [3f60] _desc, िवार, usib, াধিক,
   {{0x7d1c00dd,0x6b9b48f0,0x63ad02dd,0x752148f1}},	//   _qers, _alug, _zman, nalz,
   {{0x7d1c0cac,0x1b0d00c7,0x3ce1009d,0xa3c3009d}},	//   _vers, _হয়ে_, _करणे_, ्तच_,
   {{0x6f1d12c1,0x8c490b88,0x7d1c00a5,0xfbd20e25}},	//   _gesc, daşı, _wers, رتا_,
   {{0x7d1c1268,0x798800a5,0x298a40fc,0x98be00c6}},	//   _ters, _podw, йско_, _patį_,
   {{0x6f1d00cc,0xf1be0179,0x7dd000c2,0x442700f2}},	//   _zesc, ोविन, räss, _ovn_,
   {{0x6b9b48f2,0x2d8a0072,0x7dd048f3,0x307a006e}},	//   _flug, _iobe_, säss, מאַנ,
   {{0x3ce10d1b,0xa91c0220,0x6b9b0088,0x2d8a01e9}},	//   _करते_, _koľk, _glug, _hobe_,
   {{0xfaa30e3a,0x98b100d9,0x442748f4,0x7bc0029a}},	//   _зато, ībām_, _avn_, _ijmu,
   {{0x63ad00e9,0xf64f2204,0x2d8a019f,0x752148f5}},	//   _sman, ائي_, _jobe_, galz,
   {{0xdcfc0034,0x6720023b,0x66190139,0xbebb0f5a}},	//   _gorą, pamj, _ewwk, _teëg,
   {{0x69d84313,0x291e0212,0x57fb00ca,0x63ad0113}},	//   llve, _heta_, _הלאו, _qman,
   {{0x291e48f6,0x27070019,0x442748f7,0x6f1d34d2}},	//   _keta_, _ống_, _evn_, _resc,
   {{0x291e00dd,0x752100d3,0xa3dd0251,0xdb000088}},	//   _jeta_, calz, _तीर_, _ummæ,
   {{0x291e48f8,0xdfd50ab3,0xd7b000a4,0x44f70103}},	//   _meta_, довы, _जगाच, _عروج_,
   {{0x291e48f9,0x63ad48fa,0xf1bf0fb6,0xc43b00ca}},	//   _leta_, _uman, trás_, _התהי,
   {{0x6f1d48fb,0xddd000b6,0x7d0548fc,0x201a0154}},	// [3f70] _vesc, _řeši, tchs, _ewpi_,
   {{0xf1bf48fd,0x7d0501bf,0x6b8900d1,0xa2b800d7}},	//   rrás_, uchs, _soeg, _מפחד_,
   {{0x7d0502e2,0x6f1d269f,0x2d8a48fe,0x6b9b48ff}},	//   rchs, _tesc, _dobe_, _plug,
   {{0xfc3000b1,0x291e00f9,0x69d84900,0x7d054901}},	//   احل_, _aeta_, elve, schs,
   {{0x6b890126,0x6e220106,0x957c0138,0x6b9b4902}},	//   _voeg, šobr, rmąj, _vlug,
   {{0xac194087,0x3f8b04a3,0x2d8a4903,0x64484904}},	//   _могу_, _hocu_, _gobe_, ktdi,
   {{0x6b891db2,0xb905074c,0x291e4905,0x246c00b6}},	//   _toeg, _नर_, _deta_, _něm_,
   {{0x06094906,0xefc800de,0x8c490491,0x2d8a4907}},	//   оник_, _địch_, raşı, _zobe_,
   {{0x291e4908,0x2d8a0044,0x7afb4909,0xb659004d}},	//   _feta_, _yobe_, _igut, іших_,
   {{0x291e0102,0x1dbf4660,0x442701d3,0xbebb0313}},	//   _geta_, ्वित, _pvn_, _geëe,
   {{0xb8081857,0xf8e10557,0x7e6d4880,0x00000000}},	//   _فيلم_, _फरिय, hvap, --,
   {{0x7e6d025b,0x61c61c83,0xb60503f1,0x3f8b0542}},	//   kvap, लक्ष, _pešč, _nocu_,
   {{0x1dbf490a,0x61ff0090,0x21e40364,0x4425042c}},	//   ्वात, _cuql, höhe_, ssl_,
   {{0xb605033b,0x4427490b,0x776902c3,0x00000000}},	//   _vešč, _tvn_, ldex, --,
   {{0xa067490c,0xdb000084,0x644800bd,0x3f8b00cb}},	//   мара_, _ymmä, ctdi, _bocu_,
   {{0xafe3490d,0x200c01d3,0x3f8b490e,0xb6050141}},	//   восл, īdi_, _cocu_, _tešč,
   {{0xa1c629ab,0x200c0144,0x69d80120,0x9f4000b3}},	// [3f80] _обид, ūdi_, ylve, rmià_,
   {{0xa2ad009d,0x225700cd,0xee3700d6,0x7afb490f}},	//   ीपर्, _کلید_, ьну_, _agut,
   {{0x291e4910,0x0b464911,0x013500c1,0x1d19004d}},	//   _reta_, днен, _אָרט_, яють_,
   {{0x291e4912,0x3ebf0106,0x69c1007e,0xa91c0031}},	//   _seta_, _žute_, _ajle, _toľk,
   {{0x291e0496,0x2d8a4913,0x7769008a,0x656800f0}},	//   _peta_, _tobe_, ddex, yddh,
   {{0x7afb01e9,0x67c101d3,0x291e0216,0x13bb18ff}},	//   _egut, vēja, _qeta_, _उद्भ,
   {{0x291e4914,0xf54e0019,0xeb9a4915,0xfc030859}},	//   _veta_, _bụng_, _див_, _апсо,
   {{0x291e0294,0x33200428,0x3a260eac,0x6f160150}},	//   _weta_, _neix_, psop_, nbyc,
   {{0xf54e00ef,0x2b4400e7,0x00000000,0x00000000}},	//   _dụng_, _icmc_, --, --,
   {{0x2a640baa,0xdcfc0d62,0x67c101d3,0x6e3600c6}},	//   _ismb_, _dorć, rēja, iryb,
   {{0x332000b3,0x53ca00aa,0x2b44024a,0x98ac0233}},	//   _beix_, रवंश, _kcmc_, _tadı_,
   {{0x64484916,0x67c101d3,0x6e360034,0x9f4c01dc}},	//   rtdi, pēja, kryb, _èlèk_,
   {{0x64484917,0x332000b3,0x61f74918,0x46e21358}},	//   stdi, _deix_, _pixl, _परिह,
   {{0x246c02c6,0x00000000,0x00000000,0x00000000}},	//   _těm_, --, --, --,
   {{0x8557040a,0x104800c2,0x332000ee,0x1dbf0213}},	//   _חשוב_, мяти_, _feix_, ्वसत,
   {{0x27e60123,0x7e6d07ee,0xa3e6023a,0x00000000}},	//   _jhon_, tvap, _बीप_, --,
   {{0x7f4d00dd,0x27e60085,0x3f8b00c4,0x93bd020a}},	// [3f90] rfaq, _mhon_, _vocu_, nsăm,
   {{0xaad20251,0xdb0b034f,0x7e6d0302,0x5dd507e8}},	//   _तड़क, rigí, rvap, رقائ,
   {{0x27e6019c,0xdb0b020a,0x7e6d389d,0x00000000}},	//   _ohon_, vigâ, svap, --,
   {{0x2b44002b,0x332000b3,0x27e600fe,0x00000000}},	//   _ccmc_, _xeix_, _nhon_, --,
   {{0xf54e0023,0xd52b0139,0xdfd10d7f,0x00000000}},	//   _rụng_, _jọ̀w, _ليگ_, --,
   {{0xa3e60ccb,0x68454919,0x2b440167,0x2bb800e7}},	//   _बीन_, енка, _ecmc_, dčcu_,
   {{0x27e60013,0x200100aa,0x00000000,0x00000000}},	//   _bhon_, _juhi_, --, --,
   {{0xd0f809c1,0x7afb491a,0x2001491b,0x27e6491c}},	//   ומות_, _ugut, _muhi_, _chon_,
   {{0xb8d6009d,0xea0000de,0xf54e0023,0x394901c2}},	//   _चे_, _đầm_, _vụng_, ƙas_,
   {{0x21210167,0x8938491d,0x27e6009c,0x7649491e}},	//   _nehh_, _опус_, _ehon_, rtey,
   {{0x332005fe,0x7649491f,0xf54e0023,0x6f1602c6}},	//   _peix_, stey, _tụng_, ybyc,
   {{0xf1bf0072,0x6e3600c6,0xdb0b00ee,0x00000000}},	//   usán_, yryb, nigà, --,
   {{0x27ed4920,0xbb3a006e,0xd7cc0096,0x67c100e8}},	//   mmen_, הערי, ावरच, lējo,
   {{0x20010009,0x74ca0285,0x00000000,0x00000000}},	//   _buhi_, _सुकृ, --, --,
   {{0xddc40335,0x21210085,0x05740281,0x332000b3}},	//   jviš, _dehh_, _جاند, _teix_,
   {{0x27ed14b1,0x21210167,0xbebb0052,0x273a0367}},	//   nmen_, _eehh_, _ndës, münü_,
   {{0xee3a3d00,0x27ed4921,0xbea3107a,0x273a2ddc}},	// [3fa0] яна_, imen_, гатк, lünü_,
   {{0x27ed02dc,0x6e361df6,0x5d674922,0x67c100e8}},	//   hmen_, rryb, ниум_, kējo,
   {{0x2369023e,0x273a03e0,0x27ed4923,0x88bc00d2}},	//   _yaaj_, nünü_, kmen_, _jdět,
   {{0x27ed4924,0x67c101d3,0xa3e60285,0x6e36004b}},	//   jmen_, dējo, _बीम_, pryb,
   {{0xfeba0dd0,0x27ed02db,0xc3330289,0x00000000}},	//   _راحت_, dmen_, רוד_, --,
   {{0x27e60a02,0x27ed4925,0x7db60037,0x200105bd}},	//   _shon_, emen_, _أصحا, _yuhi_,
   {{0xfce31bec,0x27e60036,0x395c4926,0xa3e0097c}},	//   _боро, _phon_, revs_, थता_,
   {{0x2fc04927,0x6d5e4928,0x7c3e00e7,0x00000000}},	//   nnig_, lepa, mupr, --,
   {{0x7c3e0074,0x2fc04929,0xe60f1ac9,0x00000000}},	//   lupr, inig_, یشی_, --,
   {{0x6d5e492a,0x9f4000c2,0x2fc000f0,0xbd050139}},	//   nepa, lmiä_, hnig_, _ibéè,
   {{0xd6da0068,0xd4970012,0x27e6492b,0x7c3e01d3}},	//   _کوشش_, еря_, _thon_, nupr,
   {{0x2001492c,0x27e60009,0x6d5e492d,0xb6a62a72}},	//   _ruhi_, _uhon_, hepa, _пиел,
   {{0x20012af0,0xddc40357,0x00000000,0x00000000}},	//   _suhi_, zviš, --, --,
   {{0x6d5e053f,0x7c3e492e,0x660f0031,0x1a9b006e}},	//   jepa, kupr, ícke, ליכע,
   {{0xbebb074a,0x6d5e492f,0x6602007b,0x273a071d}},	//   _ndër, depa, _huok, cünü_,
   {{0x443e4930,0x987b0130,0x66024931,0xb2754932}},	//   mut_, האלט, _kuok, _алиш,
   {{0x443e4933,0x66021736,0x69b10034,0x9df9261f}},	// [3fb0] lut_, _juok, _अगली, днат_,
   {{0x443e01af,0x6d5e08c8,0x66020084,0xad9b0032}},	//   out_, gepa, _muok, _atúr,
   {{0x443e4934,0x66020084,0xbd050139,0x656a1d49}},	//   nut_, _luok, _abéè, _mafh,
   {{0xdab90037,0xddc40b18,0x290c02a1,0x67c101d3}},	//   وهات_, rviš, _afda_, vējo,
   {{0x443e4935,0xa9690cf5,0xa3c404f8,0xd9454936}},	//   hut_, дила_, ्वत_, вели,
   {{0x443e4937,0x20d5007d,0x6d5e4938,0xade51e93}},	//   kut_, _धडाध, cepa, _कठिन_,
   {{0x443e3cb8,0x6d55023e,0x27ed36c6,0x1866013d}},	//   jut_, _ibza, tmen_, ващи_,
   {{0x3f894939,0xd7ee0037,0x8b0401c2,0x67c101d3}},	//   njau_, يكو_, ƙƙab, rējo,
   {{0x64581dfc,0x3ea9493a,0x9f5e020d,0x67c100e8}},	//   _apvi, nzat_, êté_, sējo,
   {{0xa8a70b36,0xd5a30281,0x3ea9020a,0x273a020e}},	//   _прек, الدی, izat_, tünü_,
   {{0x443e493b,0x03a6493c,0x98170037,0x00000000}},	//   gut_, вино, _أبطا, --,
   {{0x672203a9,0x6d5e141c,0x273a020e,0x888a0142}},	//   _geoj, zepa, rünü_, _קרײַ,
   {{0xa2d509a1,0x3ea9023b,0x6d5e0dbe,0x273a0555}},	//   _युद्, jzat_, yepa, sünü_,
   {{0x784a0092,0x91e62bcf,0x67e5007f,0x3ea9448e}},	//   _səvi, тоге, bójc, dzat_,
   {{0x443e0012,0x67220096,0x64a5198a,0x61ee023b}},	//   cut_, _yeoj, _шака, rmbl,
   {{0x3ebf01ac,0xa0670396,0xbfc3493d,0xdee61f46}},	//   _žuta_, њата_, абск, воби,
   {{0x7523493e,0x2fc00102,0x6d5e493f,0xa7fc0740}},	// [3fc0] _kenz, rnig_, tepa, _asıl,
   {{0xdb0b19a3,0x2fcd011d,0xa3e60251,0x7c3e4940}},	//   vigá, čega_, _बीत_, tupr,
   {{0xdd100038,0x81d80081,0x2fc00124,0x9f42022b}},	//   _týžd, িষদ_, pnig_, _dikò_,
   {{0xeb974941,0x75234942,0x99d300cd,0x776b039f}},	//   ких_, _lenz, یتوا, _nagx,
   {{0x443e09fb,0x7c3e4943,0x6722037a,0xbb4311f7}},	//   zut_, supr, _reoj, речк,
   {{0x660202fd,0x7f440257,0x75234944,0x443e4945}},	//   _ruok, lgiq, _nenz, yut_,
   {{0xa3c4063a,0x7d57021e,0x1c3900c2,0x776b0372}},	//   ्वा_, _שילד_, _пять_, _bagx,
   {{0x443e4946,0xf76f0037,0xf09300ca,0x7f440415}},	//   vut_, قاً_, שנה_, ngiq,
   {{0x443e4947,0x9f590154,0x02e11e93,0x66020364}},	//   wut_, _disè_, _नरेन, _quok,
   {{0x660202fd,0x7bc2009c,0x00000000,0x00000000}},	//   _vuok, lnou, --, --,
   {{0x3ea94948,0x356700d3,0xd7ef2657,0x5d3b021e}},	//   zzat_, трын_, _ву_, ותיא,
   {{0x443e0b19,0x040d0019,0x752301c0,0x66020ae3}},	//   rut_, _hưởn, _eenz, _tuok,
   {{0x443e4949,0xe5c61d54,0x3f8f003e,0x161b00aa}},	//   sut_, _иско, ögum_, पीआर_,
   {{0x656a052f,0x7bc200b6,0x7523494a,0x7e6401dc}},	//   _uafh, hnou, _genz, dwip,
   {{0xd48f494b,0x7640083e,0x9f350426,0x7528494c}},	//   _тр_, lumy, леві, madz,
   {{0x3ea9494d,0x7523019f,0xad9b0065,0xadc40af0}},	//   tzat_, _zenz, _atúp, _ibẹr,
   {{0x7c2e0578,0x5d550d5e,0x7bc200b6,0x75230201}},	// [3fd0] _avbr, лкат, dnou, _yenz,
   {{0x3ea918bc,0x260508d4,0x00000000,0x00000000}},	//   rzat_, _हंसी_, --, --,
   {{0x9cb5001c,0x442c01cb,0x3ea90103,0x93bd020a}},	//   دمات, nsd_, szat_, drăz,
   {{0xed510068,0x201301e9,0x7528494e,0x442c494f}},	//   _گھر_, _itxi_, hadz, isd_,
   {{0x6f0d4950,0x75284951,0x199500e5,0x00000000}},	//   mcac, kadz, ладя, --,
   {{0x75280029,0xca7612eb,0xf2d400c1,0x9f594952}},	//   jadz, اموش_, סעס_, _sisè_,
   {{0x75234953,0x442c029a,0x6e2d0877,0x7bc20354}},	//   _renz, jsd_, lsab, bnou,
   {{0x75234954,0x6d454955,0x9f590113,0xdce7033b}},	//   _senz, lgha, _bisé_, _jajč,
   {{0xaab7277c,0x2d9106a3,0x4ab73245,0x7528005c}},	//   _अधिक, _koze_, _अधिव, fadz,
   {{0x6d454956,0x4585470d,0x6e2d4957,0x00000000}},	//   ngha, угов, isab, --,
   {{0x2d9108a9,0x48150c0d,0xfbb70a30,0x2013023e}},	//   _moze_, _смес, _आगाम, _ntxi_,
   {{0x75234958,0xe72e15de,0xf7701487,0x2d91031a}},	//   _wenz, _ће_, _وان_, _loze_,
   {{0x69c3025a,0x75234959,0x442c495a,0x201301ff}},	//   onne, _tenz, asd_, _atxi_,
   {{0x957c0067,0xa06a08a1,0x040d00de,0x6e2d495b}},	//   gląd, нага_, _xưởn, dsab,
   {{0x69c30a21,0x65610396,0xa0a3495c,0x6e2d010a}},	//   inne, melh, бард, esab,
   {{0x6f0d495d,0xad9b0031,0xc31e0033,0xdd110094}},	//   gcac, _stúp, _থাকি_, výši,
   {{0x63a4495e,0x6e2d20c1,0xd9e3009d,0x644f00ae}},	// [3fe0] _ilin, gsab, गतात_, ăciu,
   {{0x5166495f,0x63a4025b,0x7bc24960,0x65614961}},	//   _своб, _hlin, wnou, nelh,
   {{0x6441113a,0xdce70220,0x6f0d0124,0xdb070094}},	//   nuli, _fajč, bcac, _šlág,
   {{0x69c34962,0x2018404c,0x6f0d4963,0xd24f0260}},	//   enne, mpri_, ccac, _بنی_,
   {{0xd00f03ed,0x64414964,0x65614965,0x7bc217bb}},	//   _ولی_, huli, kelh, rnou,
   {{0x64414966,0xe89402fd,0xa3e60490,0x63a44967}},	//   kuli, иаль, _बीस_, _llin,
   {{0x64413121,0x63a44968,0x201806a3,0x52e10be4}},	//   juli, _olin, npri_, _नर्स,
   {{0x75280067,0x96340c58,0x63a40113,0x76403834}},	//   wadz, аниц, _nlin, tumy,
   {{0x2bb10067,0x040d0028,0x75284969,0xa8050143}},	//   jący_, _tưởn, tadz, _peñí,
   {{0x63a4496a,0x6561085e,0x545402b3,0x7640496b}},	//   _alin, gelh, авот, rumy,
   {{0x752800a5,0x69da496c,0x9f5903a9,0x69c801cb}},	//   radz, _ikte, _wisé_, _ijde,
   {{0x63a41173,0xdc9b00a1,0x75283f8a,0x2b4600fe}},	//   _clin, גיטל, sadz, ngoc_,
   {{0xdce7496d,0x877b006e,0x399903a9,0x61fe496e}},	//   _rajč, _ראדי, _sèsi_, _bipl,
   {{0x63a4496f,0x64414970,0x9f4900e3,0x3ebf0995}},	//   _elin, buli, rmaí_, _žuto_,
   {{0x6f0d009c,0x64413ece,0xb97b0130,0x2d914971}},	//   tcac, culi, ענלי, _roze_,
   {{0xa3dd0096,0x3f150077,0x00000000,0x00000000}},	//   _तीच_, рдас, --, --,
   {{0xa3c44972,0x2d914973,0x7f980a61,0xbebb05c2}},	// [3ff0] ्वर_, _poze_, _níqu, _geël,
   {{0x6e2d4974,0x61fe0009,0xbe8f0065,0x6f0d4975}},	//   rsab, _gipl, _aṣáj, scac,
   {{0x6e2d4976,0x2d9100cc,0x2dd800e3,0x6d454977}},	//   ssab, _voze_, ابقة_, rgha,
   {{0x61fe04a6,0x16041362,0x6d450037,0x3a750131}},	//   _zipl, रदार_, sgha, илер,
   {{0x3ce100a5,0x64414978,0x15f60789,0x00000000}},	//   _करके_, zuli, ीदार_, --,
   {{0x69c301ab,0x67c101d3,0x00000000,0x00000000}},	//   unne, mēji, --, --,
   {{0x65614979,0x18a500c6,0x69c3497a,0x67c100e8}},	//   velh, райм, rnne, lēji,
   {{0x6441497b,0x69da004d,0x69c80233,0x00000000}},	//   vuli, _ekte, _ejde, --,
   {{0x64410a15,0xa3d90251,0x2d9c0103,0x7bdb0065}},	//   wuli, ़कन_, öveg_, _ikuu,
   {{0x7ae9497c,0xbebb057a,0x00000000,0x00000000}},	//   _izet, _reël, --, --,
   {{0x63a4497d,0x6561497e,0x61fe01af,0x397a00c1}},	//   _plin, relh, _ripl, _שטענ,
   {{0xe29a497f,0x64414980,0x61fe4981,0x6561165e}},	//   вам_, ruli, _sipl, selh,
   {{0x65614982,0x63a40db1,0x61fe05aa,0x212a0154}},	//   pelh, _vlin, _pipl, tabh_,
   {{0x64414983,0x1a9a0130,0x463a00c1,0x67c101d3}},	//   puli, דישע, _יענע, dēji,
   {{0x7ae900e7,0x1fb63397,0x7bdb06b0,0x63a403a9}},	//   _lzet, асар, _okuu, _tlin,
   {{0x63a44984,0x7ae906a3,0x20184985,0xa2c300b6}},	//   _ulin, _ozet, rpri_, रपश्,

   {{0x201806a3,0x61fe0491,0x8fa3036a,0xa3d30096}},	// [4000] spri_, _tipl, цате, ववर_,
   {{0x637b0084,0x7bdb4986,0x67f50138,0xb33b0233}},	//   _tänä, _akuu, _išju, rkçe,
   {{0x31570130,0xdd8f1e56,0xf53600c1,0xcb6a0114}},	//   _דיין_, بول_, שטער_, каже_,
   {{0x3d163952,0x3ce60006,0xf456006e,0x7981030a}},	//   _प्रे_, _करीं_, ייער_, _anlw,
   {{0x67c100e8,0x7bc900fc,0x00000000,0x00000000}},	//   cēji, _djeu, --, --,
   {{0xb33b00dd,0x7bdb0172,0x2d8c00bc,0xd8760076}},	//   thçk, _ekuu, _õde_, لاعب,
   {{0x97a6002d,0x588600c6,0x7c850396,0x7ae94987}},	//   ирил, рыла, _луѓе, _ezet,
   {{0x9f4200c2,0x25a000fd,0xc7c60215,0x7f980231}},	//   _eikö_, _œil_, јски, _tíqu,
   {{0xfaa34988,0xe8950034,0x3ce60285,0xd91000d1}},	//   _дато, gółó, _करुं_, _فیش_,
   {{0x9f9700b3,0xd90e01f3,0x00000000,0x00000000}},	//   nçò_, _غیب_, --, --,
   {{0xa3c40085,0x59df0789,0x6d7900c1,0x31630d62}},	//   ्वं_, _पीटर, אָרװ, vejz_,
   {{0x69d80d4b,0x58bb00ca,0x00000000,0x00000000}},	//   love, _במבצ, --, --,
   {{0x394c010a,0x7c3e02db,0x00000000,0x00000000}},	//   _kcds_, hrpr, --, --,
   {{0x14b709e5,0xddc401d3,0x23a20139,0x67c100e8}},	//   ادیث_, ltiņ, _fójo_, vēji,
   {{0x351b006e,0x06d80033,0x69d8020a,0x394c0090}},	//   _יוגנ, দেশি, iove, _mcds_,
   {{0x34fb00a1,0xdcfc0092,0xa7fc026a,0x67c101d3}},	//   _בהוד, _sorğ, _arız, tēji,
   {{0x69d84989,0x63bd3733,0x7c3e0a2c,0xa3b80281}},	// [4010] kove, misn, erpr, _خاور_,
   {{0x7bdb498a,0x443e498b,0x67c100d9,0x69d8498c}},	//   _skuu, ort_, rēji, jove,
   {{0x69d8273a,0x2b140294,0x7ae90103,0x629d498d}},	//   dove, _ịkọ_, _szet, lyso,
   {{0x443e328f,0x63bd498e,0x67c800b6,0x60db0342}},	//   irt_, nisn, dějo, ğumd,
   {{0x443e02dc,0x7c3e05c2,0x69d8498f,0xaa67136e}},	//   hrt_, arpr, fove, ртек,
   {{0x6ab7007d,0x320902e5,0x69d84990,0x7ae9033b}},	//   _अधीर, _muay_, gove, _vzet,
   {{0x013800a1,0x260c009f,0x3158006e,0xa3e702d5}},	//   ברות_, _डूबी_, ייגן_, भता_,
   {{0x63bd1a0d,0x1bd400d6,0x443e037a,0x7bc9024a}},	//   jisn, _дося, drt_, _ujeu,
   {{0x443e4991,0x7ae904eb,0x63bd04a3,0x69d84992}},	//   ert_, _uzet, disn, bove,
   {{0x69d829b0,0x55893967,0x00000000,0x00000000}},	//   cove, убом_, --, --,
   {{0x232a4993,0x3329009c,0xa7870018,0x443e00c4}},	//   лони_, _beax_, _پشاو, grt_,
   {{0x63bd4994,0x06b800cd,0xdb0000ee,0x29fd00d4}},	//   gisn, انیک_, _immò, _mňam_,
   {{0x443e4995,0x68e1052f,0xcfcd0033,0x113a0fe9}},	//   art_, _hyld, লতান, лявы_,
   {{0x32090124,0x3d210034,0x2d830350,0x00000000}},	//   _duay_, यरों_, _nnje_, --,
   {{0x3ce60d1b,0x63bd4996,0x443e08c5,0xa7fc026a}},	//   _करें_, bisn, crt_, _arıy,
   {{0x2451025b,0xaf064997,0x2a6d0087,0xdb190365}},	//   mám_, спал, _oseb_, nnwä,
   {{0x24510146,0x82360f36,0x69d84998,0x3209037a}},	// [4020] lám_, _اربا, yove, _guay_,
   {{0x67c101d3,0xaadb00aa,0x69d84999,0x00000000}},	//   mēju, _बड़क, xove, --,
   {{0x7ae00212,0x67c101d3,0x7c3e1570,0xed572a84}},	//   _symt, lēju, urpr, сох_,
   {{0x7f860037,0x661b0270,0xbb46499a,0x2477020b}},	//   _الحن, kpuk, седк, _măm_,
   {{0x29050270,0xca560396,0x245115bf,0x1994008f}},	//   _bgla_, стењ, hám_, жаля,
   {{0x443e499b,0x20020010,0x2451499c,0x63bd00e7}},	//   yrt_, _hiki_, kám_, zisn,
   {{0x247700ef,0x69d8499d,0x20020517,0x8c4303fc}},	//   _năm_, rove, _kiki_, _нере,
   {{0x2451499e,0xa614499f,0x69d849a0,0xfaa61e6d}},	//   dám_, омич, sove, _лабо,
   {{0x69d849a1,0x5ebb00c1,0x8f9b0341,0xddc401d3}},	//   pove, ָזיק, טיקי, rtiņ,
   {{0x68e101c5,0x7afd025b,0xddc400d9,0x67c100d9}},	//   _fyld, _ústa, stiņ, dēju,
   {{0x63bd49a2,0x443e20fe,0x68e1038c,0x6d5c49a3}},	//   tisn, urt_, _gyld, _mbra,
   {{0x9f4004ea,0x200249a4,0x443e49a5,0xd2510037}},	//   blié_, _niki_, rrt_, ونج_,
   {{0x63bd150a,0x32090028,0x518749a6,0xaefb0032}},	//   risn, _quay_, бува, _ibùg,
   {{0x20021114,0x63bd2d34,0x2451045e,0x61142d03}},	//   _aiki_, sisn, bám_, здру,
   {{0x681100d9,0x63bd49a7,0x200249a8,0xbebb0f5a}},	//   _kāda, pisn, _biki_, _teëk,
   {{0x6d5c49a9,0x02a71116,0x20021114,0xdb0049aa}},	//   _abra, _гром, _ciki_, _almí,
   {{0x6d5c0167,0x200249ab,0x67c101d3,0x7c3800c4}},	// [4030] _bbra, _diki_, cēju, švrl,
   {{0x6d5c009c,0xdcfc01d3,0x200249ac,0x80090103}},	//   _cbra, _norē, _eiki_, _پردہ_,
   {{0x247700de,0x6d5c009c,0x5f950012,0x7bd9007f}},	//   _xăm_, _dbra, _динт, towu,
   {{0x6d5c49ad,0x8f4700c2,0xe1ff007f,0x7e6e007b}},	//   _ebra, _уход, zwól_, änpä,
   {{0x24510018,0xeb900bf4,0x75381420,0xc3340327}},	//   zám_, عظم_, _odvz, פוס_,
   {{0xe3cf00c7,0x9f420084,0x6d5c01b9,0x2fc9084e}},	//   রতিব, _ehkä_, _gbra, lnag_,
   {{0xa3d9000f,0x319c00c1,0x916600fe,0xc19c0266}},	//   ़का_, רבונ, _hộ_, רשוי,
   {{0x6d5c3b31,0x24510579,0x2fc949ae,0x2a6d01fa}},	//   _zbra, vám_, nnag_, _tseb_,
   {{0xbebb04e2,0x6ffc009c,0x05a9004d,0xf1bf41b7}},	//   _beëi, _dōch, ивий_, nsás_,
   {{0xdcf500d9,0x2451025b,0x290549af,0x6d5c0063}},	//   _nozī, tám_, _ugla_, _xbra,
   {{0xd38a205c,0x9166020b,0x661b2ab2,0x00000000}},	//   айне_, _lộ_, spuk, --,
   {{0xd8d607a6,0xe8d60130,0x24512159,0xe3bf01ff}},	//   _וועט_, _ווער_, rám_, giñ_,
   {{0x200249b0,0xddcd00e7,0x7cf03161,0x245100d4}},	//   _riki_, zvaš, _kórí, sám_,
   {{0xd3780d1b,0x64a501b3,0x00860a3a,0xbebb1044}},	//   ść_, _мала, олго, _geëi,
   {{0x200249b1,0xa06a04c9,0x66030415,0x67c101d3}},	//   _piki_, шава_, _iink, sēju,
   {{0xa2d51b79,0x6d5c028d,0x91660023,0x66030184}},	//   _युक्, _sbra, _bộ_, _hink,
   {{0x672b49b2,0x442702e0,0x660349b3,0xa3e6009f}},	// [4040] _megj, _hwn_, _kink, _बीए_,
   {{0x20021342,0x672b49b4,0x660319df,0x660b005c}},	//   _wiki_, _legj, _jink, _mugk,
   {{0x660349b5,0x7e7d0364,0x660b084e,0xc2c90103}},	//   _mink, _ersp, _lugk, _نبیل_,
   {{0x660349b6,0x644102bc,0x5337006e,0xab8349b7}},	//   _link, irli, ַנצן_, душк,
   {{0xadeb0851,0x644101bf,0x442700dc,0x98a5022b}},	//   _जीवन_, hrli, _lwn_, _delč_,
   {{0x66030694,0x442700a1,0x6d5c49b8,0xe3bf01ff}},	//   _nink, _own_, _ubra, ziñ_,
   {{0x672b49b9,0x99391e20,0x7afd1054,0x8b660411}},	//   _begj, сячу_, _ústn, _وارم,
   {{0x2d9849ba,0x3ebf0106,0xaa46004d,0x2fc007ac}},	//   _hore_, _žuti_, _мебл, niig_,
   {{0x2d9849bb,0x644149bc,0x672b00dd,0x3ea014d6}},	//   _kore_, erli, _degj, nyit_,
   {{0x7d1b0095,0x68ed02c6,0x442703a8,0xa2d5007f}},	//   _đusk, řada, _bwn_, _युग्,
   {{0x2d9849bd,0x660349be,0x64410106,0x2ec616e2}},	//   _more_, _dink, grli, लपुत,
   {{0x660349bf,0x2d980238,0xb4ea3d34,0xbebb02ac}},	//   _eink, _lore_, _मरी_, _geëw,
   {{0x660301e9,0x64411044,0xdceb0218,0x2bdb0d77}},	//   _fink, arli, _čiča, यकता,
   {{0xa184022c,0xbf9b001f,0x66030138,0x69ca49c0}},	//   мысл, _ciên, _gink, nnfe,
   {{0x656849c1,0x69ca49c2,0x84380037,0x442749c3}},	//   medh, infe, _اكبر_, _gwn_,
   {{0x644803b4,0x660349c4,0x656800dd,0x02a30134}},	//   mudi, _zink, ledh, _apụọ,
   {{0x59bc000c,0xdce70034,0x2fc949c5,0x660349c6}},	// [4050] ्चार, _mają, rnag_, _yink,
   {{0xd90409e5,0x2d9849c7,0x656849c8,0xe1ff0034}},	//   _لی_, _core_, nedh, zwój_,
   {{0x2d9849c9,0xdb0000b3,0x67d3044c,0x00000000}},	//   _dore_, _almà, lăje, --,
   {{0x6568001c,0xdcee0e4b,0x00000000,0x00000000}},	//   hedh, _gabč, --, --,
   {{0x672b49ca,0x7e7d3114,0x2d9849cb,0x65680421}},	//   _regj, _ursp, _fore_, kedh,
   {{0x2d9808a9,0x656801e5,0x672b0102,0xa9692139}},	//   _gore_, jedh, _segj, сика_,
   {{0x660301b3,0x6c54426c,0x3f9902e6,0xe73949cc}},	//   _rink, _окру, _kosu_, бей_,
   {{0x2d9808a9,0x660349cd,0xfe6e0068,0x3f9901e9}},	//   _zore_, _sink, _جگہ_, _josu_,
   {{0x65680239,0x672b023b,0x645d00ae,0xf96b00d3}},	//   fedh, _vegj, ăsim, _врей_,
   {{0x3f9949ce,0x65680d7f,0x644849cf,0x6441013c}},	//   _losu_, gedh, fudi, trli,
   {{0xbf9b0028,0x660349d0,0xb0db009d,0x644104e2}},	//   _riên, _vink, _मुलग, urli,
   {{0x660342f2,0x3f9949d1,0x7bcb020b,0x660b019c}},	//   _wink, _nosu_, nngu, _tugk,
   {{0x660349d2,0x2131005c,0x7bcb49d3,0x64483c6f}},	//   _tink, fazh_, ingu, audi,
   {{0x776942e9,0x67e500e1,0xdce7007f,0x681100e8}},	//   leex, dóji, _zają, _jādo,
   {{0x03a628b9,0x2b5f0357,0xfbdb00b6,0x00000000}},	//   _нико, _obuc_, यकाम, --,
   {{0x3f8608a8,0xf43a00a1,0x394001c2,0x2d9849d4}},	//   ñou_, _התקש, ɗisu_, _sore_,
   {{0x7e6d07ac,0xa3d90034,0x00000000,0x00000000}},	// [4060] gwap, ़कर_, --, --,
   {{0xc27b0c6a,0xf27b0105,0x3f8f0088,0x7bcb024a}},	//   _פריי, _פריש, ögur_, engu,
   {{0x2d9800f3,0x319b00ca,0x1d1900d6,0xcb0a02d1}},	//   _vore_, _הבינ, юють_, ميان_,
   {{0x7bcb49d5,0x9f40037a,0xdb0049d6,0x7e6d010a}},	//   gngu, rmió_, _almá, bwap,
   {{0x2d9849d7,0x93bd00ae,0x644849d8,0x7769008c}},	//   _tore_, spăg, zudi, deex,
   {{0x7bcb49d9,0xceb3006e,0x00000000,0x00000000}},	//   angu, _טיר_, --, --,
   {{0x644849da,0xb4ea0971,0x656849db,0xb7d80076}},	//   xudi, _मरे_, vedh, يوتا_,
   {{0x6f160381,0x644849dc,0x69ca0234,0xcc5700ca}},	//   ncyc, vudi, snfe, _מבלי_,
   {{0x35f40636,0x656849dd,0xaa4302f3,0x00000000}},	//   мпир, tedh, _петл, --,
   {{0x64481c40,0xb21b0088,0x7bc20239,0x25a50063}},	//   tudi, lvæg, liou, gkll_,
   {{0x92e900c7,0xb0db250d,0xaac0009d,0x656849de}},	//   _বলে_, _मुंग, _शेतक, redh,
   {{0x644849df,0x6568001c,0xb4cc08d4,0x28c900b6}},	//   rudi, sedh, _रखी_, िपरि,
   {{0x518749e0,0x644849e1,0x3f9900d3,0x98a500d9}},	//   пува, sudi, _rosu_, _ielā_,
   {{0x3f9949e2,0xddcd00a5,0xfdeb009f,0xe3b90511}},	//   _sosu_, ztał, _जींस_, nsız_,
   {{0x55770341,0xddcd0034,0x1fa7002d,0x98a7020a}},	//   _מעגן_, ytał, праг, mană_,
   {{0x5f940562,0x94730080,0x213100dd,0x7e6d49e3}},	//   нист, _أدوا, sazh_, twap,
   {{0x63ad49e4,0x7bc249e5,0xe3b90233,0xdcfc00c6}},	// [4070] _ilan, diou, ksız_, _korė,
   {{0x63ad019f,0x7e6d0a88,0x799a0703,0x224b042c}},	//   _hlan, rwap, _notw, muck_,
   {{0x63ad49e6,0x7bcb49e7,0xa3c40096,0x200c00d2}},	//   _klan, tngu, ्वच_, ídit_,
   {{0x798849e8,0xff250814,0x63ad0113,0x7bcb49e9}},	//   _andw, _تبدی, _jlan, ungu,
   {{0x1ee70260,0x63ad49ea,0xf8ae0018,0x9f9600ca}},	//   _روسی_, _mlan, یکم_, _חדרה_,
   {{0x63ad49eb,0xddcd0067,0xdcfc013f,0x799a030a}},	//   _llan, stał, _norė, _cotw,
   {{0x7bcb49ec,0x00000000,0x00000000,0x00000000}},	//   pngu, --, --, --,
   {{0xe61947cd,0x79880517,0xbc560146,0xd52b0139}},	//   оди_, _endw, žšíc, _bò̟w,
   {{0x6d4a1ba6,0x7769008c,0x6b9b009c,0xbebb02ac}},	//   ófag, reex, _ioug, _geët,
   {{0x63ad49ed,0xa3e62ebd,0x224b01ce,0x776949ee}},	//   _alan, _बीज_, duck_, seex,
   {{0x69c3202b,0x6b8917b4,0x6b9b02ac,0x00000000}},	//   mine, _kneg, _koug, --,
   {{0x63ad49ef,0x21e40364,0x6b9b0172,0x00000000}},	//   _clan, höht_, _joug, --,
   {{0x69c30a21,0x6b89005c,0x85b90037,0x6b9b49f0}},	//   oine, _mneg, _واتس_, _moug,
   {{0x63ad49f1,0xdcee0029,0x6b9b49f2,0x98a7020a}},	//   _elan, _labā, _loug, cană_,
   {{0x63ad49f3,0xc0e349f4,0x05960d83,0x00000000}},	//   _flan, ворк, _تانگ, --,
   {{0xa3e61244,0x6d430081,0x69c349f5,0x2360015c}},	//   _बीच_, ónan, hine, _ubij_,
   {{0x69c349f6,0x7bc237d0,0x6e36013f,0x6f1600d7}},	// [4080] kine, viou, usyb, rcyc,
   {{0x6ec20b94,0x6aa20051,0x69c349f7,0xfbd20018}},	//   _रेणु, vyof, jine, ھتا_,
   {{0xbc6a00cd,0x2a640167,0x6b9b49f8,0xdb0b1e3b}},	//   تمان_, _spmb_, _boug, bigü,
   {{0x6b9b49f9,0x6aa2033c,0x160d00a4,0xa7320139}},	//   _coug, tyof, सदार_, _lọrù,
   {{0x7bc249fa,0x799a00a5,0x6b890167,0x69c349fb}},	//   riou, _potw, _dneg, fine,
   {{0x7bc20373,0x6b8949fc,0x00000000,0x00000000}},	//   siou, _eneg, --, --,
   {{0xa3de2a29,0xb4cc0b89,0xec1600cd,0xe3b9008b}},	//   तका_, _रखे_, _آورد, rsız_,
   {{0x6d5e49fd,0x69c349fe,0xc6a616bd,0x17f70037}},	//   lfpa, aine, дрои, ورية_,
   {{0x056a1009,0x799a010a,0x63ad01ec,0x98a7044c}},	//   ојни_, _totw, _rlan, tană_,
   {{0xdc3e0146,0xc9861374,0xe3b9013c,0x799a0154}},	//   _líče, _تشري, qsız_, _uotw,
   {{0x69dd0037,0x98a7020a,0x23a20139,0x00000000}},	//   _ísea, rană_, _lóju_, --,
   {{0xe71700cd,0x18a334ca,0xb86549ff,0x00000000}},	//   _قيمت_, _шахм, _سامو, --,
   {{0x63ad0031,0x5ede00aa,0xbebb0f5a,0x68e808b2}},	//   _vlan, _कुल्_, _leër, _hydd,
   {{0xa4d402ec,0x63ad4a00,0xab5d00bd,0x224b0703}},	//   _полі, _wlan, _imże, ruck_,
   {{0x2eed0039,0xdb0b03be,0x7bc0010a,0x224b0167}},	//   _šef_, tigü, _ommu, suck_,
   {{0x69c34a01,0x63ad4a02,0x6d5e18ef,0x24584a03}},	//   zine, _ulan, efpa, mém_,
   {{0x24584a04,0x69c34a05,0x645a4a06,0x6b9b4a07}},	// [4090] lém_, yine, ltti, _roug,
   {{0x6b892174,0xdce70034,0xbebb084e,0x645a166f}},	//   _sneg, _zaję, _beër, otti,
   {{0x645a02fd,0x61e510dd,0x2458030b,0xb4cc17ff}},	//   ntti, _ikhl, ném_, _रखो_,
   {{0x290c0009,0x645a00c2,0xce95008f,0x7e7b0559}},	//   _agda_, itti, _замъ, _šupu,
   {{0x645a029a,0x245802c6,0x00000000,0x00000000}},	//   htti, hém_, --, --,
   {{0x68e802e0,0x2458030b,0x69c3009c,0x7bc00517}},	//   _bydd, kém_, uine, _emmu,
   {{0x3d1a0454,0xe73922e4,0x98be026a,0xbebb0abf}},	//   मुळे_, пей_, _batı_, _geër,
   {{0x69c326a4,0x68e802ad,0xa695001f,0x24584a08}},	//   sine, _dydd, ерој, dém_,
   {{0x92ea00c7,0x645a2dfb,0xb9064038,0xdb0b0143}},	//   _গল্প_, etti, _यु_, sigó,
   {{0x68e802ad,0x69c30d6a,0x14254a09,0x201c0103}},	//   _fydd, qine, ндом, _évig_,
   {{0x6578023e,0x64a500c6,0x69c14a0a,0xf7730103}},	//   _davh, хана, _imle, _لاش_,
   {{0xe3b2114c,0x61e54a0b,0x7ae90517,0x61f7009c}},	//   ارد_, _akhl, _kyet, _ahxl,
   {{0x645a4a0c,0xda0f1c83,0x3ce60096,0x6d55007f}},	//   atti, ादित_, _जुने_, _ocza,
   {{0x6d434a0d,0x00000000,0x00000000,0x00000000}},	//   ónal, --, --, --,
   {{0xe3b200e3,0x24580161,0xceb400a7,0x7ae947af}},	//   _مرة_, cém_, hbət_, _lyet,
   {{0x201e00d9,0xafe3186d,0xc17800c6,0x00000000}},	//   īti_, госл, žė_, --,
   {{0x7ae94a0e,0x0d86060b,0x765b2fcf,0x201e4a0f}},	// [40a0] _nyet, нлан, ntuy, ūti_,
   {{0xe1f20192,0x62844a10,0x00000000,0x00000000}},	//   _حسب_, _irio, --, --,
   {{0x28df0d0b,0x31570130,0x0b4606e7,0x8fa61bd1}},	//   _पुलि, _איין_, енен, _зане,
   {{0x7ae9083e,0x68e84a11,0x501b00ca,0x765b0124}},	//   _byet, _rydd, _מוטו, ktuy,
   {{0x24584a12,0x68e81322,0xef834a13,0x5b130120}},	//   zém_, _sydd, _сляп, уміт,
   {{0x7ae94a14,0x645a4a15,0x00000000,0x00000000}},	//   _dyet, ytti, --, --,
   {{0xab2a0114,0x7ae94a16,0xf806129c,0xd90d00cd}},	//   _нова_, _eyet, нчин, زین_,
   {{0x62844a17,0x2458030b,0x7bc04a18,0xfce335c1}},	//   _orio, vém_, _ummu, _сосо,
   {{0x765b4a19,0x68e80150,0x7ae9083e,0x98a700c6}},	//   gtuy, _wydd, _gyet, vaną_,
   {{0x24584a1a,0x98a70034,0xe9da04d9,0xaa3b00d7}},	//   tém_, waną_, _экз_, _מתמח,
   {{0x62844a1b,0x77920504,0x645a007b,0x765b010a}},	//   _ario, _میثا, utti, atuy,
   {{0x628401f5,0x24584a1c,0x645a4a1d,0x38cb00cd}},	//   _brio, rém_, rtti, _عالی_,
   {{0x62841ab6,0x27e64a1e,0x645a0bc6,0x98a716c3}},	//   _crio, _ikon_, stti, raną_,
   {{0x2244025b,0x6578004d,0x04940037,0x67e5007f}},	//   ámka_, _uavh, _للتح, bójs,
   {{0x62844a1f,0x2fc20085,0x00000000,0x00000000}},	//   _erio, _bmkg_, --, --,
   {{0x62844a20,0x8d77001c,0xddc404a8,0x9f5a00d8}},	//   _frio, کارا, ttiş, _tupý_,
   {{0x62844a21,0xa3de0176,0x8afd02c6,0x00000000}},	// [40b0] _grio, तकर_, _obřa, --,
   {{0x64484a22,0x201e0428,0x443c0381,0x98b0007f}},	//   ordi, ític_, _kvv_, जनाए,
   {{0x7ae916f0,0x9f5a00ee,0x7c670037,0x443c00b3}},	//   _syet, _cupó_, عائل, _jvv_,
   {{0x7ae901e5,0x53e1009d,0xa03a00c1,0x660a007e}},	//   _pyet, नविश, _קערפ, _lifk,
   {{0xbf360054,0x853c0138,0xdb0e003e,0xf8c90285}},	//   _בארץ_, rkėj, þjál, िप्प,
   {{0x27e622d4,0x7ae94a23,0x89a800d6,0x64480580}},	//   _akon_, _vyet, нків_, krdi,
   {{0x7ae9027e,0xbddb0154,0xceb400a7,0xa3e100b7}},	//   _wyet, _avèg, sbət_, थवा_,
   {{0x7c254a24,0x7ae9010a,0xceb4013c,0x00000000}},	//   mphr, _tyet, mbər_, --,
   {{0x200b002d,0x443c4a25,0x64484a26,0x7bd8020d}},	//   _mici_, _avv_, erdi, évue,
   {{0x69c14a27,0x200b0335,0x3ce6007f,0x765b4a28}},	//   _umle, _lici_, _जुडे_, rtuy,
   {{0x6448015c,0x6f1d0381,0x00000000,0x00000000}},	//   grdi, _ofsc, --, --,
   {{0x200b0012,0x62844a29,0x442e4a2a,0xe72e0291}},	//   _nici_, _prio, _dwf_, _ње_,
   {{0x64484a2b,0x27ff4a2c,0xe29729c2,0x67294a2d}},	//   ardi, mmun_, вая_, mbej,
   {{0x27ed4a2e,0x200b4a2f,0xa06a2ca3,0x6f1d0126}},	//   llen_, _aici_, мага_, _afsc,
   {{0xddd60074,0x200b2af2,0xcfaa001c,0xc0e64a30}},	//   jvyš, _bici_, وارم_, товк,
   {{0x62844a31,0x44254a32,0x613f0233,0x9f4f01cd}},	//   _trio, mpl_, _açlı, ögð_,
   {{0x200b0987,0x27ed4a33,0x628403eb,0xcad20174}},	// [40c0] _dici_, ilen_, _urio, hịrị,
   {{0x27ed02dc,0x7aef00d4,0xf4240033,0x00000000}},	//   hlen_, _úcty, _ভিতর_, --,
   {{0x27ed01c5,0x27ff005c,0x44250154,0x200b0022}},	//   klen_, kmun_, npl_, _fici_,
   {{0x27ed4a34,0x61ee4a35,0x8fa623ba,0xe62700fe}},	//   jlen_, llbl, _раме, _phố_,
   {{0x27ed4a36,0xdb0901ec,0x00000000,0x00000000}},	//   dlen_, _smeò, --, --,
   {{0x27ed4a37,0xdb0b0088,0x76494a38,0x200b4a39}},	//   elen_, rigð, drey, _zici_,
   {{0x660a0449,0x27ed4a3a,0xd7fa00ae,0x00000000}},	//   _rifk, flen_, муи_, --,
   {{0x6448005f,0x27ed3aad,0x67292897,0x65ad037a}},	//   vrdi, glen_, gbej, _búho,
   {{0xb8e90775,0xda650190,0xcad20294,0x443c4a3b}},	//   _ले_, _مالي, rịsị, _svv_,
   {{0x644802dd,0x27ed4a3c,0x21384a3d,0x443c01c0}},	//   trdi, alen_, jarh_, _pvv_,
   {{0xaefb0139,0x27ed1832,0x3a2601c0,0x67294a3e}},	//   _abùl, blen_, lpop_, bbej,
   {{0xd5b000bf,0xd3a73967,0xa73a046b,0x76490088}},	//   _گفت_, троп, _آثار_, brey,
   {{0xdcf50117,0x660a009e,0x00000000,0x00000000}},	//   _razč, _tifk, --, --,
   {{0x200b4a3f,0x442e0178,0x3a2602ac,0xf3ff0131}},	//   _sici_, _twf_, ipop_, smã_,
   {{0x99990220,0x200b4a40,0x00000000,0x00000000}},	//   _ísť_, _pici_, --, --,
   {{0x02a705e1,0x61ee0b8e,0x9f5a022b,0x00000000}},	//   _аром, albl, _supò_, --,
   {{0x291e0222,0xfe7000e3,0xdb000018,0x200b4a41}},	// [40d0] _ofta_, يدك_, _elmú, _vici_,
   {{0x68ed030b,0x67290095,0x27ff0abd,0xbbdb00c3}},	//   řadi, zbej, zmun_, यक्क,
   {{0x80ca0179,0x681100e8,0x00000000,0x00000000}},	//   _हेपे, _tādi, --, --,
   {{0x7a380134,0x764900f9,0x6f1d0231,0x291e3177}},	//   _ụtar, yrey, _ufsc, _afta_,
   {{0xd945311c,0x27ed00f2,0xeab00037,0x00000000}},	//   гели, vlen_, يعه_, --,
   {{0x487910de,0x2fc901fa,0x76490233,0x27ed49c3}},	//   есия_, liag_, vrey, wlen_,
   {{0x27ed0068,0xac940131,0x2d18001c,0x186600e5}},	//   tlen_, _карш, _شکلک_, гащи_,
   {{0x869900c9,0x291e4a42,0x27ed3dd6,0x76494a43}},	//   етот_, _efta_, ulen_, trey,
   {{0x67290021,0x3ea94a44,0x27ed4a45,0x06094a46}},	//   rbej, nyat_, rlen_, нник_,
   {{0x27ed4a47,0x76490188,0xcad20134,0x98c7468c}},	//   slen_, rrey, pịrị, _исел,
   {{0x27ed4a48,0xf7552519,0x58d40870,0x00000000}},	//   plen_, _مناج, _кофт, --,
   {{0xc2091723,0xddcd02e6,0x3ea914f7,0x44251bbc}},	//   _זה_, jvaž, kyat_, rpl_,
   {{0xdcf40307,0x290a0072,0x442501b6,0x59b70285}},	//   _čača, _ºbac_, spl_, _अतार,
   {{0x06e50081,0x3ea94a49,0x7afd00d4,0x00000000}},	//   _পৃথি, dyat_, _ústu, --,
   {{0xa0674a4a,0x75d208ba,0x9f40007b,0x2138044c}},	//   лара_, _ديوا, yliä_, rarh_,
   {{0x645c05fe,0x1fb500d3,0xaefb0139,0x224b009c}},	//   àrie, асур, _ibùj, brck_,
   {{0x3ea94a4b,0x93fb0089,0x20004a4c,0x4d664a4d}},	// [40e0] gyat_, _אלקי, rmii_, лкав,
   {{0xaf0300d3,0x00000000,0x00000000,0x00000000}},	//   спул, --, --, --,
   {{0xa0a6123a,0xf53600c1,0xacf619e8,0x28c302d5}},	//   _санд, רטער_, учај, _वेलि,
   {{0x65ad0181,0x2240108c,0x7c650076,0x00000000}},	//   _súhl, _kvik_, شامل, --,
   {{0xbb4305b8,0x60d600e8,0x1958065c,0x00000000}},	//   сечк, šamā, валы_, --,
   {{0xfce64a4e,0x44f32caa,0xa00200ac,0x8277006e}},	//   _бого, _ọ_, _ọchị, טענע_,
   {{0xdca341c3,0x7c294a4f,0x3a264a50,0x80ca0285}},	//   _лари, _čerg, spop_, _हेमे,
   {{0x7c3e0f05,0x3f804a51,0x00000000,0x00000000}},	//   mspr, ndiu_, --, --,
   {{0x7c3e2566,0x2487002b,0x36d403f2,0x35b44a52}},	//   lspr, _arnm_, ропр, ибир,
   {{0xd90e0e27,0x00000000,0x00000000,0x00000000}},	//   _عیب_, --, --, --,
   {{0xd7ef4a53,0x6d430037,0x81da0033,0x00000000}},	//   _гу_, ónai, ়তা_, --,
   {{0x3ea90253,0x2fc901fa,0x3f800052,0x7c3e41e9}},	//   yyat_, xiag_, jdiu_, ispr,
   {{0x65944a54,0xdcf500d9,0x3a240063,0x44f30032}},	//   _валу, _mazā, _jtmp_, _ẹ_,
   {{0x7c3e2452,0x00000000,0x00000000,0x00000000}},	//   kspr, --, --, --,
   {{0xd48f1cb1,0x351b0341,0x753a0a00,0x31714a55}},	//   _ур_, _אוונ, matz, rezz_,
   {{0x443e4a56,0x7c3e0429,0x753a02a7,0x69ca4a57}},	//   mst_, dspr, latz, hife,
   {{0x69ca4a58,0xe81b04f1,0x443e4a59,0x7c3e4a5a}},	// [40f0] kife, _पूना_, lst_, espr,
   {{0x753a0a00,0x443e4a5b,0x2fc9022e,0x2b4403a8}},	//   natz, ost_, siag_, _admc_,
   {{0x443e01ce,0x69ca4a5c,0x3ea902e7,0x5b1547ff}},	//   nst_, dife, syat_, амет,
   {{0x443e4a5d,0x753a4a5e,0xdb0006a3,0x63af0094}},	//   ist_, hatz, _komè, nkcn,
   {{0x753a02a7,0x2d85001f,0x443e01bf,0x386c0072}},	//   katz, _óleo_, hst_, _apdr_,
   {{0x443e4a5f,0x61e7031a,0x3a240072,0xd825036a}},	//   kst_, nojl, _dtmp_, адки,
   {{0x443e4a60,0x753a0a00,0xa7b50859,0x7c8410e8}},	//   jst_, datz, исиј, _луте,
   {{0x07a54a61,0xc1d20176,0x443e4a62,0xf7713a1d}},	//   раин, _सद्ग, dst_, زاب_,
   {{0x7bcb4a63,0x443e4a64,0xdb0000ee,0x6a230103}},	//   migu, est_, _nomè, _اہتم,
   {{0x27e0011d,0x27330028,0x443e4a65,0x7bcb4a66}},	//   čina_, ản_, fst_, ligu,
   {{0x443e0709,0x232a1102,0x2d810a02,0xa775133d}},	//   gst_, кони_, idhe_, _влеч,
   {{0x7bcb4a67,0xb4d51488,0x888a00c1,0xb4e50032}},	//   nigu, _सखी_, _שרײַ, _alàà,
   {{0x2d9126f1,0xdb004a68,0xa2c0030b,0x753a01e9}},	//   _onze_, _comè, _लेख्, batz,
   {{0x7bcb02c9,0xdb004a69,0x443e4a6a,0x673b0138}},	//   higu, _domè, bst_, lauj,
   {{0xaca40294,0x7bcb4a6b,0x84e902d5,0x7c3e029a}},	//   _kwụr, kigu, _ऑडिट_, xspr,
   {{0x673b013f,0x69ca4a6c,0x788000b6,0x3f8000ae}},	//   nauj, zife, lává, udiu_,
   {{0x22404a6d,0xd00711f4,0x3f804a6e,0xef174a6f}},	// [4100] _uvik_, рете_, rdiu_, рму_,
   {{0x7c3e4762,0x9d460e38,0x63a4044c,0x644e002b}},	//   tspr, режд, _hoin, ábig,
   {{0x63a44a70,0x98a7030b,0x9f400037,0x62864834}},	//   _koin, raně_, iliú_, lvko,
   {{0x7c3e4a71,0x753a02a7,0x63a44a72,0x1a2a00d6}},	//   rspr, zatz, _join, вжди_,
   {{0x63a404ea,0x63b64a73,0xdb004a74,0x673b0138}},	//   _moin, _mlyn, _komé, dauj,
   {{0x443e4a75,0x63a44a76,0x7c3e4a77,0x3eaf02b6}},	//   yst_, _loin, pspr, øgte_,
   {{0xb9c30080,0x7b9602ec,0x8c434a78,0x7880000d}},	//   تقوي, _краї, _мере, dává,
   {{0x96341c17,0x2ca74a79,0xebe32156,0x69ca4a7a}},	//   бниц, ände_, _досп, sife,
   {{0x753a4a7b,0x443e00f0,0x6b820178,0x3b071230}},	//   tatz, wst_, mdog, _вето_,
   {{0xdb004a7c,0x443e0ab2,0x5506225a,0x6b824a7d}},	//   _nomé, tst_, ична, ldog,
   {{0x753a03f3,0x443e4a7e,0x63b64a7f,0x63a403dc}},	//   ratz, ust_, _blyn, _boin,
   {{0x63a44a80,0x443e4a81,0x753a4a82,0xaca40134}},	//   _coin, rst_, satz, _gwụr,
   {{0x443e4a83,0x753a0a00,0xc6760dce,0x63a44a84}},	//   sst_, patz, _خطاب, _doin,
   {{0x463b0130,0xdb004a85,0x7bcb0b1a,0x443e4a86}},	//   _יעדע, _comé, zigu, pst_,
   {{0xdb004a87,0x63a400e3,0x63b60150,0xdcf500ae}},	//   _domé, _foin, _flyn, _mază,
   {{0x63a400a1,0x6d5c4a88,0x63b600f0,0x200f4a89}},	//   _goin, _acra, _glyn, ögi_,
   {{0x6b82037a,0xdb000072,0x7bcb00fd,0x69c84a8a}},	// [4110] ddog, _fomé, vigu, _omde,
   {{0x71750adb,0x673b1515,0x63a44a8b,0x7bcb0079}},	//   _اهدا, zauj, _zoin, wigu,
   {{0x2ca7002d,0x6fb5001c,0x2d81023b,0x7bcb34d2}},	//   ând_, _همدا, rdhe_, tigu,
   {{0x6d5c04ed,0x6f950037,0x6b800178,0x69c8039f}},	//   _ecra, _الحض, _camg, _amde,
   {{0x6b804a8c,0x673b013f,0x60db008b,0xb21b003e}},	//   _damg, vauj, ğumu, kvæm,
   {{0x75384a8d,0x67220065,0x6d5c0076,0x7af700a7}},	//   _nevz, _afoj, _gcra, əxtl,
   {{0x7bcb00bf,0x673b00d9,0x788002c6,0x00000000}},	//   pigu, tauj, vává, --,
   {{0xba77001c,0xb21b003e,0x69c80365,0x6b804a8e}},	//   _پارت, tvæl, _emde, _gamg,
   {{0x63a40514,0x673b24e5,0x7bc90239,0x76401a92}},	//   _roin, rauj, _imeu, gsmy,
   {{0x63a44a8f,0x7afb4a90,0x67da003d,0x63b617d2}},	//   _soin, _izut, rċja, _slyn,
   {{0x63b60074,0x63a44a91,0x2bc40557,0xb50a0179}},	//   _plyn, _poin, लोवा, _हृदय_,
   {{0xe29a1147,0x645c0428,0x79810f5a,0xdb00002b}},	//   гам_, ària, _halw, _somé,
   {{0x6d470141,0x63a40fd6,0x79814a92,0x1b7a00c1}},	//   _odja, _voin, _kalw, נטשע,
   {{0xc69200a1,0x6d4701c2,0x130329b6,0x00000000}},	//   _מאד_, _ndja, язям, --,
   {{0x63a40084,0x29de0174,0x6b8203a8,0x86220504}},	//   _toin, nịọs_, ydog, _وکیل,
   {{0x79810c56,0x44274a93,0x64412fe3,0x6d5c1814}},	//   _lalw, _itn_, msli, _scra,
   {{0x24431001,0x4427023e,0x8fa315a7,0x59b70285}},	// [4120] lım_, _htn_, чате, _अतंर,
   {{0x6b8034dd,0x7bc94a94,0x44274a95,0x798101b2}},	//   _samg, _ameu, _ktn_, _nalw,
   {{0x24430702,0x64414a96,0x7e7d0d21,0xb53a006e}},	//   nım_, nsli, _essp, רגעש,
   {{0x80c10081,0x44274a97,0x64414a98,0x6739010a}},	//   _শুক্, _mtn_, isli, _newj,
   {{0x79814a99,0x2443071d,0xab6500e8,0x00000000}},	//   _balw, hım_, daļā, --,
   {{0x09e32de0,0x644100e4,0x244301e8,0x64434a9a}},	//   почн, ksli, kım_, _ovni,
   {{0x5886055b,0x3f8214c4,0x7e641c8d,0x78b50092}},	//   сыла, _kaku_, ltip, _üzvl,
   {{0x24430702,0x27e002dd,0xf09300a1,0x64414a9b}},	//   dım_, čino_, לנו_, dsli,
   {{0x3f824a9c,0x201a4a9d,0x6441057a,0x67390a4b}},	//   _maku_, _lupi_, esli, _dewj,
   {{0x3f820706,0x44274a9e,0x79812feb,0xb865001c}},	//   _laku_, _btn_, _galw, _ژانو,
   {{0x539900d6,0x64410407,0x7e6413ce,0x395e0090}},	//   авня_, gsli, htip, _icts_,
   {{0x3f824a9f,0x61e11c0a,0x69d801d3,0xddcd0233}},	//   _naku_, पक्ष, lnve, ktaş,
   {{0x79814aa0,0x64410185,0x6443039f,0x69d82a28}},	//   _yalw, asli, _evni, onve,
   {{0x65941824,0x4427007e,0x69d84aa1,0xf43400ae}},	//   _факу, _ftn_, nnve, _декэ,
   {{0x3f824aa2,0x44260adb,0x201a4aa3,0xdc3c0138}},	//   _baku_, _ارتف, _cupi_, _išėj,
   {{0x1fa42249,0xfd590134,0x7e7d0063,0x201a0113}},	//   пруг, _febụ, _pssp, _dupi_,
   {{0x680a0067,0xdcfc0181,0x7e64259e,0x3f8202fa}},	// [4130] _będz, _darč, gtip, _daku_,
   {{0xbddb4aa4,0x201a0239,0x44270063,0x998d03f1}},	//   _evèn, _fupi_, _ytn_, _svež_,
   {{0x6ad11efb,0xa3ad09c3,0x201a05db,0x9f4000b3}},	//   तप्र, _गवा_, _gupi_, boià_,
   {{0x79814aa5,0x826400cd,0x2d9c0212,0x69d84aa6}},	//   _salw, _بهین, över_, enve,
   {{0x244308bb,0x69d80088,0xc33400ca,0x79810113}},	//   zım_, fnve, לוף_, _palw,
   {{0x244303a3,0x3f82006d,0x6e2d4aa7,0x201a024a}},	//   yım_, _zaku_, mpab, _yupi_,
   {{0x6e2d167e,0x321300d8,0x29fd0206,0xab6500e8}},	//   lpab, _mixy_, _kňaz_, taļā,
   {{0x2d830440,0x79814aa8,0x7bc90a4b,0xf6254aa9}},	//   _haje_, _walw, _umeu, одио,
   {{0xe6160fdf,0x2d831935,0x95994aaa,0x79814aab}},	//   оды_, _kaje_, атну_, _talw,
   {{0x244303a3,0x6441032e,0x2d830995,0x44270da7}},	//   tım_, tsli, _jaje_, _ptn_,
   {{0x87e72082,0xd4693f6c,0x628d4aac,0x644113ce}},	//   _люде, шине_, _arao, usli,
   {{0x24430702,0x201a4aad,0xe69506f6,0x628d4aae}},	//   rım_, _rupi_, _ولاد, _brao,
   {{0x628d0091,0x244301e8,0x64414aaf,0x33220381}},	//   _crao, sım_, ssli, rckx_,
   {{0x628d03ea,0x2d834ab0,0x3f824ab1,0x64414ab2}},	//   _drao, _naje_, _saku_, psli,
   {{0xdcfc4ab3,0x03a6164d,0x3f824ab4,0x1faa4ab5}},	//   _parč, _мико, _paku_, акви_,
   {{0xa3be0296,0x25fd007d,0x628d0527,0x7e640d81}},	//   _इति_, _रीती_, _frao, ttip,
   {{0xf7720105,0x2d834ab6,0x628d4ab7,0xdcfc0087}},	// [4140] וקן_, _baje_, _grao, _varč,
   {{0xdd920688,0x2d834ab8,0x3f820113,0x00000000}},	//   بوط_, _caje_, _waku_, --,
   {{0x7e644ab9,0x3f6a15a7,0x3f824aba,0x2a7f00aa}},	//   stip, _кино_, _taku_, _asub_,
   {{0x2ca70149,0xcb6a4abb,0x6d43003e,0x7e6416f7}},	//   ända_, раде_, ónar, ptip,
   {{0x7e030134,0x00000000,0x00000000,0x00000000}},	//   ọsar, --, --, --,
   {{0x2d834abc,0x8d76001c,0x77690381,0x00000000}},	//   _gaje_, _باحا, efex, --,
   {{0x69d84abd,0xdcfc0090,0xc7b80357,0x00000000}},	//   rnve, _forġ, _luđe_, --,
   {{0xca7629c2,0xdb001f72,0x466a098f,0x2d834abe}},	//   _музы, _homí, аром_, _zaje_,
   {{0xdb000146,0x2d830193,0x00000000,0x00000000}},	//   _komí, _yaje_, --, --,
   {{0x28960284,0x00000000,0x00000000,0x00000000}},	//   _мјес, --, --, --,
   {{0x31784abf,0xd5b70120,0x00000000,0x00000000}},	//   derz_, ісь_, --, --,
   {{0x628d4ac0,0x00000000,0x00000000,0x00000000}},	//   _prao, --, --, --,
   {{0x9f490472,0xc6d60103,0x00000000,0x00000000}},	//   llaç_, _بتات, --, --,
   {{0x442c0124,0x65c00032,0x6756015a,0xd8380383}},	//   ppd_, _dáhù, _ایکس_, _kwč_,
   {{0x2d834ac1,0x855700ca,0xd6d9007f,0x00000000}},	//   _raje_, _ושוב_, mała_, --,
   {{0x09b71fb4,0x628d4ac2,0x5f94090f,0x2d834ac3}},	//   _अत्य, _trao, мист, _saje_,
   {{0x2d834ac4,0x00000000,0x00000000,0x00000000}},	// [4150] _paje_, --, --, --,
   {{0xc05b07bf,0xdb00266c,0xab5d0090,0xdc8b0c37}},	//   _кім_, _comí, _imżi, исел_,
   {{0xdb0045f8,0x2d830087,0x6b800134,0xd838022b}},	//   _domí, _vaje_, _ịgaf, _nwč_,
   {{0x207a0130,0x2d834ac5,0x307a00c1,0xbbb50cce}},	//   _פארא, _waje_, _פארנ, ंसेक,
   {{0xbf9a040a,0x2d834ac6,0x20094ac7,0x720a0103}},	//   _הירש, _taje_, mmai_, _خفیہ_,
   {{0x20094ac8,0xd83805aa,0x00000000,0x00000000}},	//   lmai_, _bwč_, --, --,
   {{0x013800ca,0xcb35008f,0xd6d9007f,0x00000000}},	//   חרות_, _невъ, dała_, --,
   {{0x02a30134,0x2a7f023e,0x20094ac9,0xb6a500d3}},	//   _awọọ, _tsub_, nmai_, зиил,
   {{0xe81b1244,0xaefb0032,0x2a7f00bc,0x00000000}},	//   _पूरा_, _ibùs, _usub_, --,
   {{0x77bc0072,0x00000000,0x00000000,0x00000000}},	//   _réxe, --, --, --,
   {{0x20090018,0xc7b804e9,0x84583ac9,0xb9c40076}},	//   kmai_, _suđe_, орят_, _تقلي,
   {{0x78fa00ca,0x00000000,0x00000000,0x00000000}},	//   _הפעו, --, --, --,
   {{0x659511ba,0x27ed4aca,0x3a2f0063,0x6ecb0179}},	//   _наду, moen_, npgp_, _सेलु,
   {{0x7c29030b,0x27ed4acb,0x4e1f00aa,0x00000000}},	//   _čern, loen_, _बढ़ई_, --,
   {{0x9103125c,0xf992006e,0x69b302d5,0x10a600e5}},	//   епре, ערל_, _अवनी, чивн,
   {{0x20093826,0x27ed4acc,0xc7b80106,0xef1a1a57}},	//   gmai_, noen_, _tuđe_, сма_,
   {{0xdee30642,0x7a190154,0xd12f0103,0x27ed0062}},	// [4160] еоти, _lňtb, ئمہ_, ioen_,
   {{0x27ed4acd,0x22440094,0xdcfc0090,0x8cb82172}},	//   hoen_, ámku_, _jorħ, ऊनलो,
   {{0x27ed4ace,0x61ee4acf,0x711b00c1,0x660f0031}},	//   koen_, mobl, _לויפ, ícky,
   {{0xdb000012,0x161b05d4,0x200900d3,0xe1ff04d8}},	//   _româ, नदार_, cmai_, ntón_,
   {{0x27ed4ad0,0x7bc3023b,0xf38d006e,0x2565022b}},	//   doen_, ënua, יראָ, _kňlč_,
   {{0x61ee4ad1,0x00000000,0x00000000,0x00000000}},	//   nobl, --, --, --,
   {{0x38c8001c,0x2d980212,0x27ed4ad2,0x00000000}},	//   غاتی_, _inre_, foen_, --,
   {{0x27ed02a7,0xd6d900a5,0x6d5e007a,0xdcfc01d3}},	//   goen_, wała_, lgpa, _garā,
   {{0x9f400018,0x61ee07d0,0xa3c00b42,0xd6d9007f}},	//   llió_, kobl, ंघन_, tała_,
   {{0x6d5e4ad3,0x61ee030b,0x273a0023,0xe1ff0143}},	//   ngpa, jobl, ẫn_, etón_,
   {{0x443803a9,0x3dbe0081,0xb4b60251,0x61ee0117}},	//   èr_, _আদাল, छने_, dobl,
   {{0x78fb00ca,0xd6d9007f,0x23bb0216,0x00000000}},	//   _פלאפ, sała_, _bëja_, --,
   {{0xa3be02e8,0x59b002d5,0x2fc04ad4,0x00000000}},	//   _इतर_, _जकार, dhig_, --,
   {{0xbf9b4ad5,0xa91c0031,0xd49a004d,0x00000000}},	//   _chên, _maľo, _гри_, --,
   {{0x657a4ad6,0x00000000,0x00000000,0x00000000}},	//   meth, --, --, --,
   {{0x657a4ad7,0x2d98020a,0x6d5e084e,0x61ee009c}},	//   leth, _anre_, egpa, aobl,
   {{0x645a4ad8,0xaefb0139,0x20094ad9,0x61ee4ada}},	// [4170] luti, _abùr, rmai_, bobl,
   {{0xd904172a,0x657a0201,0x27ed4adb,0x200900e4}},	//   _می_, neth, zoen_, smai_,
   {{0xdcfc0029,0x645a4adc,0x69c01f88,0x2fc001b9}},	//   _parā, nuti, वसनी, bhig_,
   {{0x657a0060,0x4a75004b,0x2fc0042c,0xf1b900e8}},	//   heth, дыкт, chig_, īšu_,
   {{0x645a4add,0x657a4ade,0x3f994adf,0xc5f800d9}},	//   huti, keth, _insu_, klē_,
   {{0x645a1075,0x657a4ae0,0xe9d800c6,0x3f894ae1}},	//   kuti, jeth, пкі_, ldau_,
   {{0x27ed4ae2,0xe7390084,0xb7b50023,0xaefb0032}},	//   toen_, оей_, _dụn, _gbùr,
   {{0x645a4ae3,0x2249080e,0x3f894ae4,0x9605397e}},	//   duti, _ovak_, ndau_, रष्ट_,
   {{0x27ed4ae2,0x386701c5,0x657a0060,0xdce70138}},	//   roen_, stnr_, feth, _pajė,
   {{0x27ed4ae5,0x645a4ae6,0x657a4ae7,0x776200ee}},	//   soen_, futi, geth, _ecox,
   {{0x645a4ae8,0x9f4b00b6,0xdb000076,0x3f994ae9}},	//   guti, _akcí_, _iomá, _onsu_,
   {{0xd6ce00d0,0x58040076,0x00000000,0x00000000}},	//   اقی_, _كولك, --, --,
   {{0x61ee4aea,0x3f8902ad,0x657a4aeb,0xe1ff3e6a}},	//   tobl, ddau_, beth, rtón_,
   {{0xe1ff0610,0x657a00d1,0x213e0037,0x3f994aec}},	//   stón_, ceth, úth_, _ansu_,
   {{0xc7b80019,0x645a3f77,0xdb000072,0x7afd004d}},	//   _ttđt_, cuti, _momá, _østf,
   {{0xee3a021a,0x3e66025a,0x3a2d07ac,0x7dc002db}},	//   жна_, tôt_, _otep_, _möse,
   {{0x7dc0190f,0x61ee05b4,0x3f860031,0x68e40233}},	// [4180] _löse, pobl, ľou_, ğidi,
   {{0x3f8902e0,0xfd12114c,0x27e0011d,0x628400ac}},	//   adau_, نجا_, čini_, _isio,
   {{0x93bd002d,0xdb1906a3,0x3a2d0449,0xdb0000ee}},	//   mpăr, viwò, _atep_, _somà,
   {{0x3e660257,0x657a4aed,0x00000000,0x00000000}},	//   pôt_, zeth, --, --,
   {{0x657a4aee,0xe1ff0103,0x7f44037a,0x8e7500ae}},	//   yeth, któl_, maiq, _пурч,
   {{0x082a3407,0x645a00f9,0x7dc00364,0x62840a4b}},	//   оции_, yuti, _böse, _msio,
   {{0xdb000618,0xab2a116d,0x701c0033,0x657a4aef}},	//   _domá, _мова_, _তবুও_, veth,
   {{0x645a4586,0xf76f1a13,0x657a4af0,0xdb0005fe}},	//   vuti, لاً_, weth, _tomà,
   {{0x6e220080,0xb4b6000d,0x657a4af1,0x8966036a}},	//   íobh, छन्_, teth, _окаж,
   {{0x7bc24af2,0x645a4af3,0x65ad0031,0xb8b60284}},	//   lhou, tuti, _súhr, _осећ,
   {{0xd7ef016a,0x62840084,0x657a4af4,0x799a0193}},	//   _ау_, _asio, reth, _intw,
   {{0x645a4af5,0x7bc203ee,0x657a0201,0xb21b01cd}},	//   ruti, nhou, seth, kvæt,
   {{0x6d4e03ce,0x7d1c033b,0xe5c600c2,0x6aa20072}},	//   _odba, _ogrs, _оско, nxof,
   {{0x79884af6,0x7d030094,0x00000000,0x00000000}},	//   _jadw, ýnsk, --, --,
   {{0x798803e5,0x29180220,0x7bc20371,0x69c60138}},	//   _madw, _úrad_, khou, _įkel,
   {{0x80a00455,0x7bc201c0,0x98a7042d,0x6d4e0027}},	//   _ऑपरे, jhou, žiću_, _adba,
   {{0x799a1d19,0x443c022e,0x63ad00d3,0x7c2e00d9}},	// [4190] _ontw, _hwv_, _ioan, _atbr,
   {{0x8d771e53,0x63ad0019,0x443c0197,0x7bc22ad7}},	//   بارا, _hoan, _kwv_, ehou,
   {{0xdb004af7,0x2d870220,0x442e0044,0x798a0150}},	//   _romá, ľne_, _jtf_, ddfw,
   {{0x799a4af8,0x63ad4af9,0x2d874afa,0x3f990022}},	//   _antw, _joan, žne_, _unsu_,
   {{0x63ad019c,0xdb000579,0x443c01fa,0x79884afb}},	//   _moan, _pomá, _lwv_, _badw,
   {{0x9f400088,0xd6d90034,0xf1bf4afc,0x79880150}},	//   llið_, wało_, mpás_, _cadw,
   {{0x6d453c25,0x7988008a,0xc7b80234,0x64480381}},	//   maha, _dadw, _suđa_, jsdi,
   {{0x6d454afd,0x7bc24afe,0x799a4aff,0x6448159f}},	//   laha, chou, _entw, dsdi,
   {{0x20190918,0xdb004b00,0x6b9b4b01,0xf7710421}},	//   _misi_, _tomá, _inug, ناک_,
   {{0x77b5132d,0x6d454b02,0x77bc0933,0x20194b03}},	//   _máxi, naha, _véxa, _lisi_,
   {{0x69c30091,0x63ad4b04,0x64483155,0xe1ff4b05}},	//   mhne, _boan, gsdi, rtól_,
   {{0x6d454b06,0xceb401d4,0xdb0002b6,0x03a62105}},	//   haha, yyə_, _domæ, химо,
   {{0x6d452a0b,0x63ad4b07,0x6b890a4b,0x6448084e}},	//   kaha, _doan, _maeg, asdi,
   {{0x20194b08,0x443c022e,0x1aec0081,0x7649026a}},	//   _aisi_, _fwv_, জেকে_, msey,
   {{0x6d454b09,0x7dc002e2,0x20194b0a,0xc0e31d57}},	//   daha, _lösc, _bisi_, горк,
   {{0x67293a2f,0x93bd00ae,0x661809ac,0x63ad044c}},	//   ncej, spăr, _zivk, _goan,
   {{0x6d454b0b,0x76494b0c,0x62840051,0x3cfe0031}},	// [41a0] faha, nsey, _usio, _štv_,
   {{0x6b9b2cb2,0x443c01fa,0x4d63261f,0x69c3033b}},	//   _anug, _ywv_, лкув, jhne,
   {{0x7bc24b0d,0x443c022e,0x69c301b5,0x79884b0e}},	//   thou, _xwv_, dhne, _radw,
   {{0xbea60f2e,0x79880150,0x63ad4b0f,0xddcd007f}},	//   _замк, _sadw, _xoan, grał,
   {{0x7bc20934,0x6d454b10,0xb21b038c,0x79880313}},	//   rhou, baha, lvær, _padw,
   {{0x6d450918,0x7bc24b11,0x69c34b12,0x28f811a1}},	//   caha, shou, ghne, мель_,
   {{0x7c2e0ec9,0x307a00c1,0x7bc218f0,0x6b8902a1}},	//   _utbr, לאַנ, phou, _faeg,
   {{0x2d8a4b13,0x6618011d,0x6b890154,0x79884b14}},	//   _habe_, _sivk, _gaeg, _wadw,
   {{0x7bc04b15,0x661810b0,0x69c30a1b,0x442e4b16}},	//   _ilmu, _pivk, bhne, _stf_,
   {{0x69c34b17,0x81b00022,0x2d8a01e9,0xe96700d3}},	//   chne, _kuɓu, _jabe_, _паул_,
   {{0x61fc0abd,0x81d60081,0x6448013f,0x63ad4b18}},	//   dlrl, িকা_, usdi, _poan,
   {{0x2d8a4b19,0xd5b80029,0x6d454b1a,0xb21b3229}},	//   _labe_, skā_, zaha, dvær,
   {{0x6d454b1b,0x20194b1c,0x63ad4b1d,0xdb0b042c}},	//   yaha, _risi_, _voan, ckgä,
   {{0x20191e9a,0x27e00335,0x7afd038c,0x443c006c}},	//   _sisi_, činu_, _øste, _twv_,
   {{0x7bc00dea,0x6d454b1e,0xfd600174,0x443c029a}},	//   _olmu, vaha, _wezụ, _uwv_,
   {{0x77b54b1f,0x6d454b20,0x2d8a008c,0x00000000}},	//   _páxi, waha, _aabe_, --,
   {{0x2d8a4b21,0x20194b22,0x28c00179,0x80d102d5}},	// [41b0] _babe_, _visi_, षैति, _डेरे,
   {{0x9ce74b23,0x20194b24,0x7bc301d3,0x6b89009c}},	//   нцел, _wisi_, īnum, _saeg,
   {{0x6d454b25,0x2d8a01e9,0xf99f0023,0x3b2e0134}},	//   raha, _dabe_, _đè_, _ịyị_,
   {{0x291e00f9,0x77b50131,0xbbbd1e05,0x00000000}},	//   _agta_, _táxi, ्फेक, --,
   {{0x6d454b26,0x69c30a02,0x6b8900b7,0x3f8b033c}},	//   paha, thne, _vaeg, _iacu_,
   {{0x2d8a02a7,0x7e6d4b27,0x3f8b0027,0x7bc04b28}},	//   _gabe_, mtap, _hacu_, _elmu,
   {{0x69c300e7,0x3f8b4b29,0x7e6d4b2a,0x18a52012}},	//   rhne, _kacu_, ltap, тайм,
   {{0x3f8b14f3,0x2d8a006d,0xaad20d7a,0x76494b2b}},	//   _jacu_, _zabe_, _देवक, tsey,
   {{0x7e6d4b2c,0xba741f11,0x69c3022b,0x2d8a4b2d}},	//   ntap, _مالت, phne, _yabe_,
   {{0xef1f4b2e,0xdb000704,0x76494b2f,0x6729007e}},	//   _saül_, _domä, rsey, scej,
   {{0x69c10fea,0x39474b30,0x7afd00f2,0xf50200e5}},	//   _ille, mans_, _østb, изьо,
   {{0x39474b31,0x7d1a003e,0x7e6d07ee,0x00000000}},	//   lans_, _útse, ktap, --,
   {{0x95854b32,0xd299004d,0x7dc002c3,0xddc4044c}},	//   _алле, нтрі_, _lösa, ntiţ,
   {{0x39474b33,0xdb1b0428,0x65c70139,0xb8850065}},	//   nans_, _lluï, _déhù, _gríì,
   {{0xa0674b34,0xb21b01c5,0x2d8a4b35,0x3f8b02a4}},	//   кара_, tvær, _rabe_, _bacu_,
   {{0x2d8a0b0b,0xc2c600e3,0x3f8b3351,0x00000000}},	//   _sabe_, _ليبي, _cacu_, --,
   {{0x321a0074,0x39474b36,0x7e6d4b37,0x69c14b38}},	// [41c0] _tipy_, kans_, gtap, _olle,
   {{0xb21b4b39,0x39474b3a,0x62960079,0x5d160a85}},	//   svær, jans_, _iryo, نباز,
   {{0x39474b3b,0x7afb0f20,0x0b4600d6,0xc1bb040a}},	//   dans_, _ayut, внен, _חמיש,
   {{0x24871d32,0x22404b3c,0x629600d8,0x3f8b0169}},	//   _msnm_, _kwik_, _kryo, _gacu_,
   {{0x39474b3d,0xaad2030b,0x2d8a4b3e,0xa3ea055c}},	//   fans_, _देशक, _tabe_, _मदन_,
   {{0x7afb02c9,0x3f8b02a4,0x39474b3f,0x260609a1}},	//   _dyut, _zacu_, gans_, _सीढी_,
   {{0x8c432dd1,0x25ae4b40,0xdca31d7b,0x83fd2461}},	//   _весе, _rofl_, _кари, luđe,
   {{0x69c1017a,0xd90d09b4,0x62962621,0x77bc0072}},	//   _elle, سین_, _oryo, _véxo,
   {{0x39474b41,0x83fd0039,0x7c293c9a,0x00000000}},	//   bans_, nuđe, _čeri, --,
   {{0x39474b42,0xe1ff49d6,0x69c103a8,0x00000000}},	//   cans_, rtók_, _glle, --,
   {{0x3a244b43,0x7e6d0634,0x69d84b44,0x629605bd}},	//   _hump_, ztap, mive, _aryo,
   {{0xccf30054,0x629603a9,0x69d826a4,0x3a240063}},	//   יכת_, _bryo, live, _kump_,
   {{0x645d0138,0x83fd1523,0x27e60113,0xe29801b3}},	//   ąsia, juđe, _ijon_, ваў_,
   {{0x720500e3,0x69d81b9e,0xbbaf0096,0x00000000}},	//   اوسم, nive, _झक्क, --,
   {{0x2fc202e7,0x3f8b4b45,0x6296083e,0x00000000}},	//   _blkg_, _pacu_, _eryo, --,
   {{0x39474b46,0x645a031a,0x7e6d4b47,0x2b44024a}},	//   zans_, mrti, ttap, _nemc_,
   {{0x39470c56,0x69d80407,0x2ceb00aa,0x00000000}},	// [41d0] yans_, kive, _जुड़ल_, --,
   {{0x7e6d4b48,0x3947027e,0x69d8033b,0x645a3104}},	//   rtap, xans_, jive, orti,
   {{0x39474b49,0x7e6d4b4a,0x7afb2608,0x63bd0138}},	//   vans_, stap, _syut, oksn,
   {{0x83fd08c5,0x7e6d03a9,0x39470239,0xbddb02f1}},	//   buđe, ptap, wans_, _avèt,
   {{0x39474b4b,0xb5fd0074,0x8aa700e5,0x81d60033}},	//   tans_, luše, ържд, িকর_,
   {{0x69d805a3,0xe81b0557,0x1a680470,0x6d3400ae}},	//   give, _पूजा_, ئیلی_, _верф,
   {{0x394714b1,0x2d814b4c,0xddc400d3,0x2369015c}},	//   rans_, mehe_, stiţ, _ocaj_,
   {{0x39474b4d,0x23690197,0x2d814b4e,0x7afb0009}},	//   sans_, _ncaj_, lehe_, _tyut,
   {{0xe6190b57,0x39474b4f,0x69d84b50,0x0a68007e}},	//   нди_, pans_, bive, _архи_,
   {{0x7dc00222,0xb5fd15f4,0xddcd0034,0xceb200c1}},	//   _lösn, kuše, jważ, ציי_,
   {{0xddc416d4,0xa3c0009f,0x59b8097c,0xd8771f11}},	//   ntiš, ंघल_, _अवतर, _جاذب,
   {{0xdb1b05fe,0x629614d0,0xe1ff0034,0xb5fd1b32}},	//   _lluí, _pryo, otów_, duše,
   {{0xe1ff00a5,0x2d810113,0x673b4b51,0xe29710e0}},	//   ntów_, kehe_, mbuj, гая_,
   {{0x27ff4b52,0xa594008f,0x2d810dd9,0xddc40138}},	//   llun_, _връщ, jehe_, ktiš,
   {{0x057409e5,0x50b50ed7,0xaf9a0c4a,0x765b029a}},	//   _خاند, асту, нтах_, lruy,
   {{0xe1ff00a5,0x200b030b,0x69d84b53,0x39454b54}},	//   któw_, _chci_, zive, _lels_,
   {{0x69d84b55,0xaf0603a0,0x27ff00c2,0xe81b08d4}},	// [41e0] yive, упал, ilun_, _पूछा_,
   {{0xdca60291,0x69d825b0,0x531b00ca,0xd23b00ca}},	//   лази, xive, _אופצ, _רגיל,
   {{0x3a2401af,0x27e94b56,0x69d80b21,0x83fd00cb}},	//   _sump_, čanj_, vive, suđe,
   {{0x4fa6120c,0xaca40174,0xab2a0613,0x6e364b57}},	//   _симв, _ntụr, хода_, ppyb,
   {{0xdb1b4b58,0x673b0087,0x68ff00a7,0x69340103}},	//   _fluí, dbuj, əqdi, لکار,
   {{0x7c290074,0xaca40129,0x7d030364,0x645a003e}},	//   _červ, _atụr, ünsc, yrti,
   {{0x3945429b,0xa2db16e2,0x6e260bb6,0xfd690294}},	//   _dels_, _पेन्, _hukb, hapụ,
   {{0x69d84b59,0x57b40b2e,0x8b9549cc,0x76aa283b}},	//   sive, рбит, _круч, етов_,
   {{0x386e4b5a,0xdcee0138,0x2bb90d75,0x6e260381}},	//   stfr_, _pabė, _आवता, _jukb,
   {{0x80ba0081,0x6b824b5b,0x645a033b,0x6474008d}},	//   _উইন্, leog, trti, агоу,
   {{0x6e2600f9,0x645a4b5c,0x8d5b006e,0x00000000}},	//   _lukb, urti, עכטי, --,
   {{0x645a4b5d,0x6b820503,0x1bf408d4,0x3cdc00aa}},	//   rrti, neog, इकिल_, _गइने_,
   {{0x59b80775,0x63bd19db,0xdb19042c,0x2d810079}},	//   _अवार, rksn, chwä, yehe_,
   {{0x645a0087,0x6b8200f9,0xb5fd0141,0x76420af0}},	//   prti, heog, tuše, _iwoy,
   {{0x86070e5a,0xdb0011ce,0xaca30134,0x61f54b5e}},	//   _حقوق_, _comú, _kwục, rozl,
   {{0xb5fd0579,0x2d814b5f,0x200004f8,0x6e264b60}},	//   ruše, wehe_, glii_, _bukb,
   {{0xa3ea02e8,0x6b824b61,0x141c00a1,0xbebb00dd}},	// [41f0] _मदत_, deog, _אוהב, _afër,
   {{0x21673715,0x76420517,0xbddb020d,0x2000020a}},	//   _стиг, _mwoy, _avèr, alii_,
   {{0x80d300c7,0x2d81068d,0x99d5001c,0x673b0d46}},	//   _দুর্, rehe_, یتتا, ybuj,
   {{0x67224b62,0x3945014b,0xa1340018,0x6b82044c}},	//   _ngoj, _sels_, _پریش, geog,
   {{0x39450990,0xa9692ac0,0xddc44b63,0xfaa520e6}},	//   _pels_, вила_, stiš, рало,
   {{0x9f520257,0xa85507ed,0x9855022f,0x2c5e0294}},	//   voyé_, атиј, атиш, _ọdee_,
   {{0xe1ff0067,0x76424b64,0xdb0201cd,0x5b3703ef}},	//   stów_, _awoy, skoð, _معذر,
   {{0x765b4b65,0x98a500d3,0x9b890068,0x656a01f7}},	//   truy, _află_, _جنرل_, _acfh,
   {{0x6d470496,0x673b034f,0xdb090088,0x39450257}},	//   _keja, rbuj, _gleð, _tels_,
   {{0x6d4710e3,0x7e7d0063,0x3ea900ee,0x00000000}},	//   _jeja, _mpsp, ixat_, --,
   {{0xa3ea10ed,0x79834b66,0x9d220081,0x38bb0032}},	//   _मदद_, menw, _পড়ুন_, _dàrú_,
   {{0x6d474b67,0x7e7d34c8,0x79830150,0xaca30134}},	//   _leja, _opsp, lenw, _gwục,
   {{0x9814003f,0x75d50068,0xe5a502e1,0x6286029a}},	//   _ابلا, _پيغا, _вили, uwko,
   {{0x6d474b68,0x79834b69,0x2c51007f,0x6b8220c2}},	//   _neja, nenw, kąd_, zeog,
   {{0x6e260124,0x7e7d01d3,0x59b817ad,0x46d900c3}},	//   _sukb, _apsp, _अवसर, _बेतह,
   {{0xa0670303,0x6d554b6a,0x442700d3,0x2fc92375}},	//   јата_, _adza, _iun_, ghag_,
   {{0x44274b6b,0x6d474b6c,0x79834b6d,0x3e6f047e}},	// [4200] _hun_, _beja, kenw, güt_,
   {{0x44274b6e,0x44201ee3,0x7c273141,0x6d47034f}},	//   _kun_, _hii_, _bujr, _ceja,
   {{0x6d474b6f,0x44204b70,0x6b824b71,0x44274b72}},	//   _deja, _kii_, teog, _jun_,
   {{0x44274b73,0x44200139,0x7c290094,0xfc030859}},	//   _mun_, _jii_, _čert, опхо,
   {{0x44204b74,0x79834b75,0x83fd00cb,0x00000000}},	//   _mii_, fenw, nuđa, --,
   {{0xe85416cc,0x79834b76,0x44274b77,0xfd670134}},	//   منتد, genw, _oun_, _merụ,
   {{0xfce33e04,0x44274b78,0x80b60081,0x44200231}},	//   _доро, _nun_, ৃপক্, _oii_,
   {{0x442005a7,0x99dd022b,0x2fc04b79,0xdcee00e8}},	//   _nii_, _pwňc, nkig_, _labī,
   {{0x44274b7a,0x79830364,0x00000000,0x00000000}},	//   _aun_, benw, --, --,
   {{0x44274b7b,0x77bc2c90,0x44204b7c,0x9f59022b}},	//   _bun_, _méxi, _aii_, _eksè_,
   {{0x442722e7,0x2fc001a2,0x44200d79,0x77860fa5}},	//   _cun_, kkig_, _bii_, _влез,
   {{0x44274b7d,0xe73a0b57,0x07a31e23,0x67220095}},	//   _dun_, _ред_, _махн, _ugoj,
   {{0x44274b7e,0x44204b7f,0x659416dd,0x2c51007f}},	//   _eun_, _dii_, _галу, ząd_,
   {{0x442700a1,0x2fc90124,0x7c204b80,0xd49a007e}},	//   _fun_, whag_, _limr, _ари_,
   {{0x44270049,0x44200012,0x0ce10081,0x6d474b81}},	//   _gun_, _fii_, _ভর্ত, _reja,
   {{0x6d474b82,0x44204b83,0x2fc04b84,0x251b00ca}},	//   _seja, _gii_, gkig_, _בווא,
   {{0x6d4726f7,0xd2510080,0x44270062,0xa9230094}},	// [4210] _peja, _عند_, _zun_, ážko,
   {{0x44270256,0x14ca0096,0x44204b85,0x7c2003d3}},	//   _yun_, ानपण, _zii_, _aimr,
   {{0x44200649,0x409500e3,0x7c29025b,0x4427008a}},	//   _yii_, _الجر, _čers, _xun_,
   {{0x44201f72,0x0c242680,0x7c204b86,0x2fc00fe8}},	//   _xii_, імін, _cimr, ckig_,
   {{0x6d474b87,0x79833700,0x7c200052,0x2d87020d}},	//   _teja, tenw, _dimr, ônes_,
   {{0xb5fd0106,0xb6020146,0x389501d3,0x7f4d008c}},	//   kuša, _žánr, _pār_, laaq,
   {{0xb5fd00d9,0x7983365f,0x6e2d31ed,0x3b6700e5}},	//   juša, renw, lqab, _възв,
   {{0x07120134,0x442700a1,0x7c200063,0x7f4d008c}},	//   _gụkọ, _run_, _gimr, naaq,
   {{0x26cd0106,0x2d9103ce,0x44200d79,0x44274b88}},	//   uzeo_, _kaze_, _rii_, _sun_,
   {{0x44272c09,0x44204b70,0x69ca042c,0xf9d40012}},	//   _pun_, _sii_, chfe, _доуэ,
   {{0x2d91023f,0x85110034,0x69fa00c1,0xdb0005aa}},	//   _maze_, डेंट_, _עלעק, _anmè,
   {{0x4427020b,0x671b0557,0x481537e8,0x4420010a}},	//   _vun_, _पृथक_, _умес, _qii_,
   {{0x44204b89,0x44270065,0x79a400d3,0x1af70033}},	//   _vii_, _wun_, _урӂе, েশকে_,
   {{0x44274b8a,0x77bc0933,0xa06a4b8b,0x4420257e}},	//   _tun_, _réxi, лага_, _wii_,
   {{0x44204b8c,0xd435006f,0x8fa64b8d,0x4427008a}},	//   _tii_, _اعتب, баве, _uun_,
   {{0x44200167,0x645c02ef,0x00000000,0x00000000}},	//   _uii_, šric, --, --,
   {{0x2d914b8e,0x63a44b8f,0x2a7f023e,0xd007282a}},	// [4220] _baze_, _inin, _npub_, сете_,
   {{0xd83809ac,0x63a403a9,0x7c200de9,0xef170284}},	//   _hrče_, _hnin, _simr, сму_,
   {{0x63a41912,0x2d912414,0xa7320139,0x46d903b3}},	//   _knin, _daze_, _fọhù, _बेसह,
   {{0x6e2d0188,0xc7b80995,0xe1ff00b3,0xdee60307}},	//   bqab, _tuđi_, btós_, _гоми,
   {{0x7e644b90,0xaad20cce,0x69ca4b91,0x7afd004d}},	//   quip, _देखक, thfe, _østl,
   {{0xcaa500e3,0x22440146,0x9f490088,0xa37b0231}},	//   تصمي, ámky_, llað_, miõe,
   {{0x63a44b92,0xc0f20019,0x7c204b93,0xa37b0131}},	//   _onin, _rượu_, _timr, liõe,
   {{0x63b64b94,0x96344b95,0x63a4083e,0x69ca4b96}},	//   _noyn, ониц, _nnin, shfe,
   {{0xcf9300a1,0xa37b001f,0x00000000,0x00000000}},	//   לטה_, niõe, --, --,
   {{0x63a44b97,0xf9c40260,0x7bc200f9,0x545402d8}},	//   _anin, _بحری, lkou, овот,
   {{0x26c24b98,0x293707a6,0xc7af0084,0x69da4b99}},	//   ško_, _האבן_, _её_, _imte,
   {{0x290c4b9a,0x63b6009c,0x7bc24b9b,0x00000000}},	//   _izda_, _coyn, nkou, --,
   {{0xadfa178d,0x6e2d0188,0x63a4009c,0x59be06eb}},	//   ्तान_, xqab, _dnin, ्सपर,
   {{0x236d00a5,0xb5fd025b,0x63a44b9c,0x7f4d008a}},	//   żej_, lušn, _enin, waaq,
   {{0xcad20174,0x2d910ca3,0x7bc2007b,0x7f4d041c}},	//   dịmị, _raze_, kkou, taaq,
   {{0x543b0130,0x628d0037,0x290c0146,0x2d850034}},	//   _געהא, _tsao, _mzda_, _źle_,
   {{0xa37b001f,0x2d9100cc,0x7f4d0188,0x69c84b9d}},	// [4230] giõe, _paze_, raaq, _olde,
   {{0xcaae0033,0x6e2d008c,0xe1ff01f9,0xd83805aa}},	//   কনাফ, rqab, rtós_, _otč_,
   {{0xb5fd0b27,0x249c0090,0x9f4901cd,0x3a380141}},	//   kušn, _jrvm_, blað_, _črpa_,
   {{0x69c84b9e,0xf8a900cd,0xfd1000e3,0x7f4d008a}},	//   _alde, یگاه_, رجل_, qaaq,
   {{0x957c00a5,0xd83805aa,0x2d914b9f,0x69250d62}},	//   ciąg, _atč_, _taze_, омла,
   {{0x957c0034,0xdb1b0428,0x7bc24ba0,0x00000000}},	//   niąd, _lluç, akou, --,
   {{0xd90e0018,0xa2db0296,0xe1ff003e,0x98bc00d2}},	//   ہیے_, _पेस्, próf_, mavě_,
   {{0x6fc90287,0x69c84ba1,0xb5fd00c4,0x00000000}},	//   रसिं, _elde, gušn, --,
   {{0xb7b50134,0x7bdb4ba2,0x969400ae,0x00000000}},	//   _bụr, _imuu, прэш, --,
   {{0xb5fd04fa,0x63a44ba3,0x00000000,0x00000000}},	//   krše, _snin, --, --,
   {{0x7bc915b9,0xb5fd21b8,0x63860cc6,0x6d580076}},	//   _kleu, bušn, огна, óvai,
   {{0x645c001f,0xe29a016d,0xf1a90eda,0x00000000}},	//   ária, аам_, _בס_, --,
   {{0x7bdb00e7,0xbddb0154,0x87070411,0x00000000}},	//   _mmuu, _pwèl, _ابال, --,
   {{0x83fd005f,0x38a0002d,0x7bc90e0f,0x7bc2030b}},	//   vrđe, _fără_, _lleu, zkou,
   {{0xd83800cb,0x7bc90178,0x7bdb0172,0x7bc24ba4}},	//   _trče_, _oleu, _omuu, ykou,
   {{0x63a44ba5,0x7c29025b,0x0fb300a5,0x6fda00b6}},	//   _unin, _čerp, ीसगढ, můck,
   {{0x82360dce,0x69c34ba6,0xee374ba7,0x00000000}},	// [4240] _بربا, kkne, жну_, --,
   {{0x7bc94ba8,0x7bdb4ba9,0xad660286,0x715a00ae}},	//   _aleu, _amuu, تاره, _трис_,
   {{0x7bc90257,0xa37b0161,0xcc360037,0x7afd02b6}},	//   _bleu, siõe, زراع, _østj,
   {{0x2d0a009d,0x61fc00ae,0xa2c108d4,0x7bc90231}},	//   _वरील_, lorl, रैक्, _cleu,
   {{0xf38d00c1,0x7bc21190,0x98bc00d2,0x00000000}},	//   טראָ, rkou, bavě_, --,
   {{0x61fc4baa,0x3e7400c2,0x7bc24bab,0x8e0700ae}},	//   norl, mät_, skou, _мняв_,
   {{0xa9674bac,0x7bc94bad,0x7e762b31,0x91a900fe}},	//   ција_, _fleu, ltyp, _quả_,
   {{0x7bc910c2,0x61fc4bae,0x17f70037,0xef1f00b3}},	//   _gleu, horl, يرية_, _taüt_,
   {{0x61fc4baf,0x7e764bb0,0xa96a2a84,0xb7b50174}},	//   korl, ntyp, _виза_, _pụr,
   {{0xb5fd14f3,0xd5ba266a,0x69c34bb1,0xe80a0490}},	//   sušn, рси_, ckne, _हीरा_,
   {{0x69a7030b,0x43951111,0x44384902,0x7e76023b}},	//   चारी, панс, ër_, htyp,
   {{0xb5fd02e6,0x47c308cb,0x3e74468a,0x00000000}},	//   vrše, _обхв, kät_, --,
   {{0x671604dd,0x3e740084,0xddcd00d3,0x61fc4bb2}},	//   देशक_, jät_, ntaţ, forl,
   {{0x35f700bf,0xdb000cda,0x3e7400c2,0x61fc4bb3}},	//   _ورود_, _homó, dät_, gorl,
   {{0x7e7601af,0xdb000034,0xc1050037,0x98ac004b}},	//   etyp, _komó, سوري, _vedė_,
   {{0xc7b80542,0xd9c20033,0x394c0ec7,0x443e4bb4}},	//   _tuđu_, ্চিম, _leds_, mpt_,
   {{0x443e4bb5,0x7e764bb6,0x80dc0033,0x69c34bb7}},	// [4250] lpt_, gtyp, _মুদ্, ykne,
   {{0x7bc90305,0x443e0126,0x224900cd,0xdd910037}},	//   _sleu, opt_, _iwak_, عوا_,
   {{0x7bc94bb8,0xc17200ca,0x98bc00b6,0x7c3e00f9}},	//   _pleu, _אחי_, ravě_, gppr,
   {{0x70fa00a1,0x60fa00a1,0x22494bb9,0x443e4bba}},	//   _להתח, _להתק, _kwak_, ipt_,
   {{0xbf360341,0x7bc90db1,0x3f894bbb,0xfbdc02d5}},	//   _מארץ_, _vleu, meau_, _मगरम,
   {{0x22490051,0x3f89014b,0xb5fd00c4,0x3e7b020a}},	//   _mwak_, leau_, gušl, râtă_,
   {{0x69c34bbc,0x443e01c0,0x225e007f,0xdd5800ae}},	//   rkne, jpt_, ątki_, _фасч_,
   {{0x7bdb4bbd,0x3f894bbe,0xdb000037,0x443e00dc}},	//   _umuu, neau_, _comó, dpt_,
   {{0x645c4bbf,0x61fc01e8,0xddcd00d3,0xb5fd033b}},	//   árin, yorl, ctaţ, vršb,
   {{0xb5fd1e3a,0x49b806fa,0xdcfc0095,0x394c009c}},	//   dršc, _والد_, _zarđ, _geds_,
   {{0x22494bc0,0x61fc038c,0x232a18fa,0x64a5013f}},	//   _awak_, vorl, йони_, чана,
   {{0x2b4d00b3,0x7e7613ea,0xdc0300d8,0x00000000}},	//   _jeec_, ytyp, _očís, --,
   {{0x3f894bc1,0x61fc14ce,0x2905002b,0x443e029a}},	//   deau_, torl, _hyla_, apt_,
   {{0x3e740d64,0x29054bc2,0x3cdc007a,0xc692021e}},	//   vät_, _kyla_, _गइले_, _נאו_,
   {{0x550200a5,0x61fc4bc3,0x77bc03be,0x22490113}},	//   _रुपए_, rorl, _téxt, _ewak_,
   {{0x3e744bc4,0x4abd4bc5,0x09b818ff,0x7e7613ea}},	//   tät_, ्नाव, _अव्य, ttyp,
   {{0x4adb0b94,0x29050167,0x61fc4bc6,0xcad20134}},	// [4260] _मेलव, _lyla_, porl, rịkị,
   {{0x3e744bc7,0x7d1a0088,0x00000000,0x00000000}},	//   rät_, _útsk, --, --,
   {{0x7e762b31,0x91bb00ca,0x3e7400c2,0x2249029a}},	//   styp, _המיי, sät_, _zwak_,
   {{0x3f8918f8,0xcb6a0307,0x00000000,0x00000000}},	//   ceau_, саде_, --, --,
   {{0xf1b0045f,0xc3330327,0x29054bc8,0x19940d72}},	//   ञापन, גוד_, _ayla_, даля,
   {{0x443e4bc9,0x2905000d,0x628402ef,0xddcd020a}},	//   ypt_, _byla_, _mpio, rtaţ,
   {{0x7dcb00a5,0x6d5c4bca,0xddcd00d3,0xdb000034}},	//   yższ, _idra, staţ, _pomó,
   {{0x6d4e048e,0xf093040a,0x394c3aab,0xdb0000ee}},	//   _heba, תנה_, _weds_, _domò,
   {{0x6d4e26f7,0x443e0174,0x7c2e4bcb,0x45d44bcc}},	//   _keba, wpt_, _hubr, допс,
   {{0x645c0303,0xddd600a5,0x7c2e4bcd,0x65aa1300}},	//   ário, jwyż, _kubr, стиг_,
   {{0x443e02e2,0x2249057a,0x9f530103,0x493b00ca}},	//   upt_, _swak_, ődés_, _הגבו,
   {{0x6d4e4bce,0x7e644bcf,0x7c2e0113,0x62842bc0}},	//   _leba, krip, _mubr, _bpio,
   {{0x3f894bd0,0xd7a90096,0x35a624f7,0x97c3468d}},	//   veau_, कारच, _надг, _яйце,
   {{0x171b1723,0x6d4e4bd1,0x443e4bd2,0xddcd08a9}},	//   _הודע, _neba, ppt_, ktaš,
   {{0x3cdc02e8,0x3f894bd3,0x628401ff,0x757b00d7}},	//   _गेले_, teau_, _epio, _הטופ,
   {{0x6d5c02ad,0x6d4e0062,0x6284009c,0x645800bd}},	//   _adra, _aeba, _fpio, _ivvi,
   {{0x6d4e0b19,0x3f894226,0x443c4bd4,0x7dc002e2}},	// [4270] _beba, reau_, _htv_, _lösu,
   {{0x200238d5,0x3f89025a,0x7c2e0039,0x6d4e0328}},	//   _ekki_, seau_, _bubr, _ceba,
   {{0x7c2e0fb6,0x3f894bd5,0x6d5c00f0,0x442e0629}},	//   _cubr, peau_, _ddra, _juf_,
   {{0x7c2e0f39,0x2c7502fe,0x7e6409a1,0x443c32e8}},	//   _dubr, råd_, brip, _mtv_,
   {{0x7e644bd6,0x443c17b1,0x6d4e4bd7,0x6d430233}},	//   crip, _ltv_, _feba, ınab,
   {{0x6d4e4bd8,0x20094bd9,0xb5fd0039,0x64584bda}},	//   _geba, llai_, krša, _ovvi,
   {{0x6d454bdb,0x443c4bdc,0x7c2e0167,0xfc64008f}},	//   mbha, _ntv_, _gubr, _пътн,
   {{0x6d5c3f64,0x6d450049,0x6d4e4bdd,0x3a250381}},	//   _zdra, lbha, _zeba, _wilp_,
   {{0x442e3477,0x64584bde,0xb904382d,0x6b8b4bdf}},	//   _auf_, _avvi, _पे_, megg,
   {{0x6b8b4021,0x6d450a02,0x443c4be0,0x6d4e01ff}},	//   legg, nbha, _btv_, _xeba,
   {{0x62842dd0,0x442e0010,0x2009013f,0x6d454be1}},	//   _spio, _cuf_, klai_, ibha,
   {{0xe72e4be2,0xf7700979,0x7dc00222,0x6b8b4be3}},	//   _је_, _ماه_, _höst, negg,
   {{0xe56e4be4,0x27380028,0x27ff0c56,0xb5fd015d}},	//   _из_, _ứng_, moun_, nušk,
   {{0x443c4be5,0x6b8b008f,0x27ed01bf,0x6e270381}},	//   _ftv_, hegg, lnen_, _nijb,
   {{0x27ed4be6,0x957c00a5,0x6d450076,0x33f64be7}},	//   onen_, siąc, dbha, _очис,
   {{0x6d4e1268,0x27ed4be8,0x64412faa,0x7e644be9}},	//   _seba, nnen_, mpli, trip,
   {{0x27ed4bea,0x2216014d,0x6e270126,0xd12f0068}},	// [4280] inen_, _офор, _bijb, امہ_,
   {{0x3f4c0028,0x27ed02e2,0x7e644beb,0xb5fd25d5}},	//   ếu_, hnen_, rrip, dušk,
   {{0x64414bec,0xeb9a1b2d,0x7e644bed,0x225e0034}},	//   npli, жие_, srip, ątku_,
   {{0x27ed0ab2,0xab830084,0xddcd4bee,0x6d45152f}},	//   jnen_, вушк, rtaš, abha,
   {{0x6d4e0283,0xddcd01ac,0x27ff0154,0x27ed02db}},	//   _teba, staš, doun_, dnen_,
   {{0x27ed4bef,0x7c2e4bf0,0xb5fd0dd9,0x6d43008b}},	//   enen_, _tubr, sušj, ınac,
   {{0xdcfc0029,0xd7a9009d,0x27ed01bf,0x6441178f}},	//   _varē, कांच, fnen_, jpli,
   {{0xb5fd1419,0x27ed4bf1,0x443c2024,0x442e128c}},	//   vrša, gnen_, _rtv_, _ruf_,
   {{0x2d984bf2,0x7dc00088,0x442e4bf3,0x443c4bf4}},	//   _kare_, _föst, _suf_, _stv_,
   {{0x7dc00390,0xaa43002d,0x89161363,0x2d984bf5}},	//   _göst, _рефл, _قبائ, _jare_,
   {{0x9cec0f71,0x2d984bf6,0x200900f0,0x83fd0234}},	//   _করুন_, _mare_, ylai_, luđi,
   {{0x2d984bf7,0x443c00de,0x626f0022,0x61ee0381}},	//   _lare_, _vtv_, lɗoɗ, enbl,
   {{0x2d9800d3,0xdcf500d9,0x83fd077e,0x442e01c2}},	//   _oare_, _pazī, nuđi, _wuf_,
   {{0x6b8b01c0,0x3f820022,0x8c140081,0x7dc015cd}},	//   zegg, _abku_, িদিন_, _möss,
   {{0x6e2701c0,0x26c40138,0x7dc007ee,0x00000000}},	//   _rijb, lymo_, _löss, --,
   {{0x2d984bf8,0x2a660063,0xa8050072,0xf4830120}},	//   _aare_, krob_, miñá, _рушн,
   {{0xd90400cd,0x2d984bf9,0x6b8b4bfa,0x00000000}},	// [4290] _چی_, _bare_, vegg, --,
   {{0x4429022e,0x2d9800a1,0x6d454bfb,0x6b8b0361}},	//   _hia_, _care_, ubha, wegg,
   {{0x44294bfc,0x7dc00222,0x6d450091,0x6b8b008f}},	//   _kia_, _röst, rbha, tegg,
   {{0x26c4013f,0xb5fd3fa3,0x7dc002c3,0x6e270381}},	//   kymo_, tušk, _böss, _wijb,
   {{0x44294bfd,0x6b8b4bfe,0x2d984bff,0x27ed13c8}},	//   _mia_, regg, _fare_, vnen_,
   {{0x44294c00,0x2d984c01,0x26c4013f,0xba3d00b6}},	//   _lia_, _gare_, dymo_, _průb,
   {{0x3f994c02,0x44294c03,0x6b8b028d,0x7e6d4c04}},	//   _kasu_, _oia_, pegg, luap,
   {{0x64414c05,0x44294c06,0x27ed4c07,0x83fd14f3}},	//   vpli, _nia_, unen_, buđi,
   {{0x3f992bc2,0x27ed0e74,0x27ff4c08,0x2fc90124}},	//   _masu_, rnen_, roun_, ikag_,
   {{0x7c29401f,0xe93803ed,0xe6160ab3,0x44294c09}},	//   _hier, _قسمت_, нды_, _aia_,
   {{0x44294c0a,0x7c294c0b,0xf3e64a4e,0xb5fd4c0c}},	//   _bia_, _kier, ежно, bršn,
   {{0x44294c0d,0x6441029a,0x3f994c0e,0xc7c4176e}},	//   _cia_, rpli, _nasu_, _исчи,
   {{0x44294c0f,0x64414c10,0x7c294c11,0x2d830ea3}},	//   _dia_, spli, _mier, _obje_,
   {{0x7c291f6d,0xb5fd3b1a,0x64414c12,0x645501f9}},	//   _lier, kuši, ppli, ázis,
   {{0xf50502ec,0x3f99006d,0xb5fd00d9,0x44294c13}},	//   _язко, _basu_, juši, _fia_,
   {{0x442900ef,0x2d984c14,0x7c294c15,0x35c50251}},	//   _gia_, _sare_, _nier, _लकड़,
   {{0x9cec00c7,0x7dd201c5,0x3f990044,0xd00f0037}},	// [42a0] _করেন_, _læse, _dasu_, صلك_,
   {{0x44294c16,0x22404c17,0x2b5f00d3,0xdb002169}},	//   _zia_, _itik_, _aduc_, _komö,
   {{0x2d9802fe,0x3a3f0124,0x7c294c18,0x44294c19}},	//   _vare_, _atup_, _bier, _yia_,
   {{0x7c294c1a,0x2d984c1b,0xf43a006e,0xf8b00e27}},	//   _cier, _ware_, לגעמ, یکا_,
   {{0x2d984c1c,0xb5fd02e6,0x7c294c1d,0x66010146}},	//   _tare_, vršn, _dier, kolk,
   {{0x98a507d1,0x3f99006d,0x7c294c1e,0x6bda0103}},	//   _adlı_, _zasu_, _eier, _کورس_,
   {{0x3ea04c1f,0x3f9903e3,0x7c290707,0x83fd0995}},	//   lvit_, _yasu_, _fier, suđi,
   {{0x26c4013f,0xdb2101bf,0xf76f00ab,0xdb000042}},	//   tymo_, _äuße, ماً_, _enmá,
   {{0xc6f802ec,0xe1ff4c20,0x660102fe,0x36d402f3}},	//   ьних_, drón_, folk, топр,
   {{0x44294c21,0xa3e3382b,0x7c294c22,0x26c40138}},	//   _sia_, फोन_, _zier, rymo_,
   {{0xd7ef493c,0x44291ee3,0x22400c56,0x6296022b}},	//   _бу_, _pia_, _atik_, _asyo,
   {{0x87da2761,0x07da0391,0x442901fa,0x7c29003d}},	//   _عباس_, _عذاب_, _qia_, _xier,
   {{0x66010694,0x51870ba9,0x3f994c23,0x799a4c24}},	//   bolk, нува, _rasu_, _katw,
   {{0x80b5397e,0x44290381,0x69ca02db,0x91a9020b}},	//   _उपदे, _wia_, nkfe, _quà_,
   {{0x22404c25,0x3f994c26,0x44294c27,0xe1ff167e}},	//   _etik_, _pasu_, _tia_, brón_,
   {{0x645a4c28,0x5f9410f7,0x44294c29,0x2614009d}},	//   msti, лист, _uia_, _नीती_,
   {{0x645a4c2a,0x63ad4c2b,0x7c290472,0x3f994a4f}},	// [42b0] lsti, _inan, _rier, _vasu_,
   {{0x3f990a75,0x7c294c2c,0xf41f0084,0x799a02a4}},	//   _wasu_, _sier, lmä_, _natw,
   {{0x7c2919ca,0x7e6d005c,0x3a3f25f2,0x63ad00f9}},	//   _pier, suap, _stup_, _knan,
   {{0xeaec09d0,0x7c29034f,0x3244001c,0x69ca02ac}},	//   जपूत_, _qier, _جنیف, ekfe,
   {{0x7c294c2d,0x2bb80080,0xa30f00a3,0x645a01f7}},	//   _vier, عامة_, _सरोज_, hsti,
   {{0x7c294c2e,0xf41f00c2,0xdcfc0138,0x59a402d5}},	//   _wier, hmä_, _narė, _गोदर,
   {{0x7c294c2f,0x66010305,0x645a4c30,0x83fd0559}},	//   _tier, volk, jsti, luđu,
   {{0xdb2300bf,0x645a00f2,0xf41f0181,0x7dd2052f}},	//   _موزی, dsti, jmä_, _væse,
   {{0x799a0b08,0x645a4c31,0x79a74c32,0x00000000}},	//   _fatw, esti, _прже, --,
   {{0x63ad00bf,0x6b9b00d6,0x799a0bbd,0x645a4c33}},	//   _anan, _haug, _gatw, fsti,
   {{0x6b9b3721,0xe1ff4c34,0x22404c35,0x7d1a01ab}},	//   _kaug, trón_, _stik_, _útst,
   {{0xa3dc00a5,0x957c0034,0x6d570188,0x6b9b020d}},	//   णों_, wnąt, haxa, _jaug,
   {{0xe1ff4c36,0x3cf50e52,0xdb1b014b,0x799a3304}},	//   rrón_, ्थडे_, _boué, _yatw,
   {{0xf5050318,0x63ad4c37,0x645a1cf0,0x6b9b4c38}},	//   _изло, _enan, bsti, _laug,
   {{0x1c11000f,0xdd921ac9,0x91a90023,0xdb000131}},	//   ़ताल_, یور_, _quá_, _homô,
   {{0x63ad05db,0x673b2347,0xe1ff0103,0xdfd20037}},	//   _gnan, ncuj, lról_, جير_,
   {{0xd0072b99,0x35a60fef,0x2a7d023e,0x629600f9}},	// [42c0] тете_, _कोड़, jtwb_, _usyo,
   {{0xdca6349e,0x3ea04c39,0xa2db13ae,0x9f400076}},	//   кази, rvit_, _पेट्, nniú_,
   {{0x6b9b4c3a,0x9f400037,0x3ea04c3b,0xa03a0076}},	//   _baug, iniú_, svit_, _تأخر_,
   {{0xfdbd0455,0x9f4000e3,0x799a2253,0x9c820087}},	//   ोसॉफ, hniú_, _satw, ščob,
   {{0xdaba00bf,0xe1ff0018,0x6b9b4c3c,0x799a02f1}},	//   بهشت_, król_, _daug, _patw,
   {{0x645a4c3d,0x9d434c3e,0x799a010a,0x35a600bc}},	//   ysti, _верд, _qatw, _कोढ़,
   {{0x38c8015a,0x7d030364,0xf41f007b,0x6b9b0565}},	//   عاتی_, ünst, ymä_, _faug,
   {{0x2ca702b6,0x799a4c3f,0x6b9b4c40,0x00000000}},	//   ænde_, _watw, _gaug, --,
   {{0x4b7b00c1,0x645a25e1,0x60c70034,0x765b0270}},	//   _קאמו, wsti, zyjm, gsuy,
   {{0x645a169c,0x7bc004a6,0xd6d90034,0x9f400076}},	//   tsti, _homu, nały_, gniú_,
   {{0x81c900c7,0xc8ca00cd,0x7afd13c8,0xb865046b}},	//   লোড_, _توان_, _østr, _مانو,
   {{0xf7463574,0x7bc04c41,0x68fa0090,0x3d1a007f}},	//   _редо, _jomu, _ixtd, _भरने_,
   {{0xe7374c42,0x61e7029a,0x41e707bf,0x63ad05db}},	//   _реч_, tijl, віва, _vnan,
   {{0x63ad4c43,0x8af700a7,0x7bc0019f,0x9f490076}},	//   _wnan, _şəkl, _lomu, rnaí_,
   {{0xcf9b0396,0x61e701cb,0xdfd50ae3,0x25ae0139}},	//   мја_, rijl, говы, _infl_,
   {{0x63ad0256,0x7bc0019b,0x938b013d,0x6d57008c}},	//   _unan, _nomu, _цска_, waxa,
   {{0x6d574c44,0x6b9b4c45,0x3f154c46,0x00000000}},	// [42d0] taxa, _raug, удас, --,
   {{0xab5d0067,0x6b9b01b3,0x9d550037,0x00000000}},	//   _może, _saug, انات, --,
   {{0x6d574c47,0x6b9b4c48,0x48de007a,0xb5fd00c6}},	//   raxa, _paug, _कइगो_, mušt,
   {{0x80dc00c7,0x8af700a7,0x6b820103,0x6d57008c}},	//   _মুক্, _çəkm, gfog, saxa,
   {{0x7bc04c49,0x290c008b,0x764205bd,0xbebb0216}},	//   _domu, _ayda_, _ntoy, _egër,
   {{0x6b9b4c4a,0xbddb0154,0x00000000,0x00000000}},	//   _waug, _vwès, --, --,
   {{0xe7394c4b,0xdb00070a,0x76424231,0xe80f0096}},	//   ней_, _anmä, _atoy, ातला_,
   {{0xccf209c1,0x7c3a025a,0xdb000181,0x9d18163d}},	//   _הכל_, _étra, _pomô, _рост_,
   {{0x5a340978,0x6d5517b6,0x6fca0146,0x673b18c5}},	//   _внут, _keza, _dých, rcuj,
   {{0x6d554c4c,0xb5fd0542,0x7afb039f,0x00000000}},	//   _jeza, jušt, _ixut, --,
   {{0x290c02e0,0x6d554c4d,0xa3ea1510,0x7bc04c4e}},	//   _gyda_, _meza, една_, _yomu,
   {{0x61e54c4f,0xe1ff0103,0x69c14c50,0xd6d9007f}},	//   _amhl, sról_, _hole, zały_,
   {{0x5b7a0142,0xe57800e8,0xe1ff01f9,0x00000000}},	//   ערשא, ziķi_, pról_, --,
   {{0x6d554c51,0x61e501b9,0x69c14c52,0x265a00ca}},	//   _neza, _cmhl, _jole, _טכנא,
   {{0x69c14c53,0x394200a7,0xdb190364,0x53a60077}},	//   _mole, _əks_, chwö, _байб,
   {{0xd6d900a5,0x61e50060,0xb5fd4c54,0x60c10c19}},	//   wały_, _emhl, rušu, älma,
   {{0x6d554c55,0x7bc00e1d,0x0d8600ba,0xbd86002e}},	// [42e0] _beza, _romu, ллан, лгак,
   {{0xb5fd03ce,0x6d554c56,0x69c14c57,0x7bc04c58}},	//   dršk, _ceza, _nole, _somu,
   {{0x6d554c59,0x7bc00128,0x0b46084c,0x603c0154}},	//   _deza, _pomu, гнен, _fčma,
   {{0x9f060241,0x2d9c2f54,0xd5e20134,0x09be2b6e}},	//   _موجو, žve_, _kpọ, ्स्य,
   {{0x69c14c5a,0x16034c5b,0x6fca0038,0x61e50150}},	//   _bole, रकार_, _rých, _ymhl,
   {{0x6d554c5c,0x38a3026a,0x7bc04874,0x00000000}},	//   _geza, _bır_, _womu, --,
   {{0x69c14c5d,0x7bc04c5e,0x99650565,0x082a3e0c}},	//   _dole, _tomu, ртіл, нции_,
   {{0x69c10113,0x29d0009c,0x38a3071d,0xab5d007f}},	//   _eole, _gàan_, _dır_, _poże,
   {{0x6fca0074,0x6e2e4c5f,0x6b8400aa,0x7c224c60}},	//   _vých, _kibb, õigu, mmor,
   {{0x69c14c61,0x6e2e4c62,0x290c169c,0x4a5b2252}},	//   _gole, _jibb, _tyda_, _נדבו,
   {{0x6fca0181,0x2db70266,0xbddb0113,0x7d010c89}},	//   _tých, אלין_, _otèn, _ølst,
   {{0x6e2e4c63,0x69c14c64,0x7c220381,0xdb1b0072}},	//   _libb, _zole, nmor, _gluó,
   {{0x64432f95,0x27e64c65,0x6e2e023e,0xdcfc01d3}},	//   _etni, _imon_, _oibb, _barī,
   {{0x69d80102,0x869b00a1,0x26db00ca,0xbddb2307}},	//   nhve, _ניוז, _אקדמ, _atèn,
   {{0x69cc05d4,0xdcfc00d9,0xd0d400e5,0xd01b4c66}},	//   _तकनी, _darī, боръ, ефа_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5d554c67,0xb5fd02e6,0x6e2e4c68,0x6d5508a8}},	// [42f0] икат, pušt, _bibb, _peza,
   {{0x61e50060,0xdcfc01d3,0xbddb0383,0x22440031}},	//   _umhl, _garī, _etèn, ímke_,
   {{0xa11500cd,0x628e0995,0x69c14c69,0x6e2e041c}},	//   _خودت, čnoš, _role, _dibb,
   {{0x69c14c6a,0x7c2204aa,0x603c0095,0xaf070033}},	//   _sole, gmor, _učma, লেষণ_,
   {{0x69c14c6b,0x6e2e1cb2,0xe50b00aa,0x81e80033}},	//   _pole, _fibb, _सुनि_, যকর_,
   {{0x27e64c6c,0x6e2e4c6d,0x7c224c6e,0x68452c95}},	//   _amon_, _gibb, amor, анка,
   {{0x69c14c6f,0x7e6d032e,0x8c250037,0x7d1a04c8}},	//   _vole, lrap, _نفسه, _útsp,
   {{0x2d934c70,0x16650c58,0x28b61d96,0x6e2e00c4}},	//   lexe_, авим, _अपरि, _zibb,
   {{0x7e6d00cd,0x78a80138,0x27e6022b,0x644f015c}},	//   nrap, _erdv, _dmon_, ćcim,
   {{0x2d934c71,0x69d801bf,0x27e64c72,0x7dd202b6}},	//   nexe_, chve, _emon_, _læsn,
   {{0x7e6d4a56,0x67d50a54,0x628d4c73,0x98bc00c6}},	//   hrap, _кожу, _apao, davė_,
   {{0x6aa94c74,0xcc7600a1,0x6b890090,0xdcfc00e8}},	//   _kref, סגרת_, _jbeg, _sarī,
   {{0x6b894c75,0xe72e1372,0xdcfc00e8,0xb811007f}},	//   _mbeg, _фе_, _parī, _डीएम_,
   {{0x64a53051,0x6aa90010,0x764900bf,0xe046028d}},	//   _вака, _mref, mpey, инги,
   {{0x7c224c76,0x90c30ebf,0x6b894c77,0x6e2e0d4b}},	//   ymor, обре, _obeg, _ribb,
   {{0x3ead00cc,0x6aa90451,0x7e6d0e22,0x00000000}},	//   _šeta_, _oref, frap, --,
   {{0x7e6d4c78,0xee37311c,0x7c220e3e,0xd83805db}},	// [4300] grap, инт_, vmor, _vrči_,
   {{0x83fd005f,0x998c01d3,0x6b894c79,0x27e91054}},	//   vrđi, _vidū_, _abeg, čany_,
   {{0x6aa94c7a,0xd8380106,0xc1010023,0x00000000}},	//   _aref, _trči_, _mượt_, --,
   {{0xc1010028,0x5aca0077,0x6aa94c7b,0x8fa6001f}},	//   _lượt_, клем_, _bref, _таме,
   {{0x7e6d22d4,0x6e2e4c7c,0x6aa900f0,0x6fd84c7d}},	//   crap, _tibb, _cref, _cíce,
   {{0x20ba220e,0x6aa90150,0xceb300a1,0xc8660832}},	//   _उपाध, _dref, _ויש_, атии,
   {{0xa3c62087,0x02b4000d,0x69d84c7e,0x6aa94c7f}},	//   _एवं_, ुहुन, rhve, _eref,
   {{0x7bd901bf,0x4c9b00ca,0x6b890032,0x69d80653}},	//   chwu, _בבלו, _gbeg, shve,
   {{0x6aa94c80,0xab273eac,0x764d0555,0x1ae6002d}},	//   _gref, _вота_, _çayl, _тоам,
   {{0x14ca00c2,0xe4a635c1,0x6b8905db,0x00000000}},	//   выми_, армо, _zbeg, --,
   {{0xd4974c81,0xd5b70ab3,0x388e00a7,0x00000000}},	//   аря_, рсы_, _sərf_, --,
   {{0xc7c700c2,0xd5b800e8,0x46ea4c82,0x00000000}},	//   _выше_, mmām_, _иден_, --,
   {{0x926b008f,0x00000000,0x00000000,0x00000000}},	//   ърна_, --, --, --,
   {{0x7e6d00e5,0xf207004d,0xab5d00bd,0x00000000}},	//   vrap, рямо, _moża, --,
   {{0xa15814e8,0x55bb00d7,0x00000000,0x00000000}},	//   расу_, _במגו, --, --,
   {{0x7e6d4c83,0x25e206eb,0x2d8a05db,0x43080134}},	//   trap, टोरी_, _abbe_, ọpị_,
   {{0xba3d030b,0x5187065c,0x9df90832,0xd8384c84}},	// [4310] _prům, _куна, гнат_, _luč_,
   {{0x7e6d4c85,0x27050028,0xeca70291,0x6aa9150c}},	//   rrap, ồng_, ијен, _rref,
   {{0x7e6d47b2,0x31740220,0x7c673a89,0x6fd80076}},	//   srap, ňazí_, شاال, _síce,
   {{0x5b2500e3,0x2d934c86,0x66080087,0xddc400ae}},	//   مفضل, sexe_, hodk, triţ,
   {{0x66080332,0xd9450f32,0x7c3b0095,0x501a0266}},	//   kodk, бели, _čuru, _תורו,
   {{0xceb20132,0x81c90081,0x6fd800b6,0xab5d02a1}},	//   _זיך_, লোর_, _více, _doża,
   {{0xf09400c1,0x6fca0146,0xc10100fe,0x6b8902a1}},	//   ַנץ_, _výcv, _rượt_, _tbeg,
   {{0x6aa94c87,0xddcd011d,0xd0f8040a,0x6ead0034}},	//   _tref, ntaž, ימות_, ीमपु,
   {{0x060908c3,0xadc40139,0x6aa90051,0x66e529a4}},	//   лник_, _atẹs, _uref, сопа,
   {{0x58870895,0x660802dd,0xb86b125f,0xd8381e4d}},	//   _выда, godk, _ајде_, _fuč_,
   {{0xc329193b,0xc1010019,0x02d0030b,0x03a64c88}},	//   _נו_, _vượt_, हन्न, бино,
   {{0xd838022b,0xbddb014b,0x00000000,0x00000000}},	//   _prčv_, _stèl, --, --,
   {{0x27ed242f,0x870700c2,0xddc4007e,0xe4d6001c}},	//   mien_, _тяже, hriš, لویت_,
   {{0xd5b11ea6,0x66080188,0x6143100f,0xddc400e8}},	//   _رفع_, codk, зера, kriš,
   {{0x7dd201c5,0x3f6a4c89,0x27ed01c0,0x87db009f}},	//   _sæso, ливо_, oien_, _बताऊ,
   {{0x6ab707e2,0xafe34c8a,0xd83814f3,0x543a006e}},	//   _आपूर, посл, _grču_, _געקא,
   {{0x442006c0,0xef1a40b2,0x75460018,0xb21b0537}},	// [4320] _ihi_, ума_, _érzé, mtæn,
   {{0x27ed4c8b,0x44321049,0xab5d0090,0x7dd201cd}},	//   hien_, _hiy_, _roża, _gæsl,
   {{0x4420011b,0x7dc00068,0x27ed4c8c,0x61ee1c40}},	//   _khi_, _kösz, kien_, mibl,
   {{0x27ed0084,0x61ee00a7,0x320a0891,0x66084c8d}},	//   jien_, libl, loby_, zodk,
   {{0x27ed4c8e,0x69cc009f,0xdcfc09ac,0x395c01d3}},	//   dien_, _तकदी, _obrć, tavs_,
   {{0x61ee4c8f,0x27ed0126,0xddc40660,0x443202f1}},	//   nibl, eien_, briš, _liy_,
   {{0x6d5e4c90,0xa3ca1c65,0x44204c91,0x27ed4c92}},	//   mapa, ोसा_, _ohi_, fien_,
   {{0x27ed38ff,0x6d5e4afd,0x44200019,0x44324c93}},	//   gien_, lapa, _nhi_, _niy_,
   {{0x52b4033a,0x96030034,0x61ee4c94,0x320a0354}},	//   ुहोस, रकूट_, kibl, koby_,
   {{0x6d5e4c95,0x44204c96,0x61ee4c97,0x27ed0126}},	//   napa, _ahi_, jibl, aien_,
   {{0xab5d0067,0x18360979,0x27ed4c98,0x320a1fe8}},	//   _możn, _طراح, bien_, doby_,
   {{0x44204c99,0x27ed4c9a,0x6d5e4c9b,0xa3e3007f}},	//   _chi_, cien_, hapa, फों_,
   {{0x6d5e4c9c,0x44324c9d,0x44204c9e,0xbddb03a9}},	//   kapa, _diy_, _dhi_, _stèm,
   {{0x61ee4c9f,0x44200294,0x867b028c,0x6d5e4ca0}},	//   gibl, _ehi_, _תרגו, japa,
   {{0x84460241,0x6d5e06ee,0xba3d00b6,0x4432022b}},	//   _اختل, dapa, _průk, _fiy_,
   {{0x44200028,0x61ee02ac,0x1ee700d1,0x00000000}},	//   _ghi_, aibl, موزی_, --,
   {{0xddcd4ca1,0xa3ce009d,0x61ee351f,0xab5d00bd}},	// [4330] rtaž, _शकत_, bibl, _bożn,
   {{0x6d5e4ca2,0x27ed2807,0x717500cd,0x61ee4ca3}},	//   gapa, zien_, _بهدا, cibl,
   {{0x2bdd05a5,0x236902dd,0x9f3501ce,0xddcd013f}},	//   _मतदा, _kdaj_, _мені, ptaž,
   {{0x27ed4ca4,0x649e03d6,0xe1ff0034,0xdb004ca5}},	//   xien_, mšić, trów_, _kamè,
   {{0x27ed4ca6,0x6d5e4ca7,0x7e7900c1,0x649e007e}},	//   vien_, bapa, _דאָז, lšić,
   {{0x7f5f4ca8,0xddcd0034,0xdb0003a9,0x6d5e4ca9}},	//   laqq, ntaż, _mamè, capa,
   {{0x27ed4caa,0x3ea94cab,0x64ac2461,0xb17c0089}},	//   tien_, lvat_, nđić, אטור,
   {{0x236901e5,0x22490496,0x7f5f4cac,0x3ea94cad}},	//   _ndaj_, _otak_, naqq, ovat_,
   {{0x27ed4cae,0xb5fd00cc,0x9f9c026e,0xead20d79}},	//   rien_, kršt, _díè_, _jẹ́_,
   {{0x44202bc2,0x27ed4caf,0x3ea90084,0xb4654cb0}},	//   _shi_, sien_, ivat_, окол,
   {{0x22494cb1,0x44200028,0x27ed4cb2,0x649e0b14}},	//   _atak_, _phi_, pien_, jšić,
   {{0x4420023e,0x232a3574,0xc70a0174,0xd70a0174}},	//   _qhi_, иони_, ịrịb, ịrịr,
   {{0xadfb0775,0x6d5e367e,0xfdfb05cd,0xdb00023b}},	//   ्वान_, yapa, ्वास_, _ramë,
   {{0xb21b01c5,0x6d5e01af,0xdb0003a9,0xb5fd00e7}},	//   stæn, xapa, _damè, gršt,
   {{0x442000ef,0x320a4cb3,0x61ee4cb4,0x412a171b}},	//   _thi_, roby_, ribl, рово_,
   {{0x6d5e4cb5,0x442001b5,0x61ee1647,0xead20139}},	//   wapa, _uhi_, sibl, _bẹ́_,
   {{0x6e46110a,0x63a44cb6,0x61ee06a3,0xe29a02a0}},	// [4340] زنام, _iain, pibl, _тап_,
   {{0x63a44cb7,0x236902dd,0x60430134,0x61ee4cb8}},	//   _hain, _zdaj_, ọmat, qibl,
   {{0x63a44cb9,0x6d5e4cba,0x3ea90084,0x957c007f}},	//   _kain, rapa, avat_, miąt,
   {{0xddcd00d3,0x63a44cbb,0xead20032,0x2d854cbc}},	//   tuaţ, _jain, _fẹ́_, _ölen_,
   {{0x6d5e4cbd,0x63a44cbe,0x1a9606fa,0x3ea900d3}},	//   papa, _main, تجاج, cvat_,
   {{0xfce627c6,0x63a44cbf,0x629a007f,0xe7ec00aa}},	//   _дого, _lain, łtow, _जगहा_,
   {{0x6d5c0029,0xa37b0396,0x628600aa,0x7e6400f9}},	//   _iera, lhõe, htko, lsip,
   {{0x6d5c4cc0,0xd90d00cd,0x62860e3e,0xf76f0c5e}},	//   _hera, دیم_, ktko, ناً_,
   {{0x6d5c440c,0x7e644cc1,0xab5d0067,0xa37b0161}},	//   _kera, nsip, _możl, nhõe,
   {{0x7c3c4cc2,0x186a4cc3,0x7e644cc4,0xdb00020d}},	//   _kurr, _важи_, isip, _ramè,
   {{0x63a44cc5,0x6d5c4cc6,0x29184cc7,0x7766013d}},	//   _bain, _mera, _ára_, _дълж,
   {{0x63a444f5,0x7bc204ea,0x6d5c4cc8,0x69c800d6}},	//   _cain, njou, _lera, _hode,
   {{0x63a44cc9,0x7c3c02a7,0x68350138,0x6d5c4cca}},	//   _dain, _lurr, _išda, _oera,
   {{0xaca40134,0x69c84ccb,0xdb000257,0x63b603a8}},	//   _atọr, _jode, _camé, _enyn,
   {{0xe50206ed,0xdb000113,0x62864ccc,0xe5e7001c}},	//   _रुचि_, _damé, atko, _بزنی,
   {{0x6d5c4ccd,0x63a420ba,0x6fd80328,0xb30c0174}},	//   _aera, _gain, _píca, ọjịs,
   {{0x6d5c2394,0x7c3c03f3,0x22494cce,0x443c0197}},	// [4350] _bera, _aurr, _utak_, _huv_,
   {{0x443c1071,0x63a44ccf,0x7c3c4cd0,0x69c84cd1}},	//   _kuv_, _zain, _burr, _node,
   {{0x6d5c0b6a,0x7c3c0054,0x63a42036,0x3ea94cd2}},	//   _dera, _curr, _yain, svat_,
   {{0x69da4cd3,0x7c3c00dd,0x7f5f0090,0x443c4cd4}},	//   _alte, _durr, qaqq, _muv_,
   {{0x443c4cd5,0x69c84cd6,0x7d770f36,0x29f60034}},	//   _luv_, _bode, _واسط, kład_,
   {{0xdb1b0161,0x69c84cd7,0x7c3c4cd8,0x443c2f8a}},	//   _louç, _code, _furr, _ouv_,
   {{0x69c84cd9,0x443c022e,0x6e3d4cda,0x98be00c6}},	//   _dode, _nuv_, _husb, _metė_,
   {{0x62860d1b,0x6d4501b5,0x61c81784,0x69da4cdb}},	//   ytko, lcha, _रक्ष, _elte,
   {{0x69c84cdc,0x443c01fa,0x7f5d4cdd,0x6d454cde}},	//   _fode, _auv_, _mesq, ocha,
   {{0x6d454cdf,0x6d5c4ce0,0x69c84ce1,0x7f5d0257}},	//   ncha, _xera, _gode, _lesq,
   {{0xb21b01c5,0x2b404ce2,0x63a44ce3,0xa50935c1}},	//   rtæl, žice_, _pain, сена_,
   {{0x6d454ce4,0x22844ce5,0x62860ec9,0xe29a4ce6}},	//   hcha, tök_, ttko, бам_,
   {{0x98a707d1,0x63a44ce7,0x7dd3026a,0xc73a00ca}},	//   manı_, _vain, _kısı, _התנת,
   {{0x63a44ce8,0x7dd20170,0x853c0138,0x6e350995}},	//   _wain, _væsk, ndėl, _nizb,
   {{0x63a44ce9,0x22844cea,0x6e3d02e2,0x7dd301e8}},	//   _tain, sök_, _ausb, _mısı,
   {{0x6d5c03ec,0x63a40a02,0x7e644ceb,0xe1ff0034}},	//   _sera, _uain, tsip, wrót_,
   {{0x6d5c26f7,0xdb004b1f,0x69cc0251,0x6e3d0188}},	// [4360] _pera, _tamé, _तकली, _cusb,
   {{0x443c01fa,0x06c50081,0x7bdb010a,0x7c3c4cec}},	//   _yuv_, এনপি, _aluu, _purr,
   {{0x6d5c27cd,0x31570130,0x7e644ced,0x7bc21ed7}},	//   _vera, _מיין_, ssip, tjou,
   {{0x6d450a21,0x69c80b27,0x7bc9025a,0x6d5c4cee}},	//   acha, _sode, _coeu, _wera,
   {{0x6d450197,0x7bc20084,0x65610e9f,0x98a7173c}},	//   bcha, rjou, kalh, danı_,
   {{0x7c3c4cef,0xfd590134,0x7bc24cf0,0xed520470}},	//   _turr, _mgbụ, sjou, _سپر_,
   {{0x65614cf1,0x764b409a,0x5fe00179,0x7c3c0381}},	//   dalh, _atgy, _नताल, _uurr,
   {{0x79980c56,0x2d9a4cf2,0x443c4cf3,0xf09300ca}},	//   sevw, lepe_, _ruv_, גנה_,
   {{0x69c802fd,0xa3c600c3,0xbddb01ec,0xae1000a3}},	//   _tode, _एवज_, _stèi, ़कपन_,
   {{0x69da4cf4,0x443c006c,0xba3d00b6,0x656120df}},	//   _ulte, _puv_, _prův, galh,
   {{0x395e1d19,0x443c0113,0xfd590129,0x539900c2}},	//   _iets_, _quv_, _agbụ, овня_,
   {{0x395e0160,0x24414cf5,0x883b00ca,0x443c0350}},	//   _hets_, _dóm_, _התאו, _vuv_,
   {{0x65614cf6,0x6d454cf7,0x7f5d4cf8,0x395e0167}},	//   balh, ycha, _resq, _kets_,
   {{0x2d9a4cf9,0xa410030b,0x65614cfa,0x398f0511}},	//   jepe_, ětší_, calh, cısı_,
   {{0x7f5d4cfb,0x395e4cfc,0x6e3d01b5,0xd48f0012}},	//   _pesq, _mets_, _susb, _яр_,
   {{0x34fb00a1,0x395e4cfd,0x4abe0d75,0xd13001f9}},	//   _להוד, _lets_, ्हाव, امِ_,
   {{0x6d454cfe,0x9f400088,0x69c30034,0x00000000}},	// [4370] tcha, rnið_, yjne, --,
   {{0x6d454cff,0xf1d1000d,0x7bc94d00,0x4df4004d}},	//   ucha, _सकिन, _soeu, няєт,
   {{0x6d454d01,0x244100de,0x98a70491,0x7bdb09a1}},	//   rcha, _xóm_, yanı_, _pluu,
   {{0x6d454d02,0xbddb201c,0x398f008b,0x98a7013c}},	//   scha, _suèd, zısı_, xanı_,
   {{0x398f01e8,0xe8100efb,0x6e3d489c,0x98a707e7}},	//   yısı_, ावना_, _uusb, vanı_,
   {{0x2d9a002d,0xf9c72917,0x00000000,0x00000000}},	//   cepe_, ящен, --, --,
   {{0x395e4d03,0x65611789,0xf8920396,0x98a70555}},	//   _dets_, valh, вајќ, tanı_,
   {{0x656106a0,0x2a661ef8,0x244101ab,0xb21b01cd}},	//   walh, bsob_, _róm_, ftæk,
   {{0x656100c9,0x395e05fe,0x98a70491,0xaa580396}},	//   talh, _fets_, ranı_, _ниту_,
   {{0x98a70511,0x395e00ca,0xdcfc0090,0xdb100131}},	//   sanı_, _gets_, _harġ, _éfác,
   {{0x31631386,0x65614d04,0x398f008b,0x9f9c0065}},	//   dajz_, ralh, rısı_, _bíì_,
   {{0x6fd804c3,0x65614d05,0x98a7013c,0x6441013c}},	//   _cícl, salh, qanı_, rqli,
   {{0xe60e08a1,0x6561001f,0x398f0367,0xdcfc009e}},	//   _ад_, palh, pısı_, _marġ,
   {{0xc58e0028,0x24413238,0xc6920266,0x00000000}},	//   _hồng_, _tóm_, _סאו_, --,
   {{0x2fcb00ee,0x38672452,0x00000000,0x00000000}},	//   _bocg_, nsnr_, --, --,
   {{0x442b4d06,0x00000000,0x00000000,0x00000000}},	//   cmc_, --, --, --,
   {{0x2fcb028d,0x2d9a4d07,0xc58e00fe,0x00000000}},	// [4380] _docg_, tepe_, _mồng_, --,
   {{0x270c00ef,0xc58e00de,0x25a7022b,0xe1ff037a}},	//   ớng_, _lồng_, _janl_, lsón_,
   {{0x2d9a4d08,0xe81000b6,0x00000000,0x00000000}},	//   repe_, ावमा_, --, --,
   {{0x2d9a4d09,0xc58e00de,0x395e00ca,0x22400381}},	//   sepe_, _nồng_, _sets_, _kuik_,
   {{0xa3e30ccb,0xdb000154,0x2d9a4d0a,0x2005014b}},	//   फोट_, _anmò, pepe_, élie_,
   {{0xc33300a1,0x3f8000c6,0x8d760281,0x629606b0}},	//   דוד_, lgiu_, _تاحا, _mpyo,
   {{0x3ea01044,0xc58e0023,0x22404d0b,0x00000000}},	//   lwit_, _bồng_, _luik_, --,
   {{0x6bda00cd,0x466a2e91,0x3f804d0c,0xba3d02c6}},	//   _بورس_, ором_, ngiu_, _průt,
   {{0x96341e70,0x442b0042,0xdb0000d2,0x00000000}},	//   нниц, vmc_, _kamí, --,
   {{0xc6f70761,0xb21b0102,0x25a7009c,0x2002007e}},	//   ьных_, rtæk, _canl_, _ljki_,
   {{0xdb002b39,0x25a7022b,0xd83802c6,0xdcee0233}},	//   _mamí, _danl_, _ksčm_, _kabı,
   {{0x224024e7,0x9f9c0139,0x7e763775,0x69d84d0d}},	//   _buik_, _bíí_, kryp, lkve,
   {{0xf7d700f5,0x51874d0e,0xfd6500de,0xf743004d}},	//   _קודש_, мува, _chuỗ, _речо,
   {{0xe7ea04a9,0x69d84d0f,0x22401044,0x3ea000f9}},	//   जोरा_, nkve, _duik_, dwit_,
   {{0x86370796,0xe8df0023,0x623435c1,0x3cfa0034}},	//   _קרוב_, _kiềm_, теру, ्थों_,
   {{0x5f9443a9,0x6fa9009d,0x14cb270a,0x3f802ae7}},	//   кист, _चोखं, ाहरण, ggiu_,
   {{0xee3f0028,0xc3090033,0x7e764d10,0x62960139}},	// [4390] _quý_, রেজি_, gryp, _gpyo,
   {{0x69d801cb,0xddcd044c,0x00000000,0x00000000}},	//   jkve, draţ, --, --,
   {{0x61f503a3,0x3ea007ac,0xf3900023,0x31560289}},	//   mizl, awit_, _mảng_, _איתן_,
   {{0xe8df0019,0x69d80629,0x61f5020e,0xee3f00fe}},	//   _niềm_, ekve, lizl, _tuý_,
   {{0xdb002e64,0x3d0f04a9,0xc58e00de,0x9f8a00aa}},	//   _famí, _तुरे_, _rồng_, tööd_,
   {{0x92a900a5,0x61f5008b,0x8afd02c6,0x00000000}},	//   _załó, nizl, _neře, --,
   {{0x5fd304dd,0x2b400128,0x6722039f,0xdcfc02a1}},	//   _सवाल, žica_, _azoj, _tarġ,
   {{0x013809c1,0xe3ca0933,0xdb0002c6,0x321130e6}},	//   ורות_, _mañá_, _zamí, hozy_,
   {{0xf3900019,0xddcd00ae,0xc58e00fe,0x98c400e8}},	//   _bảng_, craţ, _vồng_, ētām_,
   {{0x2d814d11,0xab6200aa,0xf39000de,0x69d84d12}},	//   nghe_, _üüri, _cảng_, ckve,
   {{0xf77000d1,0x61f505db,0x00000000,0x00000000}},	//   _چاه_, dizl, --, --,
   {{0x1ac60081,0x7dd2003e,0xe29a0398,0x22400313}},	//   _শেয়া, _hæst, пам_, _puik_,
   {{0x45d54d13,0x2bc74d14,0x27ff0367,0x25a70154}},	//   _подс, _रचना, mnun_, _tanl_,
   {{0x25a7037a,0xf3ff0231,0x7a24015e,0x00000000}},	//   _uanl_, anã_, pòte, --,
   {{0xdb004d15,0xc0e627a5,0x25aa015a,0x3d0f0285}},	//   _ramí, ховк, _رضوی_, _तुले_,
   {{0x7dd201c5,0x27ff1335,0x3ea04d16,0xdfd20037}},	//   _læst, nnun_, twit_, دير_,
   {{0x3f804d17,0xdee34d18,0xdb000161,0x9f9d0088}},	// [43a0] rgiu_, готи, _mamã, ræðu_,
   {{0x7dd24d19,0xdcee026a,0xfce64d1a,0x00000000}},	//   _næst, _sabı, нозо, --,
   {{0xeb9a40c9,0x5ec80033,0xbddb015e,0x515b00ca}},	//   зие_, _রেখে, _suèc, _מכיו,
   {{0xfc39022b,0xddcd00ae,0xe7270076,0xdcee013c}},	//   _ciŭ_, traţ, _مص_, _qabı,
   {{0x2000020a,0x00000000,0x00000000,0x00000000}},	//   mnii_, --, --, --,
   {{0xa8a6455b,0x7bd90294,0x603c0154,0xb33b0131}},	//   ерик, akwu, _fčmt, meçe,
   {{0xde034d1b,0x27ff0088,0x8b960138,0x1d07007e}},	//   _спри, fnun_, _прач, _зери_,
   {{0x20004d1c,0x69d84d1d,0xf39000fe,0x6c360037}},	//   nnii_, skve, _sảng_, _أفرا,
   {{0xd5b00037,0x7dd24d1e,0x20004d1f,0x0eb20285}},	//   لفة_, _fæst, inii_, ीमिड,
   {{0x7dd201c5,0xab5d0090,0x00000000,0x00000000}},	//   _gæst, _rożi, --, --,
   {{0x8afd030b,0xe8df00de,0xddcd0138,0xf3ff0956}},	//   _veře, _tiềm_, nraš, tnã_,
   {{0x6b824d20,0xab5d003d,0x982b0103,0x27ff020e}},	//   ngog, _pożi, _فتنہ_, cnun_,
   {{0xf39000de,0x70c90179,0xdb1b0231,0x00000000}},	//   _tảng_, रह्ल, _anuê, --,
   {{0xd5b801d3,0xddcd0138,0x20004d21,0x00000000}},	//   rmās_, kraš, enii_, --,
   {{0x316100e7,0x9f9c0032,0xc60c1c83,0xddcd14f3}},	//   _vehz_, _bíà_, सकीय_, jraš,
   {{0x61f507aa,0xe8df0019,0x43950450,0x60d5007f}},	//   sizl, _hiểm_, _раис, ryzm,
   {{0x44294d22,0xe8df0028,0x6fd84d23,0xd8380154}},	// [43b0] _iha_, _kiểm_, _mích, _asčk_,
   {{0x44294d24,0x443b0052,0x12fc00ca,0x20004d25}},	//   _hha_, _hiq_, _מהחב, anii_,
   {{0x6fd800e3,0x2d814d26,0xc5f300c1,0x44294d27}},	//   _oích, rghe_, נדע_, _kha_,
   {{0x442902a1,0xdfd50a29,0x6d58003e,0x6b82010a}},	//   _jha_, _ромы, ðvar, ggog,
   {{0xfaa50870,0x442917c4,0x443b4d28,0x28a6007f}},	//   тало, _mha_, _miq_, _कैबि,
   {{0x442900cd,0xe9d801b3,0xbddb022b,0xddcd1db9}},	//   _lha_, нкі_, _etèr, braš,
   {{0x44294d29,0xd26201d3,0x603c05aa,0xcd370d83}},	//   _oha_, _ziņā_, _kōma, _سرسب,
   {{0x44294d2a,0xe7392178,0x9f9c0032,0x6fd800da}},	//   _nha_, мей_, _kíá_, _cích,
   {{0x7c294751,0x66e54d2b,0x6fd80037,0x7c3a028d}},	//   _iher, топа, _dích, _ètra,
   {{0x44294d2c,0x7c3b009c,0x00000000,0x00000000}},	//   _aha_, _hiur, --, --,
   {{0x4429064b,0x20121114,0x7c290239,0x6fd8033c}},	//   _bha_, yoyi_, _kher, _fích,
   {{0x44294d2d,0x443b0063,0x7c290154,0x603c022b}},	//   _cha_, _ciq_, _jher, _nōma,
   {{0x44294d2e,0x764201c2,0xaca30174,0x7c294d2f}},	//   _dha_, _guoy, faịd, _mher,
   {{0x7c3b009c,0xdb00058a,0x412a1b60,0x20120d2a}},	//   _liur, _jamá, дого_, woyi_,
   {{0x7c294d30,0xdb004d31,0xc95200ca,0x2b4d00b3}},	//   _oher, _mamá, שמל_, _ofec_,
   {{0x64430012,0x442900ac,0x200000d3,0x65630856}},	//   _iuni, _gha_, unii_, _henh,
   {{0xee3a0562,0x64434d32,0xfe432657,0x0d86460b}},	// [43c0] дна_, _huni, инто, клан,
   {{0x7c290193,0x7c3b15e7,0xdb000094,0x9f9c0065}},	//   _aher, _aiur, _namá, _díá_,
   {{0x7c3b40f2,0x64434d33,0x6fd800b3,0x7c290cc2}},	//   _biur, _juni, _líci, _bher,
   {{0x7c294d34,0x65634d35,0x64434d36,0x7c3b4d37}},	//   _cher, _lenh, _muni, _ciur,
   {{0x64434d38,0x6b824d39,0x7c294d3a,0xe7c5030b}},	//   _luni, rgog, _dher, वानप,
   {{0x65634d3b,0x7c29259e,0xddcd4d3c,0x2d9e00b6}},	//   _nenh, _eher, praš, _úte_,
   {{0x64434d3d,0x2ca702b6,0xdb000037,0x7c2901b9}},	//   _nuni, ændt_, _damá, _fher,
   {{0x7c3b4d3e,0xd6da00a9,0x7c294d3f,0x6e3c030a}},	//   _giur, дто_, _gher, _hirb,
   {{0xfaa34d40,0x65634d41,0x644319f8,0x2bab0e5f}},	//   _като, _benh, _auni, _घोटा,
   {{0x44294604,0x64434d42,0x7c3b1ecc,0x443b0052}},	//   _sha_, _buni, _ziur, _siq_,
   {{0xd82f0012,0x44294d43,0x7d7b00a1,0x6e3c4d44}},	//   _вэ_, _pha_, וניו, _mirb,
   {{0x64434d45,0x65630a9f,0xa785177a,0x44294d46}},	//   _duni, _eenh, _مشهو, _qha_,
   {{0xa3c92daa,0x80d00081,0x44290c89,0x6e3c151d}},	//   लॉग_, _হেল্, _vha_, _oirb,
   {{0x44294d47,0xaca40294,0xdb000072,0x67fe01d3}},	//   _wha_, _ahọp, _xamá, dīji,
   {{0x4429337d,0x65684d48,0x64434d49,0x629a00d3}},	//   _tha_, madh, _guni, ătoa,
   {{0x656800cd,0xaca400ac,0xd7c5009d,0x442f4d4a}},	//   ladh, _chọp, वायच, _òg_,
   {{0x6e3c03a3,0x64434d4b,0x63ad0270,0x7c3b0428}},	// [43d0] _birb, _zuni, _iaan, _riur,
   {{0xf41f4043,0x7c294d4c,0x3f7300ef,0x2d87459a}},	//   llä_, _sher, ệu_, üne_,
   {{0x6e3c01b3,0x63ad4d4d,0x7c290319,0x6443002b}},	//   _dirb, _kaan, _pher, _xuni,
   {{0x2d8700a5,0x63ad4d4e,0x65684d4f,0x6e3c01b9}},	//   żne_, _jaan, hadh, _eirb,
   {{0x7c3b0472,0xdb0000b6,0x201907ac,0x3b09013c}},	//   _viur, _pamá, _iksi_, çaq_,
   {{0x7c290054,0x63ad4d50,0x7d1c23ff,0x6e3c4d51}},	//   _wher, _laan, _fyrs, _girb,
   {{0x7c29004f,0x3da40465,0xc9843047,0x7c3b4d52}},	//   _ther, _тряб, ручи, _tiur,
   {{0x65634d53,0x63ad4d54,0x64434d55,0x7c294744}},	//   _senh, _naan, _runi, _uher,
   {{0x6568068d,0x7e6d4d56,0x64434d57,0x65634d58}},	//   fadh, nsap, _suni, _penh,
   {{0x6568110a,0x7a240c56,0x6fd8016d,0x64434d59}},	//   gadh, pòta, _víci, _puni,
   {{0x63ad4d5a,0x6563001f,0xa3df009d,0x66d90032}},	//   _baan, _venh, णसं_, _bùkú,
   {{0xf1a900a1,0x63ad008a,0x628f4d5b,0x65634d5c}},	//   _מס_, _caan, ftco, _wenh,
   {{0x656300c9,0x63ad4d5d,0x6568008a,0xe8df0023}},	//   _tenh, _daan, badh, _diễm_,
   {{0x2019067e,0x64434d5e,0x7e6d0381,0x2448030a}},	//   _aksi_, _tuni, dsap, _fûm_,
   {{0xb21b052f,0xe0d500d6,0x63ad0188,0x644301a5}},	//   kræf, ають, _faan, _uuni,
   {{0x63ad4d5f,0xdce700b6,0x8c430511,0xbea60ed7}},	//   _gaan, ůměr, ışla, лабк,
   {{0x7e6d1281,0x628f01cb,0x7649008c,0xd007007b}},	// [43e0] gsap, ctco, nqey, уете_,
   {{0xe05800cd,0xcf250037,0xef174171,0x63ad4d60}},	//   _لیست_, شرقي, уму_, _zaan,
   {{0xb33b0396,0xf8a50177,0x63ad32ea,0xe5f600c1}},	//   meça, _بک_, _yaan, נזער_,
   {{0x80a100a5,0x8afd00b6,0x6e3c0364,0xb33b0131}},	//   खबरे, _seřa, _wirb, leça,
   {{0x7e6d0103,0x388e00a7,0xa3c91fbb,0x7769037a}},	//   csap, _tərk_, लॉट_, daex,
   {{0x9f52003e,0x6e3c0076,0x48aa0307,0xb33b0231}},	//   ábær_, _uirb, етим_, neça,
   {{0x20190084,0xf41f00c2,0x7c3a028d,0x6aa90415}},	//   _yksi_, ylä_, _ètro, _esef,
   {{0x61d1143d,0x9f49003e,0x65684d61,0x27e2003e}},	//   _सक्ष, nnað_, wadh, ókn_,
   {{0x23af007d,0x7bc04d62,0x628f01ec,0x65684d63}},	//   _जोगद, _inmu, xtco, tadh,
   {{0x63ad4d64,0x35f430fd,0x1a9b006e,0x6825119e}},	//   _saan, рпор, _אימע, róda,
   {{0x63ad0256,0x4d7b0130,0x65684d65,0x9f49003e}},	//   _paan, ערטע, radh, knað_,
   {{0x5335062a,0x63ad008c,0xf7460cf5,0xd6d9007f}},	//   иент, _qaan, _седо, był_,
   {{0x6568001c,0x2d9805fe,0x63ad4d66,0x7a2400b3}},	//   padh, _obre_, _vaan, nòto,
   {{0x63ad4d67,0x85560018,0xe534141b,0xab5d02a1}},	//   _waan, _حیدر_, _кель, _inże,
   {{0x63ad4d68,0x6fd80472,0x9f49003e,0x388e013c}},	//   _taan, _lícu, fnað_, _bəri_,
   {{0x2d980b0b,0xa3e900b6,0x9f49003e,0x947304f4}},	//   _abre_, _यति_, gnað_, _ادوا,
   {{0xb33b0161,0x8c430367,0xa2c600bc,0x388e00a7}},	// [43f0] beça, ışma, ामण्, _dəri_,
   {{0x6b89013d,0x2d8a02a1,0x6f1d00d4,0x9df8022f}},	//   _sceg, _ccbe_, _vysc, гнут_,
   {{0x8d7400ab,0x7e6d4d69,0xa3e91c0a,0x67fe01d3}},	//   صالا, ssap, _यता_, līju,
   {{0x2d984d6a,0x785101d3,0xa3bb11c7,0x7e6d4d6b}},	//   _ebre_, _jāve, घाट_, psap,
   {{0xe8df0019,0x3f8b0036,0x2f282cf5,0x2d8a00b3}},	//   _kiệm_, _iccu_, _бюро_, _fcbe_,
   {{0x291e0222,0x02a30134,0x764900a7,0x3eb905bd}},	//   _byta_, _gwụọ, vqey, _irst_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xccf203c2,0x3eb93723,0x7df40034,0x785101d3}},	//   _וכל_, _krst_, yńsk, _nāve,
   {{0xda78013d,0x6aa900ca,0x00000000,0x00000000}},	//   _бях_, _usef, --, --,
   {{0xdcf506d7,0x67fe0029,0xe8df0019,0x45d52277}},	//   _hazı, dīju, _niệm_, рцит,
   {{0x69c14d6c,0xa5091121,0x78430018,0xdcf507aa}},	//   _inle, тена_, _bőve, _kazı,
   {{0x78bc2a6b,0x672e0103,0x3f8b0090,0xceb4013c}},	//   _árva, önjü, _nccu_, yvə_,
   {{0xe9ff0028,0xa2c60403,0xf679006e,0xe1ff007f}},	//   _luận_, ामध्, _סאַמ, nsów_,
   {{0xd9e50336,0xdcf50dea,0x3f8b4d6d,0x29f6007f}},	//   कसित_, _lazı, _accu_, yłam_,
   {{0xb33b4d6e,0x059600cd,0x3eb900aa,0x2f5306c0}},	//   reça, _خانگ, _arst_, _ụmụ_,
   {{0xf10602d5,0x853c00c6,0xdcf50342,0x60c12059}},	//   _रशीद_, rdėt, _nazı, ålma,

   {{0x8d660084,0x67fe00d9,0xddc4003d,0xb33b016d}},	// [4400] ивае, cīju, priż, peça,
   {{0x957c00a5,0x68350138,0xb21b4d6f,0xddd4007f}},	//   wiąz, _išdu, stær, _żało,
   {{0x3eb902e2,0x0b464d70,0x7b6608d8,0x61fc4d71}},	//   _erst_, анен, атле, mirl,
   {{0x9f061e49,0x61fc1f8a,0x69c14d72,0x32184d73}},	//   _نوجو, lirl, _anle, lory_,
   {{0x61fc00e3,0x00000000,0x00000000,0x00000000}},	//   oirl, --, --, --,
   {{0xed573e28,0x61fc4d74,0x291e4d75,0x32180565}},	//   _вор_, nirl, _pyta_, nory_,
   {{0x67fe00d9,0x9965004d,0x6c360246,0x07e64d76}},	//   zīju, стіл, _نفسا, ицим,
   {{0xd90d11a2,0xdb000181,0x69c14d77,0x61fc2ddc}},	//   رین_, _pamä, _enle, hirl,
   {{0x61fc008e,0x28a609d0,0x3a2c0167,0x7c2212d2}},	//   kirl, _कैरि, _thdp_, mlor,
   {{0x7c224d78,0xd9434d79,0xf8b80023,0x61fc01ee}},	//   llor, _дефи, _trĩ_, jirl,
   {{0xdcf508f5,0xc8ca110a,0x61fc4d7a,0x32184d7b}},	//   _yazı, _جوان_, dirl, dory_,
   {{0x67fe0029,0x00000000,0x00000000,0x00000000}},	//   tīju, --, --, --,
   {{0x61fc4d7c,0x2909008b,0x59da00c3,0x27e628b4}},	//   firl, şaat_, _बकार, _ilon_,
   {{0x3d0f110f,0xd9f822e8,0x67fe00d9,0x32184d7d}},	//   _तुझे_, ्चित_, rīju, gory_,
   {{0x7c224d7e,0x67fe00d9,0x8c430233,0x3eb91405}},	//   klor, sīju, ışka, _srst_,
   {{0x645a07ea,0x98a500c6,0x6e2e4d7f,0x61fc01b9}},	//   mpti, _eglė_, _ahbb, airl,
   {{0x32181b6d,0xb33b001f,0xdcf50092,0x61fc4d80}},	// [4410] bory_, meço, _razı, birl,
   {{0x61fc4d81,0x3eb90087,0xf1ab001c,0xb33b1e7d}},	//   cirl, _vrst_, _شاخه_, leço,
   {{0x331800fb,0xe9ff0019,0x680800b6,0x72340037}},	//   _مزید_, _quận_, vědn, _بريط,
   {{0x1b1000c7,0x7c223dc0,0x680101d3,0xdcf500a7}},	//   ়েছে_, glor, pēdi, _qazı,
   {{0x6fd804d3,0xfaa70a01,0x7cfc01df,0x2249061d}},	//   _víct, ршен, _pårø, _juak_,
   {{0xa2580054,0x224902e7,0x27e64d82,0x78ba02f7}},	//   סבוק_, _muak_, _alon_, _brtv,
   {{0x6ce402ec,0x78ba08a8,0x3ea94d83,0x22492190}},	//   _діте, _crtv, lwat_, _luak_,
   {{0x61fc01d4,0x321806c2,0x3f894d84,0x1a68110a}},	//   zirl, zory_, ngau_, _چینی_,
   {{0xe61918d4,0x61fc0740,0x27e601b9,0x6b9b4d85}},	//   лди_, yirl, _dlon_, _ibug,
   {{0x69c100ca,0xc48509e0,0x6abb0032,0x61fc4d86}},	//   _unle, блок, _iruf, xirl,
   {{0x3ea9063f,0x3218025b,0x80d70081,0x27e61844}},	//   hwat_, vory_, _ডেস্, _flon_,
   {{0x3ea94d87,0x22492190,0x98640103,0x32184d88}},	//   kwat_, _buak_, _بیٹے_, wory_,
   {{0x61fc4d89,0x13a800cd,0x78ba08a9,0x6b9b0ba7}},	//   tirl, هنگی_, _zrtv, _mbug,
   {{0x765b1195,0x6abb0350,0x00000000,0x00000000}},	//   mpuy, _mruf, --, --,
   {{0x61fc4d8a,0x25a54d8b,0x6b9b4d8c,0x3ea90124}},	//   rirl, mell_, _obug, ewat_,
   {{0x25a54d8d,0x61fc07e7,0x037a015a,0x2b40166d}},	//   lell_, sirl, _صحبت_, žici_,
   {{0x62800068,0xf41300a1,0x63a64d8e,0x61fc0605}},	// [4420] ámod, _מפה_, mekn, pirl,
   {{0x25a54d8f,0x6b9b4d90,0x62864d91,0x00ca0ebf}},	//   nell_, _abug, muko, _блок_,
   {{0x62864d92,0x6abb0032,0xec7a4d93,0x6b9b083e}},	//   luko, _aruf, упе_, _bbug,
   {{0x25a54d94,0x28bd397e,0x6abb4d95,0x3ea90270}},	//   hell_, ्मनि, _bruf, bwat_,
   {{0x7c224d96,0x62864d97,0xeafa33c6,0x2b440167}},	//   rlor, nuko, درات_, _vgmc_,
   {{0x27e64d98,0x6b9b4d99,0xdb1b0072,0xe6070246}},	//   _slon_, _ebug, _couñ, _رش_,
   {{0x25a54d9a,0x62864d9b,0x7c2240d3,0x27e60383}},	//   dell_, huko, plor, _plon_,
   {{0x62864d9c,0x765b0027,0x00000000,0x00000000}},	//   kuko, fpuy, --, --,
   {{0xe9ff0028,0x25a54d9d,0x69961d2f,0x6abb00f0}},	//   _quản_, fell_, _грех, _gruf,
   {{0x25a54d9e,0x78bc001f,0xab5d00bd,0x44980120}},	//   gell_, _árvo, _inża, авою_,
   {{0xd4970084,0xd5b7007b,0x22494d9f,0x9d260033}},	//   бря_, ссы_, _suak_, _বলুন_,
   {{0x22490332,0x62864da0,0x645a436f,0x2419022a}},	//   _puak_, fuko, rpti, ромы_,
   {{0x25a54da1,0xb33b001f,0x998c00e7,0x62864da2}},	//   bell_, reço, _midž_, guko,
   {{0x25a54da3,0xe67700a1,0x073700a1,0x645a1a92}},	//   cell_, _פתוח_, _האדם_, ppti,
   {{0x63a60167,0x67220167,0xba3d00b6,0xc0c84da4}},	//   bekn, _hyoj, _průz, буте_,
   {{0x6722010a,0x3ea94da5,0x63a60167,0xd31a0294}},	//   _kyoj, twat_, cekn, ọtụr,
   {{0x9df90832,0x644a47c3,0x3f894da6,0xe3b001c3}},	// [4430] анат_, _hufi, rgau_, _سري_,
   {{0xdce70067,0x644a4da7,0xa2c615e4,0x6b9b0036}},	//   _zdję, _kufi, ामर्, _sbug,
   {{0x21270019,0x656a1b5a,0x00000000,0x00000000}},	//   _ánh_, _mefh, --, --,
   {{0x644a3480,0x661a0995,0x60da00aa,0x3ea907ac}},	//   _mufi, hotk, ätme, pwat_,
   {{0x644a4da8,0xf42a00c2,0x661a4da9,0x00000000}},	//   _lufi, lvää_, kotk, --,
   {{0x5ce74daa,0x25a50428,0xc9870686,0x63a601d3}},	//   _люба, xell_, суди, zekn,
   {{0x25a54dab,0x644a2d92,0x62864dac,0x661a0094}},	//   vell_, _nufi, zuko, dotk,
   {{0x20094dad,0x6b9b4dae,0x59c7030b,0x62860112}},	//   nnai_, _ubug, लाहर, yuko,
   {{0x64584daf,0x25a5199d,0x785100d9,0x6abb0193}},	//   _atvi, tell_, _dāva, _uruf,
   {{0x661a0106,0x63a60821,0x644a4db0,0x7a2d4db1}},	//   gotk, wekn, _bufi, sútb,
   {{0x25a54db2,0x20090085,0x66830018,0x388e00a7}},	//   rell_, knai_, _کیخل, _dərs_,
   {{0x25a54db3,0x62864db4,0x644a0193,0x59c70980}},	//   sell_, tuko, _dufi, लावर,
   {{0x8c1a09c1,0x25a54db5,0x63a64db6,0xf7704db7}},	//   שורי, pell_, rekn, _سان_,
   {{0x6d4701e5,0x27ff4db8,0x644a00e7,0x20090d7c}},	//   _ngja, liun_, _fufi, enai_,
   {{0x61434db9,0x62864dba,0xd5b801d3,0xd6180018}},	//   дера, suko, klāj_, _اتنا_,
   {{0x27ff0032,0x543612eb,0x247500d9,0x6d554dbb}},	//   niun_, _برتر, mām_, _afza,
   {{0x44204dbc,0x76434dbd,0x9d2600c7,0x29f600a5}},	// [4440] _iki_, _kiny, _বলেন_, cław_,
   {{0x76434dbe,0x644a01c2,0x764b4dbf,0x10a60cc6}},	//   _jiny, _yufi, _mugy, _дион,
   {{0x76434a02,0x24750029,0x44204dc0,0x764b0172}},	//   _miny, nām_, _kki_, _lugy,
   {{0x76434dc1,0x27ff2d1f,0xeb9a0396,0x661a0106}},	//   _liny, jiun_, рид_, zotk,
   {{0x27ed4dc2,0x27ff4dc3,0x1fb501b6,0xa9230a7f}},	//   dhen_, diun_, _эсэр, ížno,
   {{0x76434dc4,0x247500d9,0x27ed10ba,0x09e304d9}},	//   _niny, kām_, ehen_, мочн,
   {{0x24750b4b,0x44204dc5,0xe7862b49,0xd7c5009d}},	//   jām_, _oki_, оупо, वांच,
   {{0x44204dc6,0x27ff0113,0x247500d9,0x644a48d5}},	//   _nki_, giun_, dām_, _rufi,
   {{0xa3ce1085,0x09c40081,0x76434dc7,0x661a1a3a}},	//   रान_, ্সবা, _biny, totk,
   {{0x44200068,0x44324dc8,0x764b00f9,0x76430d2a}},	//   _aki_, _ahy_, _dugy, _ciny,
   {{0x76430496,0x247500d9,0xf3ff0161,0x200900c6}},	//   _diny, gām_, tiã_, ynai_,
   {{0x27ed3477,0x27ff002d,0x2b400559,0x661a4dc9}},	//   chen_, ciun_, žicu_, sotk,
   {{0x4420009d,0x661a4dca,0x764b010a,0x76434dcb}},	//   _dki_, potk, _gugy, _finy,
   {{0x44204dcc,0x247500d9,0x76434dcd,0x61ee00f9}},	//   _eki_, bām_, _giny, ghbl,
   {{0x645802ec,0x29f60034,0xd48f0f80,0xf3ff0131}},	//   _utvi, sław_, _юр_, piã_,
   {{0x35e00da9,0x187b00c1,0x316600e7,0x76434dce}},	//   _पकड़, יטלב, _đoze_, _ziny,
   {{0x20094dcf,0x44394dd0,0x5434001c,0x6b514dd1}},	// [4450] rnai_, mms_, _ترور, _lógó,
   {{0x31351d1c,0x27ff3177,0xdcbb4dd2,0x27ed03e3}},	//   _непр, ziun_, ище_, zhen_,
   {{0x44394dd3,0x27ed0052,0x7a2400b3,0x00000000}},	//   oms_, yhen_, còti, --,
   {{0xf537006e,0xdb1b0231,0x25b900e8,0x27ed0216}},	//   קטאר_, _anuá, ēsli_, xhen_,
   {{0x601303e5,0xed150018,0x247501d3,0x44394dd4}},	//   għme, _کہاں_, zām_, ims_,
   {{0xa96600c9,0x7f3a00ca,0x69c200b6,0x26df0350}},	//   пиша_, _לערו, लागी, vyuo_,
   {{0x764b4dd5,0x27ed4dd6,0x76434dd7,0x68254dd8}},	//   _sugy, then_, _riny, lódi,
   {{0x76434dd9,0x75ed19a3,0xf77106f6,0x44394dda}},	//   _siny, _múze, راب_, jms_,
   {{0x76434ddb,0x27ed4ddc,0xadc40032,0x27ff023b}},	//   _piny, rhen_, _afẹr, riun_,
   {{0x27ed0a75,0x24750029,0x4439013f,0x27ff072f}},	//   shen_, tām_, ems_, siun_,
   {{0x44200a25,0x7a2d0072,0x26cd002b,0x388e013c}},	//   _pki_, cúta, sxeo_, _fərq_,
   {{0x38352787,0x247500d9,0xdce7030b,0x471c0134}},	//   _энер, rām_, _nejč, ịvụ_,
   {{0x764300ac,0x247501d3,0xddcd4ddd,0x75ed0220}},	//   _tiny, sām_, draž, _púzd,
   {{0x443200a1,0x44394dde,0x247501d3,0x66ba0327}},	//   _why_, ams_, pām_, _למנה,
   {{0x3116007d,0x442000a4,0x412a282a,0x200c0161}},	//   _दुखः_, _tki_, сово_, édio_,
   {{0xe0434ddf,0x8ca60251,0xb4c93751,0x66010188}},	//   енси, _टैगो, ोही_, lilk,
   {{0x6813044c,0x31710154,0x00000000,0x00000000}},	// [4460] căde, bazz_, --, --,
   {{0x63b60188,0xf8bd058f,0x66010f1c,0xd838022b}},	//   _hayn, ्माय, nilk, _apčl_,
   {{0x63b60b88,0xddcd02dd,0x61fe4de0,0xdd8f0604}},	//   _kayn, braž, _impl, اوم_,
   {{0x20570341,0x660101ee,0x1b150033,0x00000000}},	//   _מיטל_, hilk, তেছে_, --,
   {{0x63b64bbd,0x66011124,0x61fe0227,0x00000000}},	//   _mayn, kilk, _kmpl, --,
   {{0x63b6008c,0x27fd03a8,0x2d8c0ac9,0x00000000}},	//   _layn, _amwn_, _øde_, --,
   {{0xdca321fd,0x66014de1,0x44394de2,0xb21b3459}},	//   _пари, dilk, yms_, kræn,
   {{0x7a2d1bf1,0x63b6041c,0x00000000,0x00000000}},	//   rúta, _nayn, --, --,
   {{0x61fe0472,0x96341cbb,0x2e3402c3,0x00000000}},	//   _ompl, мниц, räff_, --,
   {{0xf9c40814,0x66010085,0x7a2d0206,0xddcd015c}},	//   _تحری, gilk, lútn, zraž,
   {{0x69c84de3,0xdcfc01e8,0xb21b003e,0x63b6008c}},	//   _inde, _karı, fræn, _bayn,
   {{0xb21b01c5,0x61fe1171,0x63b60188,0x21ef0364}},	//   græn, _ampl, _cayn, _mühe_,
   {{0x44394de4,0xe9ff0028,0xddcd4de5,0x69da4de6}},	//   rms_, _quần_, vraž, _kote,
   {{0x44394de7,0x69da02fd,0x66014de8,0x22450212}},	//   sms_, _jote, cilk, ölk_,
   {{0xddcd02e6,0x859b00a1,0x69da4de9,0xdf5a0294}},	//   traž, _השוו, _mote, _ọnụa,
   {{0xa3ce3245,0xe9ff0028,0x61fe4dea,0x22960c08}},	//   राण_, _tuần_, _empl, bæk_,
   {{0x69c82cbc,0xe9ff00de,0x52151102,0x69da1d4b}},	// [4470] _onde, _huấn_, _одит, _oote,
   {{0x69da4deb,0xd5b801d3,0x31710063,0x9f490076}},	//   _note, ndā_, qazz_, mhaí_,
   {{0x6825001f,0xdcfc03a3,0x26c00138,0x5c75002d}},	//   sódi, _barı, _šiol_, флет,
   {{0x3eb2007b,0xd7e60076,0x00000000,0x00000000}},	//   äntä_, _شك_, --, --,
   {{0x69da4dec,0xa3ce02e8,0x69c84ded,0x7ae24dee}},	//   _bote, रात_, _bnde, gyot,
   {{0x69da0df4,0xdea4010d,0xbde50113,0x3c2e0031}},	//   _cote, _سیمی, _dhèè, rýva_,
   {{0x7c84426e,0x66014def,0x69da4df0,0x9e343e4b}},	//   _путе, vilk, _dote, _черч,
   {{0x2d8c026a,0x7b080076,0x69da01ff,0x28040174}},	//   _öder_, ástá, _eote, ịanụ_,
   {{0x66014df1,0x91d00034,0x00000000,0x00000000}},	//   tilk, दामै, --, --,
   {{0xd70602fd,0xa37b00aa,0x63b6008c,0x00000000}},	//   ьные_, skõl, _sayn, --,
   {{0xdcfc0702,0x6add00a5,0xb21b34da,0x7bc901d0}},	//   _yarı, _मथुर, træn, _kneu,
   {{0xd91a0132,0x66014df2,0x68e3338b,0xa3ce08c0}},	//   _וועל, silk, mynd, राध_,
   {{0x68e3003e,0xb21b4df3,0x28bd1da8,0x69da037a}},	//   lynd, rræn, ्मवि, _yote,
   {{0x63b64df4,0x229602b6,0x00000000,0x00000000}},	//   _wayn, ræk_, --, --,
   {{0x3243107a,0xa3ce0789,0x80ba0034,0x1fb60e05}},	//   терг, राद_, ॉमें, мсар,
   {{0xdfd200e3,0xc7b90018,0x7a2d4df5,0x00000000}},	//   خير_, ndő_, kúto, --,
   {{0x1dc90e72,0xdb000088,0x9f4900e3,0x24530023}},	// [4480] रांत, _samþ, chaí_, _hãm_,
   {{0xdcfc03a3,0x7ae20010,0x61fe00d3,0xee370acf}},	//   _sarı, vyot, _umpl, дну_,
   {{0x7e760154,0xd344001c,0xdcfc173c,0x00000000}},	//   ssyp, _تفکی, _parı, --,
   {{0xdcfc0092,0x628618f0,0x7bc903a8,0x78bc0e2e}},	//   _qarı, orko, _cneu, _árvi,
   {{0x19580138,0x245300de,0xbb4301b3,0xdcfc020e}},	//   палы_, _lãm_, вецк, _varı,
   {{0x7ae20f6e,0x6fb4009d,0x98c618fa,0x62861350}},	//   ryot, _उघडू, дсил, irko,
   {{0x68e301c5,0xdcfc026a,0x69da1b14,0x7ae200f9}},	//   gynd, _tarı, _vote, syot,
   {{0x5fd1009d,0xb8d600c0,0xdb000094,0x7a2d35e3}},	//   हायल, _छन_, _zamý, búto,
   {{0x69da4df6,0x6d432102,0xab5d007f,0x00000000}},	//   _tote, žnat, _noży, --,
   {{0x69c840d5,0xd49a0012,0x7bc9025b,0x752f00a5}},	//   _unde, орм_, _zneu, ęczn,
   {{0x35f700e3,0x62804df7,0xe9ff0023,0xd5b801d3}},	//   بريد_, ámon, _quấn_, rdā_,
   {{0x9f490037,0x00000000,0x00000000,0x00000000}},	//   thaí_, --, --, --,
   {{0x3dca0154,0x00000000,0x00000000,0x00000000}},	//   _onbw_, --, --, --,
   {{0xe9ff0019,0xd84f0174,0xddcd14f3,0xab5d007f}},	//   _tuấn_, pọtu_, ksaš, _doży,
   {{0x3015001f,0x62864df8,0x00000000,0x00000000}},	//   едвр, arko, --, --,
   {{0xdb0033b8,0xb21b0088,0x09db42d4,0x00000000}},	//   _jamó, mræm, _भव्य, --,
   {{0xdb000143,0x00000000,0x00000000,0x00000000}},	// [4490] _mamó, --, --, --,
   {{0x442b030a,0xc7b90103,0x7bc91cab,0x25ac00f0}},	//   llc_, zdő_, _sneu, nedl_,
   {{0x7bc94df9,0x611400d3,0xdcfc01d3,0x3d940095}},	//   _pneu, _адэу, _marķ, тихр,
   {{0xaa071c83,0x1a650504,0x00000000,0x00000000}},	//   वच्छ_, فیری_, --, --,
   {{0x442b152f,0x00000000,0x00000000,0x00000000}},	//   ilc_, --, --, --,
   {{0x7bc902ad,0x1c002c5d,0x68e30ac1,0x28bd07d5}},	//   _wneu, लोबल_, tynd, ्मलि,
   {{0xdd94004b,0x4c170281,0xdcee0034,0x00000000}},	//   _шары, _قبرس, _odbę, --,
   {{0x68e3010a,0xbddb020d,0xd7750037,0x62864dfa}},	//   rynd, _guèr, رابع, yrko,
   {{0x68e30407,0xa3ce178c,0xd7092a6e,0xd90e0018}},	//   synd, रास_, яние_, لیے_,
   {{0x7c2b4dfb,0xb4650b2e,0xaca30294,0x9f400037}},	//   llgr, нкол, _nhịa, thiú_,
   {{0x64c90789,0xdb004dfc,0xc7bb0fe9,0x2a6d01ff}},	//   िमेश, _famó, _мёд_, _hweb_,
   {{0xab5d0034,0x8ca80ff9,0xf8bd07ad,0x00000000}},	//   _poży, _घनघो, ्मीप, --,
   {{0xc7d60c6a,0xd9e300c3,0x1ae10033,0x62864dfd}},	//   _רוני_, _औकात_, _খেতে_, urko,
   {{0xdb0000a5,0xe2a701cd,0x7c2b4dfe,0x645c0143}},	//   _zamó, óðar_, hlgr, íric,
   {{0x8fa64dff,0x1c1f0d77,0xc9520289,0x30750ed4}},	//   наве, यकाल_, רמל_, кутс,
   {{0x62864e00,0xdb000042,0x442b2ad7,0x00000000}},	//   prko, _xamó, clc_, --,
   {{0x44224e01,0x63a44e02,0x8d6622f6,0xdb0005aa}},	// [44a0] mok_, _ibin, евзе, _lamò,
   {{0x44224e03,0xa3ce3516,0x7c2b3155,0xad6500d1}},	//   lok_, राव_, elgr, نامه,
   {{0x9f9c0065,0x3b860231,0x2d870328,0x00000000}},	//   _díò_, елег, ónea_, --,
   {{0x44224e04,0x00000000,0x00000000,0x00000000}},	//   nok_, --, --, --,
   {{0xdb003c9e,0x5b231736,0x63a44e05,0xe7d30ff9}},	//   _ramó, льша, _mbin, थानप,
   {{0x44224e06,0xdb000154,0xcb070037,0xddcd0233}},	//   hok_, _bamò, عيون_, mpaş,
   {{0x6d4e4e07,0x63a4026e,0x22440146,0xbad80033}},	//   _igba, _obin, ímky_, _দেখছ,
   {{0x8c434e08,0x3f9201c2,0x63a40129,0x44224e09}},	//   _бесе, ngyu_, _nbin, jok_,
   {{0x44224e0a,0x7c224e0b,0x62800018,0xa6140291}},	//   dok_, moor, ámol, кмич,
   {{0x63a44e0c,0x7c2237f3,0x80e000b7,0x6d4e033c}},	//   _abin, loor, नहाइ, _jgba,
   {{0x6d4e06c0,0xa37b00aa,0x63a44e0d,0xf993006e}},	//   _mgba, lkõi, _bbin, _תרע_,
   {{0x44224e0e,0x7c224e0f,0x2bc643e2,0x988b0103}},	//   gok_, noor, _रोमा, _رحمہ_,
   {{0xa2be034d,0x6d5c06a3,0x55e64e10,0x6d4e0294}},	//   शिष्, _ofra, _подб, _ogba,
   {{0x7c220934,0xdb0246b4,0x63a40283,0x442b00b3}},	//   hoor, ndoñ, _ebin, slc_,
   {{0x44224e11,0x7c224e12,0xa3ce00c3,0xb7bd044c}},	//   bok_, koor, राश_, soţe,
   {{0x6d4e4e13,0x44224e14,0x629a00d3,0x2b490d62}},	//   _agba, cok_, ător, žaci_,
   {{0x7e641281,0x7c224e15,0xa3b8001c,0x764a0350}},	// [44b0] gpip, door, _ساير_, _kify,
   {{0xab5d00bd,0x63bd041b,0x628f0027,0x7c220abf}},	//   _inżi, ldsn, muco, eoor,
   {{0x55770130,0x7c224e16,0x628f4e17,0x6d5c4e18}},	//   געבן_, foor, luco, _dfra,
   {{0x6d5c4e19,0x7c224e1a,0x63af0146,0x207a021e}},	//   _efra, goor, necn, _קארא,
   {{0x629d4e1b,0x6d5c0150,0xe8df00de,0x628f00d8}},	//   ntso, _ffra, _phỏm_, nuco,
   {{0x44224668,0xdb0b3912,0x629d1a6c,0x66e70139}},	//   zok_, negé, itso, _lékú,
   {{0x5ba708a4,0x7c223beb,0x44224e1c,0x20020167}},	//   _праз, boor, yok_, _ymki_,
   {{0x63af0dd9,0x7c22211d,0x629d0a1f,0xd5b800e8}},	//   jecn, coor, ktso, klās_,
   {{0x629d4e1d,0xdcee030b,0x44224e1e,0x645c0174}},	//   jtso, _odbě, vok_, ̣rit,
   {{0x4422072f,0x628f4e1f,0x316602ef,0x62800103}},	//   wok_, duco, _đozo_, ámom,
   {{0x44224e20,0x06df0033,0xd7e7004d,0x764a0178}},	//   tok_, _বেশি, _підо, _dify,
   {{0x1ad80081,0xa2be17ff,0x6ec4088d,0x629d4e21}},	//   _দেয়া, शिल्, रिमु, ftso,
   {{0x44224e22,0x21f400aa,0x06df0033,0x629d0c89}},	//   rok_, _lähe_, _বেরি, gtso,
   {{0x44224e23,0x68250143,0x6d5b0233,0x21ef00bc}},	//   sok_, códr, _şuan, _püha_,
   {{0x44224e24,0x21f401bf,0x7e7d4e25,0xab5d02a1}},	//   pok_, _nähe_, _avsp, _enżi,
   {{0x63a421ef,0x6d5c18ba,0xe3b200b1,0xd84e0174}},	//   _ubin, _sfra, _ضرب_, kọnd_,
   {{0x539b0054,0xf7720130,0x7c220934,0x785101d3}},	// [44c0] _חיפו, יקן_, voor, _dāvi,
   {{0x7c220db8,0x4d634e26,0xb33b0233,0x00000000}},	//   woor, икув, reçt, --,
   {{0xeb9a12e7,0x7c224e27,0x8c46120a,0xc2c90a85}},	//   дие_, toor, веже, _قبیل_,
   {{0x31780034,0xe7270e00,0x7981039f,0x7a2d0076}},	//   larz_, _نص_, _adlw, lúth,
   {{0x7c221f49,0x7f1a0120,0x3f8201ee,0x00000000}},	//   roor, _ціну_, _idku_, --,
   {{0x7c224e28,0xa3ce0179,0x6934001c,0x6d5c4e29}},	//   soor, राँ_, هکار, _ufra,
   {{0x7c2204e2,0xa37b00aa,0xdcee0154,0x09e300f6}},	//   poor, skõi, _kebč, ројн,
   {{0x61df110f,0x67f50038,0xb21b052f,0x20124e2a}},	//   _नक्ष, _nájd, træk, nnyi_,
   {{0x31780034,0x68250850,0x680703a9,0xbb4310e0}},	//   karz_, tódr, _sèjè, _ветк,
   {{0xb21b4d1e,0x00000000,0x00000000,0x00000000}},	//   rræk, --, --, --,
   {{0x63af0f8a,0x624b03e5,0xb4cc00bc,0x2caa0063}},	//   tecn, _bżon, रमे_, _jpbd_,
   {{0x601303e5,0xd5be01d3,0x629d0b85,0xbf9b016d}},	//   għml, _šāda_, ttso, _amên,
   {{0x61e10149,0x63af1c54,0x68250143,0x63bd4e2b}},	//   öllo, recn, pódr, rdsn,
   {{0x629d03f3,0x63af042d,0xdcfc022b,0x20120172}},	//   rtso, secn, _adrč, enyi_,
   {{0x67f50103,0x629d4e2c,0x00000000,0x00000000}},	//   _fájd, stso, --, --,
   {{0xa3ce0179,0x66080188,0x26c200d4,0xb4de00a4}},	//   राः_, lidk, ťkou_, णही_,
   {{0x44294e2d,0x2caa00a4,0x644d01b9,0x3869042d}},	// [44d0] _ika_, _apbd_, _iiai, ćari_,
   {{0x2caa0085,0x20120283,0x644d0178,0x21f400bc}},	//   _bpbd_, anyi_, _hiai, _pähe_,
   {{0x9f9c003e,0x2cb801c2,0x645e020d,0x270e4e2e}},	//   _tíð_, _csrd_, _épid, ापुर_,
   {{0x44290154,0x21f400aa,0xddcd0031,0x00000000}},	//   _jka_, _vähe_, dsať, --,
   {{0x53a5048a,0x20094e2f,0x26c6022e,0x3b8401ce}},	//   ग्यश, miai_, _nroo_, рліг,
   {{0x200908a1,0x644d4e30,0x6608008c,0x5fb90096}},	//   liai_, _liai, jidk, _उघडल,
   {{0xa3e402d5,0x645c0174,0x644d01ff,0x7a2d0206}},	//   पॉड_, ̣rir, _oiai, núti,
   {{0x200908a1,0x44294e31,0x26c60085,0xa3d7009f}},	//   niai_, _nka_, _broo_, साफ_,
   {{0x7c2902a7,0xa3d70abe,0x4a541e13,0x46492383}},	//   _iker, सान_, _вкус, нзин_,
   {{0x44294e32,0xf9930dd0,0xe6160dd8,0x20094e33}},	//   _aka_, _خبر_, лды_, hiai_,
   {{0x2009013f,0x7c3b4e34,0x44293d79,0x240a008f}},	//   kiai_, _khur, _bka_, енни_,
   {{0xa3ce1757,0x4429023b,0x644d0231,0x67f5023c}},	//   राइ_, _cka_, _ciai, _báje,
   {{0xe5a51352,0xe2c70bd5,0x7c3b1c4d,0x2d83015c}},	//   _били, гляд_, _mhur, _odje_,
   {{0x44294e35,0x27ed1bfa,0xab5d00bd,0x6603063d}},	//   _eka_, lken_, _inżu, _umnk,
   {{0x644d4e36,0x7c2902c4,0x7c3b0129,0x624b00bd}},	//   _fiai, _oker, _ohur, _iżol,
   {{0x27ed4e37,0x20094e38,0x7c294e39,0x2d834bb9}},	//   nken_, giai_, _nker, _adje_,
   {{0xee3a07b3,0x27ed4e3a,0x25f70d77,0x8f7504a1}},	// [44e0] ена_, iken_, एसपी_, русі,
   {{0xdd92006f,0x7c3b4e3b,0x7c294e3c,0x27ed0167}},	//   صوص_, _ahur, _aker, hken_,
   {{0x27ed4e3d,0x67f5030b,0x7c3b0cc2,0x20090138}},	//   kken_, _záje, _bhur, biai_,
   {{0x27ed0505,0xa3d7022d,0x20094e3e,0x7c3b4e3f}},	//   jken_, साय_, ciai_, _chur,
   {{0x7c3b4e40,0x09e64e41,0xead44e42,0x66080188}},	//   _dhur, лодн, роль, yidk,
   {{0x2d83029b,0x27ed0ab2,0x7c290129,0x2fc04e43}},	//   _gdje_, eken_, _eker, ldig_,
   {{0x3ea04e44,0x7c3b07bc,0x66084e45,0xf9690120}},	//   ltit_, _fhur, vidk, трій_,
   {{0xd6da4e46,0x7c2901ff,0x7c3b0350,0xdbca00bc}},	//   ето_, _gker, _ghur, _põõs,
   {{0x3ea04e47,0xa3ce099d,0xb4cc0bf5,0x35f405ed}},	//   ntit_, राई_, रम्_, ипир,
   {{0x44291424,0xa96a00e3,0x27ed4e48,0xceb3040a}},	//   _ska_, _أمام_, aken_, צית_,
   {{0x2ed108c0,0x66080188,0xd82f00ae,0x25a7029a}},	//   _सप्त, ridk, _гэ_, _dbnl_,
   {{0x27ed4e49,0x3ea04e4a,0x2fc00126,0x78ba0018}},	//   cken_, ktit_, jdig_, _istv,
   {{0xa3d704dd,0x2009013f,0x518700c9,0xe3bf4e4b}},	//   साब_, viai_, лува, goña_,
   {{0x2fc04e4c,0x249c00dc,0x00000000,0x00000000}},	//   edig_, _tqvm_, --, --,
   {{0x657a0201,0xb21b052f,0xf55b00ca,0x00000000}},	//   math, kræv, _אדומ, --,
   {{0x657a4e4d,0x2fc000a6,0x442f4e4e,0x087700c1}},	//   lath, gdig_, _óg_, טעלט_,
   {{0x200901b3,0x33a80465,0x6e954e4f,0xed8b232c}},	// [44f0] riai_, _също_, ризу, есек_,
   {{0x78ba03ce,0x200901b3,0x7c3b4e50,0x7c294e51}},	//   _ostv, siai_, _shur, _sker,
   {{0xd7c4009d,0x2ee92f66,0x7c3b009c,0x27ed4e52}},	//   वयाच, syaf_, _phur, yken_,
   {{0x200c0257,0x657a4e53,0xce95008f,0xa3ce417a}},	//   édit_, hath, _камъ, राए_,
   {{0x657a211a,0x63bf27d9,0x3ea000ee,0x00000000}},	//   kath, _maqn, ctit_, --,
   {{0x17ed04dd,0x88c500e3,0xac770260,0x657a18c7}},	//   जस्व_, لتعل, _مارش, jath,
   {{0x27ed4bab,0x657a3581,0x28c517ad,0x14b0397e}},	//   tken_, dath, विधि, _जनगण,
   {{0x7c3b4e54,0x27ed3987,0x7c294e55,0xdb0b01f9}},	//   _uhur, uken_, _uker, legí,
   {{0x27ed4e56,0x657a4e57,0xe7e605a7,0x6b9b009c}},	//   rken_, fath, _ओकरा_, _icug,
   {{0x657a4e58,0x80bb0081,0xdb000956,0xf1ba00fe}},	//   gath, _উপন্, _camõ, _ươm_,
   {{0x21f4007a,0x2fc04e59,0x7aeb4e5a,0xa8a700e5}},	//   _näha_, ydig_, lygt, _щрак,
   {{0xab5d00bd,0x09aa0033,0x245a0052,0x3ea031cf}},	//   _dażg, _গোপা, _dëm_, ytit_,
   {{0x657a0060,0x63bf0090,0x59b92337,0x6667007b}},	//   bath, _daqn, _इसार, _съез,
   {{0x657a4e5b,0xe1ff03be,0xe3bf1ba6,0x00000000}},	//   cath, spón_, roña_, --,
   {{0xab5d0067,0x61464e5c,0x412a0c58,0x61ee4e5d}},	//   _każd, рева, тово_, rkbl,
   {{0x2fc0043e,0x1f66083c,0x3ea04e5e,0x2fda001c}},	//   udig_, ркам, ttit_, خورد_,
   {{0x2fc04e5f,0xed5a215d,0x3ea03d66,0x753805db}},	// [4500] rdig_, воз_, utit_, _zzvz,
   {{0x3ea04e60,0xc27b07a6,0xa3d707e2,0x645e014b}},	//   rtit_, _שריי, साथ_, _épic,
   {{0x3ea04e61,0x8fa64e62,0x7a2d0088,0x9f420052}},	//   stit_, _кане, nútu, _kokë_,
   {{0x657a0201,0x3ea04e63,0x9f4000c2,0xc50c006e}},	//   zath, ptit_, tkiä_, עלאָ,
   {{0x657a019f,0xa3d74660,0x6b9b009c,0x62880034}},	//   yath, सात_, _dcug, ądow,
   {{0x9f4000ce,0x00000000,0x00000000,0x00000000}},	//   rkiä_, --, --, --,
   {{0x44c500d9,0x218900c1,0x2c6c23c0,0x9f40007b}},	//   _nē_, אָפּ, _dòdò_, skiä_,
   {{0x657a4e64,0x00000000,0x00000000,0x00000000}},	//   wath, --, --, --,
   {{0x8f9b0105,0x657a4e65,0xd6d70a29,0x0ec9023a}},	//   דיפי, tath, атэ_, रियड,
   {{0x35f44e66,0x26c0013f,0x7bc04e67,0x7bc201cb}},	//   спор, _šios_, _hamu, ldou,
   {{0x78ba2904,0xd7ef4e68,0x7d7b03c2,0x6aa22bf6}},	//   _ustv, _ду_, כניו, ltof,
   {{0x0ed6000d,0x7bc04e69,0x657a4e6a,0x386900e7}},	//   ठमाड, _jamu, sath, ćart_,
   {{0x7bc04e6b,0x6aa24e6c,0x657a4e6d,0x7a2d003e}},	//   _mamu, ntof, path, rútv,
   {{0x7bc04e6e,0x7a2d0155,0x657a0372,0x44c50154}},	//   _lamu, sútv, qath, _fē_,
   {{0x16b60179,0xa3d7261e,0x80074e6f,0xdfd50109}},	//   _अनुब, साद_, ачае, бовы,
   {{0x7bc00f8b,0x74151e49,0x6aa24e70,0x2bc6023a}},	//   _namu, _دوبا, ktof, _रोला,
   {{0x64580837,0x6578022e,0xe7ee05a7,0xdb230491}},	// [4510] _huvi, _kevh, _जवना_, ürül,
   {{0x64584e71,0x7bc02a8b,0x6b9b0036,0x5d67007e}},	//   _kuvi, _aamu, _scug, ртаз,
   {{0x7bc03289,0x8d7401f9,0xdcbb008f,0x628000d4}},	//   _bamu, زالا, ъща_, ámov,
   {{0x64580090,0x81b80033,0x61e5042c,0x65784e72}},	//   _muvi, ছাঃ_, _hohl, _levh,
   {{0x7bc04e73,0x61e54e74,0x201e014b,0x67f50206}},	//   _damu, _kohl, étie_, _nája,
   {{0x65781cf3,0x64580396,0x61e502a1,0x3a3e0231}},	//   _nevh, _ouvi, _johl, _chtp_,
   {{0x61e50618,0x7bc04e75,0x00000000,0x00000000}},	//   _mohl, _famu, --, --,
   {{0xe7394e76,0x7bc04e77,0x6abb0d2a,0xe3bf002b}},	//   лей_, _gamu, _tsuf, doño_,
   {{0x6abb4e78,0x6013003d,0x66d30233,0x00000000}},	//   _usuf, għmi, dıkö, --,
   {{0x7bc04e79,0x64584e7a,0x61e5019f,0x00000000}},	//   _zamu, _buvi, _nohl, --,
   {{0x6458002d,0x7bc04e7b,0x628f4e7c,0x00000000}},	//   _cuvi, _yamu, erco, --,
   {{0x69c14e7d,0x6458001f,0x69c34e7e,0x7bc04e7f}},	//   _hale, _duvi, ldne, _xamu,
   {{0xa3e9048a,0x61e54e80,0x975600a1,0x6458002b}},	//   _मकर_, _bohl, _הינו_, _euvi,
   {{0x69c14e81,0x69c34e82,0x00000000,0x00000000}},	//   _jale, ndne, --, --,
   {{0x69c14e83,0x67f50220,0x9f42023b,0x61e51054}},	//   _male, _zája, _tokë_, _dohl,
   {{0x69c14e84,0xf6620294,0x6d55028a,0xdcfe0206}},	//   _lale, _họọr, _agza, tepľ,
   {{0x0d864e85,0x38a100e3,0xf6620174,0x64584e86}},	// [4520] йлан, hór_, _kọọr, _zuvi,
   {{0x69c14e87,0x7bc04e88,0xab8c01e8,0xa7fc0511}},	//   _nale, _samu, _çözü, _atıl,
   {{0x3157040a,0xe6620134,0x6458002b,0xf1d51f88}},	//   _ליין_, _mọọb, _xuvi, दारन,
   {{0x6d554e89,0x6aa22b4d,0x2aa006a3,0x38a1003e}},	//   _egza, ttof, tòb_, dór_,
   {{0x7bc00172,0xe3bf0072,0x7bc24e8a,0x00000000}},	//   _vamu, zoño_, rdou, --,
   {{0x6aa24e8b,0xe2a7003e,0x7bc04e8c,0x2bfa0081}},	//   rtof, óðir_, _wamu, েকেই_,
   {{0x6aa24e8d,0x69c14e8e,0xf8c5009d,0x7bc04e8f}},	//   stof, _dale, विषय, _tamu,
   {{0xb8d005a7,0x7bc00010,0x67f5058a,0x9f4206a3}},	//   _ओह_, _uamu, _pája, _pokè_,
   {{0x69c14e90,0x64584e91,0xa3d70409,0xa3dc00b6}},	//   _fale, _suvi, सास_, ठान_,
   {{0x69c14e92,0xceb3028c,0x38a10034,0xd5ba1e61}},	//   _gale, ליח_, bór_, уси_,
   {{0x28130018,0x61e54e93,0xddc600c6,0xc9570076}},	//   _کونس, _rohl, _atkū, _المش_,
   {{0x69c14e94,0x61e54e95,0xdb0b4e96,0xe3bf03eb}},	//   _zale, _sohl, legá, roño_,
   {{0x61e50363,0xa3ce046e,0x65784e97,0x69c14e98}},	//   _pohl, राज_, _tevh, _yale,
   {{0x64584e99,0x7afd026a,0x2bcf02d5,0xa3d7058f}},	//   _tuvi, _üste, _सोना, साह_,
   {{0x27e600ce,0xb6080206,0x00000000,0x00000000}},	//   _koon_, _vyšľ, --, --,
   {{0x27e64e9a,0x61e54e74,0xdb0b0042,0xb21b0537}},	//   _joon_, _wohl, hegá, træs,
   {{0x6d480871,0x442b2907,0x63ad4e9b,0x61e500b6}},	// [4530] _údaj, moc_, _iban, _tohl,
   {{0xd04701d4,0x442b4e9c,0x63ad3fab,0xa3d70557}},	//   _əmək, loc_, _hban, साव_,
   {{0x69c14e9d,0x69c30117,0x00000000,0x00000000}},	//   _rale, vdne, --, --,
   {{0xb21b052f,0x69c14e9e,0xeb901f11,0x7988030a}},	//   præs, _sale, فظه_, _addw,
   {{0x69c14e9f,0x63ad4ea0,0x8aa70b99,0x38a10034}},	//   _pale, _mban, сред, wór_,
   {{0x7e6d4ea1,0x69c14ea2,0xda782787,0x442b020b}},	//   mpap, _qale, сяц_, hoc_,
   {{0x69c31a02,0x16d100a5,0x63ad4ea3,0x68454ea4}},	//   rdne, तम्ब, _oban, онка,
   {{0x16650acf,0x63ad0134,0x57e92b16,0x442b15d3}},	//   овим, _nban, рдим_, joc_,
   {{0xa3bf1e5e,0x7c2b4ea5,0x69c14ea6,0x27e64ea7}},	//   ीयन_, mogr, _tale, _doon_,
   {{0x63ad3dd3,0x69c14ea8,0x27e60154,0x38c90103}},	//   _aban, _uale, _eoon_, _پائی_,
   {{0xca484ea9,0x04463e04,0x27e6057a,0x442b0428}},	//   _الله_, женн, _foon_, foc_,
   {{0x38850029,0x7e6d4610,0x2bcf074c,0xddcd00e7}},	//   mēr_, kpap, _सोमा, jsaž,
   {{0xe72e0a8d,0x645e00fd,0x67f500d8,0x00000000}},	//   _це_, _épin, _hájo, --,
   {{0x63ad4eaa,0x27e60126,0x6ecd030b,0x7a3f014b}},	//   _eban, _zoon_, सिनु, bête,
   {{0x27e61dd1,0xdfd21f11,0x442b044c,0x67f50139}},	//   _yoon_, ويس_, boc_, _jájo,
   {{0x628030a1,0x6b892f79,0xb4d54eab,0x63ad4eac}},	//   ámos, _ndeg, समी_, _gban,
   {{0xa3d722a3,0x7e6d13b5,0x7c2b005f,0xc7b2040a}},	// [4540] सार_, gpap, dogr, ובן_,
   {{0x0d8616dd,0x13a60018,0x6ab80033,0x6813044c}},	//   ілен, _اچھی_, _আপলো, mădu,
   {{0xb60700d9,0x67f50220,0xad65001c,0xd5fa006e}},	//   mašī, _nájo, ساله, ספער,
   {{0x35db009f,0x0a6a4ead,0x7c2b0565,0x00000000}},	//   बाड़, арки_, gogr, --,
   {{0x27e64bbd,0x254e0092,0x6013003d,0x7d240018}},	//   _roon_, zəl_, għmu, _کہان,
   {{0x6b894eae,0xc8c50789,0x27e64eaf,0xc8660cb0}},	//   _edeg, विंट, _soon_, отии,
   {{0x27e6003a,0x23ca0179,0x2e2f0364,0xdb0b00d4}},	//   _poon_, ियाद, rüft_, regá,
   {{0x254e01d4,0x7a3f00fd,0xeb970cba,0x76aa0c79}},	//   vəl_, vête, _мис_, атов_,
   {{0x442b4955,0x27e60063,0x6a830236,0x7a2d4cf5}},	//   voc_, _voon_, _олта, rútr,
   {{0x27e60a9f,0xd9460f84,0x80bb0081,0x63ad4eb0}},	//   _woon_, _дези, _উপস্, _sban,
   {{0x27e6043e,0xa3d70336,0x442b4eb1,0x41de030b}},	//   _toon_, साल_, toc_, मानस,
   {{0x7a3f0257,0xab5d00bd,0x3fc50033,0x00000000}},	//   rête, _każa, _এক্ষ, --,
   {{0x442b4eb2,0x23dd009d,0x6813020a,0x555800ae}},	//   roc_, याबद, gădu, _лаля_,
   {{0x67fc4eb3,0x14b70103,0x00000000,0x00000000}},	//   _déje, حدیث_, --, --,
   {{0x7c2b4eb4,0xba3d030b,0x957c0034,0x623400d3}},	//   yogr, _způs, ając, феру,
   {{0x63ad4eb5,0x682500a5,0x6d580138,0x7e6d4eb6}},	//   _uban, wódz, žval, tpap,
   {{0xab5d0090,0x00000000,0x00000000,0x00000000}},	// [4550] _naża, --, --, --,
   {{0x7c2b0c56,0xf2d200c1,0xe2a7003e,0x6b89028d}},	//   wogr, _װעט_, óður_, _sdeg,
   {{0x7e6d4eb7,0x40351a0c,0x61e10088,0x313528b9}},	//   spap, _неос, öllu, _хенр,
   {{0xf3ff0396,0xab5d4eb8,0x3c3c37b9,0xc17b0022}},	//   nhã_, _baża, tíva_, ɗɗan_,
   {{0xa96903fc,0xa3e9034c,0xda35013f,0x00000000}},	//   била_, _मकई_, педы, --,
   {{0xf1cb0285,0xb7bd00ae,0xf1de0179,0x997e020a}},	//   ायिन, moţi, मायन, răşi_,
   {{0x2d814eb9,0x67f50103,0xb6070138,0x997e020a}},	//   mahe_, _fájl, našū, săşi_,
   {{0x96951068,0xe7a6088d,0xd5e20139,0x2d8100d1}},	//   прош, क्लप, _atò, lahe_,
   {{0x06092dd1,0x41cb40ba,0xf1cb4eba,0xf7710d7f}},	//   йник_, ायास, ायान, واک_,
   {{0x2d814ebb,0xc9f70037,0xd706007b,0x245a00e8}},	//   nahe_, _بسرع, яные_, _zīmi_,
   {{0xc32900a1,0x645e00fd,0x00000000,0x00000000}},	//   _עו_, _épil, --, --,
   {{0x3d1900b6,0x2d810350,0x00000000,0x00000000}},	//   _दशैं_, hahe_, --, --,
   {{0xc5f5008f,0x9f590154,0x96650fe9,0x2d8103a9}},	//   _някъ, _ilsè_, _экле, kahe_,
   {{0x21670231,0x27ff0d2a,0x6813020a,0x00000000}},	//   зири_, lhun_, rădu, --,
   {{0xe3c203e0,0xdb0900b3,0x2d8103a9,0x00000000}},	//   _alış_, _obeï, dahe_, --,
   {{0x27ff0124,0x26cf0a39,0xddc4033b,0x998702c6}},	//   nhun_, _krgo_, dpiš, konů_,
   {{0x35d0000f,0x44200857,0x67f50094,0x27ff03e3}},	// [4560] _थोड़, _iji_, _nájm, ihun_,
   {{0x628603ce,0xb21b0088,0x6146013f,0x7ce10174}},	//   msko, nsæl, _непа, _ịrah,
   {{0xd7bd0454,0xc1730054,0xe7bd034d,0x62864ebc}},	//   ्याच, _אחת_, ्याप, lsko,
   {{0x5f070034,0xfaa61824,0x26cf0072,0x60db00ca}},	//   _सेक्_, задо, _orgo_, _הקטנ,
   {{0x62860ca7,0x44200010,0x64564ebd,0x27ff4ebe}},	//   nsko, _mji_, _miyi, dhun_,
   {{0x201201d4,0x62864ebf,0x64564874,0x433b006e}},	//   liyi_, isko, _liyi, זענב,
   {{0x44204ec0,0x26cf4293,0x44324ec1,0x7af200b6}},	//   _oji_, _argo_, _oky_, _řetě,
   {{0x44204ec2,0x20124ec3,0x7643005c,0xfaa62c49}},	//   _nji_, niyi_, _ahny, _набо,
   {{0x628603ce,0xfaa40260,0xf4220033,0x1de01178}},	//   jsko, _تجزی, নতার_, नापत,
   {{0x628600e9,0x44204ec4,0x44324ec5,0x64440027}},	//   dsko, _aji_, _aky_, _ahii,
   {{0x439507ca,0xbebb023b,0x64564ec6,0x67f500b6}},	//   манс, _nxën, _biyi, _zájm,
   {{0x64444ec7,0x6722006c,0x6b82190e,0x6456010a}},	//   _chii, _txoj, naog, _ciyi,
   {{0x64440694,0x62864ec8,0x64564ec9,0x201201d4}},	//   _dhii, gsko, _diyi, diyi_,
   {{0x442006c0,0x6f0400a5,0x44320a15,0x171b00a1}},	//   _eji_, dzic, _eky_, _פוגע,
   {{0x20124eca,0x644401b9,0x2d814ecb,0x64a3125f}},	//   fiyi_, _fhii, vahe_, _заја,
   {{0x75370054,0x999e013f,0x645634bd,0x200000d3}},	//   _מאוד_, _kitų_, _giyi, ghii_,
   {{0xdb080257,0xa3d30d29,0x6b824ecc,0x2d814ecd}},	// [4570] _élèv, _होय_, daog, tahe_,
   {{0x44394ece,0xddc40335,0xdb0b13cd,0x64561a05}},	//   lls_, tpiš, negå, _ziyi,
   {{0x64570fb6,0x999e013f,0x271e00de,0x64564ecf}},	//   _éxit, _litų_, ịnh_, _yiyi,
   {{0xa3d32231,0x44cc000d,0x200000d3,0x09aa0081}},	//   _होम_, _mě_, chii_, _গোলা,
   {{0x44394ed0,0xd90f0018,0xddc40542,0x2d870487}},	//   ils_, گیا_, spiš, ónes_,
   {{0x4439128c,0x3ea94ed1,0x2fc94ed2,0x614700fd}},	//   hls_, mtat_, ldag_, célé,
   {{0xd90f0068,0x44cc00b6,0x443901d3,0x27ff4ed3}},	//   دیا_, _ně_, kls_, thun_,
   {{0x2fc91044,0x44394ed4,0x62864ed5,0x00000000}},	//   ndag_, jls_, ysko, --,
   {{0x3ea94ed6,0x4439030a,0xa3d70e19,0x64564ed7}},	//   ntat_, dls_, साई_, _riyi,
   {{0x64444ed8,0x201224c3,0x64564ed9,0x44394eda}},	//   _shii, ziyi_, _siyi, els_,
   {{0x6f0400e5,0x79834edb,0x394001c2,0x64564edc}},	//   zzic, manw, ƙisa_, _piyi,
   {{0x62860106,0x2fc90ab2,0x3ea94edd,0x44390877}},	//   tsko, jdag_, ktat_, gls_,
   {{0x3ea900dd,0xe5a53df8,0x6286007b,0x67f501f9}},	//   jtat_, _жили, usko, _lájk,
   {{0x42554ede,0xd2520018,0x44394edf,0x2bcf4c5b}},	//   етст, ئنس_, als_, _सोसा,
   {{0x62860331,0x64564ee0,0xa0a325d6,0x6147020d}},	//   ssko, _tiyi, кард, vélé,
   {{0x628600e9,0x2fc94ee1,0x6f040126,0x94260f1e}},	//   psko, gdag_, tzic, _імпе,
   {{0x79834ee2,0xb226001f,0x2a6d0113,0x20124ee3}},	// [4580] kanw, _омил, _nteb_, riyi_,
   {{0x6f044ee4,0x20000694,0x20124ee5,0xfbc6009f}},	//   rzic, shii_, siyi_, _रोजम,
   {{0x2a6d0150,0x2bda0096,0x2bcf00bc,0xa3d30eeb}},	//   _ateb_, णाला, _सोहा, _होड_,
   {{0xab5d00a5,0x7c6506fa,0x1ee80018,0xa3d70179}},	//   _ważn, ءالل, _فوجی_, साए_,
   {{0x3ea9211c,0xaaba04c6,0xdcfc02a1,0xbaba0674}},	//   ctat_, تدار_, _kerċ, تداء_,
   {{0x79834ee6,0xab5d00bd,0xdcfe0031,0x00000000}},	//   ganw, _fażo, lapč, --,
   {{0xada31052,0x6da3139c,0x63a42b30,0xdcfc02a1}},	//   _шарл, _шира, _ocin, _merċ,
   {{0xab2a4ee7,0x67fc00fc,0x63a40350,0x7a3f014b}},	//   _доба_, _béja, _ncin, rêta,
   {{0x798300ac,0x9f49026a,0xdb0b4ee8,0x00000000}},	//   banw, rkaç_, tegå, --,
   {{0x44390078,0x67fc4ee9,0x79834eea,0x3e6402c3}},	//   wls_, _déja, canw, _möt_,
   {{0x2fc90185,0xdb0b3696,0x6b800129,0xcd9700ca}},	//   ydag_, regå, _kemg, ודית_,
   {{0x69ca4eeb,0x63a4009c,0x3ea92347,0x61fe05db}},	//   ldfe, _ccin, ytat_, _alpl,
   {{0xf7730054,0x65942135,0x6b80005c,0xaac7000d}},	//   _סקס_, _залу, _memg, लिएक,
   {{0x69c84eec,0x6d5c00bf,0x69ca4eed,0x44cc00b6}},	//   _jade, _ngra, ndfe, _tě_,
   {{0x246501d3,0x2fc91cab,0xa15816a1,0x78670342}},	//   _tēma_, tdag_, дару_, _kıva,
   {{0x76581ee3,0x3ea94eee,0x69da02c9,0x63a44eef}},	//   _hivy, ttat_, _lnte, _gcin,
   {{0x2fc91030,0x69da4ef0,0x63bd0fb0,0x403421be}},	// [4590] rdag_, _onte, mesn, тетс,
   {{0x3ea94ef1,0x69c84ef2,0xa3d3267b,0x629d4ef3}},	//   rtat_, _nade, _होत_, muso,
   {{0x3ea911be,0x629d4ef4,0x69ca00f0,0x26cd015c}},	//   stat_, luso, ddfe, zveo_,
   {{0x69da3916,0x3ea94ef5,0xf41f0084,0x60c54ef6}},	//   _ante, ptat_, nnä_, _ishm,
   {{0x3e644ef7,0x79834ef8,0xa3e41179,0xa9694ef9}},	//   _göt_, tanw, पॉट_, пила_,
   {{0xa2d002d5,0xe29c00a1,0xd945008f,0x6d870018}},	//   दित्, קשור, нели, _زمرہ_,
   {{0x69c84efa,0x28c2143d,0x79834efb,0x5ba7028d}},	//   _dade, _वैदि, ranw, _ораз,
   {{0x63bd0292,0x69c8009c,0x16bc00a5,0x79834efc}},	//   jesn, _eade, ्टूब, sanw,
   {{0x7bdb4efd,0x63bd4efe,0x79830174,0xb21b1410}},	//   _inuu, desn, panw, gsæk,
   {{0x69c84eff,0x629d4f00,0x6b8001d3,0xf41f007b}},	//   _gade, duso, _zemg, enä_,
   {{0x03a611cc,0xc9842ac0,0x4519007b,0x63bd4f01}},	//   нино, _шути, яция_, fesn,
   {{0x9f4b0303,0x69c8174d,0x629d0d5a,0x63bd4f02}},	//   _você_, _zade, fuso, gesn,
   {{0x7658023e,0x69da0178,0xdea90022,0x60c501ee}},	//   _fivy, _ynte, ƙoƙi, _ashm,
   {{0x80cc009d,0xa3e402d5,0xe5a52825,0x5bbc0179}},	//   हिले, पॉज_, _чики, _ईस्व,
   {{0x60264f03,0x63bd077e,0x7e7d02a1,0x3e640212}},	//   едва, besn, _awsp, _söt_,
   {{0x6d5c4f04,0x63a44f05,0x2bcf009d,0x63bd1e4d}},	//   _sgra, _ucin, _सोला, cesn,
   {{0xa3bf0096,0x2d964f06,0x629d1497,0x6b800381}},	// [45a0] ीयर_, ерес, cuso, _remg,
   {{0xee374f07,0xab5d007f,0x7981063d,0x7bdb041c}},	//   ену_, _inży, _nelw, _anuu,
   {{0x6d5c02dd,0x272100de,0x00000000,0x00000000}},	//   _vgra, ỳnh_, --, --,
   {{0x69c84f08,0x7bcf001f,0x79810178,0x7ae201c8}},	//   _sade, _ócul, _aelw, txot,
   {{0x69c84f09,0x79810372,0x7afd0233,0x7e6411bc}},	//   _pade, _belw, _üstl, qqip,
   {{0x6d5c00e9,0xaefb0065,0x09e30879,0x63bd29aa}},	//   _ugra, _afùw, лочн, zesn,
   {{0x69c84f0a,0x9d430dfb,0xf41f00c2,0x69ca1c1d}},	//   _vade, _берд, ynä_, rdfe,
   {{0x3f821197,0x69c84f0b,0x76580239,0x77910103}},	//   _jeku_, _wade, _sivy, لیما,
   {{0x63bd4f0c,0x3a260f1e,0xdb0600c2,0x601b00c2}},	//   vesn, _змаг, ämän, lämä,
   {{0x69da02d6,0x48e61b04,0x3f824f0d,0x25b70094}},	//   _unte, _позв, _leku_, _čelí_,
   {{0x29180006,0x29070067,0x63bd4f0e,0x69dd063c}},	//   _ära_, czna_, tesn, पारी,
   {{0x629d4f0f,0x3f8202e6,0x388c00b6,0x7a36020a}},	//   tuso, _neku_, měr_, râtu,
   {{0x1dd104dd,0x63bd39c4,0x79814f10,0xfbd300ca}},	//   _सफलत, resn, _yelw, אתר_,
   {{0x63bd4f11,0x26c6008c,0x00000000,0x00000000}},	//   sesn, _isoo_, --, --,
   {{0x3f82113a,0x63bd4f12,0xadc30023,0x1dce00aa}},	//   _beku_, pesn, _ngạc, _होइत,
   {{0x653b00a1,0x03320134,0x629d4f13,0xb4be00a8}},	//   _מעוד, ọrọn, puso, ुटी_,
   {{0x6e9400ae,0x644f01c2,0xf458006e,0x00000000}},	// [45b0] литу, mmci, _איהר_, --,
   {{0x4df4004d,0x50f54f14,0xbd680138,0x3f824f15}},	//   ляєт, _азот, ерце_, _eeku_,
   {{0x41de058f,0x3f82007e,0xe1ff0042,0xe29f003e}},	//   मारस, _feku_, spós_, luð_,
   {{0x2cb800a4,0xc61d077d,0xab5d0090,0x00000000}},	//   _dprd_, _पद्य_, _tażm, --,
   {{0x16bc3087,0x69dd000d,0xe29f003e,0x7bcb0212}},	//   ्टोब, पाली, nuð_, rdgu,
   {{0x3f8209ac,0xb7bd020a,0xa3d306ec,0x7a3f014b}},	//   _zeku_, inţe, _होस_, rêto,
   {{0x9f40003e,0x3f8206bd,0x99830138,0x26c6041c}},	//   lkið_, _yeku_, _ųjų_, _asoo_,
   {{0xe8c104a9,0x79814f16,0x29074f17,0xe29f003e}},	//   _शनीच, _welw, rzna_, kuð_,
   {{0x2d834f18,0x6d4800e3,0xa3e500c3,0x4a5500d3}},	//   _keje_, _údar, नान_, _акас,
   {{0x388c030b,0x2d834f19,0xc1cb009d,0x5b140219}},	//   běr_, _jeje_, ायोग, _смут,
   {{0x2d834f1a,0xb7bd020a,0x53dd09a0,0xa5090b21}},	//   _meje_, enţe, यांश, фена_,
   {{0x2d834f1b,0x9f40003e,0xe29f003e,0x00000000}},	//   _leje_, kkið_, fuð_, --,
   {{0x3f823e23,0x7c3a00fd,0x72c301b3,0xa3d70ff9}},	//   _reku_, _être, абяз, साज_,
   {{0xb8230081,0x1a9a006e,0xdcfc0154,0x00000000}},	//   _পঠিত_, וישע, _serč, --,
   {{0xb7bd00ae,0xdcfc4f1c,0x32010206,0x505a022a}},	//   anţe, _perč, _dlhy_, дшая_,
   {{0x2b5f0023,0x601b00c2,0x00000000,0x00000000}},	//   _nguc_, vämä, --, --,
   {{0x2d834f1d,0x3f824f1e,0x1f630cc0,0xdcfc00c6}},	// [45c0] _beje_, _veku_, ркум, _verč,
   {{0x601b02fd,0x25f70789,0x9c130174,0x00000000}},	//   tämä, एसटी_, _sọpl, --,
   {{0x3f824f1f,0x2d834f20,0xd00a231c,0xdcfc0094}},	//   _teku_, _deje_, _жене_, _terč,
   {{0xa3e509a1,0x67fc00fd,0x645e0036,0x388c02c6}},	//   नाय_, _réjo, _èpie, věr_,
   {{0x67fc025a,0xe7e50e50,0x44220018,0x09e604a1}},	//   _séjo, काना_, ink_, кодн,
   {{0xc333028c,0x67f50018,0x5a33004d,0x61fc037a}},	//   בוד_, _máju, аніт, nkrl,
   {{0xfce30978,0x3ea04f21,0xa3e51244,0x28c20096}},	//   _коро, luit_, नाम_, _वैशि,
   {{0x8c460084,0x2fc04f22,0x1de01101,0x321800d8}},	//   _ребе, neig_, नावत, hiry_,
   {{0x3ea04f23,0x96341121,0xa3dc00a3,0x28c20179}},	//   nuit_, лниц, ठाई_, _वैरि,
   {{0x25a7374b,0x7c220c86,0x44224f24,0x00000000}},	//   _ccnl_, lnor, enk_, --,
   {{0xa5c60139,0x2a64023b,0xddcd020a,0x15143ac9}},	//   _abóò, _humb_, lpaţ, удня,
   {{0x7c224f25,0xd7ef00e3,0x26c6006c,0xe29f003e}},	//   nnor, _وكل_, _tsoo_, tuð_,
   {{0x51874f26,0x569442f4,0x26c6008a,0xa2d01073}},	//   кува, _салт, _usoo_, दिष्,
   {{0x3ea004ea,0x7c2202e2,0xe4d40867,0x63b60172}},	//   duit_, hnor, _مقتد, _ebyn,
   {{0x925801b6,0x225800c2,0xc05b004d,0xd7f8020a}},	//   тарт_, тиры_, діа_, _luăm_,
   {{0x23aa009d,0x28d3045f,0x2d834f27,0x7c224f28}},	//   _कायद, थिति, _seje_, jnor,
   {{0x3ea04f29,0x7c2206e9,0xc058004d,0x74d00285}},	// [45d0] guit_, dnor, тір_, धिवृ,
   {{0x9f40003e,0x7c220150,0x63b600d2,0x00000000}},	//   rkið_, enor, _zbyn, --,
   {{0x23aa000d,0x2d834f2a,0xe7e50966,0x833431bb}},	//   _कामद, _veje_, कामा_, _مریض,
   {{0x7c224f2b,0x3ea04f2c,0x200c05fe,0xab5d003d}},	//   gnor, buit_, èdit_, _każi,
   {{0xee840ff8,0x3ea000ae,0x2d83023b,0x600300aa}},	//   _высо, cuit_, _teje_, _tõmb,
   {{0x27ef00d6,0x752a020b,0x2a644f2d,0x00000000}},	//   _sogn_, _oxfz, _dumb_, --,
   {{0x89d60037,0x20020483,0x628001f9,0x7c224f2e}},	//   طوير_, _ylki_, ámoz, bnor,
   {{0x06c900ae,0xc30a0033,0x4422037a,0xf7710037}},	//   егий_, রপতি_, xnk_, حاث_,
   {{0x2a644f2f,0x27ef01df,0x48df00b6,0x00000000}},	//   _gumb_, _vogn_, _कपको_, --,
   {{0xa5c50139,0xab5d00bd,0x67f501f9,0x00000000}},	//   _gbọ́, _nażi, _ráju, --,
   {{0x3ea04f30,0x00000000,0x00000000,0x00000000}},	//   zuit_, --, --, --,
   {{0xe29a4f31,0x4c9a0341,0x657a4f32,0x67240146}},	//   нам_, עברו, abth, _žije,
   {{0xab5d003d,0x00000000,0x00000000,0x00000000}},	//   _bażi, --, --, --,
   {{0xfb160130,0x64a52f0c,0x471a00c1,0x05290ff5}},	//   אַלט_, _бака, _אונג, _полк_,
   {{0x2fc04f33,0x44220063,0x7c224f34,0x00000000}},	//   teig_, pnk_, ynor, --,
   {{0x3ea04f35,0xe3b20037,0xd9c03856,0x854400ae}},	//   tuit_, _طرب_, _एस्ट, _тэче,
   {{0xdee32249,0x2fc04f36,0xab5d00bd,0x5faa02c6}},	// [45e0] боти, reig_, _fażi, ङ्गल,
   {{0x3ea04f37,0x645e0428,0xfce60859,0x2a64015e}},	//   ruit_, _èpic, лозо, _rumb_,
   {{0x3ea04f38,0x2a64061d,0x7c224f39,0xab5d009e}},	//   suit_, _sumb_, tnor, _każw,
   {{0x9e6600e3,0xa3da00df,0xab8300c2,0xdde300e8}},	//   _ماسن, _डोम_, бушк, āršo,
   {{0xa3e54f3a,0x7c224f3b,0x3ea03d56,0x6d4701c8}},	//   नात_, rnor, quit_, _ezja,
   {{0xddcd044c,0xdd9201c3,0xe9180138,0x00000000}},	//   rpaţ, _دوس_, колі_, --,
   {{0x67f50220,0xb21b4f3c,0x6e2b0103,0x00000000}},	//   _nájs, msæt, égbe, --,
   {{0xa3d3000f,0xb21b052f,0x57a61f47,0xddcd0357}},	//   _हों_, lsæt, ушка, mpaš,
   {{0xeb972887,0x7bc234d2,0x00000000,0x00000000}},	//   _щит_, meou, --, --,
   {{0xb21b02b6,0x00000000,0x00000000,0x00000000}},	//   nsæt, --, --, --,
   {{0xd5b70ae3,0xddcd00e7,0xce3700ca,0x00000000}},	//   усы_, npaš, ראית_, --,
   {{0x7bc200ca,0x24194f3d,0x00000000,0x00000000}},	//   neou, томы_, --, --,
   {{0xa3d61362,0xb21b052f,0xa8370266,0x6fa300c3}},	//   _सफर_, ksæt, _גראד_, गलसू,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb21b052f,0x2f720134,0xe4500421,0x661a4f3e}},	//   dsæt, _ọtọm, تضی_, mitk,
   {{0xd90400fb,0xa2c5045f,0x12e70120,0xddcf078e}},	//   _ہی_, िबद्, _біог, _bucş,
   {{0xdd9b1510,0x44290af0,0x7bc24f3f,0x8e154f40}},	// [45f0] еше_, _ija_, deou, адац,
   {{0x273300ef,0x628f045d,0x27210028,0xd90409e5}},	//   ợng_, msco, ẳng_, _فی_,
   {{0x628f00e3,0x644d4f41,0x2720417a,0x645f0257}},	//   lsco, _khai, मपुर_, _épis,
   {{0x907a0341,0x442906b0,0x3d190096,0x7762063d}},	//   _שטרי, _jja_, _येणे_, _ngox,
   {{0x644d006b,0x661a005a,0x628f4f42,0x44292659}},	//   _mhai, kitk, nsco, _mja_,
   {{0x3d1902e8,0x628f4f43,0xe9d8013f,0x661a0167}},	//   _येथे_, isco, лкі_, jitk,
   {{0x44294f44,0xa3d61344,0x661a4f45,0x628f0503}},	//   _oja_, _सफल_, ditk, hsco,
   {{0x44294f46,0x7bc24f47,0x66030220,0xe739313c}},	//   _nja_, ceou, _slnk, кей_,
   {{0x0ab8037f,0x3d19009d,0x628f00a5,0x6b8b4f48}},	//   _مطلب_, _येते_, jsco, magg,
   {{0x44294f49,0x7c291484,0x0f580341,0x644d4f4a}},	//   _aja_, _hjer, ניזם_, _ahai,
   {{0x644d0fab,0xe00506ae,0x628f3890,0x7c294f4b}},	//   _bhai, रसाद_, esco, _kjer,
   {{0x69c34f4c,0x6b8b4f4d,0x644d4f4e,0x7c290172}},	//   lene, nagg, _chai, _jjer,
   {{0x7c294f4f,0x644d4f50,0x7c3b0010,0x20092f9c}},	//   _mjer, _dhai, _mkur, dhai_,
   {{0x412a3e04,0x44294f51,0x69c34f52,0x27ff4f53}},	//   вого_, _eja_, nene, lkun_,
   {{0x644d0a21,0x78a300a7,0x7c29034f,0x7c3b4f54}},	//   _fhai, nunv, _ojer, _okur,
   {{0x7c294f55,0x69c34f56,0x644d4f57,0x27ed4f58}},	//   _njer, hene, _ghai, njen_,
   {{0x69c34f59,0x0d864717,0x2bbb045f,0xfbbb055c}},	// [4600] kene, илан, ोजना, ोजनम,
   {{0x7c3b4f5a,0xdbdf04c8,0x7c294f5b,0x27ed023b}},	//   _akur, _síðs, _ajer, hjen_,
   {{0xb21b4f5c,0x7c294f5d,0x27ed00dd,0x27ff4f5e}},	//   rsæt, _bjer, kjen_, kkun_,
   {{0x6b8b4f5f,0x661a0a74,0x27ff0307,0x27ed0078}},	//   gagg, zitk, jkun_, jjen_,
   {{0x69c34f60,0x27ed4f61,0x7c294f62,0x661a0085}},	//   fene, djen_, _djer, yitk,
   {{0x20000694,0x7c3b4f63,0xa3d305a7,0x7bc24f64}},	//   lkii_, _ekur, _होई_, seou,
   {{0xf80621fd,0x7c290939,0x6b8b083e,0x082a1e13}},	//   ичин, _fjer, bagg, кции_,
   {{0x20000694,0x7c294f65,0x27ed023b,0x3c3c0031}},	//   nkii_, _gjer, gjen_, tívu_,
   {{0x644d02e0,0x44290141,0x66d20233,0xdcfc078e}},	//   _rhai, _rja_, dıkç, _feră,
   {{0x644d4f66,0xe839030b,0xceb300a1,0x645f019f}},	//   _shai, ější, קית_, _siqi,
   {{0x2dd907a6,0x644d4f67,0x661a4f68,0x442900e7}},	//   אַרב, _phai, ritk, _pja_,
   {{0x20094f69,0xb4c6000d,0x661a4f6a,0x79884f6b}},	//   xhai_, _उनी_, sitk, _hedw,
   {{0x20000694,0x661a4f6c,0x628f0451,0x629d4f6d}},	//   dkii_, pitk, usco, urso,
   {{0xa3e50251,0x628f3d8c,0x36334f6e,0x3e7d0065}},	//   नाह_, rsco, _وروس, _látò_,
   {{0x644d4f6f,0x0494054f,0x20094f70,0x463900c1}},	//   _thai, _البح, thai_, _געװע,
   {{0x6f0d0990,0x69c34f71,0xa3bb0391,0x14730018}},	//   tzac, zene, _شاعر_, _باوج,
   {{0x60d301b3,0x63ad4f72,0x6b8b18ba,0x69c34f73}},	// [4610] _žemė, _ican, vagg, yene,
   {{0xa3e50abe,0x20090197,0x69c34f74,0x2d873916}},	//   नाव_, shai_, xene, úne_,
   {{0x6b8b4f75,0x2000008a,0x201e0428,0xd0100018}},	//   tagg, bkii_, ètic_, سلے_,
   {{0x44394f76,0x69c34f77,0xe29f01ab,0x201b00a7}},	//   nos_, wene, orð_, qiqi_,
   {{0x7c29029b,0x443948f0,0x6b8b4f78,0x63ad034f}},	//   _vjer, ios_, ragg, _mcan,
   {{0x44394f79,0x89a802ec,0x6b8b4f7a,0xf99100e3}},	//   hos_, иків_, sagg, سبت_,
   {{0x44394f7b,0x7c29074a,0x69c34f7c,0xdb0b4f7d}},	//   kos_, _tjer, rene, tegó,
   {{0x44394f7e,0x7c3b4f7f,0x7c291b24,0x6ebb000d}},	//   jos_, _ukur, _ujer, _उहाँ,
   {{0xa9c70465,0x27ed2f95,0x69c34f80,0x27ff4f81}},	//   _всек, rjen_, pene, rkun_,
   {{0x27ed10b2,0x79881be6,0x27ff4f82,0x44392bb5}},	//   sjen_, _gedw, skun_, eos_,
   {{0x44394f83,0x6b89007a,0x27ed4f84,0xddc60138}},	//   fos_, _keeg, pjen_, _sukū,
   {{0x27ed023b,0x63ad00da,0xa6c913c3,0x00000000}},	//   qjen_, _ccan, _موصل_, --,
   {{0x6b8903ee,0x1dc71d7d,0x63ad009c,0x853c00c6}},	//   _meeg, रजात, _dcan, ngėj,
   {{0x63ad0372,0x3dd1007f,0xf6760142,0x00000000}},	//   _ecan, _nazw_, _הײסט_, --,
   {{0x44394f85,0x20004f86,0x00000000,0x00000000}},	//   bos_, tkii_, --, --,
   {{0x4439132d,0x6b894f87,0x6e3c4f88,0xb4fa00a1}},	//   cos_, _neeg, _skrb, _תפקי,
   {{0x2000025e,0x7c39030a,0x62920031,0xdee3180b}},	// [4620] rkii_, dowr, ýkoľ, поти,
   {{0xbd8a00cd,0xe05800cd,0x20000188,0x3eb21175}},	//   انان_, _چیست_, skii_, rtyt_,
   {{0xf8a54f89,0xe05800bf,0x6b893329,0x59ae0096}},	//   _تک_, _نیست_, _beeg, _घाबर,
   {{0x44d7002d,0xab83002d,0x798805aa,0x6b89026d}},	//   _mă_, пушк, _sedw, _ceeg,
   {{0x6b890694,0xa91c0038,0x798800f0,0x3f804f8a}},	//   _deeg, _veľm, _pedw, mbiu_,
   {{0x44394f8b,0xa2d9147f,0xfce64f8c,0x3ea0023b}},	//   zos_, मित्, _лого, mrit_,
   {{0x44394f8d,0xdca32976,0x6b89409f,0x6d580031}},	//   yos_, _нари, _feeg, ývad,
   {{0x44392b2a,0xc7c612d6,0xe69813c0,0x6b890172}},	//   xos_, сски, авиш_, _geeg,
   {{0x2d8a0d2a,0xf76f0604,0xceb400a7,0xa3ac0751}},	//   _kebe_, راي_, ntə_, खलन_,
   {{0x63ad4f8e,0x44390027,0x6b894f8f,0x44d7044c}},	//   _scan, wos_, _zeeg, _bă_,
   {{0x443922d3,0x44d70a29,0x2d8a0294,0xd7ef07c7}},	//   tos_, _că_, _mebe_, _еу_,
   {{0xceb40092,0x44d700d3,0x2d8a042c,0xccf300ca}},	//   ktə_, _dă_, _lebe_, לכת_,
   {{0xe7e50c22,0xb3aa0e19,0xa2d02ebd,0x41e702b7}},	//   कारा_, _कारख, दिग्, біва,
   {{0x2d9c001f,0xdb0f00fd,0x3ea04f90,0x44d700ae}},	//   óvel_, édér, drit_, _fă_,
   {{0xa1594f91,0x60250138,0x61fa0212,0x3ea04e44}},	//   раву_, lėmi, ötla, erit_,
   {{0xceb40092,0x3ea04f92,0xf1ad02c6,0x25bc01cb}},	//   ftə_, frit_, ञ्जन, _hbvl_,
   {{0x6025013f,0x6b89007a,0xf41f00c2,0xbe19004d}},	// [4630] nėmi, _reeg, miä_, ажає_,
   {{0x6b894f93,0xf41f0084,0xafdb4f94,0x5d670a54}},	//   _seeg, liä_, _skød, стаз,
   {{0x2d8a4f95,0x3ea0023b,0x61e50060,0x6b8900aa}},	//   _debe_, arit_, _inhl, _peeg,
   {{0x3ea04f96,0xf41f0084,0xab94004d,0x2d8a008c}},	//   brit_, niä_, зиці, _eebe_,
   {{0x3ea033dd,0xdefb055b,0x78670103,0x6b894f97}},	//   crit_, _сын_, _műve, _veeg,
   {{0x6b894f98,0x600a0181,0x2d8a0684,0xf41f00c2}},	//   _weeg, _výme, _gebe_, hiä_,
   {{0x2bd4007d,0xe7e5110f,0xf41f0084,0x9f420154}},	//   _ठोका, काला_, kiä_, _ankè_,
   {{0xdd0e03a3,0x2d810013,0xf41f00c2,0x96951f3e}},	//   lışa, lbhe_, jiä_, орош,
   {{0x44d70a29,0x600300aa,0x3f8b0e94,0x2d9802b6}},	//   _să_, _nõmm, _mecu_, _ydre_,
   {{0xdd0e0491,0x06930018,0x5bc9030b,0x00000000}},	//   nışa, _ہاتھ, _रसुव, --,
   {{0x25dd009d,0xa3e54f99,0xd7c800cd,0xa3ea2ca3}},	//   _कोणी_, नां_, _گونه_, адна_,
   {{0x44d7002d,0x3f8b04a3,0x602500c6,0x61e54af4}},	//   _vă_, _necu_, bėmi, _anhl,
   {{0x26c900d1,0x672d05db,0x00000000,0x00000000}},	//   _خطای_, _žajf, --, --,
   {{0xa3da0251,0xc8ad0ee0,0x3ea04f9a,0x7af600f3}},	//   _डोर_, _टमाट, vrit_, øyti,
   {{0x3f8b0e94,0xdb2001f9,0x00000000,0x00000000}},	//   _becu_, _ötöd, --, --,
   {{0x1dac0067,0x3ea04f9b,0xa3e516e2,0x3f8b049c}},	//   _चाहत, trit_, नाः_, _cecu_,
   {{0x3f8b4f9c,0x3ea0057a,0xda090096,0xd00702b3}},	// [4640] _decu_, urit_, वसात_, цете_,
   {{0x3ea04f9d,0x62960169,0x00000000,0x00000000}},	//   rrit_, _ivyo, --, --,
   {{0xa91c0038,0x246501d3,0x7413001c,0xceb400a7}},	//   _veľk, _tēmu_, _رویا, stə_,
   {{0xdee61839,0x3ea04f9e,0x2d8a0220,0x26dd0172}},	//   _доми, prit_, _webe_, _orwo_,
   {{0x2d8a08a9,0x61f700a7,0xb4c6007f,0xf41300ca}},	//   _tebe_, _yoxl, _उन्_, ופא_,
   {{0xdd9209e5,0xddd501d3,0x602500c6,0x2023007f}},	//   _زور_, _aizņ, vėmi, ąpił_,
   {{0x9d430e1d,0x23aa009d,0xf1b200a5,0x8b960d86}},	//   _жерд, _कांद, _जानन, _мрач,
   {{0x3b8612e7,0x602500c6,0x62960350,0x00000000}},	//   _флаг, tėmi, _ovyo, --,
   {{0xc6f71736,0x6b821e59,0xf41f0084,0x3b07008f}},	//   жных_, mbog, viä_, _дето_,
   {{0xa2d90789,0x602500c6,0x00000000,0x00000000}},	//   मिस्, rėmi, --, --,
   {{0xf41f0084,0x64740426,0x629602f1,0xc8ca2519}},	//   tiä_, ягну, _avyo, _خوان_,
   {{0x9f49003e,0x6b824f9f,0xa3e52337,0x387101dc}},	//   kkað_, nbog, नाइ_, _ézra_,
   {{0x934700e3,0xf41f00c2,0xe51a030b,0x27e64fa0}},	//   تخدم, riä_, _फेरि_, _inon_,
   {{0xf41f02fd,0x720500e3,0x64460188,0x41e407bf}},	//   siä_, أوسم, alki, міса,
   {{0xf41f00c2,0x386c0094,0x6aa24fa1,0x00000000}},	//   piä_, _judr_, hrof, --,
   {{0x7a3f0257,0x53352f68,0x386c0146,0x600300aa}},	//   nêtr, _нейт, _mudr_, _tõmm,
   {{0x85560de1,0x656d07aa,0x799a0034,0xfe700d59}},	// [4650] _دیگر_, _şahi, _odtw, ندل_,
   {{0x41b2009f,0x00000000,0x00000000,0x00000000}},	//   _जायस, --, --, --,
   {{0x2d8103dc,0x27e60ea4,0xdd0e020e,0xd7bc00a4}},	//   rbhe_, _onon_, rışa, ्जाच,
   {{0x6b820d79,0x64580428,0xf8e400c3,0xa92302c6}},	//   gbog, _èxit, _कपड़ा_, ůžko,
   {{0x7f760105,0x442b4fa2,0xde46001c,0x6d4e4fa3}},	//   _מערב_, inc_, _کیلو_, _ezba,
   {{0x3ea929dd,0x6d580146,0x24520146,0x28b900e3}},	//   muat_, ývac, máme_, مطبخ_,
   {{0x3ea94fa4,0x47d40081,0xc7b90018,0x64464fa5}},	//   luat_, থানী, tfő_, ylki,
   {{0x95f52231,0x6aa20178,0xbcb400d4,0xdb0b02c3}},	//   ेस्ट_, brof, žším, degö,
   {{0xb4e30285,0xe61927a5,0x6b9b019c,0x3ea94363}},	//   नम्_, йди_, _idug, nuat_,
   {{0x97320e27,0x442b00ee,0x386c030a,0x00000000}},	//   رکنا, enc_, _fudr_, --,
   {{0x04460f1e,0x24520146,0x0ee80034,0x00000000}},	//   зенн, háme_, _ऐप्स_, --,
   {{0x3ea94fa6,0x389700d3,0x24520094,0x7a3f020d}},	//   kuat_, măr_, káme_, cêtr,
   {{0xe72e4fa7,0x66e52b49,0x26dd0193,0x1dac009d}},	//   _че_, _хола, _urwo_, _चालत,
   {{0x2452025b,0xbb3a00c1,0x3ea94fa8,0xdcee0138}},	//   dáme_, מערי, duat_, _gebė,
   {{0x389700ae,0x25e80b76,0xa7fc0233,0x753c042c}},	//   năr_, जारी_, _atıy, ürzt,
   {{0x6b9b2f79,0x6aa24fa9,0x2fc90313,0x3ea90a4b}},	//   _ndug, yrof, geag_, fuat_,
   {{0xdfcf0037,0xe7ec00aa,0x3897020a,0x00000000}},	// [4660] ديق_, झाता_, hăr_, --,
   {{0x273a0019,0x6b9b0032,0x9f49003e,0x7bde01d3}},	//   ừng_, _adug, rkað_, ēpum,
   {{0x50464faa,0xdbdf0139,0x2fc901ec,0x00000000}},	//   _необ, _kíès, beag_, --,
   {{0x3ea906ee,0x6aa24fab,0x5bb8004d,0xa3e5039d}},	//   buat_, trof, ілля_, नाए_,
   {{0x6b824fac,0x3f920967,0x3ea94fad,0x6b9b03a8}},	//   rbog, mayu_, cuat_, _ddug,
   {{0x3f9229cb,0x44224fae,0xceb3028c,0x6b9b4faf}},	//   layu_, hik_, _איש_, _edug,
   {{0xa3ac4694,0xa3cc00a3,0xa3be09d0,0x44224fb0}},	//   खला_, रजा_, ीजा_, kik_,
   {{0x6aa24fb1,0x44224fb2,0xaca40174,0xe7df00a3}},	//   prof, jik_, _chụp, _खोदा_,
   {{0x44224fb3,0xfaa34fb4,0x442b0124,0x25dd00b6}},	//   dik_, _пато, vnc_, _कोही_,
   {{0x3f920498,0x4498004d,0x2a6501b9,0x6e3e4fb5}},	//   hayu_, овою_, _gilb_, nopb,
   {{0x44224fb6,0x26d902c3,0x69ca4fb7,0x00000000}},	//   fik_, åsor_, mefe, --,
   {{0x44224fb8,0x27e60124,0xb7bd020a,0xe3bf01ff}},	//   gik_, _unon_, tiţe, kiñe_,
   {{0x3f920449,0x69ca000b,0x442b00d8,0xa3be007f}},	//   dayu_, oefe, rnc_, ीज़_,
   {{0x69d84fb9,0x2452030b,0x69ca4fba,0x442b0036}},	//   ndve, váme_, nefe, snc_,
   {{0x7c2b0150,0x7c222c6f,0x00000000,0x00000000}},	//   yngr, kior, --, --,
   {{0x44224fbb,0x3ea9396a,0x69ca4fbc,0x24521054}},	//   cik_, tuat_, hefe, táme_,
   {{0xdb1b0088,0x2fc90527,0x386600dc,0x69ca4fbd}},	// [4670] _nauð, reag_, _mior_, kefe,
   {{0xa3e50d39,0x24520146,0xdb0700fd,0x7bc0010a}},	//   नाक_, ráme_, _élég, _abmu,
   {{0x69ca4fbe,0x7c224fbf,0x7ae04fc0,0x62400696}},	//   defe, fior, _armt, möop,
   {{0x7c220465,0x389700ae,0x69d81030,0x00000000}},	//   gior, văr_, edve, --,
   {{0x3ea905fe,0xf42a0084,0xa3d50f53,0x69ca0234}},	//   quat_, ltää_, _सघन_, fefe,
   {{0x44224fc1,0x69ca4fc2,0xdb1b003e,0xd94544c5}},	//   zik_, gefe, _dauð, мели,
   {{0x44224fc3,0xf9901857,0xf42a0084,0x7c2200a5}},	//   yik_, ابه_, ntää_, bior,
   {{0x7c224fc4,0x2d934fc5,0x63bd01c0,0x44224fc6}},	//   cior, laxe_, jfsn, xik_,
   {{0x44224fc7,0x7bcb4fc8,0x69ca4fc9,0xf42a007b}},	//   vik_, megu, befe, htää_,
   {{0x49bb00bf,0x7bcb4fca,0x2d9308a8,0xb7bd00ae}},	//   _دارد_, legu, naxe_, inţi,
   {{0x69c14fcb,0x38660441,0xd5b801d3,0x00000000}},	//   _ible, _fior_, enās_, --,
   {{0x7bcb4fcc,0xe82500cd,0x25dd02d5,0xc20900ca}},	//   negu, _غذای, _कोरी_, _דה_,
   {{0x44220634,0x248002e6,0x15f50037,0x00000000}},	//   rik_, _čime_, _يستح, --,
   {{0x44224fcd,0x7c224fce,0xa06a123a,0x7bcb4fcf}},	//   sik_, zior, жава_, hegu,
   {{0x44224b6a,0x69c14fd0,0x7e7d22bb,0x614322e4}},	//   pik_, _mble, _atsp, вера,
   {{0xdee60b40,0x7bcb4fd1,0xdb0900ee,0x7c224fd2}},	//   моби, jegu, _oceà, xior,
   {{0x44204fd3,0x69c14fd4,0x69ca4fd5,0x7bcb4fd6}},	// [4680] _imi_, _oble, yefe, degu,
   {{0x44204fd7,0x69bf1bc3,0xdb1b0088,0x9f59028d}},	//   _hmi_, ल्मी, _rauð, _mosè_,
   {{0x44200270,0xdd8f1f11,0x76430167,0x69ca00f2}},	//   _kmi_, شون_, _mkny, vefe,
   {{0xf76716cc,0x7bcb4fd8,0x69c14fd9,0x7d0313b9}},	//   _لا_, gegu, _able, ønsa,
   {{0x7c224fda,0x44204fdb,0x6d47003e,0x69ca4021}},	//   rior, _mmi_, _eyja, tefe,
   {{0x7c224fdc,0xe6070421,0x38660cc2,0x00000000}},	//   sior, _شش_, _sior_, --,
   {{0x44200d79,0x69ca4fdd,0x3866001f,0x69d84fde}},	//   _omi_, refe, _pior_, rdve,
   {{0x69c10113,0x44200032,0xc6f84064,0x23aa0096}},	//   _eble, _nmi_, зних_, _कागद,
   {{0x7c2001b9,0x6f0405bd,0x00000000,0x00000000}},	//   _immr, nyic, --, --,
   {{0x44204fdf,0xf42a00c2,0x64444fe0,0x44f40915}},	//   _ami_, ytää_, _akii, епос,
   {{0xf4be00c7,0xd5e20065,0x3dd800f0,0x49060037}},	//   েম্ব, _awọ, _marw_, _تواق,
   {{0x2d9308a8,0x69c105db,0x00000000,0x00000000}},	//   zaxe_, _zble, --, --,
   {{0x27f7025b,0x44204fe1,0x236d0087,0x63b40094}},	//   žená_, _dmi_, žejo_, _žená,
   {{0x44204fe2,0xf42a02fd,0x34944fe3,0x69c10063}},	//   _emi_, ttää_, _закр, _xble,
   {{0x44200ca3,0x7e6701c0,0x7bcb04ff,0x00000000}},	//   _fmi_, _rijp, yegu, --,
   {{0x26c60294,0xf42a00c2,0x44de003d,0x44200664}},	//   _kpoo_, rtää_, _iċ_, _gmi_,
   {{0x7bcb4fe4,0xf42a0084,0x2d934fe5,0x7e670126}},	// [4690] vegu, stää_, taxe_, _pijp,
   {{0x7bcb4fe6,0x6d474fe7,0xdd9123bb,0x628d0350}},	//   wegu, _pyja, اوا_, _iwao,
   {{0x7bcb4fe8,0x2d930960,0x997302c6,0x3dd803a8}},	//   tegu, raxe_, těži_, _darw_,
   {{0x2d9308a8,0x6d47035d,0x628d0350,0x7e7d02c3}},	//   saxe_, _vyja, _kwao, _ttsp,
   {{0x82340979,0x6f1600a5,0x26c6022e,0x6d4700a5}},	//   _سریا, czyc, _npoo_, _wyja,
   {{0x7bcb4fe9,0x9f5900b3,0x628d024a,0x80a600b6}},	//   segu, _nosé_, _mwao, _छिमे,
   {{0xa9664fea,0x00000000,0x00000000,0x00000000}},	//   ниша_, --, --, --,
   {{0x200901b3,0x76430270,0x2d910062,0x23c111c7}},	//   nkai_, _skny, _heze_, ष्मद,
   {{0x5a35248d,0x9f59037a,0x200900c6,0x2fd903a8}},	//   _знат, _bosé_, ikai_, _masg_,
   {{0x69c14feb,0xe61600c2,0x20090167,0x645602a4}},	//   _uble, едь_, hkai_, _shyi,
   {{0x2d914fec,0x656d0e63,0x387e05ff,0x628d0a4b}},	//   _meze_, _şahs, _gttr_, _awao,
   {{0xafdb01c5,0x99870138,0x246c02c6,0x44204fed}},	//   _skøn, ponų_, _němu_, _qmi_,
   {{0xe2974fee,0xb3b13ad1,0xddc64fef,0x8c1a00d7}},	//   ная_, _झारख, _lukš, פושי,
   {{0xd2520dd0,0x645d4ff0,0x20cb4ff1,0x2fd903a8}},	//   انس_, amsi, ाबंध, _aasg_,
   {{0x76410103,0x2fd900eb,0x7e6003a9,0x6ac80033}},	//   moly, _basg_, _èmpi, লিযো,
   {{0x44204ff2,0xdb1b002b,0x2fd901f7,0x76410212}},	//   _umi_, _abuí, _casg_, loly,
   {{0xddc601b3,0x2a7f022e,0xdcf40995,0xbea33e0c}},	// [46a0] _aukš, _ntub_, đačk, латк,
   {{0x8c9600f3,0x9f5908a8,0x6e460dd0,0x201202a4}},	//   ерді, _xosé_, رنام, shyi_,
   {{0x2d914ff3,0x6f160067,0xe3bf03be,0xb0af0ed3}},	//   _deze_, szyc, liña_, जूदग,
   {{0xe7df07e2,0x6011004d,0xe7ae14e5,0x2d9102ac}},	//   _खोला_, _påme, _टाइप, _eeze_,
   {{0xd12f00bf,0x76414ff4,0xe3bf0042,0x00000000}},	//   _نمی_, koly, niña_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x76410178,0xe7ec00bc,0x245201f9,0x00000000}},	//   doly, झाला_, záma_, --,
   {{0xd6d000e3,0x2d914ff5,0x7d120233,0xe3bf0062}},	//   لقب_, _zeze_, ıksı, kiña_,
   {{0x27fd4ff6,0x76410018,0x87e30084,0x9f5906aa}},	//   _down_, foly, ующе, _posé_,
   {{0x76414ff7,0xb9060081,0xe3bf0042,0x61fe00e8}},	//   goly, _পথ_, diña_, _nopl,
   {{0xd82f147c,0x545510b8,0xab5d0090,0x3e7601cd}},	//   _бэ_, квот, _ibża, _læt_,
   {{0x38ba00dd,0x69da4ff8,0x89370327,0x00000000}},	//   mër_, _hate, _ארבע_, --,
   {{0x8c1b0327,0x61fe2c28,0xe3bf0062,0x25ab00d2}},	//   לוטי, _bopl, giña_, áhlé_,
   {{0x69da4ff9,0x24524ffa,0x61fe3261,0x9268037e}},	//   _jate, ráma_, _copl, ерса_,
   {{0x61fe0897,0x2fc04ffb,0xc0c817a6,0x27fd00f9}},	//   _dopl, ffig_, нуте_, _yown_,
   {{0x69da4ffc,0x20090138,0x80c20179,0xe3bf002b}},	//   _late, ukai_, _लहरे, biña_,
   {{0xe3bf08a8,0x40340084,0xfe731d28,0x23c1074c}},	// [46b0] ciña_, уетс, ادر_, ष्णद,
   {{0xe45f0222,0x20092224,0x2fd90150,0x38ba0052}},	//   lmö_, skai_, _wasg_, kër_,
   {{0x2d9102e6,0x2a7f2d0b,0xaefb0065,0x463b00c1}},	//   _veze_, _stub_, _agùt, לעמע,
   {{0x38ba023b,0x2d21009d,0xddc60234,0x69da4ffd}},	//   dër_, _मधील_, _vukš, _aate,
   {{0x69da4ffe,0x3f890f22,0x38ba057a,0xa3b934fd}},	//   _bate, mbau_, eër_, _चान_,
   {{0x69da1647,0x3ea94fff,0x38ba0052,0xddc601d3}},	//   _cate, mrat_, fër_, _tukš,
   {{0x6b750cd7,0x69da5000,0x27fd00dc,0x76415001}},	//   _албу, _date, _pown_, voly,
   {{0xf0940089,0x3f8901bf,0x3ea90428,0x6d555002}},	//   אנק_, nbau_, orat_, _izza,
   {{0x69da5003,0xe3bf0042,0x3ea95004,0x00000000}},	//   _fate, xiña_, nrat_, --,
   {{0x38ba023b,0xe3bf03be,0xfbd00018,0x69da5005}},	//   bër_, viña_, _پتہ_, _gate,
   {{0x76415006,0x7bdb0270,0x38ba0052,0xa80203e0}},	//   roly, _kauu, cër_, ğırm,
   {{0x3ea95007,0xe29a5008,0x61fe5009,0x7bdb0085}},	//   krat_, мам_, _sopl, _jauu,
   {{0x69da2ea9,0x7bdb0bb6,0xe7844a6f,0x2907245e}},	//   _yate, _mauu, _сухо, lyna_,
   {{0xe3bf08a8,0x6d55500a,0xb21b02b6,0x7bdb0231}},	//   riña_, _ozza, spæn, _lauu,
   {{0x3e7634da,0x3ea9500b,0x3f8901bf,0x27f40018}},	//   _sæt_, erat_, fbau_, _شہید_,
   {{0xa3b9000f,0x3f89500c,0x7bdb00a6,0x3ea9500d}},	//   _चाय_, gbau_, _nauu, frat_,
   {{0x61fe500e,0x1f660f80,0x3ea9500f,0x6d555010}},	// [46c0] _topl, ткам, grat_, _azza,
   {{0xee375011,0x9f590103,0x6286084e,0x600a00d8}},	//   вну_, _alsó_, mpko, _kýmk,
   {{0x3ea95012,0x69da5013,0xa3b90442,0x3f89042c}},	//   arat_, _rate, _चाम_, bbau_,
   {{0xdca35014,0x3ea95015,0x3e7601c5,0x69da5016}},	//   раци, brat_, _tæt_, _sate,
   {{0x69da5017,0x3ea95018,0x6d55083e,0xdbde0032}},	//   _pate, crat_, _ezza, _bíòb,
   {{0x38ba01e5,0x1dac02d5,0x19580b2f,0x69da5019}},	//   tër_, _चाटत, налы_, _qate,
   {{0xc2130054,0x69da501a,0x7bdb009c,0xed3500ae}},	//   שהו_, _vate, _fauu, _бэтэ,
   {{0xc7c60b2c,0x69da501b,0xf09300a1,0x7d030149}},	//   тски, _wate, בנה_, änse,
   {{0x69da501c,0x38ba023b,0x15aa008f,0xa37b0131}},	//   _tate, sër_, мъни_, ndõe,
   {{0x38ba01e5,0x7bc2501d,0x35f41942,0x00000000}},	//   për_, lfou, упор, --,
   {{0x2618000c,0xa8a51dec,0x4395232c,0x7ae2501e}},	//   योगी_, _مصنو, ланс, lvot,
   {{0xd9f0007d,0x657a0037,0x3c3c0031,0x2a6c01f7}},	//   चावत_, scth, tívy_, _hidb_,
   {{0x9f590465,0x6d580146,0x25b500f3,0x00000000}},	//   _così_, ývaj, åblå_, --,
   {{0x3ea9501f,0x65941502,0x00000000,0x00000000}},	//   vrat_, _саку, --, --,
   {{0x6286084e,0x3f89042c,0x00000000,0x00000000}},	//   apko, tbau_, --, --,
   {{0x3ea93a11,0xe3bf0933,0xdcfc0095,0x7ae221ad}},	//   trat_, miño_, _nerđ, kvot,
   {{0x9f555020,0x3ea95021,0xe3bf03be,0x7ae20995}},	// [46d0] увач, urat_, liño_, jvot,
   {{0x3ea95022,0x644f099c,0x3f895023,0x629d5024}},	//   rrat_, llci, sbau_, msso,
   {{0x629d5025,0x3ea95026,0x7bdb0270,0xe3bf0042}},	//   lsso, srat_, _pauu, niño_,
   {{0x3ea95027,0xe7c20980,0x2d9c0072,0x00000000}},	//   prat_, _वॉलप, óver_, --,
   {{0x629d5028,0x2a6c009c,0x41c009c4,0xe3bf0072}},	//   nsso, _bidb_, श्वस, hiño_,
   {{0x2a6c00dc,0x201e01d3,0x629d5029,0xf2d4006e}},	//   _cidb_, ītie_, isso, שעס_,
   {{0x9f4001cd,0x00000000,0x00000000,0x00000000}},	//   ljið_, --, --, --,
   {{0x315800a1,0x629d502a,0xe3bf20c8,0x6d590022}},	//   כיון_, ksso, diño_, ƙwab,
   {{0x98be0138,0x2907502b,0xf99302fc,0x00000000}},	//   _rytą_, syna_, _نبض_, --,
   {{0x3201025b,0x629d502c,0x9f590094,0xba550037}},	//   _nohy_, dsso, _nosí_, _صناع,
   {{0x25e80fef,0xdb00502d,0x629d0e37,0x00000000}},	//   जाजी_, _admè, esso, --,
   {{0x629d1df0,0xdd410361,0xb21b066a,0x225a0216}},	//   fsso, _aŋŋa, spæl, _shpk_,
   {{0x2bc502e8,0xd90f0068,0x46a51352,0x629d1b87}},	//   ळ्या, _دیں_, _салв, gsso,
   {{0x9f5900ee,0xe3bf2dc1,0x00000000,0x00000000}},	//   _cosí_, biño_, --, --,
   {{0xf6520054,0xe3bf03be,0x8fa601b3,0x629d502e}},	//   _הצג_, ciño_, лаве, asso,
   {{0x27ef0167,0x6286502f,0xdd41083e,0x629d502a}},	//   _jngn_, ppko, _eŋŋa, bsso,
   {{0x82360979,0x63a45030,0x6b990188,0x64465031}},	// [46e0] _مردا, _idin, dawg, moki,
   {{0x64465032,0xdcfc007e,0xa37b016d,0x4d160fe9}},	//   loki, _serđ, rdõe, льет,
   {{0x7bc24341,0x61fa2e17,0x00000000,0x00000000}},	//   tfou, ötlu, --, --,
   {{0x0ecf000f,0xdb1900a5,0x64465033,0x09bd0033}},	//   _सैकड, jewó, noki, _আফগা,
   {{0x69c35034,0x20020113,0x63a40373,0x7ae2007b}},	//   ffne, _ioki_, _mdin, uvot,
   {{0x20025035,0x6446019f,0x82d7006e,0x69bf270a}},	//   _hoki_, hoki, טונג_, ल्ली,
   {{0xa3e404a9,0xed571a0c,0x64465036,0x20025037}},	//   नया_, _бор_, koki, _koki_,
   {{0x8c46171b,0xb8cc018b,0x63a45038,0xe3bf24c7}},	//   _себе, _कट_, _ndin, viño_,
   {{0x64465039,0x27ef09a4,0x6b8005db,0x2d9a020a}},	//   doki, _dngn_, _ifmg, oape_,
   {{0x63a4503a,0x2d9a503b,0xe3bf2229,0xf486503c}},	//   _adin, nape_, tiño_, лумн,
   {{0x1dc600a8,0x32010094,0x69c802a1,0xdcfc00e8}},	//   र्यत, _rohy_, _ibde, _ierē,
   {{0xe3bf4c20,0x64460a00,0x629d503d,0xe8d700a1}},	//   riño_, goki, tsso, _תואר_,
   {{0xe60f00bf,0x2d9a503e,0x63a40150,0x69c80124}},	//   زشی_, kape_, _ddin, _kbde,
   {{0x629d5028,0x62840037,0xd57600c2,0x63a4503f}},	//   rsso, _dtio, _судь, _edin,
   {{0x20025040,0x25dd0403,0x6d4e17d2,0x6ea7074c}},	//   _boki_, _कोटी_, _nyba, _चिहु,
   {{0xa2ad0096,0xb344013c,0x9f4001cd,0x00000000}},	//   _जिप्, zaçə, tjið_, --,
   {{0xc05801b6,0x20025041,0x442b5042,0xa3cb0789}},	// [46f0] уір_, _doki_, mic_, _रॉय_,
   {{0x442b5043,0x63a400c4,0xdb19007f,0x6d4e0120}},	//   lic_, _zdin, zewó, _byba,
   {{0x5c070f1e,0xdcf500d9,0x63a400c2,0x20020324}},	//   ляда, _iezī, _ydin, _foki_,
   {{0xdea1001c,0x6d4e03a8,0x24b70142,0x00000000}},	//   _ویزی, _dyba, רהאן_, --,
   {{0xfaa73051,0x68e80150,0x3ec400b6,0x6d4e01ee}},	//   ушен, _ardd, ěstí_, _eyba,
   {{0x442b5044,0x7c970d5b,0x200221b8,0x64465045}},	//   hic_, _مشرا, _zoki_, zoki,
   {{0x20020154,0x6ce400d6,0x9f4200c2,0x64465046}},	//   _yoki_, _літе, _enkä_, yoki,
   {{0x442b191d,0x644601ff,0x00000000,0x00000000}},	//   jic_, xoki, --, --,
   {{0x442b5047,0x6d4e01af,0x64465048,0x7af600c2}},	//   dic_, _zyba, voki, äytt,
   {{0x7c2b5049,0x7ae90af0,0x7625504a,0xe9d80103}},	//   ligr, _iret, рмоз, _مذمت_,
   {{0x6446504b,0x442b504c,0x6284504d,0xa8a407c8}},	//   toki, fic_, _stio, _грчк,
   {{0x04460058,0x442b504e,0xe3660291,0x600a0031}},	//   ремн, gic_, икни, _tými,
   {{0x2002504f,0x321800d8,0xe7080452,0xa3c7007f}},	//   _roki_, thry_, _متون_, ैज़_,
   {{0x20025050,0x7ae937c9,0x5bd2023a,0x00000000}},	//   _soki_, _mret, _सस्व, --,
   {{0x2d9a04e9,0x7c2b0124,0x91034444,0x442b5051}},	//   vape_, kigr, опре, bic_,
   {{0x63a45052,0x6d4e1672,0x13065053,0x7ae9028d}},	//   _udin, _ryba, _взим, _oret,
   {{0xa0671d62,0x2d9a0257,0x2002007e,0x5ea60037}},	// [4700] рата_, tape_, _voki_, شمال,
   {{0x660302fd,0x7bc900b3,0x7c2b02ac,0x6ea72674}},	//   _jonk, _abeu, eigr, _चिरु,
   {{0xeb9a1773,0x7ae95054,0x2d9a5055,0x20025056}},	//   вие_, _aret, rape_, _toki_,
   {{0xa2ad1344,0x6d4e0618,0x7ae95057,0x66030201}},	//   _जिम्, _vyba, _bret, _lonk,
   {{0x2459025a,0x60180018,0x2d9a5058,0x5fdf02d5}},	//   néma_, _címe, pape_, _पोटल,
   {{0x7ae95059,0x442b505a,0x6603505b,0x3f800ff1}},	//   _dret, zic_, _nonk, lciu_,
   {{0x8ccd34d8,0x7ae9505c,0x2459505d,0x1dc609c4}},	//   _सहयो, _eret, héma_, र्णत,
   {{0x8c430562,0x2d981cc0,0x442b505e,0x7ae9505f}},	//   _десе, _here_, xic_, _fret,
   {{0x2d985060,0x66030060,0x442b5061,0xf1a7007a}},	//   _kere_, _bonk, vic_, _कएलन,
   {{0xa3b90ed3,0x9a6a06f6,0x2d985062,0x3ea05063}},	//   _चाह_, _شمال_, _jere_, isit_,
   {{0x2d985064,0x442b504e,0x660301a2,0x397b0341}},	//   _mere_, tic_, _donk, _סטאנ,
   {{0x2d985065,0x3ea05066,0x1dc60296,0x00000000}},	//   _lere_, ksit_, र्तत, --,
   {{0x66035067,0x60180072,0x00000000,0x00000000}},	//   _fonk, _oímb, --, --,
   {{0x442b5068,0x2d985069,0x3f82506a,0x9f590036}},	//   sic_, _nere_, _afku_, _rosà_,
   {{0x442b506b,0x3ea000dd,0x764832dd,0xe4531a13}},	//   pic_, esit_, mody, _وضع_,
   {{0x34fb09c1,0x66030060,0x2d98207f,0x9f5900ee}},	//   _יהוד, _zonk, _aere_, _posà_,
   {{0x2d98506c,0x66030060,0x7875013f,0x7c2b506d}},	// [4710] _bere_, _yonk, _išve, vigr,
   {{0x7ae901e5,0x273300ef,0x2d98002d,0x442901fa}},	//   _rret, ảng_, _cere_, _hma_,
   {{0x7ae920e4,0x2d98506e,0xd5b800e8,0x0eac074c}},	//   _sret, _dere_, igā_, _चिथड,
   {{0x37ac0081,0x1b050081,0x3f80028d,0x5fdf0096}},	//   ক্তর, _শেষে_, cciu_, _पोचल,
   {{0x44290857,0xf1ec05d4,0x2d98506f,0x3ea00018}},	//   _mma_, _छोड़_, _fere_, csit_,
   {{0x2d985070,0x2ba70028,0x7c2b5071,0x7ae95072}},	//   _gere_, ốc_, sigr, _vret,
   {{0x44295073,0xb7bd002d,0x2d81009c,0x3f990b18}},	//   _oma_, liţi, mche_, _kesu_,
   {{0x01385074,0x3f995075,0x2d815076,0x44290129}},	//   ירות_, _jesu_, lche_, _nma_,
   {{0x7c295077,0x7ae95078,0x6f0d5079,0x2d9801e8}},	//   _imer, _uret, nyac, _yere_,
   {{0x4429507a,0x2d81507b,0xe61603a7,0x644d507c}},	//   _ama_, nche_, йды_, _akai,
   {{0x2d81507d,0x66030220,0x3f80007f,0x386f05db}},	//   iche_, _vonk, yciu_, _tigr_,
   {{0x3f99507e,0x66030060,0x3ea0507f,0x00000000}},	//   _nesu_, _wonk, ysit_, --,
   {{0x7c295080,0xd7c8001c,0x24521bb9,0x00000000}},	//   _mmer, _خونه_, námi_, --,
   {{0x44295081,0x644d0a00,0x27ff003d,0x661a3700}},	//   _ema_, _ekai, ljun_, chtk,
   {{0x2d985082,0x7c295083,0x2d815084,0x00000000}},	//   _rere_, _omer, dche_, --,
   {{0x2d985085,0x3ea0468a,0x7c3b5086,0x27ff5087}},	//   _sere_, tsit_, _njur, njun_,
   {{0x2d985088,0xee3a0b11,0x7d030212,0x3f805089}},	// [4720] _pere_, гна_, änsn, rciu_,
   {{0x823600bf,0xc33300f5,0x3ea0508a,0x9f40508b}},	//   _دربا, _מוח_, rsit_, ndié_,
   {{0x442902e0,0x2d9800f3,0x3ea0508c,0xad5a345a}},	//   _yma_, _vere_, ssit_, урах_,
   {{0x2d98508d,0xeb9a048f,0xa3cb00a3,0x3ea0508e}},	//   _were_, اضات_, र्प_, psit_,
   {{0x7c3b508f,0x2d985090,0xcc8800d1,0x6f0d0169}},	//   _djur, _tere_, انچه_, cyac,
   {{0x2d81008f,0x7c295091,0x7c3b0027,0x00000000}},	//   cche_, _emer, _ejur, --,
   {{0x3f995092,0xa3b9143d,0x81cb0033,0x7c3b0078}},	//   _yesu_, _चाल_, _রোড_, _fjur,
   {{0x6c360d74,0x7c3b023b,0xc7b901f9,0x00000000}},	//   _افرا, _gjur, ggő_, --,
   {{0xa3cb2c5f,0x628008a8,0x00000000,0x00000000}},	//   र्फ_, ímol, --, --,
   {{0x645f0910,0x644d5093,0xa3cb0be4,0x44295094}},	//   _shqi, _skai, र्न_, _sma_,
   {{0x764801b3,0xb7bd002d,0xf8ac0251,0x7c295095}},	//   rody, ziţi, _घटिय, _ymer,
   {{0x6f0d0044,0x25a70072,0x6aa20167,0x14a91da8}},	//   yyac, _ednl_, osof, _किरण,
   {{0x44295096,0x6d5c0063,0xdb0000b6,0x1dd800c3}},	//   _vma_, _lzra, _odmí, ड़ात,
   {{0x98dc0557,0xf8dc0c8c,0x799a05aa,0x629603a8}},	//   _मनाए, _मनाय, _jetw, _dwyo,
   {{0x95830067,0x3f990329,0x4de10033,0xa4860781}},	//   łącz, _pesu_, নামূ, _اجتن,
   {{0x44295097,0xdb000072,0xb7bd00d3,0x506706c4}},	//   _uma_, _admí, tiţi, стга,
   {{0x44395098,0x6d5c5099,0x2c7e014b,0x6aa20381}},	// [4730] mns_, _azra, _aïd_, jsof,
   {{0x4439509a,0x7c290206,0x799a121e,0x2d81509b}},	//   lns_, _smer, _netw, uche_,
   {{0x2d8124e2,0x4439509c,0x2264030b,0x7cd92753}},	//   rche_, ons_, řské_, рмер_,
   {{0x4439509d,0x2d8112c1,0xafdb0120,0x200f00bc}},	//   nns_, sche_, _sjøf, ögid_,
   {{0xa3cb0789,0x799a0054,0x4439509e,0x6d5c0154}},	//   र्य_, _betw, ins_, _ezra,
   {{0x79e70018,0xe29c006e,0x2fc90120,0x9f40042c}},	//   صوبہ_, נשור, lfag_, leiß_,
   {{0xf8a900bf,0x799a02f1,0x600a0220,0x7c29023b}},	//   شگاه_, _detw, _týmt, _tmer,
   {{0xa3cb0789,0x7c29509f,0x6b82008f,0x443950a0}},	//   र्म_, _umer, ccog, jns_,
   {{0x1dc61d96,0x27ff14dd,0xa3dd09d0,0xe61913c0}},	//   र्वत, rjun_, ड़न_, иди_,
   {{0xdce50740,0xf993029e,0xf62500d6,0x443950a1}},	//   lahı, _ربط_, ідно, ens_,
   {{0xa3cb0640,0xbf9b00fd,0x6b9b00dc,0xafdb0565}},	//   र्भ_, _poêl, _keug, _gjøg,
   {{0x6b9b043e,0xd7e40426,0x799a06a3,0x443950a2}},	//   _jeug, _нічо, _zetw, gns_,
   {{0x93462f0c,0x799a010a,0x00000000,0x00000000}},	//   інге, _yetw, --, --,
   {{0xca7a00f5,0x6b9b0013,0xdd1c0031,0x00000000}},	//   ינשט, _leug, váža, --,
   {{0x6b8222d4,0x7d030149,0x44390154,0xc0e300ae}},	//   ycog, änsl, bns_, морк,
   {{0x6b9b50a3,0x4439009c,0xdfd20037,0xdddc026a}},	//   _neug, cns_, بير_, _birş,
   {{0x3e7f020a,0x00000000,0x00000000,0x00000000}},	// [4740] _cît_, --, --, --,
   {{0x7e560426,0x237f0031,0xdd1c0031,0x181650a4}},	//   ітац, ľuje_, ráža, _तत्व_,
   {{0x237f50a5,0x6b9b50a6,0xe7d9009f,0xb4c7007a}},	//   žuje_, _beug, ढ़ाप, _उहो_,
   {{0x6aa20dd8,0x274300c6,0x6d5c0fee,0x00000000}},	//   tsof, _kūną_, _vzra, --,
   {{0x6aa20063,0x6b8240b1,0x799a0383,0x00000000}},	//   usof, rcog, _petw, --,
   {{0x6aa250a7,0x6b82167e,0x48aa2b79,0xfd550174}},	//   rsof, scog, атим_, nlaị,
   {{0xa3cb0861,0x6b9b50a8,0x6d5c50a9,0x443950aa}},	//   र्ड_, _feug, _uzra, yns_,
   {{0x32c4026a,0x99890995,0x6b9b50ab,0x799a010a}},	//   köy_, đaš_, _geug, _wetw,
   {{0x4439052f,0x41ca00b7,0xdcfc0138,0x799a083e}},	//   vns_, िभास, _perė, _tetw,
   {{0x443950ac,0x6b9b0364,0x00000000,0x00000000}},	//   wns_, _zeug, --, --,
   {{0x7d7b00a1,0xd7fa0c10,0x69d8075b,0x3958003e}},	//   יניו, _вул_, meve, _árs_,
   {{0x443950ad,0xd7ef00e3,0x3eb23867,0x24590072}},	//   uns_, _لكم_, kryt_, rémo_,
   {{0x7875013f,0x47361a37,0x443950ae,0xc2b8004d}},	//   _išva, _براز, rns_, оляє_,
   {{0x69d850af,0x9f40042c,0x00000000,0x00000000}},	//   neve, weiß_, --, --,
   {{0xcf9b50b0,0x60180088,0xdce50092,0x3a2c037a}},	//   ија_, _síma, yahı, _mmdp_,
   {{0x69d850b1,0xdc3a028e,0xd91b2252,0x00000000}},	//   heve, kçıs, בולל, --,
   {{0xa3cb0961,0x69d800f3,0xd83802f1,0xf3ff016d}},	// [4750] र्ण_, keve, _avčk_, lmão_,
   {{0x69d82281,0x63bd50b2,0x2fc913b9,0x9f42022b}},	//   jeve, lgsn, sfag_, _makè_,
   {{0x69d850b3,0x628f4090,0xa25b020d,0x9f420154}},	//   deve, lpco, ntôm, _lakè_,
   {{0x60180102,0x3eb20578,0x69ca0429,0x00000000}},	//   _tíma, bryt_, effe, --,
   {{0x61e50060,0x7ccc00d9,0x3ffa00ca,0xdb090381}},	//   _kahl, vērš, _הפרע, _ideë,
   {{0x69d850b4,0xaca30134,0x61e5008c,0x00000000}},	//   geve, _ahụa, _jahl, --,
   {{0x5ba7261f,0x6b9b50b5,0x7e7d0de9,0xa9690ed4}},	//   _мраз, _teug, _husp, щика_,
   {{0x97d900d6,0xb8d3034c,0x7e7501e9,0x61e50415}},	//   ську_, _झट_, _hizp, _lahl,
   {{0x2be00096,0xb6a300fe,0x7bd90172,0x00000000}},	//   _नसता, _giấ, mewu, --,
   {{0x61e50074,0x69d850b6,0x80d200c7,0x7e7d50b7}},	//   _nahl, ceve, হিত্, _musp,
   {{0x7e7540b0,0x00000000,0x00000000,0x00000000}},	//   _mizp, --, --, --,
   {{0x88830018,0x63bd05e8,0x7bd91b99,0x61e501ce}},	//   _ٹیکن, ggsn, newu, _aahl,
   {{0x7e7d50b8,0x61e50201,0x5ed30081,0xb77a00ca}},	//   _nusp, _bahl, সিডে, _האנש,
   {{0x61e5078e,0xbfa10231,0x00000000,0x00000000}},	//   _cahl, ãªnc, --, --,
   {{0x7e7d50b9,0xe3b200e3,0xc5e10033,0x628f0381}},	//   _ausp, _كرة_, বাদপ, apco,
   {{0x7e7d0095,0x7e7550ba,0xa3cb2231,0xafdb02b6}},	//   _busp, _aizp, र्द_, _skør,
   {{0x7e7d0091,0xd0073bf6,0x441b0089,0x69d850bb}},	// [4760] _cusp, чете_, _לוקס, yeve,
   {{0x9f42030b,0x7e7d0357,0x24520094,0x00000000}},	//   _jaké_, _dusp, rámu_, --,
   {{0xdcfc00d9,0xb33b016d,0xafdb004d,0x7e7d01ff}},	//   _ierī, maça, _sjøe, _eusp,
   {{0x61e550bc,0xb33b50bd,0x69d800a1,0x69c1009c}},	//   _zahl, laça, weve, _acle,
   {{0x1e83224a,0x7e7d00b3,0x69d850be,0xa3dd00aa}},	//   _плям, _gusp, teve, ड़त_,
   {{0xb33b50bf,0x69ca50c0,0x693401f3,0x7e7501ff}},	//   naça, uffe, وکار, _gizp,
   {{0x69d850c1,0x7bd950c2,0x69ca02ad,0xdb021de1}},	//   reve, bewu, rffe, rgoñ,
   {{0xa2ad50c3,0x69d850c4,0x60110fbc,0xebe32f1f}},	//   _जिल्, seve, _påmi, _посп,
   {{0xc6f71736,0x5eca0081,0xba3d030b,0x8c43013d}},	//   зных_, রিকে, _kvůl, _чете,
   {{0x1dcf0a30,0x60180143,0x69d80052,0x69c10076}},	//   स्पत, _oímo, qeve, _gcle,
   {{0x9f4700b6,0xa3cb0006,0x61e5033b,0xb33b4647}},	//   ěné_, _रउआ_, _rahl, daça,
   {{0x61e550c5,0xf3ff0131,0x4394022a,0x00000000}},	//   _sahl, rmão_, наюс, --,
   {{0x61e532c3,0xf3ff0231,0xa25b0231,0x00000000}},	//   _pahl, smão_, stôm, --,
   {{0x27e60037,0x7e7d50c6,0xb33b016d,0x9f55020d}},	//   _haon_, _rusp, gaça, _âgée_,
   {{0xdcfc01d3,0x2b52007f,0x387e0141,0x81df0033}},	//   _derī, żych_, _jutr_, ণাল_,
   {{0x61e550c7,0xd3db0037,0xceb400a7,0x855700ca}},	//   _wahl, _طبعا_, frə_, _משוב_,
   {{0x644f0e4d,0x63ad50c8,0x61e550c9,0x984e00a7}},	// [4770] moci, _idan, _tahl, nğın_,
   {{0x628d0239,0xb33b016d,0xc0cb002d,0x27e600fc}},	//   _itao, caça, _луме_, _laon_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644f50ca,0x7e7d00e7,0x7988000b,0xa3dd00aa}},	//   noci, _tusp, _afdw, ड़ि_,
   {{0x9f4b0131,0x7e7d0f06,0x63ad024a,0x00000000}},	//   _cocô_, _uusp, _mdan, --,
   {{0x2d850006,0x200b0220,0x628d024a,0x660a0216}},	//   _üle_, _hoci_, _mtao, _nofk,
   {{0xa3dd0d0b,0x200b50cb,0x27e606a8,0x248900e7}},	//   ड़ा_, _koci_, _baon_, _čamo_,
   {{0x63ad50cc,0xd0f800a1,0x200b50cd,0x628d0062}},	//   _ndan, למות_, _joci_, _otao,
   {{0x200b50ce,0x660a0381,0x644f50cf,0x9f5900da}},	//   _moci_, _bofk, doci, _aosú_,
   {{0x63ad50d0,0xa3cb1926,0x7b740037,0xa3dd007a}},	//   _adan, र्स_, _أطفا, ड़ऽ_,
   {{0x1dcf000c,0x044608d1,0x628d50d1,0x39150dce}},	//   स्यत, денн, _atao, _تواز,
   {{0x200b068e,0x60180103,0xa7150291,0x6b630139}},	//   _noci_, _címl, _одељ, _gìgí,
   {{0x9f42000d,0x0cba099d,0xe72e18b9,0xe2972787}},	//   _také_, _उम्म, _ре_, мая_,
   {{0x628d0037,0x0478001c,0x63ad50d2,0x1dcf00b7}},	//   _dtao, _کليک_, _edan, स्मत,
   {{0xb33b33e1,0x6b890428,0x200b50d3,0x27e60bb6}},	//   raça, _ofeg, _boci_, _yaon_,
   {{0x644f0996,0x63ad50d4,0xdb1b24c7,0x200b0d2a}},	//   coci, _gdan, _acuí, _coci_,
   {{0x200b04a3,0xb33b50d5,0x6da63386,0x00000000}},	// [4780] _doci_, paça, диза, --,
   {{0x6b8916c8,0x63ad12c5,0xb21b181f,0x601850d6}},	//   _afeg, _zdan, spær, _tímo,
   {{0xa3cb034d,0x61460b73,0x200b0103,0xa2a400aa}},	//   र्व_, _цена, _foci_, _कबड्,
   {{0x200b0d62,0xaca40174,0x26df0129,0xd5ce020b}},	//   _goci_, _nkụp, kwuo_, _nềng_,
   {{0x27e60091,0x34da50d7,0xb3c60789,0x7bc650d8}},	//   _raon_, _बन्द, _वानख, _ökum,
   {{0x2bae0028,0x6b890294,0x09e30291,0x2a7f026d}},	//   ộc_, _efeg, вољн, _duub_,
   {{0x27e650d9,0xa3be50da,0x00000000,0x00000000}},	//   _paon_, आला_, --, --,
   {{0xb8d61860,0x2fc050db,0x2eed05db,0x76aa007b}},	//   _जि_, ngig_, _šefi_, отов_,
   {{0x6fd009d0,0x19c629db,0x7c2250dc,0xd6da00d6}},	//   ड्यू, _обам, mhor, іти_,
   {{0x7c2200c9,0x660a0694,0x63ad005c,0x63610174}},	//   lhor, _qofk, _sdan, _ịnon,
   {{0xf9c71e49,0x27e613b5,0x628d50dd,0x2db700d7}},	//   _تحقی, _taon_, _stao, ולין_,
   {{0x7c2250de,0x00000000,0x00000000,0x00000000}},	//   nhor, --, --, --,
   {{0xa3cb0abe,0x61ca074c,0x43940284,0x601801f9}},	//   र्ष_, िभूष, ђарс, _címm,
   {{0x200b323d,0x644f2a21,0x9f590037,0x63ad01c2}},	//   _soci_, soci, _tosú_, _wdan,
   {{0x200b03a9,0x7c2250df,0x38660063,0xdfd50ae3}},	//   _poci_, khor, _khor_, новы,
   {{0x63ad50e0,0xe3d00019,0x7c22033d,0xa3cb034d}},	//   _udan, _hằng_, jhor, र्श_,
   {{0x200b50e1,0x80a0009d,0x7c22292a,0x628d0051}},	// [4790] _voci_, गीबे, dhor, _utao,
   {{0x7865001f,0xa3cb17ff,0x6b890036,0xb33b50e2}},	//   móve, र्र_, _sfeg, laço,
   {{0x291901d4,0x6aa9003e,0x7c2250e3,0x7c840e20}},	//   _əsas_, _svef, fhor, вуче,
   {{0x7c2250e4,0x200b015c,0xb33b0072,0xb1130134}},	//   ghor, _uoci_, naço, tụfo,
   {{0x1dc70251,0x2444008b,0xd10800d1,0x00000000}},	//   _लापत, nıma_, _فقیه_, --,
   {{0x0d841402,0x00000000,0x00000000,0x00000000}},	//   _алён, --, --, --,
   {{0x3ea950e5,0x386601b9,0x7762039f,0x8bc72458}},	//   lsat_, _bhor_, _azox, _осад,
   {{0x3866507d,0x7d240260,0x3f890b3e,0x2a7f0174}},	//   _chor_, _شفقن, ncau_, _tuub_,
   {{0xe3d000ef,0x3ea950e6,0xf77100ab,0x1dc60557}},	//   _bằng_, nsat_, داث_, र्कत,
   {{0xe3b209b4,0x244450e7,0x00000000,0x00000000}},	//   گرد_, dıma_, --, --,
   {{0x25e0000d,0x69c44694,0x3866009c,0xb33b020d}},	//   _कसरी_, _राती, _fhor_, faço,
   {{0xccf200c1,0xe3b2010d,0x3ea950e8,0x1dcf0f8f}},	//   אכט_, درد_, ksat_, स्तत,
   {{0x386d0bc6,0x00000000,0x00000000,0x00000000}},	//   mmer_, --, --, --,
   {{0x64a550e9,0x386d50ea,0x3ea950eb,0x44220052}},	//   _зака, lmer_, dsat_, shk_,
   {{0x25a550ec,0xa3cb0789,0x3ea901b9,0x3218057a}},	//   mall_, _रॉक_, esat_, rkry_,
   {{0xd0071b4d,0x7c220052,0x3ea950ed,0xb33b4097}},	//   несе_, xhor, fsat_, caço,
   {{0x9f420c56,0x63a650ee,0x3ea90124,0x671f397e}},	// [47a0] _ankò_, makn, gsat_, यनिक_,
   {{0xa3c005cd,0x63a650ef,0x44200197,0x25a509f7}},	//   ुभव_, lakn, _hli_, nall_,
   {{0x44e101b3,0x386d0181,0x3ea90332,0x7c2200a1}},	//   _jų_, kmer_, asat_, thor,
   {{0xf76750f0,0x63a650f1,0xc5f800d9,0x6444010a}},	//   _ما_, nakn, nmēr_, _jjii,
   {{0xa3b80976,0xafdb004d,0x386d03a8,0x25a550f2}},	//   _चयन_, _kjøn, dmer_, kall_,
   {{0x7c2250f3,0xc33300c1,0x63a6063f,0x386d0220}},	//   shor, נוג_, hakn, emer_,
   {{0x442050f4,0xe3d00028,0xf1d207d5,0x291a50f5}},	//   _oli_, _rằng_, द्यन, ápa_,
   {{0xc6f825ab,0x63a609a4,0x81d40081,0xd5c20034}},	//   дних_, jakn, _সোম_, _शाहज,
   {{0x25a50cb4,0x63a6042b,0x09bf0033,0x00000000}},	//   fall_, dakn, _ইসরা, --,
   {{0xceb3004f,0x25a550f6,0x64470234,0x44320158}},	//   נית_, gall_, čkim, _amy_,
   {{0x442050f7,0x43951e20,0x60180018,0xa3dd0006}},	//   _bli_, канс, _címk, ड़ल_,
   {{0x63a60706,0x443250f8,0x07a60565,0x00000000}},	//   gakn, _cmy_, _чадн, --,
   {{0x25a550f9,0xb33b50fa,0xee3f030b,0x442001b9}},	//   ball_, raço, _svým_, _dli_,
   {{0x442050fb,0x171b0130,0x7af600c2,0x2444008b}},	//   _eli_, _צוגע, äyty, rıma_,
   {{0x9f47000d,0xa2ad0ed3,0xb33b33e1,0x63a650fc}},	//   ění_, _जिक्, paço, bakn,
   {{0x44200020,0x63a60167,0xa3520134,0x00000000}},	//   _gli_, cakn, ọkọt, --,
   {{0x506450fd,0x5fe20096,0x3f8915c7,0xb1130174}},	// [47b0] утра, _पसरल, rcau_, wụdo,
   {{0x645d50fe,0x3ea950ff,0x44200106,0x386d0211}},	//   llsi, rsat_, _zli_, zmer_,
   {{0x09bf0f71,0x3ea95100,0x442002fd,0x6ad9009d}},	//   _ইসলা, ssat_, _yli_, णब्र,
   {{0xa3d4000f,0x3ea9030b,0xdb1b0610,0xb33b026a}},	//   स्प_, psat_, _acuá, yaçl,
   {{0x645d0037,0xdb000113,0x00000000,0x00000000}},	//   ilsi, _jemè, --, --,
   {{0xdc13008e,0xdb00023b,0xf2d4006e,0xcda90981}},	//   rşıs, _zemë, רעס_, _زهره_,
   {{0x25a55101,0x63a65102,0x6d4200d3,0x24590146}},	//   vall_, yakn, şoar, lému_,
   {{0x752800e8,0x7ae219a2,0x386d0ac9,0x00000000}},	//   dzdz, bwot, umer_, --,
   {{0x386d5103,0x25a55104,0x2459025b,0x63a65105}},	//   rmer_, tall_, nému_, vakn,
   {{0xa3d406ed,0x386d5106,0x64440381,0x458500e5}},	//   स्न_, smer_, _sjii, ъгов,
   {{0x44200c56,0x63a600cb,0x25a55107,0x24590094}},	//   _pli_, takn, rall_, hému_,
   {{0x66b520e6,0x24590146,0x44200036,0x69c300bc}},	//   _абду, kému_, _qli_, lgne,
   {{0xe3b807d1,0x27ed5108,0x25a55109,0x63a6510a}},	//   ğı_, mden_, pall_, rakn,
   {{0xe3b8008e,0x27ed510b,0x63a612d2,0x44e10138}},	//   şı_, lden_, sakn, _tų_,
   {{0x69c3510c,0x63a614c4,0x4420510d,0x2056510e}},	//   igne, pakn, _tli_, втар,
   {{0x27ed510f,0x44205110,0x7848030b,0x26cd0307}},	//   nden_, _uli_, pěve, oteo_,
   {{0x27ed5111,0x26cd0610,0x63a400e8,0x672900b3}},	// [47c0] iden_, nteo_, _iein, nzej,
   {{0x63a45112,0x27ed0084,0x6f0403be,0x7641059a}},	//   _hein, hden_, rxic, nnly,
   {{0x63a45113,0x60183964,0xdb00023b,0xafdb00d6}},	//   _kein, _lími, _temë, _kjøl,
   {{0x27ed0505,0x69c40096,0x62840239,0x63a40062}},	//   jden_, _राही, _kuio, _jein,
   {{0xa3d40b2b,0x27ed5114,0x63a40e78,0x7bc216e7}},	//   स्य_, dden_, _mein, rgou,
   {{0xbda50678,0x63a45115,0x27ed5116,0xda632b94}},	//   _محفو, _lein, eden_, авчи,
   {{0x7d030222,0xdca310ab,0x27ed5117,0xadd700ca}},	//   änst, _васи, fden_, _שולח_,
   {{0x63a45118,0x6b8500e3,0x27ed5119,0xa3d4417a}},	//   _nein, _مشكل, gden_, स्म_,
   {{0x7e7c511a,0xc8ae0557,0x1dcf09c4,0x28ae00c3}},	//   _kirp, _टिकट, स्वत, _टिकि,
   {{0x4b550465,0xdb004aa4,0x49ba09e5,0xae0507d5}},	//   _съст, _remè, _زائد_, रायन_,
   {{0x63a4511b,0xdb0002f1,0x7e7c0052,0x661a04aa}},	//   _bein, _semè, _mirp, rktk,
   {{0x61fe0c56,0xd6d2003f,0x63a4511c,0x6d5c169c}},	//   _anpl, _نقص_, _cein, _myra,
   {{0x63a44b17,0x59c91792,0xf11b142e,0x81cb0033}},	//   _dein, _रामर, नन्द_, _রোগ_,
   {{0x2459025b,0x752d02c6,0xe71700ca,0x6284044c}},	//   vému_, _řaze, _בחדר_, _duio,
   {{0x63a4511d,0xdb0000ee,0x41d21d96,0xa158511e}},	//   _fein, _demé, द्धस, вару_,
   {{0x63a4511f,0x61fe5120,0x6b8000f9,0x24590094}},	//   _gein, _enpl, _ngmg, tému_,
   {{0x44395121,0x62840af3,0x6d5c5122,0x7e7c4379}},	// [47d0] mis_, _guio, _ayra, _birp,
   {{0x27ed0b88,0x24590146,0x63a401e9,0x00000000}},	//   zden_, rému_, _zein, --,
   {{0x27ed5123,0x44395124,0x7e7c0178,0x6e370231}},	//   yden_, ois_, _dirp, rixb,
   {{0x44395125,0xc4d30130,0x6d5c5126,0x00000000}},	//   nis_, יגע_, _dyra, --,
   {{0x69c4063c,0x8c160037,0x27ed5127,0x8f9a00ca}},	//   _राशी, طيور_, vden_, _רישי,
   {{0x44395128,0xa9690e20,0x78750138,0x6d5c057e}},	//   his_, нила_, _išvi, _fyra,
   {{0x44390358,0x69c35129,0x4879512a,0x6b840117}},	//   kis_, rgne, нсия_, žiga,
   {{0x4439512b,0x27ed512c,0x26cd512d,0x317c00a1}},	//   jis_, uden_, tteo_, ורומ,
   {{0x27ed512e,0x63a421b2,0x9f420850,0x6d5c0052}},	//   rden_, _rein, _kaká_, _zyra,
   {{0x63a410a5,0x26cd512f,0xafdb00f3,0xf9930e11}},	//   _sein, rteo_, _sjøl, _ضبط_,
   {{0x63a45130,0xdb005131,0x26cd034f,0x9f4200d8}},	//   _pein, _remé, steo_, _maká_,
   {{0x60185132,0x00000000,0x00000000,0x00000000}},	//   _tími, --, --, --,
   {{0x8c1a0054,0x62842c68,0x63bb003e,0x9f590e2e}},	//   גורי, _quio, óuna, _mosó_,
   {{0x63a45133,0x44395134,0x7ae90239,0x00000000}},	//   _wein, ais_, _mset, --,
   {{0x44394afd,0x63a45135,0x28c62397,0x412a5136}},	//   bis_, _tein, रूपि, хово_,
   {{0x7ae95137,0xd5cf009d,0x05cf2cb6,0x24830146}},	//   _oset, त्रज, त्रब, íjmu_,
   {{0x7e7c02ef,0x7ae90134,0x2d9613c9,0x1f66100c}},	// [47e0] _pirp, _nset, грес, укам,
   {{0x683e00e8,0x61fe0d54,0x00000000,0x00000000}},	//   mūde, _unpl, --, --,
   {{0xa3cb1efb,0x7ae95138,0x273300de,0x9f5900b3}},	//   र्क_, _aset, ảnh_, _bosó_,
   {{0x6d5c1867,0xc178013f,0x201e01d3,0xdca32cb3}},	//   _vyra, žės_, ītis_, саци,
   {{0x6d5c00a5,0x1b170033,0x7e7c5139,0xa3cc1981}},	//   _wyra, _দেবে_, _tirp, _लान_,
   {{0x4439513a,0xa3d4087c,0xb8850220,0x00000000}},	//   zis_, स्त_, zlíš, --,
   {{0x7ae9513b,0x44393273,0x69e202c6,0x0d75007b}},	//   _eset, yis_, _čteč, _вытя,
   {{0x79810150,0x6b800124,0xed570832,0x78650103}},	//   _eglw, _ugmg, _сос_, tóva,
   {{0x2907009c,0x00000000,0x00000000,0x00000000}},	//   axna_, --, --, --,
   {{0x4439513c,0x68ed00a5,0xdb2306fa,0x5a5600e5}},	//   wis_, łada, _órái, _събу,
   {{0xdb091e6a,0x97c60604,0xd7ef1e33,0xafdb0120}},	//   _ideá, _مقاو, _лу_, _sjøm,
   {{0x225a00dc,0x661d0216,0x00000000,0x00000000}},	//   _akpk_, ëskr, --, --,
   {{0x443934d2,0xa3cb097c,0x6a64015e,0x23c60e4c}},	//   ris_, र्ग_, nòfo, _वारद,
   {{0x4439513d,0xf77300ca,0x6594163d,0xc6930266}},	//   sis_, _פקס_, _таку, _האס_,
   {{0x6671001c,0x4395513e,0xa159513f,0x00000000}},	//   _بگير, _кайс, таву_, --,
   {{0x5f9512e7,0x9f4b0314,0x9f420206,0x9582007f}},	//   риат, _hacé_, _saká_, łądk,
   {{0x9f5900b3,0x00000000,0x00000000,0x00000000}},	// [47f0] _rosó_, --, --, --,
   {{0xafdb004d,0x2369022b,0xa3dd00c3,0xf41f007b}},	//   _kjøk, _izaj_, ड़क_, lkä_,
   {{0x9f5917d5,0x7ae95140,0xa8070233,0x00000000}},	//   _posó_, _sset, ngıç, --,
   {{0xf41f0084,0x7ae9015c,0xac74001c,0x1dc70096}},	//   nkä_, _pset, مانش, _लावत,
   {{0x9f420031,0x00000000,0x00000000,0x00000000}},	//   _taká_, --, --, --,
   {{0xa3cc0b89,0x7ae9135f,0x48b5044e,0x44c40139}},	//   _लाभ_, _vset, ащит, _akọṣ,
   {{0xafdb004d,0xf41f007b,0x6d430076,0xf9a80139}},	//   _skøy, kkä_, únad, _ibè̟_,
   {{0xb8cd05d4,0x69d50251,0xc88800e3,0xa8020491}},	//   _कब_, _मॉरी, دخول_, şınm,
   {{0x78a4084f,0xf7452a61,0x7ae949c4,0x762543c7}},	//   ćiva, репо, _uset, имиз,
   {{0x853901c2,0xe616007b,0x00000000,0x00000000}},	//   _haɗɗ, иды_, --, --,
   {{0x998416cc,0xe7b500d1,0x00000000,0x00000000}},	//   _المو, _نماد, --, --,
   {{0xf77000fb,0xda033845,0x25a0007e,0xdcfc0078}},	//   _کام_, लावत_, _đile_, _jerġ,
   {{0x2bd713b4,0x59da0789,0x32135141,0x87ac006e}},	//   ण्या, _मॉडर, _boxy_, _טשאַ,
   {{0xe2970f84,0x00000000,0x00000000,0x00000000}},	//   рар_, --, --, --,
   {{0x463a00c1,0x28dd0fef,0xc0e600ae,0x505a007b}},	//   _בעסע, _महफि, шовк, вшая_,
   {{0xdb0b003e,0x09af0033,0xd838022b,0xdcfc009e}},	//   yggð, চ্চা, _nwčl_, _nerġ,

   {{0xe5a30023,0x27ef01cd,0x84450037,0x00000000}},	// [4800] _điệ, _magn_, _دخول, --,
   {{0xbda50037,0x00000000,0x00000000,0x00000000}},	//   محمو, --, --, --,
   {{0xdddd00d3,0xdcfc02a1,0x91bb00ca,0x64465142}},	//   _susţ, _berġ, _במיי, onki,
   {{0x64465143,0x41d2077d,0x60de0239,0x1024001c}},	//   nnki, द्रस, _ippm, _اکسپ,
   {{0xa3cb1c05,0x64465144,0x853901c2,0xe8091e9f}},	//   र्ट_, inki, _daɗɗ, वाना_,
   {{0xca560291,0x3ceb007b,0x7c9600e5,0x22580634}},	//   штењ, äivä_, _врац, nork_,
   {{0x68ed0034,0x48a70fe9,0x1d070e06,0x2b4d5145}},	//   ładn, атым_, _кери_, _exec_,
   {{0xf09300ca,0x3dc603e3,0x601801cd,0x237f02c6}},	//   חנה_, ɗowa_, _tímu, žuji_,
   {{0x236001fa,0x9634510e,0xafdb00f3,0x00000000}},	//   _nyij_, йниц, _sjøk, --,
   {{0x22585146,0x60de00d6,0x2480009c,0x7afd0088}},	//   jork_, _oppm, _aiim_, _ásta,
   {{0xf41f0084,0x2480009c,0x6296010a,0x752d0022}},	//   tkä_, _biim_, _atyo, _ƙaza,
   {{0x38600037,0x27ef4741,0x00000000,0x00000000}},	//   _óir_, _gagn_, --, --,
   {{0xe69400e3,0x63b600f0,0x00000000,0x00000000}},	//   _التد, _ddyn, --, --,
   {{0x20024948,0xa3cb087c,0x64460878,0x25a70313}},	//   _anki_, र्ज_, anki, _genl_,
   {{0x26c45147,0x27ef005c,0x69da0085,0x62965148}},	//   lumo_, _yagn_, _mbte, _etyo,
   {{0x02a72d64,0xcf9815de,0x63b65149,0xe8090034}},	//   _кром, ију_, _gdyn, वाया_,
   {{0xf77300c1,0xa3cc3d34,0x26c4514a,0x2d83034f}},	// [4810] ַקע_, _लात_, numo_, _pgje_,
   {{0x200247fd,0x6018514b,0x00000000,0x00000000}},	//   _enki_, _bíms, --, --,
   {{0xa3d4007d,0x63b60150,0xe80900b6,0x00000000}},	//   स्व_, _ydyn, वामा_, --,
   {{0xa3cb18ff,0x26c4514c,0x69da0364,0xccf80284}},	//   र्च_, kumo_, _abte, шћу_,
   {{0xe21412eb,0x7848030b,0x68fa514d,0xa8020555}},	//   _طبیع, těvn, _artd, ğılm,
   {{0x26c4514e,0xa802008b,0x853901c2,0xdb00037a}},	//   dumo_, şılm, _waɗɗ, _gemí,
   {{0x601800b6,0x2b8d0076,0x6446514f,0x89d60076}},	//   _tímt, _cócó_, ynki, صوير_,
   {{0x9f950006,0x26c45150,0x2fc92375,0x68ed0034}},	//   _nüüd_, fumo_, ngag_, łado,
   {{0xa3cb030b,0x6e2700e7,0x26c40138,0x7bdb0113}},	//   र्छ_, _kljb, gumo_, _ibuu,
   {{0x7afb5151,0x24805152,0x06093c75,0x00000000}},	//   _irut, _siim_, унок_, --,
   {{0x249600cd,0xedf90033,0xa3cc00c3,0x248000bc}},	//   ینید_, _আকাশ_, _लाद_, _piim_,
   {{0xe29a5153,0x04460c5b,0x22585154,0xd83800d3}},	//   лам_, семн, work_, _кэч_,
   {{0xe60e5155,0x734900ae,0x7bdb0361,0x00000000}},	//   _ед_, ачёв_, _mbuu, --,
   {{0x6ec100b6,0x7afb18c7,0x00000000,0x00000000}},	//   _लमजु, _mrut, --, --,
   {{0xdb005156,0x016606c4,0x14db0096,0x7bdb0361}},	//   _remí, скво, _बहिण, _obuu,
   {{0xa3ba1a37,0xdfd20190,0x614300d3,0x60180031}},	//   _صابر_, ثير_, чеса, _ríms,
   {{0x92b61363,0xa06702b3,0x7afb0174,0x386f01ec}},	// [4820] _احبا, сата_, _nrut, _mhgr_,
   {{0x7bdb3fdc,0xa3d40034,0xdcfc5157,0x601801f9}},	//   _abuu, स्र_, _agrā, _címr,
   {{0x60de0222,0xa63a00c1,0x7afb5158,0x7bdb0172}},	//   _uppm, נגער, _arut, _bbuu,
   {{0x44225159,0x26c40009,0x20f800c4,0xd00a0236}},	//   nkk_, yumo_, _iči_, _семе_,
   {{0x7afb006b,0x20f8033b,0xdb000165,0xcf9300ca}},	//   _crut, _hči_, _temí, _מטר_,
   {{0xed5a3035,0x6d430080,0xa8a63f37,0x7bdb06b0}},	//   _бог_, únac, брик, _ebuu,
   {{0x7afb515a,0x00000000,0x00000000,0x00000000}},	//   _erut, --, --, --,
   {{0x7afb515b,0x69cd2a29,0x26c4515c,0x7bdb0065}},	//   _frut, _साथी, tumo_, _gbuu,
   {{0x7afb0a84,0xfaa3515d,0xdb000131,0xdb0e007b}},	//   _grut, _нато, _demã, äjäl,
   {{0x26c4515e,0xba23515f,0x69da0027,0x44220113}},	//   rumo_, _едук, _ubte, ekk_,
   {{0x8afd00b6,0xba3d02c6,0x00000000,0x00000000}},	//   _vyře, _tvůr, --, --,
   {{0x69d85160,0x6603010a,0x3eb2007b,0x6e3e0381}},	//   lfve, _ennk, ksyt_, hipb,
   {{0xcc3b00c1,0x7c220062,0xdcfc009e,0x25080421}},	//   רעכט, ikor, _ferħ, _چربی_,
   {{0x69ca3318,0x7c220324,0x77623dbb,0x44225161}},	//   ngfe, hkor, _iyox, akk_,
   {{0x463b00c1,0x7c225162,0x765a5163,0x2444013c}},	//   _געגע, kkor, moty, zımi_,
   {{0xef990293,0x00000000,0x00000000,0x00000000}},	//   ркаш_, --, --, --,
   {{0x44295164,0x7c225165,0xe8090179,0x63af0034}},	// [4830] _ila_, dkor, वाता_, macn,
   {{0x44292e05,0xf1a713c0,0x3e6f00bc,0x69d801cb}},	//   _hla_, _урин, küte_, jfve,
   {{0x7afb009b,0x4429057a,0x7c2b02a1,0x38950325}},	//   _srut, _kla_, thgr, _kāre_,
   {{0x7afb5166,0x237f04a3,0x61e75167,0x44290141}},	//   _prut, žuju_, lejl, _jla_,
   {{0x69c40d04,0xd90f12eb,0x6e9516bd,0x443b0036}},	//   _राखी, کیا_, _фигу, _mmq_,
   {{0xdb000072,0x44295168,0x6e9410a6,0xdb0b014b}},	//   _admó, _lla_, _хиру, nagé,
   {{0x44295169,0x1b170081,0xec6b0a7c,0x442200d6}},	//   _ola_, _দেশে_, _брак_, ykk_,
   {{0xe739516a,0x44290d79,0x7c220149,0x1bd416de}},	//   ией_, _nla_, ckor, _нося,
   {{0x7c3b516b,0x7afb1f1a,0x7c29516c,0x6f0d00b3}},	//   _imur, _urut, _iler, nxac,
   {{0x4429516d,0xc8ab0465,0x644d0918,0x765a516e}},	//   _ala_, _бъде_, _ajai, goty,
   {{0x4429516f,0xf3e60d47,0x7c295170,0x67d502ec}},	//   _bla_, ожно, _kler, _можу,
   {{0x7bcb0496,0x443b008f,0xc20900a1,0x60c700c4}},	//   nggu, _cmq_, _בה_, dujm,
   {{0x44290d1b,0x7c290113,0x61e70103,0x7c3b0090}},	//   _dla_, _mler, fejl, _mmur,
   {{0x44292e79,0x765a0113,0x7c225171,0xdb0b00fd}},	//   _ela_, coty, zkor, gagé,
   {{0x7c3b5172,0x7c295173,0x71760037,0x44220063}},	//   _omur, _oler, زهرا, pkk_,
   {{0x7c290129,0xf1db00b6,0x7c220062,0x00000000}},	//   _nler, म्बन, xkor, --,
   {{0xf99f0019,0xfe052231,0x69dc0103,0xdb0b001c}},	// [4840] _đèn_, रांस_, _öreg, bagé,
   {{0xdb000074,0x26c203ce,0x7c3b0a75,0x442900cc}},	//   _nemá, škog_, _amur, _zla_,
   {{0x20f800cc,0x7c225174,0x7c295175,0x41770103}},	//   _uči_, tkor, _bler, _واپس,
   {{0xab664d1a,0x228f0491,0x6f0d002b,0x65630f5a}},	//   овел, _yük_, bxac, _mynh,
   {{0x3ce60220,0xaca40065,0x65630537,0x19941974}},	//   ňov_, _ilọp, _lynh, паля,
   {{0x7c225176,0x7c295177,0xdca60f32,0xceb400a7}},	//   skor, _eler, _маги, msə_,
   {{0x7c290c2e,0x082a5178,0xdb0009b3,0xc27b00ca}},	//   _fler, иции_, _demá, ברסי,
   {{0xd6da064f,0xdb0005fe,0xc5b40033,0x7c295179}},	//   ато_, _temà, জ্ঞপ, _gler,
   {{0x6996013d,0x63af0a39,0xceb400a7,0xaa4600ae}},	//   _дрех, vacn, nsə_, _деал,
   {{0x44290ab2,0x9f423a4c,0x00000000,0x00000000}},	//   _sla_, _bakú_, --, --,
   {{0x4429517a,0xa3cc0251,0x656302ad,0xafdb004d}},	//   _pla_, _लाश_, _cynh, _kjøt,
   {{0x9f4b00d4,0x6a6400ee,0x1e1708c0,0x6563517b}},	//   _sací_, dòfi, _दक्ष_, _dynh,
   {{0x442909a3,0x28132729,0x48f400b6,0xdb090381}},	//   _vla_, _تونس, ्मको_, _reeë,
   {{0x44290d1f,0xe5340ab3,0x60180428,0x854600ae}},	//   _wla_, _нель, _símp, _мэйе,
   {{0x4429517c,0x65630150,0xdb0b020d,0x644d084e}},	//   _tla_, _gynh, ragé, _tjai,
   {{0x363400bf,0x1ddd04dd,0x4429517d,0x6f0d0428}},	//   _برچس, न्नत, _ula_, txac,
   {{0x645d517e,0x2d870087,0x63ad01b9,0x23280284}},	// [4850] mosi, žnem_, _iean, _моћи_,
   {{0x645d517f,0xdd9b5180,0x60c70357,0xc33200ca}},	//   losi, рша_, pujm, _נוי_,
   {{0x63ad3695,0x69c413ae,0xdb000072,0x6018002b}},	//   _kean, _राजी, _remá, _tímp,
   {{0x645d5181,0x515a00a1,0xdb0022a4,0x68ed0034}},	//   nosi, _לכתו, _semá, ładk,
   {{0xfaa50465,0x7c295182,0x63ad00a1,0x62855183}},	//   чало, _vler, _mean, _kiho,
   {{0x62855184,0x645d0150,0xa3e20455,0x7e7900c1}},	//   _jiho, hosi, _नॉन_, _לאָז,
   {{0xa3cc0e72,0x645d5185,0x62850ebd,0x20195186}},	//   _लाल_, kosi, _miho, _kosi_,
   {{0x1bb81dec,0x7c3b5187,0x62855188,0x63ad5189}},	//   _واقع_, _umur, _liho, _nean,
   {{0xdb001f9f,0xd7060084,0x2019518a,0xafdb02b6}},	//   _temá, зные_, _mosi_, _imød,
   {{0x6285518b,0xe809074c,0x6618023e,0xdb00052f}},	//   _niho, वाहा_, _covk, _bemæ,
   {{0x63ad518c,0x1ddd0bd9,0x6fcb0096,0x645d518d}},	//   _bean, न्यत, िलां, fosi,
   {{0x63ad328f,0x628501ff,0x6aa94a16,0xd9c60033}},	//   _cean, _aiho, _kwef, _এসএম,
   {{0x63ad09f7,0x6285518e,0x59d20efd,0x050b0033}},	//   _dean, _biho, _सामर, শনের_,
   {{0x1dc72b71,0xf7700d74,0x877a00c1,0xf67500c1}},	//   _लागत, _شان_, _פאסי, _צײַט_,
   {{0x7641518f,0x62852fc5,0x63ad5190,0x20195191}},	//   mily, _diho, _fean, _bosi_,
   {{0x20195192,0x63ad5193,0xa3ad0c54,0x6b895194}},	//   _cosi_, _gean, गरण_, _ngeg,
   {{0x20195195,0x6285003d,0x6fad08d4,0x1b200033}},	// [4860] _dosi_, _fiho, _ज़रू, _মেনে_,
   {{0xceb40092,0x6b895196,0x0e631402,0x62855197}},	//   rsə_, _ageg, екун, _giho,
   {{0x20190090,0xceb400a7,0x2bfd00bc,0x00000000}},	//   _fosi_, ssə_, _रोहू_, --,
   {{0x20190129,0x6aa906b0,0x62855198,0x59c900b7}},	//   _gosi_, _bwef, _ziho, _राउर,
   {{0x76415199,0x41d30b94,0x628503a5,0xab830fe9}},	//   kily, _तामस, _yiho, нушк,
   {{0x7848000d,0x69d50b88,0x3ea01bd6,0xa8a64717}},	//   pěvk, _özel, mpit_, прик,
   {{0xfce30581,0x645d519a,0x2d8a37dc,0x201912f5}},	//   _поро, yosi, _igbe_, _yosi_,
   {{0x25ee007d,0xafdb038c,0xd83800d8,0x00000000}},	//   _असही_, _hjør, _otče_, --,
   {{0xae20000f,0x2bd102e8,0x96f828dc,0xafdb02ec}},	//   _मकान_, _हाता, цепт_, _kjør,
   {{0x63ad519b,0x3ea04a00,0xddce02a1,0x984e0233}},	//   _sean, ipit_, _nibż, rşın_,
   {{0xa96a14df,0x645d519c,0x63ad519d,0x2d8a0857}},	//   _امام_, tosi, _pean, _mgbe_,
   {{0xb8652761,0x9f40519e,0x69dc0149,0x6285519f}},	//   _قانو, ndió_, _öreb, _siho,
   {{0xe80900af,0x628551a0,0x81c80081,0x764151a1}},	//   वारा_, _piho, োজন_, bily,
   {{0x321a00ca,0xdcf700a7,0x997e020a,0x4b4e0294}},	//   _copy_, zaxı, căţi_, lụsọ_,
   {{0x63ad006b,0x645d51a2,0x201951a3,0x92cd0081}},	//   _tean, posi, _posi_, রবে_,
   {{0x2d8a0af0,0x2d980154,0x6ee20134,0x65c20139}},	//   _agbe_, _afre_, _ọbag, _fíhà,
   {{0x628551a4,0xafdb51a5,0x3ea00bb6,0x74ae0081}},	// [4870] _tiho, _bjør, gpit_, _কমিউ,
   {{0x9f4b0231,0xc5f800e8,0x6b89009c,0x2d98033c}},	//   _cacá_, ndē_, _sgeg, _cfre_,
   {{0x40351f37,0xa3d4097c,0x20190084,0x8cc402d5}},	//   _женс, स्क_, _tosi_, ांगो,
   {{0x224326f1,0x764151a6,0x7a2f00d6,0x8d741a37}},	//   lijk_, zily, _møte, رالا,
   {{0xdcf70092,0xb6a30023,0xafdb004d,0x20d751a7}},	//   raxı, _chấ, _fjør, lçi_,
   {{0xafdb02ec,0x00000000,0x00000000,0x00000000}},	//   _gjør, --, --, --,
   {{0xe80917ff,0x23bf0da9,0x20d751a8,0x00000000}},	//   वाला_, ्लाद, nçi_, --,
   {{0xccf20054,0xf8dd0285,0xdb0017a5,0x764100f0}},	//   _בכל_, _महीप, _bemä, wily,
   {{0x22430505,0x997e002d,0x764151a9,0xaad10569}},	//   kijk_, tăţi_, tily, _समिक,
   {{0x20d7008b,0x7a2f0120,0x00000000,0x00000000}},	//   kçi_, _bøte, --, --,
   {{0x764151aa,0xa3ea2ca3,0xa25b0396,0x224301c0}},	//   rily, одна_, trôn, dijk_,
   {{0x4ad141f2,0xdd1c0220,0xaad10285,0xd6ce001c}},	//   _समाव, náša, _समाक, دقی_,
   {{0xdb0001bf,0x764107ac,0x00000000,0x00000000}},	//   _gemä, pily, --, --,
   {{0x7a2f01df,0x14c53ec4,0x00000000,0x00000000}},	//   _føte, _विपण, --, --,
   {{0xa3cc007d,0x3eb90113,0x7a2f0170,0x987d0342}},	//   _लाऊ_, _avst_, _gøte, lçın_,
   {{0x98a700a5,0x60c101cd,0xafdb0b81,0x00000000}},	//   czną_, álma, _sjør, --,
   {{0x61f751ab,0x321a109b,0x4477006e,0x85050103}},	// [4880] _faxl, _topy_, _קעפל_, _روکن,
   {{0x3ea051ac,0xae0e2231,0xdddc00c6,0x00000000}},	//   rpit_, साधन_, _birš, --,
   {{0x3ea0026a,0xe8032cca,0x00000000,0x00000000}},	//   spit_, _शोभा_, --, --,
   {{0xdca3204e,0x0ea90b94,0x0b4651ad,0x6fb20034}},	//   таци, _चौकड, мнен, _ज़िं,
   {{0x25ee0e72,0x8db602ec,0x5f0600c6,0xa3cc3b08}},	//   _असली_, _осві, _ўзга, _लाई_,
   {{0x2cb80995,0x1ddd142e,0x00000000,0x00000000}},	//   _tvrd_, न्दत, --, --,
   {{0x2611121d,0x35a7000f,0xafdb02ec,0xda6500e3}},	//   तानी_, _ग़ज़, _kjøp, راهي,
   {{0x7d0301c5,0xb6a30023,0xc7c61543,0x7d1800f2}},	//   ænse, _thấ, фски, øvsu,
   {{0xc6f71736,0x78ad1419,0x6b63141b,0xe7bf1981}},	//   дных_, ćava, _акта, _एयरप,
   {{0x6aa2019f,0x00000000,0x00000000,0x00000000}},	//   mpof, --, --, --,
   {{0x994a0e25,0x6e2000ae,0x00000000,0x00000000}},	//   _بلال_, _îmbu, --, --,
   {{0x61f701d4,0x22430126,0x69da1e9f,0xf3ff0231}},	//   _saxl, wijk_, प्री, rlão_,
   {{0xd838022b,0x25ae1881,0xdb00032e,0xe298013f}},	//   _dwčt_, _tefl_, _femå, маў_,
   {{0x20d703a3,0x785300ae,0x7d030212,0x88c702c6}},	//   tçi_, măva, ånsk, spěš,
   {{0x22430ab2,0xf194510e,0xd01b2b16,0x00000000}},	//   rijk_, тись, офа_, --,
   {{0x4ea70a28,0xd6f20be4,0x20d751ae,0x6d430076}},	//   држа, _अनाथ_, rçi_, únam,
   {{0xceff0033,0x799a0381,0x20d7028e,0x00000000}},	// [4890] ৃন্দ_, _oftw, sçi_, --,
   {{0x2489006c,0xff0400c2,0x7c3a0138,0xdddc0138}},	//   _hiam_, ъясн, _įtra, _pirš,
   {{0x24890154,0x644f028d,0x224101ff,0x00000000}},	//   _kiam_, onci, _imhk_, --,
   {{0xdddc01b3,0x447c00c1,0xdfa700e3,0x25e502d5}},	//   _virš, ַנגע, _تحدي, _जॉनी_,
   {{0xa3d40714,0xd6c60f43,0x644f0037,0x45140033}},	//   स्ट_, _حق_, inci, ানিক_,
   {{0x248951af,0x9f4200b6,0x661c0212,0xdea4001c}},	//   _liam_, _jaký_, örkl, _شیمی,
   {{0x9f400088,0x1b1700c7,0x24890063,0xe9460018}},	//   ldið_, _দেখে_, _oiam_, ٹروی,
   {{0x248901bb,0x3e7401bf,0xa25b0231,0x00000000}},	//   _niam_, räte_, drôm, --,
   {{0xf6250747,0x9f400102,0x236951b0,0x0685007e}},	//   едпо, ndið_, _nyaj_, нгин,
   {{0xa3e20851,0x644f22a4,0xe6110037,0x69de00aa}},	//   न्न_, enci, اشة_, õpet,
   {{0xb7d50065,0xd46a4223,0x693402a0,0x00000000}},	//   _aṣet, зине_, _инфу, --,
   {{0x2489022e,0x2c750537,0x00000000,0x00000000}},	//   _ciam_, både_, --, --,
   {{0xe72e064f,0x27ed10c4,0x248951b1,0x87270e5a}},	//   _се_, meen_, _diam_, _تعام,
   {{0x27ed51b2,0x200b006d,0x2369022b,0x644f51b3}},	//   leen_, _anci_, _dyaj_, anci,
   {{0xafe60978,0x50b543a9,0x12d00081,0x42d00081}},	//   новл, ксту, িবেদ, িবেশ,
   {{0x27ed51b4,0x248900de,0x6b9b0361,0x00000000}},	//   neen_, _giam_, _nfug, --,
   {{0x644651b5,0x15f300b6,0x00000000,0x00000000}},	// [48a0] miki, _असार_, --, --,
   {{0x27ed51b6,0x6b9b0517,0xd12f0018,0x682e009c}},	//   heen_, _afug, جمہ_, _mùda,
   {{0x61d70132,0x27ed51b7,0x61ee51b8,0x682e01b9}},	//   _אויף_, keen_, mebl, _lùda,
   {{0x644651b9,0x248901fa,0xdb1b0610,0xfe0e049d}},	//   niki, _xiam_, _acuñ, साहस_,
   {{0xa3e205cd,0x27ed51ba,0x59f82dfb,0xe803009d}},	//   न्य_, deen_, деля_, _शोधा_,
   {{0x644651bb,0x61ee51bc,0x61fc51bd,0x6b9b06b0}},	//   hiki, nebl, ndrl, _efug,
   {{0x644651be,0x88580a95,0x7e7e00f9,0xed574532}},	//   kiki, микс_, mmpp, _зор_,
   {{0x683e0029,0x27ed51bf,0x6446198d,0xa3cc007a}},	//   līdz, geen_, jiki, _लाग_,
   {{0x644651c0,0xc5f80029,0x2489022e,0x26010ccb}},	//   diki, klēt_, _riam_, _वोही_,
   {{0x2c752ca7,0x61ee51c1,0x682e009c,0x601801f9}},	//   råde_, jebl, _dùda, _címz,
   {{0xa3cc00e2,0x644651c2,0x27ed008a,0x2489006c}},	//   _लाख_, fiki, been_, _piam_,
   {{0x64460193,0x27ed008a,0x248951c3,0x682e01b9}},	//   giki, ceen_, _qiam_, _fùda,
   {{0x24890231,0x644f01cb,0x00000000,0x00000000}},	//   _viam_, rnci, --, --,
   {{0x61ee042c,0xf10c0285,0x5187001f,0x00000000}},	//   gebl, हमूद_, еуба, --,
   {{0x2bd105d4,0x248901bb,0x644651c4,0x00000000}},	//   _हाला, _tiam_, biki, --,
   {{0x63a903be,0x644651c5,0x2489061d,0x68fc0131}},	//   ñend, ciki, _uiam_, _árdu,
   {{0x9df915ef,0xe7e231f4,0x9f420220,0xc2750da5}},	// [48b0] мнат_, क्या_, _taký_, _илиј,
   {{0x6b9b00e5,0x04b70018,0x61ee51c6,0x27ed01c8}},	//   _sfug, _تھیں_, cebl, zeen_,
   {{0x27ed025e,0x26110285,0x00000000,0x00000000}},	//   yeen_, ताती_, --, --,
   {{0x09c92183,0x27ed51c7,0x683e00c6,0x442b0357}},	//   रल्य, xeen_, būdi, nkc_,
   {{0x27ed3312,0x9f590052,0x00000000,0x00000000}},	//   veen_, _masë_, --, --,
   {{0x644651c8,0xceb200c1,0xa9693340,0xd945007e}},	//   ziki, _דיך_, мила_, кели,
   {{0x27ed51c9,0x644651ca,0xed150068,0xa3e205a5}},	//   teen_, yiki, _جہاں_, न्ड_,
   {{0x6e2000ae,0x644601e9,0x6b9b0239,0xd70900c2}},	//   _îmbr, xiki, _ufug, дние_,
   {{0x27ed51cb,0x03ec0081,0x644651cc,0x68470113}},	//   reen_, য়ামী_, viki, _aèdè,
   {{0x27ed51cd,0x3866005a,0x26c302dd,0x7c2b0149}},	//   seen_, _ekor_, čjo_, lkgr,
   {{0x644651ce,0x853c013f,0x69c151cf,0x03a6182e}},	//   tiki, lbėj, _idle, кино,
   {{0x61aa0569,0x61e5036b,0x27ed0188,0x044651d0}},	//   कर्ष, _abhl, qeen_, темн,
   {{0x386d51d1,0x26cd04d8,0xdb091ba6,0x64461aa3}},	//   mler_, queo_, _ideó, riki,
   {{0x644651d2,0x66820018,0x387f51d3,0x7ae60212}},	//   siki, _پیپل, lmur_, _äkte,
   {{0x386d1081,0xa06a02b3,0x9f4205aa,0x4f96001f}},	//   oler_, дава_, _nakò_, врзу,
   {{0x386d0b88,0x7ae90084,0x70e213db,0x61ee0185}},	//   nler_, _opet, _पहील, sebl,
   {{0xa0670478,0xc7b207a6,0x60dc51d4,0x69c106e9}},	// [48c0] тата_, יבן_, strm, _odle,
   {{0x386d02e2,0xdee31312,0x442051d5,0x69c10201}},	//   hler_, рофи, _hoi_, _ndle,
   {{0x386d51d6,0x387f2d96,0xf76751d7,0xdb090072}},	//   kler_, kmur_, _چا_, _odeó,
   {{0x4420002d,0xf7671850,0x351a00c1,0x69c1133e}},	//   _joi_, _نا_, ווענ, _adle,
   {{0x80e20d0b,0x442051d8,0x386d51d9,0x7c2903e5}},	//   _पहुं, _moi_, dler_, _ċert,
   {{0x442051da,0xa3e234d8,0x386d51db,0x7875013f}},	//   _loi_, न्त_, eler_, _išvy,
   {{0x644451dc,0x386d51dd,0x6e431a9c,0xc6c30081}},	//   _omii, fler_, _терз, ্বোচ,
   {{0x442051de,0x386d16f4,0xc6f825ab,0x764351df}},	//   _noi_, gler_, ених_, _amny,
   {{0xa3cc262c,0x7c2001b5,0xf76f0037,0xdb0b51e0}},	//   _लाज_, _iomr, ياً_, pagá,
   {{0xceb300a1,0x44200037,0x35e300d6,0x64442696}},	//   סית_, _aoi_, ацюв, _amii,
   {{0x386d17d2,0x44320665,0xd7ef016a,0x2905042d}},	//   bler_, _bly_, _ку_, _grla_,
   {{0x442051e1,0x644400a4,0x6d4300e3,0x07a60831}},	//   _coi_, _cmii, únai, _радн,
   {{0xa3e200c0,0x27e651e2,0x442000ca,0x00000000}},	//   न्ध_, _ibon_, _doi_, --,
   {{0x442051e3,0xb7d50032,0x7c200503,0x00000000}},	//   _eoi_, _iṣat, _lomr, --,
   {{0x44201371,0x443251e4,0x764851e5,0x00000000}},	//   _foi_, _fly_, midy, --,
   {{0xceb40253,0x442051e6,0xa3e200af,0xfa000033}},	//   yyət_, _goi_, न्द_, ্সটল_,
   {{0x09ca00c7,0xda020096,0xcddb0284,0x00000000}},	// [48d0] ল্যা, लयात_, дње_, --,
   {{0xe7e21fb4,0x386d0587,0x387f51e7,0x05140033}},	//   क्ता_, zler_, zmur_, ানীর_,
   {{0x7ae951e8,0x386d01e8,0x2d8731da,0xee8451e9}},	//   _spet, yler_, äne_, рыто,
   {{0xd0110037,0x00000000,0x00000000,0x00000000}},	//   _الح_, --, --, --,
   {{0x7c2b1cab,0x386d51ea,0x764800f9,0xdd1c0206}},	//   rkgr, vler_, kidy, _vášm,
   {{0x386d51eb,0x27e6060f,0x853c0138,0xcda90f98}},	//   wler_, _abon_, rbėj, _سهره_,
   {{0x386d5127,0xb7d50065,0x18692de2,0xbd6800d3}},	//   tler_, _aṣat, наки_, _арте_,
   {{0xb8db0971,0x386d51ec,0x387f01cd,0x00000000}},	//   _अब_, uler_, umur_, --,
   {{0x442051ed,0x386d51ee,0x3b5551ef,0x7643023e}},	//   _roi_, rler_, _скар, _pmny,
   {{0x69c101c5,0x386d51f0,0x442051f1,0x7c200220}},	//   _udle, sler_, _soi_, _zomr,
   {{0xc3291541,0xb7d52761,0x44200465,0x386d047e}},	//   _צו_, _مقاب, _poi_, pler_,
   {{0xe7b7063c,0x27e60032,0x889a00ca,0x7a3400ee}},	//   _इजिप, _gbon_, _טבעי, _vàte,
   {{0x442051f2,0xe2972ba6,0x27fd02ad,0x55e50077}},	//   _voi_, лая_, _iawn_, _болб,
   {{0x27fd03e5,0x4420005c,0x27ff0a00,0x68350072}},	//   _hawn_, _woi_, ldun_, _dáde,
   {{0x442051f3,0x63a90072,0xd8380154,0x629903a9}},	//   _toi_, ñenc, _otčl_, _éwon,
   {{0x644400a6,0x69cd0336,0x00000000,0x00000000}},	//   _umii, _साझी, --, --,
   {{0x67291c35,0x27ff51f4,0x7d0302b6,0x673b00d8}},	// [48e0] nyej, idun_, ænsn, nzuj,
   {{0xc3330054,0x2482005c,0x62960124,0x63b651f5}},	//   _לוח_, lmkm_, _iuyo, _heyn,
   {{0x63b651f6,0x7c2009ac,0x6296024a,0x683500d2}},	//   _keyn, _pomr, _huyo, _záde,
   {{0x62961f6e,0x3cf800b3,0x67290172,0x00000000}},	//   _kuyo, _vsrv_, kyej, --,
   {{0x61fe51f7,0x4af827c9,0x682e01b9,0x27ff51f8}},	//   _kapl, телю_, _dùdl, ddun_,
   {{0x673b0220,0x63b651f9,0x2ee00085,0x62962cd0}},	//   dzuj, _leyn, mtif_, _muyo,
   {{0x76480383,0x2000008a,0x7c202c28,0xb33b00a7}},	//   vidy, odii_, _tomr, rbçi,
   {{0x26c202e6,0x61fe02f1,0x76aa455f,0x6d5c00a7}},	//   škom_, _lapl, нтов_, _ixra,
   {{0x2ee045b0,0x963423bf,0x764829f2,0x9f592f35}},	//   ntif_, иниц, tidy, _pasé_,
   {{0x14ca02fd,0xa3e2034d,0x7d07002b,0x00000000}},	//   ными_, न्स_, _yrjs, --,
   {{0xb99318a9,0x63b6051d,0xd7e600d6,0x87e6416d}},	//   _المب, _beyn, _біло, _бюле,
   {{0x6f040995,0x629618b1,0x87060260,0x61fe51fa}},	//   kvic, _buyo, _مبتل, _aapl,
   {{0xfe0404dd,0x2000025e,0x051400c7,0x6296058a}},	//   रयास_, ddii_, ানের_, _cuyo,
   {{0x62962430,0x9f4b0037,0x6f0451fb,0x20000188}},	//   _duyo, _tacú_, dvic, edii_,
   {{0x61fe51fc,0xd5b80029,0x261151fd,0xa3e245c8}},	//   _dapl, skās_, तारी_, न्ह_,
   {{0x62960063,0x506717c5,0x63b6008c,0x645d014b}},	//   _fuyo, утга, _geyn, érid,
   {{0x629651fe,0x3da70058,0x61fe02ac,0x2ca30231}},	// [48f0] _guyo, греб, _fapl, _stjd_,
   {{0x61fe51ff,0x63b60491,0x68fa02db,0x00000000}},	//   _gapl, _zeyn, _ostd, --,
   {{0x2ee00d17,0xe817000d,0xe7f900b6,0x8234001c}},	//   atif_, थामा_, ्यमा_, _دريا,
   {{0x3e970037,0x69da5200,0xaed51907,0x2000008c}},	//   _مؤسس, _acte, _комш, cdii_,
   {{0x2ee05201,0x26c2084f,0x3d95004d,0x6f0400d4}},	//   ctif_, škoj_, _вигр, cvic,
   {{0x3ea903b4,0xdd940138,0x6925028d,0xab262348}},	//   mpat_, _гары, имла, роша_,
   {{0x44395202,0x3ea95203,0x68352c85,0x2d85014b}},	//   khs_, lpat_, _nádc, _àle_,
   {{0x26df028d,0xec685204,0x00000000,0x00000000}},	//   ttuo_, _брук_, --, --,
   {{0x63b60102,0xa3d90d7e,0xdb260068,0xe7390231}},	//   _reyn, ालन_, _پولی, теп_,
   {{0x63b65205,0x673b02c6,0x62960079,0x3ea915d3}},	//   _seyn, rzuj, _ruyo, ipat_,
   {{0x62962f35,0x6729023b,0x20000188,0x61fe5206}},	//   _suyo, syej, ydii_, _rapl,
   {{0xe29a5207,0x63860d5e,0x62965208,0x2000008a}},	//   кам_, игна, _puyo, xdii_,
   {{0x61fe22bb,0x63bb003e,0x8c1a0327,0x43760db2}},	//   _papl, ðuna, דורי, рунт,
   {{0x63b6008a,0x6f040451,0xdb0000d4,0x00000000}},	//   _weyn, vvic, _nemý, --,
   {{0x602619e0,0x216a13b2,0x443901ec,0x00000000}},	//   адва, тиви_, bhs_, --,
   {{0x32040067,0x44395209,0x3db20081,0x6296520a}},	//   śmy_, chs_, _চাইল, _tuyo,
   {{0x645d520b,0x00000000,0x00000000,0x00000000}},	// [4900] érie, --, --, --,
   {{0xee37131b,0x2ee0520c,0x35dd0aa1,0xa2bb006e}},	//   ану_, rtif_, _माफ़, _שמיט,
   {{0x7afb520d,0x3ea906a8,0x2ee0014b,0xf41f00bc}},	//   _asut, apat_, stif_, smäe_,
   {{0xa3d906e4,0x2ee0520e,0x2000008c,0x26c201f9}},	//   ालय_, ptif_, qdii_, ákok_,
   {{0x539b00ca,0x00000000,0x00000000,0x00000000}},	//   דינו, --, --, --,
   {{0x98c61b77,0x7a340441,0x7bdb0172,0x26cd01b9}},	//   асил, _bàta, _ecuu, dreo_,
   {{0x7a3400ee,0x7afb520f,0x2d9c0103,0x00000000}},	//   _càta, _esut, űves_, --,
   {{0x5886004b,0xb8fe02d5,0xb8ce05a7,0x4814430b}},	//   шыла, _तम_, _कऽ_, смис,
   {{0xe7e200e2,0xfaa302f3,0xdb1903a9,0x00000000}},	//   क्षा_, _мато, jawè, --,
   {{0xb3b00033,0x00000000,0x00000000,0x00000000}},	//   _কাগজ, --, --, --,
   {{0x0d9700a1,0xd82f2529,0x7ae25210,0x44391b68}},	//   יכים_, _дэ_, ltot, ths_,
   {{0x66e62ac1,0x26cd5211,0xe7860012,0x62980106}},	//   _вода, breo_, _куло, _čvor,
   {{0x7ae25212,0x26cd0328,0xc458007b,0xa3d900c3}},	//   ntot, creo_, риях_, ालब_,
   {{0x05dd02e8,0xb7e21117,0xe7f91da8,0x443900fc}},	//   _मायब, क्रम_, ्यथा_, shs_,
   {{0x68350146,0x389501d3,0x7ae20329,0x44395213}},	//   _háda, _pāri_, htot, phs_,
   {{0x3ea95214,0x5f4500e3,0xdb000364,0x251b5215}},	//   tpat_, منزل, _bemü, _יווא,
   {{0xdb005216,0xe7f905cd,0x3ea95217,0x06f8007f}},	// [4910] _memó, ्यता_, upat_, ्टिव_,
   {{0x63bd5218,0x313541b1,0x3ea95219,0xf41f00c2}},	//   lasn, _геор, rpat_, ljä_,
   {{0x03ec0081,0x7c3917c4,0x26cd0580,0x7ae201d3}},	//   য়ারী_, thwr, zreo_, etot,
   {{0x3ea9521a,0xa2ce0640,0x69d824e7,0x61f5521b}},	//   ppat_, _तिम्, egve, lezl,
   {{0x09df00c7,0xdb0001bf,0xee87163d,0x7ae20eac}},	//   _যোগা, _gemü, _выво, gtot,
   {{0x44c40032,0x6ca74936,0x63bd521c,0xf41f007b}},	//   _ajọṣ, _враж, hasn, hjä_,
   {{0x63bd03ce,0xd90f0260,0x2ef50092,0x261a2748}},	//   kasn, بیا_, şafı_, बानी_,
   {{0x9b8900b1,0x26cd0072,0x7afb03e3,0x7ae2211d}},	//   _منزل_, treo_, _tsut, btot,
   {{0x63bd04a3,0xdb0041b7,0x68350072,0x1dcb0d88}},	//   dasn, _demó, _cáda, ाणपत,
   {{0x26cd11c4,0xa2ce045f,0x63bb0088,0x645e007e}},	//   rreo_, _तिब्, ðunn, čsim,
   {{0x26cd1197,0x63bd521d,0xd549110c,0x00000000}},	//   sreo_, fasn, упне_, --,
   {{0xd79500e3,0x60d50335,0xa4160033,0x74160033}},	//   _الإخ, duzm, াস্য_, াস্ট_,
   {{0x320100f9,0x3a2500bd,0x06d50033,0xd34800d1}},	//   _bahy_, _kolp_, _তৈরি, شیده_,
   {{0xe2972fec,0xdb19001c,0xc692006e,0xdb000154}},	//   сар_, gawé, _זאג_, _kemò,
   {{0x63bd09a4,0x41a900b6,0x00000000,0x00000000}},	//   basn, _कभरस, --, --,
   {{0xdb0005fe,0x7ae200fc,0x35dd00c3,0x00000000}},	//   _memò, ytot, _माड़, --,
   {{0xe7e90454,0x63a4521e,0x3201033c,0x00000000}},	// [4920] झ्या_, _ifin, _fahy_, --,
   {{0x60c901d3,0x00000000,0x00000000,0x00000000}},	//   ņema, --, --, --,
   {{0x23be0034,0xb7f9521f,0x019700ca,0x00000000}},	//   _्याद, ्याम_, _לכיש_, --,
   {{0x7ae25220,0x7ff62ce3,0xdee61eb9,0x00000000}},	//   ttot, _اسدا, _ломи, --,
   {{0xa3d907e2,0x853c013f,0xdb000042,0x63a40171}},	//   ालत_, lbėt, _remó, _mfin,
   {{0x7ae25221,0x2002068d,0x3e3609b4,0xbea316dd}},	//   rtot, _haki_, _افسر, _харк,
   {{0x20020496,0x63a408dd,0xf41f0084,0x69d84c28}},	//   _kaki_, _ofin, yjä_, rgve,
   {{0x6d5700c1,0x200200a5,0xdb00015e,0x7d5700ca}},	//   _הילף_, _jaki_, _demò, _הילד_,
   {{0x368a02e1,0x3b075222,0x501b00a1,0x9f49003e}},	//   лсон_, _лето_, רופו, ndað_,
   {{0x20025223,0x63a40145,0x63bd5224,0x3a2500f9}},	//   _laki_, _afin, wasn, _golp_,
   {{0xe85303ed,0x63bd5225,0x69c84219,0xdb00002b}},	//   _کنند, tasn, _idde, _temó,
   {{0x24805226,0x491700a1,0x20025227,0xb97b0266}},	//   _chim_, _לקבל_, _naki_, _גנבי,
   {{0x63a40124,0xb8651629,0x7a340065,0x61f529e4}},	//   _dfin, _بالو, _jàto, tezl,
   {{0x290c00e7,0x63a45228,0xe5340bd5,0x9f4b0103}},	//   _krda_, _efin, _мель, ámít_,
   {{0x20025229,0xdddc522a,0x25dd007a,0x63a4522b}},	//   _baki_, _birž, _खाती_, _ffin,
   {{0x2002522c,0x25be0124,0xf4850018,0x290c09ac}},	//   _caki_, latl_, _باتی, _mrda_,
   {{0x69c8522d,0x2002522e,0x637f0065,0xdddc0138}},	// [4930] _odde, _daki_, _dàní, _dirž,
   {{0x290c522f,0xdceb0031,0x2007007f,0x7853044c}},	//   _orda_, žiči, śni_, răvi,
   {{0x5f95002d,0x59d20096,0x20025230,0xacf900ae}},	//   _минт, _साजर, _faki_, рнеу_,
   {{0x69db267b,0xfbd000bf,0x69c80054,0x644f411b}},	//   _नाही, فته_, _adde, nici,
   {{0xdc3903e5,0x290c5231,0x683f0065,0x00000000}},	//   għġb, _arda_, _làdù, --,
   {{0x290c08a9,0x20025232,0x644f5233,0x8cbb2eb5}},	//   _brda_, _zaki_, hici, _مدرس_,
   {{0xa3d90714,0x644f1114,0x20021114,0x3a255234}},	//   ाला_, kici, _yaki_, _volp_,
   {{0x09ca00c7,0x69c80517,0x29075235,0x20025236}},	//   ল্লা, _edde, rvna_, _xaki_,
   {{0x25dd17ff,0x290c037a,0x4e0d09b0,0xba550396}},	//   _खादी_, _erda_, _सफाई_, _двај,
   {{0x63a45237,0x24805238,0x0a6b0291,0x7aed50d5}},	//   _sfin, _shim_, _срби_, çatu,
   {{0x24805239,0x6e274289,0xe5710037,0x290c0141}},	//   _phim_, _mojb, بطة_, _grda_,
   {{0x644f025a,0x787e0052,0x546a00c2,0xf1a900ca}},	//   gici, tëve, рамм_, _יס_,
   {{0xe29a523a,0x67d40426,0x645d11e9,0x14c50096}},	//   раг_, _хочу, éria, _विकण,
   {{0xa509523b,0x2002523c,0xe61100d1,0x787e0216}},	//   _века_, _saki_, _زشت_, rëve,
   {{0xf41f02fd,0x2480523d,0x2002523e,0x7bc900fd}},	//   mmän_, _thim_, _paki_, _odeu,
   {{0x6603523f,0xf41f09fc,0xdbf2030b,0x23600197}},	//   _hank, lmän_, _příz, _txij_,
   {{0x7e26185c,0x66035240,0x3e6f0018,0x26c22052}},	// [4940] одаж, _kank, yütt_, škov_,
   {{0x66035241,0x20023cd3,0x7bc92733,0x44225242}},	//   _jank, _waki_, _adeu, ljk_,
   {{0x6835025b,0x20025243,0x9f4b00ee,0x66035244}},	//   _nádo, _taki_, _bacó_, _mank,
   {{0x66035245,0xd00a31f6,0x717b0054,0x44e30062}},	//   _lank, _теме_, _כניס, iñ_,
   {{0xd8381a98,0xda66013d,0x7bc90150,0xab830a54}},	//   _juče_, овди, _ddeu, мушк,
   {{0x683c025a,0xd8380106,0xa8a61ca5,0x3b0d0216}},	//   _méde, _muče_, орик, _dreq_,
   {{0x644f5246,0xed571e46,0x69db08c0,0x683c033c}},	//   yici, _дор_, _नारी, _léde,
   {{0x66035247,0x00000000,0x00000000,0x00000000}},	//   _aank, --, --, --,
   {{0xb5fc03e5,0x7c221e95,0x00000000,0x00000000}},	//   loġi, mjor, --, --,
   {{0x66035248,0x644f00a5,0x69c84fbc,0x290c0117}},	//   _cank, wici, _udde, _trda_,
   {{0x660349bc,0x644f1647,0x2918007e,0x290c5249}},	//   _dank, tici, _šraf_, _urda_,
   {{0x7c22524a,0x660d0022,0xd6d90034,0xd8380128}},	//   njor, _ɗaki, szła_, _buče_,
   {{0x6603524b,0x67560260,0xdddc003d,0x261a00df}},	//   _fank, _بخار, _birż, बादी_,
   {{0x644f3964,0x7e04000c,0x38690039,0x44fa01b6}},	//   sici, रयोग_, čare_, _tū_,
   {{0xe3bf0042,0x69c2136b,0x59df0c38,0xf43500ae}},	//   pañ_, _रजनी, प्टर, _некэ,
   {{0x26c20146,0x60c901d3,0x2d98524c,0x66030141}},	//   škou_, ņemo, _agre_, _zank,
   {{0xdd9b524d,0x9f4b05fe,0x7c22524e,0x260f009d}},	// [4950] аше_, _racó_, djor, _थोडी_,
   {{0x442900ef,0x26c4524f,0x9f4b0487,0x6603013c}},	//   _hoa_, ismo_, _sacó_, _xank,
   {{0x6aa95250,0x442901e9,0x20160181,0x7c2202ec}},	//   _stef, _koa_, ácií_, fjor,
   {{0x44295251,0x7c220e32,0x8ccc0c9c,0x1c0b1b11}},	//   _joa_, gjor, _हिरो, _सोशल_,
   {{0x44295252,0x3b092b99,0x501a0796,0xe47c006e}},	//   _moa_, село_, _הורו, בראכ,
   {{0xceb23629,0x44295253,0x6f0f0036,0x68350206}},	//   _איך_, _loa_, _ircc, _pádo,
   {{0x66035254,0x644d00c2,0x77620372,0x7c225255}},	//   _rank, _omai, _axox, bjor,
   {{0x44295256,0x59d70e72,0x66035257,0x9f40016d}},	//   _noa_, _ठाकर, _sank, ceió_,
   {{0x66035258,0x41dc00a8,0x26c400c6,0x6aa90e37}},	//   _pank, _बालस, gsmo_, _utef,
   {{0x644d5259,0x683c525a,0x3eb901bf,0x7c29525b}},	//   _amai, _réde, _mwst_, _hoer,
   {{0x4429525c,0x7c29525d,0x6603525e,0x7c3b525f}},	//   _boa_, _koer, _vank, _klur,
   {{0x442922e7,0x66035260,0x7c294ae5,0xaacf009f}},	//   _coa_, _wank, _joer, _हटाक,
   {{0x66031679,0x44295261,0x7c2934b3,0x987a0089}},	//   _tank, _doa_, _moer, _פאנט,
   {{0x683c0018,0x249600cd,0x386d04e2,0xd8380106}},	//   _véde, _کنيد_, loer_, _vuče_,
   {{0x7c3b5262,0x28cf023a,0x3eb90150,0xe7e216e2}},	//   _olur, सूचि, _awst_, क्का_,
   {{0xd83801ac,0x644d5263,0xe3ba153d,0x386d5264}},	//   _tuče_, _gmai, _уби_, noer_,
   {{0xe7e31161,0x7d0e04ad,0xee3a0a51,0x2fc05265}},	// [4960] _गाना_, _srbs, бна_, raig_,
   {{0x7c3b5266,0x2fc05267,0x3ea00052,0x9f4b0103}},	//   _alur, saig_, rqit_, ámát_,
   {{0x7c295268,0xa06a0077,0x8fa6293e,0x644d5269}},	//   _boer, _гана_, _нане, _ymai,
   {{0x386d03a9,0xd6d900a5,0x7c29526a,0x7c3b2c98}},	//   joer_, kuł_, _coer, _clur,
   {{0x7c2239ee,0x08e60033,0x68350231,0x386d066a}},	//   rjor, কিছু_, _cádm, doer_,
   {{0x38a3008e,0x7c3b526b,0x7c221075,0x776200bd}},	//   _sıra_, _elur, sjor, _rxox,
   {{0x60c80076,0x7c2905bf,0x2d8c014b,0xf84a00d3}},	//   ádmh, _foer, _àde_, йчий_,
   {{0x97140465,0xd6da00d6,0x8d5b00ca,0x7c3b01cb}},	//   дмиц, бто_, _הכלי, _glur,
   {{0xbbd80179,0xa2ce0167,0x26c400c6,0x7a3d02f1}},	//   डलीक, _तिष्, usmo_, _sète,
   {{0xba293862,0xceb300a1,0xdce70034,0x4429526c}},	//   _وسلم_, עית_, _wyją, _soa_,
   {{0x25dd007d,0x386d526d,0x44291d29,0x645d526e}},	//   _खारी_, boer_, _poa_, ério,
   {{0x897b00c1,0x62490146,0x644d0090,0x7bc20239}},	//   _פראצ, nžov, _qmai, naou,
   {{0x288b03ed,0x4429526f,0xd05000a7,0x69dc02c3}},	//   _اصلی_, _voa_, _ödəy, _öres,
   {{0x26c2013f,0xa2ce00b6,0x4429020b,0x25a5009c}},	//   škos_, _तिर्, _woa_, ccll_,
   {{0x0cd700c7,0x44295270,0xae0a030b,0x61144911}},	//   _সন্ত, _toa_, _होइन_, ндру,
   {{0x644d5271,0x656f042c,0x00000000,0x00000000}},	//   _umai, ßche, --, --,
   {{0x7c295272,0x920800e8,0xddde02c6,0x26110096}},	// [4970] _roer, _brāļ, lopř, ताची_,
   {{0xd35800a1,0xb2bc00ca,0x93780037,0x46d400b6}},	//   _משחק_, _המזר, _عصير_, _दिनह,
   {{0x7c3b5273,0xd7dc0454,0x7c2900d1,0xfe700037}},	//   _plur, _यांच, _poer, ادق_,
   {{0x645d5274,0x98c402c6,0x317e042c,0x629f2e10}},	//   nnsi, štěn_, ütze_, _kuqo,
   {{0x7c290934,0xa3e204f8,0x25dd31f4,0x386d159f}},	//   _voer, न्ट_, _खाली_, voer_,
   {{0x2009013f,0xae0a009d,0x7c295275,0x629f0167}},	//   ldai_, _होऊन_, _woer, _muqo,
   {{0x7c290934,0x2ee90102,0x6f0d0328,0xa8895276}},	//   _toer, ltaf_, lvac, ойка_,
   {{0x20095277,0x77f91c83,0xd6d900a5,0x7a3d022b}},	//   ndai_, ्येक_, tuł_, _bètc,
   {{0xfaf00fb7,0x2ee902ad,0xd7060084,0x200901c2}},	//   _مثل_, ntaf_, дные_, idai_,
   {{0x62975278,0xd6d90034,0xafdb00f3,0x28dd0096}},	//   _nixo, szło_, _fløg, नंदि,
   {{0x69c31075,0x6f0d1197,0x6d452952,0xab5d00bd}},	//   mane, hvac, nzha, _beżg,
   {{0x69c35279,0x9f400088,0x62850103,0x629700ee}},	//   lane, keið_, _ahho, _aixo,
   {{0x200902e0,0x7a3401ec,0x27ed0022,0x6297338f}},	//   ddai_, _bàth, mfen_, _bixo,
   {{0x27ed02e2,0x2009013f,0x62850154,0x7a34009c}},	//   lfen_, edai_, _chho, _càth,
   {{0x261a046e,0xafe600d6,0x1606009f,0x6b9b3eb7}},	//   बारी_, мовл, _वोटर_, _ogug,
   {{0x6d450808,0x62971258,0x6b9b527a,0x683c01dc}},	//   dzha, _eixo, _ngug, _kéda,
   {{0x69c3527b,0xf41300a1,0x2cad0284,0x27ed01bf}},	// [4980] kane, _יפה_, _čeda_, ifen_,
   {{0x2019527c,0x69c3527d,0x683c42a6,0x6b9b520f}},	//   _ensi_, jane, _méda, _agug,
   {{0x621b07a6,0x61fc527e,0xafdb0c08,0x20190036}},	//   _וויק, merl, _blød, _fnsi_,
   {{0x61fc527f,0x629f1a4a,0xa3e20c54,0x3e7d0036}},	//   lerl, _yuqo, न्च_, bìto_,
   {{0x69c3067d,0xdb000181,0x624916d4,0xdb0b5280}},	//   fane, _nemô, ržov, dagó,
   {{0x69c35281,0x27ed5282,0x320a0ac1,0x6b9b063d}},	//   gane, efen_, ndby_, _egug,
   {{0x27ed2b9e,0x26f81fbb,0xafdb02b6,0x998502c6}},	//   ffen_, ्ट्र_, _flød, _dolů_,
   {{0x61e901ac,0x683c5283,0x27ed0150,0xec160113}},	//   đeli, _béda, gfen_, _تورد,
   {{0xa3e2033a,0x61fc5284,0x60dc0113,0x661801ff}},	//   न्छ_, kerl, hurm, _pnvk,
   {{0x386903ce,0x61fc0559,0x645d5285,0xdb00016d}},	//   čara_, jerl, wnsi, _demô,
   {{0x61fc5286,0x7bc05287,0x6aa00a4b,0x2455001c}},	//   derl, _kemu, _humf, فندس,
   {{0x7bc05288,0x6835025b,0x6aa05289,0x60dc528a}},	//   _jemu, _nádh, _kumf, durm,
   {{0x7bc0528b,0x61fc528c,0x645d528d,0x7bdf0428}},	//   _memu, ferl, rnsi, òqui,
   {{0x7bc0528e,0x60dc0078,0xc5d50081,0x6aa0528f}},	//   _lemu, furm, ত্বপ, _mumf,
   {{0xa3e70c9c,0xe5f700a1,0x6aa003e3,0x6297002b}},	//   _पाप_, _חזור_, _lumf, _vixo,
   {{0x7bc05290,0x6f0d14f3,0x7a3400b3,0x7a3d0513}},	//   _nemu, tvac, _dàti, _mèta,
   {{0x61fc0b88,0x20095291,0x6aa00d2a,0x62975292}},	// [4990] berl, rdai_, _numf, _tixo,
   {{0x61fc5293,0xab5d4197,0x2ca708a8,0x69c300b3}},	//   cerl, _jeże, índo_, xane,
   {{0x69c35294,0x7bc00018,0x2ee95295,0x44395296}},	//   vane, _bemu, staf_, oks_,
   {{0x443951e4,0x69c35297,0x09d7009d,0xdb0b0428}},	//   nks_, wane, ठल्य, dagò,
   {{0x69c35298,0xa3e702e8,0x7bc05299,0xfb3500c6}},	//   tane, _पान_, _demu, эндэ,
   {{0xd3380054,0x683c0257,0xa2d71d7d,0x7a3d0154}},	//   ורדה_, _réda, _बिन्, _bèta,
   {{0xdb0b0080,0x27ed0b88,0x3e740149,0x7a340428}},	//   tagó, tfen_, rätt_, _xàti,
   {{0x44390ab2,0x7bc00991,0x27ed02e2,0x683c0257}},	//   jks_, _gemu, ufen_, _péda,
   {{0x27ed529a,0xf70800de,0x9f4b0146,0x61e50146}},	//   rfen_, _củ_, _obcí_, _ochl,
   {{0x4439529b,0xab84529c,0x7bc00284,0xd83814f3}},	//   eks_, _руск, _zemu, _vuča_,
   {{0x27ed01bf,0xc8c91ac9,0x7bc001b2,0xab5d009e}},	//   pfen_, _روشن_, _yemu, _deże,
   {{0x69c1529d,0x29050694,0xd8382461,0x61e500f0}},	//   _hele, _isla_, _tuča_, _achl,
   {{0x2bd0009d,0x7a3400ee,0x163500d3,0x683500d8}},	//   हणता, _sàti, _педя, _nádi,
   {{0x69c1529e,0x975600a1,0x60dc3287,0x61fc0364}},	//   _jele, _אינו_, turm, uerl,
   {{0x69c1529f,0xae032125,0x78a100b3,0x463a006e}},	//   _mele, रजनन_, _julv, _מעסע,
   {{0x69c152a0,0x443952a1,0x61fc52a2,0xafdb038c}},	//   _lele, cks_, serl, _smør,
   {{0x683504d8,0x1e860cf5,0x61fc14a5,0xdfcf0190}},	// [49a0] _cádi, елам, perl, صيل_,
   {{0x7bc01268,0x2d9c1484,0x69c152a3,0x9f400ab2}},	//   _semu, øve_, _nele, lgië_,
   {{0x7bc00496,0x163600c1,0x6aa001c2,0x71bb00ca}},	//   _pemu, ענער_, _sumf, _מציג,
   {{0xdd8f0f43,0x09c8009d,0xa06a0077,0x69c152a4}},	//   حوم_, रण्य, _хама_, _aele,
   {{0x2905026a,0x94210096,0x628e0337,0xa3de30a8}},	//   _asla_, यातच_, ombo, _ढाई_,
   {{0xfce652a5,0x78a152a6,0xf70800de,0x7a3d00ee}},	//   _пого, _bulv, _rủ_, _pèta,
   {{0x7bc052a7,0x645d00cd,0xc7c6036f,0xf1b30796}},	//   _temu, érik, нспи, נסה_,
   {{0xfba40557,0x69c100b7,0x6aa0024a,0x571814fb}},	//   _ओलिम, _eele, _tumf, джия_,
   {{0x69c10068,0xc6f7055b,0x8c4300c2,0x6e2e52a8}},	//   _fele, еных_, _сете, _kobb,
   {{0x69c152a9,0x6e2e52aa,0x78a1028d,0x3a060018}},	//   _gele, _jobb, _fulv, _سکتی_,
   {{0x6e2e52ab,0x78a1038c,0x3ea252ac,0x06de0033}},	//   _mobb, _gulv, _lukt_, _বৈশি,
   {{0x61e502d6,0xf7080019,0x443952ad,0x46a652ae}},	//   _schl, _tủ_, uks_, _задв,
   {{0xa3e7143d,0x443952af,0x27e61665,0x683c2f8a}},	//   _पाठ_, rks_, _icon_, _hédo,
   {{0x443952b0,0x171b00a1,0x6e2e52b1,0x960600e3}},	//   sks_, _מודע, _nobb, _سبتم,
   {{0x2cad015c,0x443900e7,0x68352bb5,0x00000000}},	//   _čedo_, pks_, _sádi, --,
   {{0x4ea708d1,0x23720294,0x683c014b,0x3ea20572}},	//   ержа, ọlọj, _médo, _bukt_,
   {{0x63ad02ad,0x63bb003e,0x6e9900f3,0xfe1c007f}},	// [49b0] _ifan, ðunu, двар_, नांस_,
   {{0x6e2e22d4,0x54e400aa,0xa3d90d61,0x5d6742a4}},	//   _cobb, _कमाए_, ालक_, нтез,
   {{0x6e2e52b2,0xf65300c1,0x248952b3,0x27e601ff}},	//   _dobb, נצע_, _kham_, _ocon_,
   {{0x3ea2169c,0xfff9001c,0x00000000,0x00000000}},	//   _fukt_, _تکست_, --, --,
   {{0x63ad52b4,0x09e5016e,0x6f844214,0x248952b5}},	//   _mfan, волн, _бурж, _mham_,
   {{0x660a06e1,0x6e2e52b6,0x5338006e,0xaad2152c}},	//   _nafk, _gobb, ענגן_, _सिरक,
   {{0x63ad52b7,0xecf8021a,0x787e0216,0x00000000}},	//   _ofan, _перш_, mëvj, --,
   {{0xe81e007a,0x69c152b8,0x200b08a9,0xb8c90096}},	//   भाषा_, _wele, _jaci_, _गं_,
   {{0xdcfc00d9,0x200b52b9,0xdb000088,0xfae002c6}},	//   _izrā, _maci_, _afmæ, íště_,
   {{0x63ad52ba,0x660a006d,0x69c10239,0x3b544c3e}},	//   _afan, _cafk, _uele, _скур,
   {{0x044602fd,0xd46a15de,0x558921f4,0x9f490037}},	//   венн, дине_, ьбом_, dfaí_,
   {{0x200b04a3,0x25dd04f1,0x248952bb,0x2af5007a}},	//   _naci_, _खाकी_, _cham_, _इहाँ_,
   {{0xe72e52bc,0x6605198a,0x248952bd,0x1de2007f}},	//   _те_, _апла, _dham_, _पालत,
   {{0xe2972371,0xe5a2002d,0x2d9c0181,0x7a3d3e9b}},	//   кая_, _киши, ľvek_, _mèto,
   {{0xe29752be,0x200b52bf,0xa2ce3542,0x63ad0178}},	//   тар_, _baci_, _तिक्, _ffan,
   {{0x63a908a8,0x27ff52c0,0x200b52c1,0x6e2e0036}},	//   ñent, neun_, _caci_, _sobb,
   {{0x200b52c2,0x6da652c3,0xa3e70c9c,0x59d10096}},	// [49c0] _daci_, виза, _पात_, सणार,
   {{0x200b02a1,0x4f9500d3,0xa2d70966,0xceb4013c}},	//   _eaci_, урсу, _बित्, rpə_,
   {{0x27ff0167,0x200b52c4,0x6146044b,0xd7b300a4}},	//   keun_, _faci_, _рена, ीराच,
   {{0x27ff0139,0x69d703be,0x200b0022,0x7a3d022b}},	//   jeun_, óxen, _gaci_, _bèto,
   {{0x6e2e52c5,0x7c6552c6,0x200000ae,0x63a900c6}},	//   _tobb, دالل, meii_, ženg,
   {{0x6f0402a4,0x200b0022,0x683c020d,0xdb0b01cd}},	//   mwic, _zaci_, _pédo, ragð,
   {{0x200b0d2a,0x98c308a1,0x7c9600ae,0x63a1007f}},	//   _yaci_, асыл, _арац, ślni,
   {{0x27ff0085,0x660a52c7,0x00000000,0x00000000}},	//   geun_, _safk, --, --,
   {{0xe7e3007d,0xfaa63168,0xc05300a1,0x6f0450b5}},	//   _गारा_, _разо, יזה_, nwic,
   {{0x63ad00d3,0x14ca007b,0x00000000,0x00000000}},	//   _sfan, мыми_, --, --,
   {{0x248952c8,0xd5b801d3,0x63ad0364,0x2ee0029a}},	//   _pham_, rbā_, _pfan, huif_,
   {{0x5fe115e4,0x6f0452c9,0xdceb00e7,0x2ee00313}},	//   _फाइल, kwic, žići, kuif_,
   {{0x660a0044,0x1de250da,0x2000044c,0x2ee0014b}},	//   _tafk, _पांत, deii_, juif_,
   {{0x7df3000d,0x200b52ca,0xab5d00bd,0x2ef90027}},	//   _měsí, _saci_, _jeża, _rpsf_,
   {{0x248952cb,0x200b52cc,0x0efd0096,0xdfd5163d}},	//   _tham_, _paci_, ॉट्स_, ловы,
   {{0x63ad52cd,0x2369006c,0x261a09c3,0xaad202d5}},	//   _ufan, _txaj_, बाकी_, _सिंक,
   {{0x44ce52ce,0x4ea40aa8,0x22840212,0x7a3d0f09}},	// [49d0] lę_, арха, söka_, _bètl,
   {{0x7a3d015e,0xab5d02a1,0x27ff52cf,0x41a709a1}},	//   _rèto, _neża, zeun_, _खलिस,
   {{0x44ce52d0,0x3cd52a6e,0x72340037,0x200b3654}},	//   nę_, ужес, _خريط, _taci_,
   {{0x1c1d097c,0x6f0452d1,0x2ef90350,0x2000044c}},	//   फाइल_, bwic, _tpsf_, ceii_,
   {{0x41a7152c,0x00000000,0x00000000,0x00000000}},	//   _खलास, --, --, --,
   {{0x44ce52ce,0x2fc952d2,0x00000000,0x00000000}},	//   kę_, laag_, --, --,
   {{0x44ce00a5,0x27ff1215,0xe8f50037,0x99850141}},	//   ję_, teun_, استخ, _bolš_,
   {{0xd70952d3,0x44ce52d4,0x2fc9008a,0x22580364}},	//   ение_, dę_, naag_, zirk_,
   {{0x27ff01b9,0xe5a50b2e,0x4b4e0129,0x3c5800ae}},	//   reun_, липи, nụlọ_, _ритэ_,
   {{0x9a8752d5,0x7afb2375,0x27ff0313,0x26f300aa}},	//   _рубл, _iput, seun_, _अहीर_,
   {{0x44ce52d4,0x3866004d,0x00000000,0x00000000}},	//   gę_, _fjor_, --, --,
   {{0xc209004f,0x999e0154,0x2fc9057a,0xb8090076}},	//   _מה_, _antň_, jaag_, _سيتم_,
   {{0x2fc952d6,0x4de300b6,0x225852d7,0x5a4400ae}},	//   daag_, खलाई_, tirk_, _сэӂа,
   {{0x644652d8,0x387f30ed,0x6fe102d5,0x7afb52d9}},	//   shki, llur_, _फाउं, _mput,
   {{0x213e1823,0x44ce00a5,0x660152da,0x2000020a}},	//   áth_, cę_, melk, teii_,
   {{0x6f0402e2,0x320c0146,0x7afb0134,0x2fc9008c}},	//   twic, ždy_, _oput, gaag_,
   {{0x442043b4,0x33260253,0x64560193,0x64440239}},	// [49e0] _ini_, _çox_, _imyi, _ilii,
   {{0x443252db,0xa20652dc,0xdee31720,0x539b00ca}},	//   _hoy_, _спод, софи, _איפו,
   {{0x7afb0134,0x442052dd,0x63a91b30,0x4ac60789}},	//   _aput, _kni_, žene, रीनव,
   {{0xf767172a,0x0b4623a3,0xdd8f012b,0xfaa652de}},	//   _ها_, лнен, سون_, гадо,
   {{0xa3e71244,0x60c90029,0xa09b00c1,0x44200449}},	//   _पास_, ņemt, _ריכט, _mni_,
   {{0xa2d7000c,0xada300c6,0xf41f00c2,0x629e4612}},	//   _बिस्, _гарл, lmät_, _jipo,
   {{0x66012782,0x7afb52df,0x629e037a,0x4432008c}},	//   delk, _eput, _mipo, _ooy_,
   {{0xc6f85011,0x387f0088,0x44200139,0x44ce0138}},	//   вних_, glur_, _nni_, vę_,
   {{0xab662dfb,0x44ce0034,0x660152e0,0xbf9a006e}},	//   _свал, wę_, felk, עיִש,
   {{0x442052e1,0x44ce16e0,0x644452e2,0x26f700e3}},	//   _ani_, tę_, _alii, اريخ_,
   {{0x442000ec,0x387f52e3,0x644401b9,0x9e7700a1}},	//   _bni_, blur_, _blii, רגיה_,
   {{0x69ca52e4,0x44320449,0x629e52e5,0x442052e6}},	//   lafe, _coy_, _aipo, _cni_,
   {{0x442052e7,0x660152e8,0x44ce40f0,0x44320a43}},	//   _dni_, belk, sę_, _doy_,
   {{0x442052e9,0x69ca52ea,0x44ce52eb,0x629e52ec}},	//   _eni_, nafe, pę_, _cipo,
   {{0x629e0918,0x765a52ed,0x8fb200ac,0xbe050103}},	//   _dipo, mity, _ọnọd, یورٹ,
   {{0x765a52ee,0xa2ce009d,0x7ae2013f,0x69ca52ef}},	//   lity, _तिच्, kuot, hafe,
   {{0xcddb2d16,0xf3f000e3,0x2fc90cad,0x7ae2013f}},	// [49f0] ење_, _رأي_, raag_, juot,
   {{0x59e0000c,0x765a52f0,0x7ae2013f,0x629e52f1}},	//   _नागर, nity, duot, _gipo,
   {{0x2d870149,0x44201175,0x683c01f9,0x9d230033}},	//   åne_, _yni_, _védj, পন্ন_,
   {{0x660100a5,0x765a0084,0x644401b9,0x629e0172}},	//   zelk, hity, _xlii, _zipo,
   {{0x34c10961,0x3ea90090,0x765a52f2,0x998c00b6}},	//   _शब्द, qqat_, kity, _bodů_,
   {{0x50b80e8c,0x08d52dfb,0x6835025b,0x69ca52f3}},	//   _جدید_, ация, _nádr, gafe,
   {{0x765a5266,0x63bd00f9,0x1a680018,0x7a3452f4}},	//   dity, kbsn, دیلی_, _pàtr,
   {{0x38aa009c,0x660152f5,0x2bbb0076,0x00000000}},	//   _dùr_, welk, _سارة_, --,
   {{0x7afb02e6,0xeab01e53,0x7bcb52f6,0x69ca52f7}},	//   _uput, _فعل_, magu, bafe,
   {{0x443252f8,0x7bcb52f9,0x387f003e,0x26cd52fa}},	//   _soy_, lagu, slur_, rseo_,
   {{0x9967141b,0x629e52fb,0xb46652fc,0x261a1152}},	//   _стал, _ripo, икол, बाजी_,
   {{0x2aab0021,0x68e352fd,0x629e52fe,0x7bcb52ff}},	//   _køb_, mund, _sipo, nagu,
   {{0xa3e717ff,0x68e35300,0x44320081,0x66010a00}},	//   _पार_, lund, _voy_, pelk,
   {{0x7bcb2263,0xa2d72a29,0x44205301,0x6383224a}},	//   hagu, _बिर्, _wni_, ігра,
   {{0x68e35302,0x20565303,0x44200510,0x7ae2013f}},	//   nund, атар, _tni_, zuot,
   {{0x645d5304,0x7bcb50c4,0x64445305,0x8fa32fad}},	//   érit, jagu, _ulii, жате,
   {{0x7bcb5306,0x68e35307,0xd00709b9,0x63a42783}},	// [4a00] dagu, hund, шете_, _igin,
   {{0x68e35308,0x7ae25309,0xa3e60336,0x24420139}},	//   kund, vuot, _काँप_, _kómo_,
   {{0x68e3007a,0x6b890036,0x61e10072,0x00000000}},	//   jund, _azeg, ólle, --,
   {{0xf09f530a,0x7ae20fdf,0x68e3530b,0x683c0113}},	//   _già_, tuot, dund, _gédh,
   {{0x69ca530c,0x6b8900a5,0xc5fe0081,0xab5d0090}},	//   tafe, _czeg, ্ঞতা_, _deżo,
   {{0x68e3530d,0x7ae201b3,0xaa53013f,0xda63530e}},	//   fund, ruot, овіш, овчи,
   {{0x68e31f97,0x7bcb530f,0x765a0084,0x63a45310}},	//   gund, bagu, vity, _ogin,
   {{0x63a45311,0xa2d7269c,0x69ca5312,0xdca3380e}},	//   _ngin, _बिल्, safe, _фати,
   {{0x09e65313,0xf1c604f1,0x68350037,0x765a5314}},	//   _возн, वरान, _pádr, tity,
   {{0x63a402a7,0xd8380995,0x7e62014b,0x38aa01f7}},	//   _agin, _muči_, éoph, _tùr_,
   {{0x24420eb8,0x69c85315,0x765a5316,0xd8380087}},	//   _cómo_, _iede, rity, _luči_,
   {{0x69c85317,0x765a02fd,0x290c265b,0x673b0027}},	//   _hede, sity, _isda_, byuj,
   {{0x69c85318,0x59ba0096,0x78a802c3,0x683c38df}},	//   _kede, _उभार, _hudv, _rédh,
   {{0x69c8374e,0x63a403f3,0x22450088,0x7bcb5319}},	//   _jede, _egin, ólk_, zagu,
   {{0x645d025a,0x7bcb531a,0xf09f0036,0x349500d3}},	//   éris, yagu, _pià_, _лакр,
   {{0x69c8531b,0x7bcb531c,0xd83805db,0x859b00ca}},	//   _lede, xagu, _buči_, _בשוו,
   {{0x78a8531d,0x69c801cb,0x2d853e76,0x7bcb058f}},	// [4a10] _ludv, _oede, _šle_, vagu,
   {{0x645d531e,0x386903ce,0x68e3531f,0x683c5320}},	//   lisi, čari_, yund, _dédi,
   {{0x7bcb5321,0x6b890018,0x68e35322,0x645d0503}},	//   tagu, _szeg, xund, oisi,
   {{0x645d5323,0x68e35324,0xf3910065,0x70550504}},	//   nisi, vund, _aṣia_, _چنگا,
   {{0x7bcb5325,0x68e35326,0xf1db0557,0xd8380307}},	//   ragu, wund, _बयान, _guči_,
   {{0x7bcb5327,0x78a80542,0x645d5328,0xa9693bbc}},	//   sagu, _budv, hisi, лила_,
   {{0x645d5329,0x7bcb532a,0xab5d009e,0x00000000}},	//   kisi, pagu, _teżo, --,
   {{0xb8ff000c,0xccf200a1,0x69c8008a,0x645d532b}},	//   _ति_, _מכל_, _eede, jisi,
   {{0x6b80532c,0xe7f8007f,0x00000000,0x00000000}},	//   _gymg, ्ज़ा_, --, --,
   {{0x69c8532d,0x68e3532e,0x63a40a9a,0x645d0dd8}},	//   _gede, pund, _sgin, eisi,
   {{0x645d532f,0xda7a006e,0x391500d1,0x704e0139}},	//   fisi, _ענער, _دواز, _líjọ,
   {{0x4aab04a9,0x6aa102dc,0x69c85330,0x98140076}},	//   _चढाव, _hilf, _zede, _وبنا,
   {{0xd87400e3,0x69c8026a,0x7bc91183,0x9f5900ee}},	//   _بالب, _yede, _meeu, _masó_,
   {{0xe5a5008f,0x7bc903ee,0x683c0257,0xdb020161}},	//   _уики, _leeu, _rédi, scoç,
   {{0x64b539d9,0x6aa15331,0x61431248,0x1a9a00c1}},	//   _احتر, _milf, пера, טישע,
   {{0x63a4042d,0x645d1647,0x683c0349,0x44f15332}},	//   _ugin, cisi, _pédi, má_,
   {{0xef1a013f,0x44f15333,0x20120009,0x9eea109d}},	// [4a20] ыма_, lá_, rdyi_, طفال_,
   {{0x7a3d022b,0x2d9600c2,0xee375334,0x764113ea}},	//   _fèti, брес, бну_, nkly,
   {{0x44f15335,0x69c81063,0x9f59037a,0x4b4e0174}},	//   ná_, _rede, _basó_, pụkọ_,
   {{0x69c85336,0xa3d8063a,0xd8380b18,0x9f590328}},	//   _sede, ाणि_, _tuči_, _casó_,
   {{0x69c830d3,0x44f1025b,0x7ff70100,0xda34007b}},	//   _pede, há_, _اسپا, желы,
   {{0x645d5337,0x29180103,0x6e35042d,0x44f10146}},	//   zisi, _árak_, _gozb, ká_,
   {{0x69c85338,0xa3d85339,0x645d533a,0xfce3002d}},	//   _vede, ाणा_, yisi, _норо,
   {{0xdd8f00e3,0x44f1185d,0x69c8533b,0xc879020a}},	//   _سوق_, dá_, _wede, goş_,
   {{0x69c8533c,0x6aa1533d,0x2ee00150,0x2fc00bb6}},	//   _tede, _filf, nrif_, ibig_,
   {{0x645d533e,0x225a061d,0x7bc9533f,0x6aa1030a}},	//   wisi, _nmpk_, _zeeu, _gilf,
   {{0x645d5340,0x998618a9,0xd7fa079c,0x44f10131}},	//   tisi, _الاو, _бул_, gá_,
   {{0x3d00417a,0x2ee05341,0x7a3d0154,0x9f40034f}},	//   _रहने_, krif_, _bètw, nfió_,
   {{0xd796054f,0x645d5342,0x073a00b1,0xafdb02b6}},	//   _الشخ, risi, _حساب_, _fløj,
   {{0x44f100d4,0x3dca0172,0xa78506cf,0x7a3d0154}},	//   bá_, _nebw_, _بشمو, _pèti,
   {{0x645d1197,0x6e3512fb,0xd25816dd,0x44f11e6c}},	//   pisi, _rozb, сця_, cá_,
   {{0xdbf1030b,0x2ee00150,0x8c3d00d3,0x645d5343}},	//   _přík, frif_, _mişc, qisi,
   {{0x94120092,0x403400c2,0x6e3521d7,0x2ee000f0}},	// [4a30] _niyə_, четс, _pozb, grif_,
   {{0x9f590139,0xbfed0134,0xdd04097c,0xe45f007b}},	//   _basò_, _ṅụọ_, रबंध_, liö_,
   {{0x403500d3,0x9f590890,0x2fc04350,0x64b3020a}},	//   _денс, _pasó_, bbig_, _tăie,
   {{0x6aa15344,0xbebb023b,0xd1b80470,0xdbf100d2}},	//   _silf, _rrëf, _پایا_, _třík,
   {{0x79815345,0xa3e7000f,0x44f15346,0xab295347}},	//   _sylw, _पाई_, zá_, рола_,
   {{0x6ca70747,0x6e3500cc,0x683c2a56,0x656f044c}},	//   _граж, _uozb, _médu, şchi,
   {{0x44f1016d,0x7bc901cb,0x00000000,0x00000000}},	//   xá_, _teeu, --, --,
   {{0x44f10871,0x81c10081,0xeaf812eb,0x26df034f}},	//   vá_, ুলি_, _گرفت_, truo_,
   {{0x6aa10170,0xac9401b6,0xb8d01362,0x2d830216}},	//   _tilf, _хатш, _टू_, _hyje_,
   {{0x44f15348,0xe81e009d,0x8f9c006e,0xf9d4002d}},	//   tá_, _मोठा_, ניזי, _ноуэ,
   {{0x26c60174,0x76415349,0xdddc00e8,0x00000000}},	//   _ewoo_, rkly, _skrū, --,
   {{0x78a20465,0x01e10033,0x76411e95,0x672400d8}},	//   _giov, ম্মদ, skly, _šije,
   {{0x683c1f84,0x26c60174,0x44f1421d,0xd6291472}},	//   _cédu, _gwoo_, sá_, _воле_,
   {{0x38692461,0x2fd9002b,0x44f1534a,0x683c00fd}},	//   čaru_, _adsg_, pá_, _dédu,
   {{0x6f1d0364,0xd6780076,0x7de00065,0x2bcc2b6e}},	//   _arsc, _احنا_, _lásà, ारमा,
   {{0xa3e707e2,0x44d50029,0xe3b21790,0xe2e6534b}},	//   _पाए_, mā_, _غرب_, _джип,
   {{0x44d500d9,0x2480534c,0x44c70018,0x3eb90154}},	// [4a40] lā_, _ikim_, lő_, _ctst_,
   {{0x22570037,0xde6d00fe,0x9f4000ee,0x00000000}},	//   _وليد_, tươn, rgià_, --,
   {{0x44d50029,0x6f1d02e2,0x8fa6534d,0xe7ea009f}},	//   nā_, _ersc, _мане, _टाला_,
   {{0x984c030b,0x32130231,0x00000000,0x00000000}},	//   věď_, _zaxy_, --, --,
   {{0xb605033b,0x3f820233,0x3eb901cb,0x78a20231}},	//   _kršč, _uyku_, _gtst_, _riov,
   {{0x44d50029,0x248000dc,0x27fd041c,0x7cdc044c}},	//   kā_, _lkim_, _abwn_, tără,
   {{0x44d50b4b,0x8c46450e,0xf84a016a,0x78a211f4}},	//   jā_, _деве, ичий_, _piov,
   {{0x44d500d9,0x2480022e,0x44c70103,0xec774876}},	//   dā_, _nkim_, dő_, _дпс_,
   {{0xf093534e,0x7bc2025a,0x466a534f,0x78a2024a}},	//   ונה_, mbou, иром_, _viov,
   {{0x683c025a,0x7cdc020a,0x7bc25350,0x24805351}},	//   _rédu, pără, lbou, _akim_,
   {{0x683c00fd,0xe45f00c2,0x44d501d3,0x29185352}},	//   _sédu, tiö_, gā_, _éra_,
   {{0x7bc25353,0x80b10980,0x26c65354,0xa5ba0285}},	//   nbou, _आंबे, _twoo_, _श्रौ,
   {{0xfbd30054,0x61fe0063,0x06650401,0xe45f00c2}},	//   ותר_, _bbpl, _کانپ, riö_,
   {{0xa3e739d4,0x248001e8,0x28d10034,0x44d501d3}},	//   _पाक_, _ekim_, _सबमि, bā_,
   {{0xa2d708fa,0x63b60150,0x7ae2042c,0x3cf6007f}},	//   _बिक्, _ffyn, hrot, ीबों_,
   {{0x7ae25355,0x1eab02a3,0xd8380b18,0x80dc058f}},	//   krot, لائي_, _tuču_, _फिरे,
   {{0xddab0d5e,0x69da4289,0x8c3d0511,0x7bc201cb}},	// [4a50] ател_, _odte, _nişa, dbou,
   {{0x291e008e,0x7ae25356,0x32550c10,0x6f1d007e}},	//   _orta_, drot, _хвор, _vrsc,
   {{0x628704eb,0x61f800a7,0xdb070072,0x0ea7074c}},	//   mljo, _övla, _ámús, _कंकड,
   {{0x69da00dc,0x7bc2029a,0x3ea30381,0x00000000}},	//   _adte, gbou, _wijt_, --,
   {{0x44c70068,0x7ae25357,0x291e442c,0x9fbf00d4}},	//   ző_, grot, _arta_, nčík_,
   {{0x6f0d0239,0xab5d0078,0xfc7d00d2,0x660805db}},	//   mwac, _jeżi, _žádá_, jedk,
   {{0xa3eb05d4,0x291e0106,0x7ae20036,0x6f0d5358}},	//   मला_, _crta_, arot, lwac,
   {{0x3d0002b0,0x7ae20b6a,0x44d500d9,0x2bcc0096}},	//   _रहते_, brot, vā_, ारणा,
   {{0x7ae25359,0x787e023b,0x6f0d0dbc,0x00000000}},	//   crot, tëvr, nwac, --,
   {{0x44d50029,0x44c70068,0x248008d3,0x1dcb00b7}},	//   tā_, tő_, _skim_, िरित,
   {{0x69c30087,0x6f0d01bf,0xa5091c00,0xfbcf00bc}},	//   mbne, hwac, щена_, _हजाम,
   {{0x44d500d9,0x78fa00ca,0x44c701f9,0x24420139}},	//   rā_, _לפעו, rő_, _kómi_,
   {{0x44d500d9,0x38b1003e,0x93431278,0xae1b0285}},	//   sā_, _hár_, еняе, नयान_,
   {{0x27ed535a,0xe29a0077,0x44d501d3,0x471a0266}},	//   lgen_, саг_, pā_, _לונג,
   {{0x20d703e5,0x38b10103,0xab5d02a1,0xb6050095}},	//   għi_, _jár_, _deżi, _vršč,
   {{0x27ed535b,0x38b100fb,0x2167001f,0x7bdb0172}},	//   ngen_, _már_, чиси_, _nduu,
   {{0x27ed0bb7,0x38b100e3,0x628710cb,0x6abb0134}},	// [4a60] igen_, _lár_, bljo, _ntuf,
   {{0x2d960f30,0x7bdb008a,0x64460084,0x7a3d0154}},	//   прес, _aduu, lkki, _mèts,
   {{0x6026535c,0x6abb535d,0x6f0d008a,0x38b100e3}},	//   _една, _atuf, awac, _nár_,
   {{0x27ed0505,0x64460084,0xeb9a535e,0xb7ea0b7f}},	//   jgen_, nkki, бие_, _टाइम_,
   {{0x7bdb06b0,0x2cbf0559,0x7bc2535f,0x68e3042c}},	//   _dduu, _čude_, rbou, ernd,
   {{0x27ed3f15,0x38b10018,0x7bc25360,0x82d700c1}},	//   egen_, _bár_, sbou, לונג_,
   {{0x6abb0134,0x7ae25361,0x660801df,0x7bc2029a}},	//   _etuf, srot, vedk, pbou,
   {{0x27ed5362,0x7e7e5363,0x291e0128,0x38b10037}},	//   ggen_, lopp, _vrta_, _dár_,
   {{0xab5d0034,0x68e30381,0x00000000,0x00000000}},	//   _odży, arnd, --, --,
   {{0x7e7e5364,0x291e211b,0x0f5700ca,0x683c5365}},	//   nopp, _trta_, פיים_, _cédr,
   {{0xab5d043f,0x66085366,0x291e5367,0xa3d800ec}},	//   _reżi, redk, _urta_, ाणं_,
   {{0x7e7e5368,0x33203631,0x66085369,0x6f0d007f}},	//   hopp, _brix_, sedk, ywac,
   {{0x62870a39,0xafdb00f2,0x00000000,0x00000000}},	//   tljo, _kløv, --, --,
   {{0x9fbf0094,0x00000000,0x00000000,0x00000000}},	//   rčík_, --, --, --,
   {{0xd5fb00a1,0x64b3044c,0x7e7e536a,0x363331bb}},	//   _הפור, _tăia, dopp, _سروس,
   {{0xb4d8009d,0xd46815de,0x11f700cd,0x628700e7}},	//   ाळी_, _није_, _کودک_, sljo,
   {{0x4429536b,0x644d536c,0x7a3d536d,0xa2d704f1}},	// [4a70] _ina_, _ilai, _mètr, _बिट्,
   {{0x6f0d536e,0x425500bf,0x644d022e,0xddab49cc}},	//   rwac, _آندر, _hlai, стал_,
   {{0x644d536f,0x443b12b7,0x6abb5370,0x27ed5371}},	//   _klai, _koq_, _stuf, ygen_,
   {{0x442904a3,0x26d90018,0xa3bf3542,0x60d60796}},	//   _jna_, ások_, ेरि_, _קורא_,
   {{0x44295372,0xf41f00c2,0x38b15373,0xe46a007b}},	//   _mna_, ylän_, _sár_, ltöä_,
   {{0x38b15374,0x7e7e00e5,0x443b037a,0x644d00f0}},	//   _pár_, copp, _loq_, _llai,
   {{0x64465375,0x27ed5376,0x7a3d022b,0x69c35377}},	//   ykki, tgen_, _bètr, rbne,
   {{0x442900ac,0x27ed5378,0x38b10103,0xccf20796}},	//   _nna_, ugen_, _vár_, _שכן_,
   {{0x27ed029a,0xf1bf1b92,0x61fb00cc,0x41bf1178}},	//   rgen_, ्रान, đulj, ्रास,
   {{0x44295379,0x644d23a6,0x7c3b537a,0xa2d7030b}},	//   _ana_, _alai, _hour, _बिज्,
   {{0x7c3b0c56,0x644d537b,0x240a008f,0x7aeb537c}},	//   _kour, _blai, онни_, lugt,
   {{0x332004ea,0x31c60e72,0x7c3b537d,0x7ae42388}},	//   _prix_, वर्ध, _jour, šite,
   {{0x7c3b0c56,0x644602fd,0x386d01ce,0x64ba009e}},	//   _mour, rkki, mner_, _aċid,
   {{0x4429537e,0x386d537f,0x321801c2,0x64463c28}},	//   _ena_, lner_, udry_, skki,
   {{0x386d0501,0x7c295380,0xa3e7009d,0x3218084e}},	//   oner_, _oner, _पाच_, rdry_,
   {{0x644d5381,0x44290124,0x7c3b5382,0xa2d700df}},	//   _glai, _gna_, _nour, _बिच्,
   {{0xee3a1b42,0x7e7e5383,0x2d91083e,0x09e50033}},	// [4a80] она_, topp, _azze_, প্যা,
   {{0x442902e6,0x7c295384,0x386d5385,0x7aeb5386}},	//   _zna_, _aner, hner_, dugt,
   {{0x7e7e5387,0x442902ad,0x7c290167,0x7c3b5388}},	//   ropp, _yna_, _bner, _bour,
   {{0x7c3b537d,0x387f025a,0x7e7e5389,0x629c066a}},	//   _cour, jour_, sopp, lmro,
   {{0x7c3b538a,0x386d42f0,0x29050113,0x2d9106b0}},	//   _dour, dner_, _apla_, _ezze_,
   {{0x386d4464,0x4dfd030b,0xf6470037,0xa6e2003e}},	//   ener_, र्दै_, _شئ_, _æðis,
   {{0x7c3b538b,0x7aeb0138,0x7a3d0113,0x00000000}},	//   _four, augt, _pètr, --,
   {{0xd6da538c,0x386d538d,0x7c3b538e,0x69c50088}},	//   ото_, gner_, _gour, ðher,
   {{0x6e3c3734,0x63a9110e,0xd90e0018,0x4429538f}},	//   _korb, ženk, _چیت_, _rna_,
   {{0x4429006b,0x644d5390,0x2bcc1b92,0xe81e00aa}},	//   _sna_, _slai, ारवा, _मोरा_,
   {{0x6e3c5391,0x644d05d7,0x386d04cc,0x7c3b00a1}},	//   _morb, _plai, bner_, _your,
   {{0x386d5392,0x6e3c5393,0x21211d32,0x387f5394}},	//   cner_, _lorb, _rrhh_, cour_,
   {{0x6e3c1507,0x644d078e,0x44290227,0x4394061b}},	//   _oorb, _vlai, _vna_, каюс,
   {{0x6e3c5395,0x6aa802a1,0x29180076,0xe46a007b}},	//   _norb, _jidf, _áras_, ttöä_,
   {{0x6aa85396,0x30a75397,0x00000000,0x00000000}},	//   _midf, драв, --, --,
   {{0x44295398,0x44f85399,0x4395539a,0x6618539b}},	//   _una_, mé_, _пайс, _havk,
   {{0x6e3c03ce,0x44f8539c,0x63ad38ff,0xdef80ab3}},	// [4a90] _borb, lé_, _igan, дых_,
   {{0x7c3b539d,0x3ea7539e,0x7c291d4a,0xb6a500de}},	//   _sour, önt_, _sner, _nhậ,
   {{0x44f8539f,0x7c3b0b87,0x2d87052f,0x62850201}},	//   né_, _pour, æne_, _ikho,
   {{0x22840212,0x7aeb0fa0,0x6618004d,0x7c94001c}},	//   sökt_, tugt, _lavk, نشنا,
   {{0x6e3c0b8d,0x44f853a0,0x2019002d,0x386d038c}},	//   _forb, hé_, _iasi_, vner_,
   {{0x201953a1,0x386d53a2,0x7aeb53a3,0x44f853a4}},	//   _hasi_, wner_, rugt, ké_,
   {{0x201953a5,0x387f53a6,0x386d0709,0x7c3b53a7}},	//   _kasi_, tour_, tner_, _tour,
   {{0x672203ce,0x63ad53a8,0x44f853a9,0x0ccb009d}},	//   _broj, _ngan, dé_, ाठीम,
   {{0x6285019f,0xd70600c2,0xb6a500d3,0x00000000}},	//   _okho, еные_, ниил, --,
   {{0x201953aa,0x63ad164f,0x387f0063,0x672248ac}},	//   _lasi_, _agan, sour_, _droj,
   {{0x66180087,0x44f85320,0x201926ae,0x6d450103}},	//   _davk, gé_, _oasi_, nyha,
   {{0x201953ab,0xa01b0222,0x6285019f,0x63ad0027}},	//   _nasi_, _skön, _akho, _cgan,
   {{0x63ad0167,0x672253ac,0x64ba00bd,0x00000000}},	//   _dgan, _groj, _rċie, --,
   {{0x44f853ad,0x63ad53ae,0x3d000006,0xe605007b}},	//   bé_, _egan, _रहले_, ärää,
   {{0x2019068d,0x7d020067,0x44f80257,0x6b89010a}},	//   _basi_, łosz, cé_, _lyeg,
   {{0x20191ffc,0x54360018,0x6e3c53af,0x6285019f}},	//   _casi_, _سربر, _sorb, _ekho,
   {{0x2cbf08c5,0x6b8953b0,0x649600e3,0x20190449}},	// [4aa0] _čuda_, _nyeg, ráid, _dasi_,
   {{0x6618023e,0x64960037,0x09e50081,0x63ad0141}},	//   _xavk, sáid, প্তা, _zgan,
   {{0x6e3c53b1,0x10a617a6,0x201953b2,0x09d80081}},	//   _vorb, _пион, _fasi_, সলমা,
   {{0x27ff53b3,0x201953b4,0xfbd20018,0x2d9536bf}},	//   jfun_, _gasi_, اتا_, трус,
   {{0xeb9a00d3,0x98a70138,0xab830399,0x6b8905bd}},	//   чид_, lynė_, лушк, _cyeg,
   {{0x44f853b5,0xb86600cd,0x67220216,0x00000000}},	//   yé_, کاتو, _rroj, --,
   {{0x321a1fe8,0x6b8953b6,0x27ff01c2,0x44f83ece}},	//   _mapy_, _eyeg, ffun_, xé_,
   {{0x44f853b7,0x63a93f64,0x660300f9,0x6618031a}},	//   vé_, ženi, _abnk, _savk,
   {{0xd5bd53b8,0xe666215f,0x44f81a7b,0xbbcc030b}},	//   ोरंज, етно, wé_, ारीक,
   {{0x44f853b9,0xa2d4007d,0x63ad53ba,0x644053bb}},	//   té_, _बौध्, _sgan, ömin,
   {{0x44f8020d,0x00000000,0x00000000,0x00000000}},	//   ué_, --, --, --,
   {{0x44f853bc,0xe7ea0789,0xe73a00c2,0x2d8a0063}},	//   ré_, _टाटा_, _нее_, _mybe_,
   {{0x44f853bd,0xfdf0009f,0x91a60023,0x63ad0167}},	//   sé_, _चांस_, _đó_, _vgan,
   {{0x44f853be,0x201953bf,0xbebb0216,0x8bcc00aa}},	//   pé_, _sasi_, _brën, ारुअ,
   {{0x201901e5,0xdfd50fdf,0xc693006e,0x9f490037}},	//   _pasi_, ковы, _גאס_, rgaí_,
   {{0x63ad3128,0x8c3d0233,0x20193a78,0x244201cd}},	//   _ugan, _pişm, _qasi_, _dóms_,
   {{0x02a7247a,0x201953c0,0x747c0089,0x533528f1}},	// [4ab0] _пром, _vasi_, _מנהג, _репт,
   {{0x44390149,0xbebb0052,0x62850201,0x201953c1}},	//   ljs_, _frën, _ukho, _wasi_,
   {{0x201905e0,0x7059061b,0xc1bf0179,0x27ff04d6}},	//   _tasi_, _жанр_, ्रीग, yfun_,
   {{0x201953c2,0xae0209c4,0x2d8a0537,0x00000000}},	//   _uasi_, र्बन_, _dybe_, --,
   {{0x2fc953c3,0x7de700d6,0xee3f0023,0x6d4553c4}},	//   mbag_, _півд, _buýt_, syha,
   {{0x3eaa02dc,0x2fc953c5,0xd2b80327,0x3a2c53c6}},	//   _gibt_, lbag_, עלות_, _cndp_,
   {{0xdd94013f,0xf1b40266,0x6d430212,0x99d401c3}},	//   _бары, נסק_, änad, اتها,
   {{0x2fc901af,0x48092a84,0x00000000,0x00000000}},	//   nbag_, феин_, --, --,
   {{0x39490b4b,0xc2210251,0x6b890169,0xa3eb0285}},	//   ņas_, मयाब_, _uyeg, मलई_,
   {{0xa01b0ce3,0xb0e102d5,0x9f40028d,0xe6450b31}},	//   _sköl, _फिंग, ggiù_, теоп,
   {{0x2ee953c7,0x57f53cf9,0x00000000,0x00000000}},	//   hraf_, _апет, --, --,
   {{0xbebb023b,0x3d090179,0x2ee900dc,0x996453c8}},	//   _rrën, _सहने_, kraf_, _стул,
   {{0xae020521,0x321a53c9,0x52be0ff9,0x00000000}},	//   र्डन_, _papy_, ्ठेस, --,
   {{0xdddc0a9e,0x26d900d4,0x2ee953ca,0x2cbf05db}},	//   _okrš, ásou_, draf_, _čudn_,
   {{0x389e0294,0xd17900f3,0x00000000,0x00000000}},	//   _ọria_, есті_, --, --,
   {{0x2fc902c9,0x3eaa003d,0x88e30033,0xafdb00f2}},	//   gbag_, _sibt_, _মহাক, _slør,
   {{0x2ee953cb,0xf48709e5,0x59d10006,0xdfcf0037}},	// [4ac0] graf_, _جاوی, हरार, زيل_,
   {{0xaf060139,0x6d1d0285,0x78ab02ac,0xdcf50233}},	//   _ajùú, फिंग_, _ligv, _agzı,
   {{0x2fc901c2,0x77790090,0xdee300d3,0x00000000}},	//   bbag_, _lxwx, лоӂи, --,
   {{0x0b460426,0xee3f0023,0xd6d9007f,0x628e53cc}},	//   кнен, _suýt_, szły_, llbo,
   {{0x3eaa0113,0x00000000,0x00000000,0x00000000}},	//   _tibt_, --, --, --,
   {{0xc4bc0033,0xee3f0023,0x00000000,0x00000000}},	//   _আয়োজ, _quýt_, --, --,
   {{0x9e6307c8,0x00000000,0x00000000,0x00000000}},	//   _тврд, --, --, --,
   {{0xdd8f048f,0x8c430095,0x38c80139,0xb81419e8}},	//   _ذوق_, _кесе, _aìrò_, удиј,
   {{0xae0214e5,0xc6f70084,0x09f6002d,0x78ab084e}},	//   र्थन_, вных_, _ачея, _digv,
   {{0xfd4d0af0,0x3a2c53cd,0x8f9b006e,0x60de007e}},	//   _awoṣ, _undp_, ויפי, _ovpm,
   {{0x39580501,0x38c80065,0xe1f30018,0xa01b003e}},	//   _års_, _dìrò_, یسس_, _sköm,
   {{0xae0206e4,0x69d853ce,0x443f0088,0x2ee953cf}},	//   र्तन_, lave, ðu_, yraf_,
   {{0x38b80682,0xc458007b,0x00000000,0x00000000}},	//   _hér_, тиях_, --, --,
   {{0x61bf2f74,0xf526107a,0xe29808a1,0x32051206}},	//   ्रेष, _афин, каў_, ýly_,
   {{0x2cbf005f,0x443905db,0x00000000,0x00000000}},	//   _čudo_, pjs_, --, --,
   {{0x38b80682,0x69d830e2,0x2ee904e2,0xbbcc030b}},	//   _mér_, have, traf_, ारोक,
   {{0x2fc953d0,0xdddc015c,0x2d8e0364,0x672402ef}},	// [4ad0] rbag_, _skrš, üfen_, _šijj,
   {{0xa2b040c1,0x2ee953d1,0x1d6b0dce,0x5dd50103}},	//   ंदर्, rraf_, وصاً_, اقائ,
   {{0xf3ff00c9,0xa2b90034,0x94170096,0xae022cba}},	//   nião_, _एंड्, _तसाच_, र्धन_,
   {{0x8c3d0702,0x32110c6f,0x00000000,0x00000000}},	//   _kişi, lezy_, --, --,
   {{0x81d60081,0x69d853d2,0x9985078e,0x00000000}},	//   _হাত_, fave, _balş_, --,
   {{0xfe711b67,0xf41f02fd,0x69d82eb8,0xae0200df}},	//   _اگر_, hdä_, gave, र्दन_,
   {{0xdddc0b18,0xd90f0d7f,0x00000000,0x00000000}},	//   _ukrš, تیا_, --, --,
   {{0x38b853d3,0x649d0503,0x224153d4,0x00000000}},	//   _dér_, léif, _lohk_, --,
   {{0x69d80618,0x6456023b,0xfc64008f,0x672d00c4}},	//   bave, ëzim, _търн, _šajb,
   {{0x99675155,0x7bd953d5,0x69d815c1,0x69ca274c}},	//   _ител, lawu, cave, _स्पी,
   {{0xf3ff0396,0x04463051,0xe81e0ccb,0x6fd300a4}},	//   gião_, генн, _मोका_, तरां,
   {{0x8c3d0555,0x26d90103,0x7bd953d6,0x00000000}},	//   _bişi, ásos_, nawu, --,
   {{0x66e50a51,0x6f0701d3,0x00000000,0x00000000}},	//   _сола, nībā, --, --,
   {{0x41a509c3,0x09e50033,0x7bd953d7,0x2cad53d8}},	//   _गृहस, প্রা, hawu, _lied_,
   {{0x628e22d4,0x50b51824,0x09d80081,0xe2970831}},	//   rlbo, исту, _সামা, уар_,
   {{0x69d853d9,0x3dcd0081,0x8c3d00d3,0x64ba0078}},	//   zave, _লাগল, _fişi, _kċin,
   {{0x69d8063d,0x7afd042c,0x7bd953da,0x00000000}},	// [4ae0] yave, _ästh, dawu, --,
   {{0x2bcc0a30,0x533700c1,0xed5a1211,0xbbcc33dc}},	//   ार्थ, _ענין_, ноз_, ार्क,
   {{0x2d9644ec,0x2cad0185,0x69d853db,0x4ce6036a}},	//   урас, _bied_, vave, ужеб,
   {{0x3ce60181,0x69d84698,0xa2cb02d5,0x7bd9019f}},	//   čov_, wave, तीक्, gawu,
   {{0x38b80682,0x201253dc,0x2d0d02d5,0x2cad00ca}},	//   _sér_, meyi_, सबॉल_, _died_,
   {{0x20120491,0x2ab90154,0xd37b006e,0x69d800b3}},	//   leyi_, _dèb_, ערסט, uave,
   {{0xdd920814,0xf41f0084,0x64ba0090,0x7bd953dd}},	//   _طور_, ydä_, _aċin, bawu,
   {{0xdb0208a8,0x06c80081,0x645633f4,0x6f160034}},	//   scoñ, _শিবি, ūzij, owyc,
   {{0xd5b00080,0xc9f600e3,0x6f0701d3,0xd6d7002d}},	//   يفة_, _مساع, cībā, лтэ_,
   {{0x6aca0081,0x24890e32,0x38b80103,0xfaa60aa8}},	//   _রিপো, _skam_, _tér_, _сазо,
   {{0x5fb404a9,0x201253de,0xbebb023b,0x2459004d}},	//   ंखाल, keyi_, _rrëm, вань_,
   {{0x8c3d008b,0xf3ff0131,0x87264db7,0x00000000}},	//   _pişi, rião_, _معتم, --,
   {{0x6eb00ee0,0x4e14009f,0xf3ff0161,0x290d0995}},	//   _अंगु, ड़ाई_, sião_, čkaš_,
   {{0x290c005c,0xa5460103,0xf3ff016d,0xd6270291}},	//   _kpda_, _مضبو, pião_, _боље_,
   {{0x64960037,0x326400e5,0x32111ea1,0x00000000}},	//   máin, стяв, rezy_, --,
   {{0x6018013a,0x64960037,0x20120172,0x00000000}},	//   лося_, láin, geyi_, --,
   {{0x2cad0078,0xe8062301,0xe8150aa1,0x2d980357}},	// [4af0] _ried_, व्या_, ढ़ता_, _azre_,
   {{0x63a90146,0x6496119e,0x539c0327,0x00000000}},	//   žens, náin, _איחו, --,
   {{0x867b00f5,0x2cad53df,0x7bd93683,0x9d1527a5}},	//   ערבו, _pied_, tawu, рдеч,
   {{0x644f4afa,0x3d051161,0x6f0700e8,0x00000000}},	//   nkci, _रहीं_, tībā, --,
   {{0x1614000f,0x7bd953e0,0x649d0076,0x69d908d4}},	//   तजार_, rawu, méid, _नजदी,
   {{0xeab000cd,0x7bd9276a,0x6287129d,0x649d0076}},	//   سعه_, sawu, nojo, léid,
   {{0xa3c500a5,0x48791e00,0x6f0701d3,0x7bd9019f}},	//   एडा_, ксия_, sībā, pawu,
   {{0xaae7012b,0xa6e52cb8,0x644f01cb,0x332901b9}},	//   _مسئو, ажил, jkci, _orax_,
   {{0x628703df,0xfd100068,0x61e50146,0x86990396}},	//   kojo, _وجہ_, _odhl, ктот_,
   {{0xe7080080,0x7b740cd2,0x60c553e1,0xb8db0081}},	//   اتين_, _اطفا, _othm, _অব_,
   {{0x481523a3,0x628717b1,0x6f160034,0x69c14ea8}},	//   _вмес, dojo, zwyc, _ifle,
   {{0xd46a53e2,0x61e503ea,0x63ba02c6,0x386902c3}},	//   тиме_, _adhl, ětno, _öar_,
   {{0xd6c303ed,0xe81e0f53,0x62871b38,0x6496109d}},	//   _امتی, _मोटा_, fojo, báin,
   {{0xe29a0235,0x35a50138,0xe5a54a52,0x33290113}},	//   таг_, _калг, _кили, _drax_,
   {{0x2012026a,0xa06a0e06,0x798d03e3,0x76430350}},	//   teyi_, вава_, ƙawu, _iony,
   {{0x67241523,0x2eb100b6,0x764353e3,0x00000000}},	//   _šiji, जदूत, _hony, --,
   {{0x764353e4,0x6287316d,0x44321515,0x442001b6}},	// [4b00] _kony, bojo, _iny_, _iai_,
   {{0x442053e5,0x44320085,0x64440113,0x114a002d}},	//   _hai_, _hny_, _hoii, _апой_,
   {{0x442053e6,0x76430da3,0x00000000,0x00000000}},	//   _kai_, _mony, --, --,
   {{0x69c153e7,0x09d800c7,0x442053e8,0x649d0037}},	//   _afle, _সাধা, _jai_, réig,
   {{0x442053e9,0x2b160084,0xf1da009f,0x7643010a}},	//   _mai_, рьер, _बजान, _oony,
   {{0x442053ea,0x5eeb02d5,0x290c0063,0x38660a39}},	//   _lai_, _चित्_, _ppda_, _smor_,
   {{0x443253eb,0x09cf0081,0xfce32917,0x442053ec}},	//   _ony_, _রাখা, _моро, _oai_,
   {{0xd90d0281,0x76430a4b,0x69c153ed,0x7d0e1355}},	//   عین_, _aony, _efle, _ipbs,
   {{0xa2b253ee,0x04f20081,0x764353ef,0x25ab00a7}},	//   _इंग्, _জনের_, _bony, əklə_,
   {{0x44320054,0x7c2253f0,0x764305b4,0x6444009c}},	//   _any_, ldor, _cony, _aoii,
   {{0x442053f1,0x7c2053f2,0x764300bf,0x628753f3}},	//   _bai_, _kamr, _dony, vojo,
   {{0x4420072c,0x7aed53f4,0xe70400cd,0x7c2053f5}},	//   _cai_, šate, _هستی, _jamr,
   {{0x442053f6,0x628753f7,0x4432030b,0x629e00e7}},	//   _dai_, tojo, _dny_, _bhpo,
   {{0x7c2001c2,0x7643010a,0x44200231,0x1779013f}},	//   _lamr, _gony, _eai_, _ёсць_,
   {{0x442053f8,0x3d05000f,0x628753f9,0x6444009c}},	//   _fai_, _रहें_, rojo, _foii,
   {{0x442053fa,0x7c2002dd,0x64b3078e,0x7c2201cb}},	//   _gai_, _namr, _căiu, jdor,
   {{0x7c220150,0x6287316d,0x764353fb,0x81d60033}},	// [4b10] ddor, pojo, _yony, _হার_,
   {{0x44200a75,0x7d010222,0x2cb80090,0xe3b00037}},	//   _zai_, _älsk, _burd_, _ترى_,
   {{0x442053fc,0x60c553fd,0xc27c00ca,0x27e60062}},	//   _yai_, _uthm, _ברזי, _odon_,
   {{0x442053fe,0x8c3d00ae,0x4c9500c2,0x3dd8084e}},	//   _xai_, _nişt, щиес, _eerw_,
   {{0x69c101bf,0x26c60197,0x7c2053ff,0xa2cb009d}},	//   _pfle, _ntoo_, _damr, तीच्,
   {{0x98e500e3,0x27e60d2a,0x442200e7,0x6f0f01ff}},	//   مكتو, _adon_, zdk_, _ipcc,
   {{0x76435400,0x94170096,0xf09f00fe,0x9c820141}},	//   _rony, _तसंच_, _khà_, _ščeg,
   {{0x76435401,0x3eb95402,0x64960037,0x987100c6}},	//   _sony, _kust_, gáil, _všį_,
   {{0x44205403,0x3eb90054,0x76435404,0x2d9e00ee}},	//   _rai_, _just_, _pony, _úter_,
   {{0x44205405,0x44325406,0x3eb945ae,0x645d5407}},	//   _sai_, _sny_, _must_, ërin,
   {{0xb9950080,0x442015dc,0x200b025b,0x671c3fac}},	//   _الاب, _pai_, _obci_, _बैठक_,
   {{0xf09f011b,0x645d013f,0x64960037,0x629e0052}},	//   _nhà_, ūrin, cáil, _shpo,
   {{0x44205408,0x386d5409,0x47a50033,0x4b79006e}},	//   _vai_, mier_, _গ্রী, ראָו,
   {{0x386d540a,0x4420006d,0x61462ac0,0xf77001c3}},	//   lier_, _wai_, бега, _تام_,
   {{0x4420540b,0x4432540c,0xf09f01ec,0x3eb900f3}},	//   _tai_, _tny_, _bhà_, _aust_,
   {{0xe3b20391,0x44e307d1,0x386d540d,0x4432060f}},	//   _عرب_, mı_, nier_, _uny_,
   {{0x44e306d7,0x8fa345f4,0x127a0018,0xf09f01b5}},	// [4b20] lı_, зате, _محدث_, _dhà_,
   {{0x7c20540e,0x386d540f,0x3eb95410,0x6d5e5411}},	//   _samr, hier_, _dust_, tzpa,
   {{0x44e30390,0x2ee00257,0x7c20001c,0x6f1d5412}},	//   nı_, ssif_, _pamr, _essc,
   {{0xaae60080,0x7c205413,0xa3d803b3,0xa01b0212}},	//   مستو, _qamr, िरि_, _sköv,
   {{0x7c2201e5,0x3eb9485a,0x386d3813,0x09cf0081}},	//   rdor, _gust_, dier_, _রাজা,
   {{0x09d800c7,0x4df55414,0x44e301d4,0x7c225415}},	//   _সাহা, _мяст, kı_, sdor,
   {{0x386d5416,0x8d63016a,0xa3d840ba,0x6b9b0294}},	//   fier_, _евре, िरा_, _ezug,
   {{0x44e30702,0x6f045417,0x3eb101ff,0xbebb030a}},	//   dı_, otic, _zizt_, _crëw,
   {{0x2bce02e8,0x6f045418,0x64960037,0xf41f02db}},	//   _ह्या, ntic, ráil, klär_,
   {{0x59cf332a,0xb8fe0081,0x14ca007b,0x386d1044}},	//   _स्पर, _তম_, лыми_, aier_,
   {{0x69da0029,0x386d5419,0x994a0f43,0x461401f9}},	//   _iete, bier_, _حلال_, موکر,
   {{0x7bc2541a,0x6f0401d9,0x69da541b,0x386d541c}},	//   ncou, ktic, _hete, cier_,
   {{0x69da4b82,0x7ae40080,0x20be0134,0x136b153d}},	//   _kete, áith, _ọkpụ_, ушни_,
   {{0x69da00dd,0x7ae20167,0x44e3008b,0xe71700d7}},	//   _jete, isot, bı_, _לחדר_,
   {{0x44e30587,0x6f040036,0x7ea90138,0xd5b801d3}},	//   cı_, etic, _užpi, ndām_,
   {{0x69da541d,0x6f04078e,0x7ae2541e,0x6f1d0063}},	//   _lete, ftic, ksot, _pssc,
   {{0x25570092,0x78ba00e7,0x2ca60270,0x69da0381}},	// [4b30] vələ_, _lutv, dmod_, _oete,
   {{0x291e198c,0x69da541f,0x386d0126,0xd35800ca}},	//   _osta_, _nete, zier_, _לשחק_,
   {{0xf09f5420,0x6f042ab6,0xdd9b0950,0x93780281}},	//   _thà_, atic, уша_, _نصیر_,
   {{0x69da058f,0xdda8002d,0xa01b09a8,0xfebb001c}},	//   _aete, стул_, _sjöf, _ماست_,
   {{0x69da2aa6,0x386d5421,0x291e0012,0x6f041173}},	//   _bete, vier_, _asta_, ctic,
   {{0x44e30b88,0x291e0270,0x255700a7,0x386d05c2}},	//   yı_, _bsta_, sələ_, wier_,
   {{0x386d5422,0x69da377e,0x645d0188,0x26c20094}},	//   tier_, _dete, khsi, íkon_,
   {{0xd6d11823,0x7bc25423,0x25e109c3,0x46e935c1}},	//   وقع_, ccou, पण्ण, адин_,
   {{0x291e309c,0x386d1842,0x69ca04f8,0x9f400102}},	//   _esta_, rier_, _स्वी, ngið_,
   {{0x69da4a71,0x44e3008e,0xa01b003e,0x386d5424}},	//   _gete, tı_, _fjög, sier_,
   {{0xe80602e8,0xa509121c,0x64a63d7b,0x7d0500f9}},	//   व्हा_, шена_, жана, nths,
   {{0x44e35425,0x69da3d99,0x6abb0239,0x6295029a}},	//   rı_, _zete, _kuuf, elzo,
   {{0x44e308fd,0x69da01e8,0x8c1a040a,0x888c006e}},	//   sı_, _yete, בורי, _גראַ,
   {{0x59cf2581,0x26cd0036,0xa3d8009f,0x649d0131}},	//   _स्मर, mpeo_, िरह_, téic,
   {{0x69c31ac3,0x6abb010a,0x26cd037a,0x60264a13}},	//   icne, _luuf, lpeo_, одва,
   {{0x6f045426,0x645d5427,0xa9270138,0x00000000}},	//   ttic, chsi, mažė, --,
   {{0x67295428,0x9f40003e,0xc61c0033,0x3b1f02a1}},	// [4b40] nvej, ggið_, তারা_, _nsuq_,
   {{0xee370394,0xa01b5429,0x7bc21423,0x2d9630fa}},	//   ону_, _sköt, wcou, орес,
   {{0x69da542a,0x41d0033a,0x3218542b,0x09d80081}},	//   _rete, _त्यस, mery_, _সালা,
   {{0x69da542c,0x7bc2025a,0x3218542d,0x51f6110a}},	//   _sete, ucou, lery_, _اسکر,
   {{0xbb431736,0x7bc2541c,0x2ca6542e,0x69da542f}},	//   мецк, rcou, rmod_, _pete,
   {{0x98c6264b,0x7bc253a7,0x2ca6028a,0x69da0052}},	//   осил, scou, smod_, _qete,
   {{0x7ae25430,0x69da1bc8,0x768f00f3,0x32180f5a}},	//   ssot, _vete, høys, iery_,
   {{0x69da5431,0xe8e000ef,0x6abb010a,0x00000000}},	//   _wete, hiệp_, _fuuf, --,
   {{0x69da5432,0x645d023b,0x321817c9,0x6abb01ee}},	//   _tete, ërim, kery_, _guuf,
   {{0x78ba0006,0x93f600a7,0x393600ae,0x32185433}},	//   _tutv, şələ, _мэес, jery_,
   {{0x6802030b,0x32185434,0x332000b3,0xd7e6004d}},	//   _půjč, dery_, _asix_, _діло,
   {{0x2bb10251,0xd7f72fad,0x2ef20313,0xafdb0120}},	//   ुँचा, _душ_, kryf_, _fløy,
   {{0x59de0dc4,0x78a25435,0xafdb004d,0x00000000}},	//   _नजार, _ihov, _gløy, --,
   {{0x2ef20185,0x78a20372,0x7afd00f3,0x32185436}},	//   dryf_, _hhov, _åste, gery_,
   {{0x551e0034,0x768f0120,0x00000000,0x00000000}},	//   _बनिए_, røyt, --, --,
   {{0x91cb00a8,0x6295037a,0x6aa6023a,0x00000000}},	//   _त्रै, slzo, गगुर, --,
   {{0x32185437,0x62800031,0xdb19042c,0x00000000}},	// [4b50] bery_, émoc, ubwü, --,
   {{0x69ca0789,0x551e423b,0x9f4001cd,0x2009002b}},	//   _स्ली, _बनाए_, rgið_, sfai_,
   {{0x7c87017b,0x6abb008c,0x3b1f00bd,0x8d680161}},	//   оуде, _suuf, _ssuq_, ојца_,
   {{0x7d055438,0x2121005c,0x00000000,0x00000000}},	//   rths, _ishh_, --, --,
   {{0x2cbf00cb,0x00000000,0x00000000,0x00000000}},	//   _čudu_, --, --, --,
   {{0xdcfb00cd,0x01d90033,0x76b2007f,0xba2200f6}},	//   _پرسش_, _তাঁদ, _słyn, едшк,
   {{0x76b20034,0xafdb00f3,0x768f004d,0x00000000}},	//   _płyn, _sløy, køyr, --,
   {{0x78a20363,0x787e00d9,0xd6c300cd,0x3218142e}},	//   _chov, tīva, ومبی, zery_,
   {{0xf771054f,0xfe0202d5,0xf094021e,0x00000000}},	//   عاب_, र्कस_, ונק_, --,
   {{0x67295439,0x056500c2,0xf9932ce3,0x38b105db}},	//   rvej, звон, _قبض_, _išrm_,
   {{0x3218543a,0x6729543b,0x7ea90138,0xf96b00ae}},	//   very_, svej, _užpu, _трай_,
   {{0x59cf0efb,0x3218543c,0x225a18f0,0xae0b09a1}},	//   _स्तर, wery_, _slpk_, स्तन_,
   {{0x32183ec7,0x7ae40087,0x3a25026a,0x2907543d}},	//   tery_, šitv, _kalp_, ltna_,
   {{0xaadd0557,0x78a9543e,0x3a2501cb,0x768f0120}},	//   नीयक, lmev, _jalp_, røys,
   {{0x20560291,0x10a60508,0xc69200a1,0x753c0364}},	//   птар, зивн, _ראו_, ärzt,
   {{0xa01b13da,0xaec60e1d,0x044600ae,0xd37f00c4}},	//   _skör, збал, _хеин, šćak_,
   {{0x3218543f,0x1f66098a,0x00000000,0x00000000}},	// [4b60] pery_, чкам, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628e5440,0xc1bb00ca,0x91bb00d7,0x00000000}},	//   mobo, _למיש, _למיי, --,
   {{0x78a900dd,0xdd8f0f36,0xc50c006e,0x00000000}},	//   jmev, دوم_, שלאָ, --,
   {{0x20070092,0x2a6c5441,0x2905009e,0x29075442}},	//   əni_, _pmdb_, _aqla_, etna_,
   {{0x26c20181,0x19943546,0x78a25443,0x2907042d}},	//   íkom_, маля, _shov, ftna_,
   {{0xa3ac0bd9,0xbea33979,0x00000000,0x00000000}},	//   केत_, _чарк, --, --,
   {{0x628e023f,0x78a201fa,0x5d7b00ca,0xc863007b}},	//   hobo, _qhov, _האלק, етьи,
   {{0x628e5444,0x2907096f,0x649d259a,0x00000000}},	//   kobo, atna_, féin, --,
   {{0x649d0503,0xc87f00a7,0x3a250231,0x290705db}},	//   géin, ışam_, _galp_, btna_,
   {{0x628e5445,0xd7ef1067,0x557300ae,0x00000000}},	//   dobo, _пу_, егэт, --,
   {{0x35670077,0xf8aa0291,0x00000000,0x00000000}},	//   ярын_, _увек_, --, --,
   {{0xd90e00cd,0xa3be0cce,0x21210167,0x59c600b6}},	//   _شیک_, ेड़_, _sshh_, रुअर,
   {{0x628e5446,0x24800113,0x67225447,0x00000000}},	//   gobo, _ejim_, _isoj, --,
   {{0x06b102c6,0x00000000,0x00000000,0x00000000}},	//   řící_, --, --, --,
   {{0x661a5448,0xa01b09df,0x559700ca,0xf0b404a1}},	//   letk, _sjöb, _מדוע_, ейсь,
   {{0xead700c7,0xbebb0052,0x00000000,0x00000000}},	// [4b70] _সম্ম, _rrës, --, --,
   {{0x661a5449,0x037800ca,0x672d031a,0xff5f03a8}},	//   netk, _מתחת_, _šajk, _ffîn_,
   {{0xa25b0220,0x8c3d026a,0xef1f047e,0x764a03a8}},	//   spôs, _ahşa, _eyüp_, _mofy,
   {{0x69c8544a,0xfc64008f,0x661a0302,0x00000000}},	//   _afde, нъчн, hetk, --,
   {{0x0dcb0a51,0xcfab001c,0xbebb0216,0x00000000}},	//   _губи_, _دادم_, _erër, --,
   {{0x290709a8,0x2296003e,0x1de100c3,0x00000000}},	//   ttna_, tæki_, _फ़ित, --,
   {{0x661a544b,0x67220af0,0x3a25169c,0x649d0076}},	//   detk, _asoj, _valp_, véin,
   {{0x628e2ad2,0x2907544c,0xfbd336c2,0x97d9097a}},	//   zobo, rtna_, _ستر_, цьку_,
   {{0x628e092f,0x2907544d,0x26010b89,0x649d095d}},	//   yobo, stna_, _शादी_, téin,
   {{0x7ae9316d,0x661a483d,0x628e544e,0x00000000}},	//   _ivet, getk, xobo, --,
   {{0x628e544f,0xa78700cd,0x7ae91d15,0x6e272059}},	//   vobo, _کشاو, _hvet, _majb,
   {{0x7ae9135f,0x628e5450,0xecd50034,0x68fc004d}},	//   _kvet, wobo, डीएफ, _årda,
   {{0x4463008f,0x661a5451,0xdd1c0094,0x00000000}},	//   твяв, betk, mšťa, --,
   {{0x661a04a3,0x764a02ad,0x76ba00ca,0x21a61e46}},	//   cetk, _gofy, _ומספ, дигм,
   {{0x27ff5452,0xe2972742,0xe7d14735,0x661c00bc}},	//   ogun_, фар_, _सभाप, õrke,
   {{0x27ff34ac,0x628e0a15,0x10a307c8,0x7ae95453}},	//   ngun_, sobo, висн, _ovet,
   {{0x628e5454,0x032300d3,0xdee31111,0x787e00e8}},	// [4b80] pobo, _адын, коти, zīvo,
   {{0xe292212c,0x00000000,0x00000000,0x00000000}},	//   _جذب_, --, --, --,
   {{0x7ae92260,0xdbc6007a,0x823b00ca,0x8c46004d}},	//   _avet, _mööd, _ועיצ, меже,
   {{0xae020469,0xed57004d,0x6aa602d5,0x69b309c4}},	//   र्जन_, ьох_, गग्र, ेखनी,
   {{0x7ae95455,0x671c417a,0xaca40174,0xb5e30033}},	//   _cvet, _बैंक_, _haịp, _মানচ,
   {{0xbe1600cd,0xd9d80285,0x27ff4c73,0x2bce1677}},	//   _توسع, डरेट, egun_, _ह्रा,
   {{0x661a5456,0x247601d3,0xdd92015a,0x5cf5065c}},	//   vetk, nāms_, _شور_, _пяту,
   {{0x764a0412,0x20005457,0x649d0076,0x7ae40076}},	//   _sofy, ngii_, géil, áits,
   {{0xf09300a1,0x2d985458,0x661a13ea,0x00000000}},	//   כנה_, _hyre_, tetk, --,
   {{0x6446023e,0x7afd0b85,0xae02023a,0x00000000}},	//   ejki, _åsta, र्चन_, --,
   {{0xe01e0b5f,0x38c80260,0x984c0034,0x6475456d}},	//   _पसंद_, _راضی_, jść_, егну,
   {{0x247601d3,0x62805459,0x00000000,0x00000000}},	//   dāms_, émon, --, --,
   {{0xe666545a,0xd62a545b,0x661a0968,0x984c007f}},	//   _отко, _моде_, petk, eść_,
   {{0x6cfe3d34,0xe56f015a,0x38a1119e,0xf3ff0231}},	//   _उमंग_, اطی_, móra_, tiãs_,
   {{0xfbde049d,0x38a1545c,0x00000000,0x00000000}},	//   मराम, lóra_, --, --,
   {{0x6e270a39,0x20000188,0x27e42ba4,0x3eb83bf8}},	//   _sajb, ggii_, namn_, _airt_,
   {{0x3eb8003e,0x64ba02a1,0x3f850034,0xa2b91179}},	// [4b90] _birt_, _eċit, _ślub_, _एंट्,
   {{0x5ec800c7,0x4429545d,0x27e40160,0x80090018}},	//   _লিখে, _haa_, hamn_, _کردہ_,
   {{0x7ae9545e,0x4429545f,0x649d0076,0x3eb80133}},	//   _svet, _kaa_, héim, _dirt_,
   {{0x44295460,0x2d9801df,0x260e277c,0xfbd00190}},	//   _jaa_, _dyre_, त्ती_, لته_,
   {{0x44295461,0x271d000d,0x2d9801af,0x6e2703e5}},	//   _maa_, _भनेर_, _eyre_, _tajb,
   {{0x44295462,0xf2d400c1,0x38a15463,0x2d98181f}},	//   _laa_, דעס_, dóra_, _fyre_,
   {{0xdbd901cd,0x00000000,0x00000000,0x00000000}},	//   _fæðu, --, --, --,
   {{0x44295464,0x2601152c,0x644d01ff,0xf8a80037}},	//   _naa_, _शाही_, _noai, وديه_,
   {{0x7c3b5465,0x2b9000cd,0x38a15466,0x7ae90036}},	//   _inur, _پیوس, góra_, _uvet,
   {{0x7c295467,0xe8df0134,0x7c2b5468,0x645f2bb3}},	//   _haer, _alụm_, ldgr, _alqi,
   {{0x44295469,0xa90700d0,0x20000188,0x7c292866}},	//   _baa_, _زبان, ygii_, _kaer,
   {{0xc20900a1,0x7c2b1a92,0x3d0700a5,0x44291503}},	//   _לה_, ndgr, _हमने_, _caa_,
   {{0x7c3b546a,0x644d546b,0x4429546c,0xdbc600aa}},	//   _mnur, _doai, _daa_, _tööd,
   {{0x66f600a1,0x7c29057a,0x20000188,0x247600e8}},	//   _נמצא_, _laer, wgii_, tāms_,
   {{0xf9920130,0xc5f20341,0x4429546d,0x7c3b546e}},	//   ָרן_, _עדה_, _faa_, _onur,
   {{0x442900ac,0x387f0088,0xe3da0081,0x3eb800bd}},	//   _gaa_, nnur_, _থাকব, _sirt_,
   {{0x2000546f,0x3f86001f,0xa3ac3c80,0xdbd9003e}},	// [4ba0] rgii_, çou_, केश_, _ræðu,
   {{0x63a45470,0x44295471,0x7c3b3a4a,0x7c2b18f0}},	//   _izin, _zaa_, _anur, edgr,
   {{0x44295472,0x7c295473,0xa3ac00b6,0x3eb85474}},	//   _yaa_, _baer, केर_, _virt_,
   {{0x7c2902ad,0x3eb80078,0x64960037,0x44295475}},	//   _caer, _wirt_, máis, _xaa_,
   {{0x7c294b82,0x649600e3,0x45250033,0x62810117}},	//   _daer, láis, যমিক_, člov,
   {{0x2d98074a,0x63a40239,0x7c295476,0x7c2b02ac}},	//   _tyre_, _mzin, _eaer, adgr,
   {{0xada30565,0x6da31a57,0x00000000,0x00000000}},	//   _барл, _бира, --, --,
   {{0x3b0a0097,0x7c290150,0x63a448d3,0x387f0653}},	//   _небо_, _gaer, _ozin, gnur_,
   {{0x44295477,0x39a60065,0x63a45478,0x00000000}},	//   _raa_, _bísí_, _nzin, --,
   {{0x44295479,0x628008a8,0xb602000d,0x649d0037}},	//   _saa_, émol, _část, réim,
   {{0x4429547a,0x63a4395b,0xa3d5163d,0x83f900d3}},	//   _paa_, _azin, конч, менс_,
   {{0xe7864ddf,0x63a4547b,0x4429041c,0x629c01cb}},	//   _пуло, _bzin, _qaa_, elro,
   {{0x442b0027,0x4429547c,0x00000000,0x00000000}},	//   rdc_, _vaa_, --, --,
   {{0x44290fdc,0x63a401d3,0x6726003e,0x39a60139}},	//   _waa_, _dzin, ækju, _gísí_,
   {{0x4429547d,0x63a4547e,0x6aba547f,0x644d01ff}},	//   _taa_, _ezin, _mitf, _toai,
   {{0x759b03c2,0x645f023b,0x6aba5480,0x44290085}},	//   _מיוח, _ulqi, _litf, _uaa_,
   {{0xf41f00c2,0x64960076,0x09e60033,0x7c29010a}},	// [4bb0] meä_, ráit, _নানা, _raer,
   {{0x38a10088,0x7c3b5481,0x765a0138,0x2ee90178}},	//   jórn_, _snur, nkty, rsaf_,
   {{0x649600e3,0x7c295482,0x61e75483,0x2296003e}},	//   cáis, _paer, majl, rækt_,
   {{0x64960037,0xafdb0170,0x61e704d6,0x00000000}},	//   láir, _snøf, lajl, --,
   {{0x7c2b5484,0x09d80033,0x27ef0027,0x7c295485}},	//   rdgr, _সাজা, _rdgn_, _vaer,
   {{0x6f0d0d2a,0x7c295486,0x50d4015a,0x64960076}},	//   mtac, _waer, _جزیر, náir,
   {{0x6f0d5487,0x9d183fea,0xf41f00c2,0x26cf037a}},	//   ltac, _порт_, keä_, _stgo_,
   {{0x61e75488,0x6f0d01f7,0xa3ac0006,0x64960076}},	//   hajl, otac, केँ_, háir,
   {{0xb8c8007d,0x7c84007e,0xd7060084,0x387f5489}},	//   _खी_, _суре, вные_, rnur_,
   {{0x6285015c,0xd12102d5,0x61e70880,0x6b9b063d}},	//   _njho, मबाण_, jajl, _iyug,
   {{0xc9594f89,0x63a40068,0x69ca014e,0x6f0d548a}},	//   _تلاش_, _szin, _स्टी, htac,
   {{0xa01b0212,0x6f0d548b,0x765a548c,0x00000000}},	//   _sjön, ktac, akty, --,
   {{0x032300d6,0xa85600ca,0xa3ac0861,0x00000000}},	//   адян, _שינה_, कें_, --,
   {{0x64960076,0x6b9b0079,0x99870103,0x765a0ac1}},	//   gáir, _myug, lenő_, ckty,
   {{0x26c20181,0x40960058,0x09e60081,0x20c70023}},	//   íkov_, врат, _নামা, _cõi_,
   {{0x20c70019,0x4e1406ed,0x6f0d0022,0x3e64548d}},	//   _dõi_, न्नै_, ftac, _möte_,
   {{0x6b9b0018,0x63a4548e,0x00000000,0x00000000}},	// [4bc0] _nyug, _uzin, --, --,
   {{0x3f9c01d3,0x02fb0266,0x0e6313a4,0x00000000}},	//   āvu_, _קלימ, акун, --,
   {{0xa06a1d57,0x6f0d0441,0xf8b30be4,0xa01b003e}},	//   _жана_, atac, ुदाय, _kjöl,
   {{0xf53600c1,0x6f0d0022,0x6b9b3ffb,0x2d950360}},	//   כטער_, btac, _byug, урус,
   {{0xa01b0ee1,0x80af0034,0x6f0d548f,0x6b9b0169}},	//   _mjöl, ंगरे, ctac, _cyug,
   {{0x9f42023b,0x00000000,0x00000000,0x00000000}},	//   _lekë_, --, --, --,
   {{0xda650037,0x6b89078e,0x6b9b063d,0x7aeb009c}},	//   داني, _exeg, _eyug, asgt,
   {{0xdca60a22,0xd7f00037,0x5ca6002d,0x00000000}},	//   _раби, حكة_, _рибб, --,
   {{0xe3e10081,0x9f490088,0xa09b00ca,0x799a0034}},	//   _ভালব, ngað_, ויקט, _wytw,
   {{0x2bce0bd9,0x6aba18f0,0x00000000,0x00000000}},	//   हुरा, _uitf, --, --,
   {{0x4e350130,0x765a0222,0x61e70d62,0x4e1405d6}},	//   אָרן_, rkty, vajl, न्यै_,
   {{0x8979006e,0x2baf0d75,0x9979006e,0x290c01ee}},	//   _אָנה, जेवा, _אָנפ, _iqda_,
   {{0xae0304f1,0x61e75490,0xdcfc00c6,0x6f0d11bc}},	//   _लालन_, tajl, _tyrė, xtac,
   {{0x175700ca,0x9737021e,0x07a30284,0x9421013c}},	//   _בסדר_, _שרגא_, _тачн, _əsər_,
   {{0xc6930132,0xa01b0682,0x61e75491,0x7ae0023e}},	//   _דאס_, _fjöl, rajl, _lwmt,
   {{0x20c705a7,0x6f0d5492,0x61e70b88,0x9f9d0088}},	//   _või_, ttac, sajl, _bæði_,
   {{0x53350562,0xc6250081,0x3eaa009c,0x26172fbd}},	// [4bd0] _септ, বারা_, _bhbt_, _बॉडी_,
   {{0x6f0d5493,0x3a2c47a6,0x81dd0081,0x6d45023e}},	//   rtac, _nadp_, _ডাক_, txha,
   {{0x7bf91107,0x20160206,0xc7b901f9,0x00000000}},	//   енер_, ícií_, ndőr_, --,
   {{0x645d5494,0x6f0d5495,0x00000000,0x00000000}},	//   nksi, ptac, --, --,
   {{0x7ae0030a,0x6d4a0170,0x61e5107b,0x9f9d01cd}},	//   _cwmt, øfar, _kehl, _gæði_,
   {{0x3a2c0072,0x61e502c6,0x6b9b0027,0x00000000}},	//   _cadp_, _jehl, _vyug, --,
   {{0xa3e31edd,0x645d056e,0x3a3e03a9,0x7e60020a}},	//   धरा_, kksi, _dntp_, _împa,
   {{0xccf20054,0x39490335,0x7af6013f,0x9f42022b}},	//   _לכל_, ćas_, šyta, _bekè_,
   {{0x62950018,0x7ae003a8,0x00000000,0x00000000}},	//   kozo, _gwmt, --, --,
   {{0xb7bd00d3,0x61e55496,0xa2c209c3,0x645d0b8e}},	//   deţe, _nehl, लदस्, eksi,
   {{0x69c15497,0xf3e6283b,0x1fb04080,0xdd1204a8}},	//   _igle, лжно, _झण्ड, _müşr,
   {{0xb7bd020a,0x388500e8,0xd6d9007f,0x00000000}},	//   feţe, mēro_, zyły_, --,
   {{0x81d50f71,0xc87908bb,0x61e5019f,0x7ae0023e}},	//   _হয়_, miş_, _behl, _xwmt,
   {{0x412a14ae,0xc8790491,0x43751b60,0x645d2ac9}},	//   ного_, liş_, руют, ërir,
   {{0x61e55498,0x216a1d62,0x00000000,0x00000000}},	//   _dehl, хиви_, --, --,
   {{0xc87907d1,0x787e01d3,0x3eaa0063,0x645d0703}},	//   niş_, tīvi, _shbt_, cksi,
   {{0x44225499,0xee3a549a,0x69c119d0,0x61e502dc}},	// [4be0] mek_, нна_, _ogle, _fehl,
   {{0x69c1012b,0xb22605e1,0xc87900a7,0x5d6a1b2d}},	//   _ngle, _смол, hiş_, низм_,
   {{0xf1a8000d,0xc87901e8,0xdca60476,0x2d9c02b6}},	//   _गरिन, kiş_, гажи, æve_,
   {{0x4422549b,0x61e54697,0x16130f38,0xfb8a0231}},	//   nek_, _zehl, त्तर_, нбек_,
   {{0x6d430149,0x44220634,0xc8790345,0x00000000}},	//   änar, iek_, diş_, --,
   {{0x90e5015a,0xe3bf0072,0x28f800ae,0x31e20033}},	//   _حسین, meñe_, векь_, _বাঁশ,
   {{0x4422549c,0x645d0084,0x9f420154,0x00000000}},	//   kek_, yksi, _sekè_, --,
   {{0x4422549d,0x6e2e549e,0x6295549f,0xd6da0cb0}},	//   jek_, _habb, zozo, нто_,
   {{0x20570130,0x3b8614f2,0x6a66003e,0x7c2254a0}},	//   טיקל_, _слаг, _aðfe, meor,
   {{0x91d4000f,0x7c22044c,0x09b90033,0xa3cd0592}},	//   _ब्लै, leor, ঁড়া, शुई_,
   {{0x6295030b,0x442254a1,0x61e50063,0x6e2e083e}},	//   vozo, fek_, _rehl, _mabb,
   {{0x44220018,0x645d0084,0x6e2e54a2,0x69c10087}},	//   gek_, uksi, _labb, _zgle,
   {{0xb8930037,0x629554a3,0x7a210174,0xb7bd020a}},	//   _النع, tozo, ịtek, teţe,
   {{0x6e2e083e,0x45d454a4,0x7c2254a5,0x25ee0096}},	//   _nabb, _токс, heor, _आयटी_,
   {{0xd49b2b53,0x629554a6,0x27e60124,0x7c220120}},	//   _при_, rozo, _keon_, keor,
   {{0x4422074e,0x4fd554a7,0x61e554a8,0x6e2e0188}},	//   cek_, ржат, _wehl, _aabb,
   {{0x7c2254a9,0x6e2e0a75,0xf3ff001f,0x61e554aa}},	// [4bf0] deor, _babb, lhão_, _tehl,
   {{0xe45f0149,0x60c554ab,0xc879013c,0x27e60133}},	//   lkö_, _tuhm, ziş_, _leon_,
   {{0x6e2e40fb,0xf3ff001f,0xc8790740,0xfbd60033}},	//   _dabb, nhão_, yiş_, _হয়ত,
   {{0x7c2254ac,0xe45f007b,0x69c154ad,0x388500e8}},	//   geor, nkö_, _sgle, vēro_,
   {{0x6e2e54ae,0xab2911b4,0xbb4507df,0x200b01b9}},	//   _fabb, тола_, релк, _icci_,
   {{0x442254af,0x2bd502d5,0x27e90d12,0xe45f007b}},	//   zek_, _ड्रा, _žan_, hkö_,
   {{0x442254b0,0x325800a1,0x684501a0,0xe45f00c2}},	//   yek_, רסום_, инка, kkö_,
   {{0x5d8400e3,0x7ccc03a3,0x6e2e083e,0xbd050032}},	//   _الفل, _uğra, _zabb, _eléé,
   {{0xc8790702,0x27e60313,0x7b673732,0x574600e5}},	//   riş_, _deon_, _стве, изъм_,
   {{0x442254b1,0x6e2e008c,0x00000000,0x00000000}},	//   wek_, _xabb, --, --,
   {{0x442254b2,0x35a50077,0xd46a4b95,0xe5a5117f}},	//   tek_, ранг, вине_, рини,
   {{0x6f1d01c0,0x3e640212,0x76b20034,0x200b02ac}},	//   _opsc, _möta_, _błys, _ncci_,
   {{0x442254b3,0x76b200a5,0x24890113,0xe8b30096}},	//   rek_, _płyt, _djam_, ुदीच,
   {{0x442254b4,0x368b54b5,0x27e601ff,0x00000000}},	//   sek_, _ясен_, _zeon_, --,
   {{0x442254b6,0xc0e64e42,0x64a61940,0xf3ff016d}},	//   pek_, робк, _кака, chão_,
   {{0x6e2e54b7,0x7cc50138,0x251a00ca,0x44e30103}},	//   _sabb, _gėri, _יוצא, mű_,

   {{0x6e2e0088,0x7d1c0a39,0x00000000,0x00000000}},	// [4c00] _pabb, _sprs, --, --,
   {{0x2bde0af1,0x9dba0281,0x2cbf020a,0x6e2e54b8}},	//   मर्थ, نداز_, _aiud_, _qabb,
   {{0x6e2e00e5,0xa0a63333,0x716a3e1c,0x10a61b60}},	//   _vabb, _ванд, _ранг_, _винн,
   {{0x6e2e4f77,0x3d07007a,0xe3bf0143,0x00000000}},	//   _wabb, _हमरे_, señe_, --,
   {{0x6e2e1114,0x7e6000d3,0x7bc4013f,0x7c2254b9}},	//   _tabb, _împo, žiuo, reor,
   {{0x7c2206ee,0xb8f40037,0xe9df00de,0x7af60138}},	//   seor, مكتب, _đúc_, šyto,
   {{0x6f040091,0x672b00dd,0x7c220328,0x7d1c14f3}},	//   luic, _asgj, peor, _uprs,
   {{0x649d54ba,0x5fc6009f,0xc5f00033,0x00000000}},	//   néit, लखिल, জ্ঞা_, --,
   {{0x44f103e5,0x76aa00c2,0xbebb023b,0x627600e8}},	//   eġ_, ктов_, _rrëz, rņoj,
   {{0x649d020d,0x27e6037a,0x1daa0861,0x24890216}},	//   héit, _weon_, _करात, _sjam_,
   {{0x994a1b49,0xe45f0084,0x24590c5b,0x76b20034}},	//   _جلال_, tkö_, гань_, _słys,
   {{0x7d0305fe,0x291e0332,0xd4980012,0x6f0403e3}},	//   ànsi, _ipta_, иря_, kuic,
   {{0x3d08009d,0x3866044c,0x00000000,0x00000000}},	//   ांडे_, _ilor_, --, --,
   {{0x48fd000d,0x3d070034,0xe45f1b9f,0x6f0401ec}},	//   रूको_, _हमले_, skö_, duic,
   {{0x20190167,0x313500e5,0x00000000,0x00000000}},	//   _pbsi_, щевр, --, --,
   {{0x4e1939d4,0xfe190096,0xc1040037,0x61e20218}},	//   न्नई_, न्नस_, توفي, _đole,
   {{0x6f0454bb,0x3e640212,0x25ed009f,0x00000000}},	// [4c10] guic, _söta_, _आजमी_, --,
   {{0x644f0106,0x7e6000ae,0x291e54bc,0x386600b3}},	//   ljci, _împl, _opta_, _llor_,
   {{0x386654bd,0x6287042d,0x9f400231,0x00000000}},	//   _olor_, mnjo, raiá_, --,
   {{0x6280025b,0xbd440037,0x644f015c,0x6f0454be}},	//   émov, تنمي, njci, buic,
   {{0x649d00da,0x00000000,0x00000000,0x00000000}},	//   léis, --, --, --,
   {{0xa3ac2231,0x386654bf,0x200954c0,0x0dcb02e1}},	//   केट_, _alor_, lgai_, _шуми_,
   {{0xceb20130,0x5c0700c2,0x649d0037,0x20f300c4}},	//   _מיך_, _вяза, néis, nći_,
   {{0x20091a2c,0x6c8500e3,0x4c94007b,0x386654c1}},	//   ngai_, _الرم, _дисс, _clor_,
   {{0xf74900cd,0x09e60033,0x649d0fdb,0x62870218}},	//   اجعه_, _নারা, héis, knjo,
   {{0x62870995,0x386654c2,0x20f300e7,0xd4d901b3}},	//   jnjo, _elor_, kći_, льмі_,
   {{0x628703ce,0xc32900f5,0x99351b49,0x1acf0033}},	//   dnjo, _רו_, _دفات, _রিয়া,
   {{0xdd380029,0x15f3116e,0x491c2373,0x44e30103}},	//   nāša, _आयकर_, _महतो_, rű_,
   {{0x38a10088,0x27ed54c3,0x649d0072,0xa6c9022a}},	//   jóri_, maen_, véit, _ёлка_,
   {{0x27ed02ad,0xe611001c,0x9ad30174,0x7d050113}},	//   laen_, _رشت_, yịnw, kuhs,
   {{0x76430067,0xa06a013d,0x649d033c,0xa3ac0bf5}},	//   _inny, гава_, téit, केज_,
   {{0x320c00a5,0x27ed54c4,0x00000000,0x00000000}},	//   żdy_, naen_, --, --,
   {{0x644400a6,0x3fcb1ac9,0x628700e7,0x649d0037}},	// [4c20] _inii, ادفی_, bnjo, réit,
   {{0x443254c5,0x6f0454c6,0xf41f007b,0x6456041c}},	//   _hay_, ruic, nnän_, _hoyi,
   {{0x4432440d,0x5bc600e3,0x61ee54c7,0x2009005c}},	//   _kay_, مقال, mabl, bgai_,
   {{0xdd8f54c8,0x645654c9,0x61ee54ca,0x8b6a008f}},	//   رون_, _joyi, labl, лиев_,
   {{0x4432004f,0x645606a3,0xa3ac0096,0xa2ce097c}},	//   _may_, _moyi, केच_, _धूम्,
   {{0x64560065,0x523a0130,0x3320030b,0x649d00e3}},	//   _loyi, רײַנ, _mpix_, néir,
   {{0x629e0129,0xed570a29,0x27ed54cb,0xdd3801d3}},	//   _mkpo, _лор_, faen_, bāša,
   {{0x764354cc,0x44322d6f,0xc6f85011,0xb8810220}},	//   _anny, _nay_, аних_, _šíre,
   {{0x7d1b00e7,0x629e0129,0x254e0092,0x6d5e54cd}},	//   _ćusi, _okpo, məli_, lypa,
   {{0xbb3b00c1,0x61ee037a,0x443254ce,0x629e0134}},	//   _געמי, jabl, _aay_, _nkpo,
   {{0x6456130e,0x443254cf,0xd94328f1,0xfe9b0089}},	//   _boyi, _bay_, _нефи, ריימ,
   {{0x764354d0,0x629e0134,0x443254d1,0x61ee0143}},	//   _enny, _akpo, _cay_, eabl,
   {{0x443254d2,0x628708a9,0xd5440032,0x7e7e0116}},	//   _day_, tnjo, _bẹ̀r, kipp,
   {{0x61ee1d32,0x649d0037,0xa6b6008f,0x6444010a}},	//   gabl, téis, _усещ, _enii,
   {{0x443254d3,0x645626e3,0xf64f001c,0x4a5b0142}},	//   _fay_, _foyi, _سئو_, נדלו,
   {{0x629e0129,0x20090138,0x645654d4,0x6444009c}},	//   _ekpo, ugai_, _goyi, _gnii,
   {{0x623554d5,0x61ee1647,0x62870234,0xd5440139}},	// [4c30] _депу, babl, pnjo, _fẹ̀r,
   {{0x63ad03f3,0x443254d6,0x51870f2e,0x6dc700c2}},	//   _izan, _zay_, _гума, ссаж,
   {{0x64561a69,0x601910bb,0x254e013c,0x443217bb}},	//   _yoyi, _коня_, fəli_, _yay_,
   {{0xac194171,0x443254d7,0x764401c2,0xc1b50442}},	//   роду_, _xay_, _ɗiya, ंधीग,
   {{0xa3ea0c9c,0x3de80081,0xdea40018,0x7d050231}},	//   यरत_, _পারল, _کیلی, suhs,
   {{0x63ad54d8,0xdcf4020e,0x08d53ac9,0x388500e8}},	//   _mzan, _çağl, оция, mēri_,
   {{0x6d5e0113,0x27ed54d9,0x00000000,0x00000000}},	//   cypa, taen_, --, --,
   {{0x61ee0845,0x63ad1b5a,0x1fe70033,0x9c6500d1}},	//   zabl, _ozan, _ফাঁস, _بهرو,
   {{0x27ed54da,0x656d01c2,0x443254db,0x63ad05bd}},	//   raen_, _ƙaho, _ray_, _nzan,
   {{0x443254dc,0x06960037,0xb659004d,0xe6161aad}},	//   _say_, ينية_, рших_, одь_,
   {{0x63ad54dd,0x443200a1,0xe3bf0072,0xe7680281}},	//   _azan, _pay_, veña_, لحین_,
   {{0x290754de,0xdb070653,0x87b90983,0x3a2700e7}},	//   muna_, _ímót, _култ_, lenp_,
   {{0xd6db1756,0x6d5e00a5,0x61ee1647,0x443254df}},	//   _сте_, zypa, tabl, _vay_,
   {{0x386d00c9,0x44320054,0x95cb54e0,0x11da0037}},	//   lher_, _way_, _суда_, شورة_,
   {{0x61ee54e1,0x443200ef,0x290754e2,0x059500cd}},	//   rabl, _tay_, nuna_, _باشگ,
   {{0xe3bf0081,0x70b400df,0xd12f0103,0x6d5e54e3}},	//   seña_, ंगेल, کمہ_, vypa,
   {{0xa06707f3,0x8fa32457,0x290711b9,0x7e7e54e4}},	// [4c40] цата_, дате, huna_, tipp,
   {{0x290754e5,0xa3af267b,0x6d5e54e6,0x63a41621}},	//   kuna_, _करत_, typa, _iyin,
   {{0x290754e7,0xb5fa006e,0x38a12ce2,0x63ad0172}},	//   juna_, שלעכ, lóru_, _zzan,
   {{0x290754e8,0x629c54e9,0x6d5e54ea,0xc50c006e}},	//   duna_, loro, rypa, רלאָ,
   {{0x386d003d,0x9d0a0081,0x7ff7001c,0xda051101}},	//   dher_, রবেন_, _بسپا, _राखत_,
   {{0x290754eb,0x63a402a4,0x6f1654ec,0xab5d0090}},	//   funa_, _myin, mtyc, _egżo,
   {{0x290754ed,0xa3ea2373,0x20e800ae,0xed5a004d}},	//   guna_, यरा_, nşi_, _тов_,
   {{0x629c54ee,0x63a43c53,0x386d54ef,0x254e013c}},	//   horo, _oyin, gher_, qəli_,
   {{0x63a454f0,0x629c54f1,0x290700d3,0x368a1d68}},	//   _nyin, koro, auna_, исон_,
   {{0x2ca654f2,0x629c54f3,0x76aa001f,0xda660076}},	//   llod_, joro, јтив_, _باري,
   {{0x63a43f3e,0x63ad472c,0xd7ef455b,0x2bba049d}},	//   _ayin, _szan, _оу_, ेशवा,
   {{0x386d54f4,0x6f1600a5,0x63a4023f,0x2ca60ddc}},	//   cher_, ktyc, _byin, nlod_,
   {{0x629c54f5,0x63a405bd,0x779205bc,0xf76f00d1}},	//   foro, _cyin, _زیدا, _لاو_,
   {{0x59dd000d,0xcfe70033,0x629c1aa3,0x67220231}},	//   नुपर, _ফাইন, goro, _ipoj,
   {{0xc0cb2348,0xc7ad0018,0x2ca606a8,0x63a454f6}},	//   руге_, _لڑی_, klod_, _eyin,
   {{0x67220174,0x200f00aa,0x4395084c,0x6280020d}},	//   _kpoj, ügi_, _найс, émor,
   {{0x629c54f7,0x7658023e,0x29070a00,0x63ad54f8}},	// [4c50] boro, _kovy, zuna_, _uzan,
   {{0xe3bf0610,0x290754f9,0x00000000,0x00000000}},	//   leño_, yuna_, --, --,
   {{0x20e8020a,0x290754fa,0x2ca621ad,0x00000000}},	//   cşi_, xuna_, flod_, --,
   {{0xa3af13b4,0x2907322a,0x6fda02d5,0x69c8004d}},	//   _करा_, vuna_, युदं, _agde,
   {{0xfe73046b,0x3d07007a,0x290754fb,0xcfab14ea}},	//   _قدس_, _हमके_, wuna_, _خادم_,
   {{0xdc550018,0x9ad30174,0x76580094,0x00000000}},	//   _کرسک, lịkw, _novy, --,
   {{0x386d004f,0x67220065,0x6b8d00ae,0x2ca6032e}},	//   ther_, _apoj, _ţigă, blod_,
   {{0x629c54fc,0x25ed0096,0x9ad30294,0xe3bf037a}},	//   zoro, _आजही_, nịkw, jeño_,
   {{0x290754fd,0x386d02e2,0x629c46b6,0xe3bf0328}},	//   suna_, rher_, yoro, deño_,
   {{0x7ae91a25,0x386d54fe,0x6e3554ff,0x9ad30129}},	//   _iwet, sher_, _jazb, hịkw,
   {{0x629c2af0,0x64a65500,0xe9d01790,0x386d5501}},	//   voro, зана, _شغل_, pher_,
   {{0x7ae95502,0x629c5503,0xdb00020d,0x6f16007f}},	//   _kwet, woro, _symé, ytyc,
   {{0x629c1125,0x87044345,0x7ae9009e,0x888c006e}},	//   toro, _قبول, _jwet, _דראַ,
   {{0x70b40c13,0xf77012eb,0x7ae95504,0x2f140212}},	//   ंग्ल, _جام_, _mwet, väg_,
   {{0x629c423d,0x213e0037,0x7e6000ae,0x6a6f0120}},	//   roro, íth_, _împi, _tøff,
   {{0x629c5505,0xcfe70033,0xe3bf034f,0x20e85506}},	//   soro, _ফাউন, ceño_, rşi_,
   {{0x44205507,0x629c5508,0x7ae906c0,0x63a4019f}},	// [4c60] _ibi_, poro, _nwet, _uyin,
   {{0x388501d3,0x6f16007f,0x7bc945e0,0xa01b5509}},	//   mēru_, rtyc, _ageu, _sjöt,
   {{0x6f160067,0x0c26550a,0x7ae90172,0x6e35007e}},	//   styc, змен, _awet, _dazb,
   {{0x3d1c550b,0x9b6a0426,0x7ae90517,0x26df0174}},	//   _नहीं_, йшла_, _bwet, kpuo_,
   {{0x4420550c,0xfaa6550d,0x2ca6550e,0x225a0154}},	//   _mbi_, падо, rlod_, _kopk_,
   {{0x8d66550f,0x44202773,0x6f041e03,0xa3af007a}},	//   _евге, _lbi_, mric, _करस_,
   {{0x672201d9,0x442006c0,0x7ae90129,0x6f045510}},	//   _spoj, _obi_, _ewet, lric,
   {{0x44205511,0xdca31693,0x76585512,0x7ae90154}},	//   _nbi_, _заси, _sovy, _fwet,
   {{0x07f700e3,0x6f045513,0xa01b0088,0x7ae90361}},	//   سريع_, nric, _kjör, _gwet,
   {{0x44205514,0x6f040a1b,0xe67800d6,0x60c601d3}},	//   _abi_, iric, ійні_, _likm,
   {{0x44205515,0x7ae90acb,0xe3bf0143,0x7afd059a}},	//   _bbi_, _zwet, teño_, _åstr,
   {{0x2b205516,0x60c60496,0x00000000,0x00000000}},	//   _यहाँ_, _nikm, --, --,
   {{0xa5f80277,0xe3bf5517,0x6f040381,0x00000000}},	//   _делу_, reño_, jric, --,
   {{0x44205518,0xe3bf11ce,0xf7bb00ca,0x7afd0537}},	//   _ebi_, seño_, _הזדמ, _æste,
   {{0x6f040036,0xe3bf0610,0xceb400a7,0x78a2010a}},	//   eric, peño_, ktəb_, _kkov,
   {{0x6e3502c6,0x30a4038a,0x00000000,0x00000000}},	//   _sazb, ерув, --, --,
   {{0xa01b5519,0xbfab2787,0x3ed90037,0x6d58084d}},	// [4c70] _björ, стве_, زواج_, ävan,
   {{0x442b0fee,0x4439551a,0x7bc90013,0x9ad30294}},	//   lec_, lds_, _sgeu, sịkw,
   {{0x7ae9551b,0x6e3500b6,0x2dd80037,0x6fa20096}},	//   _swet, _vazb, سبلة_, _कुठू,
   {{0xc0ab0678,0x4439551c,0x442b551d,0x78a20ab9}},	//   _داخل_, nds_, nec_, _nkov,
   {{0x4439551e,0x1a65037f,0x6f0403be,0xa01b003e}},	//   ids_, ویری_, cric, _fjör,
   {{0x78a200e7,0x442b551f,0xbb4214e0,0xa01b003e}},	//   _akov, hec_, тешк, _gjör,
   {{0x442b407d,0x261300b6,0xdd940dd8,0x63a8007f}},	//   kec_, _दाबी_, _зары, ędni,
   {{0xba7700cd,0x44395520,0x673b09ac,0x7ae95521}},	//   _کارت, jds_, tvuj, _twet,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443904ee,0x44205522,0x7c2b5523,0x673b0094}},	//   eds_, _sbi_, legr, rvuj,
   {{0xb5790084,0x44205524,0x442b00ee,0x66e30139}},	//   ющих_, _pbi_, fec_, _bíkò,
   {{0x442b2281,0x6f045525,0x44200113,0xe1e61e05}},	//   gec_, yric, _qbi_, कर्ण_,
   {{0x78a90973,0x087600c1,0xe738004d,0x60c65526}},	//   mlev, _קענט_, _неї_, _rikm,
   {{0x60c65527,0x6f045528,0x68030032,0x27ef0537}},	//   _sikm, vric, _fìjà, _hegn_,
   {{0x442b1fe8,0x3d0c00a5,0x6f045529,0x78a94880}},	//   bec_, _हमें_, wric, olev,
   {{0x4420552a,0x78a9552b,0x26c70193,0x388501d3}},	//   _ubi_, nlev, _hino_, mērs_,
   {{0x26c7552c,0x26cf552d,0x6f04009c,0xaec61fdb}},	// [4c80] _kino_, _jugo_, uric, дбал,
   {{0x26cf552e,0x6f04552f,0x26c720e3,0xa3d600bc}},	//   _mugo_, rric, _jino_, ाँक_,
   {{0x26cf0933,0x6f045530,0x78a90bd3,0x60c65531}},	//   _lugo_, sric, klev, _tikm,
   {{0x26c75532,0x7c2b49bc,0x32d40084,0x50b63006}},	//   _lino_, gegr, _käy_, _існу,
   {{0x78a95533,0xa01b238c,0x628e0565,0x00000000}},	//   dlev, _tjör, onbo, --,
   {{0x442b1c7f,0x78a201c5,0x78a95534,0x628e5535}},	//   zec_, _skov, elev, nnbo,
   {{0x7c2b0dbc,0x44395536,0x628e5537,0x78a95538}},	//   begr, yds_, inbo, flev,
   {{0x29005539,0x26cf0d2a,0x8b260396,0x6c310018}},	//   čia_, _bugo_, _одбе, _مہما,
   {{0x26c70283,0x61fe1e4d,0x388501d3,0x32d4007b}},	//   _bino_, _odpl, vērt_, _näy_,
   {{0x26c703a9,0x98ae008b,0x628e029a,0x78a9553a}},	//   _cino_, ınır_, jnbo, alev,
   {{0x26c7553b,0x78a9553c,0x7ae2553d,0x7e6000ae}},	//   _dino_, blev, lpot, _împu,
   {{0x27ef0088,0x628e18f0,0xa3d650da,0x32060022}},	//   _gegn_, enbo, ाँग_, _ɓoye_,
   {{0x4439553e,0x26c7553f,0x442b2778,0x7ae25540}},	//   rds_, _fino_, rec_, npot,
   {{0x26c72a8c,0x31350086,0x7c2b0034,0x65945541}},	//   _gino_, негр, zegr, _палу,
   {{0x6d58007b,0x6aaa00f0,0x00000000,0x00000000}},	//   äval, ilff, --, --,
   {{0x9ed90077,0x26c70517,0x628e5542,0x24800167}},	//   змат_, _zino_, anbo, _gmim_,
   {{0x69da5543,0xeb0d099d,0x26cf002b,0x15f20096}},	// [4c90] _ofte, _समेत_, _xugo_, _आजार_,
   {{0x26c700ee,0x78a04835,0x00000000,0x00000000}},	//   _xino_, homv, --, --,
   {{0x8c3d01e8,0xdb00002b,0x61f5008b,0x78a00079}},	//   _akşa, _gzmú, mazl, komv,
   {{0x1ddf052c,0x69da40d5,0x1bd55544,0x6d41034f}},	//   _प्रत, _afte, ходя, _álam,
   {{0x7c2b0042,0x27ef02fe,0x9c1300ac,0x3897020a}},	//   regr, _regn_, họgh, năre_,
   {{0xdcfb00bf,0x26cf0193,0x6f0d5545,0x9c130134}},	//   _ورزش_, _rugo_, muac, kọgh,
   {{0x6f0d38c4,0x26c75546,0x78a94f97,0x26cf5547}},	//   luac, _rino_, tlev, _sugo_,
   {{0x69da0651,0x26c75548,0x26cf00f9,0x61f5008b}},	//   _efte, _sino_, _pugo_, hazl,
   {{0x6f0d3964,0x78a95549,0x27ef00b7,0x26130ed3}},	//   nuac, rlev, _vegn_, _दादी_,
   {{0x99671d0b,0x5b34015a,0x7afb04ff,0xb7bd020a}},	//   _отел, _جعفر, _ivut, neţi,
   {{0x78a91bfa,0x27ef0856,0x6f0d554a,0x03e70033}},	//   plev, _tegn_, huac, _কাজী_,
   {{0xa7751231,0x26c7554b,0x764a0178,0x00000000}},	//   _плеч, _wino_, _enfy, --,
   {{0x3ea10006,0x2f2301d3,0x26dd05bd,0xe3b20674}},	//   koht_, nīgā_, _utwo_, طرح_,
   {{0xd774097d,0x6f0d1c40,0x7afb0239,0x64620034}},	//   _جامع, duac, _mvut, _świą,
   {{0xe297554c,0x628e1b87,0x6acb16e2,0x7bdb0361}},	//   хар_, rnbo, ादुर, _ofuu,
   {{0x7bdb083e,0x9f52014b,0x7afb0415,0x00000000}},	//   _nfuu, layé_, _ovut, --,
   {{0x06e30081,0x6f0d554d,0x2d870610,0x61f5554e}},	// [4ca0] _মিডি, guac, únen_, bazl,
   {{0xa2d50bb5,0x7bdb554f,0xee375550,0x33770327}},	//   _यंत्, _afuu, нну_, _נעים_,
   {{0x9f4202fd,0x7afb5551,0x9e431405,0x6f0d009c}},	//   _sekä_, _avut, áďat, auac,
   {{0xdee6191b,0xe8df00ac,0x6ab80179,0x7ae22e7f}},	//   _поми, ahịa_, इग्र, tpot,
   {{0x7ae21419,0x6f0d0e4d,0x29075552,0x80d602d5}},	//   upot, cuac, erna_, _मंडे,
   {{0x7ae25553,0x9f5206a3,0x7bdb5554,0x7ae4044c}},	//   rpot, vayè_, _efuu, ţito,
   {{0xdd92054f,0x98c600d3,0x389700ae,0x7bdb010a}},	//   _صور_, нсил, zăre_, _ffuu,
   {{0x9d1b040a,0x61f508a9,0x7ae25555,0x20125556}},	//   _מולט, zazl, ppot, ngyi_,
   {{0x29070091,0x78a020af,0x61f5020e,0x2f2300e8}},	//   arna_, romv, yazl, cīgā_,
   {{0x3b833bbc,0x9b930037,0xae102fd5,0x7bc400c6}},	//   _слуг, _إلكت, ालिन_, žius,
   {{0xf76f00cd,0x65945557,0xb9050033,0xc58a007b}},	//   لای_, тану, _ভয়_, ящие_,
   {{0x7ccc0491,0x15f200a4,0x00000000,0x00000000}},	//   _uğru, _आजवर_, --, --,
   {{0x4e10000d,0x7eb002c3,0x00000000,0x00000000}},	//   ालाई_, väpn, --, --,
   {{0x1ee70018,0x9c130294,0x00000000,0x00000000}},	//   ہوری_, pọgh, --, --,
   {{0xe4a722be,0xe29f0088,0x290e0044,0x291c0103}},	//   _прио, nuði_, nufa_, ntva_,
   {{0x2ea9074c,0xd49801b3,0x403400c6,0x00000000}},	//   कत्त, _пры_, лесс, --,
   {{0x644d5558,0x9e075559,0x3eb80b14,0x290e042c}},	// [4cb0] _inai, ечел, _bhrt_, hufa_,
   {{0x290e555a,0x80b30789,0x6f0d10e4,0x644d009c}},	//   kufa_, _आठवे, ruac, _hnai,
   {{0x443b00dd,0x628704d9,0xaca40174,0x3eaf01d3}},	//   _kaq_, mijo, akọt, ēgt_,
   {{0x6287555b,0xfbd00037,0x644d009c,0xf21700c3}},	//   lijo, مته_, _jnai, _ताड़_,
   {{0x6f0d555c,0x201c0092,0xf1d50e1f,0x644d555d}},	//   quac, əvi_, _दलान, _mnai,
   {{0x6287555e,0x2f2301d3,0x29070117,0x644d009c}},	//   nijo, rīgā_, trna_, _lnai,
   {{0x644d4a10,0xba741673,0x386901c2,0x290e09b7}},	//   _onai, دانت, _ƴar_, gufa_,
   {{0x7e6000d3,0x644d01b9,0x443b026d,0x645f063d}},	//   _împr, _nnai, _naq_, _noqi,
   {{0x2ba80251,0x5b15325f,0x6287163d,0x7c3b00ae}},	//   _छुपा, _шмат, kijo, _iaur,
   {{0x7c3b555f,0x644d5560,0xada20220,0x7bd201d3}},	//   _haur, _anai, čúva, ājuš,
   {{0x7c3b5561,0x6287522a,0x644d009c,0x291c2347}},	//   _kaur, dijo, _bnai, ctva_,
   {{0x7c3b02a7,0xddce030b,0x9f5200fd,0x32010167}},	//   _jaur, _dobř, sayé_, _adhy_,
   {{0x7c3b5562,0x987a00c1,0xe73901c9,0x443b0090}},	//   _maur, _קאנט, _цел_, _daq_,
   {{0xd2520c5e,0x6287013f,0x161806ed,0x412a14fa}},	//   جنس_, gijo, _दायर_, мого_,
   {{0x78b9023e,0x443b128b,0x7fd60426,0xc61600ca}},	//   _khwv, _faq_, візі, _יחסי_,
   {{0x7c3b5563,0x3eb800f9,0x39450090,0x644d03d3}},	//   _naur, _shrt_, _mrls_, _gnai,
   {{0x62875564,0xee3a5565,0x984500d9,0xef1a5566}},	// [4cc0] bijo, мна_, dēļ_, ьма_,
   {{0x62870138,0x644d009c,0x00000000,0x00000000}},	//   cijo, _znai, --, --,
   {{0x5fa7009d,0x7c3b5567,0x68e15568,0x644d009c}},	//   _कुठल, _baur, _ntld, _ynai,
   {{0xb50909c3,0x7c3b5569,0x443b008a,0x81d90033}},	//   _विनय_, _caur, _xaq_, ারণ_,
   {{0x7c3b556a,0x33290063,0x6aa307ee,0x6a6f0537}},	//   _daur, _xpax_, fonf, _søfa,
   {{0xe18909e5,0x290e0850,0xc33300ca,0x291c0325}},	//   _آئین_, tufa_, יוד_, ttva_,
   {{0x6e3c556b,0x7c3b556c,0x3e640212,0x00000000}},	//   _iarb, _faur, _dött_, --,
   {{0x7c3b556d,0x6287013f,0x291c0018,0x290e003d}},	//   _gaur, zijo, rtva_, rufa_,
   {{0x6e3c556e,0x291c08a9,0x290e258e,0x644d01b9}},	//   _karb, stva_, sufa_, _rnai,
   {{0x644d556f,0x7c3b5570,0xb9080081,0xddce02c6}},	//   _snai, _zaur, _বি_, _pobř,
   {{0xa96a1b67,0xb7bd00d3,0xd82f0a29,0x6e3c5571}},	//   _تمام_, deţu, _кэ_, _marb,
   {{0x70be09f6,0xb97b0341,0x644d009c,0x649d015e}},	//   ्दोल, _קנאי, _qnai, néix,
   {{0x62875572,0x63b600a5,0x764d0103,0xa3e20e4c}},	//   tijo, _czyn, ányí, धड़_,
   {{0x8673004d,0x3e640212,0x00000000,0x00000000}},	//   _кліє, _möts_, --, --,
   {{0x62875573,0x236d0181,0x644d00a6,0x9f4b0220}},	//   rijo, šej_, _tnai, _vecí_,
   {{0x62875574,0x6e3c5575,0x644d5576,0x6d410037}},	//   sijo, _aarb, _unai, _álai,
   {{0xdef85577,0xc0c83f6c,0x6e3c0707,0x62871056}},	// [4cd0] вых_, туре_, _barb, pijo,
   {{0x7c3b0a75,0x63ad5578,0x6e3c5579,0xa3df030b}},	//   _saur, _iyan, _carb, दुर_,
   {{0x6e3c557a,0x7c22557b,0x7c3b008f,0x5bcb277c}},	//   _darb, ffor, _paur, िश्व,
   {{0x7c22557c,0x6e3c0441,0x63ad557d,0x6acb0096}},	//   gfor, _earb, _kyan, ाद्र,
   {{0x6e3c557e,0x4ea70131,0x7875037a,0x63ad0169}},	//   _farb, _арва, _jáve, _jyan,
   {{0x63ad557f,0x7c3b01c2,0xddde020a,0x6e3c5580}},	//   _myan, _waur, ripţ, _garb,
   {{0x7c3b1eb8,0x7c225581,0x63ad3d1d,0xdb000094}},	//   _taur, bfor, _lyan, _vymá,
   {{0x81d900c7,0x6e3c00bd,0x6d4718bc,0xf8a9001c}},	//   ারি_, _zarb, _irja, رگاه_,
   {{0x62850505,0x63ad5582,0x7c8400a9,0x9f400036}},	//   _omho, _nyan, _туре, laiò_,
   {{0x3d0802e8,0x9c130174,0x6e3c5583,0x00000000}},	//   ांचे_, bọch, _xarb, --,
   {{0x63ad5584,0x81d90081,0x199400e5,0x4e36006e}},	//   _ayan, ারা_, _кафя, אָכן_,
   {{0x224607aa,0xf2c900c1,0xa3df0caf,0x63ad5585}},	//   _şok_, _זע_, दुल_, _byan,
   {{0x63ad26c5,0xd7f80f1e,0x00000000,0x00000000}},	//   _cyan, _рух_, --, --,
   {{0xa3e40bd9,0x454500d0,0x63ad5586,0xd29500d6}},	//   _प्र_, _منتق, _dyan, арсь,
   {{0x04461894,0x63ad5587,0xf1a400c3,0x7eab0364}},	//   _бейн, _eyan, _खुशन, nüpu,
   {{0x6e3c5588,0x388c030b,0x63ad0154,0x6285063d}},	//   _sarb, běru_, _fyan, _emho,
   {{0x6d475589,0x386d03ee,0x7c2201df,0x6e3c044c}},	// [4ce0] _arja, iker_, vfor, _parb,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x386d0f56,0x6e3c558a,0x78750181,0x5d8600e3}},	//   kker_, _varb, _záve, دلال,
   {{0xeb9a07df,0x6e3c0694,0x386d0ab2,0xbf9b016d}},	//   ние_, _warb, jker_, _idên,
   {{0x6e3c558b,0x7c2226a4,0x5efe00b7,0xab620092}},	//   _tarb, rfor, _लिट्_, _şübh,
   {{0x7c2252b2,0x386d1183,0xc7b90103,0x00000000}},	//   sfor, eker_, tfőn_, --,
   {{0x14cf009d,0x7c22558c,0xe9df00fe,0x00000000}},	//   _संगण, pfor, _đút_, --,
   {{0x63a90067,0x66030451,0x386d0479,0xa37b016d}},	//   żeni, _adnk, gker_, lcõe,
   {{0x44f101b3,0x6a1614f4,0xeb972105,0x1ddb0557}},	//   eš_, _مبار, _бит_, मुकत,
   {{0x2ca621c7,0xf41f0212,0x388c02c6,0x660301ff}},	//   lood_, ynäs_, věru_, _cdnk,
   {{0x63ad558d,0x38ba0f5a,0x00000000,0x00000000}},	//   _syan, eëre_, --, --,
   {{0x2ca6558e,0x386d558f,0xd5b7198b,0x63ad5590}},	//   nood_, cker_, ысы_, _pyan,
   {{0x657a0018,0x6d4100e1,0x261c0285,0x81d90033}},	//   szth, _álav, _मापी_, ারস_,
   {{0x2ca65591,0x63ad5592,0x44f105db,0x9985004b}},	//   hood_, _vyan, bš_, _galų_,
   {{0x63ad4341,0x2ca61953,0x9f4b00ee,0x69ce5593}},	//   _wyan, kood_, _secà_, _úbed,
   {{0x9c130134,0x00000000,0x00000000,0x00000000}},	//   kọah, --, --, --,
   {{0x26ce5594,0x44295595,0x20981119,0x2ca65596}},	// [4cf0] _kifo_, _iba_, укты_, dood_,
   {{0xdd9b004d,0xdddc0154,0x11d90076,0x6d470141}},	//   нше_, _forō, _جودة_, _prja,
   {{0x386d1c1d,0x261c0751,0xe3bf01ff,0xbc1907bf}},	//   yker_, _मानी_, reñu_, вілі_,
   {{0x2ca65597,0xae19030b,0x23bb0139,0x44290383}},	//   good_, न्जन_, _gàjí_, _jba_,
   {{0x442906c0,0x291e02a1,0x447c006e,0xb05b042c}},	//   _mba_, _aqta_, ענדע, _diät,
   {{0xaa454f07,0x61f700ec,0x06e30033,0xcb665598}},	//   рекл, _jexl, _মিলি, раше_,
   {{0x44295599,0xe509417a,0x60cf00cc,0x3a3e0072}},	//   _oba_, _विधि_, _kicm, _datp_,
   {{0x6f0d009b,0x248b007e,0x78650ef1,0x4429559a}},	//   orac, jicm_, ркиз, _nba_,
   {{0x7c29559b,0x6f0d152f,0x60cf0113,0x23a509c3}},	//   _iber, nrac, _micm, _गुलद,
   {{0x386d559c,0x4429559d,0x06851a1b,0xa5253f98}},	//   sker_, _aba_, ргон, амод,
   {{0x4429559e,0x6f0d1ab6,0x6fa7049d,0x25ae03a8}},	//   _bba_, hrac, _कुसं, _cyfl_,
   {{0x64a6559f,0x6739022e,0x60cf00b6,0x7c2902a1}},	//   рама, _tswj, _nicm, _jber,
   {{0x7c2955a0,0x27ed55a1,0x26ce0032,0x61f712ba}},	//   _mber, mben_, _fifo_, _bexl,
   {{0x27ed55a2,0x877a00c1,0x442955a3,0x60cf0037}},	//   lben_, _באני, _eba_, _aicm,
   {{0x7c2955a4,0x257b0065,0x4429030a,0x6f0d55a5}},	//   _ober, _dálé_, _fba_, erac,
   {{0x3fe655a6,0x44290649,0x6f0d55a7,0x27ed55a8}},	//   ржав, _gba_, frac, nben_,
   {{0x27ed02dc,0x7eb000c2,0x1e860818,0x60cf00c4}},	// [4d00] iben_, läpi, алам, _dicm,
   {{0x7c2955a9,0x60cf0036,0x228c0139,0x2ca64f2d}},	//   _aber, _eicm, _dókè_, wood_,
   {{0x27ed0068,0x6f0d1519,0x2ca655aa,0x61fc55ab}},	//   kben_, arac, tood_, marl,
   {{0x61fc55ac,0x0b460dc9,0x5ede007f,0x00000000}},	//   larl, инен, _कंप्_, --,
   {{0x2ca6026d,0xa01b0149,0x7c290533,0x612c0103}},	//   rood_, _omöj, _dber, _fölö,
   {{0x61fc55ad,0x27ed02dc,0x60c455ae,0x7c2955af}},	//   narl, eben_, lmim, _eber,
   {{0xed571e46,0x2ca600bc,0xe2a701cd,0x20dc0139}},	//   _кор_, pood_, úðir_, _jíi_,
   {{0xec1612eb,0x27ed0103,0x26ce2e10,0x91790023}},	//   _خورد, gben_, _sifo_, _hợp_,
   {{0x61fc55b0,0x98be00ae,0xc6f7013f,0x26ce55b1}},	//   karl, _artă_, аных_, _pifo_,
   {{0xa3bd099d,0x61fc55b2,0x7c2955b3,0x645d023e}},	//   _अरब_, jarl, _zber, wjsi,
   {{0x27ed55b4,0x61fc55b5,0xa2b7000d,0x442933aa}},	//   bben_, darl, ोगस्, _pba_,
   {{0x746b1b48,0x61f70429,0x7c2900dc,0x6f0d0178}},	//   тров_, _sexl, _xber, yrac,
   {{0xec710130,0x61fc0f05,0x26ce55b6,0x442955b7}},	//   פֿט_, farl, _tifo_, _vba_,
   {{0x443f55b8,0x6f0d103b,0x7d03025b,0x20dc026e}},	//   žu_, vrac, ánsk, _bíi_,
   {{0x60c40063,0x6f0d26cb,0x787501cd,0x00000000}},	//   fmim, wrac, _háva, --,
   {{0x6f0d55b9,0x442955ba,0x38a10034,0x60c406a8}},	//   trac, _uba_, wórz_, gmim,
   {{0x61fc55bb,0xdddc2f54,0xe2ab0867,0x5fa72397}},	// [4d10] barl, _smrš, _لادن_, _कुशल,
   {{0x7c2908a8,0x61fc55bc,0x27ed0018,0xe45f0149}},	//   _sber, carl, zben_, ljö_,
   {{0x6f0d0049,0x27ed0018,0x40350219,0x00000000}},	//   srac, yben_, _ленс, --,
   {{0x6f0d109b,0x88bc00b6,0x2ba803b3,0x60c40216}},	//   prac, _zpěv, _छुहा, cmim,
   {{0x7875023c,0x27ed55bd,0xbb452503,0x09e51ac8}},	//   _náva, vben_, селк, болн,
   {{0x5338006e,0x24890172,0x7f3a006e,0x00000000}},	//   ינדן_, _lmam_, _געשו, --,
   {{0x27ed0068,0xdd9400c6,0x7c29009e,0xaa560284}},	//   tben_, _дары, _tber, сију_,
   {{0x61fc55be,0x27ed55bf,0x78752bb5,0x22410117}},	//   zarl, uben_, _báva, _lahk_,
   {{0x27ed55c0,0xbb8500e3,0x61fc55c1,0x290e009c}},	//   rben_, _الذي, yarl, arfa_,
   {{0x248955c2,0x7875025b,0x60c400cc,0x27ed0018}},	//   _amam_, _dáva, zmim, sben_,
   {{0xe5a50036,0x76410eb5,0xd46a0095,0x9f5b0216}},	//   сини, rdly, гине_, faqë_,
   {{0x25450029,0x3e76003e,0x261c00a8,0x00000000}},	//   _vēl_, _mæta_, _माथी_, --,
   {{0xb7da006e,0x2a652c97,0x7eb0007b,0x00000000}},	//   _עקסי, _kolb_, säpi, --,
   {{0x91e344f3,0x2cbf009e,0x00000000,0x00000000}},	//   зоре, _lhud_, --, --,
   {{0x61fc55c3,0x7875025b,0xceb400a7,0x25aa1054}},	//   rarl, _záva, stək_, čilé_,
   {{0x61fc55c4,0x20550231,0x34931009,0x00000000}},	//   sarl, отур, _најр, --,
   {{0x60c455c5,0x63a91f4a,0x200f2c85,0x00000000}},	// [4d20] rmim, üent, ógia_, --,
   {{0x61fc1a4a,0xc7b20341,0x3e760088,0x78a901c0}},	//   qarl, לבן_, _bæta_, hoev,
   {{0xa3df0b94,0x63a903e5,0x628e55c6,0xa0a6013f}},	//   दुक_, żent, mibo, _ганд,
   {{0x628e55c7,0x78a90a39,0x3157006e,0x8c950120}},	//   libo, joev, _היטן_, орчі,
   {{0x38ba023b,0x2a65033c,0x78a90ea9,0x00000000}},	//   jëra_, _bolb_, doev, --,
   {{0xdee30a52,0x2cbf55c8,0x628e55c9,0x2ce80421}},	//   _хори, _ehud_, nibo, _نظری_,
   {{0xb5091115,0x649603e5,0x8c462b36,0x88bc02c6}},	//   _विषय_, rġij, _леве, _opět,
   {{0xe45f0149,0x628e55ca,0x7c960076,0x38c80103}},	//   xjö_, hibo, _الرص, جاتی_,
   {{0x628e55cb,0x1ddc0179,0x3f800220,0xe81934d8}},	//   kibo, _बलात, nziu_, _धारा_,
   {{0x8c4400d3,0xda650190,0xbdf60033,0x00000000}},	//   ăşur, _والي, _চাঁদ_, --,
   {{0xd7ef55cc,0x628e0a69,0xa96a33c6,0x499a008f}},	//   _ну_, dibo, _حمام_, _стая_,
   {{0x7d0304d8,0x6aaa000b,0x628e0381,0x7eab09a1}},	//   ánsi, loff, eibo, hüpp,
   {{0x628e3b3f,0x938b079c,0x00000000,0x00000000}},	//   fibo, усна_, --, --,
   {{0x38660934,0x3f800138,0xe45f0212,0x628e55cd}},	//   _hoor_, dziu_, sjö_, gibo,
   {{0x54e6006f,0x9f590665,0x659355ce,0x38663aac}},	//   _استق, _gesê_, _нашу, _koor_,
   {{0x439555cf,0x7602030b,0x248903e3,0x6aaa0d87}},	//   _майс, bízí, _umam_, hoff,
   {{0x9df955d0,0x628e0435,0x38662c4e,0x6aaa225b}},	// [4d30] инат_, bibo, _moor_, koff,
   {{0x88bc00b6,0x787500d4,0x2cad55d1,0xf3ff0231}},	//   _zpět, _návn, _sked_, laã_,
   {{0x6eff0032,0x6aaa030a,0x5fae00c3,0xe2ab0103}},	//   _bàbá, doff, _झुठल, _لاگن_,
   {{0x386655d2,0x2a650270,0xf3ff0231,0x00000000}},	//   _noor_, _solb_, naã_, --,
   {{0x629a0146,0x6aaa55d3,0x6d5816c7,0xbca40076}},	//   čtov, foff, ävar, أمني,
   {{0x6aaa55d4,0xbebb0052,0x996202c6,0x2cbf00bd}},	//   goff, _epër, líře_, _whud_,
   {{0x78750146,0x4879008f,0x386655d5,0xeab008ba}},	//   _dávn, исия_, _boor_, رعه_,
   {{0xd70907df,0x38660072,0x628e0201,0x38ba0052}},	//   ание_, _coor_, zibo, tëra_,
   {{0x386655d6,0x628e1621,0x78a955d7,0xa3e00d77}},	//   _door_, yibo, roev, _तलब_,
   {{0x6aaa03a9,0x7ae955d8,0x69a40980,0xddce0206}},	//   coff, _itet, _चुकी, _hlbš,
   {{0x628e022b,0x7ae90095,0x2d810076,0x7e6712d9}},	//   vibo, _htet, nzhe_, _mojp,
   {{0x38660188,0xa34a07ce,0x628e55d9,0x00000000}},	//   _goor_, азма_, wibo, --,
   {{0x628e55da,0x28df0e50,0x63ba0034,0x9f4205aa}},	//   tibo, _पंडि, ętno, _lekò_,
   {{0x78750146,0x27ff003e,0x479a006e,0x7ae90a4b}},	//   _kávo, laun_, _דינס, _mtet,
   {{0x628e55db,0x764318c4,0xe29755dc,0x9f590052}},	//   ribo, _iany, цар_, _fesë_,
   {{0x764355dd,0x4fea55de,0x628e55df,0x7ae90084}},	//   _hany, рман_, sibo, _otet,
   {{0x764355e0,0x442004ea,0x628e00f9,0x6d41167a}},	// [4d40] _kany, _ici_, pibo, _šlap,
   {{0x645601fa,0x7643006d,0x3f8055e1,0xaec300d6}},	//   _hnyi, _jany, rziu_, дбул,
   {{0x764355e2,0x78750074,0x644455e3,0x7ae955e4}},	//   _many, _návo, _kaii, _atet,
   {{0x6143030b,0x2b4d01b9,0x9f420154,0xa3ae0966}},	//   sílá, _brec_, _dekò_, _कडा_,
   {{0x7d0055e5,0x6aaa04aa,0x2b4d0472,0x64440bb6}},	//   _bárá, toff, _crec_, _maii,
   {{0x764355e6,0x71250103,0xf3ff0231,0x00000000}},	//   _nany, _بریل, zaã_, --,
   {{0x6f041e3f,0x6aaa08b2,0x787c55e7,0x645600ac}},	//   lsic, roff, _léve, _onyi,
   {{0x644400a6,0x6aaa55e8,0x764355e9,0x2b4d00ee}},	//   _naii, soff, _aany, _frec_,
   {{0x38663b0f,0x764355ea,0xf22005d4,0x6f0455eb}},	//   _voor_, _bany, _बाढ़_, nsic,
   {{0x645655ec,0x0f5700a1,0xf76f0037,0x9f5955ed}},	//   _anyi, קיים_, ضاً_, _desè_,
   {{0x764355ee,0x2fc70019,0x9f5900dd,0x3866057a}},	//   _dany, ̀ng_, _pesë_, _toor_,
   {{0x629e061c,0x764306b0,0x9f590154,0xb4b5007f}},	//   _ajpo, _eany, _fesè_, झते_,
   {{0x764355ef,0x7875030b,0xfbca0e5e,0x27e602f1}},	//   _fany, _závo, िधिम, _ifon_,
   {{0x787c04ea,0x76434704,0x645655f0,0x644655f1}},	//   _déve, _gany, _enyi, adki,
   {{0x867b00a1,0x6f060141,0x6444138f,0x00000000}},	//   _דרגו, _avkc, _faii, --,
   {{0x78750094,0x764355f2,0x6f040364,0x9f4205aa}},	//   _návl, _zany, fsic, _rekò_,
   {{0xcddb4bac,0x2fcf0222,0x6d4e55f3,0x764355f4}},	// [4d50] ање_, ägg_, _arba, _yany,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae955f5,0x7e670095,0x44390231,0x27e60154}},	//   _stet, _vojp, oes_, _ofon_,
   {{0x2b4d55f6,0x6f04042c,0x44200113,0x00000000}},	//   _prec_, bsic, _xci_, --,
   {{0x09e555f7,0x6d4e55f8,0x443955f9,0x6f0455fa}},	//   полн, _erba, ies_, csic,
   {{0x443940c3,0x27e60150,0x389700ae,0x00000000}},	//   hes_, _afon_, mări_, --,
   {{0x6d4e0ca7,0xc27c00a1,0x27ff00d1,0x64960031}},	//   _grba, שרוי, taun_, lšie,
   {{0x443955fb,0x764355fc,0x2b4d55fd,0x319c22fe}},	//   jes_, _sany, _trec_, יבונ,
   {{0x764355fe,0x7ae90010,0xbc560094,0x389700ae}},	//   _pany, _utet, ššíc, nări_,
   {{0x45850c58,0x787555ff,0x2fd9100b,0x787c520b}},	//   згов, _távo, _lgsg_, _réve,
   {{0x76435600,0x64442005,0x04465601,0x27ff5602}},	//   _vany, _paii, пенн, paun_,
   {{0x443941a2,0x76435603,0x6f041fdd,0x19ba00ca}},	//   ges_, _wany, ysic, _המעב,
   {{0x76435604,0xb7da00a1,0x64960220,0xe72e01b3}},	//   _tany, _הקני, jšie, _яе_,
   {{0x11da00e3,0xb6cc020e,0x76435605,0x20005606}},	//   صورة_, şürü, _uany, waii_,
   {{0x66015607,0x6b8200e5,0x44391647,0x95cb00c2}},	//   malk, zzog, bes_, _туда_,
   {{0x443917fc,0x44200580,0x66015608,0x53a600f7}},	//   ces_, _uci_, lalk, _найб,
   {{0x27fd02e0,0x6d4e5609,0x389700ae,0x44e1560a}},	// [4d60] _mewn_, _srba, gări_, _hó_,
   {{0x6f0402dc,0x6601560b,0x44e10649,0xf09f0139}},	//   rsic, nalk, _kó_, _ejà_,
   {{0x44e1560c,0x6f04560d,0x8ebb0033,0x61fe00e8}},	//   _jó_, ssic, _অংশগ, _iepl,
   {{0x44e1560e,0x6d4e1100,0x389700d3,0xfe1e00aa}},	//   _mó_, _vrba, bări_, _पावस_,
   {{0x387f01e5,0x44e102b4,0x61fe560f,0x66015610}},	//   dhur_, _ló_, _kepl, kalk,
   {{0x44395611,0x63b60084,0x66015612,0x61fe0113}},	//   zes_, _myyn, jalk, _jepl,
   {{0x44e15613,0x44395614,0x66015615,0xa96707ed}},	//   _nó_, yes_, dalk, зија_,
   {{0x8c435616,0x61fe5617,0x387f5618,0x44395619}},	//   _песе, _lepl, ghur_, xes_,
   {{0x44390788,0x6601561a,0x26dd0113,0x649602ef}},	//   ves_, falk, _cuwo_, kšib,
   {{0x44e13d5b,0x6601561b,0x4439561c,0xe72f00b9}},	//   _bó_, galk, wes_, اصي_,
   {{0x44e1561d,0x27fd02ad,0xb0db0ed3,0x389700d3}},	//   _có_, _fewn_, _मूंग, zări_,
   {{0x44e1561e,0x4439561f,0x6fbe5620,0x387f03dc}},	//   _dó_, ues_, ्धां, chur_,
   {{0x66015621,0x61fe1215,0x23c71179,0x77920504}},	//   balk, _bepl, रेंद, _سیدا,
   {{0x44e1026e,0x61fe5622,0x442b0090,0x6601008c}},	//   _fó_, _cepl, sfc_, calk,
   {{0x61fe5623,0x44395624,0xa5d712eb,0x44e10032}},	//   _depl, pes_, _عبور_, _gó_,
   {{0x44392c1a,0x389700d3,0x26dd0027,0xa3b51980}},	//   qes_, tări_, _yuwo_, _झडप_,
   {{0xbed801a0,0x9f3400f3,0xe2aa001c,0x00000000}},	// [4d70] здух_, неті, _ژاپن_, --,
   {{0x61fe3b6c,0xdcfc0702,0x389700d3,0x76480150}},	//   _gepl, _ayrı, rări_, nddy,
   {{0x06e30081,0x389700ae,0xfe1e06e4,0x70550103}},	//   _মিছি, sări_, _पारस_, _ہنگا,
   {{0x69da0665,0x254c030b,0x6a6f0170,0x81d90033}},	//   _agte, _měl_, _løft, ারও_,
   {{0xfebb00cd,0xdb1b0023,0x660117c0,0x2e4b00e5}},	//   _هاست_, _nguô, yalk, _ляво_,
   {{0x6601008c,0x52da0033,0x00000000,0x00000000}},	//   xalk, বীকৃ, --, --,
   {{0x66015625,0xa3b4000d,0x6d341c99,0x3e7f044c}},	//   valk, _जुन_, _перф, _cîte_,
   {{0x44e15626,0x69da0665,0x315800a1,0x7658022b}},	//   _ró_, _egte, ליון_, _anvy,
   {{0x44e15627,0x7bc00042,0xdead01c2,0x00000000}},	//   _só_, _gzmu, wwaƙ, --,
   {{0x44e15628,0x387f01e5,0x2caf0126,0x649608a9}},	//   _pó_, shur_, logd_, kšic,
   {{0x61fe5629,0xd9990080,0x6601562a,0x64a6562b}},	//   _repl, _بنات_, ralk, дана,
   {{0x69c1562c,0x6601562d,0x61fe562e,0x7afb0174}},	//   _izle, salk, _sepl, _kwut,
   {{0xf745562f,0x66015630,0x44e102b4,0x61fe022b}},	//   _цело, palk, _wó_, _pepl,
   {{0x44e102b4,0x7afb0134,0x6d0d0096,0x6601008c}},	//   _tó_, _mwut, _हिंग_, qalk,
   {{0x67295631,0x91e30d9b,0x629c3c81,0x00000000}},	//   ltej, тосе, rnro, --,
   {{0x63a40a00,0x7bdb083e,0x63b6007b,0x7afb063d}},	//   _txin, _nguu, _tyyn, _owut,
   {{0xe4c70de1,0x61fe0618,0x67295632,0x25820257}},	// [4d80] _تصوی, _tepl, ntej, _télé_,
   {{0x80be07e2,0xaae10251,0xee375633,0xb88102c6}},	//   _वीरे, _पढ़क, мну_, _šíle,
   {{0x787c26ca,0xa06a0831,0xa01b0f3a,0xf41f0149}},	//   _léva, _дана_, _blöd, miär_,
   {{0x7875025b,0xe8190592,0x67295634,0x6ab8023a}},	//   _dávk, _धागा_, ktej, ेग्र,
   {{0x76480150,0x69c13d10,0x6d5a0220,0x7c650037}},	//   yddy, _azle, _štad, عامل,
   {{0x3b061a4a,0x9f40023c,0x7bdb010a,0x44320113}},	//   rsoq_, ncií_, _eguu, _lby_,
   {{0x7afb405f,0xa01b0212,0xb05b0212,0x290702c3}},	//   _ewut, _flöd, _ohäl, gsna_,
   {{0xa3ae0336,0x807b00c1,0x7bdb06b0,0x6a74015e}},	//   कथा_, ַניצ, _gguu, _màfi,
   {{0x9f400220,0x6f160150,0x29070188,0x69da0036}},	//   kcií_, nryc, asna_, _tgte,
   {{0x44324cb3,0x787c5635,0x7791001c,0x00000000}},	//   _aby_, _déva, دیها, --,
   {{0xc58a0084,0xeae60081,0x6d5a0103,0x7ae00a4b}},	//   ющие_, _নিয়ম, _átad, _humt,
   {{0x7ae05636,0x291c0060,0x6f160034,0x00000000}},	//   _kumt, muva_, kryc, --,
   {{0x291c5637,0x7ae001d3,0x6a740139,0x6f1602c6}},	//   luva_, _jumt, _aàfi, jryc,
   {{0x44320a15,0x78ad3df1,0xeb91006e,0x257400da}},	//   _eby_, čave, אָל_, _cúlú_,
   {{0x7ae000dd,0x86370089,0x44320167,0xc6930266}},	//   _lumt, _חרוב_, _fby_, _באס_,
   {{0x64a40234,0x3ce200a3,0x00000000,0x00000000}},	//   rđic, _ओढ़े_, --, --,
   {{0x7ae0104d,0x4ade09a1,0x00000000,0x00000000}},	// [4d90] _numt, _फूलव, --, --,
   {{0x291c5638,0x752f0034,0x645a01d3,0x78a20095}},	//   kuva_, ńcze, ētie, _ljov,
   {{0x60c9003d,0xe3b00470,0xdb000094,0xdd910037}},	//   ċemb, _مری_, _vymý, دوا_,
   {{0x6f160034,0x291c5639,0x78a2563a,0x00000000}},	//   bryc, duva_, _njov, --,
   {{0x60cd563b,0x7ae03bf8,0x00000000,0x00000000}},	//   mmam, _cumt, --, --,
   {{0x60cd3823,0x388c02c6,0xceb400a7,0x6d4301ab}},	//   lmam, měry_, stər_, ænas,
   {{0x63ba0034,0x08d500e5,0x291c563c,0x2ebd00a8}},	//   ętni, нция, guva_, ्गीत,
   {{0x2907563d,0x60cd03a3,0x6729563e,0x69c104ad}},	//   rsna_, nmam, ttej, _vzle,
   {{0x29070222,0x6d5a563f,0xb9060b7f,0x28df3aee}},	//   ssna_, _àtar, _यू_, _पूरि,
   {{0x67295640,0x44322608,0xa3d0116e,0x2a7e0062}},	//   rtej, _sby_, _वृष_, _gltb_,
   {{0x67295641,0x291c4a4f,0x62955642,0x60cd5643}},	//   stej, cuva_, dizo, kmam,
   {{0x67295644,0x60cd0031,0x00000000,0x00000000}},	//   ptej, jmam, --, --,
   {{0x68e15645,0x78bb00b6,0x3945080e,0x62955646}},	//   _huld, mluv, _hsls_, fizo,
   {{0x68e15647,0xe5a552c3,0x62955648,0x4375004d}},	//   _kuld, _пили, gizo, туют,
   {{0x2056125c,0xa5640037,0xe6b4001c,0xc0d60076}},	//   нтар, _لدين, _جلوگ, فيسب,
   {{0x6f165649,0x60cd0256,0xa01b0149,0x2c7e015e}},	//   tryc, gmam, _smör, _oïda_,
   {{0x91e65550,0xaade009f,0xaec619e8,0x7875002b}},	// [4da0] _попе, _फूंक, ебал, _cávi,
   {{0x68e10154,0x7a33564a,0x60cd0036,0x6f160213}},	//   _ould, nıtı, amam, rryc,
   {{0xe820009d,0x24804902,0x2c7e3edc,0x6d5a564b}},	//   _याला_, _klim_, _aïda_, _štab,
   {{0x44222eb4,0x60cd564c,0x388c02c6,0x2a6c0141}},	//   ngk_, cmam, běry_, _sodb_,
   {{0x26c700e7,0xfe1e009d,0xb0bf02d5,0x228d0031}},	//   _ohno_, _पाऊस_, ्षरग, eľky_,
   {{0x291c564d,0x68e1564e,0x78a201c5,0x38ba023b}},	//   tuva_, _buld, _sjov, mëri_,
   {{0xa3d016b7,0x7875025b,0x2002564f,0x78a200c6}},	//   वेत_, _závi, _keki_, _pjov,
   {{0x20025650,0x291c02c3,0xdd8f02a3,0x62950415}},	//   _jeki_, ruva_, _طوق_, zizo,
   {{0x9f405651,0x7d1e01df,0xab620233,0x00000000}},	//   ncià_, lups, ğüsl, --,
   {{0x68e101c5,0x24805652,0x20025653,0x7e6e04cc}},	//   _fuld, _alim_, _leki_, _jobp,
   {{0x68e15654,0x04b80018,0x60cd5655,0x75d400d1}},	//   _guld, کھوں_, ymam, ضيحا,
   {{0x7c221a8e,0x629500a5,0x38cb010d,0x2480020d}},	//   ngor, wizo, _فانی_, _clim_,
   {{0xa6ca028d,0x00000000,0x00000000,0x00000000}},	//   _елда_, --, --, --,
   {{0x5694121c,0x64960138,0x388c02c6,0x24805656}},	//   _шалт, ršia, věry_, _elim_,
   {{0xc1770f36,0x3e760088,0x60cd5657,0x64960a39}},	//   ردست, _gæti_, tmam, mšin,
   {{0x62955658,0x20025659,0x60cd565a,0xae1e030b}},	//   sizo, _ceki_, umam, _पाउन_,
   {{0x60cd565b,0x7c220b18,0xa3d009d0,0x2002026a}},	// [4db0] rmam, dgor, वेद_, _deki_,
   {{0x2480015c,0x290c0095,0x64960094,0x60cd565c}},	//   _zlim_, _ovda_, nšin, smam,
   {{0x98730012,0x20020239,0x60cd0e63,0x4ea41a5c}},	//   nţă_, _feki_, pmam, урта,
   {{0x7c22565d,0x6ac933dc,0x764a0383,0xf3ff0131}},	//   ggor, िग्र, _lafy, ijão_,
   {{0x68e1565e,0x290c255c,0xbb450cba,0x00000000}},	//   _suld, _avda_, телк, --,
   {{0x7c220634,0xc3340796,0x20020233,0x68e1565f}},	//   agor, רוס_, _zeki_, _puld,
   {{0xecbb01f3,0x68e1013c,0x00000000,0x00000000}},	//   _فطرت_, _quld, --, --,
   {{0x787c0257,0x64960138,0xccf200ca,0x9f400036}},	//   _dévo, ešin, _ככל_, mbiò_,
   {{0x3e760088,0x66150103,0xb6a500d3,0x2bd05660}},	//   _sæti_, ózko, киил, तेदा,
   {{0x68e15661,0x78bb2e7e,0x248015bc,0x00000000}},	//   _tuld, sluv, _slim_, --,
   {{0xe5a51525,0x764a00f0,0x35a54c88,0x85780ed7}},	//   тини, _dafy, танг, есят_,
   {{0x6d5500e7,0xf770001c,0x39580076,0x00000000}},	//   _mrza, _گام_, _ársa_, --,
   {{0x20025662,0x987300ae,0xe3b20037,0x4ccb0033}},	//   _reki_, aţă_, شرح_, িদপু,
   {{0x3ce2007d,0x6d5508a8,0x09d50081,0xf7700602}},	//   _ओढले_, _orza, _স্যা, _دام_,
   {{0x2b910028,0x9987013f,0x2002026a,0x91030291}},	//   ạch_, menų_, _peki_, ипре,
   {{0x660302fd,0x43b306c0,0xa3e80f8f,0x38ba0052}},	//   _henk, ụrụ_, मुख_, tëri_,
   {{0x6d470006,0x66035663,0x6d555664,0xdee30c3f}},	// [4dc0] _asja, _kenk, _arza, иоти,
   {{0x6d5509ac,0x66035665,0x2b5800b6,0x7c225666}},	//   _brza, _jenk, _črc_, wgor,
   {{0x66035667,0x20025668,0xa3e900bc,0x2215002d}},	//   _menk, _teki_, _बलम_, _сфыр,
   {{0x6d5503ce,0x66035669,0x38ba00dd,0x7d1e1f12}},	//   _drza, _lenk, përi_, rups,
   {{0x4fa300d6,0x38ba023b,0x7d1e566a,0x787c0154}},	//   _вияв, qëri_, sups, _dévl,
   {{0x6603566b,0x290c01c0,0x4ed51689,0x6a7d0154}},	//   _nenk, _pvda_, _бюст, _dèfo,
   {{0x09d50f71,0x81b400c7,0x7d530068,0xd954001c}},	//   _স্বা, জের_, _پہنچ, انبخ,
   {{0xe8df0174,0x00000000,0x00000000,0x00000000}},	//   _gbọm_, --, --, --,
   {{0xf09317f5,0x1ae602ec,0x6603566c,0x6496030b}},	//   ינה_, _розм, _benk, tšin,
   {{0x78ad03ce,0x6603566d,0x64960138,0x998700c6}},	//   čava, _cenk, ušin, genų_,
   {{0x66034af8,0xf76f00bf,0x649633c9,0x3f890022}},	//   _denk, مای_, ršin, zzau_,
   {{0x7d03001f,0x66030313,0x987300ae,0x764a0350}},	//   ânsi, _eenk, rţă_, _wafy,
   {{0x660325d5,0x6496566e,0x4e2200b6,0x163419a5}},	//   _fenk, pšin, मलाई_, _беля,
   {{0x261c007a,0x66030537,0x00000000,0x00000000}},	//   _माटी_, _genk, --, --,
   {{0x6608566f,0x00000000,0x00000000,0x00000000}},	//   madk, --, --, --,
   {{0x70bf04a9,0x66035670,0x66085671,0x3f8902b6}},	//   ्षेल, _zenk, ladk, tzau_,
   {{0x3d05007d,0x44295672,0xd9040068,0x645f5673}},	// [4dd0] हीने_, _ica_, _ڈی_, _inqi,
   {{0xd9040de1,0x6608008a,0x644d0a88,0xb0c30966}},	//   _وی_, nadk, _haai, _वीरग,
   {{0xf1ab00cd,0x44290131,0x644d1cab,0x6a7d05aa}},	//   _زاده_, _kca_, _kaai, _sèfo,
   {{0x261c02e8,0x66085674,0x9f4b0036,0x644f01cb}},	//   _माझी_, hadk, _decò_, ndci,
   {{0x644d13e3,0x09cb06ae,0x44295675,0x66085676}},	//   _maai, ाध्य, _mca_, kadk,
   {{0x26dc5677,0x6e951d7b,0x2009057a,0x644d0313}},	//   _nivo_, _сигу, laai_, _laai,
   {{0x60dd5678,0x66035679,0x66080188,0xceb200ca}},	//   _kism, _renk, dadk, _הים_,
   {{0x4429567a,0x60dd009e,0x660320a8,0x644d567b}},	//   _nca_, _jism, _senk, _naai,
   {{0x60dd567c,0x66031736,0x6eb9030b,0x1bd400ae}},	//   _mism, _penk, ्तपु, _вотя,
   {{0x44290013,0x6603023b,0x6f0d0dc7,0x7c290433}},	//   _aca_, _qenk, isac, _hcer,
   {{0x4429567d,0x6603567e,0x7c291197,0xf771001c}},	//   _bca_, _venk, _kcer, شاک_,
   {{0x09d500c7,0x44293b31,0x6f0d567f,0x66035680}},	//   _স্থা, _cca_, ksac, _wenk,
   {{0xe7390012,0x660335d3,0xaca30129,0x660843c8}},	//   _чел_, _tenk, _abịa, badk,
   {{0x81bf0081,0x7c290234,0x787c0103,0x27ed1066}},	//   েশন_, _lcer, _névj, lcen_,
   {{0x644d0188,0x24995681,0x64860072,0x76415682}},	//   _faai, bism_, _póid, mely,
   {{0x27ed5683,0x26dc1197,0x60dd5684,0x9f4b0036}},	//   ncen_, _zivo_, _cism, _recò_,
   {{0xa3d05685,0x60dd5686,0xb4c242d4,0x6f0d00ee}},	// [4de0] वेश_, _dism, ्गी_, gsac,
   {{0x7c29309c,0x628714c0,0x60dd0138,0xe1fa08a1}},	//   _acer, chjo, _eism, _яго_,
   {{0x67200268,0x6f0d0a02,0x8d760037,0x20095687}},	//   zumj, asac, داءا, baai_,
   {{0x76415688,0xac2500d6,0xb19b0266,0x3b861855}},	//   hely, ифік, _טייכ, ллег,
   {{0x7c29033d,0x764103a0,0x6496033b,0x6f0d044c}},	//   _dcer, kely, jšim, csac,
   {{0x7c290194,0x67db00e8,0x24990324,0x76410120}},	//   _ecer, _mājī, zism_, jely,
   {{0x76415689,0x78ad033b,0x66083a9a,0xe5671374}},	//   dely, čavn, vadk, _اط_,
   {{0x26dc0128,0x75213912,0x98743761,0x00000000}},	//   _sivo_, dulz, рлиц, --,
   {{0xb606568a,0x64961e4d,0x644d568b,0x66081e8f}},	//   лянк, ršil, _raai, tadk,
   {{0x7641568c,0x320a0124,0x644d568d,0xe96a0265}},	//   gely, jaby_, _saai, _пазл_,
   {{0x05ce009d,0x6608008a,0x6496568e,0x644d568f}},	//   हेंब, radk, mšij, _paai,
   {{0x69c85690,0x27ed006d,0xb4af09c3,0x649605db}},	//   _izde, ccen_, कवे_, bšim,
   {{0x24995691,0x66085692,0x60dd0483,0xe6c40088}},	//   rism_, padk, _rism, þjóð,
   {{0x60dd5693,0x20091044,0x644d112f,0x76415694}},	//   _sism, waai_, _waai, cely,
   {{0x648600e3,0x44290fa9,0x6d5a5695,0x867b040a}},	//   _dóib, _tca_, _štan, _ארגו,
   {{0x60dd00a7,0xa3e906ed,0x6f0d2b9e,0x44295696}},	//   _qism, _बलि_, tsac, _uca_,
   {{0x60dd00d9,0x20091507,0x657a030a,0xe7f707d5}},	// [4df0] _vism, raai_, lyth, ीरता_,
   {{0x81b40081,0x6f0d5697,0x7c294126,0x518700c2}},	//   জেই_, rsac, _scer, _бума,
   {{0x60dd5698,0x3e76003e,0x62855699,0xa3e9009f}},	//   _tism, _rætt_, _ilho, _बला_,
   {{0x6f0d009c,0x3b5523b9,0xe46a007b,0xac19290e}},	//   psac, икер, mpöä_, тоду_,
   {{0xae1e0557,0x6f0f0239,0x63ad00bd,0x7c2950a5}},	//   _पाचन_, _uvcc, _jxan, _vcer,
   {{0x78750074,0x657a01af,0xfbd01f11,0x64960094}},	//   _návr, kyth, ستن_, všim,
   {{0x7641569a,0x6285569b,0x27ed0062,0xf8650ff7}},	//   vely, _mlho, tcen_, ивко,
   {{0x69d50074,0x76410150,0x7af5004d,0x78ad015c}},	//   _územ, wely, _взає, čavo,
   {{0x6285569c,0x0685185c,0x7641569d,0x9a270192}},	//   _olho, игин, tely, _معان,
   {{0xbb8400e3,0x7a570103,0x27ed078e,0x00000000}},	//   _الكي, _حضرا, scen_, --,
   {{0x81eb0033,0x38ba0052,0x940b00a7,0x657a00f0}},	//   মরা_, tërt_, licə_, gyth,
   {{0x752f00a5,0x6285569e,0x9f5900c2,0x7641569f}},	//   ńczo, _alho, _kesä_, sely,
   {{0xa3d0018b,0x386d0ea3,0x752100a7,0xa01b01cd}},	//   वें_, mjer_, sulz, _plön,
   {{0x386d0bab,0x471a00c1,0x387f56a0,0x36690e2c}},	//   ljer_, _יונג, lkur_, _јако_,
   {{0x62850181,0x3aeb004d,0x3d050336,0x38ba0052}},	//   _dlho, _løp_, _हौले_, përt_,
   {{0xe0df013d,0x386d25e5,0x64a300e5,0x387f56a1}},	//   _ciò_, njer_, _маща, nkur_,
   {{0x387f01cd,0xe3b80092,0x386d56a2,0x4e0624ec}},	// [4e00] ikur_, şıb_, ijer_, изаб,
   {{0xed5a061b,0x7c3d0233,0xdd8f00d1,0x387f00bc}},	//   коз_, _ısra, ژول_, hkur_,
   {{0x387f0088,0x386d4f4b,0x00000000,0x00000000}},	//   kkur_, kjer_, --, --,
   {{0xf5360130,0x629c56a3,0x386d003d,0xe0580260}},	//   יטער_, liro, jjer_, _حیرت_,
   {{0x386d0480,0xf41700c1,0xddc705db,0xab270284}},	//   djer_, בֿות_, _vojš, иоца_,
   {{0x291c1386,0xd3570289,0x00000000,0x00000000}},	//   trva_, ייני_, --, --,
   {{0x7bc901c2,0xddc70b14,0x649656a4,0x38ba0052}},	//   _ezeu, _tojš, ršij, dërr_,
   {{0x629c3d9d,0x69c856a5,0x20b60285,0xa2cd034c}},	//   hiro, _vzde, ंविध, _दीन्,
   {{0xe6664a4e,0x629c56a6,0x657a0150,0xdceb00c6}},	//   атно, kiro, wyth, čiąj,
   {{0x629c01c2,0x291c0995,0x8f37021e,0xd6d70012}},	//   jiro, prva_, סטיג_, итэ_,
   {{0xd7ef08c3,0x629c56a7,0x69c81dfc,0x69960879}},	//   _му_, diro, _uzde, _трах,
   {{0x629c2a96,0x657a56a8,0xe2f901ce,0x2ca600f0}},	//   eiro, ryth, лемі_, nnod_,
   {{0x628501fa,0x6d5a0995,0x68e806c5,0x00000000}},	//   _plho, _štal, _hudd, --,
   {{0x68e856a9,0x629c56aa,0x00000000,0x00000000}},	//   _kudd, giro, --, --,
   {{0x800756ab,0x20db0174,0x224302c3,0x00000000}},	//   ичае, ụime_, rejk_, --,
   {{0x68e856ac,0x63ad0a00,0x629c02ac,0x61fa047e}},	//   _mudd, _txan, airo, ıtla,
   {{0x68e856ad,0x0eeb004d,0xf3ff0231,0x00000000}},	// [4e10] _ludd, тьби_, mbã_, --,
   {{0x629c1ba6,0x387f00c6,0x9df844b2,0x787c020d}},	//   ciro, zkur_, инут_, _dévi,
   {{0x2ca602ad,0xab62026a,0x6d5a0103,0x61e5009c}},	//   fnod_, _şüph, _átal, _ighl,
   {{0xa5d900c1,0x940b0092,0x2ca656ae,0xe537006e}},	//   אַני, ticə_, gnod_, שטאט_,
   {{0x7bc002ad,0x64860161,0xb7c10033,0x00000000}},	//   _cymu, _jóia, _উল্ট, --,
   {{0x1df802e3,0x7bc00150,0x8e850037,0x00000000}},	//   _веры_, _dymu, _السه, --,
   {{0x68e856af,0x3cf00031,0x3a2c56b0,0x386d00b3}},	//   _cudd, ľové_, _dcdp_, tjer_,
   {{0x629c02e6,0x68e856b1,0x3cf00146,0xbca50cc8}},	//   ziro, _dudd, žové_, _امري,
   {{0x387f56b2,0x7bc00150,0x7c3b3fa5,0x6a7d06a3}},	//   rkur_, _gymu, _ibur, _lèfi,
   {{0xba74054f,0x387f003e,0x629c56b3,0xca7400e3}},	//   _والت, skur_, xiro, _والغ,
   {{0x629c56b4,0x68e80694,0x443b56b5,0xe820009d}},	//   viro, _gudd, _bbq_, _याचा_,
   {{0x7ae156b6,0xb4e7000d,0x629c163e,0x64a60290}},	//   _hilt, _बढी_, wiro, сама,
   {{0x7ae156b7,0x629c56b8,0x7c3b56b9,0x27ff56ba}},	//   _kilt, tiro, _mbur, mbun_,
   {{0x6d5a215e,0x412a08d1,0x787c0802,0x26d900b6}},	//   _štam, лого_, _révi, ůsob_,
   {{0x7c3b56bb,0x7ae90084,0x68e8008c,0xd179004d}},	//   _obur, _luet, _xudd, асті_,
   {{0x629c013f,0x27ff56bc,0x6a7d0428,0x69c13500}},	//   siro, nbun_, _dèfi, _myle,
   {{0xee3a08c3,0xa01b0222,0x644656bd,0x7ae109f7}},	// [4e20] лна_, _glöm, meki, _oilt,
   {{0x644656be,0x5d6a1cb1,0xcf2500e3,0x42262195}},	//   leki, лизм_, ترفي, _удов,
   {{0x7bc002ad,0x69c156bf,0xd9f800a3,0x64460062}},	//   _symu, _nyle, ुरसत_, oeki,
   {{0x644656c0,0x1d071907,0x68e856c1,0x7ae1009b}},	//   neki, сеци_, _rudd, _ailt,
   {{0x7ae156c2,0x7d1e08a9,0x2057040a,0x2905009e}},	//   _bilt, srps, _היכל_, _awla_,
   {{0x60c456c3,0x7c3b0294,0xdd20030b,0x644656c4}},	//   llim, _ebur, může, heki,
   {{0x5d860080,0x68e803e5,0x7ae10052,0x7ae900b3}},	//   _الأل, _qudd, _dilt, _euet,
   {{0x6d5c56c5,0x60c456c6,0x6d4e56c7,0x69c10150}},	//   _irra, nlim, _isba, _dyle,
   {{0xd6da0c28,0x69c101e8,0x661c56c8,0x68e801c2}},	//   лто_, _eyle, órko, _wudd,
   {{0x27300d79,0x7ae156c9,0x60c40868,0x68e856ca}},	//   ràn_, _gilt, hlim, _tudd,
   {{0xe72f1e49,0x245f0084,0x6d5a1271,0x27ff0022}},	//   وصی_, _nämä_, _štaj, bbun_,
   {{0x996400b6,0x644656cb,0x60c400e7,0xab5d007f}},	//   _kůže_, geki, jlim, _wyże,
   {{0x27e62d35,0x7ae903a4,0xdc9b00ca,0x3eba56cc}},	//   _igon_, _xuet, ריכל, kopt_,
   {{0x9964000d,0x442d0034,0x6d5c56cd,0x60c456ce}},	//   _může_, że_, _orra, elim,
   {{0x7e7512fb,0x644656cf,0x9f490076,0x29df0078}},	//   _rozp, beki, rcaí_, _għaċ_,
   {{0x60c456d0,0x64a41d2e,0x9f490037,0x00000000}},	//   glim, _наја, scaí_, --,
   {{0x6d5c56d1,0x6e991469,0x6d4e2e1a,0x68e256d2}},	// [4e30] _arra, авар_, _asba, _miod,
   {{0x44390db8,0x68e2009c,0x61e501b9,0x00000000}},	//   lfs_, _liod, _ughl, --,
   {{0x443956d3,0x7ae956d4,0x2489084e,0x7e75037a}},	//   ofs_, _suet, _klam_, _vozp,
   {{0x7ae156d5,0x27e60019,0xa3d01e18,0x71f80018}},	//   _silt, _ngon_, वेक_, _پریس_,
   {{0x6d5c56d6,0x7ae1007a,0x6d4e45cf,0xcb693084}},	//   _erra, _pilt, _esba, рале_,
   {{0x644656d7,0x27e656d8,0x09d20033,0x2b4d0141}},	//   zeki, _agon_, াশনা, _vsec_,
   {{0x68e256d9,0xaefb009c,0x644601a4,0xb9220174}},	//   _biod, _brùg, yeki, mkpọ_,
   {{0x7c3b092f,0x69c1025b,0x645a01d3,0xa01b0212}},	//   _ubur, _vyle, ētik, _slöj,
   {{0x7ae11d46,0x68e256da,0x7c2400e3,0x200b00d3}},	//   _tilt, _diod, óire, _meci_,
   {{0x24894cba,0x27e602a7,0x27ff00dc,0x2cbf0234}},	//   _alam_, _egon_, sbun_, _hkud_,
   {{0x68e201f7,0x248956db,0x660a00c4,0x044600c2}},	//   _fiod, _blam_, _defk, оенн,
   {{0x7c2b56dc,0xf99200a1,0x2ee301c0,0x6d5a00cb}},	//   nggr, _קרא_, _lijf_, _štak,
   {{0xe60e50b0,0x644656dd,0x248956de,0x78a956df}},	//   _од_, reki, _dlam_, mnev,
   {{0x644656e0,0x78bb030b,0x248956e1,0x78a956e2}},	//   seki, louv, _elam_, lnev,
   {{0x248900b3,0x7f5d01b9,0x78a90052,0x644656e3}},	//   _flam_, _arsq, onev, peki,
   {{0x200b56e4,0x78bb56e5,0x53a600d6,0xe6d90088}},	//   _ceci_, nouv, _майб, ðræð,
   {{0x200b56e6,0x60c408d3,0x26c556e7,0x3eba029a}},	// [4e40] _deci_, rlim, ollo_, topt_,
   {{0x245f02fd,0x66cf004d,0x8d5a0291,0x2cbf00bc}},	//   _tämä_, bøke, ишет_, _akud_,
   {{0x60c456e8,0x26c556e9,0x78bb06a3,0x78a956ea}},	//   plim, illo_, kouv, knev,
   {{0xb9220174,0x00000000,0x00000000,0x00000000}},	//   akpọ_, --, --, --,
   {{0x2cad0fa3,0x69c556eb,0xaefb009c,0x0a6a1720}},	//   _djed_, ühen, _crùd, ирки_,
   {{0x200b00d3,0xaefb01b9,0x78a90bd3,0x6d5c56ec}},	//   _zeci_, _drùd, enev, _trra,
   {{0x6d5c56ed,0x6d4e3693,0x660a00e7,0xcb1c0096}},	//   _urra, _usba, _refk, _निवड_,
   {{0xa77413b0,0xdd8f0391,0x26c556ee,0x78a956ef}},	//   злич, _شوق_, ello_, gnev,
   {{0x920a04dd,0x660a0d62,0x2bd90179,0xa01b003e}},	//   वराज_, _pefk, बेदा, _slök,
   {{0xd6d006fa,0x24890632,0x78a91175,0x00000000}},	//   عقد_, _slam_, anev, --,
   {{0x248956f0,0xceb30130,0x994a0080,0x286a0291}},	//   _plam_, ויז_, _خلال_, _врло_,
   {{0x66e604d2,0x78bb04ea,0xe3b807d1,0xe7860565}},	//   _дода, couv, ğın_, _муло,
   {{0x200b03ce,0xe3b808bb,0x443956f1,0xc87f02e2}},	//   _reci_, şın_, rfs_, öße_,
   {{0x9f59008f,0xaaca030b,0x628e00ca,0x78a0024a}},	//   _gesù_, ितिक, ghbo, limv,
   {{0x764856f2,0x31c4185c,0x7cf303e5,0x20190124}},	//   medy, дств, _oħra, _pdsi_,
   {{0x764856f3,0x248956f4,0xda780146,0x752805db}},	//   ledy, _ulam_, _loď_, mudz,
   {{0x200b0181,0x66cf004d,0xaaca00b6,0x9f34004d}},	// [4e50] _veci_, søke, िताक, меті,
   {{0x764856f5,0x2cbf04a7,0x78ad077e,0x7cf300bd}},	//   nedy, _skud_, čavi, _aħra,
   {{0x2ee30126,0x92b400e3,0x9bf80134,0x64a400cc}},	//   _vijf_, _تحيا, _ịsụg, rđiv,
   {{0x6ac30469,0xa3c4148e,0x76480d1f,0x7c8456f6}},	//   षत्र, _्रम_, hedy, муче,
   {{0x395e4768,0x764812ff,0xdb0703e0,0x26c50178}},	//   _arts_, kedy, _ömür, yllo_,
   {{0x76480034,0x75280350,0x3f4d00c4,0x386656f7}},	//   jedy, kudz, _ižu_, _anor_,
   {{0x7f4d003d,0x764800f2,0x78a956f8,0x6ca7513f}},	//   lwaq, dedy, tnev, _драж,
   {{0x3a3e0090,0x2cad56f9,0xb4b5030b,0x64860503}},	//   _ebtp_, _ujed_, जको_, _cóil,
   {{0x32110074,0x78a956fa,0x78bb56fb,0x395e02ac}},	//   kazy_, rnev, rouv, _erts_,
   {{0x7afb06a8,0x78a956fc,0x26c5028d,0x78bb56fd}},	//   _itut, snev, ullo_, souv,
   {{0xc8ab013d,0x64860037,0x26c5002b,0x78a956fe}},	//   _къде_, _fóil, rllo_, pnev,
   {{0x3f4d2d5a,0xc8642a6e,0x26c50072,0x6486033c}},	//   _ožu_, _отчи, sllo_, _góil,
   {{0x69c7052f,0x752800e8,0x649600d4,0x7648022b}},	//   _øjeb, audz, dšit, bedy,
   {{0x7afb0a4b,0x752856ff,0x5fb500b7,0x00000000}},	//   _mtut, budz, _अँजल, --,
   {{0xd13200e3,0xa06a0e06,0x0163203c,0xe2972c96}},	//   عمر_, бава_, нкро, чар_,
   {{0x4fea12d1,0x7afb5700,0x2b5f00a7,0xe45f007b}},	//   сман_, _otut, _oruc_, llön_,
   {{0x443202a4,0xaefb0139,0x7afb0129,0x1e8600c6}},	// [4e60] _icy_, _arùb, _ntut, плам,
   {{0x64565701,0x649600c6,0x00000000,0x00000000}},	//   _hayi, ršiu, --, --,
   {{0x7afb5702,0x645618e0,0x3f86035d,0xaefb01ec}},	//   _atut, _kayi, šou_, _crùb,
   {{0xdee64444,0x2b5f5703,0x64565704,0x00000000}},	//   _номи, _bruc_, _jayi, --,
   {{0x64565705,0x648600e3,0x20125706,0x6f63013f}},	//   _mayi, _nóim, mayi_, _звяз,
   {{0x645601d4,0x38665707,0x753d007f,0x00000000}},	//   _layi, _snor_, łszy, --,
   {{0x7afb5708,0x9d430b2e,0xd90d110a,0x64860037}},	//   _etut, _перд, لیل_, _póil,
   {{0x20125709,0x64560b1a,0xd60100fe,0xc6f85334}},	//   nayi_, _nayi, _đún, оних_,
   {{0x629e570a,0x49080034,0x64860076,0x67292c68}},	//   _ompo, _सबको_, _cóim, guej,
   {{0x9f9700a1,0xbafb00a1,0x20124132,0x8b0302c6}},	//   פדיה_, _להמש, hayi_, ářen,
   {{0x64564524,0x6b82570b,0x2fc70019,0x7648570c}},	//   _bayi, lyog, ́ng_, redy,
   {{0x3866002d,0x629e570d,0x764856bf,0x6456008c}},	//   _unor_, _ampo, sedy, _cayi,
   {{0x787c025a,0x7648558d,0x6b820ab9,0x6456570e}},	//   _févr, pedy, nyog, _dayi,
   {{0x356a4c82,0x752816fc,0xe1f800ae,0x00000000}},	//   _грин_, pudz, зерч_, --,
   {{0xe63b00a1,0x321112fb,0x6456570f,0xa63b00ca}},	//   _התוכ, razy_, _fayi, _הגור,
   {{0x629e5710,0x20125711,0x6456554f,0x6b820361}},	//   _empo, gayi_, _gayi, kyog,
   {{0xa2b51456,0xe8d700a1,0x98a70106,0x64960433}},	// [4e70] _обич, לולר_, šiću_, ršit,
   {{0x64565712,0x2012010a,0x00000000,0x00000000}},	//   _zayi, aayi_, --, --,
   {{0x7afb5713,0x64565714,0x2d875715,0xaefb01b9}},	//   _stut, _yayi, áne_, _brùc,
   {{0x317e01bf,0x7684022b,0x6456008c,0x64960095}},	//   ätze_, _bòyk, _xayi, lšir,
   {{0x2d875716,0x61ec0018,0x69a202d5,0xaefb009c}},	//   šne_, _állá, _केबी, _drùc,
   {{0xa96912e7,0x2b5f015c,0x6496015c,0x64860076}},	//   жика_, _vruc_, nšir, _róim,
   {{0xa2a002e8,0x6d5a0b18,0x6b820361,0xd9fe00aa}},	//   _ऑगस्, _štav, ayog, _उभरत_,
   {{0x2b5f5717,0xa3ad0640,0x6b822cb9,0x6ba801f9}},	//   _truc_, कपा_, byog, ásgá,
   {{0x64565718,0x7afb3583,0x64960a39,0x6b820027}},	//   _rayi, _utut, kšir, cyog,
   {{0x64565719,0x4585468c,0x00000000,0x00000000}},	//   _sayi, дгов, --, --,
   {{0xe3b803a3,0xa9070781,0x2012571a,0x1fda030b}},	//   ğım_, _ربان, yayi_, _भण्ड,
   {{0xe3b803a3,0x03a6571b,0x64564628,0x00000000}},	//   şım_, димо, _qayi, --,
   {{0x6729571c,0x798300f0,0x6456010a,0x7cf300bd}},	//   quej, lynw, _vayi, _oħro,
   {{0xa5094794,0x23600ab2,0x6aa3571d,0x6456571e}},	//   _дека_, _vrij_, ninf, _wayi,
   {{0x2d1c0455,0x6456571f,0xd5d10b94,0x00000000}},	//   _पटेल_, _tayi, _हरिज, --,
   {{0x20552863,0xa067007e,0x00000000,0x00000000}},	//   нтур, маса_, --, --,
   {{0x8fa30a67,0x20125720,0xe29a5721,0xef1a065c}},	// [4e80] вате, rayi_, _маи_, юма_,
   {{0x20125722,0x59dd04f8,0x629e5723,0xc3c915ae}},	//   sayi_, मधार, _umpo, _عظيم_,
   {{0x6aa35724,0x44f30231,0x20120169,0xb05b00ce}},	//   dinf, _jã_, payi_, _ikän,
   {{0x44f30028,0x9b8a0286,0x6aa3058f,0xa3c40285}},	//   _mã_, ينال_, einf, _्रा_,
   {{0x44f35725,0x4bda0470,0xcce50037,0x228d0206}},	//   _lã_, آباد_, رسمي, ežky_,
   {{0x6b821cd7,0x798300f0,0x00000000,0x00000000}},	//   ryog, fynw, --, --,
   {{0xa9671fdb,0x44f33a3b,0x9f4b003e,0xa3de0096}},	//   дија_, _nã_, élög_, थेत_,
   {{0x64964092,0xd90d001c,0x63b60027,0x7e7c20a8}},	//   zšir, صیه_, _oxyn, _horp,
   {{0xb05b0149,0xdca31719,0x6d5e13b9,0xab6501d3}},	//   _okän, _рати, lvpa, _peļņ,
   {{0xda66223e,0x44f30023,0xceb400a7,0x2ba400aa}},	//   _تاري, _bã_, qsəd_, _खेया,
   {{0x99860391,0x6fd50006,0x98a702c6,0x44f35726}},	//   _تلاو, _दरभं, ntně_, _cã_,
   {{0x25fe0693,0x9f405727,0x44f300de,0x7ae802b6}},	//   _श्री_, nció_, _dã_, _hidt,
   {{0x69c85728,0x78750094,0xddce0034,0x7e7c0abf}},	//   _hyde, _návy, _jabł, _oorp,
   {{0x44f3001f,0x09d50081,0x81d80081,0x98a702c6}},	//   _fã_, _স্টা, িশন_, ktně_,
   {{0x7ae81484,0x44f300de,0x9f400103,0x62870407}},	//   _midt, _gã_, kció_, rkjo,
   {{0x62870ab8,0x7afc0117,0x76585729,0x00000000}},	//   skjo, _črtn, _havy, --,
   {{0x69c8572a,0x776202a1,0xb3d300aa,0xddd500d2}},	// [4e90] _lyde, _jrox, _सरिख, _pozů,
   {{0x234800bf,0x765a084e,0xc5f801d3,0x51870c3f}},	//   _کلیپ_, ndty, ncē_, _жума,
   {{0x44f30028,0x7e7c572b,0x69c8572c,0xa01b0212}},	//   _xã_, _dorp, _nyde, _blöt,
   {{0x6ab9000c,0x7e7c0a6c,0x7762002b,0x6aa30381}},	//   ेत्र, _eorp, _orox, winf,
   {{0x7e7c038c,0x9098013d,0x6aa3572d,0x6d5a572e}},	//   _forp, _цвят_, tinf, _štat,
   {{0x9f400472,0x7658572f,0x7e7c0a00,0x69c85730}},	//   ació_, _navy, _gorp, _byde,
   {{0x6aa35731,0x7ae802c9,0xa01b5732,0x228d02c6}},	//   rinf, _didt, _flöt, užky_,
   {{0x9f4016c8,0x44f35733,0x77620131,0x7d02007e}},	//   cció_, _rã_, _brox, ćost,
   {{0x44f33fe6,0xf41f00c2,0x76582f23,0xe7a9166f}},	//   _sã_, tkän_, _bavy, явил_,
   {{0xb6cc08bb,0xe3b801e8,0x44f30131,0xddc700d4}},	//   şünü, şık_, _pã_, _mojž,
   {{0x7658022b,0x9f400451,0x00000000,0x00000000}},	//   _davy, nciò_, --, --,
   {{0x7762002b,0xb05b30c1,0x44f35734,0xe7950161}},	//   _frox, _skän, _vã_, _пиењ,
   {{0xf7450d89,0x7dee0103,0x00000000,0x00000000}},	//   _чело, nősí, --, --,
   {{0x27395735,0x09e30081,0x44f30023,0x6d4718f0}},	//   mèn_, _ন্যা, _tã_, _opja,
   {{0x61435736,0x0446022a,0x64a601b3,0x7bc90154}},	//   лера, _зейн, _пака, _lyeu,
   {{0x645a01d3,0xafe642c7,0xa0b50284,0x00000000}},	//   ētis, еобл, вљуј, --,
   {{0x44205737,0x673b5738,0x3cff0039,0x7bc90051}},	// [4ea0] _idi_, ntuj, _čuva_, _nyeu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa01b5739,0x4420573a,0x7e7c573b,0x9f59037a}},	//   _plöt, _kdi_, _vorp, _besó_,
   {{0x673b1fe8,0x69c8573c,0x6d5e00aa,0x4420573d}},	//   ktuj, _ryde, rvpa, _jdi_,
   {{0x7e7c0092,0x9f4005fe,0x98a700b6,0x69c800f2}},	//   _torp, rció_, stně_, _syde,
   {{0xada60752,0x2739573e,0xa01b01cd,0x00000000}},	//   _загл, dèn_, _flös, --,
   {{0x4420199b,0x6f04573f,0x9f405740,0x6444010a}},	//   _odi_, lpic, pció_, _obii,
   {{0x77623894,0x7ae85741,0x44203124,0x76580138}},	//   _prox, _widt, _ndi_, _savy,
   {{0x7658013f,0x65630126,0xc6a644ab,0x76430167}},	//   _pavy, _arnh, ерни, _bbny,
   {{0x69c85742,0x69963715,0x64445743,0x66cf0120}},	//   _tyde, _прех, _abii, søkn,
   {{0x44200052,0x673b010a,0x00000000,0x00000000}},	//   _bdi_, atuj, --, --,
   {{0x2ebe0557,0x644401b9,0xdbdc0af0,0x76580350}},	//   ्तुत, _cbii, _káàk, _wavy,
   {{0x366a02fd,0xa8872a6e,0x44205744,0x76430167}},	//   _надо_, _яйца_, _ddi_, _fbny,
   {{0x44205745,0xa6aa06f6,0x6f045746,0xaefb009c}},	//   _edi_, _عاشق_, dpic, _brùn,
   {{0xe5f70054,0xaefb01b9,0x44205747,0xfd4c0174}},	//   _אזור_, _crùn, _fdi_, reiị,
   {{0xceb400a7,0x69d500a4,0x00000000,0x00000000}},	//   zrət_, येटी, --, --,
   {{0x6d470088,0xaefb0139,0xa01b5748,0x7ff4001c}},	// [4eb0] _spja, _erùn, _slös, اسفا,
   {{0x644f5749,0x4420574a,0x645d04c8,0x6d47009e}},	//   leci, _zdi_, ldsi, _ppja,
   {{0x44200150,0x6d5a5366,0x7d1c0335,0x9f59037a}},	//   _ydi_, _štar, _cvrs, _pesó_,
   {{0x673b16ac,0x645d574b,0x9f4000e5,0x20f80206}},	//   ytuj, ndsi, rciò_, _učia_,
   {{0x645d01b5,0x20091d91,0x60cd574c,0x6fd5009f}},	//   idsi, mbai_, mlam, _दरिं,
   {{0xaa45171b,0x78a2574d,0x7dee0103,0xcb66235c}},	//   текл, _amov, rősí, таше_,
   {{0x644f0f1f,0xfd660129,0x84ef074c,0x00000000}},	//   keci, _mkpọ, _घूंट_, --,
   {{0x673b0084,0x60cd574e,0x2739574f,0x644f29d0}},	//   ttuj, nlam, tèn_, jeci,
   {{0x644f5750,0x752800a5,0x6d5a0072,0x7d1c0117}},	//   deci, erdz, _átar, _zvrs,
   {{0x2d850006,0x60cd5751,0x27395752,0xfd660134}},	//   _üles_, hlam, rèn_, _nkpọ,
   {{0x673b5753,0x44205754,0x644f5755,0x66cf00f2}},	//   stuj, _pdi_, feci, søko,
   {{0x64a6325f,0xfd6600ac,0x673b00a5,0x27395756}},	//   тама, _akpọ, ptuj, pèn_,
   {{0x60cd5757,0x8c1a0327,0x44205758,0x289a0142}},	//   dlam, וורי, _vdi_, _קינא,
   {{0x68eb019c,0xcb1200a1,0x60cd00a3,0x67290ddb}},	//   _higd, שלם_, elam, mrej,
   {{0xa56400e3,0x76415759,0x09e30033,0x6729575a}},	//   _مدين, mfly, নুরা, lrej,
   {{0x68fc0068,0x4420575b,0x68eb02a1,0x76410407}},	//   _érde, _udi_, _jigd, lfly,
   {{0xd9ad04a9,0x68eb575c,0x7d1c0039,0xc0e34e41}},	// [4ec0] टपुट, _migd, _svrs, ротк,
   {{0x60cd575d,0xaefb0019,0x7641012a,0x68eb575e}},	//   alam, _trùn, nfly, _ligd,
   {{0x6729575f,0x60cd5760,0xe0da0831,0x321800ca}},	//   hrej, blam, _ово_, mary_,
   {{0x6aca0a30,0x68eb1da7,0x6f045761,0x32185762}},	//   ित्र, _nigd, ppic, lary_,
   {{0x24800034,0x2ca65763,0xda7a00ae,0x03e40033}},	//   _moim_, riod_, дяй_, কুরী_,
   {{0x644f0067,0x60c45764,0x32185765,0xba180037}},	//   zeci, loim, nary_, ريبا_,
   {{0xbea35766,0x7d1c0128,0x7641052f,0xdbdc0139}},	//   _тарк, _uvrs, dfly, _dáák,
   {{0x7d5700c1,0xc9834cb0,0x60c4007b,0x75280a39}},	//   _בילד_, руши, noim, vrdz,
   {{0x67295767,0x68eb03a9,0x644f5768,0x32180be5}},	//   grej, _digd, veci, kary_,
   {{0x3aeb00cd,0x60c40037,0x752800e7,0x60cd0a60}},	//   _قبلی_, hoim, trdz, zlam,
   {{0x644f5769,0xb05b0149,0x60c400c2,0x245508ba}},	//   teci, _skäm, koim, هندس,
   {{0x52bd178c,0x78a200cc,0x3213576a,0x60cd0092}},	//   ोत्स, _umov, _sexy_, xlam,
   {{0x24840212,0x645d576b,0x60c4576c,0x00000000}},	//   ömma_, rdsi, doim, --,
   {{0xc7d700ca,0x7afd576d,0x3135576e,0x46a300e5}},	//   _סוגי_, _éste, легр, _качв,
   {{0x60cd576f,0x61141a57,0xb6d900c1,0x2ba400c3}},	//   tlam, идру, _אַקט, _खेसा,
   {{0xf0b402b7,0x64860076,0x00000000,0x00000000}},	//   айсь, _sóiv, --, --,
   {{0x6d5a005f,0x2009013f,0x9ed90cba,0x05c600c3}},	// [4ed0] _štap, rbai_, емат_, _रुतब,
   {{0x60cd068d,0xd25100bf,0x248000c4,0xa2c40096}},	//   slam, _اند_, _zoim_, ळवण्,
   {{0x60cd5770,0x672915f2,0xf1df1fbb,0x69a200a4}},	//   plam, zrej, फेशन, _केली,
   {{0x60c40124,0x1b1900c2,0x60cd013c,0x6adb0285}},	//   coim, ежды_, qlam, यग्र,
   {{0x291e033b,0x0c243006,0xa09a00c1,0x9f9800d3}},	//   _avta_, рмін, _נישט, _авяу_,
   {{0xbbd30b89,0x67291711,0xeab9004b,0x00000000}},	//   _तरीक, vrej, эйл_, --,
   {{0x98ac03e0,0xa3aa0442,0xc27c0eda,0x00000000}},	//   _ardı_, _गेन_, ורגי, --,
   {{0x67295771,0xc17400a1,0x88c5030b,0x69c702b6}},	//   trej, שחק_, _ověř, _øjem,
   {{0x68eb5772,0x3f890d2a,0x64860076,0x76415481}},	//   _vigd, nyau_, _móit, tfly,
   {{0x67295773,0x64ab02c6,0x2492084e,0x60c439bd}},	//   rrej, yřic, _slym_, zoim,
   {{0x32180146,0xceb40341,0x34aa1b4d,0x68eb019c}},	//   vary_, ייץ_, евно_, _tigd,
   {{0x67295774,0x3f8901c2,0x76415775,0x3218007f}},	//   prej, kyau_, sfly, wary_,
   {{0x32185776,0x3ced1c9d,0x60c45777,0x386f0036}},	//   tary_, _miev_, voim, _ingr_,
   {{0x78a95778,0xb6075779,0x64ab00d2,0x00000000}},	//   liev, _рядк, třic, --,
   {{0x26c5577a,0x60c4577b,0x3218577c,0x64860076}},	//   molo_, toim, rary_, _bóit,
   {{0x3218577d,0x26c5019f,0x78a9577e,0x66cf0537}},	//   sary_, lolo_, niev, køkk,
   {{0xddd50618,0x648600e3,0x60c4577f,0x20f800c4}},	// [4ee0] _rozš, _dóit, roim, _ičim_,
   {{0x26c55780,0x20f808a9,0x94190092,0x78a900ca}},	//   nolo_, _učio_, disə_, hiev,
   {{0xa0a65781,0x60c4001f,0xa2c1009d,0x26c5028d}},	//   _банд, poim, लकर्, iolo_,
   {{0x20565782,0x26c50201,0x317b00c1,0x628e5783}},	//   _стор, holo_, _נאכד, lkbo,
   {{0x26c55784,0xa3aa13ae,0x5fe017ff,0x7f750a29}},	//   kolo_, _गेम_, पेशल, _курц,
   {{0xc33309c1,0x3b060216,0x628e5785,0x386f0154}},	//   מוד_, rpoq_, nkbo, _angr_,
   {{0x26c55786,0x2ca40167,0x78a90036,0x00000000}},	//   dolo_, _tmmd_, fiev, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c55787,0x64860037,0x386f01ff,0x3af9022b}},	//   folo_, _lóis, _dngr_, _gèp_,
   {{0x0f570054,0x9b930080,0x26c55788,0xfb1b040a}},	//   ניים_, _الكت, golo_, _נובמ,
   {{0x88c502c6,0x45d415d6,0x090624ec,0x64751536}},	//   _svěř, ронс, _спен, агну,
   {{0x628e084e,0xceb4013c,0x699503a0,0x00000000}},	//   ekbo, xsən_, _трух, --,
   {{0x26c50220,0x752f007f,0x00000000,0x00000000}},	//   bolo_, ącza, --, --,
   {{0x26c50465,0xb05b00c2,0x39ae00a7,0x6aaa0178}},	//   colo_, _ikäi, _kəs_, niff,
   {{0x661a4b2c,0x20f804ad,0x64860076,0xa1945789}},	//   matk, _učil_, _cóis, барч,
   {{0x661a578a,0x6aaa01bf,0x88bc02c6,0x98a7020a}},	//   latk, hiff, _uvěd, mună_,
   {{0xb4c30789,0xceb40092,0x2ba41592,0x8e150a99}},	// [4ef0] ्ती_, rsən_, _खेला, идац,
   {{0x645f005c,0xc7d700a1,0x661a578b,0x78a9028d}},	//   _haqi, רומי_, natk, ziev,
   {{0x5d554fb4,0xf1ab00cd,0x7c8718d4,0x13b40281}},	//   ркет, _ساده_, луде, _نصیح,
   {{0x44fa0910,0x661a005a,0x3af914b1,0x80d30081}},	//   _më_, hatk, _pèp_, _দূর্,
   {{0x661a578c,0x09dd578d,0x44fa023b,0x645f578e}},	//   katk, मध्य, _lë_, _maqi,
   {{0xb4c32fc2,0x44fa0185,0x2ba4009d,0x39ae00a7}},	//   ्तु_, _oë_, _खेळा, _bəs_,
   {{0x661a578f,0x44fa5790,0x78a95791,0x26c5008f}},	//   datk, _në_, tiev, volo_,
   {{0x645f2a83,0x1d34002d,0x3af90154,0x7d01078e}},	//   _naqi, _ынся, _tèp_, _cârţ,
   {{0x26c55792,0x78a95793,0x236901fa,0x661a17b6}},	//   tolo_, riev, _nraj_, fatk,
   {{0x661a1a79,0x201b5794,0x44fa023b,0x78a95795}},	//   gatk, haqi_, _bë_, siev,
   {{0x26c55796,0x645f5797,0xb4c30096,0x78a900e8}},	//   rolo_, _baqi, ्तू_, piev,
   {{0x26c50283,0x23690113,0x290502a1,0x645f008c}},	//   solo_, _braj_, _itla_, _caqi,
   {{0x661a06ee,0x26c55798,0x648600da,0x645f0188}},	//   batk, polo_, _sóis, _daqi,
   {{0x412a3379,0xee0f152c,0x648600e3,0x27ff0451}},	//   кого_, िरोध_, _cóir, lcun_,
   {{0x7c3b09b3,0x91e60950,0x628e5799,0x6b8b338b}},	//   _ocur, рове, rkbo, hygg,
   {{0x27ff22d4,0x7bcd00d9,0x92b60033,0x7c3b05bd}},	//   ncun_, ļauj, জতে_, _ncur,
   {{0xee3a06d5,0xa3e51b92,0x44fa023b,0x60dd022b}},	// [4f00] кна_, भेद_, _zë_, _dhsm,
   {{0x2bdc0ccb,0xa5ca02d5,0x27e001b5,0x00000000}},	//   _बरबा, _सुडौ, _ùine_, --,
   {{0xc27b0054,0x645f579a,0x2b4d579b,0x127b006e}},	//   _סרטי, _yaqi, _apec_, _סאטע,
   {{0x8c460e58,0xdd8f0adc,0x645f008a,0xab660cf5}},	//   реде, بوم_, _xaqi, ивел,
   {{0x661a46c3,0x7d090087,0x39ae0092,0xbb432f24}},	//   yatk, _čese, _səs_, жечк,
   {{0x7c3b1fa1,0x2000044c,0x00000000,0x00000000}},	//   _ecur, lcii_, --, --,
   {{0x6aaa579c,0x661a579d,0x00000000,0x00000000}},	//   riff, vatk, --, --,
   {{0x6b8b1842,0x6d5c3e80,0x200052e1,0x661a31c7}},	//   bygg, _isra, ncii_, watk,
   {{0x44fa074a,0xd6da579e,0x20050092,0x661a5002}},	//   _së_, кто_, _əli_, tatk,
   {{0x3cf8579f,0x7afd57a0,0x443b0072,0x645f579a}},	//   _kurv_, _ésta, _scq_, _saqi,
   {{0x44fa0910,0x661a4691,0x20000181,0xb05b00c2}},	//   _që_, ratk, kcii_, _ikäv,
   {{0xb4c3084a,0x661a063f,0x69da57a1,0x44fa0052}},	//   ्ते_, satk, _izte, _vë_,
   {{0x661a10f3,0x6d5c0124,0x645f013c,0x00000000}},	//   patk, _lsra, _vaqi, --,
   {{0x44fa57a2,0x171b040a,0x23690220,0x6d4e02b6}},	//   _të_, _יודע, _vraj_, _opba,
   {{0x30a757a3,0xa0a757a4,0xbbd31178,0x00000000}},	//   арав, ашал, _तर्क, --,
   {{0xe3b80555,0x00000000,0x00000000,0x00000000}},	//   ğır_, --, --, --,
   {{0xe3b8008e,0x6d5c2f9c,0x6618023e,0x6d4e00e8}},	// [4f10] şır_, _asra, _kevk, _apba,
   {{0xde191e53,0x42550a09,0x44390170,0x6f020037}},	//   اقات_, _اندر, lgs_, íoca,
   {{0x2d8757a5,0xc21200ca,0x4439037a,0x66180233}},	//   âne_, _מהי_, ogs_, _mevk,
   {{0x443957a6,0x66180087,0x315600c1,0x67220128}},	//   ngs_, _levk, _פירן_, _ovoj,
   {{0x69da02a7,0x6b650f80,0x628557a7,0x201900ae}},	//   _azte, скла, _koho, _iesi_,
   {{0x628557a8,0x201901c8,0x6b8b57a9,0x661857aa}},	//   _joho, _hesi_, rygg, _nevk,
   {{0x2019068d,0x628557ab,0x8d9500e3,0x69da0034}},	//   _kesi_, _moho, _الأش, _czte,
   {{0xb4c3000d,0x6ca403d9,0x20190fa3,0x96010abe}},	//   ्तो_, _друж, _jesi_, ोर्ट_,
   {{0xb8fe1085,0x201957ac,0xb4c3000d,0x27ff57ad}},	//   _दी_, _mesi_, ्तै_, rcun_,
   {{0x27ff323d,0x20190060,0x628557ae,0x44392e8c}},	//   scun_, _lesi_, _noho, egs_,
   {{0x74ea13c7,0x79a72a90,0xaefb01f7,0x752f0034}},	//   лдог_, _трае, _drùi, ączo,
   {{0x443957af,0x648600e3,0xb4d22065,0x38ba01d3}},	//   ggs_, _cóip, वते_, pīra_,
   {{0x26d90472,0xe60e511e,0x00000000,0x00000000}},	//   ïsos_, _нд_, --, --,
   {{0xcb1200a1,0x44391183,0xd295004d,0xaefb009c}},	//   הלך_, ags_, орсь, _grùi,
   {{0x6285134c,0x20190496,0x4096014d,0xdddc00ae}},	//   _doho, _besi_, брат, _morţ,
   {{0x387f0510,0x10a3017b,0xe0df57b0,0x6618026a}},	//   njur_, писн, _chò_, _zevk,
   {{0xa0670465,0x201957b1,0x200057b2,0x777b0042}},	// [4f20] щата_, _desi_, rcii_, nxux,
   {{0xdc1000c3,0x20000036,0x20190139,0x1fb5004d}},	//   ार्ड_, scii_, _eesi_, істр,
   {{0x629c00e3,0x7bdb0361,0x20190065,0x387f003e}},	//   mhro, _azuu, _fesi_, kjur_,
   {{0xeb9a2120,0x628557b3,0x20190239,0xa5da006e}},	//   лие_, _zoho, _gesi_, אַדי,
   {{0x387f0212,0x69da0103,0x38c80a85,0x00000000}},	//   djur_, _szte, یابی_, --,
   {{0x6e96054f,0x6d5c0037,0x2010007f,0x69dc0285}},	//   _السا, _tsra, łnić_, _फरदी,
   {{0x5fac02e8,0xd7fa0095,0x6d5c181b,0x3e85030b}},	//   _घेतल, луп_, _usra, _dítě_,
   {{0x387f57b4,0xceb40092,0x8c4316bd,0xb4d20096}},	//   gjur_, ksək_, _несе, वतो_,
   {{0x7f4457b5,0xdddc00d3,0x661857b6,0x67200dd9}},	//   ntiq, _forţ, _pevk, usmj,
   {{0x69da00e7,0x3ce657b7,0x2a96007f,0x00000000}},	//   _tzte, lmov_, yłby_, --,
   {{0x628557b8,0x69da57b9,0x98c4026a,0x984a008f}},	//   _roho, _uzte, ştım_, _бяла_,
   {{0x672257ba,0x3eaa0063,0xfbdc5660,0x443957bb}},	//   _tvoj, _lmbt_, _बराम, ugs_,
   {{0x62851b32,0x443957bc,0x2019098c,0xb4c305d6}},	//   _poho, rgs_, _resi_, ्तौ_,
   {{0x201957bd,0x659400d3,0x629c57be,0x00000000}},	//   _sesi_, _малу, ghro, --,
   {{0x2019028d,0xe3b80233,0xc6930142,0x20d70f98}},	//   _pesi_, şıp_, _מאס_, مترج,
   {{0x3ce6230b,0x3eaa01cb,0x00000000,0x00000000}},	//   jmov_, _ambt_, --, --,
   {{0x62850363,0x201930a9,0x644d01e9,0xe45f02c3}},	// [4f30] _toho, _vesi_, _ibai, slös_,
   {{0x43d40037,0x68fa57bf,0x415557c0,0x201957c1}},	//   _عزيز, _outd, _двос, _wesi_,
   {{0x201957c2,0x7f440257,0xe0df00fe,0x00000000}},	//   _tesi_, atiq, _thò_, --,
   {{0x42550018,0x3e8500b6,0xdddc044c,0x00000000}},	//   _انگر, _sítě_, _sorţ, --,
   {{0xa03a0130,0x644d00e3,0x7f442322,0xdddc00ae}},	//   _דערפ, _mbai, ctiq, _porţ,
   {{0x660d08c5,0x44290131,0x8cd90034,0x1c0a01e4}},	//   _đako, _lda_, _फीरो, हुबल_,
   {{0x644d003b,0x442957c3,0x6f0d57c4,0x3ce60124}},	//   _obai, _oda_, lpac, bmov_,
   {{0xa3aa3b30,0x442957c5,0x7afd058a,0x6d4557c6}},	//   _गइल_, _nda_, _ésto, mtha,
   {{0x66040702,0x7c290032,0x68fa00b3,0x6d4557c7}},	//   _şika, _ider, _eutd, ltha,
   {{0x442957c8,0x644d57c9,0xda02000f,0x6d4557ca}},	//   _ada_, _abai, रुआत_, otha,
   {{0x6d4557cb,0x7afb0084,0x442957cc,0x25a003e3}},	//   ntha, _huut, _bda_, _ƙila_,
   {{0x6d4502ad,0x442957cd,0x7afb57ce,0xa7750aec}},	//   itha, _cda_, _kuut, _млеч,
   {{0x442957cf,0x629c4f4e,0x7afb5460,0x6d4557d0}},	//   _dda_, thro, _juut, htha,
   {{0x7afb1c73,0x442957d1,0x3ce619ad,0x2bdc1024}},	//   _muut, _eda_, zmov_, _बरसा,
   {{0x0446013d,0xf41f007b,0xa187001f,0xd175007b}},	//   _дейн, tkät_, обра_, пыты,
   {{0x7c2957d2,0x6f0d029a,0x644d01b9,0x6d4502db}},	//   _nder, fpac, _gbai, dtha,
   {{0x629c0e9b,0x6d4502ad,0x7afb0185,0x2caf0126}},	// [4f40] phro, etha, _nuut, digd_,
   {{0x7c2957d3,0x6d4557d4,0x4429551d,0x7f4457d5}},	//   _ader, ftha, _zda_, rtiq,
   {{0x7f4457d6,0x22580a9f,0x91e657d7,0xed5a413c}},	//   stiq, merk_, _фоне, рое_,
   {{0x82360018,0x7f4457d8,0x0b8a380e,0xbfa300fe}},	//   _ارکا, ptiq, исли_, _kiể,
   {{0x6d450091,0xdee6013d,0x7c290150,0x7ae1009c}},	//   atha, _моми, _dder, _bhlt,
   {{0x7c2957d9,0x6d4557da,0x6da60950,0x752f00a5}},	//   _eder, btha, _дига, ńczy,
   {{0xdd920018,0x6d4557db,0xb05b09df,0xdddc57dc}},	//   _غور_, ctha, _fjäd, _forš,
   {{0xf8ba00c7,0xd90d001c,0x7afb06b0,0xdddc1fcc}},	//   ুষ্ঠ, این_, _fuut, _gorš,
   {{0xa3aa0006,0xda0b009d,0x442957dd,0x22580a9f}},	//   _गेल_, _स्वत_, _rda_, kerk_,
   {{0x442957de,0x09e6125f,0x68fa00a7,0x7c29007f}},	//   _sda_, _дозн, _tutd, _zder,
   {{0x7c2901c5,0xc3220033,0x00000000,0x00000000}},	//   _yder, ভূমি_, --, --,
   {{0x6f0d57df,0xe4a7004d,0xbfa300fe,0xaaa6007f}},	//   ypac, ірно, _biể, कोरक,
   {{0x443f00d9,0xa01b03a8,0x00000000,0x00000000}},	//   ļu_, _glöy, --, --,
   {{0x6d4500f0,0x443f57e0,0x96a60096,0x2903014b}},	//   ytha, żu_, टोशॉ, _éjac_,
   {{0x349505e1,0x68e209a4,0x60d600f0,0x7ea020af}},	//   _накр, _khod, flym, _köpf,
   {{0x442957e1,0xd5b900d6,0x26cc03a9,0x6d4501fa}},	//   _uda_, _усі_, lodo_, vtha,
   {{0x68e2009b,0xbd000129,0x4aca382b,0x22870077}},	// [4f50] _mhod, _ịkpọ, ाकाव, _дунг,
   {{0x6f0d57e2,0xa2b40084,0x7afb0673,0x6d4557e3}},	//   rpac, _обыч, _ruut, ttha,
   {{0x68e2025b,0x7afb03cf,0x6d4557e4,0x2caf029a}},	//   _ohod, _suut, utha, tigd_,
   {{0x6d4557e5,0x7afb0fc4,0x660d02ef,0xaefb01f7}},	//   rtha, _puut, _đakm, _brùt,
   {{0x0f7907a6,0x26cc57e6,0xcb691669,0x3f79006e}},	//   _האָב, kodo_, сале_, _האָס,
   {{0x24893aab,0x4efa00ca,0x60cd0350,0x7ce300bc}},	//   _loam_, _להשו, loam, kõrg,
   {{0x26cc57e7,0x68e257e8,0x68200294,0x7d2400d3}},	//   dodo_, _bhod, _ịdab, _офте,
   {{0x68e212fb,0x60cd334c,0x31bc0266,0x7c2957e9}},	//   _chod, noam, יזונ, _uder,
   {{0x68e203a9,0xe7310037,0x64ab02c6,0x00000000}},	//   _dhod, رصة_, přij, --,
   {{0x26cc57ea,0x776903be,0x78c40134,0x60cd43fd}},	//   godo_, rvex, ịkpọ_, hoam,
   {{0x225857eb,0x68e2036b,0xd46a0408,0x66dd03a9}},	//   verk_, _fhod, бине_, gèka,
   {{0x225835a5,0x649a0a71,0x2a6531da,0x68e202a1}},	//   werk_, стор_, _halb_, _ghod,
   {{0x68e957ec,0x225857ed,0x26cc57ee,0x80c70033}},	//   mmed, terk_, bodo_, লগঞ্,
   {{0x68e957ef,0x2cbf0149,0x68e20244,0x7d0957f0}},	//   lmed, _ljud_, _zhod, _česn,
   {{0x40960fa5,0x5bb822a3,0x66cf004d,0x5502007f}},	//   прат, _अश्व, søks, _रूपए_,
   {{0x032613b0,0xb05b0222,0x68e957f1,0x2360022e}},	//   _един, _skär, nmed, _tsij_,
   {{0x44223ca0,0x22581507,0x2d8757f2,0x28cc0dba}},	// [4f60] mak_, perk_, änen_, ावति,
   {{0x442257f3,0x68e9050d,0x629501c2,0x2216007b}},	//   lak_, hmed, ckzo, _эфир,
   {{0x44220a00,0x60cd57f4,0x60d60124,0x68e957f5}},	//   oak_, boam, plym, kmed,
   {{0x442257f6,0x60cd0131,0x68e957f7,0x00000000}},	//   nak_, coam, jmed, --,
   {{0x68e202ad,0x44220a00,0x00000000,0x00000000}},	//   _rhod, iak_, --, --,
   {{0x442214f7,0x68e257f8,0x68e957f9,0x2a6500b3}},	//   hak_, _shod, emed, _calb_,
   {{0x442257fa,0x20070067,0xda6500e3,0xfd650294}},	//   kak_, śnie_, باني, _masị,
   {{0x7ce300aa,0x78bb0357,0x6f0d03a9,0x00000000}},	//   võrg, gnuv, _èncè, --,
   {{0x442217fb,0x68e20074,0x7c2200f2,0x3f800072}},	//   dak_, _vhod, maor, nxiu_,
   {{0x7c220065,0x7bcd01d3,0x24570023,0x442221c8}},	//   laor, ļaut, _ầm_, eak_,
   {{0x26cc013f,0x1dbe277c,0x68e90220,0xd82f004c}},	//   rodo_, ्थित, bmed, _пэ_,
   {{0x442257fb,0x7c2257fc,0x26cc57fd,0x00000000}},	//   gak_, naor, sodo_, --,
   {{0xb4bd2cba,0x24890231,0x00000000,0x00000000}},	//   _आदी_, _voam_, --, --,
   {{0x1dbe0d7e,0x1adc0789,0x66dd001c,0x44220167}},	//   ्थात, यतिथ, pèka, aak_,
   {{0x442257fe,0x31c457ff,0x7c223dd5,0x765a5800}},	//   bak_, еств, kaor, mety,
   {{0x44225801,0x765a5802,0x753a5803,0x00000000}},	//   cak_, lety, mutz, --,
   {{0x60cd2546,0x290c0a82,0xf3ff0131,0xe3bf037a}},	// [4f70] roam, _ltda_, ldão_, fañe_,
   {{0xaefb01ec,0x2cad13cd,0x765a5804,0x290c0154}},	//   _brùr, _smed_, nety, _otda_,
   {{0x753a02dc,0xf3ff016d,0x68e95805,0x60cd5806}},	//   nutz, ndão_, ymed, poam,
   {{0x765a00c2,0x00000000,0x00000000,0x00000000}},	//   hety, --, --, --,
   {{0x753a5807,0x68e92d84,0x66dd0113,0x7ce300bc}},	//   hutz, vmed, dèkn, võrd,
   {{0x44222855,0x9f9600a1,0x2a65003d,0x88bc00b6}},	//   zak_, _חדשה_, _qalb_, _dvěm,
   {{0x44224609,0x68e95808,0xbd450037,0xdca700ae}},	//   yak_, tmed, _تنزي, _ешап,
   {{0x38661909,0x442201e9,0xd70900ae,0x2cbf1124}},	//   _caor_, xak_, оние_, _ujud_,
   {{0xcb34013d,0x44225809,0x7e670ebd,0x386603dc}},	//   _петъ, vak_, _kajp, _daor_,
   {{0x4422580a,0x00000000,0x00000000,0x00000000}},	//   wak_, --, --, --,
   {{0x4422580b,0x753a0a00,0xe5a5580c,0x68e9580d}},	//   tak_, gutz, фини, pmed,
   {{0x442201e9,0x7e67580e,0x66dd0113,0x6836020e}},	//   uak_, _lajp, cèkn, rüdü,
   {{0x4422580f,0x765a1113,0xfd650174,0xd6291f46}},	//   rak_, bety, _pasị, _доле_,
   {{0x7e675810,0x7ea05811,0x59e102d5,0x753a0062}},	//   _najp, _köpe, _फरार, butz,
   {{0xaca300de,0x61431689,0x2d4700bc,0x753a020a}},	//   _chừn, кера, jõe_, cutz,
   {{0x98a01386,0x25d600c1,0xe0da02b7,0x00000000}},	//   čić_, _קוקן_, іва_, --,
   {{0x442000d3,0x7e670a39,0x7ea00212,0x044300d3}},	// [4f80] _iei_, _bajp, _löpe, _реын,
   {{0xf7675812,0x44205813,0x7c220174,0x3f800072}},	//   _یا_, _hei_, waor, rxiu_,
   {{0xa0a6025d,0x7c2200dc,0x629e028d,0x229400ce}},	//   _жанд, taor, _ilpo, _näki_,
   {{0x442001b3,0xa3d2063c,0x290c0027,0x80dc0033}},	//   _jei_, _वडा_, _rtda_, _মূর্,
   {{0x7c2218ba,0x629e0063,0x26c32f54,0x673b5814}},	//   raor, _klpo, čjoj_, juuj,
   {{0x44205815,0x3866006b,0x7c22061d,0x7125001c}},	//   _lei_, _saor_, saor, _تریل,
   {{0xd90d03ed,0x2f040222,0x442001cb,0x00000000}},	//   میل_, _hög_, _oei_, --,
   {{0x44201a5c,0x00000000,0x00000000,0x00000000}},	//   _nei_, --, --, --,
   {{0x6f0216cc,0x765a5816,0xb6f40215,0x29030113}},	//   íoch, tety, нзиј, _éjan_,
   {{0x6996036a,0x753a5817,0x7c2007ee,0x00000000}},	//   _орех, tutz, _hemr, --,
   {{0x44205818,0xf76f0979,0x2f040088,0xce3700ca}},	//   _bei_, های_, _lög_, ואית_,
   {{0x44200012,0x765a5819,0xf3ff0161,0x753a0a00}},	//   _cei_, sety, rdão_, rutz,
   {{0x4420581a,0xd7e220cd,0xe7e21677,0x7c201567}},	//   _dei_, _परिच, _परिप, _memr,
   {{0x7d03581b,0x80dc0081,0x44200072,0xddd500d4}},	//   ínsk, _মূল্, _eei_, _rozž,
   {{0x4420581c,0xd5af581d,0xd4c71146,0xe63b00ca}},	//   _fei_, _рс_, _осип, _ותוכ,
   {{0x4420581e,0x7c2009ef,0x629e581f,0xe7e20efb}},	//   _gei_, _nemr, _elpo, _पराप,
   {{0x645d5820,0xadc40139,0x7e675821,0x00000000}},	// [4f90] mesi, _ipẹr, _pajp, --,
   {{0x44200ab2,0xaca300fe,0x7d1c00eb,0x2bd200a3}},	//   _zei_, _thừn, _bwrs, _तड़ा,
   {{0x7e67023e,0xaefb0139,0x752801d3,0x7d1c03a8}},	//   _vajp, _erùp, nsdz, _cwrs,
   {{0x645d5822,0x8b6b00d9,0x44200850,0x2d810216}},	//   nesi, ņēmē, _xei_, rxhe_,
   {{0x7e6702a1,0x511f007a,0x628e00cc,0xaefb01b9}},	//   _tajp, _बबुआ_, žnoš, _grùp,
   {{0xa9690562,0x2d470161,0x7d1c030a,0x00000000}},	//   зика_, põe_, _fwrs, --,
   {{0x7c2000dd,0x645d5823,0xac190b7b,0x6e250167}},	//   _femr, kesi, _нову_, mahb,
   {{0x645d5824,0xe3b8008b,0xa7655136,0x7c2003a9}},	//   jesi, ğız_, екид, _gemr,
   {{0x44205825,0x59e10cce,0xbb190037,0x6444009c}},	//   _rei_, _फरवर, _رياض_, _rcii,
   {{0x44202cc5,0x396402fd,0x7c2000dd,0x45853574}},	//   _sei_, ässä_, _zemr, егов,
   {{0x04464441,0xd46a1669,0x00000000,0x00000000}},	//   ненн, пине_, --, --,
   {{0x64ca277c,0xd46a0f21,0x7ea002c3,0xf77125a1}},	//   रवेश, чиме_, _köpc, _مات_,
   {{0xe72e5826,0x44205827,0xaca30028,0xf7700504}},	//   _ще_, _vei_, _chứn, _پان_,
   {{0xa764004d,0xf74200e5,0x00000000,0x00000000}},	//   _шкід, _сешо, --, --,
   {{0xf09f009c,0x44205828,0x2bdc0e52,0x6e250113}},	//   _blà_, _tei_, _बर्थ, dahb,
   {{0x645d5829,0xf41f007b,0x20e8042c,0x00000000}},	//   cesi, ljän_, ißig_, --,
   {{0x672914e2,0x8fa31b48,0x6f1d03a8,0x00000000}},	// [4fa0] nsej, гате, _cwsc, --,
   {{0x6da61d1c,0x76412085,0xf09f0139,0x200b00b3}},	//   низа, ngly, _elà_, _efci_,
   {{0xe3bf08a8,0x200603be,0x7c200510,0x200700a5}},	//   maña_, ñois_, _pemr, śnia_,
   {{0xac07582a,0x0ca900e3,0x61e10eef,0x6729582b}},	//   енца_, وطني_, ülle, ksej,
   {{0xc5f80029,0xeb9700c2,0x7cfa02c6,0x67290206}},	//   ldēt_, ниц_, _důra, jsej,
   {{0x645d582c,0x99661165,0x6e2537e5,0xef11006e}},	//   zesi, етил, cahb, _כּל_,
   {{0x645d582d,0x672b00d6,0xed5700c2,0xdc340206}},	//   yesi, _avgj, _пор_, lúči,
   {{0xd90d001c,0x00000000,0x00000000,0x00000000}},	//   زیه_, --, --, --,
   {{0xb9070454,0xdca32edd,0xb8e809b0,0x6d5000c4}},	//   _मी_, _сати, _ईद_, ždač,
   {{0x645d582e,0x95ca0b99,0xa96a1d54,0x67530037}},	//   wesi, зума_, _низа_, اخير,
   {{0x7d09582f,0x645d5830,0xd5ba2cc5,0x6adc02d5}},	//   _česk, tesi, яси_, यतीर,
   {{0x7afa1f60,0x779200cd,0xddc700d9,0x00000000}},	//   _hitt, _میبا, _sajū, --,
   {{0x087700c1,0x200901fa,0xddc733f4,0x6e2500dc}},	//   _רעדט_, vcai_, _pajū, yahb,
   {{0x7afa003d,0x877b00c1,0xe3bf00e1,0x3ce7074c}},	//   _jitt, _מאדי, gaña_, _छीने_,
   {{0x7afa5831,0xf09f00ee,0x00000000,0x00000000}},	//   _mitt, _plà_, --, --,
   {{0x7afa5832,0x7bde00a5,0x645d023b,0x69da0e9f}},	//   _litt, ępuj, qesi, _myte,
   {{0x9f340120,0xe3bf0487,0x00000000,0x00000000}},	// [4fb0] леті, baña_, --, --,
   {{0x7afa02a1,0xa3aa152c,0x3f8701ac,0x6eba0b94}},	//   _nitt, _गेट_, ćnu_, ्वगु,
   {{0xeab11e49,0x81d80033,0x200900dc,0x69da0727}},	//   یعت_, ়েব_, pcai_, _nyte,
   {{0x2bdc007d,0x7c845833,0x7afa01e8,0xa3e800aa}},	//   _बरखा, луче, _aitt, _भरम_,
   {{0x7afa5834,0x69da5835,0xf41f007b,0x5fe41536}},	//   _bitt, _ayte, yjän_, _бірж,
   {{0x7afa0465,0x69da5836,0x1ee70a85,0x00000000}},	//   _citt, _byte, _سوزی_, --,
   {{0x7afa4126,0x7f4d5837,0xa96617a8,0x291e030a}},	//   _ditt, ltaq, вища_, _cwta_,
   {{0x7afa0102,0xa3c30635,0xb17c0341,0x67295838}},	//   _eitt, ्था_, לטור, tsej,
   {{0x7f4d00a7,0x81d70081,0x7afa5839,0x07a50161}},	//   ntaq, িধি_, _fitt, тапн,
   {{0x7afa0b88,0x79a7197b,0x7c2d003e,0x7ea00212}},	//   _gitt, _прее, ðarf, _köpa,
   {{0x6729583a,0x64a6583b,0x7bdb0167,0x89340604}},	//   ssej, вана, _hyuu, _معنا,
   {{0x7afa583c,0x7bdb583d,0x660d0095,0x3a27007e}},	//   _zitt, _kyuu, _đaku, lanp_,
   {{0xccf200c1,0xe3bf0610,0x7ea00212,0x386d583e}},	//   יכט_, taña_, _löpa, mder_,
   {{0x386d0073,0x64410138,0x00000000,0x00000000}},	//   lder_, ėlia, --, --,
   {{0xaca3011b,0xa01b0149,0xe3bf583f,0xe5a2004d}},	//   _nhữn, _onöd, raña_, _вищи,
   {{0x3a2700f9,0xe3bf0328,0x92b20033,0xc5f800e8}},	//   hanp_, saña_, টকে_, rdēt_,
   {{0xe3bf11c4,0xb05b070a,0x386d510f,0x6456023f}},	// [4fc0] paña_, _tjän, ider_, _ibyi,
   {{0xb05b070a,0x386d00f0,0x2d962458,0xee3713dd}},	//   _hjäl, hder_, крес, кну_,
   {{0x4432030b,0x2d9c0181,0x386d00dc,0x7bdb0188}},	//   _kdy_, áve_, kder_, _ayuu,
   {{0x7afa5840,0x386d5841,0x6aa15842,0x2ca00037}},	//   _sitt, jder_, _allf, óid_,
   {{0x8c431af2,0xef170084,0x69da5843,0x386d40d5}},	//   рече, _имя_, _syte, dder_,
   {{0x386d08c8,0x63890052,0x61e902c6,0xdb110103}},	//   eder_, _hënë, řele, ágáb,
   {{0x69da01e5,0x7afa5844,0x98c62972,0x7bdb0172}},	//   _qyte, _vitt, ксил, _eyuu,
   {{0xfce60a8d,0x7afa08c8,0x69da3e67,0x386d40d6}},	//   _робо, _witt, _vyte, gder_,
   {{0x7afa5845,0xc6f80938,0x47340291,0x8b0503e3}},	//   _titt, нних_, ћнос, ƙƙar,
   {{0x7afa5846,0x645605bd,0x4de6007f,0x44325847}},	//   _uitt, _abyi, _कराई_, _ady_,
   {{0xceb30054,0x2294007a,0x629c110e,0x25a901c2}},	//   שית_, _läks_, dkro, _ƙala_,
   {{0x79b70054,0x6389023b,0x35b306c4,0x629c02ac}},	//   _בלבד_, _nënë, рбюр, ekro,
   {{0xa3e82397,0x4432030a,0xf7430120,0x00000000}},	//   _भरण_, _ddy_, _вечо, --,
   {{0x28ae007a,0xf2c400c2,0x645602a4,0x78a20234}},	//   जोरि, ассн, _ebyi, _hlov,
   {{0xe2f8004d,0xb05b0212,0x40355848,0xd9f40569}},	//   тері_, _fjäl, левс, ेखित_,
   {{0x44325849,0x7f4d584a,0x61e5030b,0x3a2706a3}},	//   _gdy_, ttaq, _vzhl, zanp_,
   {{0xe3bf11ce,0x6ab817d2,0x26de142f,0x2d8e042c}},	// [4fd0] maño_, kivf, olto_, äfen_,
   {{0xa3e804a9,0x7f4d584b,0xe3bf03be,0x78a2584c}},	//   _भरत_, rtaq, laño_, _llov,
   {{0x386d584d,0x7f4d584e,0x44320150,0xb90b0065}},	//   yder_, staq, _ydy_, _dajọ_,
   {{0xe7e20f42,0x603e020a,0x23690216,0x00000000}},	//   _परंप, rămâ, _ksaj_, --,
   {{0x386d004d,0x6f020076,0x00000000,0x00000000}},	//   vder_, íoct, --, --,
   {{0x539c0266,0x386d00d7,0x78a2584f,0x38ba00e8}},	//   וידו, wder_, _alov, kīrs_,
   {{0x27e60018,0x79a7008f,0x00000000,0x00000000}},	//   _azon_, ърде, --, --,
   {{0x2ca65850,0x386d0126,0x78a25851,0x629c00d4}},	//   chod_, uder_, _clov, zkro,
   {{0x386d5852,0x629c0313,0xe3bf0072,0x00000000}},	//   rder_, ykro, daño_, --,
   {{0xb05b070a,0x386d10f8,0x27e6007e,0x7ea00212}},	//   _själ, sder_, _dzon_, _löpn,
   {{0x39151e20,0x236900dd,0x69c400ae,0x78a25853}},	//   _смер, _asaj_, şier, _flov,
   {{0x3a255854,0xe3bf0487,0x79b60327,0x78a21190}},	//   _help_, gaño_, _גלעד_, _glov,
   {{0x29055855,0x629c08c5,0x23690103,0x753a5856}},	//   _hula_, tkro, _csaj_, artz,
   {{0x29055857,0x2d731912,0x2ebf034d,0x78a205db}},	//   _kula_, _oće_, ्वोत, _zlov,
   {{0x29055858,0x629c0f05,0xe3bf0328,0x00000000}},	//   _jula_, rkro, baño_, --,
   {{0x29055859,0x629c3988,0xa067585a,0xe3bf0143}},	//   _mula_, skro, ласа_, caño_,
   {{0x2905585b,0xbd8a001c,0x3fe614f2,0xc0e313fc}},	// [4fe0] _lula_, کنان_, ужав, сотк,
   {{0xa3c324eb,0x3a250167,0x673b0063,0x11d60037}},	//   ्थर_, _nelp_, iruj, _متجد,
   {{0x2176105c,0x88bc030b,0x2ca6585c,0x3d2b001c}},	//   _супр, _květ, thod_, فتنی_,
   {{0x64461bd6,0xa3e80f78,0x6adc1f88,0x673b16a6}},	//   ngki, _भरा_, यत्र, kruj,
   {{0x29054772,0x60c4585d,0x6d41032e,0xc2c90281}},	//   _aula_, mnim, _ålan, _سبیل_,
   {{0x78a2585e,0x2905585f,0xaa58074b,0x60c45860}},	//   _slov, _bula_, тику_, lnim,
   {{0x248004eb,0x29050ca7,0x1fbf0033,0xada60307}},	//   _onim_, _cula_, _আরএস, _савл,
   {{0x47345861,0x60c45862,0x290511b9,0x6d4e5863}},	//   анис, nnim, _dula_, _iqba,
   {{0x7c930080,0x29050a69,0x862652d5,0x38ba0139}},	//   _القص, _eula_, льне, _aàrè_,
   {{0x248000a6,0x2905502e,0x64460381,0x00000000}},	//   _anim_, _fula_, egki, --,
   {{0x29052d96,0x7afd008f,0x24191ad1,0xe3bf0610}},	//   _gula_, _èsta, коны_, taño_,
   {{0x78a25864,0xa3c300c0,0x60c45865,0x2369007e}},	//   _ulov, ्थल_, jnim, _psaj_,
   {{0x60c45866,0x3a250632,0x6eeb5867,0x2f0d0206}},	//   dnim, _yelp_, lübe, _oľga_,
   {{0x6d5c18f9,0x24805868,0x236902dd,0x3eba023b}},	//   _opra, _enim_, _vsaj_, jipt_,
   {{0x6f065869,0x6eeb586a,0x81dd0081,0x30eb3715}},	//   _aukc, nübe, তেন_, ефан_,
   {{0x2369022e,0x60c4586b,0x301524f7,0x00000000}},	//   _tsaj_, gnim, рдар, --,
   {{0x6d5c586c,0x6d4e0188,0xa3c30096,0x23ab0139}},	// [4ff0] _apra, _aqba, ्थळ_, _dòjé_,
   {{0x32552cbf,0x88bc00b6,0x64480138,0x3eba0076}},	//   _твор, _zvět, ėdie, gipt_,
   {{0x60c4586d,0x67220172,0x00000000,0x00000000}},	//   bnim, _lwoj, --, --,
   {{0x2905586e,0xb19a00ca,0x60c4586f,0x00000000}},	//   _rula_, _ייתכ, cnim, --,
   {{0x29055870,0xcb694438,0x7658033d,0x7ea01a92}},	//   _sula_, тале_, _obvy, _köpl,
   {{0x29053ad9,0xeb96249b,0x442b5871,0x7c2d01cd}},	//   _pula_, риш_, hac_, ðarb,
   {{0x0dc802ec,0xe5090028,0x442b5872,0xdd9400c6}},	//   _бути_, _mặc_, kac_, _лары,
   {{0x38ba5873,0x673b5874,0x29052e74,0x4df4030b}},	//   tūra_, truj, _vula_, ्खरै_,
   {{0x8b58097d,0x6d5c030b,0x3a250096,0x290501c2}},	//   _مجلس_, _zpra, _telp_, _wula_,
   {{0x88bc000d,0x290500a6,0xe8df0174,0x60c4033b}},	//   _svět, _tula_, _idọm_, znim,
   {{0x3ced023e,0x442b2a7e,0x60c45875,0x05cf0034}},	//   _khev_, fac_, ynim, _सुखब,
   {{0x442b008a,0x3ced0063,0x60c40188,0xa3c30167}},	//   gac_, _jhev_, xnim, ्थं_,
   {{0x60c40087,0x87e75876,0x78a90120,0x6e3500d8}},	//   vnim, _сюже, mhev, _odzb,
   {{0x6e2700b6,0xe5090023,0x7ea0026a,0x7c2b0072}},	//   _nejb, _cặc_, _röpo, hagr,
   {{0x60c404fa,0x6f060034,0x00e4001c,0x7c2b5877}},	//   tnim, _sukc, متری, kagr,
   {{0xa3b139d4,0x661c026a,0x80660859,0x00000000}},	//   _टेक_, ırke, јваж, --,

   {{0xa0672de0,0x6d5c5878,0x60c45879,0xb4c409a0}},	// [5000] шата_, _spra, rnim, ्वी_,
   {{0x6f0600e7,0x2d9a0133,0x7d070216,0x6d5c02a1}},	//   _vukc, type_, _bujs, _ppra,
   {{0x69da009d,0xdd1f24a1,0x823b00ca,0x60c40660}},	//   _पुढी, _píšt, _בעיצ, pnim,
   {{0x7d0902e6,0xeb9a0d64,0x6d5c0b27,0xfce3004d}},	//   _čest, кие_, _vpra, оохо,
   {{0x3ced023e,0x78bb028d,0xfcaa0504,0x6d5c007f}},	//   _dhev_, diuv, _یارو_, _wpra,
   {{0x442b0995,0x3d28001c,0x7ea002c3,0x00000000}},	//   zac_, _متری_, _köpm, --,
   {{0x67220067,0x81d80081,0x6d4e061d,0x442b1321}},	//   _swoj, ়ের_, _uqba, yac_,
   {{0x8c4308c3,0x6eeb02e2,0x672206a3,0x2d68026a}},	//   _месе, rübe, _pwoj, _işe_,
   {{0x442b00e9,0x6eeb0364,0xf708020b,0x00000000}},	//   vac_, sübe, _bủa_, --,
   {{0xf708561d,0x7d00587a,0x442b587b,0x0f5700ca}},	//   _của_, _hims, wac_, סיים_,
   {{0x442b587c,0x7d00587d,0x58861402,0x45d42290}},	//   tac_, _kims, _выла, сонс,
   {{0x67220067,0x78a9158e,0x08fa1850,0x395e061d}},	//   _twoj, chev, _شراب_, _ipts_,
   {{0xbf9b001f,0x2007007f,0x00000000,0x00000000}},	//   _agên, śnik_, --, --,
   {{0x7c2b587e,0xdddc009e,0x1b030033,0x1de600aa}},	//   zagr, _borż, রীকে_, _करूष_,
   {{0x45440103,0x64400610,0xddce01d3,0x00000000}},	//   _انعق, ómic, _dabū, --,
   {{0xd25100bf,0xd5fb0054,0x7d00484a,0x8d870103}},	//   _کند_, _בפור, _nims, یشان,
   {{0xe5090023,0x644d0027,0x7c2b587f,0x9e070e2c}},	// [5010] _tặc_, _icai, vagr, ачел,
   {{0x7d000a62,0x44290006,0x4fc4325f,0xdddc02a1}},	//   _aims, _hea_, іста, _forż,
   {{0x3ced023e,0xdef85880,0x5d552cf5,0x44295881}},	//   _phev_, рыт_, скет, _kea_,
   {{0x3ced022e,0x7d00007e,0x3211007f,0x00000000}},	//   _qhev_, _cims, lczy_, --,
   {{0x7c2b5882,0x4429002d,0xa3dd00a5,0x3c0f030b}},	//   ragr, _mea_, _तुम_, ाडौँ_,
   {{0x44295883,0x3e57030b,0x6e350995,0x691502a1}},	//   _lea_, _dětí_, _udzb, _jġeg,
   {{0x442902f1,0x3ced022e,0x69da0789,0xb7bd00ae}},	//   _oea_, _thev_, _पुदी, maţi,
   {{0xc31d00c7,0x6d455884,0xb7bd002d,0x644d006c}},	//   _তিনি_, muha, laţi, _ncai,
   {{0x6d451ef8,0x78a95885,0x00000000,0x00000000}},	//   luha, rhev, --, --,
   {{0x7c292ddf,0x644d5886,0x78a95887,0xb7bd00d3}},	//   _heer, _acai, shev, naţi,
   {{0x6d454609,0x7c295888,0x78a90120,0x00000000}},	//   nuha, _keer, phev, --,
   {{0x44290012,0xb4c40a35,0x7c295889,0x443e02e2}},	//   _cea_, ्वे_, _jeer, ßt_,
   {{0x4429588a,0x7c29588b,0x6d45588c,0x7ce300bc}},	//   _dea_, _meer, huha, tõrj,
   {{0x7c29588d,0x6d451f21,0x4429009e,0x7e650167}},	//   _leer, kuha, _eea_, jehp,
   {{0x91e6158d,0x4429034f,0x6d4500bc,0xb7bd00ae}},	//   сове, _fea_, juha, daţi,
   {{0x6d45588e,0x7c29588f,0x3eb80dab,0x644d00e3}},	//   duha, _neer, _smrt_, _gcai,
   {{0x4fea3c76,0xe29a007e,0x7f4a0037,0x6d450231}},	// [5020] уман_, _бап_, طلاق_, euha,
   {{0xb7bd00d3,0x442940b0,0xe45f007b,0x00000000}},	//   gaţi, _zea_, nnön_, --,
   {{0x7c295890,0x6d455891,0x691502a1,0x2b5f020a}},	//   _beer, guha, _jġed, _apuc_,
   {{0x30860037,0x395e0072,0x7c290188,0x691500bd}},	//   _الحف, _rpts_, _ceer, _mġed,
   {{0x7c295892,0x7c2d01cd,0x7f440639,0x395e00dc}},	//   _deer, ðara, quiq, _spts_,
   {{0x6d455893,0xb7bd002d,0x427a006e,0xdce8020e}},	//   buha, caţi, ראַג, ılır,
   {{0xfce65894,0x6d451df6,0x7c292a7e,0xd90d0281}},	//   _гово, cuha, _feer, نیل_,
   {{0x7c295895,0xb4c4023a,0x3ae90037,0xc8665896}},	//   _geer, ्वो_, rúpa_, стки,
   {{0x44295897,0x644d5898,0x4fbb006e,0x66dd03a9}},	//   _rea_, _rcai, ָציא, jèks,
   {{0xed4f00fb,0x644d00e3,0x7c295899,0x7ae30124}},	//   _تھے_, _scai, _zeer, clnt,
   {{0x4429007a,0x7c293329,0x2fc700de,0x38640231}},	//   _pea_, _yeer, ̃ng_, pemr_,
   {{0x7c29008a,0xb7bd00d3,0xf1c000de,0x7ce300bc}},	//   _xeer, zaţi, _ương_, võrk,
   {{0x4429589a,0xc6270033,0x6d45589b,0x16340927}},	//   _vea_, _মারা_, zuha, _деля,
   {{0x6d45589c,0x46f600c2,0x4429589d,0xddc7033b}},	//   yuha, _учет, _wea_, _lajš,
   {{0x518421b6,0x30a7589e,0x321100a5,0xd65700ca}},	//   пута, брав, rczy_, _ליגת_,
   {{0xfd4d0028,0xddc7589f,0xd3a700d3,0x00000000}},	//   _thoạ, _najš, _гроп, --,
   {{0x59df58a0,0xb7bd00d3,0x7c29008a,0x6d4558a1}},	// [5030] _पुनर, taţi, _reer, wuha,
   {{0x7c2958a2,0x2aab01c5,0x6d4558a3,0xdef81119}},	//   _seer, _købe_, tuha, бых_,
   {{0x628558a4,0xb7bd002d,0xe5090023,0xaca30174}},	//   _inho, raţi, _lặn_, swọd,
   {{0xa3bd099d,0x6aa80381,0xb7bd044c,0x00000000}},	//   _आधा_, _aldf, saţi, --,
   {{0x7c2958a5,0x2aab052f,0xb7bd020a,0xe0df0065}},	//   _veer, _løbe_, paţi, _ikò_,
   {{0x7c2958a6,0x6d450e22,0xbdfb0018,0xfbd001c3}},	//   _weer, puha, _مرزا_, رتن_,
   {{0x9d1858a7,0x7c2958a8,0x59a40034,0xb05b02c3}},	//   _гост_, _teer, गैलर, _djäv,
   {{0xddc705db,0x98bc00e8,0x6aa858a9,0x00000000}},	//   _gajš, tuvā_, _eldf, --,
   {{0xdddc0b88,0x7a340103,0xe50900fe,0x628518f0}},	//   _karş, _sütő, _cặn_, _onho,
   {{0x8699004c,0xe5090023,0xb9120139,0x6297063d}},	//   ртит_, _dặn_, _jabọ_, _noxo,
   {{0xaca300de,0xdddc03e0,0x00000000,0x00000000}},	//   _chủn, _marş, --, --,
   {{0x2b403f64,0x394744c3,0x6285052f,0x00000000}},	//   šice_, muns_, _anho, --,
   {{0x629700d4,0x00000000,0x00000000,0x00000000}},	//   _boxo, --, --, --,
   {{0xe5a558aa,0xe0df35c6,0x35a50077,0x2bc00285}},	//   _мили, _akò_, _малг, _शेफा,
   {{0x40961af2,0xc61600ca,0x629758ab,0x20fe0134}},	//   орат, _וחצי_, _doxo, ọime_,
   {{0xd0071896,0x6ab6022d,0x62853dc1,0x00000000}},	//   жете_, _अग्र, _enho, --,
   {{0x39470065,0x62970072,0xdd0102c6,0xddc70117}},	// [5040] huns_, _foxo, štěs, _rajš,
   {{0x9b8a001c,0x7ea00212,0x62970634,0x7c2d01cd}},	//   ینال_, _köpi, _goxo, ðarn,
   {{0x3947020a,0xa01b0c19,0x00000000,0x00000000}},	//   juns_, _knöl, --, --,
   {{0x23771e49,0xa31e00b6,0x1cba0076,0x00000000}},	//   _امید_, _बझाङ_, جائب_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629758ac,0x5f274e42,0xdddc11bc,0x00000000}},	//   _xoxo, _форм_, _garş, --,
   {{0xa2cd0961,0x39472558,0xda6500e3,0xdca60399}},	//   _सदस्, guns_, ثاني, _дави,
   {{0x7cf10bab,0x29020222,0xbc63107a,0x00000000}},	//   gård, öka_, _овск, --,
   {{0xdb2400d0,0xe66658ad,0xb8660103,0x5ebf0033}},	//   _روای, отно, ماکو, ্তরে,
   {{0x7c2258ae,0x39470161,0xe5090023,0xb50b58af}},	//   lbor, buns_, _vặn_, _संशय_,
   {{0x291a1054,0x3947542a,0x95ca46ff,0x00000000}},	//   ípad_, cuns_, рупа_, --,
   {{0x7c2258b0,0x1b1d0081,0xd7fa0b36,0x290c58b1}},	//   nbor, _নিতে_, _кул_, _iuda_,
   {{0x04b80018,0x7c2258b2,0x00000000,0x00000000}},	//   تھوں_, ibor, --, --,
   {{0xaabc0557,0xaca358b3,0x4abc0096,0xe0df022b}},	//   ्चिक, _ihụn, ्चिव, _skò_,
   {{0x290c58b4,0x3ce60631,0x7c2258b5,0x8afd02c6}},	//   _juda_, klov_, kbor, _upře,
   {{0x261604a9,0x290c1e9a,0x3ce62174,0x213e0076}},	//   पुरी_, _muda_, jlov_, átha_,
   {{0x9f5958b6,0x6297002b,0x7c2258b7,0x290c0995}},	// [5050] _også_, _toxo, dbor, _luda_,
   {{0xdddc0253,0x518750e9,0x62850072,0xf3ff016d}},	//   _qarş, _дума, _unho, leão_,
   {{0x80271823,0x290c58b8,0xbc19224a,0x4c180294}},	//   _ورحم, _nuda_, білі_, _ịtụk,
   {{0x7c2258b9,0x7cf125e5,0x3ce605db,0x00000000}},	//   gbor, kåre, glov_, --,
   {{0x7cf10149,0x290c57d7,0x7ce300bc,0xf41f00ce}},	//   vård, _auda_, kõrv, ljäs_,
   {{0x2e48007b,0x7cf10ac9,0xfbd04345,0x27190033}},	//   _мясо_, dåre, ختم_, _দিলো_,
   {{0x81dd00c7,0x7762002b,0x7c2258ba,0x3ce61656}},	//   তের_, _apox, bbor, blov_,
   {{0x290c120d,0x39470161,0x6d57023e,0x7e7501c8}},	//   _duda_, runs_, mtxa, _hazp,
   {{0x7c3b58bb,0xf3ff0231,0x6d570062,0x00000000}},	//   _idur, deão_, ltxa, --,
   {{0xca740037,0x7e750062,0xe80d3516,0x00000000}},	//   _يالغ, _jazp, _हलवा_, --,
   {{0x290c1114,0x6d5701e9,0x44220062,0x1dbd4f99}},	//   _guda_, ntxa, tbk_, ्पित,
   {{0x895a0796,0x7c3b00bd,0x7cf10b81,0x00000000}},	//   _לדעת, _jdur, båre, --,
   {{0x7c3b00e7,0x00000000,0x00000000,0x00000000}},	//   _mdur, --, --, --,
   {{0x290c0283,0xb77a00ca,0xfe1b0bf5,0x7e7558bc}},	//   _yuda_, _לאנש, _प्लस_, _nazp,
   {{0xd1790a8d,0x64a658bd,0x703a02fd,0x7c3b58be}},	//   ості_, _нака, йчас_, _odur,
   {{0x7c3b58bf,0x7c2d003e,0x7cea0094,0xa6e201cd}},	//   _ndur, ðarl, výro, öðvu,
   {{0xee3a58c0,0x7c2258c1,0x7e7501ff,0x9f5800a7}},	// [5060] йна_, vbor, _bazp, _özüm_,
   {{0x7c3b026e,0xd37b00ca,0xb05b02c3,0x9f4b01f9}},	//   _adur, _פריט, _sjät, émát_,
   {{0x929b0054,0xe29b00a1,0x7c2258c2,0x729b00ca}},	//   _היית, _השיר, tbor, _הסיס,
   {{0xdcb9004d,0x2fcd0234,0x7f56014b,0x00000000}},	//   ощі_, _žege_, ptyq, --,
   {{0x7c2236e2,0x290c042d,0x200700b6,0x3ce62059}},	//   rbor, _suda_, ěnit_, rlov_,
   {{0x3ce658c3,0x7c3b58c4,0x7e7558c5,0x6d57023e}},	//   slov_, _edur, _gazp, btxa,
   {{0x3ce608a9,0xe50900fe,0x00000000,0x00000000}},	//   plov_, _bặm_, --, --,
   {{0x6e2e26f1,0xb05b0222,0x7e750a00,0xaca30023}},	//   _hebb, _hjär, _zazp, _phụn,
   {{0xd6da0465,0x7f4418c8,0x7d0e58c6,0x6e2e58c7}},	//   йто_, nriq, _hubs, _kebb,
   {{0x7cf10c08,0x290c00cc,0xcfb70266,0xfd690294}},	//   råre, _tuda_, פליי_, jupụ,
   {{0x94d5016c,0x7cf125e5,0x2bc00096,0xaa430110}},	//   донц, såre, _शेता, _чехл,
   {{0xd5b700c6,0x8ec40081,0x443b034f,0x7cf102c3}},	//   ясы_, ্তিগ, _qdq_, påre,
   {{0x7d0e58c8,0x68e258c9,0x9987007e,0xd7e3004d}},	//   _lubs, _ikod, manš_, _пішо,
   {{0x27e60256,0x6e2e58ca,0x7f4458cb,0x29064ead}},	//   _iyon_, _nebb, driq, _hioa_,
   {{0x30a73703,0x26de58cc,0x7e750b27,0x27e60027}},	//   прав, moto_, _razp, _hyon_,
   {{0x61e50074,0xc7b90103,0x6d57023e,0x4de6007a}},	//   _vyhl, kből_, vtxa, _करजई_,
   {{0xb4d90b89,0x6e2e58cd,0xc43c00ca,0x2ca600f9}},	// [5070] ़की_, _bebb, _התחי, dkod_,
   {{0x26de58ce,0x645d00e7,0x7d0e00c4,0x61e502c6}},	//   noto_, lfsi, _bubs, _tyhl,
   {{0x6e2e58cf,0x27e658d0,0x26cc001f,0x6b8002ac}},	//   _debb, _lyon_, indo_, _armg,
   {{0x7f4458d1,0x26de58d2,0x644f019f,0x6d570a00}},	//   briq, hoto_, ngci, rtxa,
   {{0x6e2e013d,0x26de58d3,0xb05b0149,0x60cd58d4}},	//   _febb, koto_, _fjär, mnam,
   {{0x60cd0358,0x68e258d5,0xe9a9001c,0xfe710470}},	//   lnam, _akod, يگان_, _جگر_,
   {{0x27e60256,0x24890154,0xac190f1e,0x7d0e0167}},	//   _ayon_, _onam_, _мову_, _gubs,
   {{0x60cd58d6,0x26cc58d7,0xb4ac030b,0x7c3b01c2}},	//   nnam, endo_, _गते_, _udur,
   {{0x26de58d8,0x60cd58d9,0xa80600e1,0x6e2e58da}},	//   foto_, inam, _riñó, _yebb,
   {{0x248958db,0x68e258dc,0x6f0f00e5,0x26de58dd}},	//   _anam_, _ekod, _mucc, goto_,
   {{0x04461c32,0x6f0f008f,0xa8060328,0x7d030139}},	//   менн, _lucc, _piñó, _gìrì,
   {{0x6f07023e,0x98bc013f,0x38c30139,0xfd690129}},	//   _lijc, tuvą_, _dèrè_, wupụ,
   {{0x7ea00149,0x68e90407,0x26de58de,0xe72e1cbb}},	//   _köpt, mled, boto_, _ше_,
   {{0x65c53f98,0x68e958df,0x248958e0,0xda0d06ed}},	//   _обла, lled, _enam_, िखित_,
   {{0x81e600c7,0x91e3355a,0x35fb12eb,0x2cad007a}},	//   বেন_, воре, _ارشد_, _oled_,
   {{0x60cd58e1,0x20fa0efb,0x6f0f58e2,0x6e2e58e3}},	//   gnam, ्देश_, _bucc, _sebb,
   {{0x6f0f2d37,0x6d4501bf,0x63a00212,0x68e9518d}},	// [5080] _cucc, erha, ämnd, iled,
   {{0x248902e6,0xee3a013f,0x68e9000d,0x60cd01b5}},	//   _znam_, іне_, hled, anam,
   {{0xd00a58e4,0xed570fd5,0x60264659,0x68e958e5}},	//   _мене_, дох_, _одна, kled,
   {{0x6e2e58e6,0x68e901c5,0x60cd00e3,0x6f0f0036}},	//   _webb, jled, cnam, _fucc,
   {{0x68e958e7,0x9987031a,0x38aa01ec,0xb05b173a}},	//   dled, vanš_, _bùrn_, _tjär,
   {{0x6d4300e3,0x60c458e8,0x2ca658e9,0x7d0e01fa}},	//   ánac, liim, skod_, _tubs,
   {{0xde030562,0x6f0f008f,0x6d4502ad,0x26de58ea}},	//   _апри, _zucc, crha, voto_,
   {{0x68e9005f,0x88bc030b,0xa77423a3,0x3f8201d9}},	//   gled, _hvěz, елич, _krku_,
   {{0x26de068d,0xb8f60285,0x69be0285,0x964600c6}},	//   toto_, _सद_, _वेरी, мэнд,
   {{0x60cd134c,0x60c40188,0x26cc58eb,0x24890036}},	//   znam, hiim, undo_, _snam_,
   {{0x68e958ec,0x26de58ed,0x60c458ee,0x60cd58ef}},	//   bled, roto_, kiim, ynam,
   {{0xb4d9000f,0x26de4621,0x7ea00212,0x3f82003e}},	//   ़के_, soto_, _köps, _orku_,
   {{0x80c10e28,0x26de58f0,0x25080018,0x27e658f1}},	//   रोफे, poto_, _کرتی_, _uyon_,
   {{0x45d43ae7,0x26de0188,0x68e0039f,0x60cd02cb}},	//   _полс, qoto_, lomd, wnam,
   {{0x31c458f2,0x6f0f29b0,0x60cd58f3,0x7c2d003e}},	//   вств, _succ, tnam, ðark,
   {{0x248958f4,0x60cd58f5,0x60c4044c,0x00000000}},	//   _unam_, unam, giim, --,
   {{0xa3c205cd,0x2bde17d3,0x2ef500e5,0xfbde58f6}},	// [5090] ्पण_, _फुला, езар, _फुलम,
   {{0x60cd58f7,0x291e3a30,0x3d17009e,0xf09f0023}},	//   snam, _otta_, _aħwa_, _giàn_,
   {{0x40350467,0x68e958f8,0x60cd01d0,0x6915003d}},	//   _пенс, yled, pnam, _aġen,
   {{0x3f820580,0x6f0f0036,0x20c501d3,0xb4bd10e9}},	//   _frku_, _tucc, rķis_, _इगो_,
   {{0x291e56ca,0x6ef80174,0x68e958f9,0x38b10139}},	//   _atta_, ụbar, vled, _járe_,
   {{0xef1f026a,0xfaa700a9,0x68e91b68,0xa3c209c3}},	//   _itü_, ьшен, wled, ्पत_,
   {{0x68e958fa,0x00000000,0x00000000,0x00000000}},	//   tled, --, --, --,
   {{0xd7ca0034,0x7aea084e,0x2b4601b9,0x00000000}},	//   ापंच, alft, broc_, --,
   {{0x68e9000b,0x68fb58fb,0x291e58fc,0x2b46483a}},	//   rled, rmud, _etta_, croc_,
   {{0x7d0958fd,0xef1f00bc,0x19951782,0x38ba00e8}},	//   _hies, _mtü_, _пазя, dūru_,
   {{0x7d0958fe,0x35a558ff,0x7ea05900,0xe4c61bec}},	//   _kies, ханг, _köpr, ейни,
   {{0x7c2d003e,0x00000000,0x00000000,0x00000000}},	//   ðarh, --, --, --,
   {{0x7d095901,0x386d5902,0x850b046e,0x60c413e1}},	//   _mies, meer_, _संकट_, viim,
   {{0x386d01a2,0x78a95903,0xd6d90034,0x479a0266}},	//   leer_, lkev, tułu_, _מינס,
   {{0x60c45904,0xe1f10103,0x69dc0ac9,0x7afd0154}},	//   tiim, لسِ_, _øret, _èstu,
   {{0xef1a5905,0x7d095906,0x78a95907,0xf70800de}},	//   зма_, _nies, nkev, _rủi_,
   {{0x60c45908,0x64560193,0xff240068,0xf70800fe}},	// [50a0] riim, _icyi, ئبری, _sủi_,
   {{0x386d5909,0x60c4590a,0x7d09590b,0x443206e5}},	//   heer_, siim, _aies, _hey_,
   {{0x386d057a,0x443249c7,0x78a901df,0x6da3268e}},	//   keer_, _key_, kkev, лифа,
   {{0x26c5590c,0x7d091838,0x3f820e94,0x386d590d}},	//   hilo_, _cies, _trku_, jeer_,
   {{0x7d09590e,0x386d590f,0xaca30019,0x26c55910}},	//   _dies, deer_, _giọn, kilo_,
   {{0xc3330054,0x443214e2,0x2b460428,0x2b400117}},	//   רוג_, _ley_, rroc_, šico_,
   {{0x7d09058a,0x2bc00789,0x090600ae,0x629e00c2}},	//   _fies, _शेरा, нчим, _mopo,
   {{0x386d15b9,0xa3c2009d,0x7d095911,0x2b46044c}},	//   geer_, ्पा_, _gies, proc_,
   {{0x26c5013d,0x68e04350,0x3947211d,0xc6f85912}},	//   filo_, romd, arns_, мних_,
   {{0xc6f73dbc,0x629e3861,0x26c55913,0x443237c9}},	//   нных_, _nopo, gilo_, _aey_,
   {{0xceb309c1,0x386d0db8,0x2f16052f,0x44325914}},	//   רית_, beer_, _læg_, _bey_,
   {{0xb4cb0096,0x38ba01d3,0x78a95915,0x386d01cb}},	//   ळचे_, tūru_, ckev, ceer_,
   {{0xdcf50067,0x629e5916,0x7c2d003e,0x00000000}},	//   _urzą, _bopo, ðari, --,
   {{0xda1004a9,0x629e5917,0x44320188,0x69dc3229}},	//   ाशित_, _copo, _eey_, _øres,
   {{0x629e5918,0xd5af5919,0x4432591a,0x00000000}},	//   _dopo, _сс_, _fey_, --,
   {{0x4432013c,0x00000000,0x00000000,0x00000000}},	//   _gey_, --, --, --,
   {{0x7d09591b,0x8464013d,0xa923013f,0x8c3d026a}},	// [50b0] _ries, _съще, ąžin, _hoşg,
   {{0x752d00a5,0x59b000b7,0x386d1b05,0x00000000}},	//   _łazi, जनार, zeer_, --,
   {{0x7d09591c,0x753a04aa,0x443214a7,0x611c022b}},	//   _pies, nstz, _yey_, _pčle,
   {{0x38b10103,0xef1f00bc,0x7d0900bd,0x00000000}},	//   _márc_, _ttü_, _qies, --,
   {{0x7d09591d,0x386d04ee,0xa03600ca,0x7f4d0231}},	//   _vies, veer_, _בארה_, quaq,
   {{0x386d0305,0x7d09591e,0xf09f00de,0x23690063}},	//   weer_, _wies, _hoà_, _mpaj_,
   {{0x7d091861,0x26c515f4,0x386d0305,0x08d50927}},	//   _ties, vilo_, teer_, кция,
   {{0x7d09084e,0x00000000,0x00000000,0x00000000}},	//   _uies, --, --, --,
   {{0x386d591f,0x44325920,0x23690197,0x78a95921}},	//   reer_, _rey_, _npaj_, rkev,
   {{0x386d4021,0x78a95922,0xa6821e20,0x44325923}},	//   seer_, skev, альд, _sey_,
   {{0x26c55716,0x19ab1ad1,0x23690065,0x63210081}},	//   rilo_, _этап_, _apaj_, _বিষয়_,
   {{0x629e5924,0x7cea01cd,0x26c55925,0x25a55926}},	//   _sopo, týri, silo_, ryll_,
   {{0x629e5927,0x26c55928,0xcc3a00c1,0x69dc02b6}},	//   _popo, pilo_, וערט, _ører,
   {{0x7cf82df7,0x44320188,0xc7b90103,0x63a60407}},	//   míre, _wey_, mző_, rykn,
   {{0x20565929,0xc7b90018,0x91e605ed,0x6e370188}},	//   ктар, lző_, тове, daxb,
   {{0x20550e1b,0x7ae3592a,0xe3b200cd,0x64560169}},	//   лтур, hont, _نرخ_, _ucyi,
   {{0x629e592b,0xb226139c,0x6d43592c,0xb4de2172}},	// [50c0] _topo, _импл, ánan, तकी_,
   {{0x3f80592d,0xd0f4009d,0x7ae3592e,0x2f16592f}},	//   rviu_, _आठवण_, jont, _væg_,
   {{0x7ae35930,0xdb08003e,0x00000000,0x00000000}},	//   dont, _ólét, --, --,
   {{0x673b5931,0x8c460095,0x00000000,0x00000000}},	//   ksuj, теде, --, --,
   {{0x7ae35932,0xc3260033,0xdbcc0072,0x7cf802c6}},	//   font, _বিডি_, _póño, jíre,
   {{0x7ae35933,0x2ab00065,0x69150090,0x59f800ae}},	//   gont, _bàba_, _eġem, неля_,
   {{0xa967016c,0x987d013c,0x7e7c033c,0x00000000}},	//   вија_, _açıb_, _iarp, --,
   {{0x7e7c5934,0x7cf803be,0x987428ce,0xd90d001c}},	//   _harp, fíre, улиц, سیه_,
   {{0xb50c0e72,0xdca3020a,0x7ae3104a,0x00000000}},	//   _संजय_, _тати, bont, --,
   {{0xa3e604a9,0x7ae31b9e,0x41db0034,0x7c2d003e}},	//   _बुध_, cont, _मुझस, ðarv,
   {{0x2ab00065,0x6b82108c,0x00000000,0x00000000}},	//   _gàba_, lvog, --, --,
   {{0x249f0682,0x7e7c002b,0x7cf800b6,0x69da0634}},	//   ðum_, _larp, bíre, _ixte,
   {{0x6b82028d,0x6d5e5935,0x00000000,0x00000000}},	//   nvog, htpa, --, --,
   {{0x38660234,0x2d85007e,0x7e7c5936,0x63a002c3}},	//   _hbor_, _šlem_, _narp, ämna,
   {{0xb50c00c3,0x62340870,0xf1a429b6,0x201e020a}},	//   _संचय_, ресу, артн, _ştia_,
   {{0x38b13161,0x64550831,0x6b820357,0x55970327}},	//   _kára_, _свиђ, kvog, _ידוע_,
   {{0x44395937,0x7ae318e0,0x38660113,0xaca300fe}},	// [50d0] mas_, yont, _mbor_, _niền,
   {{0xa3c2143d,0x71795938,0x7e7c5939,0x6d433274}},	//   ्पर_, _збор_, _carp, ánao,
   {{0x7e7c02ad,0x38b10d79,0x7ae30311,0xf09f0023}},	//   _darp, _lára_, vont, _toà_,
   {{0x4439593a,0x442b593b,0x7ae3593c,0xac19067f}},	//   nas_, nbc_, wont, ходу_,
   {{0x4439593d,0x7ae3593e,0xe50408fa,0x7e7c0441}},	//   ias_, tont, रगति_, _farp,
   {{0x44393ace,0xddce0018,0xeb900182,0x63a03229}},	//   has_, _ebbő, تظم_, ømni,
   {{0x4439593f,0xceb200c1,0x2d9c0c08,0x67220065}},	//   kas_, _פיל_, øvet_, _atoj,
   {{0x44391dfc,0x7ae35940,0x6e355941,0x48d10081}},	//   jas_, sont, _hezb, াত্র,
   {{0xe50a00ef,0xa6e500ae,0x7ae35942,0xe45f00c2}},	//   _mặt_, лжил, pont, tiön_,
   {{0xc7b90018,0x1ab714e5,0x38b1026e,0x8cbf02d5}},	//   rző_, _अतिथ, _dára_, लोरो,
   {{0x64a60f2e,0x6722010a,0xe45f007b,0xc3260033}},	//   гана, _etoj, riön_, _বিধি_,
   {{0x44395943,0xb4de009d,0x38b15944,0x6e355945}},	//   gas_, तके_, _fára_, _lezb,
   {{0x889a0105,0xf7450832,0x387f5946,0x6aa15947}},	//   _רבני, _село, mdur_, _kolf,
   {{0x387f0102,0x38665948,0x6e355949,0x80c105e4}},	//   ldur_, _zbor_, _nezb, रोसे,
   {{0x4439594a,0xa06a594b,0x6d5e594c,0x76430167}},	//   bas_, нава_, xtpa, _idny,
   {{0x443908ec,0x387f594d,0x2d5c058a,0x039600e5}},	//   cas_, ndur_, víe_, _броя,
   {{0x6e352461,0xa4fb00a1,0x0e6611d9,0x4420594e}},	// [50e0] _bezb, _אלקט, лкан, _ifi_,
   {{0x387d0150,0x76430167,0x425600ae,0xe29a1102}},	//   _lawr_, _jdny, _стит, _чао_,
   {{0x6e3500d3,0x7e7c594f,0x6d5e2c97,0x00000000}},	//   _dezb, _varp, utpa, --,
   {{0x6d5e5950,0x6adc0285,0x387d0150,0xe50a00fe}},	//   rtpa, मक्र, _nawr_, _gặt_,
   {{0x7e7c0963,0xfaa65951,0x387f5952,0x44200d2a}},	//   _tarp, ладо, ddur_, _mfi_,
   {{0x44395953,0x6b825954,0x442001af,0x2d9c00f2}},	//   zas_, rvog, _lfi_, øves_,
   {{0x67225955,0x81e600c7,0x38b15956,0x44205957}},	//   _stoj, বের_, _sára_, _ofi_,
   {{0xb4de000d,0xa96700e3,0xfce60070,0x44200af0}},	//   तको_, اميم_, _собо, _nfi_,
   {{0x7d02166f,0xaefb01ec,0x387d01ee,0x629c01dc}},	//   mmos, _spùi, _dawr_, kjro,
   {{0x44395958,0x44205959,0x6444595a,0x76430167}},	//   was_, _afi_, _adii, _cdny,
   {{0xa92621a1,0x387d02ad,0x8b03030b,0x44203177}},	//   _сдел, _fawr_, ířen, _bfi_,
   {{0xd5b72f68,0x6aa1028d,0x764303a8,0x387d030a}},	//   усь_, _zolf, _edny, _gawr_,
   {{0x4439595b,0x6444083e,0x44200ac1,0x3fe3074c}},	//   ras_, _ddii, _dfi_, _कुंआ_,
   {{0x78a2595c,0x3ce6595d,0x8c3d0092,0x644406b0}},	//   _hoov, hoov_, _xoşb, _edii,
   {{0x2b400074,0xc6930089,0x442000f0,0x2d850428}},	//   šich_, _לאס_, _ffi_, _àlex_,
   {{0x443903e5,0x7d02374a,0x6d43595e,0x30a4001f}},	//   qas_, jmos, ánam, брув,
   {{0xe50a0028,0x611c0087,0x81e60033,0xa01b02c3}},	// [50f0] _vặt_, _včla, বেল_, _snös,
   {{0xd2510177,0x78a200aa,0x387f03e0,0x7cea01cd}},	//   _بند_, _loov, zdur_, kýrs,
   {{0x2d87595f,0x6e350542,0xdd1e0146,0xef1f01bf}},	//   íne_, _vezb, _píše, _grün_,
   {{0x611c0291,0x387f01d4,0x78a2010a,0x00000000}},	//   _učla, xdur_, _noov, --,
   {{0x2d9c038c,0x6aa10141,0x7988462c,0x00000000}},	//   øver_, _polf, _ardw, --,
   {{0x7d025960,0x69255961,0x8c3d078e,0x00000000}},	//   amos, амка, _boşc, --,
   {{0x7c2d003e,0x59df007a,0x9ed80859,0x48b53c75}},	//   ðars, _पुखर, _смрт_, ищит,
   {{0x6aa15962,0x52d2262c,0xe7f00caf,0x18a5016d}},	//   _wolf, _सद्स, _चरखा_, раим,
   {{0x44205963,0x387f5964,0x79882ead,0x752414f3}},	//   _rfi_, rdur_, _erdw, _čiza,
   {{0xb05b0149,0x6b895965,0x44205966,0x46f51009}},	//   _smäl, _ireg, _sfi_, јчит,
   {{0x99620146,0xd999071c,0x5fc70285,0x32cc0032}},	//   píše_, _جنات_, _रेसल, _lóyè_,
   {{0x3858177a,0x6b895967,0xdddc00e8,0x00000000}},	//   _مشهد_, _kreg, _sarū, --,
   {{0x76430167,0x290f0188,0xdead01c2,0xdddc0144}},	//   _tdny, _iiga_, ssaƙ, _parū,
   {{0x7643052f,0x290f00f9,0x23270231,0x6d4b007f}},	//   _udny, _higa_, рори_, ągaj,
   {{0xe297031e,0x7d021d82,0x67295968,0x00000000}},	//   шар_, ymos, lpej, --,
   {{0x290f506a,0xdd2f030b,0x3ce6022e,0x7f4d5969}},	//   _jiga_, _běžn, xoov_, fraq,
   {{0x1fa7266a,0x3ea30090,0xaec6596a,0x00000000}},	// [5100] акти_, _bojt_, абал, --,
   {{0x27f20120,0x00000000,0x00000000,0x00000000}},	//   _øyne_, --, --, --,
   {{0x248001fa,0x6b89596b,0x7d02596c,0x290f034f}},	//   _kaim_, _areg, tmos, _oiga_,
   {{0xb4c43b30,0x6b89596d,0x2480005c,0x1b1d0081}},	//   _एगो_, _breg, _jaim_, _নিজে_,
   {{0x6b89596e,0x2480022e,0x7d020133,0x1be7085f}},	//   _creg, _maim_, rmos, адци_,
   {{0x78a20006,0x3ce60197,0x2480022e,0x7d02596f}},	//   _soov, soov_, _laim_, smos,
   {{0x6b8902a4,0x290f5970,0x9d4300d3,0x224501cd}},	//   _ereg, _biga_, _мерд, ólki_,
   {{0x7afd00d9,0x7cf8030b,0x24805971,0x290f0218}},	//   _īste, bíra, _naim_, _ciga_,
   {{0x290f5972,0x7c2d5973,0x6b895974,0x23ad0065}},	//   _diga_, ñare, _greg, _mójú_,
   {{0x290f23ff,0x4aaa04f1,0x27ef0212,0x1b1d0033}},	//   _eiga_, _कविव, _dygn_, _নিচে_,
   {{0x290f26ae,0x24800ece,0x78a200bc,0x592401f3}},	//   _figa_, _baim_, _toov, _اکتف,
   {{0x290f026e,0x24800231,0x8c3d0233,0xe7860e2c}},	//   _giga_, _caim_, _koşa, _вуко,
   {{0x248001bb,0xe8d700a1,0x60d65975,0x00000000}},	//   _daim_, _דואר_, dnym, --,
   {{0x290f0294,0x1757006e,0xddc70090,0x00000000}},	//   _ziga_, _כסדר_, _pajż, --,
   {{0x6ac413b8,0x4de6009d,0x290f5976,0x23ad0af0}},	//   _वगैर, _जुलै_, _yiga_, _bójú_,
   {{0x2d850072,0x290f008c,0x248001ff,0x7f4d00fc}},	//   _álei_, _xiga_, _gaim_, traq,
   {{0x23ad0065,0x7eb200f3,0x00000000,0x00000000}},	// [5110] _dójú_, _væpn, --, --,
   {{0x26cc2c90,0x6b8901e5,0x7f4d015e,0x9f6600de}},	//   nido_, _rreg, rraq, _đuôi_,
   {{0xafdb0430,0x6b8900d1,0xb7bd044c,0x88bc00d2}},	//   _idøm, _sreg, rbţi, _rtěn,
   {{0x40950080,0x8c3d0511,0x248001fa,0x88bc00b6}},	//   _الحر, _boşa, _xaim_, _stěn,
   {{0x26cc5977,0x290f5978,0x2d8a5979,0x7cf10e3e}},	//   kido_, _riga_, _erbe_, nåri,
   {{0x60cd597a,0x290f0145,0x26cc597b,0xe50a0023}},	//   liam, _siga_, jido_, _lặp_,
   {{0x26cc0b0b,0x290f597c,0x27230220,0xd9990281}},	//   dido_, _piga_, kčný_, انعت_,
   {{0x60cd597d,0x6b8901e5,0x3949597e,0x52a40179}},	//   niam, _treg, čas_, _ऐक्स,
   {{0x6b89597f,0x290f00aa,0x26cc5980,0x248001b9}},	//   _ureg, _viga_, fido_, _raim_,
   {{0x26cc237a,0x60cd00e5,0x67292d34,0x60d6152e}},	//   gido_, hiam, rpej, znym,
   {{0x290f10e3,0x60cd01b3,0x3cff006c,0x2480023e}},	//   _tiga_, kiam, _khuv_, _paim_,
   {{0xe50a0019,0x2480023e,0x60cd0239,0x6729007b}},	//   _cặp_, _qaim_, jiam, ppej,
   {{0x26cc22a4,0x60cd14fb,0x24805981,0x68e95982}},	//   bido_, diam, _vaim_, moed,
   {{0x26cc132d,0x26c718c4,0x68e90150,0x27230031}},	//   cido_, _umno_, loed, ačný_,
   {{0x60cd5983,0x248011c8,0x60d65984,0x00000000}},	//   fiam, _taim_, tnym, --,
   {{0xe50a0028,0x60cd5985,0x672d03e5,0xb9200032}},	//   _gặp_, giam, _ħajj, _aarọ_,
   {{0x2d8a1100,0xddd50087,0x44220231,0xc879044c}},	// [5120] _srbe_, _razš, mck_, goşi_,
   {{0x68e902e0,0xee370a18,0x44224ee8,0x1eaa0452}},	//   hoed, йну_, lck_, داري_,
   {{0x60cd013d,0xc27b00c1,0x4d4a0f50,0x3ce40557}},	//   biam, _גריי, упен_, टकले_,
   {{0x26cc001f,0x7d1b0087,0x20560284,0xaefb009c}},	//   zido_, _čust, _утор, _spùt,
   {{0x44270253,0x68e902ad,0x442201c2,0x09b00c38}},	//   _ən_, doed, ick_, जन्य,
   {{0x26cc0933,0xd37b00ca,0x64a50285,0x00000000}},	//   xido_, טרנט, _ऑक्श, --,
   {{0x26cc3884,0xae072918,0x68e900f0,0x2d8a5986}},	//   vido_, वेदन_, foed, _urbe_,
   {{0xa3b8277c,0x68e95987,0x6cd60dce,0x26cc2977}},	//   चना_, goed, _اقرا, wido_,
   {{0x26cc0b0b,0xf09f0019,0x2fc05530,0x290401c2}},	//   tido_, _giàu_, nzig_, rmma_,
   {{0x60cd5988,0x6e3e5989,0x4422281c,0x2fc004aa}},	//   ziam, napb, eck_, izig_,
   {{0x26cc0b0b,0x7cf8598a,0xa5f806ea,0x7c220036}},	//   rido_, níro, рену_, ocor,
   {{0x7c22598b,0x7aea2387,0x6d4300e3,0x2b400a9e}},	//   ncor, loft, ánai, šicu_,
   {{0x26cc0145,0x60cd598c,0x9403018b,0x2fc001c0}},	//   pido_, viam, रेंच_, jzig_,
   {{0x2b440072,0x60cd0034,0x7cf1032e,0x00000000}},	//   _mvmc_, wiam, råri, --,
   {{0x60cd598d,0x7cf800d4,0x00000000,0x00000000}},	//   tiam, vírn, --, --,
   {{0x7cf8381f,0xc879044c,0x7aea01cb,0x00000000}},	//   díro, toşi_, hoft, --,
   {{0x60cd0f6a,0x2aab01c5,0x40340084,0x7eb2003e}},	// [5130] riam, _købt_, яетс, _tæpl,
   {{0x765a013f,0x60cd598e,0x443b0052,0x4255015a}},	//   ngty, siam, _heq_, _بندر,
   {{0x443b00dd,0x3cff40d4,0x257a00d9,0x09ad0081}},	//   _keq_, _phuv_, _jūl_, _কেনা,
   {{0xaca30019,0x61fa3ad7,0x7c2200b3,0x00000000}},	//   _miện, ütle, gcor, --,
   {{0xeb990318,0x68e90305,0xfaa5598f,0xfd10097d}},	//   рил_, voed, жало, رجم_,
   {{0x7c225990,0x7cf85991,0x93fc006e,0x2d871d21}},	//   acor, bíro, אלדי, ånes_,
   {{0x44220222,0x3cff01fa,0xaa560831,0x7cf85992}},	//   yck_, _thuv_, цију_, círo,
   {{0x7c225993,0x81e60081,0x81fb0033,0x765a0f5a}},	//   ccor, বেক_, _আলাপ_, egty,
   {{0x68e90150,0x78bb1531,0x8882001c,0xcb3400e5}},	//   roed, rhuv, بینن, _нетъ,
   {{0x7c3b5994,0x78bb5995,0x68e94494,0xf09f0441}},	//   _heur, shuv, soed, _fhàg_,
   {{0x7c3b5996,0xa2af030b,0x21260220,0x68e91570}},	//   _keur, ुसन्, _čoho_, poed,
   {{0x44225997,0x443b009c,0x63210033,0x7c3b0239}},	//   uck_, _ceq_, _বিজয়_, _jeur,
   {{0x7c3b5998,0xe7392887,0x7cf80103,0x43fa04a1}},	//   _meur, _тел_, zíro, рхня_,
   {{0x7c3b04ea,0x00000000,0x00000000,0x00000000}},	//   _leur, --, --, --,
   {{0x64a65999,0x7cf8002b,0xa3e60096,0x611c05aa}},	//   _мака, xíro, _बँक_, _tčlm,
   {{0x7c3b599a,0x7c2203be,0x2fc00364,0x6e3e0167}},	//   _neur, xcor, tzig_, wapb,
   {{0xee3a04e6,0x65bf0139,0x611c05aa,0x26050961}},	// [5140] ина_, _fáhé, _kčlk, हेरी_,
   {{0x7c220381,0x7cf85991,0x61e9020a,0x2fc0042c}},	//   wcor, tíro, şela, rzig_,
   {{0x7c3b599b,0x6e3e599c,0xa0a60aa8,0xb8860072}},	//   _beur, rapb, _данд, ntíñ,
   {{0x61fe57a1,0x7c3b599d,0x2fc0599e,0x7afd01d3}},	//   _izpl, _ceur, pzig_, _īsta,
   {{0x7c22599f,0x7c3b59a0,0x752404a3,0x7aea0ac1}},	//   rcor, _deur, _čizm, toft,
   {{0x7c225189,0x7cf82299,0x6d5703be,0x3a250154}},	//   scor, píro, buxa, _cflp_,
   {{0x7c3b1e03,0x7aea59a1,0x6e3c020a,0x00000000}},	//   _feur, roft, _ierb, --,
   {{0x6e3c59a2,0xbebb00dd,0x7c3b59a3,0x00000000}},	//   _herb, _atëh, _geur, --,
   {{0xd6da0020,0xd7fa3006,0x7d1c59a4,0x36d42887}},	//   ито_, шук_, _hurs, зопр,
   {{0x7c3b59a5,0x6e3c0234,0x7aea023b,0x998759a6}},	//   _zeur, _jerb, qoft, ganų_,
   {{0x6915033a,0x6e3c59a7,0x611c0154,0x443b0850}},	//   _všec, _merb, _dčlk, _peq_,
   {{0xef1f0364,0x92da0081,0x7e770023,0x2ab0009c}},	//   _früh_, ়তো_, zexp, _sàbh_,
   {{0x7d1c59a8,0x7bc259a9,0x443b023b,0x6e3c05c2}},	//   _lurs, nzou, _veq_, _oerb,
   {{0xd6d900a5,0x6e3c59aa,0x7d1c451f,0xa3c20ff9}},	//   kuły_, _nerb, _ours, ्पज_,
   {{0x27200023,0x7d1c59ab,0x8c3d008b,0x30a72813}},	//   _hòn_, _nurs, _boşl, орав,
   {{0xa3e62231,0x27200383,0x92bd0081,0x6ab70c3c}},	//   _बुक_, _kòn_, েকে_, _अत्र,
   {{0x6e3c063f,0xb4e700c3,0x7c3b59ac,0x4adb02d5}},	// [5150] _berb, बकी_, _reur, _बदलव,
   {{0x7c3b02fd,0x272059ad,0x6e3c0150,0x7d1c59ae}},	//   _seur, _mòn_, _cerb, _burs,
   {{0x628500f9,0x6e3c59af,0x7c3b59b0,0x6fdd0592}},	//   _iaho, _derb, _peur, _यशवं,
   {{0x645d03ec,0x7d1c59b1,0x6aba59b2,0x317a00c1}},	//   ngsi, _durs, _altf, _פארד,
   {{0x628559b3,0x7c3b0990,0xe0df0139,0x6aa8030a}},	//   _kaho, _veur, _ijò_, _bodf,
   {{0x7d1c59b4,0x6e3c59b5,0x63a00149,0x3ce659b6}},	//   _furs, _gerb, ämni, čova_,
   {{0xf2d40130,0x628559b7,0x7c3b0868,0x69150090}},	//   ועס_, _maho, _teur, _aġer,
   {{0x6e3c02a7,0x6d4559b8,0x27200383,0x6f1d0364}},	//   _zerb, msha, _bòn_, _kusc,
   {{0x272000ef,0x6d450694,0x6e3c59b9,0x6f1d59ba}},	//   _còn_, lsha, _yerb, _jusc,
   {{0x6285000d,0x672604c8,0x6f1d59bb,0x869959bc}},	//   _naho, íkja, _musc, стит_,
   {{0x6d4559bd,0xbec301d3,0x6e25042c,0x998700c6}},	//   nsha, _ķīli, ichb, ranų_,
   {{0x7f440257,0xf2c900c1,0x62850270,0x6d4559be}},	//   ysiq, _גע_, _aaho, isha,
   {{0x628559bf,0x27200019,0x6d4559c0,0x7cf11842}},	//   _baho, _gòn_, hsha, lårs,
   {{0xe0df0065,0x6d4559c1,0x628551ec,0xc87959c2}},	//   _ajò_, ksha, _caho, leş_,
   {{0x628559c3,0x272006a3,0x764159c4,0xdddc00d3}},	//   _daho, _zòn_, maly, _marţ,
   {{0x6e3c59c5,0x6f1d22bf,0x6d4559c6,0xc879026a}},	//   _serb, _busc, dsha, neş_,
   {{0x6e3c4937,0x7d1c59c7,0x6f1d028d,0xef17438d}},	// [5160] _perb, _surs, _cusc, зму_,
   {{0x1fb502ec,0x6f1d0003,0x22650031,0x6d4559c8}},	//   єстр, _dusc, ľský_, fsha,
   {{0xc27b004f,0x6e3c27cd,0x7f440257,0x6aa859c9}},	//   _פרטי, _verb, ssiq, _rodf,
   {{0x6e3c02e2,0x13b00081,0x6285103b,0x6f1d59ca}},	//   _werb, _চেয়, _zaho, _fusc,
   {{0x6e3c1268,0x6aa808c5,0xfe700018,0x6f1d028d}},	//   _terb, _podf, _لگا_, _gusc,
   {{0x7d1c08a9,0x3f82025e,0x6d450188,0x764104c8}},	//   _turs, _isku_, bsha, jaly,
   {{0x6f1d01bf,0xfe550260,0x69dc59cb,0x764159cc}},	//   _zusc, _زینب_, _žreb, daly,
   {{0x4ddb00a1,0xc87900ae,0xc1730266,0x00000000}},	//   _החלו, geş_, גחה_, --,
   {{0x80c10d61,0xb76301b6,0xb6050117,0x00000000}},	//   रोटे, нтэй, _lušč, --,
   {{0x02ce0034,0x35b40457,0x764159cd,0x2ba909a1}},	//   होमभ, дбор, galy, कहरा,
   {{0x628559ce,0x69c30067,0xc87959cf,0x645a00c6}},	//   _raho, czne, beş_, ėtin,
   {{0x62853996,0x2eb900c3,0xbec301d3,0xdcfc0141}},	//   _saho, _इत्त, _ķīmi, _osrč,
   {{0x291e4194,0x764159d0,0x645d59d1,0x628559d2}},	//   _huta_, baly, rgsi, _paho,
   {{0x764a052f,0x6f1d59d3,0xb05b0364,0x88bc02c6}},	//   _udfy, _rusc, _kläg, _stěh,
   {{0x6f1d59d4,0x291e383f,0x628759d5,0x628559d6}},	//   _susc, _juta_, rdjo, _vaho,
   {{0x291e59d7,0x628559d8,0x557700c1,0x6f1d59d9}},	//   _muta_, _waho, _זעהן_, _pusc,
   {{0x442959da,0x291e59db,0x6d4559dc,0x6f1500e1}},	// [5170] _ifa_, _luta_, wsha, _pizc,
   {{0x6d450201,0x80c109c4,0x7cf802c6,0x6e250364}},	//   tsha, रोजे, bírk, uchb,
   {{0x6f15384e,0x3f820a00,0x6e250364,0x7c2d0610}},	//   _vizc, _esku_, rchb, ñaro,
   {{0x7bf90b1e,0x6e250364,0x6d4559dd,0xe45f0212}},	//   онер_, schb, rsha, ngö_,
   {{0x6d4559de,0x2d9c0149,0x68e4035d,0xdddc00ae}},	//   ssha, äver_, čidl, _parţ,
   {{0x28ca0fef,0x1ee70421,0x7cf159df,0x69c302db}},	//   ़ोसि, _روزی_, tårs, tzne,
   {{0xaca30134,0x764159e0,0x644d01b9,0x291e0044}},	//   _akụn, valy, _odai, _cuta_,
   {{0x291e0498,0x7cf1038c,0x442959e1,0xfc330e5a}},	//   _duta_, rårs, _nfa_, _سحر_,
   {{0x3eaa59e2,0xf70800de,0x69c33c90,0xc87959e3}},	//   _yobt_, _hủy_, szne, reş_,
   {{0x442959e4,0x644d59e5,0x291e59e6,0xb05b0206}},	//   _afa_, _adai, _futa_, _zmät,
   {{0xb05b0222,0xa50a3f1d,0xdddc522a,0x291e59e7}},	//   _kläd, жена_, _karš, _guta_,
   {{0x2d9108a9,0x764159e8,0x442924f9,0x7c2902a1}},	//   _mrze_, saly, _cfa_, _jfer,
   {{0xaca30019,0xdddc59e9,0x672b00d6,0x38b800fd}},	//   _chỉn, _marš, _utgj, _zéro_,
   {{0x442959ea,0x291e59eb,0x386d59ec,0xb605033b}},	//   _efa_, _yuta_, lfer_, _pušč,
   {{0x442959ed,0x77690c19,0x8c3d0233,0xa1870291}},	//   _ffa_, ltex, _coşk, мбра_,
   {{0xf1b803e5,0xdddc013f,0xc5f200ca,0x7c2d0487}},	//   ġġ_, _narš, _שדה_, ñarl,
   {{0x98a61a5d,0x4de60034,0x776959ee,0x2d85007e}},	// [5180] žiće_, _जुड़े_, ntex, _šlep_,
   {{0x2d910039,0xb6050138,0x44290a4b,0x7cf80437}},	//   _brze_, _tušč, _zfa_, pírk,
   {{0x329b00a1,0x201e00d3,0x6449003e,0xe29b00ca}},	//   _וביד, _ştiu_, ðeig, _ושיר,
   {{0x291e0e4d,0x2d9108a9,0x386d0126,0x4429037a}},	//   _ruta_, _drze_, jfer_, _xfa_,
   {{0x291e59ef,0x8c431e9e,0x7c2901ff,0x3f8200b7}},	//   _suta_, тече, _dfer, _usku_,
   {{0x291e00e9,0x7c290294,0x2bd2009d,0x776903a9}},	//   _puta_, _efer, _देणा, dtex,
   {{0x2d8c02a8,0x7c290150,0x386d0d4b,0xe2a7003e}},	//   _éde_, _ffer, ffer_, æðir_,
   {{0x52bb2674,0xb05b0149,0xdddc00d9,0x2c8600c6}},	//   _उत्स, _gläd, _garš, _būdų_,
   {{0x291e59f0,0x776959f1,0xc7c600c2,0x644d01b9}},	//   _wuta_, gtex, ьски, _rdai,
   {{0xc6f7055b,0x442901af,0x20020350,0x00000000}},	//   мных_, _sfa_, _mzki_, --,
   {{0x2bd259f2,0x442959f3,0x186a0396,0xafdb02b6}},	//   _देता, _pfa_, _мажи_, _udøv,
   {{0x7cf80076,0xb8930037,0x20020141,0x7f560216}},	//   fíri, _للمع, _ozki_, kryq,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98bc00c6,0x26ce039f,0x00000000,0x00000000}},	//   tuvė_, _umfo_, --, --,
   {{0x29060028,0x44290036,0x00000000,0x00000000}},	//   _khoa_, _tfa_, --, --,
   {{0xd7880019,0x2b4909ac,0x442959f4,0xaca30023}},	//   _kể_, šaci_, _ufa_, _thỉn,
   {{0x7c2953b3,0xa295325f,0x3320015e,0x22b80154}},	// [5190] _rfer, _запі, _guix_, _fٍk_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5a0149,0x7c2901bf,0x2489041c,0x386d59f5}},	//   _åtal, _pfer, _kaam_, yfer_,
   {{0x77690113,0x6fd00096,0xfc3000b9,0x68e20113}},	//   ytex, _ठेवू, لحه_, _njod,
   {{0x2258110a,0x248959f6,0xdddc59f7,0x776959f8}},	//   _عجیب_, _maam_, _varš, xtex,
   {{0x2489023e,0x68e20032,0x290601c8,0x8a0500ae}},	//   _laam_, _ajod, _ahoa_, нзле,
   {{0xdddc00c6,0x7c2902a1,0x00000000,0x00000000}},	//   _tarš, _tfer, --, --,
   {{0x24891d19,0x6915025b,0x26de59f9,0x776912d2}},	//   _naam_, _všeo, ento_, ttex,
   {{0x386d59fa,0x236901fa,0x78ab02ac,0x00000000}},	//   rfer_, _nqaj_, _vogv, --,
   {{0xd70602fd,0x386d59fb,0x2cad1f1e,0xfaa700c6}},	//   нные_, sfer_, _hoed_, _ўшан,
   {{0x776959fc,0x386d0364,0x41cf0285,0x2cbf59fd}},	//   stex, pfer_, _हेलस, _klud_,
   {{0x77690113,0x332000ee,0x38b14b00,0x2489026d}},	//   ptex, _puix_, _páru_, _caam_,
   {{0x2cad1044,0x68fb026a,0x248959fe,0x00000000}},	//   _moed_, mlud, _daam_, --,
   {{0x290d59ff,0x68fb5a00,0xc7d6021e,0x00000000}},	//   lmea_, llud, _אוני_, --,
   {{0xf65200f5,0x91e3079c,0x11d500d6,0x3d1800aa}},	//   _עצה_, горе, вітр, _बूझे_,
   {{0x7cf80b0b,0xb05b0149,0x8fa601b6,0x3ce9007f}},	//   píri, _smär, набе, टकों_,
   {{0x64465a01,0x48fa006e,0xaf065a02,0x00000000}},	// [51a0] maki, פּלא, епал, --,
   {{0x64465a03,0x21210063,0x611c0154,0x2cbf037a}},	//   laki, _fuhh_, _bčlt, _alud_,
   {{0x68fb3813,0x2cbf00e7,0x248901fa,0xd00f0018}},	//   klud, _blud_, _yaam_, للہ_,
   {{0x8fa65a04,0x64465a05,0x2cad00f0,0x5c0606c4}},	//   _заме, naki, _coed_, няла,
   {{0x69150094,0x2cad030a,0xf09f020b,0xfbd200d1}},	//   _všel, _doed_, _khàn_, دتا_,
   {{0x64465a06,0x60c45a07,0xd7880023,0x62980103}},	//   haki, lhim, _rể_, _óvod,
   {{0x64465a08,0x2d9e00c4,0xff0700ae,0x60c40131}},	//   kaki, _štef_, _черк_, ohim,
   {{0x2cad13f4,0x7e7e5a09,0x7d030371,0x97a608f9}},	//   _goed_, lepp, ïnst, ерол,
   {{0x6d5e5a0a,0x64465a0b,0x24895a0c,0x60c45a0d}},	//   lupa, daki, _raam_, ihim,
   {{0x24890665,0x26de00e5,0x8c3d00d3,0xa49b0428}},	//   _saam_, unto_, _roşi, ològ,
   {{0xd5b70f80,0x68fb04a3,0x49ba0018,0x64465a0e}},	//   еся_, blud, _عائد_, faki,
   {{0x68fb0054,0x64465a0f,0x7e7e5a10,0x94d50a99}},	//   clud, gaki, hepp, томц,
   {{0x60c45a11,0x5ef50bba,0x7e7e003e,0xf09f01f7}},	//   dhim, ्तम्_, kepp, _bhàn_,
   {{0x8caa0336,0x179b2252,0x00000000,0x00000000}},	//   _झकझो, _מידב, --, --,
   {{0x64465a12,0xf09f01ec,0x31c4455b,0x6d5e15cd}},	//   baki, _dhàn_, гств, jupa,
   {{0x6d5e06ee,0xb5fb00f5,0x60c41098,0xd5fb0327}},	//   dupa, _מלוכ, ghim, _מפור,
   {{0xf1b900d9,0x44395a13,0xb4dd0096,0x442b020b}},	// [51b0] ņš_, mbs_, णची_, mcc_,
   {{0xdd950084,0x2121005c,0xb05b0149,0xaca300de}},	//   казы, _tuhh_, _bläc, _thịn,
   {{0xe2a70088,0x60c4063d,0x2cad00bc,0x672200ce}},	//   æður_, bhim, _poed_, _luoj,
   {{0x2bd21792,0xec1500bf,0xc5f3006e,0xa1360142}},	//   _देहा, نواد, אדע_, _שארק_,
   {{0x68fb5a14,0x2cad0313,0xbc18004d,0x6b82010a}},	//   vlud, _voed_, ніші_, gwog,
   {{0x6d5e5a15,0x64465a16,0xeb96075f,0xb05b1683}},	//   bupa, zaki, тиш_, _fläc,
   {{0x64465a17,0x6d5e0dfc,0x7ae40072,0x6b82010a}},	//   yaki, cupa, éita, awog,
   {{0xa3c10454,0x2bd20693,0x29190149,0x69230995}},	//   ंना_, _देवा, ösa_, _uđem,
   {{0x64465a18,0xb0c90789,0x5b155a19,0x290d5a1a}},	//   vaki, _रतनग, _амат, rmea_,
   {{0x64465a1b,0x68fb5a1c,0x7d1b5a1d,0x60c4023b}},	//   waki, slud, _hius, zhim,
   {{0x64465a1e,0x7d1b5a1f,0xf09f0023,0x68fb00e4}},	//   taki, _kius, _nhào_, plud,
   {{0x893400e3,0x60c40052,0x0446007b,0x38660503}},	//   _إعلا, xhim, ъемн, _gcor_,
   {{0x7d090010,0x387f5a20,0x78a95a21,0xf09f00fe}},	//   _mhes, meur_, mjev, _phàn_,
   {{0x387f5a22,0x64465a23,0x480402ec,0x6d5e2a0b}},	//   leur_, saki, _спів, yupa,
   {{0x44395a24,0x64465a25,0x60c45a26,0xf09f0019}},	//   bbs_, paki, thim, _chào_,
   {{0x78a903f1,0x8c3d01e8,0x387f5a27,0x76435a28}},	//   njev, _koşu, neur_, _heny,
   {{0x76435a29,0x44200d79,0x2fc95a2a,0x60c41a47}},	// [51c0] _keny, _igi_, gzag_, rhim,
   {{0x60c45a2b,0x6d5e3e2c,0x06e30081,0x75234c4e}},	//   shim, tupa, _নীতি, _kunz,
   {{0x764339a0,0x2b4d1729,0x78bb03cf,0x629e5a2c}},	//   _meny, _avec_, kkuv, _inpo,
   {{0x6d5e03b4,0x76435a2d,0x7e7e5a2e,0x75235a2f}},	//   rupa, _leny, sepp, _munz,
   {{0x2bd2009d,0x7d1b39a0,0x6d5e5a30,0xfbd20d88}},	//   _देशा, _dius, supa, _देशम,
   {{0x628e5a31,0x44200808,0x38665a32,0xc8820092}},	//   ndbo, _lgi_, _scor_, mişə_,
   {{0xada323d0,0x67220084,0x6df600e3,0x752318ba}},	//   _карл, _suoj, _شكرا, _nunz,
   {{0x7d1b0465,0x78a900f3,0x44205a33,0x387f5a34}},	//   _gius, gjev, _ngi_, geur_,
   {{0x76435a35,0xaca30028,0x6f1c5a36,0x8c3d00ae}},	//   _beny, _giốn, _kirc, _coşu,
   {{0x75235a37,0x6f1c02a1,0x61230294,0x76435a38}},	//   _bunz, _jirc, ọlit, _ceny,
   {{0x76435a39,0xceb30105,0xb8e800c7,0x387f0185}},	//   _deny, ייז_, _ঈদ_, beur_,
   {{0xb865001c,0x387f00fd,0x629e05aa,0x6444009c}},	//   _ماهو, ceur_, _anpo, _ceii,
   {{0x44395a3a,0x317a5a3b,0x7643299f,0x44205a3c}},	//   rbs_, _appz_, _feny, _dgi_,
   {{0x75235a3d,0x764314b1,0x26c50220,0x44205a3e}},	//   _funz, _geny, chlo_, _egi_,
   {{0x34950b9e,0x76485a3f,0x442b5a40,0x550700ae}},	//   _байр, mady, pcc_, _ичиа,
   {{0x764352cd,0x629e02f1,0x764802cb,0x442006b0}},	//   _zeny, _enpo, lady, _ggi_,
   {{0x7d1b013d,0x76431fde,0x7d0902ad,0x752302a4}},	// [51d0] _rius, _yeny, _rhes, _zunz,
   {{0xfe701823,0x6f1c29b0,0x76485a41,0x539a00a1}},	//   قدم_, _circ, nady, _ניתו,
   {{0x387f0257,0x6f1c5a42,0x7d1b3067,0x5dd50076}},	//   yeur_, _dirc, _pius, دقائ,
   {{0x8c3d00ae,0xaf37001c,0x387f014b,0x6f1c5a43}},	//   _noşt, _لرست, xeur_, _eirc,
   {{0x387f39a4,0x7d1b5a44,0x76480270,0x6d4e5a45}},	//   veur_, _vius, kady, _evba,
   {{0x6d582347,0x69150138,0xf09f009c,0xda651ac8}},	//   ávac, _išei, _mhàm_, увки,
   {{0x387f5a46,0x7d090054,0x78a9023b,0x80ba009d}},	//   teur_, _thes, tjev, _एकमे,
   {{0x7523010a,0x88bc02c6,0x7d09102f,0x00000000}},	//   _runz, _stěr, _uhes, --,
   {{0x76430496,0x78a95a47,0x387f5a48,0x8c3d0092}},	//   _peny, rjev, reur_, _qoşu,
   {{0xb7bd002d,0x387f5a49,0x6b895a4a,0xceb40092}},	//   ncţi, seur_, _iseg, qqət_,
   {{0x04462d7b,0x78a9053f,0x387f00fd,0x211f0096}},	//   ленн, pjev, peur_, _मंगळ_,
   {{0x76435a4b,0x3f4f0029,0xc79506cf,0xf77101c3}},	//   _weny, kļu_, _مشتب, _هات_,
   {{0x765c0067,0xe91800d6,0x7e9b00d9,0x76485a4c}},	//   óryc, _році_, _kāpē, bady,
   {{0x291d0d1f,0xf09f00ee,0x7eb202b6,0x64440063}},	//   _hiwa_, _anà_, _næpp, _weii,
   {{0x27295a4d,0x291d5a4e,0x7ae35a4f,0x6729023b}},	//   _hún_, _kiwa_, innt, lqej,
   {{0x291d1084,0x2729026e,0x44200979,0x65615a50}},	//   _jiwa_, _kún_, _ugi_, mulh,
   {{0x27294028,0x3f4f00d9,0x6f1c01d3,0x691502c6}},	// [51e0] _jún_, gļu_, _pirc, _všeh,
   {{0x6da603fc,0x629e027e,0x27295a51,0x291d1b99}},	//   лиза, _unpo, _mún_, _liwa_,
   {{0x6b895a52,0x27295a53,0x2d96004b,0x7f4d01ee}},	//   _aseg, _lún_, ырас, asaq,
   {{0x5fd5009d,0x9b6a2249,0x1b4a08c3,0x7d031044}},	//   _ठेवल, ешка_, езди_, ïnsp,
   {{0x2d87052f,0xb05b3a40,0x65615a54,0xc882013c}},	//   æner_, _klän, hulh, qişə_,
   {{0x61fe0e91,0x69ca5a55,0x00000000,0x00000000}},	//   _kypl, tzfe, --, --,
   {{0x272914e2,0x6b895a56,0x80b80557,0xa9671fdb}},	//   _aún_, _eseg, _इकाइ, гија_,
   {{0x37e80081,0x7ae3152f,0x291d0022,0x27295a51}},	//   _পরবর, annt, _ciwa_, _bún_,
   {{0x291d5a57,0xd90d00cd,0x764807ac,0x8881001c}},	//   _diwa_, ذیه_, tady, زیون,
   {{0x27291739,0x557405ed,0x00000000,0x00000000}},	//   _dún_, агот, --, --,
   {{0x76485a58,0x65610161,0xdef7006e,0x00000000}},	//   rady, gulh, רמיט_, --,
   {{0x272902b4,0x76482839,0x291d5a59,0x26d900fd}},	//   _fún_, sady, _giwa_, ésor_,
   {{0xaab8007d,0xf09f0019,0x9cd700ca,0x27290af0}},	//   _अवाक, _giày_, רוכה_, _gún_,
   {{0x248d0954,0x291d0051,0x2d8a023b,0x65944444}},	//   žem_, _ziwa_, _osbe_, _ваку,
   {{0x291d006d,0x6234004d,0x61fe00eb,0x2bdb0285}},	//   _yiwa_, сесу, _cypl, _मेना,
   {{0x54550f7e,0x95531d28,0x61fe007f,0xb05b16c7}},	//   _твит, _اخوا, _dypl, _elän,
   {{0x1ee700cd,0x2d985a5a,0x272900fe,0x00000000}},	// [51f0] هوری_, _arre_, _xún_, --,
   {{0xaca300de,0xb05b2104,0x7f4d0abd,0x00000000}},	//   _phỏn, _glän, rsaq, --,
   {{0x7f4d00bd,0x6b895a5b,0x61fe030a,0x9e075a5c}},	//   ssaq, _sseg, _gypl, учал,
   {{0x200701d4,0x6fd0136b,0x7e9b00e8,0xb5051e05}},	//   ənin_, _सेकं, _sāpē, रतिय_,
   {{0x2d980068,0x90980ea0,0x7eb202b6,0x20c700aa}},	//   _erre_, _свят_, _tæpp, _võid_,
   {{0x27295a5d,0x291d3db2,0x6b890087,0x00000000}},	//   _rún_, _siwa_, _vseg, --,
   {{0x6115013f,0x27290af0,0x20c700bc,0x291d007f}},	//   _sąly, _sún_, _tõid_, _piwa_,
   {{0x6b895a5e,0x52d15a5f,0x00000000,0x00000000}},	//   _tseg, सफुस, --, --,
   {{0x6a6711a2,0x29030029,0x7e9b00d9,0xa8022ddc}},	//   _مطال, ēja_, _tāpē, _şırn,
   {{0x4905000f,0x81bb00c7,0x681b00d9,0x65615a60}},	//   _हीरो_, _আইন_, _rādī, tulh,
   {{0x64a600c6,0x27e0003e,0xdb1f00bc,0x81c300e8}},	//   аана, _þinn_, övõt, šēji,
   {{0x27290649,0x65615a61,0xb05b0149,0x9abd010a}},	//   _tún_, rulh, _slän, _kuŋo,
   {{0xf7455a62,0xb4e60065,0xb05b0364,0xa2a200b6}},	//   _тело, _alàá, _plän, खाल्,
   {{0x61fe5a63,0x65610231,0x00000000,0x00000000}},	//   _pypl, pulh, --, --,
   {{0x3f990d2a,0xa3e205cd,0x6146075f,0x00000000}},	//   _arsu_, _दशक_, реба, --,
   {{0x61fe18ed,0x92d600c7,0x91e300d6,0x00000000}},	//   _vypl, িকে_, іоте, --,
   {{0x44320085,0xb4e60139,0x00000000,0x00000000}},	// [5200] _ify_, _elàá, --, --,
   {{0xee375a64,0xb3bb021e,0x00000000,0x00000000}},	//   ину_, _סמיכ, --, --,
   {{0x72061ac9,0x0d86038f,0x5d6a00c2,0x71a60077}},	//   _خودم, рлен, тием_, _танз,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c3020a,0x9abc003d,0x92e80033,0x00000000}},	//   _înma, _liċe, বতী_, --,
   {{0xd9540308,0x27e00138,0xb05b00ce,0x00000000}},	//   منتخ, _žino_, _yläo, --,
   {{0x8c462972,0x27e000ae,0x2d9837d6,0x9abc00bd}},	//   _вебе, _ţin_, _urre_, _niċe,
   {{0xb4c509a1,0xf4c10081,0x7c2d034f,0x25f900c3}},	//   _एते_, _উদ্ব, ñart, _उड़ी_,
   {{0xc6a65a65,0x7d025a66,0xc6f80291,0xab2a1720}},	//   арни, mlos, лних_, _роза_,
   {{0x6d5e0d8d,0x59761402,0xdeb403e3,0xd6d4022a}},	//   orpa, _выду, _ƙaƙa, ёжны,
   {{0x7aed0257,0xd82f0012,0x95ca5a67,0x00000000}},	//   éate, _мэ_, тупа_, --,
   {{0x7d0202e2,0x9abc003d,0xf8da034c,0x66c40154}},	//   nlos, _diċe, _बगिय, _dòka,
   {{0x66e61f82,0x6d5e042c,0x3ce605db,0x00000000}},	//   _кода, hrpa, inov_, --,
   {{0x7d025a68,0x60c65a69,0x1dc61e05,0xa5d70504}},	//   hlos, _alkm, लनात, ابیر_,
   {{0x7d025a6a,0x2d850328,0x8546013f,0x691500d4}},	//   klos, _álex_, _тэле, _všev,
   {{0x30a40396,0x7d02015c,0x63a201d3,0x3f9900d2}},	//   орув, jlos, _šone, _prsu_,
   {{0x6d58135f,0x3ce6033b,0x98af0a39,0x6d5e0565}},	// [5210] ávan, dnov_, žaće_, erpa,
   {{0xc8791a4a,0x00000000,0x00000000,0x00000000}},	//   mişe_, --, --, --,
   {{0x63bd5a6b,0x20c705a7,0xe3b00260,0x518741c8}},	//   lysn, _võib_, _فری_, _тупа,
   {{0xb05b0212,0xf3ff016d,0x78a2037a,0x2d58002d}},	//   _kläm, ngão_, _nnov, риць_,
   {{0x307a00c1,0x69de0220,0x3f8b0a39,0x3f99020a}},	//   _גארנ, úpen, _uscu_, _ursu_,
   {{0x78a25a6c,0xe8e000fe,0x00000000,0x00000000}},	//   _anov, ướt_, --, --,
   {{0x6915025b,0x7c2d0610,0xfc67008f,0x7d025a6d}},	//   _ošet, ñars, _възн, blos,
   {{0x9abc03e5,0xb05b0212,0x7d020fe4,0x00000000}},	//   _riċe, _oläm, clos, --,
   {{0x3f8900f0,0xb9950504,0xf09f00fe,0x28a9049d}},	//   nwau_, _گلاب, _chài_, काबि,
   {{0x78a25a6e,0x6b9b5a6f,0x38b801cd,0xc879047e}},	//   _enov, _irug, _sért_, dişe_,
   {{0x8afa006e,0x00000000,0x00000000,0x00000000}},	//   _עפעק, --, --, --,
   {{0xf41f00c2,0xe7990867,0x39155a70,0x9abc0090}},	//   ydät_, _مختص_, _умер, _viċe,
   {{0xf09f01b9,0x00000000,0x00000000,0x00000000}},	//   _ghài_, --, --, --,
   {{0x78a2134c,0x216a0c3f,0x23275a71,0x7d021d4f}},	//   _znov, лиги_, сори_, zlos,
   {{0xb05b02fd,0x20560077,0x7d020036,0x3ce65a72}},	//   _eläm, йтар, ylos, ynov_,
   {{0x25710102,0x6b9b0143,0xb886002b,0x92e80033}},	//   mál_, _orug, muíñ, বতে_,
   {{0x543b00c1,0x8fa300c2,0x6b9b0174,0x4fa3008f}},	// [5220] _געפא, пате, _nrug, питв,
   {{0x39451342,0x528600e3,0x6d5e0995,0x2eb7274c}},	//   _owls_, _الدك, trpa, _आकृत,
   {{0x25712e16,0x7d021419,0x6b9b5a73,0x6d5e5a74}},	//   nál_, tlos, _arug, urpa,
   {{0x6b9b08dc,0xab2a4e4f,0x6d5e0324,0x00000000}},	//   _brug, года_, rrpa, --,
   {{0x7d025a75,0x2bd21fe6,0x6d43020a,0x3ce63e94}},	//   rlos, _देखा, ânar, rnov_,
   {{0x6b9b5a76,0x7d025a77,0x6da65a78,0x3ce6078e}},	//   _drug, slos, _лига, snov_,
   {{0x6b9b0294,0xed3501b6,0xf41f227a,0x00000000}},	//   _erug, _мэтэ, ndär_, --,
   {{0x6b9b052f,0x473440e5,0x25713171,0x9abc0090}},	//   _frug, онис, dál_, _biċc,
   {{0x6b9b5a79,0x78a2033b,0x3198022b,0x00000000}},	//   _grug, _vnov, _lčz_, --,
   {{0x8c3d03a3,0x7e7c0154,0xdd1c00d4,0x00000000}},	//   _inşa, _jbrp, nážn, --,
   {{0x7c2d2b73,0x39450090,0xf76f001c,0x2571446d}},	//   žare, _gwls_, وای_, gál_,
   {{0x78a20087,0x2419007b,0x63bd007b,0x00000000}},	//   _unov, ионы_, tysn, --,
   {{0x69152ba9,0x38cb015a,0x2efa2997,0x2f0f0364}},	//   _všet, _حالی_, kopf_, lüge_,
   {{0x77600abd,0x7ae400e3,0x2904054a,0xa49b00b3}},	//   mrmx, éith, llma_, clòn,
   {{0x26de5a7a,0x20020d30,0x225f026a,0x6d5810a8}},	//   mito_, _ayki_, ğuk_, ával,
   {{0x764a02e0,0x6915025b,0xdddc0b9c,0x00000000}},	//   _hefy, _ušet, _barž, --,
   {{0x29041d2d,0x6d580029,0x9ed92b36,0x63a916f4}},	// [5230] ilma_, šval, амат_, åend,
   {{0x6b9b01e5,0xdddc013f,0x59a8218b,0xfebb487a}},	//   _rrug, _darž, कमार, دارت_,
   {{0x21225a7b,0x62875a7c,0x60c300ae,0x764a0154}},	//   _fikh_, mejo, _înmo, _mefy,
   {{0xe9a900bf,0x6b9b005f,0xd5fb00c1,0x26de0036}},	//   یگان_, _prug, נפאר, hito_,
   {{0x60cd5a7d,0xfb85001c,0x76580094,0x4478021e}},	//   mham, تدای, _odvy, מעאל_,
   {{0x60cd5a7e,0x62875a7f,0x6b9b0185,0x26de5a80}},	//   lham, nejo, _vrug, jito_,
   {{0x26de5a81,0x00000000,0x00000000,0x00000000}},	//   dito_, --, --, --,
   {{0x60cd5a82,0x25710103,0x66c40154,0x6b9b5a83}},	//   nham, vál_, _bòko, _trug,
   {{0x6b9b023f,0x28d8000f,0x62875a84,0x26de436e}},	//   _urug, बोधि, kejo, fito_,
   {{0x673b5a85,0x290400f9,0x25712e16,0xb8860072}},	//   rpuj, alma_, tál_, tuíñ,
   {{0x34aa336f,0x60cd0201,0x80c90557,0x764a5a86}},	//   авно_, kham, रसाइ, _defy,
   {{0x644f481f,0x26cc0188,0x673b00c2,0x69150094}},	//   gaci, ahdo_, ppuj, _všes,
   {{0x26de5a87,0x98f40391,0x60cd32ea,0x232a2da1}},	//   bito_, _عثما, dham, роги_,
   {{0x26de5a88,0x68fb00c2,0xb05b0212,0x6295029a}},	//   cito_, loud, _fläk, gdzo,
   {{0x6915033b,0x2492235a,0xdd1c033d,0x90b60291}},	//   _ušes, _taym_, vážn, ољаш,
   {{0x644f3964,0x33660aad,0x60cd5a89,0x67235a8a}},	//   caci, _двиг, gham, _hinj,
   {{0x67235a8b,0x2f0f0364,0x62875a8c,0x254701f9}},	// [5240] _kinj, züge_, bejo, lől_,
   {{0x68fb203e,0xdddc013f,0x67235a8d,0xb05b00c2}},	//   houd, _varž, _jinj, _yläk,
   {{0xc27b0105,0x68fb0154,0x2d9c5a8e,0x527b0796}},	//   _דריי, koud, íve_, _דניא,
   {{0x60cd5a8f,0x67235a90,0xdd1c0146,0xfbdb1c05}},	//   cham, _linj, sážn, _मेहम,
   {{0x6d5500e7,0x26de05bd,0x60c4024a,0x68e95a91}},	//   _evza, yito_, mkim, dned,
   {{0x644f04d8,0x60c45a92,0x75243ba5,0x539b0142}},	//   zaci, lkim, _liiz, יסנא,
   {{0x7c2f04ad,0x644f5a93,0x3f820167,0x3eb801b9}},	//   _širš, yaci, _hpku_, _iort_,
   {{0x60c45a94,0x764a02ad,0x644f5a95,0x3eb805fe}},	//   nkim, _sefy, xaci, _hort_,
   {{0x3eb821ad,0x26de5a96,0x67235a97,0xb05b0149}},	//   _kort_, tito_, _binj, _släk,
   {{0x672304a3,0x644f006d,0xddde00d3,0x60c45a98}},	//   _cinj, waci, cepţ, hkim,
   {{0x644f0e4d,0x3eb85a99,0x672303e5,0x60c403cf}},	//   taci, _mort_, _dinj, kkim,
   {{0x26de5a9a,0x62950034,0x26cc0052,0x3eb802b6}},	//   sito_, wdzo, shdo_, _lort_,
   {{0x6d580074,0x26de5a9b,0x67230139,0x75245a9c}},	//   ávaj, pito_, _finj, _diiz,
   {{0x25470068,0x67232bb2,0xe572097d,0x68e05a9d}},	//   ből_, _ginj, _قطع_, limd,
   {{0x60cd5a9e,0x644f34d2,0x752406b0,0x26dc02a4}},	//   tham, paci, _fiiz, _imvo_,
   {{0x6287001f,0x65685a9f,0x68e05aa0,0x67235aa1}},	//   sejo, mudh, nimd, _zinj,
   {{0x3eb82fe7,0x44295aa2,0x60cd5aa3,0x62875aa4}},	// [5250] _bort_, _iga_, rham, pejo,
   {{0x60cd5aa5,0x3eb85aa6,0xdd9b5aa7,0x644d009c}},	//   sham, _cort_, ише_, _heai,
   {{0x3eb85aa8,0x68e902ad,0x60cd0060,0x644d061d}},	//   _dort_, yned, pham, _keai,
   {{0x44295aa9,0x6b800294,0x6ab8007f,0x644d033c}},	//   _jga_, _ịgag, _अवॉर, _jeai,
   {{0x442911eb,0x65685aaa,0xeb991011,0xd7d904f1}},	//   _mga_, hudh, сил_, _बेंच,
   {{0xda7b1c00,0x65685aab,0x68fb5aac,0x3eb82bc0}},	//   ряд_, kudh, woud, _gort_,
   {{0xceb207a6,0x67235aad,0x672b023b,0x2d5800ae}},	//   _אים_, _rinj, _sugj, _мирь_,
   {{0x44295aae,0x67235aaf,0xa3cb0e4c,0x66035ab0}},	//   _nga_, _sinj, लना_, _rynk,
   {{0x764102ad,0x67235ab1,0x66035ab2,0x66e50423}},	//   tbly, _pinj, _synk, зопа,
   {{0x44295ab3,0x25470018,0xddde134c,0x68e92096}},	//   _aga_, től_, lepš, sned,
   {{0x442901af,0xb05b0084,0x76415ab4,0xe5a53340}},	//   _bga_, _eläi, rbly, чини,
   {{0x25470068,0x44295ab5,0x644d5ab6,0x81e90033}},	//   ről_, _cga_, _ceai, _বরং_,
   {{0x672318c4,0xfbbd12f2,0x7c2902a1,0x66030f5a}},	//   _tinj, ्निम, _mger, _wynk,
   {{0x4429415d,0x386d1a08,0xf67500c1,0x65685ab7}},	//   _ega_, lger_, _זײַט_, budh,
   {{0x2f141424,0x60c40084,0x44290072,0x505a0109}},	//   lägg_, tkim, _fga_, йшая_,
   {{0x386d038c,0xf99207a6,0x7c295ab8,0xddde0ea3}},	//   nger_, ערן_, _nger, jepš,
   {{0x60c45ab9,0x386d365f,0x3eb82198,0x61fb07e7}},	// [5260] rkim, iger_, _port_, ğula,
   {{0x7c295aba,0xd00f00e3,0x60c45abb,0x26c50138}},	//   _ager, الك_, skim, nklo_,
   {{0xf09f01ec,0x3eb80537,0x68e00555,0x60c45abc}},	//   _chàs_, _vort_, yimd, pkim,
   {{0x3eb801bf,0xf53600c1,0x386d5abd,0x00000000}},	//   _wort_, לטער_, jger_, --,
   {{0x3eb824f9,0x6e3b026a,0xb09b00ca,0x6606007f}},	//   _tort_, _şube, _היכר, ękki,
   {{0x386d5abe,0x65682f91,0x3eab003d,0x80d802d5}},	//   eger_, yudh, ċità_, नोरे,
   {{0x8c4623bf,0x24800542,0x68e0020e,0x7c2d031a}},	//   _неве, _obim_, timd, žara,
   {{0x386d0501,0x200f042c,0x00000000,0x00000000}},	//   gger_, ügig_, --, --,
   {{0x644d48f0,0x36d40221,0x7b090088,0x68e0008b}},	//   _reai, допр, ðstö, rimd,
   {{0x692a033a,0x68e05abf,0x4429026d,0x644d0076}},	//   _před, simd, _sga_, _seai,
   {{0xceb30054,0x59865ac0,0x6aa801c5,0x28a934fd}},	//   תית_, _хлеб, _indf, काशि,
   {{0x6aba5ac1,0xc9850037,0x65685ac2,0x00000000}},	//   _hotf, _تشكي, rudh, --,
   {{0x46a65ac3,0x7bc20085,0x28a90f62,0x65683600}},	//   _надв, nyou, कारि, sudh,
   {{0x442901af,0x9713097a,0x00000000,0x00000000}},	//   _wga_, _зміц, --, --,
   {{0x5184022a,0x27320023,0x867b00ca,0x692a00b6}},	//   нута, _hân_, _הרוו, _hřeb,
   {{0x44295ac4,0xd49800d3,0x116a00d1,0x00000000}},	//   _uga_, _ерь_, تلفی_, --,
   {{0xf09f01b9,0xbefa0285,0xfbdb00c3,0x00000000}},	// [5270] _bhàr_, ्तून_, _मेंम, --,
   {{0x200700e8,0x27325ac5,0xf09f01ec,0x6aba5ac6}},	//   āni_, _mân_, _chàr_, _notf,
   {{0x27325ac7,0x386d0973,0x5c7500c6,0x00000000}},	//   _lân_, yger_, длет, --,
   {{0x5fde0caf,0xd0100103,0x6aa80957,0x00000000}},	//   _नेवल, ئلے_, _andf, --,
   {{0x05de05a5,0x7aed00fd,0x62973787,0xe0df0032}},	//   _फेसब, éato, _kaxo, _imò_,
   {{0xf09f009c,0x2f1402c3,0x00000000,0x00000000}},	//   _ghàr_, vägg_, --, --,
   {{0x28a9030b,0x386d5ac8,0x2d830381,0x7c2902a1}},	//   कालि, tger_, _upje_, _tger,
   {{0x27325ac9,0x7c295aca,0x386d021f,0xb4bc007a}},	//   _bân_, _uger, uger_, _आके_,
   {{0x27325acb,0x386d40c3,0xcd020034,0x7d03020a}},	//   _cân_, rger_, _dość_, însu,
   {{0x273200ef,0x057500e3,0xd70600c2,0x79960034}},	//   _dân_, واجد, мные_, ływa,
   {{0x7ae31402,0x386d0212,0x00000000,0x00000000}},	//   mint, pger_, --, --,
   {{0x7ae35acc,0xcd0200a5,0xf2c90341,0x69c300f0}},	//   lint, _gość_, _דע_, myne,
   {{0x1e0a33dc,0x7e0a2674,0x7ae35acd,0x27325ace}},	//   _वर्ष_, _वर्ग_, oint, _gân_,
   {{0xe0df5acf,0x06930018,0xdb000231,0x6d5800c6}},	//   _amò_, _ساتھ, _armê, švai,
   {{0xb0c9277c,0xdb2600a7,0x629700fc,0xdb0b01f9}},	//   रसंग, şqçi, _daxo, lygó,
   {{0x7ae35ad0,0xf09f01ec,0x6297033c,0x00000000}},	//   hint, _shàr_, _eaxo, --,
   {{0x7ae35ad1,0xd007015f,0x3178007f,0x629700d8}},	// [5280] kint, дете_, strz_, _faxo,
   {{0x9d46244f,0x7ae35ad2,0xbefa0eeb,0x7bc2411d}},	//   дежд, jint, ्तेन_, vyou,
   {{0x7ae35ad3,0x6aba0e37,0x00000000,0x00000000}},	//   dint, _rotf, --, --,
   {{0x04040081,0x7c2d0128,0x69c35ad4,0x7c8300c2}},	//   রেণী_, žarn, dyne, вуше,
   {{0xe7e800c7,0x7ae35ad5,0x6d67013f,0x692a02c6}},	//   _পর্য, fint, _įraš, _ořec,
   {{0x7ae35ad6,0x6d5700a7,0x00000000,0x00000000}},	//   gint, bsxa, --, --,
   {{0x27320019,0x7bc2022b,0x6aba007e,0x00000000}},	//   _sân_, syou, _votf, --,
   {{0x7ae30441,0x692a00b6,0xcc870a3a,0xa3be00a4}},	//   aint, _přeb, _обсе_, _इथं_,
   {{0x692a02c6,0xb05b042c,0x00000000,0x00000000}},	//   _břec, _gläu, --, --,
   {{0x27320019,0xcaa60037,0x35b400e5,0x6aa84492}},	//   _vân_, _تصري, ебор, _undf,
   {{0x27e90102,0x62970960,0xb05b0212,0x7afd04c8}},	//   _þann_, _raxo, _klät, _ísta,
   {{0x692a000d,0x27325ad7,0x62975ad8,0x00000000}},	//   _třeb, _tân_, _saxo, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62970188,0x057604f4,0x20c700bc,0x00000000}},	//   _qaxo, _قاعد, _võim_, --,
   {{0xdb00023b,0x41e4224a,0x26ce0154,0x00000000}},	//   _armë, віта, _ilfo_, --,
   {{0x7ae35ad9,0x50645ada,0x62975adb,0x00000000}},	//   zint, ктуа, _waxo, --,
   {{0x7ae35adc,0x3cf2009f,0x13f4007b,0x00000000}},	// [5290] yint, ंचने_, _изъя, --,
   {{0x20c705a7,0x7ae3008a,0x66c4022b,0x44390103}},	//   _kõik_, xint, _bòki, lcs_,
   {{0x7ae35add,0x25780018,0xb05b0364,0x3d29001c}},	//   vint, nél_, _blät, ستای_,
   {{0x44395ade,0x7ae35adf,0x213e0037,0x69c35ae0}},	//   ncs_, wint, íthe_, vyne,
   {{0x7ae35ae1,0x60d609c1,0x44395ae2,0x69c300f0}},	//   tint, _נושא_, ics_, wyne,
   {{0xdb250018,0x69c35ae3,0x443900e7,0xe80200c3}},	//   _épül, tyne, hcs_, _लड़ा_,
   {{0x64460034,0x225e007f,0xb05b02c3,0xa3cf02f0}},	//   ybki, ótki_, _flät, वैत_,
   {{0x7ae35ae4,0x2f1402e2,0xa3c10e5e,0x69c35ae5}},	//   sint, räge_, ूना_, ryne,
   {{0x692a030b,0x7c3b2caa,0x69c35ae6,0x00000000}},	//   _přec, _ifur, syne, --,
   {{0xb65900c2,0x98a5078e,0x7ae35ae7,0x00000000}},	//   чших_, _bulă_, qint, --,
   {{0xa50a5ae8,0xaaac00b6,0x4aac0096,0xe57600d3}},	//   зена_, चारक, चारव, нзэ_,
   {{0x92bc00c7,0x26ce5ae9,0xdb0000ee,0xcdda006e}},	//   _আগে_, _elfo_, _armè, פֿיר,
   {{0x78ab2545,0x61fb01e8,0x31c84eab,0x692a02c6}},	//   _ingv, şull, रन्ध, _třec,
   {{0x387f5aea,0xf679006e,0xb05b02c3,0x66cd0206}},	//   lfur_, _זאַמ, _oläs, _fúka,
   {{0x7c3b5aeb,0xd1322ba0,0x00000000,0x00000000}},	//   _ofur, امر_, --, --,
   {{0x387f0188,0x60260e06,0xa2c10714,0x7c3b00bd}},	//   nfur_, едба, रॉब्, _nfur,
   {{0xd00f0080,0x6e3b01e8,0x6fd6004d,0x00000000}},	// [52a0] ملف_, _şuba, хівц, --,
   {{0x63a45aec,0x7c3b5aed,0x4df600c2,0xb05b11d0}},	//   _irin, _afur, няет, _slät,
   {{0x63a40088,0xb05b5aee,0xa3ba01f3,0x00000000}},	//   _hrin, _plät, _ذاکر_, --,
   {{0x628e5aef,0x63a4487c,0x66e60af0,0x00000000}},	//   lebo, _krin, _kékè, --,
   {{0x26060251,0x63a200c4,0x629c0b8e,0x39d800a3}},	//   _सुनी_, _šonj, odro, _भेड़ि,
   {{0x629c5af0,0x63a4001c,0xb05b5af1,0x7c3b0079}},	//   ndro, _mrin, _fläs, _efur,
   {{0xa3e702d5,0x629c5af2,0x7c3b02ad,0x9c83211b}},	//   _येन_, idro, _ffur, ščar,
   {{0x63a45af3,0x628e5af4,0xf1b300a1,0x25784ce5}},	//   _orin, hebo, רסה_, vél_,
   {{0x7d025af5,0xb05b0364,0x67d416e6,0x9abc0090}},	//   moos, _klär, топу, _jiċk,
   {{0x7d025af6,0x628e32e1,0x6d5c0234,0x7c24007e}},	//   loos, jebo, _kvra, žirs,
   {{0x63a45af7,0x6d4e0167,0xa4d5018a,0x00000000}},	//   _arin, _jwba, воні, --,
   {{0x629c084e,0x00000000,0x00000000,0x00000000}},	//   edro, --, --, --,
   {{0x44395af8,0xdb000257,0x68e20193,0x629c029a}},	//   rcs_, _armé, _imod, fdro,
   {{0x69a405a5,0x628e09ed,0x44395af9,0x56935afa}},	//   किपी, gebo, scs_, _башт,
   {{0x63a45afb,0x30a70084,0x7d025afc,0x78ab2fe3}},	//   _erin, нрав, koos, _yngv,
   {{0x69d800cc,0x63a415bc,0x00000000,0x00000000}},	//   izve, _frin, --, --,
   {{0x63a45afd,0x2906068d,0x6d5c5afe,0x7d025aff}},	// [52b0] _grin, _mkoa_, _avra, doos,
   {{0xdef84fee,0x7c3b00bd,0x2bdb09c4,0x6d4e03a8}},	//   ных_, _sfur, _मेगा, _bwba,
   {{0x68e25b00,0x63a42c00,0x2d875b01,0xf653006e}},	//   _omod, _zrin, ïne_, רצע_,
   {{0x9e0400ae,0x69d801d3,0x69a4088d,0x7d025b02}},	//   учул, dzve, किनी, goos,
   {{0x6d5c5b03,0x6d4e5b04,0x660a02ac,0x00000000}},	//   _evra, _ewba, _lyfk, --,
   {{0x68e20150,0xda622c37,0xd056013c,0xaaa4007f}},	//   _amod, авши, diyə, _गोदक,
   {{0x7d025b05,0x212b5b06,0x68e20090,0x6d580031}},	//   boos, _kich_, _bmod, ávat,
   {{0x6d450201,0x212b00b6,0x200700a7,0x629c1799}},	//   mpha, _jich_, ənir_, zdro,
   {{0x212b02dc,0x387f5b07,0x629c4c80,0x6d5c0094}},	//   _mich_, rfur_, ydro, _zvra,
   {{0x2cbf0126,0x2cad035c,0x63a42c1a,0x68e25b08}},	//   _houd_, _hned_, _rrin, _emod,
   {{0xb9b533ce,0x63a41423,0x2cbf5b09,0x628e5b0a}},	//   _جماع, _srin, _koud_, vebo,
   {{0x212b5b0b,0x62850364,0x32cf026a,0xb9650139}},	//   _nich_, _abho, _rüya_, _ebìí,
   {{0x75650068,0x629c5b0c,0x628e5b0d,0x65685b0e}},	//   ریکہ_, tdro, tebo, ardh,
   {{0x212b01ec,0x66c40065,0x63a42d5b,0x68e20034}},	//   _aich_, _bòku, _vrin, _zmod,
   {{0x232709f2,0x628e5b0f,0xa2840470,0xe45f0c19}},	//   тори_, rebo, نیکو, rhör_,
   {{0x55f600ca,0x7c2d033b,0x62850415,0x2cbf0381}},	//   _במצב_, žarj, _ebho, _noud_,
   {{0x212b5b10,0x290d5b11,0x6e3b2461,0x9f4f003e}},	// [52c0] _dich_, ilea_, _đubr, ægð_,
   {{0x212b02e0,0x7f44023b,0x69a4077d,0x2cad00eb}},	//   _eich_, rpiq, किमी, _aned_,
   {{0x22585b12,0x212b022b,0x6b89222b,0x290d2d17}},	//   mark_, _fich_, _apeg, klea_,
   {{0xcb6a1b4d,0x0b8a3574,0x225802ac,0x212b009c}},	//   даде_, дски_, lark_, _gich_,
   {{0x2bb7009d,0x6bd60f36,0x6d455b13,0xa3c200aa}},	//   _आपणा, ختار, apha, ंहि_,
   {{0x212b0505,0xdd921e49,0x6e4341c0,0x68e25b14}},	//   _zich_, _پور_, _верз, _smod,
   {{0x6d455b15,0x610c01bf,0x6b8900e7,0xd91a00c2}},	//   cpha, eßli, _epeg, мьи_,
   {{0x2cbf5b16,0x69d85b17,0x290d04e9,0xa3c2294e}},	//   _goud_, rzve, glea_, ंहा_,
   {{0x6c7b00c1,0x00000000,0x00000000,0x00000000}},	//   _קאמפ, --, --, --,
   {{0x2b4605fe,0x291f0051,0x70bf030b,0x2bdb0f8f}},	//   mpoc_, amua_, _एक्ल, _मेटा,
   {{0xd5b702ec,0x1e5700a1,0x290d01c8,0xaa37006e}},	//   вся_, כשיר_, blea_, _סטאק_,
   {{0xf09f0065,0x9ad30174,0x290d2f10,0x77ca4a46}},	//   _akàn_, _jịnj, clea_, _олег_,
   {{0x212b5b18,0x29040141,0x21200117,0x60d60350}},	//   _rich_, moma_, dmih_, dhym,
   {{0x212b3477,0x25fd0251,0x9abc02a1,0x59b61462}},	//   _sich_, _रुकी_, _biċi, _अपार,
   {{0x7aed025a,0x31c45b19,0xe71700a1,0x66c4022b}},	//   éati, аств, _שחור_, _dòkt,
   {{0xe4d9001c,0x2f145b1a,0x00000000,0x00000000}},	//   _سوخت_, väga_, --, --,
   {{0x260610e9,0x6d455b1b,0x212b00b3,0x00000000}},	// [52d0] _सुती_, wpha, _vich_, --,
   {{0x2cbf00b6,0x290d01e9,0x20f302ef,0x6e450037}},	//   _soud_, zlea_, pćio_, انضم,
   {{0x29045b1c,0xa3e702e8,0x6b895b1d,0x6e940cb0}},	//   koma_, _येत_, _speg, риху,
   {{0x0ce100c7,0x60d65b1e,0x29045b1f,0x5fde2171}},	//   যক্ত, chym, joma_, _नेकल,
   {{0x29045b20,0x692a030b,0xfbd00037,0x6d58003e}},	//   doma_, _přen, يته_, ávar,
   {{0x3f995b21,0x291f023e,0x49990927,0x2cbf0a88}},	//   _issu_, wmua_, етия_, _woud_,
   {{0x49bb00cd,0xc87903e0,0xb05b007b,0x6d585b22}},	//   باشد_, lişi_, _yläp, švar,
   {{0x60cd5b23,0x29041e52,0xb9280134,0xf9900adb}},	//   nkam, goma_, _ikwụ_, تبه_,
   {{0x2fc95b24,0x7d095b25,0x59d1000d,0x60cd5b26}},	//   nyag_, _ikes, तनहर, ikam,
   {{0x60cd5b27,0x752d002b,0x77695b28,0x290d01e9}},	//   hkam, _aiaz, rrex, slea_,
   {{0x7d1b113a,0x60cd5b29,0xf8750604,0x290d034f}},	//   _khus, kkam, _مهاج, plea_,
   {{0xc3290054,0x29045b2a,0xaca30023,0x7d0902a1}},	//   _זו_, coma_, _khốn, _jkes,
   {{0x60cd5b2b,0x22585b2c,0x7d1b5b2d,0xb38313fc}},	//   dkam, tark_, _mhus, блял,
   {{0x68e95b2e,0xb05b0222,0xdb200181,0x320c00a5}},	//   lied, _släp, _štúd, żdym_,
   {{0xaca3321e,0xb9280174,0x60cd02ac,0xe81f0c3c}},	//   _akọn, _nkwụ_, fkam, मेरा_,
   {{0x60cd20c1,0x68e91514,0x7d09051e,0x9abc0078}},	//   gkam, nied, _nkes, _viċi,
   {{0xef1a176b,0xb9280129,0x10a31612,0x44320103}},	// [52e0] ема_, _akwụ_, щитн, _igy_,
   {{0x539b0054,0x68e95b2f,0x7d1b5b30,0x60cd5b31}},	//   _טיפו, hied, _ahus, akam,
   {{0xc27b0130,0x64565b32,0x629e0124,0x29045b33}},	//   _אריי, _keyi, _iapo, yoma_,
   {{0x7d1b5b34,0x629e0d3d,0x3a3e01af,0x64560139}},	//   _chus, _hapo, _sftp_, _jeyi,
   {{0x629e5b35,0xaca30028,0x59b622a0,0x7d1b5b36}},	//   _kapo, _chốn, _अपहर, _dhus,
   {{0x672102e6,0x7d090294,0x6456026e,0x00000000}},	//   jmlj, _ekes, _leyi, --,
   {{0x29045b37,0x629e5b38,0x3f800428,0x68e95b39}},	//   toma_, _mapo, ltiu_, fied,
   {{0x629e5b3a,0xeb9a5b3b,0x6d5e5b3c,0x26d90052}},	//   _lapo, _пиб_, mspa, ëson_,
   {{0x29045b3d,0x752d002b,0x3f805b3e,0x2a76001c}},	//   roma_, _riaz, ntiu_, _مداح,
   {{0x29045b3f,0xcaa600e3,0x60cd5b40,0xdb000094}},	//   soma_, _حصري, zkam, _krmí,
   {{0x68e95b41,0x752d013d,0x5886004b,0x443200f9}},	//   bied, _piaz, _была, _bgy_,
   {{0x68e9132d,0x799a14b1,0x60cd0694,0x629e5b42}},	//   cied, _istw, xkam, _aapo,
   {{0x64560253,0x752d572f,0x629e5b43,0xa3cf33c5}},	//   _deyi, _viaz, _bapo, वैं_,
   {{0x443207d9,0x629e5b44,0x6d5e5b45,0x53345781}},	//   _egy_, _capo, kspa, серт,
   {{0x765a5b46,0x160b2ebd,0xd5af0235,0x64565b47}},	//   maty, _सुपर_, _ус_, _feyi,
   {{0x64565b48,0x7c2d0559,0x765a5b49,0x60cd0138}},	//   _geyi, žari, laty, ukam,
   {{0x7aea0501,0xce6b00a9,0x6f1c009c,0x3e6b13c0}},	// [52f0] kift, еред_, _bhrc, ешен_,
   {{0xc8790587,0x7d1b5b4a,0x68e901d3,0x629e5b4b}},	//   rişi_, _shus, zied, _gapo,
   {{0x999e01b3,0x3d950b11,0x6d5e03bd,0xdd910602}},	//   _metų_, риер, gspa, توا_,
   {{0x645600a7,0x9b750076,0x1df5110d,0x692a00d2}},	//   _xeyi, لاتص, _आशीष_, _břem,
   {{0x3f800990,0xa3e5000d,0x629e5b4c,0xeb992de9}},	//   ctiu_, पछि_, _yapo, тил_,
   {{0x68e90d1b,0x7aea1bfa,0x629e03be,0xa9692249}},	//   wied, gift, _xapo, вика_,
   {{0x68e95b4d,0x7d1b5b4e,0x08d50927,0x69ca4279}},	//   tied, _thus, иция, gyfe,
   {{0xaca30028,0x08c514f8,0x7d1b0010,0x00000000}},	//   _thốn, рбин, _uhus, --,
   {{0x68e95b4f,0x645606a3,0x799a5b50,0x78bb5b51}},	//   ried, _reyi, _estw, rjuv,
   {{0x6b9b0694,0xfaf30688,0x45851d5c,0xa6e5060b}},	//   _isug, _اثر_, агов, ржол,
   {{0x68e95b52,0x2d815b53,0x645606a3,0x67210580}},	//   pied, nthe_, _peyi, rmlj,
   {{0x2d81054f,0x629e5b54,0xb605026e,0x03a60c79}},	//   ithe_, _sapo, _aláà, аимо,
   {{0x07472fd4,0x765a5b55,0x629e5b56,0x81e30033}},	//   _схем, baty, _papo, _ফুল_,
   {{0xe5a518b9,0xdb00001f,0x6d5e5b57,0x247f0129}},	//   _вики, _irmã, yspa, ọmpi_,
   {{0x2056002d,0x64565b58,0xf09f0032,0x273b00fe}},	//   итар, _teyi, _baà_, _hên_,
   {{0x629e0239,0x6d5e2c28,0x2d811881,0x443201f9}},	//   _wapo, vspa, dthe_, _ugy_,
   {{0x629e4108,0xb6050174,0x41270832,0x44260023}},	// [5300] _tapo, _fláà, рото_, _ào_,
   {{0x6d5e08c8,0x3f802b2a,0xf8d21f88,0x20c700bc}},	//   tspa, rtiu_, _तत्प, _sõit_,
   {{0x273b00ef,0x3f805b59,0x2d810076,0xf09f0139}},	//   _lên_, stiu_, gthe_, _faà_,
   {{0x692a00b6,0x3f80015e,0x00000000,0x00000000}},	//   _přem, ptiu_, --, --,
   {{0x273b00ef,0xac07002d,0x7aea0c19,0x765a00f9}},	//   _nên_, анца_, tift, yaty,
   {{0x99660848,0x6d5e5b5a,0x4ed55566,0x291d02a1}},	//   атил, pspa, _люст, _ahwa_,
   {{0x7aea17d2,0xaca30028,0x291d005c,0x8c3d028e}},	//   rift, _chồn, _bhwa_, _başd,
   {{0x273b0028,0x291d140d,0x692a02c6,0xdb0900d2}},	//   _bên_, _chwa_, _zřej, ěnác,
   {{0x69d500fb,0xd90d00bf,0x765a5b5b,0xbb435b5c}},	//   _üzen, ریه_, taty, _метк,
   {{0x4b7b0289,0xb6c60451,0x273b020b,0x00000000}},	//   _באמו, рсий, _dên_, --,
   {{0xdcfc40f0,0x765a5b5d,0x6b825b5e,0xe80200c3}},	//   _sprę, raty, ltog, _लडका_,
   {{0x765a0154,0x57ea0a80,0xdb0000ae,0xf485015a}},	//   saty, _идем_, _urmâ, حادی,
   {{0x765a5b5f,0x386601ff,0x273b03a8,0x00000000}},	//   paty, _idor_, _gên_, --,
   {{0x81e80081,0x2d815b60,0x3d0800a4,0x00000000}},	//   _বড়_, ythe_, िकडे_, --,
   {{0xf1a4236f,0x171b0130,0x3866033b,0x925829db}},	//   ортн, _שווע, _kdor_, раст_,
   {{0x273b0019,0x403400c2,0x2489063d,0x00000000}},	//   _yên_, жетс, _ubam_, --,
   {{0x645d5b61,0x692a030b,0x765800c2,0xc05800f3}},	// [5310] masi, _přej, _kevy, ріс_,
   {{0x539c00a1,0x22950037,0xfe730d59,0x42750da5}},	//   _ייחו, _الدس, تدر_, _угос,
   {{0x62955b62,0x20070034,0x66cd003e,0x62870430}},	//   mezo, łni_, _súkk, mfjo,
   {{0x645d5b63,0x76580084,0x62955b64,0x20c700aa}},	//   nasi, _levy, lezo, _võis_,
   {{0x57b02397,0x61fb028e,0x6b8202ac,0x00000000}},	//   जमोह, ğulu, gtog, --,
   {{0x645d3d3a,0x765840a6,0x62955b65,0x61fb5b66}},	//   hasi, _nevy, nezo, şulu,
   {{0x645d5b67,0x49931e49,0xceb200c1,0x2d9c052f}},	//   kasi, تیار, _ציל_, ævet_,
   {{0x62955b68,0x645d5b69,0x6b9b0d2a,0x291d063d}},	//   hezo, jasi, _tsug, _qhwa_,
   {{0xa49b06a3,0x6d4100fd,0x6b825b6a,0x3866007e}},	//   vlòp, _élab, ctog, _ddor_,
   {{0x629500e7,0x4ec50033,0x61380134,0x00000000}},	//   jezo, _এগুল, ụlit, --,
   {{0xdb2603ed,0x09e50081,0x76585b6b,0x64a65b6c}},	//   _اولی, _পুরা, _devy, бана,
   {{0x273b00ef,0x6aa1000b,0xdb0008a8,0x39815b6d}},	//   _tên_, _half, _irmá, mós_,
   {{0xb05b0222,0x39815b6e,0x6aa15b6f,0x889a00ca}},	//   _poän, lós_, _kalf, _תבני,
   {{0x8c1a00a1,0x62955b70,0x645d010a,0x00000000}},	//   טורי, gezo, aasi, --,
   {{0x645d5b71,0x6aa15b72,0xf8db0067,0xa06a3d78}},	//   basi, _malf, _बताय, лава_,
   {{0xaca300de,0x645d0e13,0x656100f9,0xdb090f5a}},	//   _khổn, casi, mslh, _breë,
   {{0x62955b73,0x6d4700d9,0xdb0901c0,0x39810131}},	// [5320] bezo, _atja, _creë, hós_,
   {{0x692a030b,0xfca905d1,0xe45f003e,0xe29a180b}},	//   _přek, یانو_, gjöf_, _сао_,
   {{0x0d865b74,0x39815b75,0x20e800a7,0x00000000}},	//   слен, jós_, nşik_, --,
   {{0x2703007d,0x6b825b76,0xdd8f0192,0x26d90052}},	//   रकुर_, ttog, عون_, ësoj_,
   {{0xdb005b77,0x8c3d01e8,0x6b74004d,0x2cb7023c}},	//   _armá, _başb, ілку, _šedé_,
   {{0x645d5b78,0x39810428,0x39a70023,0x2d9c02b6}},	//   zasi, fós_, _bđs_, æves_,
   {{0x645d5b79,0x6b825b7a,0x7658224d,0xdca6120a}},	//   yasi, stog, _revy, _лави,
   {{0x6b825b7b,0x160b009f,0x7aed020d,0x6444010a}},	//   ptog, _सुधर_, éatr, _nfii,
   {{0x6295019f,0x645d5b7c,0x38660141,0x00000000}},	//   yezo, vasi, _vdor_, --,
   {{0x645d5b7d,0x39815b7e,0x64440361,0x79810134}},	//   wasi, bós_, _afii, _ịwet,
   {{0x645d5b7f,0x629504fa,0x398100ee,0x00000000}},	//   tasi, vezo, cós_, --,
   {{0xf79a071c,0x2ed50eeb,0xa9265b80,0x6aa10381}},	//   _منصب_, _धत्त, _удел, _zalf,
   {{0x62950995,0x645d5b81,0x76430167,0x31d1080f}},	//   tezo, rasi, _ffny, सन्ध,
   {{0xadfa30a8,0x64440172,0x2f0f042c,0x00000000}},	//   ्थान_, _efii, nügt_, --,
   {{0x692a000d,0x3633046b,0x60c600f3,0xd5af065c}},	//   _přeh, _عروس, _bokm, _эс_,
   {{0x957c0067,0x316c0181,0x645d00a7,0x78a200de}},	//   rząd, ádza_, qasi, _jaov,
   {{0x62955b82,0x6d47354e,0x78a20239,0xdb090383}},	// [5330] pezo, _stja, _maov, _freè,
   {{0x63ad5b83,0x60c60172,0xd2510a85,0x00000000}},	//   _iran, _eokm, _تند_, --,
   {{0x403501b3,0x6aa15b84,0x00000000,0x00000000}},	//   _менс, _ralf, --, --,
   {{0x63ad5b85,0x3981381f,0x81c10081,0xe6c50179}},	//   _kran, vós_, ্ছদ_, _लक्ज,
   {{0x2d9c01c5,0x25630491,0x2f0f0364,0x63ad5b86}},	//   æver_, zıl_, fügt_, _jran,
   {{0x3981369c,0x63ad00d1,0x256307e7,0x29d30174}},	//   tós_, _mran, yıl_, ṭa_,
   {{0x6aa15b87,0xfd13006f,0x60c60233,0x78a2020b}},	//   _valf, _فجر_, _yokm, _baov,
   {{0x63ad1268,0x3981395f,0x69d50018,0x3ea35b88}},	//   _oran, rós_, _üzem, _hajt_,
   {{0x3ea3580e,0x6aa15b89,0xbcb400d4,0x00000000}},	//   _kajt_, _talf, šším, --,
   {{0x66e500d6,0x46e95b8a,0x8f9c0266,0x5589294a}},	//   іона, рдон_, ריזי, абом_,
   {{0xceb40796,0x9abc02a1,0x3ea30216,0x8c3d078e}},	//   ליץ_, _tiċr, _majt_, _gaşc,
   {{0xa50a34fc,0x81c10081,0xe80a02d5,0x3ea3007e}},	//   рема_, ্ছা_, _हुवा_, _lajt_,
   {{0x25630b88,0x60c60220,0xe6130281,0x63ad5b8b}},	//   sıl_, _rokm, _کشش_, _cran,
   {{0x63ad5b8c,0xe5710f36,0x60c65b8d,0x78a20a39}},	//   _dran, _قطب_, _sokm, _zaov,
   {{0x63ad5b8e,0xd7650018,0x333300bd,0xdb095b8f}},	//   _eran, _انڈی, _dixx_, _creé,
   {{0x63ad5b90,0x26c703a8,0xddc70034,0x2f1400aa}},	//   _fran, _hono_, _wejś, mägi_,
   {{0xaec64a4e,0x26c700cd,0xa3e7009d,0x04040033}},	// [5340] обал, _kono_, _येऊ_, রেজী_,
   {{0xafdb0170,0x26c75b91,0x3ea30141,0x853c00c6}},	//   _iføl, _jono_, _cajt_, dvėj,
   {{0x63ad025b,0xa2a3009d,0xb22600ae,0xe45f02c3}},	//   _zran, _छोट्, _фмнл, bjöd_,
   {{0xa3c1009d,0x2eea02a1,0x00000000,0x00000000}},	//   ूनच_, _wmbf_, --, --,
   {{0x160b007d,0x7ed600d6,0xa2c102d5,0x78a200de}},	//   _सुसर_, _дівч, रॉक्, _raov,
   {{0x44020067,0x290000c6,0xf96a227c,0x320d0233}},	//   _लखनऊ_, čiam_, арий_, şeye_,
   {{0xe6070286,0x7d0b0537,0x66e00065,0x00000000}},	//   _آش_, bogs, _lákù, --,
   {{0xe81e007a,0x478a327e,0x6cd60037,0x1d07125c}},	//   _परदा_, асом_, _بقرا, _деси_,
   {{0x27e90218,0x291801d3,0xd6d00037,0x6b632569}},	//   _žanr_, ēra_, فقة_, _окта,
   {{0x26c752fa,0x85742c37,0x78a20239,0x63ad5b92}},	//   _cono_, плох, _waov, _rran,
   {{0x63ad553b,0xa2be0490,0xd6d702ec,0x26c75b93}},	//   _sran, शान्, іть_, _dono_,
   {{0x63ad5b94,0x2ca65b95,0xd05f0092,0xd90e0281}},	//   _pran, ndod_, biqə, _جیب_,
   {{0x26c75a96,0x1818001c,0x63ad013c,0x2246028e}},	//   _fono_, _اراک_, _qran, _şoka_,
   {{0x8c3d020e,0x24800216,0x00000000,0x00000000}},	//   _maşa, _ecim_, --, --,
   {{0x692a030b,0x3ea35b96,0x63ad00f0,0x26f804f1}},	//   _dřev, _rajt_, _wran, ुवीर_,
   {{0x63ad5b97,0x3ea35b98,0x00000000,0x00000000}},	//   _tran, _sajt_, --, --,
   {{0x63ad5b99,0x26c71d42,0x7d0b01cd,0x00000000}},	// [5350] _uran, _yono_, vogs, --,
   {{0x957c0067,0xddab0d5e,0x7f4d0092,0xdbd801cd}},	//   cząc, ител_, rpaq, væða,
   {{0x80c70081,0x3ea3580e,0xd9ea10e9,0x26d90216}},	//   রোগ্, _vajt_, _झेलत_, ësoi_,
   {{0x8c3d01e8,0xd25109b4,0x8f355b9a,0x853c0138}},	//   _başa, _تنگ_, _немц, tvėj,
   {{0x21295b9b,0x7d0b5b9c,0x3ea352b1,0x00000000}},	//   mmah_, rogs, _tajt_, --,
   {{0x7f3a0054,0x8c3d1a4a,0x212900dc,0x539c0089}},	//   _לעשו, _daşa, lmah_, יידו,
   {{0x7c970037,0x26c749dd,0x00000000,0x00000000}},	//   _وشرا, _rono_, --, --,
   {{0x26c70020,0x26de00c2,0x01fc00ca,0x2f1400bc}},	//   _sono_, ehto_, יפול, vägi_,
   {{0x26c70077,0xacda006e,0xf7710076,0x00000000}},	//   _pono_, _פֿלי, راة_, --,
   {{0x21292d96,0x3a7400ae,0x00000000,0x00000000}},	//   hmah_, _олур, --, --,
   {{0x21295b9d,0x64a60f6a,0xd05f00a7,0x5afa006e}},	//   kmah_, пана, siqə, _פלעצ,
   {{0x8c3d0390,0x656e0037,0x64410034,0xdb00042c}},	//   _yaşa, ábha, ślin, _ermä,
   {{0xf749054f,0x69ce02d6,0x692a030b,0xd05f0092}},	//   _التي_, _über, _přev, qiqə,
   {{0x26de0074,0x68fb09a1,0x00000000,0x00000000}},	//   chto_, lnud, --, --,
   {{0x76ba00ca,0x957c007f,0x00000000,0x00000000}},	//   _למספ, rząc, --, --,
   {{0x68fb0088,0xa507013d,0x248009ac,0x957c0034}},	//   nnud, _неща_, _ucim_, sząc,
   {{0xb4ca0557,0x2ca40063,0xd47b00ca,0x752401ff}},	// [5360] ोसी_, _ramd_, _האפל, _ihiz,
   {{0x44205b9e,0x6fb30037,0x2ca45b9f,0xbea3100c}},	//   _izi_, عملا, _samd_, наук,
   {{0x68fb0ac1,0x823b00ca,0x3cff02c3,0x00000000}},	//   knud, _לעיצ, _bjuv_, --,
   {{0x8c3d5ba0,0x644613ff,0x26f80285,0x00000000}},	//   _paşa, ncki, _ंद्र_, --,
   {{0x2ca65ba1,0xdb09015e,0x3cdd0034,0x6d41014b}},	//   rdod_, _creï, _खतरे_, _élan,
   {{0x60c402e6,0x05cb1244,0x44200372,0x60d6028a}},	//   ljim, ाहाब, _mzi_, lkym,
   {{0xd9100470,0x752401c8,0x7de2033c,0xe8110285}},	//   پیش_, _ohiz, _dísé, _डुबा_,
   {{0x60c403ce,0x44200857,0x60d6055b,0xa3cc007a}},	//   njim, _ozi_, nkym, लहा_,
   {{0x44205ba2,0xed3501b6,0x00000000,0x00000000}},	//   _nzi_, _цэрэ, --, --,
   {{0xfa6700a9,0x7e7e0124,0x64460034,0x75245ba3}},	//   _наук_, ngpp, ecki, _ahiz,
   {{0x44205ba4,0xceb300a1,0x3eb80085,0x1bf20179}},	//   _azi_, גית_, _mnrt_, _आइडल_,
   {{0x48e33f67,0x60c43d42,0x7524024a,0x4420044c}},	//   _похв, jjim, _chiz, _bzi_,
   {{0x60c40335,0x00000000,0x00000000,0x00000000}},	//   djim, --, --, --,
   {{0x27f70146,0x236d033b,0x75240634,0x27f90206}},	//   šená_, šejo_, _ehiz, úsne_,
   {{0x44205ba5,0x21290350,0x00000000,0x00000000}},	//   _ezi_, tmah_, --, --,
   {{0xd5fb00a1,0x60c4023b,0x657a5ba6,0x3d060034}},	//   _לפור, gjim, muth, षकों_,
   {{0x657a4b62,0x21295ba7,0x00000000,0x00000000}},	// [5370] luth, rmah_, --, --,
   {{0x2129365a,0x692a02c6,0x290d0051,0x3f141602}},	//   smah_, _křes, zoea_, едус,
   {{0x0c4a0134,0x645f0052,0x00000000,0x00000000}},	//   _ịdịl, _keqi, --, --,
   {{0x60c400e7,0x645f00bd,0x00000000,0x00000000}},	//   cjim, _jeqi, --, --,
   {{0xfaa535c1,0x657a0201,0x6f0200fd,0x0b44004d}},	//   дало, huth, éocc, енін,
   {{0x657a0e7a,0x4fd600ca,0x645f0372,0x98af0154}},	//   kuth, _חושב_, _leqi, _vigč_,
   {{0xdd940138,0x63a800e8,0x3f895ba8,0x3cff1e8f}},	//   _пары, ādni, ltau_, _tjuv_,
   {{0x236903ce,0x26dc0161,0x645f0415,0xdb19007f}},	//   _ovaj_, _alvo_, _neqi, tywó,
   {{0x3f895ba9,0x75241423,0x7c3b1dd0,0x68fb5baa}},	//   ntau_, _rhiz, _igur, rnud,
   {{0x68fb0033,0x657a0201,0x3f8900c6,0x00000000}},	//   snud, futh, itau_, --,
   {{0x645f08cf,0xf771110a,0x236909ac,0x692a00b6}},	//   _beqi, راک_, _avaj_, _přet,
   {{0xb4ca0b95,0x3f890063,0x661d02c6,0x44200141}},	//   ोसे_, ktau_, řsko, _pzi_,
   {{0x61e203e3,0x321c00d4,0x78a90877,0x00000000}},	//   _ƙolo, _švy_, mdev, --,
   {{0xc72400d6,0x657a0201,0x60dd0126,0xe8e000de}},	//   _здій, buth, _alsm, ượt_,
   {{0x692a030b,0x7c3b5bab,0x75244d35,0x00000000}},	//   _třet, _ogur, _thiz, --,
   {{0x387f5bac,0x7c3b5bad,0x2b4d025b,0x6ee01683}},	//   ngur_, _ngur, _otec_, _möbe,
   {{0x442002a4,0x60c45bae,0x60d60138,0x8c3d044c}},	// [5380] _uzi_, rjim, rkym, _paşn,
   {{0x63a45baf,0x290001b3,0x7c3b5bb0,0x645f023b}},	//   _isin, čiai_, _agur, _zeqi,
   {{0xdb09058a,0x6ee00233,0x60c40216,0x00000000}},	//   _creí, _nöbe, pjim, --,
   {{0xdb000018,0x628e1730,0xeaaf0018,0x2b4d03a8}},	//   _ismé, lfbo, یٹن_, _btec_,
   {{0xab9a09b4,0x78a9533d,0x3f890150,0xbb435bb1}},	//   تخار_, ddev, ctau_, вечк,
   {{0xed5a5bb2,0x63a40010,0x78a900e5,0x7c3b01e9}},	//   _мог_, _msin, edev, _egur,
   {{0x78a91044,0x7c3b009e,0x2b4d0231,0x00000000}},	//   fdev, _fgur, _etec_, --,
   {{0x63a45bb3,0x387f5bb4,0x2b580018,0x657a019f}},	//   _osin, ggur_, _فیصد_, vuth,
   {{0xb8f617e5,0x63a45bb5,0x6d4803a9,0x00000000}},	//   _हव_, _nsin, _édab, --,
   {{0x692a000d,0x629c5bb6,0x66cd0181,0x657a019f}},	//   _přes, jero, _súkr, tuth,
   {{0x9e770054,0x78a90307,0x5886004b,0x6aba0090}},	//   וגיה_, bdev, _жыла, _intf,
   {{0x657a0099,0x63a40090,0x6aa8030a,0x3e750139}},	//   ruth, _bsin, _hadf, _kùtà_,
   {{0x629c5bb7,0x63a40068,0x2b4d0428,0x657a0415}},	//   fero, _csin, _xtec_, suth,
   {{0x81cd00c7,0x7f4400a7,0x63a40085,0xd5b00103}},	//   _শেষ_, dqiq, _dsin, _مفت_,
   {{0x8c3d08f5,0x63a45bb8,0xf67b00a1,0x23c500dd}},	//   _başl, _esin, _ואומ, _bëjë_,
   {{0xe7d211c7,0x3f8902db,0x00000000,0x00000000}},	//   _तथाप, ttau_, --, --,
   {{0x6d4e0029,0x6d5c00d1,0x6aba000b,0x8c3d013c}},	// [5390] _atba, _awra, _ontf, _daşl,
   {{0xdef80761,0x7c3b01f7,0xbf1500e3,0x3f895bb9}},	//   мых_, _sgur, رواب, rtau_,
   {{0x62850129,0x3f891a4c,0x2d870257,0x8c9501ce}},	//   _icho, stau_, îne_, ерлі,
   {{0xd0100068,0x3f89020a,0x200f00bc,0x00000000}},	//   الے_, ptau_, ügis_, --,
   {{0xdcfc01d3,0x007600ca,0x6d5c5bba,0x20e82af9}},	//   _aprē, _אתרי_, _ewra, rşit_,
   {{0x21390063,0x6aa800eb,0x00000000,0x00000000}},	//   _hish_, _cadf, --, --,
   {{0x8c3d07d1,0xf9910dd0,0x6d5c0150,0x2139023b}},	//   _yaşl, ابت_, _gwra, _kish_,
   {{0x6aba02e2,0x7e650808,0x78a90036,0x764a0537}},	//   _entf, lahp, udev, _affy,
   {{0x629c5bbb,0x78a939eb,0x692a00b6,0x21390052}},	//   yero, rdev, _přer, _mish_,
   {{0xb4ca033a,0x629c266e,0x21391d09,0x62850294}},	//   ोस्_, xero, _lish_, _ncho,
   {{0xa2be277c,0x63a40361,0x67385bbc,0x78a9015e}},	//   शास्, _ssin, _divj, pdev,
   {{0x62855bbd,0x63a402ef,0x629c5bbe,0x2edc02c6}},	//   _acho, _psin, wero, _यत्त,
   {{0x36d54aa9,0x629c5bbf,0x934300c2,0x6b8902a1}},	//   _подр, tero, лняе, _jqeg,
   {{0x213900ec,0xe0df02f1,0x776900fe,0x6b8902a1}},	//   _aish_, _alò_, msex, _mqeg,
   {{0xf8d3009f,0x7e65061d,0x628e0131,0x412a3b4c}},	//   _तवाय, dahp, rfbo, зово_,
   {{0x63a45bc0,0xe45f5bc1,0x67385bc2,0xe0df01b5}},	//   _tsin, ljön_, _zivj, _clò_,
   {{0x629c5bc3,0x63a40054,0x21395bc4,0xd0070f50}},	// [53a0] pero, _usin, _dish_, еете_,
   {{0xef175bc5,0x629c0052,0x21390f5a,0x5ea60037}},	//   ему_, qero, _eish_, عمال,
   {{0x8c3d026a,0xb9170139,0x213900ca,0xe0df0154}},	//   _taşl, _didẹ_, _fish_, _flò_,
   {{0x63f7001c,0xfce33d77,0x00000000,0x00000000}},	//   _آفیس_, лохо, --, --,
   {{0xdb0901b9,0x7bdd00a7,0x77690206,0xbc670452}},	//   _breà, _üsul, jsex, رمون_,
   {{0x9f400181,0x79a628f1,0x6105013f,0x39a65bc6}},	//   nzií_, ерие, mėla, ешив,
   {{0x7c961557,0x6ee00068,0x00000000,0x00000000}},	//   _прац, _több, --, --,
   {{0x3eaa01bf,0xe8762c31,0x38af0103,0x67380052}},	//   _habt_, راعظ, yörű_, _sivj,
   {{0xa09b0266,0xdb0900b3,0xfce35bc7,0x1d075bc8}},	//   ליקט, _freà, _сото, _чети_,
   {{0xc66a00c2,0x00000000,0x00000000,0x00000000}},	//   чшие_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62855bc9,0x26d90052,0x26c30212,0x00000000}},	//   _scho, ësor_, öjor_, --,
   {{0x21395bca,0x67380090,0x00000000,0x00000000}},	//   _rish_, _tivj, --, --,
   {{0x290008a1,0x24710019,0x21395bcb,0xe5e4001c}},	//   čiau_, ễm_, _sish_, _لزبی,
   {{0x59a624cf,0x62850146,0x201f007e,0x02d10179}},	//   _कैमर, _vcho, _šui_, _सकीन,
   {{0x62850034,0x00000000,0x00000000,0x00000000}},	//   _wcho, --, --, --,
   {{0x2d9814b1,0x62851428,0xd25100cd,0xb0350450}},	// [53b0] _apre_, _tcho, _پنج_, тнаш,
   {{0x62855bcc,0x213900ca,0x9e0700d3,0x6d410113}},	//   _ucho, _wish_, нчел, _élak,
   {{0x7e65005c,0x26ce0231,0xa49b00b3,0x00000000}},	//   rahp, _mofo_, cnòc, --,
   {{0x2b49065b,0x00000000,0x00000000,0x00000000}},	//   íaco_, --, --, --,
   {{0xdb095bcd,0x386f016d,0x5c1452d5,0x644d0350}},	//   _areá, _rdgr_, льшу, _mfai,
   {{0xbb520037,0x2ca900e7,0x3a3e0956,0xdb090503}},	//   جنوب, žad_, _cgtp_, _breá,
   {{0x692a030b,0xdb091ba6,0x66e70139,0x00000000}},	//   _přep, _creá, _lékù, --,
   {{0x0c72001c,0x644d01b9,0x776913c5,0x6b890078}},	//   _نگهد, _nfai, tsex, _tqeg,
   {{0xdb0901b9,0x2d9805db,0x00000000,0x00000000}},	//   _treà, _zpre_, --, --,
   {{0xf1b3142e,0xda675bce,0xdb090072,0xcf920327}},	//   ुमान, _سائي, _freá, סטי_,
   {{0xa50a2249,0x77690161,0xb8950037,0x644d033c}},	//   дена_, ssex, _للاع, _bfai,
   {{0x43462de0,0x8e3600a1,0xe45f0212,0x81e00033}},	//   кемв, כנתא_, sjön_, _দখল_,
   {{0xe72e5bcf,0x26ce2fd7,0x06b00081,0xe45f5bd0}},	//   _ве_, _fofo_, _চকরি, mjöl_,
   {{0x8c3d0b88,0x66e70065,0xd2520103,0xf1aa00d1}},	//   _başk, _dékù, شنر_, وازه_,
   {{0x45d219e8,0x644d0150,0xf50600e5,0x9f400206}},	//   _војс, _ffai, _изко, rzií_,
   {{0x2eda00b6,0x78ab1e71,0xdd1c00c6,0x8c3d013c}},	//   णस्त, _jagv, ršūn, _daşk,
   {{0x1e860002,0x2d98002d,0x7ae10076,0x60cf0365}},	// [53c0] клам, _spre_, _ollt, _docm,
   {{0xd37b0105,0x321a1af5,0xdfcf00e3,0xed5a0565}},	//   _קריט, _typy_, غيل_, дож_,
   {{0x181e34d8,0xdca600c2,0x0d862fd4,0x254c02c6}},	//   _पर्व_, кажи, тлен, _těle_,
   {{0x7ae15bd1,0x78ab084e,0x60cf020b,0x00000000}},	//   _allt, _nagv, _gocm, --,
   {{0x3eab00c2,0x3eaa02b6,0x28c5097c,0xaca40134}},	//   öitä_, _tabt_, वानि, laịt,
   {{0xdb090328,0x00000000,0x00000000,0x00000000}},	//   _preá, --, --, --,
   {{0x99630077,0x3f8020df,0x78ab02b6,0xa9c300e5}},	//   атыл, luiu_, _bagv, исък,
   {{0x2bb400aa,0x00000000,0x00000000,0x00000000}},	//   ूमदा, --, --, --,
   {{0x78ab5bd2,0xbb4600c2,0xb8fa5bd3,0x3f800131}},	//   _dagv, _резк, _ठक_, nuiu_,
   {{0x7d020f72,0x644000e7,0xb9960037,0x02d10835}},	//   lnos, žmil, _للطب, _सकेन,
   {{0x24f90109,0xaaab0e4c,0x00000000,0x00000000}},	//   енны_, _टोटक, --, --,
   {{0x7d025bd4,0x63b65bd5,0x29000138,0x26ce01c2}},	//   nnos, _bryn, čias_, _wofo_,
   {{0x69d50b88,0x5694061b,0x7d021894,0x63b600f0}},	//   _üzer, _балт, inos, _cryn,
   {{0x60cf5bd6,0x68e21b32,0x7d025bd7,0x78ab00c4}},	//   _socm, _hlod, hnos, _zagv,
   {{0x69d80018,0x68e25bd8,0x7d025bd9,0x60cf00c4}},	//   nyve, _klod, knos, _pocm,
   {{0x63b65bda,0x28c500b7,0x00000000,0x00000000}},	//   _fryn, वायि, --, --,
   {{0xb4df24cf,0x3f805bdb,0x63b65bdc,0x68e25bdd}},	// [53d0] णसी_, guiu_, _gryn, _mlod,
   {{0x6449013f,0x62890559,0x8c3d59c2,0x00000000}},	//   žeid, đeos, _taşk, --,
   {{0x28c5034c,0x60cf00d3,0x63ba01d3,0x29060113}},	//   वामि, _tocm, ātne, _ojoa_,
   {{0x657a09f7,0x7d025bde,0x3f800131,0x90e00139}},	//   irth, gnos, buiu_, _jọ̀,
   {{0x248900dc,0x6441007f,0x78a001cb,0x90e00065}},	//   _mcam_, śliw, demv, _mọ̀,
   {{0xa9270181,0x8c3d002d,0xf41400ca,0x6d430174}},	//   _obľú, _maşi, ספס_, ̣nay,
   {{0x69d81060,0x7d025bdf,0x68e21842,0x248900e7}},	//   gyve, bnos, _blod, _ocam_,
   {{0xe94600bf,0x7d02068e,0x3ea10006,0x3ce6025b}},	//   دروی, cnos, leht_, chov_,
   {{0x68e200eb,0xb05b02c3,0x00000000,0x00000000}},	//   _dlod, _knäb, --, --,
   {{0xeb0e0557,0x68e2483a,0x69d84a9b,0x7ae10b6a}},	//   ाकृत_, _elod, byve, _ullt,
   {{0x68e25be0,0x90e00065,0xb955008f,0x69d8029a}},	//   _flod, _bọ̀, _свещ, cyve,
   {{0x68e25be1,0x63b60150,0x248900b3,0x2a650062}},	//   _glod, _pryn, _ccam_, _helb_,
   {{0x657a5be2,0x2d8101bf,0x90e00065,0x2a65009e}},	//   arth, huhe_, _dọ̀, _kelb_,
   {{0x64490933,0x7d0215f4,0x43435be3,0x877a006e}},	//   ñeir, znos, серв, _נאצי,
   {{0x2a6502ef,0x7d025a96,0x91e30b1e,0xdb09016d}},	//   _melb_, ynos, боре, _ereç,
   {{0xc4861e6e,0x205505ed,0x25d60089,0x3ce6006c}},	//   _слик, итур, _תוקן_, xhov_,
   {{0x7d025be4,0x212b009c,0x291f5be5,0xaca400ac}},	// [53e0] vnos, _dhch_, ilua_, saịt,
   {{0x7d021765,0x3ea10364,0x3f801789,0x41aa04d9}},	//   wnos, geht_, ruiu_, _звон_,
   {{0x6b9b0174,0xed57007e,0xc1060037,0x3ce6023e}},	//   _apug, гох_, _مودي, thov_,
   {{0x0b8a5be6,0x5c065566,0x2cad030a,0x00000000}},	//   ески_, ляла, _caed_, --,
   {{0x628108ec,0x254c030b,0x6b9b0090,0x7af802c6}},	//   ólog, _měla_, _cpug, tivt,
   {{0x68e240e8,0x1a66001c,0x69d85be7,0x1fb2007f}},	//   _slod, ایای_, tyve, ीमीड,
   {{0x7d02134c,0x39452f7c,0xfd650134,0x3ce602c3}},	//   pnos, _culs_, _mesị, phov_,
   {{0x58d423a3,0x02d1000d,0xd90d12eb,0x3ce601fa}},	//   роит, _सक्न, ویل_, qhov_,
   {{0x6cc300d3,0x78a00565,0x00000000,0x00000000}},	//   _уйта, remv, --, --,
   {{0x24895be8,0xb05b0212,0x2a650364,0xd9461dde}},	//   _scam_, _knäc, _gelb_, _бежи,
   {{0x6b821a12,0x9e7b006e,0xd5b75be9,0x69c512f1}},	//   luog, ענטפ, гся_, ähet,
   {{0xdb090303,0x657a00e3,0x2db700c1,0x28c5030b}},	//   _preç, rrth, אלטן_, वाणि,
   {{0xf3ff0131,0x6b8200c6,0x8c3d020a,0x2d8100c4}},	//   raão_, nuog, _paşi, zuhe_,
   {{0xf41f0212,0x2d8105bd,0x00000000,0x00000000}},	//   ffär_, yuhe_, --, --,
   {{0x31c4453b,0x8c3d013c,0x00000000,0x00000000}},	//   бств, _vaşi, --, --,
   {{0x90555bea,0x6ad10096,0x6b82024a,0x00000000}},	//   рвац, _तक्र, kuog, --,
   {{0x81cd0081,0x3ea101bf,0x386600dc,0x2ef51d57}},	// [53f0] _শেখ_, teht_, _meor_, азар,
   {{0xbd6b2f34,0x38663789,0x26de5beb,0xc7d700ca}},	//   ерде_, _leor_, nkto_, אומי_,
   {{0x7127006f,0x752d440d,0x6b9b374b,0x644f0451}},	//   _مرحل, _khaz, _spug, occi,
   {{0x2d815bec,0x4c950396,0x62870212,0x629501cb}},	//   ruhe_, ридс, lgjo, lfzo,
   {{0x60cd5bed,0xda655bee,0x752d0350,0x00000000}},	//   mjam, авли, _mhaz, --,
   {{0x450b0081,0x38690141,0x3eaf01d3,0xe81e00aa}},	//   রতিক_, _žar_, ēgts_, _परजा_,
   {{0x60cd01b3,0x6ee0072a,0xdb005bef,0xc334021e}},	//   ojam, _möbl, _armó, זוס_,
   {{0x44295bf0,0x2cbf0124,0x752d0129,0x6d5501e9}},	//   _oza_, _unud_, _nhaz, _itza,
   {{0x7d1b03f3,0x6d475bf1,0x44295bf2,0x38665bf3}},	//   _ikus, _huja, _nza_, _deor_,
   {{0x6d475bf4,0x59670465,0x7c295bf5,0x8c3d01e8}},	//   _kuja, _бъда, _izer, _başv,
   {{0x28c50179,0x44295bf6,0xe4c61bfe,0xf6251146}},	//   वादि, _aza_, айни, рдно,
   {{0x38690682,0x6d475bf7,0x752d5bf8,0x26de00f9}},	//   _þar_, _muja, _chaz, akto_,
   {{0x7d095bf9,0x89342761,0x68e95bfa,0x7d1b0239}},	//   _mjes, _اعلا, mhed, _mkus,
   {{0x60cd00d9,0x7e67030b,0x68e95bfb,0x644f00e5}},	//   ejam, _nejp, lhed, acci,
   {{0x7d1b5bfc,0xa06a4b34,0x44294968,0x27ed5bfd}},	//   _okus, кава_, _eza_, lzen_,
   {{0x68e95bfe,0x752d5bff,0x0f1e0179,0x68fb5c00}},	//   nhed, _ghaz, भत्स_, niud,

   {{0x0e6610fb,0x27ed3682,0x03a64d18,0x644407ac}},	// [5400] икан, nzen_, _типо, _igii,
   {{0x44205c01,0x7d1b5c02,0x6d475c03,0x27ed5c04}},	//   _iyi_, _akus, _buja, izen_,
   {{0x7c2901d4,0xc27b0105,0x6aa35c05,0x68e9057a}},	//   _azer, _בריי, denf, khed,
   {{0x44200a40,0x6ec4058f,0x60cd0034,0x40960b9e}},	//   _kyi_, राहु, cjam, _трот,
   {{0x27ed0505,0x7c290067,0x68e95c06,0xa3e6030b}},	//   jzen_, _czer, dhed, पनि_,
   {{0x7d1b0201,0x6aa35c07,0x7c2901d3,0x7983406e}},	//   _ekus, genf, _dzer, funw,
   {{0xdcfe14f3,0x7c295c08,0x38660fb6,0x27ed0126}},	//   lupč, _ezer, _peor_, ezen_,
   {{0x68e95c09,0x44200129,0x68fb008f,0x7d095c0a}},	//   ghed, _oyi_, giud, _gjes,
   {{0x44205c0b,0x6d47042d,0x6d400188,0x65630090}},	//   _nyi_, _zuja, _iima, _awnh,
   {{0x7d1b030b,0x60cd4eb8,0x644401b9,0x645d01fa}},	//   _zkus, zjam, _agii, wbsi,
   {{0x6d405c0c,0x44205711,0x68e90201,0x38661097}},	//   _kima, _ayi_, bhed, _teor_,
   {{0x68e95c0d,0x6d405c0e,0x44200169,0x752d405d}},	//   ched, _jima, _byi_, _qhaz,
   {{0xdcfc00d9,0x6d405c0f,0xaca40134,0x44205c10}},	//   _aprī, _mima, _nzọp, _cyi_,
   {{0x35f700cd,0xdb090b97,0xd5ba1102,0x644f00b3}},	//   ارید_, _treå, _аси_, scci,
   {{0x44200649,0x60cd05fe,0xaca40294,0xc1050037}},	//   _eyi_, tjam, _azọp, موسي,
   {{0x6d405c11,0x6d475c12,0x44200238,0x955300cd}},	//   _nima, _ruja, _fyi_, _بخوا,
   {{0x60cd5c13,0x6d475c14,0x7d095c15,0x692a030b}},	// [5410] rjam, _suja, _rjes, _břez,
   {{0x63ad2bd7,0x6d475c16,0x539a00a1,0x7d1b5c17}},	//   _isan, _puja, _עיתו, _skus,
   {{0x7c2907d9,0x7d095c18,0x6d405c19,0x254c00b6}},	//   _szer, _pjes, _bima, _mělo_,
   {{0xbd180a8d,0x6d405c1a,0x6d475c1b,0x8d740470}},	//   ації_, _cima, _vuja, زاما,
   {{0x7c201a2e,0x6d405c1c,0x8c3d00d3,0x7d1b035d}},	//   _cymr, _dima, _naşt, _vkus,
   {{0xd94520ec,0xa969090f,0x63ad0051,0x6d475c1d}},	//   беки, гика_, _msan, _tuja,
   {{0x7d090268,0x6d4003e3,0x68fb5c1e,0xa3a908d4}},	//   _tjes, _fima, tiud, _गैस_,
   {{0x27ed5c1f,0x7d1b0060,0x6d405c20,0x7d09067d}},	//   tzen_, _ukus, _gima, _ujes,
   {{0x8aa70c58,0x7c2002e0,0x68e95c21,0x68fb00dd}},	//   _вред, _gymr, rhed, riud,
   {{0x28c5143d,0x39b50029,0x27ed17d1,0x68e95c22}},	//   वाहि, _tās_, rzen_, shed,
   {{0x44260029,0x63ad5c23,0x99d90080,0x4420048e}},	//   _šo_, _asan, _حواء_, _syi_,
   {{0x7d190034,0x03a61278,0x6d40026d,0x44200154}},	//   nows, бимо, _xima, _pyi_,
   {{0x386d038c,0x291d2e6b,0x69cc020a,0x00000000}},	//   maer_, _ikwa_, ăneş, --,
   {{0x386d18f0,0x63ad0167,0x59bd1d96,0xd6db5c24}},	//   laer_, _dsan, ्मपर, _ште_,
   {{0x63ad5c25,0x69dc0b88,0x41b50465,0x9c820087}},	//   _esan, _üret, остт, ščic,
   {{0xe3b203ef,0x8c3d0233,0x386d384c,0x00000000}},	//   _فرخ_, _yaşt, naer_, --,
   {{0x6d405c26,0x44260028,0x4420063d,0x692a00b6}},	// [5420] _rima, _áo_, _uyi_, _přez,
   {{0x6d405c27,0x52aa0291,0xdcfe0094,0x00000000}},	//   _sima, _свом_, rupč, --,
   {{0xa0a65c28,0x6d405c29,0xdd8f01c3,0x291d5c2a}},	//   _ланд, _pima, فول_, _okwa_,
   {{0x237f3fa3,0x6d40041c,0x291d0129,0x61e100f2}},	//   šuje_, _qima, _nkwa_, ølle,
   {{0xb05b02c3,0x2d850429,0x00000000,0x00000000}},	//   _knän, _ålen_, --, --,
   {{0x291d00ac,0x6f1c0995,0x3eb101c8,0x6e3a01cd}},	//   _akwa_, _ukrc, _gazt_, _útbo,
   {{0xa9670a28,0x6d405c2b,0x8c3d020e,0x386d0ac9}},	//   бија_, _tima, _başs, faer_,
   {{0xa3a90006,0x386d5c2c,0x6d403a52,0x8c3d020a}},	//   _गईल_, gaer_, _uima, _paşt,
   {{0x7b072728,0x69b809a1,0x7bc60141,0x98be078e}},	//   órtá, ्मही, _škuf, _aută_,
   {{0xb6c60084,0x675300e3,0x2ca61821,0x6d4100fd}},	//   ссий, أخير, leod_, _élar,
   {{0x63ad083e,0x2a6e0167,0x386d5c2d,0x00000000}},	//   _ssan, mafb_, baer_, --,
   {{0x63ad00b6,0x6fc80980,0x386d0143,0xe4eb0076}},	//   _psan, रमां, caer_, اعده_,
   {{0x28c5099d,0x254c00b6,0x635402c6,0x00000000}},	//   वारि, _tělo_, věný, --,
   {{0x61050138,0x248d0034,0x3f805c2e,0x2245004d}},	//   mėli, żem_, driu_, ølk_,
   {{0xa3a904dd,0x31c41fdb,0x61050138,0x30560134}},	//   _गैर_, пств, lėli, _ọlụ_,
   {{0x63ad5c2f,0x3f805c30,0x00000000,0x00000000}},	//   _tsan, friu_, --, --,
   {{0x6105013f,0xa49b0428,0x2ca600aa,0x7afa010a}},	// [5430] nėli, riòd, deod_, _omtt,
   {{0x7c2600d4,0x3cfb0285,0x7b1f0231,0x00000000}},	//   _úkry, लोने_, nêut, --,
   {{0x957c00a5,0xf5490023,0x741501f3,0x7d19007f}},	//   cząt, _lấn_, _دوکا, tows,
   {{0x3f805c31,0x61050138,0x2d930634,0x00000000}},	//   briu_, kėli, rtxe_, --,
   {{0x3f800472,0x7d195c32,0xa2be0096,0x3aeb0120}},	//   criu_, rows, शाच्, _løpe_,
   {{0x4ea7002d,0x61050138,0x8c3d0233,0x00000000}},	//   _урма, dėli, _başr, --,
   {{0xda780a18,0x28c500a5,0x386d5c33,0x00000000}},	//   сяч_, वालि, taer_, --,
   {{0xa3a90034,0x7ae82227,0xd04d03e3,0xf549020b}},	//   _गईं_, _eldt, rhaɗ, _bấn_,
   {{0xdb23001c,0x98be00ae,0xf5490023,0xd04d0022}},	//   _فوری, _sută_, _cấn_, shaɗ,
   {{0xb6a51a0c,0x81c20033,0x7bc600c4,0xf54900fe}},	//   циол, ্নত_, _škug, _dấn_,
   {{0x64a611a0,0xd629147c,0x7ac4007b,0xb8830206}},	//   оана, роне_, _эсте, _príď,
   {{0xf2c900a1,0x291d0193,0x657c003e,0x399320df}},	//   _בע_, _ukwa_, árha, mãs_,
   {{0x39930231,0x00000000,0x00000000,0x00000000}},	//   lãs_, --, --, --,
   {{0x7b1f0161,0x55e5247a,0xe7560452,0x00000000}},	//   cêut, _молб, _بلوغ_, --,
   {{0xc5d5116d,0x32435c34,0x00000000,0x00000000}},	//   _філь, дерг, --, --,
   {{0x3f805c35,0xe4520bf4,0x1f66345a,0xd7110033}},	//   triu_, _غضب_, жкам, _হওয়া_,
   {{0x254500e8,0x00000000,0x00000000,0x00000000}},	// [5440] _vēlu_, --, --, --,
   {{0x3f803906,0xe29a007e,0x00000000,0x00000000}},	//   rriu_, _тао_, --, --,
   {{0x412a004d,0x6da64175,0x00000000,0x00000000}},	//   _воно_, تمام, --, --,
   {{0x0c26282a,0x3f805c36,0xc7b90103,0x8c460b31}},	//   омен, priu_, kvő_, цеде,
   {{0x8c3d01d4,0x00000000,0x00000000,0x00000000}},	//   _başq, --, --, --,
   {{0xe81d0034,0xf21f034c,0x61050138,0x00000000}},	//   _पड़ा_, _मुड़_, vėli, --,
   {{0xfce6204e,0x39930231,0x00000000,0x00000000}},	//   _дово, gãs_, --, --,
   {{0x6d5e0084,0x394232ee,0x610500c6,0x00000000}},	//   mppa, öks_, tėli, --,
   {{0x629e033b,0xc6f800d6,0xddc500e7,0x3b1e0113}},	//   _obpo, йних_, mahš, _tktq_,
   {{0xf5490028,0xd6da5c37,0x6b820510,0xaefb0065}},	//   _vấn_, рти_, mrog, _awùj,
   {{0x81df0081,0x94050092,0xbb3b006e,0x6b8200b3}},	//   _দেন_, ələ_, _כעמי, lrog,
   {{0xf5490019,0x98a65be3,0x9c832347,0xf74607ec}},	//   _tấn_, _фиде, _účtu, _дедо,
   {{0x7b1f016d,0x25a90a39,0x629e00fc,0x00000000}},	//   pêut, _ćale_, _bbpo, --,
   {{0xdb0001bf,0x050b0081,0x394c00e7,0x6b82002b}},	//   _ermö, রতের_, _kuds_, irog,
   {{0x306b1009,0x254500e8,0x2a6c03a8,0x00000000}},	//   ијан_, _dēls_, _medb_, --,
   {{0x6ab70096,0xb05b0212,0x394c00b3,0xd3a71e11}},	//   _आफ्र, _gnäl, _muds_, _дроп,
   {{0xd8d7006e,0x6e3a01ab,0xdb0b00f3,0x00000000}},	// [5450] קומט_, _útbj, lvgå, --,
   {{0x62350424,0x394c0f5a,0x00000000,0x00000000}},	//   _непу, _ouds_, --, --,
   {{0xac580174,0xde190037,0x00000000,0x00000000}},	//   _ịnụb, حقات_, --, --,
   {{0x272b00f3,0x00000000,0x00000000,0x00000000}},	//   jønn_, --, --, --,
   {{0xef930814,0x6b820e8e,0x7ba700e3,0x6d5e5c38}},	//   _زیاد, grog, تصام, appa,
   {{0xe80e00a8,0x39930131,0x00000000,0x00000000}},	//   ापना_, tãs_, --, --,
   {{0x26c900de,0xc27c006e,0x3ebe01cd,0xa49b009c}},	//   _đao_, ברוי, _ótta_, anòi,
   {{0x6b825c39,0xab950161,0x00000000,0x00000000}},	//   brog, _набљ, --, --,
   {{0x23690383,0xb903058f,0xdb260504,0xf09f0065}},	//   _nwaj_, _नक_, _کولی, _mbà_,
   {{0xb05b0149,0x394c007e,0x6e2203e3,0x00000000}},	//   _snäl, _fuds_, ƙobt, --,
   {{0x394c017a,0x7bd90134,0x28f900ae,0xd7c900d1}},	//   _guds_, ̣bụ, _лежь_, _گوشه_,
   {{0x499a00a1,0x629e007e,0xa50a001f,0x7983010a}},	//   _לשעב, _sbpo, сема_, mrnw,
   {{0xddd50018,0x7d0b5c3a,0x00000000,0x00000000}},	//   _mező, ings, --, --,
   {{0xf09f0af0,0x78a90517,0xfbd20289,0x00000000}},	//   _abà_, leev, עתם_, --,
   {{0x26c75c3b,0x81df0033,0xdb1b0231,0x00000000}},	//   _inno_, _দেব_, _crué, --,
   {{0x78a90361,0x00000000,0x00000000,0x00000000}},	//   neev, --, --, --,
   {{0x23690090,0x8fa33120,0x00000000,0x00000000}},	// [5460] _gwaj_, нате, --, --,
   {{0x63a45c3c,0x78a9023e,0x59bd274c,0x7d0b0113}},	//   _ipin, heev, ्मार, engs,
   {{0x629c5c3d,0x32db00ca,0x6b8200f0,0x628e199b}},	//   mfro, _החינ, wrog, mgbo,
   {{0x31570130,0xf09f0d79,0xf54900de,0x629c0a2c}},	//   _מיטן_, _gbà_, _nấm_, lfro,
   {{0xaac705d4,0xf8bf009d,0xddc50220,0x6d5e0036}},	//   लांक, _शोधय, rahš, sppa,
   {{0x628e3988,0xb4e90213,0x99661be2,0x63a45c3e}},	//   ngbo, _यत्_, птил, _mpin,
   {{0xada33d03,0x394c0899,0xf5490019,0xa9671009}},	//   _парл, _quds_, _bấm_, пија_,
   {{0x26c70465,0xf54900de,0xacea0037,0xd910015a}},	//   _anno_, _cấm_, _ارسل_, خیص_,
   {{0x6d4e5c3f,0x2b4514cf,0x3ce623a0,0x2d5702a1}},	//   _huba, _filc_, mkov_, _għeb_,
   {{0x6d4e4e7b,0x3ce60b27,0x7d025c40,0x6f1e042d}},	//   _kuba, lkov_, lios, nopc,
   {{0x63a45c41,0x2d78037d,0x6d4e5c42,0x18a600c2}},	//   _apin, nče_, _juba, _нажм,
   {{0x6d4e5c43,0x3ce65c44,0x7d025c45,0x6d5c0023}},	//   _muba, nkov_, nios, _mtra,
   {{0xa847006f,0x6d4e5c46,0x629c5c47,0x254c030b}},	//   _علوم_, _luba, ffro, _měli_,
   {{0x6d5c5c48,0xa77b0054,0x569304f5,0x7d025c49}},	//   _otra, _פרופ, _зашт, hios,
   {{0x3946171d,0x2d785c4a,0x63a45c4b,0xa69b00ca}},	//   _kios_, jče_, _epin, _השופ,
   {{0x6aaa09ec,0x3ce60e9e,0x7d020634,0x7bc001ab}},	//   heff, jkov_, jios, _ormu,
   {{0x7d025c4c,0x3ce64092,0x84985c4d,0x39465c4e}},	// [5470] dios, dkov_, _رئيس_, _mios_,
   {{0x6d4e5c4f,0x394603ea,0xd25113c3,0xd5b0023a}},	//   _buba, _lios_, _جند_, _जनाज,
   {{0x6d4e2e2a,0x7bc05c50,0x7d025c51,0x2b4d015e}},	//   _cuba, _armu, fios, _suec_,
   {{0xeae5009f,0xe81d5c52,0x78a9023e,0x6d5c00da}},	//   कस्त_, _पडला_, xeev, _dtra,
   {{0x212910dd,0x6d5c5c53,0x00000000,0x00000000}},	//   mlah_, _etra, --, --,
   {{0x21295c54,0x7b390134,0xf54900fe,0xaac70179}},	//   llah_, _aňur, _sấm_, लाइक,
   {{0x6d5c5214,0x6d4e5c55,0x7bc00827,0x3ce65366}},	//   _gtra, _guba, _ermu, bkov_,
   {{0x212906ee,0xe8df0134,0x8c3d00a7,0x3ce65c56}},	//   nlah_, maịa_, _abşe, ckov_,
   {{0x39465c57,0x6d4e5c58,0x212906e1,0x78a9083e}},	//   _dios_, _zuba, ilah_, reev,
   {{0x2129005a,0x3ced5c59,0x3cff01fa,0x6b8b56ad}},	//   hlah_, _hlev_, _hmuv_, mugg,
   {{0x39460049,0x21293ad9,0x6d5c5c5a,0x34aa24e9}},	//   _fios_, klah_, _xtra, овно_,
   {{0x59a63212,0x69c12e13,0x39460231,0x00000000}},	//   _कैटर, _irle, _gios_, --,
   {{0x4c9a00a1,0x21295c5b,0x00000000,0x00000000}},	//   חברו, dlah_, --, --,
   {{0x7d025c5c,0x66050a01,0x6d5a0257,0x69c10106}},	//   zios, _опла, _étag, _krle,
   {{0x43432249,0x212900dc,0x3ced00aa,0x628e3ea1}},	//   терв, flah_, _olev_, rgbo,
   {{0x6d4e5c5d,0x7d0208a8,0x212902fa,0x6b8b25f6}},	//   _ruba, xios, glah_, kugg,
   {{0x6d4e5c5e,0x3ce6199c,0x2730009c,0xd24f0068}},	// [5480] _suba, vkov_, làna_, انہ_,
   {{0x21290da3,0x44322647,0x291f03e3,0x6b8b002b}},	//   alah_, _izy_, houa_, dugg,
   {{0x3ce62782,0x3ced3813,0x550206ed,0x2129048e}},	//   tkov_, _blev_, _लगाए_, blah_,
   {{0x25d607a6,0x7e6e5c5f,0xfce31121,0x00e300ae}},	//   ווען_, _webp, кохо, _ажюн,
   {{0x69c15c60,0x5f760bf4,0x6b99023e,0xdb1b0428}},	//   _arle, _تاجر, gtwg, _cruï,
   {{0x3ce65c61,0x45060081,0x39465c62,0x7d0211cf}},	//   skov_, ৈতিক_, _sios_, sios,
   {{0x6aaa5c63,0x3ce65c64,0x6d5c5c65,0x7d02007b}},	//   reff, pkov_, _utra, pios,
   {{0x3eb83994,0x57b4387c,0x6b8b5c66,0xdd8f0182}},	//   _hart_, ебит, bugg, _خوف_,
   {{0x69c149bf,0x3eb848d9,0x39465c67,0xb7be0081}},	//   _erle, _kart_, _vios_, েন্ট,
   {{0xddce39c1,0x6a835ada,0x75245c68,0x98a300d9}},	//   _nebū, _алфа, _akiz, ējā_,
   {{0x3eb804a8,0xceb300a1,0x212000e7,0x21295b9b}},	//   _mart_, דית_, koih_, ylah_,
   {{0x3eb8023b,0x21290063,0x67230ebd,0xa4d5004d}},	//   _lart_, xlah_, _eknj, хомі,
   {{0x44320d1b,0x290403ce,0xd9432edb,0x78a20131}},	//   _czy_, mima_, _реци, _ibov,
   {{0x29045c69,0x75240517,0x63bd066a,0x00000000}},	//   lima_, _ekiz, rvsn, --,
   {{0x212906ee,0x98a60034,0xf2040a2d,0x69dc0231}},	//   tlah_, _choć_, вято, _àred,
   {{0x21290808,0x3eb8354c,0x43950284,0xe4a70161}},	//   ulah_, _aart_, _заис, _црко,
   {{0x21294939,0x26dc013f,0x6d581054,0x3eb81d91}},	// [5490] rlah_, _kovo_, ívan, _bart_,
   {{0x44295c6a,0x2129005a,0x29045c6b,0x0ec90557}},	//   _iya_, slah_, hima_, राइड,
   {{0x2129063f,0x61e10222,0x3ced023e,0xfbd0001c}},	//   plah_, älld, _plev_, یته_,
   {{0x290403ce,0xd2510814,0x44290a15,0xdb1b00b3}},	//   jima_, _جنگ_, _kya_, _pruï,
   {{0x290408a9,0x80cc01e4,0xf04400c2,0x3eb81d91}},	//   dima_, हारे, _аэро, _fart_,
   {{0x26dc5c6c,0x78a200a1,0x69c1033b,0xb06200aa}},	//   _novo_, _abov, _prle, _äärm,
   {{0x60dd5c6d,0x44290283,0xdb09009c,0x6b8b1cab}},	//   _kosm, _lya_, _breò, sugg,
   {{0x44295c6e,0x290d002d,0x644d0037,0xf41f042c}},	//   _oya_, unea_, _ngai, lgäu_,
   {{0x44295c6f,0x290d5c70,0x60dd0052,0x6d49009c}},	//   _nya_, rnea_, _mosm, _iiea,
   {{0x644d4f4e,0x26dc028d,0x75245c71,0x60dd18f0}},	//   _agai, _covo_, _skiz, _losm,
   {{0x44295c72,0x2904042d,0x644d5c73,0x7c295c74}},	//   _aya_, bima_, _bgai, _hyer,
   {{0x290403ce,0x44293289,0x09bd0b94,0xd7560100}},	//   cima_, _bya_, ्मीय, بلیت_,
   {{0x4429092f,0x644d00b3,0x00000000,0x00000000}},	//   _cya_, _dgai, --, --,
   {{0x68e95c75,0x67230335,0x60dd01ec,0x2b5f0063}},	//   lked, _uknj, _aosm, _mtuc_,
   {{0x28d304dd,0x67210880,0x60dd5c76,0x3eb801df}},	//   थापि, molj, _bosm, _rart_,
   {{0x68e95c77,0x67210268,0x69c014e5,0x69dc05fe}},	//   nked, lolj, विती, _àree,
   {{0x7c295c78,0x3eb85c79,0x60dd5c7a,0x44290517}},	// [54a0] _nyer, _part_, _dosm, _gya_,
   {{0x29045c7b,0x67215c7c,0x78b9023e,0x139b00ca}},	//   zima_, nolj, _lawv, _צביע,
   {{0x7c295c7d,0x3eb800f3,0x68e95c7e,0x29045c7f}},	//   _ayer, _vart_, kked, yima_,
   {{0x61e15c80,0x7c290193,0xdb1b0072,0x80ca0081}},	//   älle, _byer, _druí, রসঙ্,
   {{0x290400e9,0x4429022e,0x3eb85c81,0x37df0033}},	//   vima_, _xya_, _tart_, _বেসর,
   {{0x940400a7,0xdb09037a,0x7c290052,0x67210234}},	//   ümə_, _breñ, _dyer, jolj,
   {{0xfbd800c7,0x67210995,0x2b5f02a1,0x00000000}},	//   _দেখত, dolj, _etuc_, --,
   {{0x7c29023b,0x6d49009c,0x63b602c3,0x26dc05db}},	//   _fyer, _giea, _osyn, _sovo_,
   {{0x7c290068,0x6d5a025a,0x26dc02a8,0xf41f00c2}},	//   _gyer, _étab, _povo_, ngät_,
   {{0x4429023f,0x644d0441,0xf1d006eb,0x00000000}},	//   _rya_, _sgai, हमान, --,
   {{0x44295c82,0x23605c83,0xfe9b0089,0x25a700ee}},	//   _sya_, _atij_, היימ, _cpnl_,
   {{0x399a00dd,0x78a2024a,0xa49b00ee,0xd7fa00d3}},	//   mës_, _ubov, ciòl, _нул_,
   {{0x66e65c84,0x248002e0,0x399a00dd,0xf8b30341}},	//   _пода, _ddim_, lës_, _תשנ_,
   {{0x44291ee3,0xd5b000cd,0x26dc00e5,0x2480013c}},	//   _vya_, _نفت_, _uovo_, _edim_,
   {{0x399a01e5,0x28c507e2,0x60dd5c85,0x51841e33}},	//   nës_, वाचि, _posm, лута,
   {{0x88bd0067,0x28a60789,0x644d5c86,0x248002a1}},	//   mośc, _कॉमि, _ugai, _gdim_,
   {{0x81df00c7,0x399a00dd,0x44290415,0x61e10212}},	// [54b0] _দেশ_, hës_, _uya_, ällb,
   {{0x399a01e5,0x68e90103,0x7c295c87,0xf09f009c}},	//   kës_, zked, _ryer, _smàd_,
   {{0x88bd0067,0x6d4900d9,0xe31400e3,0x399a00dd}},	//   nośc, _piea, _حبيب, jës_,
   {{0x30790130,0x399a023b,0x7c290154,0x67215c88}},	//   _קאָנ, dës_, _pyer, zolj,
   {{0x06b700c7,0xeb99380e,0x2d57009e,0x6ef21410}},	//   জাতি, фил_, _għen_, _sæbe,
   {{0x6aba16e3,0x88bd00a5,0x78b9022e,0xfaa5137d}},	//   _catf, kośc, _sawv, тако,
   {{0x399a00dd,0x68e95c89,0x6ca70138,0x273903a9}},	//   gës_, tked, _праж, lèng_,
   {{0xdddc01e8,0x657a02b6,0xddc705db,0x88bd007f}},	//   _herş, dsth, _gejš, dośc,
   {{0x68e91a08,0x78bb5c8a,0x75eb0103,0x00000000}},	//   rked, rduv, közö, --,
   {{0x68e95c8b,0x0ab40dd0,0x2caf0126,0x9b440cd2}},	//   sked, _محمد, legd_, _منقو,
   {{0x940c01d4,0x399a023b,0x67215c8c,0x88bd0034}},	//   ədə_, cës_, rolj, gośc,
   {{0xe94500cd,0x67215c8d,0x9f400036,0xd8890281}},	//   _شرای, solj, nziò_, _آپشن_,
   {{0x67211419,0x3f89023e,0x6c7a006e,0x273903a9}},	//   polj, jrau_, וארפ, jèng_,
   {{0x3f895c8e,0x88bd007f,0x69dc464f,0x00000000}},	//   drau_, bośc, _àrec, --,
   {{0x412a5c8f,0xd04d01c2,0x6b9b02a1,0xa822015a}},	//   дово_, nkaɗ, _lqug, _مکین,
   {{0x3f895c90,0x2fc05c91,0x00000000,0x00000000}},	//   frau_, tvig_, --, --,
   {{0xd007078b,0x614308d9,0x412701c9,0x3f895c92}},	// [54c0] вете_, рета, тото_, grau_,
   {{0x45140033,0x2fc05c93,0x6133026a,0x2bb8009f}},	//   _সঠিক_, rvig_, rçla, _इनबा,
   {{0x9d46013d,0xdd8f0cd2,0x127b00c1,0xaefb5c94}},	//   вежд, قول_, _קאטע, _awùs,
   {{0x399a01e5,0x7afd01b3,0x13e60081,0x3f890150}},	//   vës_, _įsta, _পেয়, brau_,
   {{0x8b965c95,0xe457006e,0x88bd007f,0x3f89044c}},	//   треч, דינט_, zośc, crau_,
   {{0x399a01e5,0x6e9600b9,0x9f400103,0x63a95c96}},	//   tës_, _جلسا, rzió_, çeni,
   {{0xf54a00fe,0x00000000,0x00000000,0x00000000}},	//   _hấu_, --, --, --,
   {{0x399a01e5,0x52df303f,0xfce30202,0xb9e300d6}},	//   rës_, _नक्स, _косо, ріши,
   {{0x88bd0067,0x8afd000d,0x8c434d18,0x399a00dd}},	//   wośc, _stře, _вете, sës_,
   {{0x399a023b,0x88bd0034,0x31020dba,0x95d8001f}},	//   pës_, tośc, रोतः_, едот_,
   {{0x7bc25c97,0xaca40174,0x399a0052,0x00000000}},	//   lvou, agụt, qës_, --,
   {{0x657a5c98,0x88bd007f,0xf48505bc,0x00000000}},	//   rsth, rośc, دادی, --,
   {{0x7bc204ee,0xf54a0019,0x6d580146,0x657a00f3}},	//   nvou, _nấu_, ívaj, ssth,
   {{0x2caf0126,0x6594037e,0x21390227,0xf53f0407}},	//   zegd_, _баку, _shsh_, små_,
   {{0x8c3d11bc,0x00000000,0x00000000,0x00000000}},	//   _daşy, --, --, --,
   {{0x99bb00a1,0x50641f5d,0x3f895c99,0xd7b60285}},	//   וזלט, итуа, trau_, _अनाच,
   {{0xa2d0007d,0xf54a0019,0xab5d02a1,0xdddc026a}},	// [54d0] दाश्, _cấu_, _arżn, _perş,
   {{0xf54a0028,0x2ef40974,0x7bc20141,0x00000000}},	//   _dấu_, азур, dvou, --,
   {{0x7bc25c9a,0xa2d02b6e,0x00000000,0x00000000}},	//   evou, दार्, --, --,
   {{0x273900fd,0x506400d6,0x645d5c9b,0x00000000}},	//   mène_, _втра, ncsi, --,
   {{0xceeb0814,0x273900fd,0xf54a00de,0x3b0700a7}},	//   _قرآن_, lène_, _gấu_, tinq_,
   {{0x8f9a00a1,0xaefb0065,0xd9d70033,0xf54a00fe}},	//   _אישי, _ewùr, তনসম, _hất_,
   {{0xf2d40130,0xeaf309d0,0x3b0700a7,0x39b7013c}},	//   יעס_, _अतीत_, rinq_, _kəsə_,
   {{0xa502009d,0x00000000,0x00000000,0x00000000}},	//   _लगेच_, --, --, --,
   {{0xf54a0019,0xf7710192,0x6e3a01cd,0xdbd6042c}},	//   _mất_, حاب_, _útbr, mäße,
   {{0x6d553565,0xc9872c22,0x2be0030b,0xb05b02c3}},	//   _kuza, _ауди, कहरू_, _knäs,
   {{0x66055c9c,0x6d554126,0x00000000,0x00000000}},	//   упна, _juza, --, --,
   {{0x6d555c9d,0xa87900c1,0x26ce06a3,0x9a9901d3}},	//   _muza, _װאַר, _enfo_, žādā,
   {{0x6d550a00,0xe72e3bbc,0x7ae1026a,0xc8795c9e}},	//   _luza, _ге_, _kolt, maş_,
   {{0xc7b200ca,0x81df0033,0x201c0233,0x6d550154}},	//   _לבד_, _দেই_, şvik_, _ouza,
   {{0x7ae15c9f,0xf54a00de,0x273900fd,0x973600ca}},	//   _molt, _bất_, gène_, _גרסא_,
   {{0x61e10149,0xb4db05fe,0xf54a00de,0xe610001c}},	//   älla, rmàc, _cất_, _بشه_,
   {{0x7e7512fb,0xb348003d,0x251b00ca,0x6d5512fa}},	// [54e0] _bezp, _agħż, _רופא, _auza,
   {{0x4df602fd,0x6d555ca0,0x27e001b9,0x00000000}},	//   ляет, _buza, _àine_, --,
   {{0x91e602b7,0x6d55016d,0x80d30033,0x2739014b}},	//   _соне, _cuza, _সতর্, cène_,
   {{0x2d8704d8,0x6d5500cc,0xf54a0023,0x7bc21cab}},	//   ánea_, _duza, _tấu_, tvou,
   {{0x7ae15ca1,0xc879008b,0x7fd501ce,0x6d600234}},	//   _bolt, daş_, _кірі, _žvač,
   {{0x6b8400e7,0x7ae1372f,0x28a60176,0x7bc25ca2}},	//   šigo, _colt, क्नि, rvou,
   {{0xee375ca3,0x13ad0033,0x00000000,0x00000000}},	//   _бнр_, খিয়, --, --,
   {{0x8c460d5e,0x61e10565,0xc879044c,0x00000000}},	//   _бебе, ølli, gaş_, --,
   {{0x6d550146,0x3f92026a,0x7ae15ca4,0x00000000}},	//   _zuza, nuyu_, _folt, --,
   {{0x7f4e003d,0x7ae10141,0x6d4201ff,0x00000000}},	//   _jibq, _golt, lmoa, --,
   {{0xd88400cd,0x645a00b6,0x97d70103,0x16342b16}},	//   _نهای, ětin, نظیر_, реня,
   {{0x3f925ca5,0x27395ca6,0x7ae15ca7,0xc879020a}},	//   kuyu_, vène_, _zolt, caş_,
   {{0xf54a00ef,0x2bc70b42,0x09060018,0x69c800d8}},	//   _rất_, लिया, _لڑکی_, _hrde,
   {{0x88bd0034,0x69c805db,0x7f4e009e,0x00000000}},	//   nośn, _krde, _nibq, --,
   {{0xd13b5ca8,0x7e750167,0x69d8029a,0x00000000}},	//   еха_, _rezp, nxve, --,
   {{0x6d5502a4,0x68e25ca9,0x2739020d,0x00000000}},	//   _ruza, _jood, rène_, --,
   {{0x68e25caa,0xf54a0023,0x3f92001c,0x27392bc7}},	// [54f0] _mood, _vất_, guyu_, sène_,
   {{0x3f8702e6,0x200d0102,0xdef81736,0x63ad5cab}},	//   čnu_, _þeim_, лых_, _ipan,
   {{0xf54a0028,0x628503a9,0xadb55cac,0xff5f03a8}},	//   _tất_, _idho, рбеш, _grîn_,
   {{0x68e201a2,0xa3e90635,0xf54a00fe,0x3f92024a}},	//   _nood, _यथा_, _uất_, buyu_,
   {{0x69c85cad,0x6d5a025a,0x7ae15cae,0xc8790587}},	//   _arde, _étan, _polt, vaş_,
   {{0x63ad466b,0x6d552dd6,0x084e0294,0x2bc72231}},	//   _mpan, _tuza, _kọfị_, लिबा,
   {{0x7ae15caf,0x68e25cb0,0xdb00052f,0x2c5e0134}},	//   _volt, _bood, _opmæ, _ịde_,
   {{0x7ae1222c,0x69c33137,0x88c95cb1,0x2d930072}},	//   _wolt, rvne, тлив_, muxe_,
   {{0x68e25cb2,0x62852052,0x7ae12c6d,0xccf200a1}},	//   _dood, _odho, _tolt, _וכן_,
   {{0x7d0b5cb3,0x2cbf1305,0xa3b00034,0xe7390291}},	//   ligs, _haud_, _टैग_, ђен_,
   {{0xa2d900e2,0x68e25cb4,0x63ad5cb5,0xe5a54000}},	//   मान्, _food, _apan, шини,
   {{0x7bc95cb6,0x7d0b5cb7,0x68e25cb8,0x27300023}},	//   _kreu, nigs, _good, hành_,
   {{0x61e10222,0x5fc9023a,0x2cbf5cb9,0xb76705e1}},	//   älln, रिफल, _maud_, _стей,
   {{0xf77000bf,0x2cbf5cba,0x386d02e2,0xcb1200c1}},	//   _راه_, _laud_, lber_, ַלן_,
   {{0x63ad5605,0x7d0b02c9,0x68e20036,0x00000000}},	//   _epan, kigs, _yood, --,
   {{0x394f01af,0x386d01cd,0x3d1f007f,0x2fcd1500}},	//   _jigs_, nber_, यकों_, _šega_,
   {{0x386d01bf,0x394f00f9,0x7d0b02ac,0xaf065cbb}},	// [5500] iber_, _migs_, digs, апал,
   {{0x394f0063,0x543b006e,0x3f920fce,0x386d0233}},	//   _ligs_, _בעפא, ruyu_, hber_,
   {{0x386d5cbc,0x7d0b0364,0xdcff00b6,0x63ad007e}},	//   kber_, figs, _úvěr, _zpan,
   {{0x0b8a1510,0x7bc95cbd,0xdca6232c,0xa3ba1792}},	//   вски_, _breu, ради, _घना_,
   {{0x7bc95cbe,0x2cbf5cbf,0x68e25cc0,0x69c85cc1}},	//   _creu, _daud_, _rood, _srde,
   {{0x7bc95cc2,0x68e24d4e,0x6d420a00,0x69c81177}},	//   _dreu, _sood, smoa, _prde,
   {{0xaca40134,0x68e200aa,0xf9e90033,0xb05b0212}},	//   _agụp, _pood, _কেবল_, _knäp,
   {{0x7bc95cc3,0xa774016a,0x00000000,0x00000000}},	//   _freu, блич, --, --,
   {{0x7bc95cc4,0x6fc91687,0x68e200aa,0x5fc909a1}},	//   _greu, रियं, _vood, रियल,
   {{0x2cbf022e,0x28a602d5,0x68e25cc5,0x69c80117}},	//   _zaud_, _कॉरि, _wood, _trde,
   {{0xd5b75cc6,0x386d5cc7,0x68e2007a,0xd6d72787}},	//   ася_, bber_, _tood, рты_,
   {{0x186a5011,0x6fc90789,0x2ca60150,0x63ad0063}},	//   _ради_, रिमं, nfod_, _ppan,
   {{0xda780038,0x07da00cd,0x8af900a7,0x938b00e5}},	//   _keď_, _جذاب_, bləğ, ъсна_,
   {{0x59bd2172,0x61e102c3,0x00000000,0x00000000}},	//   ्मचर, ällo, --, --,
   {{0xb6cb0068,0x31c45cc8,0x57b600b6,0x00000000}},	//   _جانے_, оств, _अनुह, --,
   {{0x26de00e7,0x27390113,0x00000000,0x00000000}},	//   ljto_, mèna_, --, --,
   {{0x63ad5cc9,0x752d5cca,0x8af900a7,0x2cbf5ccb}},	// [5510] _upan, _ikaz, lləş, _raud_,
   {{0x28a60354,0x2cbf006c,0xf54a0019,0x2d8704d8}},	//   क्ति, _saud_, _hấp_, áneo_,
   {{0x386d07a4,0x7d0b2b84,0x8af90092,0x2cbf00ec}},	//   yber_, tigs, nləş, _paud_,
   {{0x7c87215f,0x237f0995,0x67280a39,0x30a75ccc}},	//   руже, šuju_, hodj, _тров,
   {{0x672803d6,0x752d0051,0x60da0266,0x7d0b0a1f}},	//   kodj, _mkaz, _עקשנ, rigs,
   {{0x7bc95ccd,0xf54a0023,0x7d0b10ef,0x752d010a}},	//   _vreu, _lấp_, sigs, _lkaz,
   {{0x752d5cce,0xceb200a1,0x386d0167,0x7db400e3}},	//   _okaz, _מים_, tber_, _وصفا,
   {{0x7bc95ccf,0x2d815cd0,0xac9400a9,0xa3c9030b}},	//   _treu, mshe_, _масш, ोमा_,
   {{0x7d095cd1,0x394f057a,0x6edb058f,0x69de0120}},	//   _imes, _vigs_, नापु, øper,
   {{0x752d4dce,0x67280786,0x7d1b0aa8,0x7c3b5cd2}},	//   _akaz, godj, _hjus, _izur,
   {{0x2d811114,0x77690042,0x25ae0231,0xb4db015e}},	//   nshe_, spex, _cpfl_, rmàn,
   {{0xf54a00ef,0x23c302d5,0xda7802c6,0x3f8000c6}},	//   _cấp_, शिंद, _zeď_, ysiu_,
   {{0x67280580,0xa85600a1,0x7d095cd3,0x7c3b0090}},	//   bodj, _הינה_, _mmes, _jzur,
   {{0x7d1b5cd4,0x7c3b0010,0x62631d8a,0x9f95042c}},	//   _ljus, _mzur, звра, _süße_,
   {{0x27ed5cd5,0x7d095cd6,0xaca30139,0xf5950037}},	//   lyen_, _omes, _amọn, _العج,
   {{0xf54a0019,0x7c3b0294,0x7d1b0995,0xa5641f11}},	//   _gấp_, _ozur, _njus, _بدون,
   {{0x27ed14b1,0x7c3b0010,0x27ff0d2a,0x3f800138}},	// [5520] nyen_, _nzur, nzun_, usiu_,
   {{0x7d095cd7,0x7d1b5cd8,0x7e565cc8,0xdfcf00e3}},	//   _ames, _ajus, стац, عيل_,
   {{0x7c3b5cd9,0x3f800428,0xe1f20421,0x27ed3ae4}},	//   _azur, ssiu_, _رسد_, hyen_,
   {{0x6d5a5cda,0xa1360421,0xf54a00fe,0x8d8500d1}},	//   _étam, _درخش, _xấp_, زشمن,
   {{0x2ca602ad,0x27ed0db0,0x68fb4648,0x8af9013c}},	//   rfod_, jyen_, dhud, zləş,
   {{0x7d095cdb,0x27ed06a3,0x64410092,0x60c45cdc}},	//   _emes, dyen_, əlid, ldim,
   {{0x6728479c,0x7c3b0134,0xda780220,0x443201dc}},	//   vodj, _ezur, _veď_, _lyy_,
   {{0x60c45cdd,0xdca32b49,0x68fb21ff,0x44205cde}},	//   ndim, _наси, ghud, _oxi_,
   {{0x27ed0068,0xda78030b,0xe7620174,0x200000d3}},	//   gyen_, _teď_, _bọọs, nzii_,
   {{0xf76f0b05,0xc6f7022c,0x7d090031,0x7a420103}},	//   راً_, йных_, _zmes, gíté,
   {{0x67280d12,0x67fe0065,0x7d0900f0,0x19f900ae}},	//   rodj, _bàjé, _ymes, _кэць_,
   {{0x27ed0c56,0x8af901d4,0x67285cdf,0x629e009c}},	//   byen_, rləş, sodj, _acpo,
   {{0x7e7e0665,0x6b821561,0xf54a0023,0xddd50154}},	//   kapp, nsog, _vấp_, _egzň,
   {{0x64560068,0xd765001c,0xa2d91a09,0x2d810052}},	//   _egyi, _بنوی, माध्, yshe_,
   {{0x752d044c,0x7e7e1f6d,0xf54a00fe,0x8af9013c}},	//   _tkaz, dapp, _tấp_, qləş,
   {{0x752d2188,0x39ae013c,0x7e7e2925,0x00000000}},	//   _ukaz, _kəsb_, eapp, --,
   {{0x14d60d7e,0x2d8302ef,0x6133026a,0x24895ce0}},	// [5530] धारण, _svje_, nçli, _idam_,
   {{0x6d405ce1,0x7d095ce2,0x2d81019f,0x4e781673}},	//   _ahma, _smes, tshe_, محمد_,
   {{0x6d4002ef,0x2c5e0294,0xb0c40971,0x28bd5ce3}},	//   _bhma, _ịda_, _लोकग, ्यमि,
   {{0x2d815ce4,0x27ed5ce5,0x24890124,0x7a420103}},	//   rshe_, yyen_, _jdam_, zíté,
   {{0x7e7e5ce6,0x7d090087,0x2d810022,0x6d40041c}},	//   bapp, _vmes, sshe_, _dhma,
   {{0x28a613ae,0x7e7e5ce7,0x27ed5ce8,0xa8a70555}},	//   क्सि, capp, vyen_, şmüş_,
   {{0xdd9404d9,0x6d580181,0x24890a60,0x27ed5ce9}},	//   _нары, ívat, _odam_, wyen_,
   {{0x7d095cea,0x27ed06a3,0x27ff0a00,0xe7620134}},	//   _umes, tyen_, tzun_, _sọọs,
   {{0xe8f6059b,0x2369022e,0x7c3b5ceb,0x290d01ff}},	//   іль_, _ntaj_, _uzur, riea_,
   {{0x27ed5cec,0x45852b49,0x05a91ad1,0xd7090084}},	//   ryen_, огов, авой_, рное_,
   {{0x27ed5ced,0x443200c2,0x1dd90285,0x7a420103}},	//   syen_, _syy_, णमित, ríté,
   {{0x7a420018,0x03a60084,0x7e7e0a53,0x81df0033}},	//   síté, оимо, zapp, থনা_,
   {{0xdd0c00a5,0x7a420103,0xe0df01f7,0x2b520233}},	//   _późn, píté, _mhòd_, _üncü_,
   {{0x36690831,0x61ee5cee,0x6d48028d,0x387f020a}},	//   _тако_, tybl, _èdav, laur_,
   {{0xd5ac0068,0x23695cef,0x2d870220,0x2cad0206}},	//   _یہی_, _etaj_, šnej_, _obed_,
   {{0x60c4013f,0x4420006c,0x463a00c1,0x7e7e4251}},	//   udim, _txi_, _דעצע, wapp,
   {{0x443200f9,0x00000000,0x00000000,0x00000000}},	// [5540] _uyy_, --, --, --,
   {{0x6d40023b,0x20005cf0,0x63a40201,0xa3e70cce}},	//   _shma, rzii_, _iqin, पहर_,
   {{0xbc6a0241,0x629c5cf1,0x57b6007a,0x04930018}},	//   لمان_, mgro, _अन्ह, _علیح,
   {{0x629c1f58,0x60c400a7,0x9b6a090f,0xe0df01f7}},	//   lgro, qdim, ашка_, _chòd_,
   {{0x8bb600cd,0x63a601af,0x7e7e3355,0x387f5cf2}},	//   تصاص, ntkn, papp, daur_,
   {{0x629c5cf3,0x2fcf052f,0x29e503e3,0x3e6b0421}},	//   ngro, ægge_, rɓan_, _نجفی_,
   {{0x14ca00a5,0x6b825cf4,0xe0df01b9,0x6d40009c}},	//   ियाण, ssog, _fhòd_, _thma,
   {{0x6d5c5cf5,0x387f5cf6,0x37aa5cf7,0x629c0178}},	//   _iura, gaur_, атон_, hgro,
   {{0x28a606ae,0xd7fa3d80,0x6d5c5cf8,0x629c1570}},	//   क्षि, руй_, _hura, kgro,
   {{0x6bd70037,0x00000000,0x00000000,0x00000000}},	//   _بوكس_, --, --, --,
   {{0x7e7c0533,0x248900ec,0xa01b0364,0x63a40415}},	//   _merp, _pdam_, _geöf, _aqin,
   {{0x30c50081,0x7e7c00f0,0x629c5cf9,0x2be10033}},	//   _এক্স, _lerp, egro, _খেয়ে_,
   {{0x81af00c7,0x38cb09b4,0x6d5c5cfa,0x5bb802d5}},	//   ওয়া_, _خالی_, _lura, _इनोव,
   {{0x2d87000d,0x6d5c00fc,0x629c02ac,0x00000000}},	//   ánek_, _oura, ggro, --,
   {{0x7ae80021,0xc0d10139,0xa8ee030b,0x63a40201}},	//   _modt, _akíọ, _जवाफ_, _eqin,
   {{0x63a4023b,0x7ae802b6,0x7e7c0503,0xc5f800e8}},	//   _fqin, _lodt, _aerp, ncēm_,
   {{0x7e7c03b4,0x6d5c5cfb,0xdced01d3,0x40345c34}},	// [5550] _berp, _aura, ākļo, детс,
   {{0x6d5c5cfc,0x7e7c0918,0x539a00a1,0x629c01ec}},	//   _bura, _cerp, _פיתו, cgro,
   {{0x6d5c5cfd,0x7e7c5cfe,0x7bc05cff,0x31350566}},	//   _cura, _derp, _asmu, _неор,
   {{0xd7bc022d,0x7afa5d00,0xe7bc28fb,0x00000000}},	//   ्टाच, _altt, ्टाप, --,
   {{0x3af5163d,0xe0df5d01,0x60da00ca,0xb0d80285}},	//   зяйс, _fiòr_, _הקרנ, डारग,
   {{0x6d5c5d02,0x38660134,0x7bc00113,0xed050d5b}},	//   _fura, _afor_, _dsmu, _کورپ,
   {{0x6d5c5d03,0x7bc0015e,0xe8df00fe,0x99850076}},	//   _gura, _esmu, _ngợm_, ألبو,
   {{0x28bd0d77,0xddc705db,0x99d40286,0x7e65042c}},	//   ्यधि, _kejž, بتها, lchp,
   {{0x7f5d025a,0x2d9e0149,0x7ae80537,0xfbbf1358}},	//   _jusq, _äter_, _fodt, _एनिम,
   {{0x387f5d04,0x6d5c5d05,0x7ae800d6,0x7f5d3d54}},	//   saur_, _yura, _godt, _musq,
   {{0x6d5c5d06,0xe8550037,0x2bbf06ec,0x3866030a}},	//   _xura, _فناد, _शैता, _ffor_,
   {{0x629c0d4d,0x26c3033b,0x6d480036,0x2ec8110d}},	//   wgro, žjo_, _èdat, _रफ्त,
   {{0x629c3447,0x98e40037,0x0876006e,0x7f5d026d}},	//   tgro, _تكنو, _זענט_, _nusq,
   {{0x254d00b6,0x853d00c6,0x63a63f6d,0xb5aa0103}},	//   _měly_, ltėl, rtkn, جئیے_,
   {{0x629c5d07,0xbbb802f0,0x867a00ca,0x91e600b8}},	//   rgro, _इन्क, _הרצו, чове,
   {{0x6d5a04ea,0x7f5d5d08,0x629c04e2,0xc0e35d09}},	//   _étai, _busq, sgro, носк,
   {{0x6d5c0f8b,0x629c5d0a,0xe29a2c11,0x00000000}},	// [5560] _sura, pgro, _лап_, --,
   {{0x6d5c2af5,0xdfcf0037,0xaec3235c,0x7e7c0216}},	//   _pura, ديك_, нбул, _qerp,
   {{0x7e7c1c7d,0xfc660465,0x25615d0b,0x6d5c5d0c}},	//   _verp, пълн, _jól_, _qura,
   {{0x6d5c0491,0x6fc93e2a,0x409600c2,0x7e7c1183}},	//   _vura, रिशं, _эрот, _werp,
   {{0x7e7c03b4,0x6d5c006d,0x92e912eb,0x60c60bb6}},	//   _terp, _wura, _طریق_, _iakm,
   {{0x6d5c5d0d,0x60c65d0e,0x38660a39,0x98a401d3}},	//   _tura, _hakm, _sfor_, domā_,
   {{0x2bb80034,0x6d5c0be9,0x00000000,0x00000000}},	//   _इनका, _uura, --, --,
   {{0x61e15d0f,0x7ae3023e,0xc8fc0081,0xae1b00ca}},	//   älli, ajnt, ুক্ত_, _הולכ,
   {{0x60c65d10,0x69c101e9,0x387d00eb,0x00000000}},	//   _makm, _esle, _dewr_, --,
   {{0xd6da5d11,0x8626457f,0x25612214,0xdddc2224}},	//   сти_, зьме, _ból_, _nerū,
   {{0x2fc700de,0x00000000,0x00000000,0x00000000}},	//   ̉ng_, --, --, --,
   {{0xd84e0134,0x3eba029a,0x69a100a4,0x00000000}},	//   tọde_, hept_, _गमती, --,
   {{0x395e0634,0x78a2039f,0x2561033c,0x00000000}},	//   _huts_, _icov, _eól_, --,
   {{0x66e302ec,0x28da2fc2,0x60c600f9,0x2d9a5d12}},	//   _поча, भावि, _aakm, kupe_,
   {{0x25611e6f,0x7f550479,0x60c6026a,0x31353456}},	//   _gól_, _rizq, _bakm, девр,
   {{0x395e026b,0xd2500103,0x00000000,0x00000000}},	//   _muts_, انِ_, --, --,
   {{0x60c61195,0x395e00b7,0x00000000,0x00000000}},	// [5570] _dakm, _luts_, --, --,
   {{0x853d00c6,0x2a7e039f,0xaf3300d1,0x00000000}},	//   itėm, _netb_, رواژ, --,
   {{0x2d875d13,0x7e655d14,0x2d9a0113,0x395e0158}},	//   éne_, rchp, gupe_, _nuts_,
   {{0x7f5d037a,0x6e350094,0x7e652f71,0x25dd00b6}},	//   _tusq, _vyzb, schp, गमती_,
   {{0xfbab0978,0x00000000,0x00000000,0x00000000}},	//   стей_, --, --, --,
   {{0x3eba5d15,0x395e00fd,0x78a200b3,0x3dc60034}},	//   cept_, _buts_, _acov, łowa_,
   {{0xa9c400e3,0x2d9a00fd,0xceb2006e,0x60c60233}},	//   فزيو, cupe_, _שיל_, _yakm,
   {{0x25610cc8,0x6ca45d16,0x395e00b3,0x28da0980}},	//   _ról_, _пруж, _duts_, भाषि,
   {{0x25615d17,0x29030138,0x752f0034,0x6d4b0571}},	//   _sól_, ėja_, docz, mmga,
   {{0x09bc00c7,0xca4800cd,0x55895d18,0x25615d19}},	//   _অপরা, _کلمه_, обом_, _pól_,
   {{0x69c15d1a,0xf212278e,0x00000000,0x00000000}},	//   _usle, _डेढ़_, --, --,
   {{0xfd660af0,0x3eba01bf,0x00000000,0x00000000}},	//   _aapọ, zept_, --, --,
   {{0xb4e60139,0x00000000,0x00000000,0x00000000}},	//   _apàà, --, --, --,
   {{0x25615d1b,0x853d0138,0x60c6001c,0x78bb490e}},	//   _tól_, ntėj, _sakm, leuv,
   {{0xb0c90034,0x752f0034,0x395e00b3,0x21670131}},	//   ाएंग, bocz, _xuts_, диси_,
   {{0x78bb5d1c,0x26c70193,0x69ce32f7,0xfefa0033}},	//   neuv, _hano_, थिती, _আদেশ_,
   {{0x26c75d1d,0x3eba00d3,0x03262917,0x60c65d1e}},	// [5580] _kano_, tept_, _один, _vakm,
   {{0x24805d1f,0xd5b10c9c,0x2d9a5d20,0x26c75d21}},	//   _heim_, _जहाज, tupe_, _jano_,
   {{0x26c75d22,0x60c65d23,0x80a606ed,0x6b895d24}},	//   _mano_, _takm, _छापे, _aveg,
   {{0x2d870161,0x6b830294,0x2d9a5d25,0x3eba5d26}},	//   ânea_, _ọgar, rupe_, sept_,
   {{0x61e102c3,0x1ab4007b,0x00000000,0x00000000}},	//   ällv, ебля, --, --,
   {{0xf96a5d27,0x27e003e5,0x290f0124,0x78a25d28}},	//   орий_, _ħin_, _amga_, _scov,
   {{0x200d0682,0x68eb5d29,0x3da700ae,0x2fc053ca}},	//   _þeir_, _bogd, _окро_, lwig_,
   {{0xa3de030b,0x2bbf02d5,0x69340421,0xb4c8049d}},	//   णमा_, _शैवा, رکار, ईयो_,
   {{0x68eb5d2a,0x26c70283,0x7d025d2b,0x200400a7}},	//   _dogd, _bano_, mhos, _ümid_,
   {{0x7d02001f,0x752f00a5,0x395e5d2c,0x0b4300d3}},	//   lhos, wocz, _tuts_, _анун,
   {{0x248002dc,0x75d400e3,0x151500c2,0x8e9700ca}},	//   _beim_, ريحا, едня, ודיו_,
   {{0x7d025d2d,0x290f0124,0x2ebb0469,0x38cb33e7}},	//   nhos, _gmga_, _उस्त, _وانی_,
   {{0x26c75d2e,0x27e00511,0x752f0034,0x8afd00b6}},	//   _fano_, _çin_, rocz, _stři,
   {{0xf54a0028,0x26c738d0,0x2fc05d2f,0xe60f0688}},	//   _mấy_, _gano_, dwig_, اشی_,
   {{0xf54a0028,0x3946023e,0x752f00a5,0x7d020060}},	//   _lấy_, _khos_, pocz, khos,
   {{0xc1570129,0xd25807bf,0x6441013c,0x00000000}},	//   _ụgbọ, ьця_, əlin, --,
   {{0x26c702c9,0x7d023600,0xf54a0023,0x69dc0072}},	// [5590] _yano_, dhos, _nấy_, _áref,
   {{0xa3be0789,0xf3ff0161,0x8afd02c6,0x26c75d30}},	//   ीटर_, lcão_, _kuře, _xano_,
   {{0x6b8902e6,0x7d025d31,0xc7c800fe,0xe2a7003e}},	//   _sveg, fhos, _lố_, áður_,
   {{0xf54a0023,0x7d025d32,0xf3ff0131,0x00000000}},	//   _bấy_, ghos, ncão_, --,
   {{0x4fc400d3,0xf54a0023,0x3f9b00a7,0x6d4b0325}},	//   _исра, _cấy_, ququ_, rmga,
   {{0x290f005c,0x39460124,0x68eb5916,0xdb1b0037}},	//   _smga_, _ahos_, _sogd, _tsuí,
   {{0x7d025d33,0x394601ec,0x853d00c6,0xa96600e5}},	//   bhos, _bhos_, rtėj, нища_,
   {{0x26c75d34,0xc7c80028,0x6b895d35,0x673a0371}},	//   _sano_, _bố_, _tveg, eltj,
   {{0x26c75d36,0xc7c80028,0x3946022e,0x78bb0257}},	//   _pano_, _cố_, _dhos_, reuv,
   {{0x3ea10239,0xeab00037,0x6e2a0052,0x7cde020a}},	//   nght_, _نعم_, _ëmbë, _tărâ,
   {{0x3ea15d37,0x6d5a0257,0x2bc70d88,0x26c71b38}},	//   ight_, _état, लिका, _vano_,
   {{0xed59000d,0x673a0db1,0x64ca148e,0x26c70283}},	//   _již_, altj, ियेश, _wano_,
   {{0x394d5d38,0xdd0c0067,0x26c70010,0x248000b3}},	//   mmes_, _różn, _tano_, _veim_,
   {{0x394d5d39,0x0ece1179,0x273903a9,0x3f8901b9}},	//   lmes_, _होंड, kèni_, dsau_,
   {{0x7d025d3a,0x394d05fe,0x28a65d3b,0x69dc020d}},	//   yhos, omes_, क्कि, _àret,
   {{0x7d025d3c,0x273901dc,0x458200e5,0x40955d3d}},	//   xhos, dèni_, _сгъв, крут,
   {{0x14dd0592,0xc95200ca,0x1e963c75,0x291f39bd}},	// [55a0] यारण, רמן_, ерер, inua_,
   {{0x64440027,0x2fc014bd,0x394d5d3e,0xf8bd5d3f}},	//   _izii, rwig_, hmes_, ्युप,
   {{0x7d025d40,0x394d129d,0xf54a0023,0x2fc05d41}},	//   thos, kmes_, _sấy_, swig_,
   {{0xa6de00ef,0xfd660023,0x3ea101ff,0x69ce0072}},	//   _nhưn, _khuấ, aght_, _ábei,
   {{0x28c3000c,0x99bc0081,0x7d025d42,0x7afd00c6}},	//   वजनि, _অপেক, rhos, _įstr,
   {{0x7d025d43,0x6723020b,0x80a600b6,0x00000000}},	//   shos, _njnj, _छाडे, --,
   {{0xc7c800ef,0x7d025d44,0x39461ec5,0x21200a39}},	//   _số_, phos, _phos_, onih_,
   {{0x3cff007e,0x394d5d45,0xa6de0023,0x64440172}},	//   _gluv_, gmes_, _chưn, _ozii,
   {{0xf76f00cd,0xf77200e3,0x7d00007a,0x69dc007e}},	//   یای_, داع_, _ilms, _šred,
   {{0x09e626d0,0xbb531454,0x75242230,0x21200117}},	//   _позн, _منقب, _ajiz, hnih_,
   {{0xceb300a1,0x64440361,0xb9090174,0x00000000}},	//   אית_, _azii, nchọ_, --,
   {{0xc7c80019,0x28a75d46,0x3f890150,0x00000000}},	//   _tố_, _गायि, ysau_, --,
   {{0x258600b6,0xe0df009c,0x7643010a,0xf7f306cf}},	//   _bílá_, _bhòn_, _ezny, _مسود,
   {{0x7524181e,0xb9090134,0x69dc4466,0xf3ff0131}},	//   _ejiz, kchọ_, _àres, scão_,
   {{0x7d0000f9,0x69dc002b,0x64440172,0x21202a4e}},	//   _olms, _áred, _ezii, fnih_,
   {{0xa63b00ca,0xb4db015e,0xe63b00ca,0xd1382db3}},	//   _מגור, gmàt, _מתוכ, еху_,
   {{0x101700cd,0x273900bf,0xa9230146,0x691700ae}},	// [55b0] ربرد, wèni_, ížil, nţea,
   {{0x61e10149,0x3ea100a1,0x8e275d47,0x2d870161}},	//   älls, ught_, нфед, âneo_,
   {{0x2120011d,0x3f895d48,0x00000000,0x00000000}},	//   bnih_, ssau_, --, --,
   {{0x5ce45d49,0x62875d4a,0xa2d9521f,0x00000000}},	//   люча, lajo, माक्, --,
   {{0x60cd0256,0xfaa504fd,0x60dd0381,0xa2c60096}},	//   mdam, вало, _insm, ायच्,
   {{0x60cd5d4b,0x386910a4,0x60dd0167,0xe3b4006e}},	//   ldam, _żar_, _hnsm, רױס_,
   {{0x60cd013f,0x09e524c0,0x394d5d4c,0xf2d4006e}},	//   odam, тойн, tmes_, טעס_,
   {{0x60cd0fda,0x62875d4d,0x29045d4e,0x6f17037a}},	//   ndam, hajo, ghma_, lixc,
   {{0x394d5d4f,0xf7715d50,0x5ef806e4,0x20095d51}},	//   rmes_, جاب_, _एवम्_, nzai_,
   {{0x394d5d52,0x60cd5d53,0x62875d54,0x7c2902a1}},	//   smes_, hdam, jajo, _ixer,
   {{0x62875d55,0xe8df0134,0x7c3b0085,0x60cd0138}},	//   dajo, _agụm_, _hyur, kdam,
   {{0xc32900f5,0x290428f6,0x6d490332,0xdb1b01e9}},	//   _וו_, chma_, _jhea, _iruñ,
   {{0x6d4910f0,0x60cd5d56,0x68e90268,0x66080034}},	//   _mhea, ddam, mjed, azdk,
   {{0x68e95d57,0xe61112eb,0x60dd3383,0xa2d9063c}},	//   ljed, _پشت_, _ansm, माग्,
   {{0x5eca0081,0x6d4901c8,0xddc500d2,0x00000000}},	//   রামে, _ohea, dchů, --,
   {{0x60cd5d58,0x20095d59,0x7fd60565,0x75240d2a}},	//   gdam, fzai_, кізі, _ujiz,
   {{0x62872200,0x6563483c,0xb4db05fe,0x7c3b5d5a}},	// [55c0] bajo, _hunh, rmàt, _nyur,
   {{0x21200117,0x60cd2122,0x656300c2,0x6d4900d7}},	//   snih_, adam, _kunh, _ahea,
   {{0x6d49003b,0x65630396,0x68fb007a,0x7c290062}},	//   _bhea, _junh, kkud, _axer,
   {{0x6d495d5b,0x65635368,0x6d5b01b9,0x7c3b0169}},	//   _chea, _munh, _ciua, _byur,
   {{0x6d490a21,0x4e12000d,0xdca34c82,0x6d5b02e7}},	//   _dhea, _धेरै_, рачи, _diua,
   {{0x69ce007a,0xdb1b0143,0x7bc21183,0xb9090174}},	//   थिली, _bruñ, rwou, pchọ_,
   {{0x29045d5c,0x656322e7,0x6d4910f0,0xe567006f}},	//   thma_, _nunh, _fhea, _خط_,
   {{0x6d490514,0x68e9023b,0x6d5b009c,0x2004003e}},	//   _ghea, gjed, _giua, _ýmis_,
   {{0xaae2086d,0x7c3b0103,0x656301ff,0x6e3c02c3}},	//   पादक, _gyur, _aunh, _hyrb,
   {{0x81b90081,0x29042b58,0x6d5b00ae,0xcc120134}},	//   চিত_, shma_, _ziua, pọbị,
   {{0x65635d5d,0xdb1b5d5e,0x68e90292,0x60cd5d5f}},	//   _cunh, _usuá, bjed, ydam,
   {{0xdddc03ce,0x656322e7,0x26ca02dd,0x68e90ac3}},	//   _održ, _dunh, žbo_, cjed,
   {{0x656305dc,0x62875d60,0xd706078b,0x60cd5d61}},	//   _eunh, tajo, _изди, vdam,
   {{0xd5b000cd,0x691700ae,0x2d9a007e,0xb4db00b3}},	//   _هفت_, nţen, krpe_, gmàr,
   {{0xbbbf02d5,0x30a7097a,0x5bbf02d5,0x6563351f}},	//   _एन्क, крав, _एन्व, _gunh,
   {{0x62875d62,0x44295d63,0x6b8d02ef,0x60cd004b}},	//   sajo, _txa_, šagi, udam,
   {{0xbed90805,0x62875d64,0x14190037,0x6d5b015e}},	// [55d0] ндах_, pajo, _سيدة_, _riua,
   {{0x65635d65,0x20095d66,0xdf3900e3,0x60cd5d67}},	//   _yunh, rzai_, ركات_, sdam,
   {{0x6d490091,0x7c3b18c4,0x62855d68,0x24920150}},	//   _phea, _syur, _ieho, _ydym_,
   {{0x28a700aa,0xdd9401b3,0x6e3c5d69,0xada40120}},	//   _गाधि, рацы, _dyrb, раїл,
   {{0x68e90268,0x62855d6a,0xeab9008f,0x2d9a028d}},	//   vjed, _keho, ейл_, arpe_,
   {{0x62855d6b,0x93fc0341,0x63ad02a1,0x7c3b024a}},	//   _jeho, ולדי, _mqan, _vyur,
   {{0x3c9312eb,0x6285389a,0xdddc4c54,0x68e90dd9}},	//   _نیاز, _meho, _zdrž, tjed,
   {{0x62855d6c,0x6d5a0257,0x7c2901e9,0xdb021f20}},	//   _leho, _étap, _txer, rtoá,
   {{0x69c80472,0x7b9900cd,0x68fb5d6d,0x68e955bd}},	//   _esde, _سپاس_, rkud, rjed,
   {{0x68e90292,0x6285499e,0x65630161,0x68fb5d6e}},	//   sjed, _neho, _punh, skud,
   {{0x941e01d4,0x63ad5d6f,0xe0df01b9,0x00000000}},	//   ətə_, _aqan, _phòl_, --,
   {{0xf2c90105,0x97c5029e,0x5a0c00c1,0x7bc905aa}},	//   _מע_, _مقصو, _קלאַ, _kseu,
   {{0x62854e43,0x48e00034,0xe0df0023,0x644100a7}},	//   _beho, कारो_, _chòm_, əlik,
   {{0xe3634460,0xe5a55d70,0x69dc002b,0xddde0095}},	//   скри, _бики, _árec, hapš,
   {{0x021900d6,0x2c1a030b,0x62855d71,0xf53f1842}},	//   віть_, _मेनू_, _deho, blå_,
   {{0x386d5d72,0xe0df01b9,0xa2a805d6,0x00000000}},	//   ncer_, _cnò_, ञ्ज्, --,
   {{0x614300f6,0x63ad039f,0x00000000,0x00000000}},	// [55e0] сета, _gqan, --, --,
   {{0x62855d73,0x6d43020d,0x82364345,0x28da0861}},	//   _geho, înan, _مرجا, _मोनि,
   {{0x386d0085,0x00000000,0x00000000,0x00000000}},	//   kcer_, --, --, --,
   {{0x163600c1,0xa3c800b7,0x00000000,0x00000000}},	//   אנער_, _ईना_, --, --,
   {{0x925a00bf,0x6285405e,0xdddc0579,0xaff50018}},	//   _تشکر_, _yeho, _udrž, _پہلا_,
   {{0x69c808a8,0xbb830037,0x386d016d,0x6e3c5d74}},	//   _psde, حلوي, ecer_, _tyrb,
   {{0x14aa0096,0x5eca0033,0x7bc9020a,0x690701ff}},	//   _काढण, রাদে, _eseu, _oñed,
   {{0x29025d75,0xed5705cb,0xee370284,0x6b44015e}},	//   óka_, _бос_, _снс_, cògn,
   {{0x1d070084,0xb6a300fe,0x7bdd0231,0x99470076}},	//   _сети_, _tuầ, _àsup, دليل_,
   {{0x35b45d76,0x56940c37,0x00000000,0x00000000}},	//   абор, јант, --, --,
   {{0x62855d77,0xdbca007a,0xe8141e9f,0x64405d78}},	//   _reho, _võõr, _तेरा_, ümin,
   {{0x386d5d79,0x2ca611b9,0x6917002d,0x62855d7a}},	//   ccer_, ngod_, nţel, _seho,
   {{0x3eb80ebd,0x628505db,0xab0001cd,0x00000000}},	//   _obrt_, _peho, _þjóð_, --,
   {{0xf53f0073,0x59b80403,0x00000000,0x00000000}},	//   slå_, _आहार, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x161a0557,0x2eff020d,0xf4875d7b,0x6285246c}},	//   _फेयर_, _œuf_, _сукн, _weho,
   {{0x62855d7c,0x351c0796,0x3f1500c6,0xa295084c}},	// [55f0] _teho, _רוחנ, адас, _капі,
   {{0x6917044c,0x26ce01ee,0x00000000,0x00000000}},	//   eţel, _jafo_, --, --,
   {{0x8afc00a5,0xd2510281,0x00000000,0x00000000}},	//   _międ, _گنگ_, --, --,
   {{0x26ce5d7d,0x1c1600aa,0xed130033,0x00000000}},	//   _lafo_, _देहल_, িক্স_, --,
   {{0x6a85107a,0x2b5e009c,0x69de0120,0x4c8407bf}},	//   алла, _bitc_, åpen, слів,
   {{0x60cf5d7e,0x49950636,0x00000000,0x00000000}},	//   _hacm, ашит, --, --,
   {{0xa2ad030b,0x7e740018,0x3b06008f,0x5338006e}},	//   _जान्, _چاہئ, рещо_, אנגן_,
   {{0x386d01b9,0x2fd900e7,0x1c161006,0x60cf05aa}},	//   ucer_, _krsg_, _देवल_, _jacm,
   {{0x386d5d7f,0x60cf5d80,0x2f040149,0x26ce5d81}},	//   rcer_, _macm, _höga_, _bafo_,
   {{0xc987470d,0x386d001f,0x28a7030b,0x46f5002d}},	//   _буди, scer_, _गावि, рчит,
   {{0xa50a08c3,0x26ce5d82,0xe0df05aa,0x2fcb04e9}},	//   вена_, _dafo_, _chòk_, _lscg_,
   {{0x69dc0b0b,0x7dd00103,0xc8c80470,0x27e00a39}},	//   _área, lósá, _مومن_, _šine_,
   {{0x888c00c1,0xa6c95d83,0x66e55d84,0xdddc05db}},	//   _טראַ, _алла_, _вола, _merš,
   {{0x39ae00a7,0x26ce25bf,0x00000000,0x00000000}},	//   _səsi_, _gafo_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e10149,0x60262a33,0x6448013c,0x00000000}},	//   ålla, адба, ədin, --,
   {{0x8fa60b73,0x1e861b60,0x8e8600c2,0x853d00c6}},	// [5600] разе, илам, игае, rtėt,
   {{0xbe8500e3,0xb4db00b3,0xd0590120,0x2fcb00fc}},	//   مجمو, plàc, урсі_, _dscg_,
   {{0xe29b00ca,0x91e60b9e,0x729b00ca,0x61461ca7}},	//   _בשיר, _тоне, _בסיס, _вена,
   {{0x8fa621bf,0xdddc00e7,0x60cf0188,0x00000000}},	//   _каме, _cerš, _gacm, --,
   {{0xaae2000d,0x2ca63e7f,0x691700ae,0x00000000}},	//   पालक, rgod_, rţel, --,
   {{0x60c45d85,0x2ca600f0,0x99d60037,0x81b90a43}},	//   leim, sgod_, لتعا, চির_,
   {{0x79450067,0x2ca600f9,0x00000000,0x00000000}},	//   równ, pgod_, --, --,
   {{0x60c4050e,0xdca31a19,0xdddc007e,0x940c00a7}},	//   neim, _маси, _gerš, şdə_,
   {{0x28bd0789,0xfaa60b9e,0x26ce0172,0x082a00e5}},	//   ्यजि, _вазо, _pafo_, ъцки_,
   {{0x60c45d86,0x6d425d87,0xd6da1cda,0x29e50d2a}},	//   heim, lloa, тти_, rɓar_,
   {{0x3ed900c1,0x4ed9006e,0x60c45d88,0xa3a90096}},	//   אַרא, אַרנ, keim, खून_,
   {{0x60c45d89,0x69da0a00,0x2509001c,0x61fc13ea}},	//   jeim, _irte, اردی_, dyrl,
   {{0x442d023b,0x60c42148,0x2906007b,0x60cf05db}},	//   çe_, deim, _iloa_, _racm,
   {{0x81c30b4b,0x28b40034,0x65660291,0x28da2fc2}},	//   ņēmu, ंभवि, _књиж, _मोति,
   {{0x60cf22d4,0x6d420634,0x28bd28fb,0xdbd1003e}},	//   _pacm, kloa, ्यचि, _lýðr,
   {{0x6d4200d3,0x69da0147,0x3cf500aa,0x00000000}},	//   jloa, _mrte, _आवें_, --,
   {{0xa15814e8,0x6d420062,0x6e670392,0x00000000}},	// [5610] рату_, dloa, атеж, --,
   {{0x69da5d8a,0xa85700ca,0x2906015e,0xc43c00ca}},	//   _orte, שימה_, _lloa_, _בתחי,
   {{0x28a70455,0x23695d8b,0xdceb2a6c,0xdddc5d8c}},	//   _गालि, _huaj_, šiči, _perš,
   {{0x2369006c,0xfd100d59,0x68e401ec,0x00000000}},	//   _kuaj_, وجن_, _òidh, --,
   {{0x69da1075,0x236900dd,0xee870084,0x248900ee}},	//   _arte, _juaj_, _выбо, _meam_,
   {{0x23691071,0x68e20150,0x8d7709b4,0x248901b5}},	//   _muaj_, _anod, _نارا, _leam_,
   {{0x23690197,0xa3a939d4,0x6ef3030b,0x69da01ac}},	//   _luaj_, खंड_, _výbě, _crte,
   {{0x77855d8d,0x2489044c,0x6d34002d,0xa7d50076}},	//   близ, _neam_, _десф, متخص,
   {{0x69da5d8e,0x23690154,0xe0df00fe,0x00000000}},	//   _erte, _nuaj_, _chòi_, --,
   {{0x68e25d8f,0xb33b0072,0xd70600c2,0x7bdb5d90}},	//   _enod, duço, йные_, _iruu,
   {{0x24890fa7,0x00000000,0x00000000,0x00000000}},	//   _beam_, --, --, --,
   {{0x7bdb2a94,0xb0d608c0,0x2fc902ac,0x00000000}},	//   _kruu, _ढोंग, kwag_, --,
   {{0x387f4985,0x2369022e,0xb4c800a5,0x78a90371}},	//   mbur_, _cuaj_, _उसी_, mgev,
   {{0x23695d91,0x78a95d92,0xa2ad009d,0x644800a7}},	//   _duaj_, lgev, _जाण्, ədil,
   {{0x26c55d93,0x6d42019c,0x00000000,0x00000000}},	//   melo_, yloa, --, --,
   {{0x26c50060,0x2369023e,0x24895d94,0x25a55d95}},	//   lelo_, _fuaj_, _geam_, mull_,
   {{0x60c45d96,0x93960286,0x2fc902ac,0x00000000}},	// [5620] reim, _اجبا, gwag_, --,
   {{0x26c50060,0xb33b01e8,0x6d42020b,0xb4db015e}},	//   nelo_, nuçl, wloa, nlàn,
   {{0x628e5d97,0x25a50a9a,0x236901fa,0xa2ad1388}},	//   mabo, null_, _zuaj_, _जात्,
   {{0x26c50201,0xfd4d0294,0x236901fa,0x2fc90009}},	//   helo_, _ichọ, _yuaj_, bwag_,
   {{0x26c50060,0x2369023e,0x78a91570,0x25a55d98}},	//   kelo_, _xuaj_, dgev, hull_,
   {{0x26c50292,0x628e5d99,0x25a55d9a,0x68e25d9b}},	//   jelo_, nabo, kull_, _snod,
   {{0x7bdb083e,0x78a90b8e,0x00000000,0x00000000}},	//   _eruu, fgev, --, --,
   {{0x628e5d9c,0x78a95d9d,0xa77405e1,0x69da0087}},	//   habo, ggev, олич, _vrte,
   {{0x628e5d9e,0x7d025d9f,0x7bdb5da0,0x3f920072}},	//   kabo, mkos, _gruu, nsyu_,
   {{0x23695da1,0x63a6063f,0x26c55da2,0x25a55da3}},	//   _ruaj_, dukn, gelo_, full_,
   {{0xd6d70fdf,0x69da03f3,0x628e5da4,0xfd4d0129}},	//   сты_, _urte, dabo, _nchọ,
   {{0x7d025da5,0x236901fa,0x07a61d62,0x387f07e7}},	//   nkos, _puaj_, _гадн, cbur_,
   {{0x26c55da6,0x2369006c,0x14aa1fb4,0xfd4d00ac}},	//   belo_, _quaj_, _कारण, _achọ,
   {{0x26c55da7,0x628e5da8,0x25a55da9,0x7d0208ac}},	//   celo_, gabo, bull_, hkos,
   {{0x25a505fe,0x24894b72,0x7d025daa,0x41e4084c}},	//   cull_, _team_, kkos, піта,
   {{0x23690d7d,0x673a05fe,0x63a6483d,0x628e0eac}},	//   _tuaj_, lotj, bukn, aabo,
   {{0x752d06e1,0x628e2e60,0x63a60063,0x2ef50284}},	// [5630] _ijaz, babo, cukn, озар,
   {{0x7d02057a,0x2fc90185,0x628e5dab,0x644d5dac}},	//   ekos, rwag_, cabo, _izai,
   {{0x2fc95dad,0x7d0218f0,0x00000000,0x00000000}},	//   swag_, fkos, --, --,
   {{0x30a70084,0x26c50201,0x7d025dae,0x7bdb00aa}},	//   _уров, zelo_, gkos, _pruu,
   {{0x752d0350,0x25a50216,0x00000000,0x00000000}},	//   _mjaz, zull_, --, --,
   {{0x386602ad,0x49992dfb,0xe0df022b,0x26c55daf}},	//   _agor_, атия_, _chòv_, xelo_,
   {{0x78a9043e,0x1986008f,0x28da0296,0x98be0233}},	//   tgev, общи_, _मोहि, _attı_,
   {{0xb4c80067,0x628e5db0,0xe8f90b1e,0x14d9009d}},	//   _उसे_, zabo, рли_, _बोलण,
   {{0x78a90ab2,0x7d1b5db1,0x26c555bc,0x7d090139}},	//   rgev, _imus, telo_, _iles,
   {{0x80d200c7,0x78a904e2,0x25a5023b,0x212900dc}},	//   হায্, sgev, tull_, hnah_,
   {{0x8afc0d1b,0x7d095db2,0xe4c613dc,0x628e5db3}},	//   _więc, _kles, ойни, vabo,
   {{0x63a602e7,0x25a55db4,0x21295db5,0x628e5db6}},	//   tukn, rull_, jnah_, wabo,
   {{0x80d200c7,0x26c55db7,0xa34a5db8,0x752d02f1}},	//   হাম্, pelo_, изма_, _djaz,
   {{0x27ff5db9,0x63a65dba,0x7d095dbb,0x25a5023b}},	//   myun_, rukn, _lles, pull_,
   {{0x628e5dbc,0x7d1b0a15,0x63a6100b,0x27ff5dbd}},	//   rabo, _omus, sukn, lyun_,
   {{0xb146116d,0xa06702b3,0xdfd20d59,0x7945007f}},	//   інал, жата_, ويز_, dówk,
   {{0xef1a5dbe,0x628e5dbf,0x09a605d6,0xe29a1828}},	// [5640] ама_, pabo, _गम्य, _кап_,
   {{0x69c15dc0,0x7d095dc1,0x27ed0472,0x752d5dc2}},	//   _ople, _ales, ixen_, _zjaz,
   {{0x6f1e5dc3,0x27ff5dc4,0x69c1022e,0x7d025dc5}},	//   ripc, hyun_, _nple, tkos,
   {{0xf7671f0b,0x0eac009d,0xdd8f0dce,0x76430150}},	//   _يا_, _चावड, ئون_, _myny,
   {{0x6b440472,0x60d6013f,0x69c15dc6,0x764305ff}},	//   lògi, mdym, _aple, _lyny,
   {{0x7d095dc7,0x60d6013f,0x7d1b5dc8,0x69c10076}},	//   _eles, ldym, _emus, _bple,
   {{0xa2ad02e8,0xd90d110a,0xf98f00ab,0xe90a00ae}},	//   _जास्, گین_, نبي_, ихик_,
   {{0xd7c800bf,0xdcfc0039,0x60d60138,0x656400c2}},	//   موعه_, _tvrđ, ndym, _niih,
   {{0xd90d037f,0xb81d09c3,0x27ff00f9,0x69c10120}},	//   دین_, _बेदम_, gyun_, _eple,
   {{0x21295dc9,0x28da00df,0x7d1b007f,0x2ef8014b}},	//   znah_, _मोरि, _zmus, _jorf_,
   {{0x673a5dca,0x76430150,0x64445dcb,0x6564010a}},	//   rotj, _cyny, _ayii, _biih,
   {{0x290d5dcc,0xe9ff00de,0x1c1f0034,0xa2ad02d5}},	//   chea_, _hiếm_, _मेडल_, _जाह्,
   {{0xe9ff0028,0x8d5b00c1,0x7763002b,0x64444c93}},	//   _kiếm_, יכטי, _finx, _cyii,
   {{0x9943026a,0x764300f0,0x356a00ae,0x00000000}},	//   _kış_, _fyny, _крин_, --,
   {{0x32052299,0x21290991,0x76435dcd,0x6b440428}},	//   ály_, tnah_, _gyny, gògi,
   {{0xf8bc06ed,0x69a202d5,0x752d5dce,0xe9ff0023}},	//   ्जिय, _गिनी, _ujaz, _liếm_,
   {{0x212903b4,0xc05b02ec,0x3f8700e7,0x320502c6}},	// [5650] rnah_, рів_, ćnuo_, šly_,
   {{0x21292fc5,0x77635dcf,0x79450034,0x6d405dd0}},	//   snah_, _xinx, tówk, _akma,
   {{0x2d875dd1,0xe0df01f7,0x2ef85dd2,0x00000000}},	//   ène_, _bhòt_, _dorf_, --,
   {{0x27ff0913,0x753d2214,0x79450034,0xe0df009c}},	//   yyun_, nosz, rówk, _chòt_,
   {{0x35cc0251,0x69c15dd3,0x999e00b6,0xe9ff00fe}},	//   ़बड़, _sple, _bytů_, _biếm_,
   {{0x794500a5,0xeb960d97,0x6d4007ee,0xa9692a59}},	//   mówi, чиш_, _ekma, бика_,
   {{0x290d51c6,0x7d095dd4,0x753d3e15,0x00000000}},	//   thea_, _tles, kosz, --,
   {{0x6ca45dd5,0x7d1b5dd6,0x77635dd7,0x25de0179}},	//   _оруж, _umus, _sinx, गिनी_,
   {{0xf8ae0281,0x5b1500ae,0x776300b3,0x6564007b}},	//   اکم_, _емат, _pinx, _riih,
   {{0x65640084,0x6b890134,0xdce700e7,0xd70900c2}},	//   _siih, _iweg, _mujč, сное_,
   {{0x27ff00f9,0x00000000,0x00000000,0x00000000}},	//   syun_, --, --, --,
   {{0x753d0018,0x6b890595,0x9cf90033,0x6444010a}},	//   gosz, _kweg, _আগুন_, _pyii,
   {{0x43750f30,0x65640084,0x6b890090,0x77635dd8}},	//   дуст, _viih, _jweg, _tinx,
   {{0xe6890037,0x6b893683,0xd066013c,0xb7da00d7}},	//   _انثى_, _mweg, əqəl, _לקני,
   {{0x67215dd9,0xcaf40096,0x6b892673,0x753d3e11}},	//   milj, _अवघड_, _lweg, bosz,
   {{0x6f1c0580,0x67212fe3,0x00000000,0x00000000}},	//   _smrc, lilj, --, --,
   {{0x6b8900ac,0x60d62a7a,0x4426016d,0x6d4000c4}},	// [5660] _nweg, rdym, _ão_, _rkma,
   {{0xe0df022b,0x21200167,0x9f5f01cd,0x20000350}},	//   _akòd_, siih_, órða_, ryii_,
   {{0x02fb0327,0x6b890172,0x291d010a,0x42fb00ca}},	//   _הלימ, _aweg, _omwa_, _ההיס,
   {{0xccf900a5,0x61e101c5,0xc8da5dda,0x656e0037}},	//   _coś_, ælle, _मोंट, íbhi,
   {{0xead41c32,0x1c160006,0x67215ddb,0x2ef8030a}},	//   доль, _देखल_, kilj, _torf_,
   {{0x6721042d,0x291d0154,0x6d590172,0xdb09009c}},	//   jilj, _amwa_, amwa, _speò,
   {{0x6721005f,0x6b890294,0xe81402d5,0x99d30037}},	//   dilj, _eweg, _तेजा_, فتيا,
   {{0x8b6600b1,0xdc3c1054,0x97a605da,0x2d98014b}},	//   _فاطم, _háčk, прол, _ivre_,
   {{0x67215ddc,0x68f900ec,0xed575ddd,0x6b895dde}},	//   filj, _dowd, _хот_, _gweg,
   {{0x9f9b0364,0x6601004d,0x95ca5ddf,0x00000000}},	//   _läßt_, fylk, бума_, --,
   {{0x7ae80021,0xe9470018,0xe5352458,0xd90f01b3}},	//   _indt, _کرلی, день, _зь_,
   {{0x76a20065,0x7afa0d4b,0x29021ee2,0x68f901ee}},	//   _bíyà, _hott, ökad_, _gowd,
   {{0x672103ce,0x753d07ff,0x66e62012,0xe73a182e}},	//   bilj, rosz, _нода, _лед_,
   {{0x7afa0084,0x660100d4,0x2d980537,0x23650ee2}},	//   _jott, bylk, _ovre_, ölj_,
   {{0x31c40f16,0x2d9c0396,0x7afa5de0,0x76bb00a1}},	//   нств, ável_, _mott, _המופ,
   {{0x7afa0d63,0x76a20139,0xd5b800e8,0x00000000}},	//   _lott, _fíyà, mtā_, --,
   {{0x88bd0034,0xd5b801d3,0x403400c2,0x9f040281}},	// [5670] liśc, ltā_, еетс, کولو,
   {{0x7afa013d,0x6b89023f,0x42755de1,0xdce70234}},	//   _nott, _rweg, _югос, _vujč,
   {{0xd5b800d9,0x6b89007f,0x6441173c,0x00000000}},	//   ntā_, _sweg, şlid, --,
   {{0xd5b801d3,0x00000000,0x00000000,0x00000000}},	//   itā_, --, --, --,
   {{0x7afa5de2,0x2d985de3,0xbfa800ae,0x00000000}},	//   _bott, _evre_, _нтре_, --,
   {{0xd5b800d9,0x7afa0a5f,0xaa880076,0x00000000}},	//   ktā_, _cott, كنهم_, --,
   {{0x7afa5de4,0x2d98010a,0x9e3400d3,0x68f92ab4}},	//   _dott, _gvre_, _зерч, _powd,
   {{0x7ae8038c,0x6b895de5,0x2cbf0085,0xa3cd009f}},	//   _endt, _tweg, _ubud_, रबा_,
   {{0x6721042d,0x3cf00146,0x2d815de6,0x2d9e0149}},	//   tilj, ťové_, lphe_, _åter_,
   {{0x667300cd,0xd7560103,0x1dd109c4,0x00000000}},	//   رگتر, وليت_, _सनात, --,
   {{0x64a60fb0,0xe81d00aa,0xcb1200ca,0x00000000}},	//   мана, _बेरा_, _שלב_, --,
   {{0x7afa18ef,0x92ea0033,0x291d0027,0x00000000}},	//   _zott, _মতে_, _umwa_, --,
   {{0x69d50179,0x00000000,0x00000000,0x00000000}},	//   भिकी, --, --, --,
   {{0x2bc00ed3,0x88bd0034,0xf62500f6,0x00000000}},	//   _एहसा, biśc, _одло, --,
   {{0x61460f7e,0xc7b90103,0x443e007f,0xdce05de7}},	//   дева, ltő_, łt_, _simč,
   {{0xdb025de8,0xdc3c1054,0x70a80096,0x2d9c00d2}},	//   troë, _sáčk, गलेल, ávem_,
   {{0xc7b90018,0x1f66141b,0x4aae0096,0xdc3c0094}},	// [5680] ntő_, дкам, _घालव, _páčk,
   {{0x2bd4009f,0x3f8000c6,0x253b0294,0x8fa33168}},	//   _धनबा, rpiu_, ụntụ_, тафе,
   {{0x7afa5de9,0xdd8f0c5e,0xa06a0360,0x82360018}},	//   _rott, لول_, _мана_, _زردا,
   {{0x0c260d64,0x7afa5a3d,0xb80d0ff9,0x69dc003e}},	//   ммен, _sott, िनाम_, _árei,
   {{0xe7d80081,0x28a70034,0xe81d0cd5,0x7afa5dea}},	//   _তথ্য, _गाजि, _बेला_, _pott,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d6801e8,0x7afa056e,0xb4db00ee,0x2d98014b}},	//   _eğer_, _vott, noàc, _uvre_,
   {{0x92ea00c7,0xa02201e8,0xa3a90179,0xf1b300ca}},	//   _মতো_, _şöyl, खूँ_, דסה_,
   {{0x629e12fb,0xb8d603a2,0x7afa0084,0x88bd00a5}},	//   _odpo, _जा_, _tott, wiśc,
   {{0x35f408c3,0x7ae8052f,0xa3cd058f,0x98c300e8}},	//   епор, _undt, रबस_, īvās_,
   {{0xda650037,0x2aeb00a8,0x00000000,0x00000000}},	//   _كامي, चारु_, --, --,
   {{0xd5b800d9,0xa8061e23,0x2eea0231,0x63a61726}},	//   rtā_, _озел, _lnbf_, frkn,
   {{0xd5b80029,0x00000000,0x00000000,0x00000000}},	//   stā_, --, --, --,
   {{0x17540bb9,0x65942b94,0xd703008f,0x6b8209ac}},	//   _явля, _заку, _изчи, ipog,
   {{0x26cc5deb,0x399a00e8,0x2caf09a8,0x00000000}},	//   medo_, nīs_, yggd_, --,
   {{0x6ec1000d,0xa2bf0789,0x6907037a,0x00000000}},	//   र्नु, _लॉर्, _añej, --,
   {{0x6b820087,0x00000000,0x00000000,0x00000000}},	// [5690] jpog, --, --, --,
   {{0x26cc002b,0x3ed50037,0x6b8217a0,0x00000000}},	//   nedo_, عقار, dpog, --,
   {{0x709513a4,0xaad943e2,0xdb02014b,0x00000000}},	//   _панф, _योगक, croé, --,
   {{0xa3d60ccb,0x399a01d3,0x26cc0294,0x2d81014b}},	//   _सनम_, dīs_, hedo_, rphe_,
   {{0x50642ca3,0x60cd5dec,0x3f79006e,0xf09f0065}},	//   _атра, meam, _מאָס, _idà_,
   {{0x6295068d,0x60cd0a1b,0x26cc0783,0x2cbd01ff}},	//   nazo, leam, jedo_, sfwd_,
   {{0x8d7407e8,0x00000000,0x00000000,0x00000000}},	//   _لاقا, --, --, --,
   {{0x60cd5ded,0xc7b90103,0x62955dee,0x7b1400b3}},	//   neam, ttő_, hazo, _nàuf,
   {{0x62955def,0x7d0400c2,0x20040233,0x00000000}},	//   kazo, öise, _ümit_, --,
   {{0x6d4b5df0,0x60cd0a1b,0x6b9b0193,0x45853051}},	//   llga, heam, _ivug, нгов,
   {{0x629548f4,0x6ec100e2,0x60cd007b,0x00000000}},	//   dazo, र्यु, keam, --,
   {{0x17fb0037,0x29d10234,0x00000000,0x00000000}},	//   _ورشة_, _iša_, --, --,
   {{0xe72e078b,0x60cd5df1,0xe3b20391,0x26cc0143}},	//   _бе_, deam, درج_, bedo_,
   {{0x6ec10f8f,0x6b9b02a4,0x2d9c02c6,0x62955df2}},	//   र्मु, _mvug, ávek_, gazo,
   {{0xa18a0465,0xa50a3574,0x68eb0113,0x60cd00b3}},	//   ябва_, _нека_, _kngd, feam,
   {{0x61e101c5,0x644101bf,0x60cd5df3,0x6b9b010a}},	//   ælla, ßlic, geam, _ovug,
   {{0x8fa3455b,0xb4cc009d,0x4fa34a4e,0x62955df4}},	// [56a0] лате, रजी_, литв, bazo,
   {{0x62955df5,0x27e005db,0x00000000,0x00000000}},	//   cazo, _šink_, --, --,
   {{0x6b9b023f,0x60cd5df6,0xdcf40335,0x7bde01d3}},	//   _avug, beam, šači, āpum,
   {{0xe57200c1,0xc8ae00c0,0x60cd036b,0x00000000}},	//   אַס_, _टाइट, ceam, --,
   {{0x26cc037a,0x00000000,0x00000000,0x00000000}},	//   yedo_, --, --, --,
   {{0x399a00d9,0x68eb2375,0x290f5df7,0x6d4b5df8}},	//   tīs_, _angd, _alga_, alga,
   {{0x99660d9b,0xdca6430b,0x6b9b0172,0x13c90033}},	//   нтил, _пави, _evug, শিয়,
   {{0xa9675df9,0x290f01b9,0xdb025dfa,0xdcfe01d3}},	//   нија_, _clga_, croî, rspē,
   {{0x26cc5dfb,0x399a01d3,0x2f260139,0x752601ff}},	//   tedo_, sīs_, _gígè_, dikz,
   {{0xb33b026a,0x8afc0034,0x290f078e,0x00000000}},	//   nuçt, _mięk, _elga_, --,
   {{0x26cc23fa,0x62955dfc,0x60cd0239,0x1a9b006e}},	//   redo_, vazo, yeam, _זיבע,
   {{0x26cc5dfd,0x2ca00037,0xa3cd5dfe,0x62950a3d}},	//   sedo_, óidh_, रबल_, wazo,
   {{0x62955dff,0x04670084,0xdceb0335,0xd4980d4f}},	//   tazo, этом, šići, эрэ_,
   {{0x6d4200bc,0xdc12013c,0x00000000,0x00000000}},	//   hooa, nğıc, --, --,
   {{0x623400ae,0xdb025e00,0x6d4201ff,0x00000000}},	//   геру, ntoñ, kooa, --,
   {{0x62955e01,0xdddc004b,0x00000000,0x00000000}},	//   sazo, _berž, --, --,
   {{0x62950933,0x60cd4f4e,0xf8c205d6,0xbfa800ae}},	// [56b0] pazo, ream, व्यय, етхе_,
   {{0x60cd5e02,0x6d4b008a,0x63af0580,0x69c85e03}},	//   seam, wlga, mucn, _opde,
   {{0x6b9b04a3,0x63bd594c,0x60cd5e04,0x776a0090}},	//   _svug, ltsn, peam, _mifx,
   {{0x394601fa,0xeb090f8f,0x764a0150,0xc0ab0037}},	//   _nkos_, वस्त_, _myfy, _عاجل_,
   {{0x4ea7016c,0x69c85e05,0x00000000,0x00000000}},	//   _прва, _apde, --, --,
   {{0xfe70012b,0x9f3500d6,0x4ea700a9,0xaa495e06}},	//   _هدف_, _регі, _ярма, мпла_,
   {{0x9f3400d6,0xae1e009d,0x6b440428,0x8f3400d6}},	//   _сері, _येऊन_, tògr, _серц,
   {{0x69a21efb,0x22450a7f,0x63bd2452,0x00000000}},	//   _गिरी, ýlky_, ktsn, --,
   {{0x6b9b0193,0x69c8037a,0x00000000,0x00000000}},	//   _uvug, _epde, --, --,
   {{0xb8e80789,0x55e541c3,0xa2ad077d,0x39460131}},	//   _लॉ_, вооб, _जाग्, _ekos_,
   {{0x290f06a8,0x764a0150,0x2701009f,0x6b4400b3}},	//   _tlga_, _cyfy, _लकीर_, pògr,
   {{0xb4ac5e07,0x68eb1bfa,0x2f040149,0x2d4720df}},	//   खले_, _ungd, _högt_, mões_,
   {{0x63af04a3,0x2d470161,0x394d4a9b,0x395f49ac}},	//   gucn, lões_, mles_, mmus_,
   {{0x394d5e08,0x395f5e09,0x764a00f0,0x5fe000b6}},	//   lles_, lmus_, _fyfy, निसल,
   {{0x320c025b,0x63bd029a,0x764a00f0,0x00000000}},	//   ády_, atsn, _gyfy, --,
   {{0x25de007d,0xdddc013f,0x8afc00a5,0x394d03be}},	//   गिरी_, _perž, _pięk, nles_,
   {{0x394d0257,0x75245e0a,0x2d47016d,0x00000000}},	// [56c0] iles_, _imiz, hões_, --,
   {{0x395f2169,0xdddc5e0b,0x00000000,0x00000000}},	//   hmus_, _verž, --, --,
   {{0x8afc00a5,0xb4e60032,0xe0df022b,0x2d9c01f9}},	//   _więk, _gbàá, _ikòn_, éve_,
   {{0x6da35e0c,0x63a91e4d,0x2d47016d,0xdca60231}},	//   рица, šene, dões_, тади,
   {{0x2f040088,0xdd0c0034,0x75240172,0x20561231}},	//   _sögu_, _półn, _mmiz, _штор,
   {{0x394d0bfe,0xf9c60938,0x69c803be,0x394600f1}},	//   eles_, вщин, _ppde, _skos_,
   {{0x2d47016d,0x6c860076,0x00000000,0x00000000}},	//   gões_, _للأم, --, --,
   {{0x395f04de,0x3cff2676,0x31600154,0xa2a211c7}},	//   gmus_, _gouv_, nmiz_, कृत्,
   {{0xab665e0d,0x00000000,0x00000000,0x00000000}},	//   _авал, --, --, --,
   {{0x394d5e0e,0x75245e0f,0x7d002988,0x9bb70266}},	//   ales_, _amiz, _homs, _בהמה_,
   {{0x394d4768,0xceb300a1,0xd6d70450,0x395f023e}},	//   bles_, בית_, тты_, bmus_,
   {{0x394d5e10,0x98a30aec,0x752400c4,0xdcfc0559}},	//   cles_, _вице, _cmiz, _otrč,
   {{0x693100cd,0x7d005e11,0x39440138,0x27e000f3}},	//   _دکور, _moms, moms_, _éin_,
   {{0x63af04a3,0x75245784,0x63bd2864,0x27e65e12}},	//   rucn, _emiz, rtsn, _iron_,
   {{0x575700a1,0x67285e13,0x6456010a,0x4ac4077d}},	//   _שבוע_, midj, _ezyi, ल्यव,
   {{0x26dc01c0,0x39445e14,0x2bf30096,0x7d00019f}},	//   _havo_, noms_, _आपलं_, _noms,
   {{0x26dc5e15,0x2d470161,0x27e60113,0x93470076}},	// [56d0] _kavo_, zões_, _jron_, _لخدم,
   {{0x3f145e16,0x3f9b53df,0x395f1e14,0x75241054}},	//   адус, rsqu_, zmus_, _zmiz,
   {{0x8d741629,0x7bc95e17,0x39445e18,0x2d47001f}},	//   لانا, _speu, koms_, xões_,
   {{0x39442c2e,0x26dc5ae9,0x656d096f,0x644d0113}},	//   joms_, _lavo_, _jiah, _kyai,
   {{0x21290484,0x7d000f05,0x351c0341,0x39445e19}},	//   miah_, _doms, וואנ, doms_,
   {{0x21290496,0x2d47001f,0xf1c7009d,0x78a200b3}},	//   liah_, tões_, _लहान, _adov,
   {{0x27e62a78,0x60dd5e1a,0x395f15bf,0x394d5e1b}},	//   _aron_, _kasm, tmus_, tles_,
   {{0x27e65e1c,0x21295e1d,0x2d47016d,0x394d5e1e}},	//   _bron_, niah_, rões_, ules_,
   {{0x200903b4,0x60dd5e1f,0x2d47001f,0x27e601b9}},	//   nyai_, _masm, sões_, _cron_,
   {{0x26dc008f,0x60dd5e20,0x212902fa,0x394d5e21}},	//   _cavo_, _lasm, hiah_, sles_,
   {{0x88bd00a5,0x6d5b5e22,0x212900dc,0x316011bc}},	//   liśm, _khua, kiah_, ymiz_,
   {{0x644d010a,0x394424f9,0x27e65e23,0x81cc0033}},	//   _byai, coms_, _fron_, লিম_,
   {{0x21290496,0xef280491,0x787a006e,0x27e600eb}},	//   diah_, lmüş_, _אָוו, _gron_,
   {{0x6d5b023e,0x68fb257f,0x26dc0138,0x6b4d0131}},	//   _lhua, ljud, _gavo_, fúgi,
   {{0x6d495e24,0x717633c6,0x212923b0,0x60dd5e25}},	//   _okea, اهرا, fiah_, _basm,
   {{0xdd000029,0x656d49e7,0xdddc003d,0x60dd2a7d}},	//   ītīb, _giah, _verż, _casm,
   {{0x2d8300dd,0xa2ac074c,0x2f16052f,0x7d0000f3}},	// [56e0] _atje_, _जयप्, _læge_, _roms,
   {{0x6d5b5e26,0x7d005e27,0x63a93b84,0xf0635e28}},	//   _ahua, _soms, šenc, скуп,
   {{0x6d5b10f0,0x2009048e,0x212902e7,0x290d00c2}},	//   _bhua, ayai_, biah_, kkea_,
   {{0x6d5b0514,0x67282024,0x68fb083e,0x69ba097c}},	//   _chua, zidj, jjud, _एमबी,
   {{0x6d5b4f67,0x5b2601b3,0xac9700b9,0xdcfc09ac}},	//   _dhua, лька, انها_, _utrč,
   {{0x9e66001c,0xe4570266,0x6d5b0231,0xeef600d3}},	//   _مازن, ניסט_, _ehua, _сямэ,
   {{0x672808a9,0x6d5b0013,0x2fc01683,0x39444c3c}},	//   vidj, _fhua, ltig_, toms_,
   {{0x26dc08a1,0x6d5b0a02,0x60c40383,0x6d4901ff}},	//   _savo_, _ghua, nfim, _gkea,
   {{0x2fc05e29,0x39445e2a,0x78a21b32,0x320a0094}},	//   ntig_, roms_, _vdov, hyby_,
   {{0x2fc002e2,0x6d5b03e3,0x59dc030b,0x21295e2b}},	//   itig_, _zhua, _मनपर, ziah_,
   {{0x68fb0222,0x644d1bd6,0x644101d4,0xceb300a1}},	//   bjud, _syai, əliy, זית_,
   {{0x69da5d7e,0x2ed122f1,0x27e65e2c,0x2fc02452}},	//   _iste, _हस्त, _tron_, ktig_,
   {{0x60dd5e2d,0x26dc013f,0x2fc0029a,0x27e60052}},	//   _rasm, _tavo_, jtig_, _uron_,
   {{0xe81d0da9,0x60dd5e2e,0x59b8086d,0x3dc60034}},	//   _बेटा_, _sasm, _इमार, łowy_,
   {{0x2129005c,0x2fc0057a,0x60c432a7,0x656d1206}},	//   tiah_, etig_, ffim, _tiah,
   {{0x2fc000f2,0x70af0096,0xdbd100aa,0xdb0b0537}},	//   ftig_, टलेल, _püüa, stgø,
   {{0x2fc05e2f,0x2129048e,0x200f0018,0x6d5b006c}},	// [56f0] gtig_, riah_, ági_, _rhua,
   {{0x69da3d20,0x6d5b5e30,0x60dd3584,0xf09f0013}},	//   _oste, _shua, _wasm, _clàr_,
   {{0x60dd5e31,0x21290096,0x5c75554c,0x69da0090}},	//   _tasm, piah_, алет, _nste,
   {{0x6d5b0197,0x212900dc,0x60dd0076,0x00000000}},	//   _qhua, qiah_, _uasm, --,
   {{0xc0580565,0x69da4078,0xec780120,0x2ba70284}},	//   _бір_, _aste, упі_, ујев,
   {{0x3f895e32,0x6d5b01dc,0x4aa628b0,0x00000000}},	//   mpau_, _whua, акшн_, --,
   {{0x6d5b5e33,0xd2b800a1,0xf2d4006e,0x1dc900bc}},	//   _thua, אלות_, מעס_, _रहित,
   {{0x629700dd,0x2be20442,0x7c3b0634,0xb90500ae}},	//   _lexo, पिशा, _txur, рзик,
   {{0xe8f6065c,0x290d1d77,0xf71901b3,0xf6f30103}},	//   рлы_, rkea_, віны_, مزدگ,
   {{0x81cc0081,0x62972ad4,0xd70900c2,0x290d5e34}},	//   লিত_, _nexo, тное_, skea_,
   {{0xdce95e35,0x28c20096,0x00000000,0x00000000}},	//   _lieč, व्हि, --, --,
   {{0xb9120134,0x2b470095,0x00000000,0x00000000}},	//   _mgbọ_, lonc_, --, --,
   {{0xdce90181,0xd456013d,0x9cd600a1,0xdb1b09d3}},	//   _nieč, ртнь, בורה_, _aqué,
   {{0x69da5e36,0x26c7022e,0x00000000,0x00000000}},	//   _yste, _ubno_, --, --,
   {{0x40962249,0xe29757a3,0x395d022e,0xa2a20f82}},	//   ират, рас_, _khws_, कृष्,
   {{0x2fc04c28,0x387f0991,0x7bdb5e37,0x63a90995}},	//   ttig_, ncur_, _osuu, šena,
   {{0x06d800c7,0xb9120174,0x21672c3b,0x60c45e38}},	// [5700] তারি, _agbọ_, рити_, rfim,
   {{0xef175e39,0x2fc05e3a,0x629702ac,0x386001b5}},	//   аму_, rtig_, _gexo, _ùire_,
   {{0x2fc05e3b,0x7bdb083e,0x02b20285,0xdcfc0877}},	//   stig_, _asuu, जलीन, _atrā,
   {{0xbfcd0065,0xad650286,0x00000000,0x00000000}},	//   _dáṣọ_, مانه, --, --,
   {{0xfbd20d5b,0x3f54042c,0x00000000,0x00000000}},	//   تتا_, läum_, --, --,
   {{0xa3ce5e3c,0x2d9c0094,0x00000000,0x00000000}},	//   _रहन_, áves_, --, --,
   {{0x6da31037,0x7bdb0361,0xada3136e,0x629c002b}},	//   _мира, _esuu, _марл, iaro,
   {{0x3b861e79,0xed5a1722,0x58d85e3d,0x4ddb00d7}},	//   _влаг, _роб_, удия_, _בחלו,
   {{0x629c5e3e,0xd7fa5e3f,0xc60e1efb,0xe0df022b}},	//   karo, туй_, ान्य_, _chòy_,
   {{0xa9a6013d,0x629c5e40,0xe6665e41,0x7bc205db}},	//   _вижд, jaro, итно, mtou,
   {{0x69da5e42,0x0f5700a1,0x00000000,0x00000000}},	//   _uste, שיים_, --, --,
   {{0x7bc23447,0xd7e6004d,0x00000000,0x00000000}},	//   otou, _віко, --, --,
   {{0x7bc25e43,0x6297002b,0xbba40096,0xa7f707e8}},	//   ntou, _pexo, _ऑटोक, _نعوذ_,
   {{0x629c5e44,0x82370781,0x20e300fe,0xdce95e45}},	//   garo, لرزا, _ổi_, _rieč,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09c30081,0x00000000,0x00000000,0x00000000}},	//   ্মচা, --, --, --,
   {{0x25de000f,0x29d8020b,0x00000000,0x00000000}},	// [5710] गिकी_, _lũa_, --, --,
   {{0x02a75e46,0x629c5e47,0x6578023e,0x8afc0034}},	//   _трим, caro, _kuvh, _mięs,
   {{0xdcfc0029,0xa3df13ae,0x7bdb083e,0x00000000}},	//   _strā, णिक_, _ssuu, --,
   {{0xd7a60251,0xdb0b058a,0xa3ce0336,0xc579006e}},	//   _खिंच, rugí, _रहम_, אָסט,
   {{0x2bda05cd,0xaca30134,0x657800dc,0x00000000}},	//   _मैदा, _nnụn, _luvh, --,
   {{0x7d190350,0x00000000,0x00000000,0x00000000}},	//   shws, --, --, --,
   {{0x29d8020b,0x00000000,0x00000000,0x00000000}},	//   _cũa_, --, --, --,
   {{0x629c28b3,0xf77f0131,0xf2381777,0x00000000}},	//   zaro, íço_, ירוץ_, --,
   {{0x7bc204d4,0x6133003d,0x8afc0034,0x7c240037}},	//   ctou, għli, _pięt, úirt,
   {{0x629c3c39,0x46f500c2,0x387f5e48,0xa3e60285}},	//   xaro, счит, scur_, फिस_,
   {{0x629c5e49,0x395d023e,0x7ae15e4a,0x160e1f88}},	//   varo, _thws_, _ialt, ानगर_,
   {{0x7ae15e4b,0x629c5e4c,0x5a0c0142,0x00000000}},	//   _halt, waro, _שלאַ, --,
   {{0x7ae15e4d,0x66e5186f,0x087600c1,0x63af00e7}},	//   _kalt, _гола, _הענט_, grcn,
   {{0x4463008f,0xf67900c1,0x2bfa0096,0x00000000}},	//   явяв, _גאַמ, ्हतं_, --,
   {{0x7ae104f9,0x629c5e4e,0x7b3200a5,0xd1790120}},	//   _malt, raro, sług, исті_,
   {{0x645a0253,0x629c5e4f,0xd1320037,0x69c35e50}},	//   ətin, saro, أمر_, itne,
   {{0xdce000c6,0x69c30141,0x00000000,0x00000000}},	// [5720] _gimę, htne, --, --,
   {{0x1ea95e51,0x69c35e52,0x93fb0327,0x7ae11175}},	//   لامي_, ktne, _עליי, _nalt,
   {{0x69c30a39,0x61460138,0x00000000,0x00000000}},	//   jtne, _гена, --, --,
   {{0xdca31d1c,0x63a43813,0x7ae15e53,0x80d20033}},	//   заци, _kvin, _aalt, হাঙ্,
   {{0xd9e0147f,0x7ae11864,0x69c102a1,0x2d081b11}},	//   पट्ट, _balt, _aqle, _वकील_,
   {{0x7bc2025a,0x60d64d7a,0x7ae15e54,0x69c35e55}},	//   rtou, leym, _calt, ftne,
   {{0x7ae15e56,0x7bc2030b,0xf2d30796,0x69d8029a}},	//   _dalt, stou, פעה_, uwve,
   {{0x7ae15e57,0x63a45e58,0x61e1052f,0x63602a6b}},	//   _ealt, _ovin, ælli, lönd,
   {{0xfaa6495f,0xaaba0602,0x17fa0037,0x63a40172}},	//   _газо, _مدار_, ارعة_, _nvin,
   {{0xd6da5e59,0x7ae117c6,0x69c305db,0x64410847}},	//   ути_, _galt, btne, şlik,
   {{0x63a45e5a,0x29e704e9,0x24f90fe9,0x4efb0142}},	//   _avin, _gđa_, анны_, אליג,
   {{0x2d730f39,0x7ae101cb,0x00000000,0x00000000}},	//   _kćer_, _zalt, --, --,
   {{0x07e90018,0x443f5e5b,0x7ae14881,0x60d6026d}},	//   _پرنٹ_, çu_, _yalt, deym,
   {{0x63a92188,0xdc370130,0x443f03e5,0x68e22bc0}},	//   šeno, מאכט_, ħu_, _haod,
   {{0x63a408bb,0x68e20066,0x2bda023a,0x00000000}},	//   _evin, _kaod, _मैसा, --,
   {{0x863700ca,0x115502b7,0x60d601cd,0x00000000}},	//   _לרוב_, ікаю, geym, --,
   {{0x752f00a5,0xa1580db2,0x63620174,0x68e2009c}},	// [5730] micz, сату_, ịnar, _maod,
   {{0x752f00a5,0xa3ce007a,0x69c30094,0x27e90433}},	//   licz, _रहत_, ytne, _šank_,
   {{0xf3cb00bf,0xa28200cd,0x63a45e5c,0x2d875e5d}},	//   _شبکه_, _آیفو, _zvin, ëne_,
   {{0x752f0067,0x81cc00c7,0x6aa8030a,0x2d8701d3}},	//   nicz, লিশ_, _addf, īne_,
   {{0x7ae15e5e,0xdcfc002d,0x5ee10081,0x00000000}},	//   _palt, _stră, নাবে, --,
   {{0x69c35e5f,0x539c00c1,0x3d9503c8,0x317a0449}},	//   ttne, ניוו, _мигр, _yupz_,
   {{0x7ae15e60,0x68e25e61,0x20120206,0x00000000}},	//   _valt, _baod, čniť_, --,
   {{0x7785197b,0xe7a92c22,0x2bd9015a,0x00000000}},	//   олиз, авил_, _پارک_, --,
   {{0x6d4b0018,0x69c35e62,0x68e25e63,0x7ae15e64}},	//   moga, stne, _daod, _talt,
   {{0x6b89023f,0x7ae1009c,0x853d00c6,0x00000000}},	//   _iteg, _ualt, krės, --,
   {{0xceb20130,0x752f00a5,0x68e20013,0x6f07033b}},	//   ויי_, ficz, _faod, _mojc,
   {{0x752f00a5,0x6d4b5cf2,0xa3e60b95,0x671d0f8f}},	//   gicz, noga, फिल_, योजक_,
   {{0xe72e5bc7,0x636002e2,0x317a00c4,0x39a500e8}},	//   _же_, höne, _supz_, lēs_,
   {{0xe2971102,0x6d4b5e65,0x6b890239,0x1b7a006e}},	//   жар_, hoga, _mteg, יטשע,
   {{0x91e35e66,0x6d4b5e67,0x39a501d3,0x66e20285}},	//   море, koga, nēs_, _कोटक_,
   {{0x63a4032e,0xf8d90ed3,0x6b895e68,0x78bb5e69}},	//   _tvin, ढ़िय, _oteg, nguv,
   {{0x6d4b5e6a,0x60d65e6b,0xaf065e6c,0x6b892622}},	// [5740] doga, reym, опал, _nteg,
   {{0x0cd60033,0x00000000,0x00000000,0x00000000}},	//   _সচেত, --, --, --,
   {{0x6d4b081f,0xec7a3566,0x6b895e6d,0x98a400ae}},	//   foga, апе_, _ateg, nimă_,
   {{0xa3ce0d1b,0xf09f0028,0x92b600d0,0x260a02d5}},	//   _रहा_, _hoàn_, _احکا, ाहती_,
   {{0x6bd6001c,0x653b006e,0x77e3023a,0x00000000}},	//   تتار, סענד, कटोक_, --,
   {{0x63600018,0xfd520065,0x05a900a4,0x00000000}},	//   lönb, _jijẹ, _किंब, --,
   {{0x6b89083e,0x66df0138,0x9cb60037,0xddc307f6}},	//   _eteg, iškė, _ومست, _обри,
   {{0x984f008e,0x8c462249,0x4422007e,0x97a65e6e}},	//   _ağır_, _дебе, kzk_, орол,
   {{0x8afc007f,0x2d98030a,0x00000000,0x00000000}},	//   _chęc, _hwre_, --, --,
   {{0xe5c602fd,0x752f0034,0xcff700ca,0x15ea004d}},	//   осмо, wicz, קציה_, аємо_,
   {{0xd5b75e6f,0x6d430257,0x7c225e70,0x88ac0033}},	//   ося_, énag, lzor, ক্ষক,
   {{0x6eca034d,0x7d025e71,0x3ce65e72,0xb8650103}},	//   स्तु, njos, ndov_, _کامو,
   {{0x66e6075f,0xdce20117,0x78a00027,0x18360981}},	//   _мода, jmoč, mamv, _براح,
   {{0x78a0019f,0x672a003e,0x394902c6,0x00000000}},	//   lamv, _umfj, čase_, --,
   {{0x31c41c32,0x398301e8,0x6d4b5e73,0x645a0092}},	//   мств, _kısa_, yoga, ətim,
   {{0x2eed5e74,0x6d4b5d82,0x2ee30078,0x3ce60206}},	//   _şef_, xoga, _sajf_, jdov_,
   {{0x752d5e75,0x6d4b5e76,0x673a1183,0x7d020a39}},	// [5750] _imaz, voga, ontj, djos,
   {{0x7c22011d,0x78a00027,0x5fac0096,0x6d4b5e77}},	//   dzor, hamv, _चिरल, woga,
   {{0x57b70454,0x6d4b5e78,0x673a04e2,0x78a00350}},	//   _आम्ह, toga, intj, kamv,
   {{0x7bf93898,0x6f07007f,0x752d01ff,0x7d020216}},	//   йнер_, _wojc, _jmaz, gjos,
   {{0x6d4b5e79,0x4fc42b16,0x752d0361,0x2bbb0076}},	//   roga, _осра, _mmaz, شاشة_,
   {{0x37c200c7,0x31695e7a,0x673a01c0,0x39a501d3}},	//   ্টার, lmaz_, jntj, tēs_,
   {{0x5ee10081,0xeab00037,0x98a400ae,0xc334021e}},	//   নাদে, ئعه_, ximă_, ווס_,
   {{0x316907aa,0x39a500d9,0x673a04e2,0x2919003e}},	//   nmaz_, rēs_, entj, ósa_,
   {{0x63a902e6,0x6b894069,0x7c220034,0x39a500e8}},	//   šenj, _uteg, czor, sēs_,
   {{0x1dd20354,0x752d5e7b,0x7d095e7c,0x7d1b003e}},	//   _सहमत, _amaz, _hoes, _hlus,
   {{0x7d1b5e7d,0xe8df0134,0x64480092,0x7d095e7e}},	//   _klus, _azụm_, ədiy, _koes,
   {{0x673a1183,0x00000000,0x00000000,0x00000000}},	//   antj, --, --, --,
   {{0x7d095e7f,0x8c4600a7,0x27e90076,0x7d04007b}},	//   _moes, _peşə, _éan_, öisi,
   {{0x752d5e80,0x394d5e81,0xe796001c,0x7d1b5e82}},	//   _emaz, loes_, _راهک, _llus,
   {{0x7d1b5e83,0x7c22028d,0xf770001c,0x62635e84}},	//   _olus, zzor, _شاه_, евра,
   {{0x0446008f,0x752d0344,0x64430034,0x7d1b03a9}},	//   _нейн, _gmaz, _śnie, _nlus,
   {{0xe0435e85,0xf09f00ef,0x80dd007d,0x65645e86}},	// [5760] енти, _toàn_, _पसरे, _ihih,
   {{0x7d1b4207,0x752d0181,0x394d5e87,0x8c3d026a}},	//   _alus, _zmaz, hoes_, _keşf,
   {{0x7d095e88,0xf29700ca,0x98a400c6,0xf27b00ca}},	//   _boes, _מכיר_, limą_, _לריש,
   {{0xdd8f0f43,0x7d1b5e89,0x2d872027,0x7c220a00}},	//   اون_, _clus, ínea_, tzor,
   {{0x98a4013f,0x629e0cd0,0x63a65e8a,0x7d0900a1}},	//   nimą_, _kepo, nskn, _does,
   {{0x7d1b5e8b,0x7c225e8c,0xada60ef7,0x63a618ef}},	//   _elus, rzor, _нагл, iskn,
   {{0x7c220103,0x394d0150,0xf41f0c19,0x7d1b5e8d}},	//   szor, foes_, nbär_, _flus,
   {{0x629e5e8e,0xfce3062a,0x98a4013f,0x39830092}},	//   _lepo, _посо, kimą_, _qısa_,
   {{0x98a4013f,0x6d4043b5,0x78a00169,0x00000000}},	//   jimą_, _ijma, ramv, --,
   {{0x629e5e8f,0x65645e90,0x752d00b6,0x98a40138}},	//   _nepo, _ahih, _smaz, dimą_,
   {{0x27200028,0x78a00193,0xa4d95334,0x6448013c}},	//   _lòng_, pamv, одну_, şdil,
   {{0x394d0161,0x291f5e91,0xe995001c,0x399a00c6}},	//   coes_, chua_, _آهنگ, mūs_,
   {{0x399a013f,0x65645e92,0x272000fe,0x98a400c6}},	//   lūs_, _dhih, _nòng_, gimą_,
   {{0x65640129,0x629e50fc,0x00000000,0x00000000}},	//   _ehih, _cepo, --, --,
   {{0x629e1f97,0x6588030b,0x5f000285,0x31690555}},	//   _depo, _běhe, रान्_, tmaz_,
   {{0xe63b00a1,0x752d5e93,0x25d7006e,0x2720020b}},	//   _לתוכ, _umaz, _זוהן_, _bòng_,
   {{0xc05b00d6,0x7d090629,0x224d0034,0x272000fe}},	// [5770] сів_, _roes, łek_, _còng_,
   {{0x27200028,0x629e5e94,0x316900d9,0x7d0918ef}},	//   _dòng_, _gepo, smaz_, _soes,
   {{0x7d095e95,0x6f1c033c,0x753d042c,0x2d5c00b3}},	//   _poes, _dlrc, onsz, ríen_,
   {{0x291f023e,0x6ec10287,0x65640052,0xdb0b042c}},	//   xhua_, र्जु, _xhih, zugä,
   {{0x3b095d70,0xdb1b0161,0xed5800d6,0x6360186b}},	//   жело_, _aquá, чої_, löna,
   {{0x7d090a9f,0x60cd00ee,0x82340421,0x6287007f}},	//   _woes, lfam, _آریا, ncjo,
   {{0x7d0904ee,0x2fc95e96,0xe9d900d6,0x399a00e4}},	//   _toes, ltag_, іки_, gūs_,
   {{0xa3ce3b30,0x7d1b01e8,0x60cd5e97,0x64b602c6}},	//   _रहल_, _ulus, nfam, _křiž,
   {{0xb8d5034c,0x2fc95e98,0x6287007f,0xdb19042c}},	//   _जय_, ntag_, kcjo, ttwä,
   {{0x05a90084,0x656400dd,0x2fc901bf,0x98a4013f}},	//   овой_, _shih, itag_, vimą_,
   {{0xdb2600bf,0x6aa30947,0x645600dc,0xdbd7007b}},	//   _تولی, manf, _syyi, säät,
   {{0x629e5e99,0x6b9b0dd5,0xdbd700c2,0x98a400c6}},	//   _sepo, _kwug, päät, timą_,
   {{0x629e5e9a,0x6d5900b3,0xe3b20037,0x20000072}},	//   _pepo, ilwa, خرج_, xxii_,
   {{0x63a60501,0x68e92ead,0x6aa30e78,0x06e10081}},	//   rskn, lded, nanf, বাহি,
   {{0x60cd2a99,0xa50a1d62,0x272000fe,0xa2cd277c}},	//   ffam, _мека_, _sòng_, द्ध्,
   {{0x68e92218,0x629e063d,0xb7f100b6,0x98a400c6}},	//   nded, _wepo, _अछाम_, pimą_,
   {{0x2fc902c9,0x8fa310f7,0x27ed5e9b,0xb4da00bc}},	// [5780] gtag_, кате, nven_, ठजी_,
   {{0x27200028,0x6d595e9c,0xfe7204f4,0x27ed3987}},	//   _vòng_, elwa, ندا_, iven_,
   {{0xa3e604f8,0x6aa323ff,0x6ce6004d,0x6b9b2e60}},	//   फिक_, danf, діле, _awug,
   {{0x68e902b6,0x6b9b0169,0x272000fe,0x399a00c6}},	//   jded, _bwug, _tòng_, vūs_,
   {{0x27ed0505,0x68e95e9d,0x9b6a2ff8,0xdb1b0328}},	//   jven_, dded, ошка_, _apuñ,
   {{0x6d5945be,0x399a0138,0x291d5e9e,0xdcfc00bd}},	//   alwa, tūs_, _alwa_, _kurċ,
   {{0x81cc00c7,0x27ed0126,0x1dd2115b,0x999e0138}},	//   লিক_, even_, _सहित, _rytų_,
   {{0x63a90181,0x68e95e9f,0x399a0138,0xa9670b1b}},	//   šeni, gded, rūs_, мија_,
   {{0x5ee10081,0x2d5c0428,0x399a004b,0x00000000}},	//   নারে, níem_, sūs_, --,
   {{0xf4040033,0x291d5ea0,0x6b6300ae,0x00000000}},	//   উনার_, _elwa_, _акуа, --,
   {{0x27ed00ee,0x60cd026a,0x6fca0033,0xdb1900d1}},	//   aven_, yfam, রিয়ে, duwè,
   {{0x291d05aa,0x6b805ea1,0x249f003e,0x00000000}},	//   _glwa_, _kumg, úum_, --,
   {{0x7a13000d,0x7ae83642,0x69ca4d25,0x00000000}},	//   _větš, _kadt, ltfe, --,
   {{0x27200154,0xbcfd0023,0xdb0b0212,0x2d5c015e}},	//   _bòne_, _nhũn, stgö, díem_,
   {{0x09dc074c,0x7ae85ea2,0x8c3d020a,0xe7070d7f}},	//   _मनोय, _madt, _ieşe, _تسنی,
   {{0x2fc9160c,0x2d5502b6,0x00000000,0x00000000}},	//   ttag_, nået_, --, --,
   {{0x40342ea7,0xe7bc0081,0x7afa3ba3,0x60cd2e7f}},	// [5790] ветс, _অনুয, _ontt, rfam,
   {{0x7ae85ea3,0x63bd0675,0x2d8710d9,0x2fc95ea4}},	//   _nadt, musn, íneo_, rtag_,
   {{0xc17509fe,0x68e95ea5,0x7cd923a3,0x2fc95ea6}},	//   _площ, yded, змер_, stag_,
   {{0x61e52c1f,0x7afa5ea7,0x2d5c00ee,0x27ed0ac1}},	//   _ishl, _antt, bíem_, yven_,
   {{0x7ae85ea8,0xeb9915a7,0x3e7c00d2,0x6aa35ea9}},	//   _badt, чил_, uští_, tanf,
   {{0xdcf500ae,0x8f9a021e,0xa3d7274c,0x31790103}},	//   _buză, _מישי, _सहन_, _hisz_,
   {{0xaca30174,0x6d5906a3,0x63605eaa,0x63bd03a9}},	//   _azụa, plwa, könn, husn,
   {{0x27ed00cc,0x7afa5eab,0x7d0400c2,0x2d5502b6}},	//   tven_, _entt, öist, gået_,
   {{0x6c5422d5,0x68e95eac,0x69c8009e,0x7ae80076}},	//   _акту, rded, _eqde, _fadt,
   {{0x290202c3,0x27e90141,0x00000000,0x00000000}},	//   ökar_, _šans_, --, --,
   {{0x7bcb5ead,0x77785eae,0x8c3d00ae,0x5f0005d6}},	//   ltgu, _divx, _deşe, रात्_,
   {{0x6aa1157c,0xf2c90089,0xa3e4034c,0x64430034}},	//   _helf, _לע_, _ननद_, _śnia,
   {{0x2d9c3072,0x63bd5eaf,0x7bcb5968,0x79810270}},	//   ávez_, gusn, ntgu, _hulw,
   {{0xe9ff0028,0x5ecf0081,0x798110df,0x2d5c0428}},	//   _giảm_, _হোসে, _kulw, víem_,
   {{0x216a5eb0,0x76580138,0x6aa12f0e,0xdbd7007b}},	//   зиви_, _gyvy, _melf, _hääp,
   {{0x63bd2281,0x7981083e,0xc57a00ca,0x6ec200b6}},	//   busn, _mulw, _צרפת, _लाहु,
   {{0xd175004b,0xc56900b9,0x9f40007b,0x7981083e}},	// [57a0] тыры, _تحول_, yviä_, _lulw,
   {{0xe9e50028,0x6fb30f43,0x2d5c05fe,0x6b805eb1}},	//   _đúng_, املا, ríem_, _rumg,
   {{0x82360260,0x2d9c56e5,0xdd8f1d28,0xa0a6171b}},	//   _سردا, ève_, مول_, _панд,
   {{0xb81f0096,0x2ca00037,0x7ae8039f,0x25e71176}},	//   यनाम_, úid_, _sadt, _जननी_,
   {{0x80c9009d,0x6aa15eb2,0x2d55004d,0xd04d03e3}},	//   _हॉटे, _belf, vået_, ddaɗ,
   {{0x853d013f,0x79815eb3,0x6aa10150,0x69ca004d}},	//   gsėj, _bulw, _celf, ttfe,
   {{0x6aa15eb4,0x3f82068d,0x2d55181f,0x14c60096}},	//   _delf, _huku_, tået_, _वाढण,
   {{0x3f825eb5,0x2c570067,0xdcfc5eb6,0x612300aa}},	//   _kuku_, _będą_, _kurč, _võlg,
   {{0x0b461681,0x63bd025b,0xdcfc5eb7,0x6aa10018}},	//   _знан, xusn, _jurč, _felf,
   {{0x3f82006d,0x2ca602c9,0x6f0e3d59,0x612300aa}},	//   _muku_, laod_, _jobc, _tõlg,
   {{0x613b00c2,0x3f825eb8,0x79810172,0x658800d2}},	//   nälä, _luku_, _gulw, _běha,
   {{0x6aa10505,0x765800d8,0x00000000,0x00000000}},	//   _zelf, _vyvy, --, --,
   {{0x8c3d0b88,0x27e000e5,0x00000000,0x00000000}},	//   _teşe, _èin_, --, --,
   {{0x63bd06ee,0x6123007a,0x613b007b,0x27e65eb9}},	//   rusn, _mõle, kälä, _ison_,
   {{0x63bd005a,0xf09f00de,0x3f82049e,0x26de5eba}},	//   susn, _hoài_, _auku_, meto_,
   {{0x3f8226f7,0x365b00a1,0x63600018,0x78a2016d}},	//   _buku_, _מכונ, lönl, _jeov,
   {{0xb4dd1085,0x3f825ebb,0xa3ce00aa,0x00000000}},	// [57b0] ड़ी_, _cuku_, _रहए_, --,
   {{0x200700e9,0x26de5ebc,0xc43c00a1,0xce6b15a9}},	//   ćni_, neto_, _מתחי, пред_,
   {{0xf09f00de,0xd35800ca,0x63ad01cd,0x612300bc}},	//   _loài_, _איזי_, _hvan, _põld,
   {{0x6aa15ebd,0x26de5ebe,0xa2cd07ad,0x7bcb4893}},	//   _self, heto_, द्र्, ttgu,
   {{0x26de5ebf,0x490400bc,0x4fc701b6,0x00000000}},	//   keto_, वानो_, _ясна, --,
   {{0x26de5ec0,0x3ce902dd,0x7bcb093e,0x63ad460c}},	//   jeto_, žav_, rtgu, _mvan,
   {{0x6aa15ec1,0x2d850257,0x7bcb00ee,0x94120092}},	//   _velf, _île_, stgu, _deyə_,
   {{0x63ad0572,0xe7ed007f,0x6aa100d7,0x6f0e13be}},	//   _ovan, जिला_, _welf, _zobc,
   {{0x6aa15ec2,0x3ea3580e,0x26de5ec3,0x2d830141}},	//   _telf, _kejt_, feto_, _huje_,
   {{0x798106b0,0x3cff00a4,0x00000000,0x00000000}},	//   _tulw, ळावे_, --, --,
   {{0x63ad01e6,0xd629022a,0xb4dd0aa1,0x2d832618}},	//   _avan, фоне_, ड़ू_, _juje_,
   {{0x3835129c,0x78a20d85,0x2d833351,0x33335ec4}},	//   _инер, _geov, _muje_, _amxx_,
   {{0x26de5ec5,0x68eb0124,0x290f431c,0xfd590af0}},	//   beto_, _iagd, _ioga_, _bibẹ,
   {{0x26de5ec6,0x68eb12ff,0x656f023e,0xe73306cf}},	//   ceto_, _hagd, amch, _حصص_,
   {{0x63ad5ec7,0x3f825ec8,0xf2a32357,0xdcfc0d62}},	//   _evan, _suku_, рисп, _surč,
   {{0x3f8200ac,0xb1435ec9,0x216708c3,0xddc70034}},	//   _puku_, ансл, виси_, _wyjś,
   {{0x68eb5eca,0x3ea35ecb,0x2d9125a8,0xf09f0023}},	// [57c0] _magd, _bejt_, _atze_, _xoài_,
   {{0x3f82031a,0x68eb5ecc,0x8afc0034,0xb6050139}},	//   _vuku_, _lagd, _więz, _gbáà,
   {{0x63ad5ecd,0x2d8308a9,0x2d552ba4,0x1b200033}},	//   _zvan, _cuje_, våer_, _বদলে_,
   {{0x3f820afa,0x68eb152a,0xe9ff0019,0x6123007a}},	//   _tuku_, _nagd, _nhằm_, _põle,
   {{0xe7bc0f71,0x99410034,0x613b00ce,0x78a209a1}},	//   _অন্য, kół_, sälä, _reov,
   {{0x60c45ece,0x3ea302a1,0x7b140428,0xf09f00fe}},	//   lgim, _gejt_, _nàut, _roài_,
   {{0x6da35ecf,0x2d830044,0x26de5ed0,0x2d550b85}},	//   _виса, _guje_, veto_, råer_,
   {{0x60c45ed1,0x23b20f78,0x26de5ed2,0xe9ff00fe}},	//   ngim, _जिंद, weto_, _chằm_,
   {{0x68eb5ed3,0x26de5ed4,0x2fc04090,0xc8f200c3}},	//   _dagd, teto_, nuig_, _अफीम_,
   {{0x2480023b,0x63ad0d62,0xd5b801d3,0xd6da2777}},	//   _agim_, _rvan, trā_, фти_,
   {{0x63ad4a75,0x557501a0,0xc9d50470,0x5ebb00ca}},	//   _svan, лгот, _مملک, וזיק,
   {{0xb4dd1085,0x69da5ed5,0x43950ef7,0x5ed60033}},	//   ड़े_, _ipte, ламс, _ডোমে,
   {{0x26de5ed6,0xe72f00bf,0xaac9397e,0x4ac95ed7}},	//   peto_, صصی_, _रामक, _रामव,
   {{0x2d870fc5,0x59c6014e,0x68e05ed8,0x63ad010a}},	//   ínek_, रंपर, lemd, _vvan,
   {{0x290f5ed9,0x20c73967,0x00000000,0x00000000}},	//   _yoga_, ксаг, --, --,
   {{0x74150dd0,0x60c45eda,0x63ad038c,0x290f03be}},	//   _موبا, ggim, _tvan, _xoga_,
   {{0x691c0257,0x2fc033aa,0x2d8303e3,0x63ad5edb}},	// [57d0] _réel, guig_, _suje_, _uvan,
   {{0x63a90074,0x4fc400f6,0x68e002ac,0x00000000}},	//   šens, јста, hemd, --,
   {{0x39460890,0x3cff0096,0xc7b90103,0x4ac900a4}},	//   _ojos_, ळाले_, rzői_, _राबव,
   {{0x2fc05edc,0xa3d70096,0xa3c711b5,0x70550103}},	//   buig_, _सहा_, _उमा_, _منجا,
   {{0x628000b6,0x68e05edd,0x7b1400ee,0x2d830169}},	//   ěmov, demd, _nàus, _wuje_,
   {{0xe1f00068,0x68eb01c5,0x2d835ede,0x6b6501b3}},	//   _اسی_, _sagd, _tuje_, ыкла,
   {{0x68eb1336,0x1cbb00e3,0x38660154,0x9f3401ce}},	//   _pagd, _يارب_, _azor_, _тері,
   {{0xb4dd009f,0x89d60dd0,0xa96654b5,0x68e00231}},	//   ड़ो_, اوير_, лища_, gemd,
   {{0x69da00ee,0x6ec7034c,0x7b1400b3,0x6eca00c3}},	//   _epte, ालपु, _càus, स्कु,
   {{0x3cff023e,0x38660124,0x290f0239,0x0609007b}},	//   _hnuv_, _dzor_, _woga_, енок_,
   {{0x290f03ce,0x64a65edf,0x68eb5ee0,0x1fcf0033}},	//   _toga_, лана, _tagd, রিটস,
   {{0x2f160102,0xdcfc00d9,0x290f5ee1,0xa50a0219}},	//   _hægt_, _kurā, _uoga_, хема_,
   {{0xf7f40177,0x9f405ee2,0x60c40555,0x7c2b042c}},	//   _پسند, rviú_, vgim, nzgr,
   {{0x78a900aa,0x6d9300bd,0x7bdb563a,0x3ced00bc}},	//   laev, _iħaf, _mpuu, _laev_,
   {{0x321e025b,0x395f260d,0x200f09a1,0x00000000}},	//   áty_, olus_, ägin_, --,
   {{0x2fc05ee3,0x46cf2a29,0x661c00f2,0x78a9014b}},	//   tuig_, त्रह, ørke, naev,
   {{0x60c45ee4,0x321e025b,0xe3b20018,0x75245ee5}},	// [57e0] rgim, šty_, _ارب_, _iliz,
   {{0x26c500dc,0x693a003d,0x75360146,0x139b0796}},	//   nglo_, nċer, _hmyz, _רביע,
   {{0x629c1f84,0x7524005f,0x7bdb007b,0x78a909a1}},	//   mbro, _kliz, _apuu, kaev,
   {{0xe45f0222,0xd00a0161,0x2fc0015e,0x6da35ee6}},	//   mför_, _земе_, puig_, сица,
   {{0x6d425ee7,0x395f00bc,0x75243620,0x6d9302a1}},	//   rnoa, dlus_, _mliz, _nħaf,
   {{0xbda60241,0x395f00bc,0x6d4a1d23,0xdb0b015e}},	//   _محرو, elus_, éfab, nsgè,
   {{0xe45f0222,0xe607177a,0xdce20542,0xfc3f0088}},	//   nför_, _اش_, jmoć, _þín_,
   {{0x391407ec,0x612300aa,0xdce200cc,0x395f00f0}},	//   рмир, _kõla, dmoć, glus_,
   {{0xed3500c6,0x68e05ee8,0x629c35ab,0x7d000090}},	//   _тэрэ, remd, kbro, _inms,
   {{0x47341456,0x68e05ee9,0x75245eea,0x38660146}},	//   рнос, semd, _aliz, _vzor_,
   {{0x0f57040a,0xd6d702e3,0x7bc25eeb,0x629c07ee}},	//   ריים_, уты_, luou, dbro,
   {{0x395f5eec,0x9e7700a1,0x64755eed,0x629c000b}},	//   clus_, טגיה_, игну, ebro,
   {{0x386608c5,0x658800b6,0x6d9300bd,0xb7960291}},	//   _uzor_, _těho, _għaf, _срећ,
   {{0x75245eee,0x6aaa5eef,0xa01b0212,0x629c5ef0}},	//   _eliz, naff, _oför, gbro,
   {{0x3495116a,0x2259007b,0x673a00b3,0x00000000}},	//   _кайр, тивы_, mitj, --,
   {{0x6aaa17d1,0x316006a3,0x5184002d,0x63600364}},	//   haff, gliz_, сура, hönh,
   {{0x6aaa1e71,0x656d5ef1,0x629c3001,0x2d5c00b3}},	// [57f0] kaff, _ihah, bbro, níeu_,
   {{0x78a90233,0x6aaa010a,0x00000000,0x00000000}},	//   zaev, jaff, --, --,
   {{0x395f5ef2,0x656d01c2,0x61f70063,0xddc700e8}},	//   ylus_, _khah, _urxl, _izjū,
   {{0x661a061d,0x7c2b11fc,0x8d740452,0x61fa01cd}},	//   iytk, tzgr, مانا, ætle,
   {{0xd7e600e3,0x6aaa0044,0x63af0037,0x661a08ac}},	//   _بك_, faff, nscn, hytk,
   {{0x645a00d3,0x2129005c,0x6aaa5ef3,0x398a0065}},	//   ştig, lhah_, gaff, _bùs_,
   {{0xaa49013d,0x2f1634da,0x395f007a,0xdb0b5ef4}},	//   ъпка_, _vægt_, tlus_, nsgé,
   {{0x63bd1912,0xe8f93898,0xc27c006e,0x9b9500d3}},	//   krsn, тли_, ערהי, _виац,
   {{0x69150072,0x7bdb0239,0x644d009c,0x395f00b7}},	//   _sáes, _upuu, _nxai, rlus_,
   {{0x21293d42,0x75240094,0xaa880037,0x63bd0141}},	//   hhah_, _sliz, _منكم_, drsn,
   {{0x75240c56,0xf5061942,0xb4db0428,0xd5b801d3}},	//   _pliz, азно, rnàn, dzās_,
   {{0x7ae35ef5,0x69c302ad,0x6967048f,0x316000ec}},	//   lent, mune, _صداق, xliz_,
   {{0x656d5ef6,0x212900bf,0x289a00c1,0x74040081}},	//   _dhah, dhah_, _סיסא, উন্ট_,
   {{0x661a1643,0xa3c70251,0x290d1197,0x291f5ef7}},	//   bytk, _उमर_, ljea_, lkua_,
   {{0x63bd0013,0x69c3044c,0x6d49034f,0x7ae35ef8}},	//   arsn, nune, _ojea, ient,
   {{0xe45f070a,0x7ae35ef9,0x629c2d0c,0x6d5b022e}},	//   rför_, hent, sbro, _nkua,

   {{0x7ae35efa,0x69c35efb,0x27290023,0xa2ce00b6}},	// [5800] kent, hune, _cúng_, _ताप्,
   {{0x69c35efc,0x6d5b3466,0x656d005c,0x2129023e}},	//   kune, _akua, _zhah, ahah_,
   {{0x720800fb,0x69c300aa,0x291f00c2,0x21295efd}},	//   _صفحہ_, june, kkua_, bhah_,
   {{0x63a43f68,0x69c35efe,0x47dc0081,0xeb9a13c0}},	//   _kwin, dune, বিতী, вид_,
   {{0x7ae340d7,0xb92a0019,0x6aaa0517,0xeb065eff}},	//   fent, _thuế_, taff, ичко,
   {{0x7ae310a5,0x63a41639,0x69c35f00,0x6d5b5f01}},	//   gent, _mwin, fune, _ekua,
   {{0x69c35f02,0x19a70077,0x8884010d,0xa2ce0469}},	//   gune, атып_, میان, _तान्,
   {{0xa3d71349,0x21200117,0x7d00037a,0xdb020143}},	//   _सहल_, nkih_, _unms, rroñ,
   {{0x673a023b,0x2fd202c3,0x69c3014b,0x00000000}},	//   titj, ntyg_, aune, --,
   {{0x656d5f03,0x63bd02e6,0x21205f04,0x89d6004d}},	//   _shah, vrsn, hkih_, _відш,
   {{0x69c35f05,0x673a5f06,0x6d9303e5,0x981300cd}},	//   cune, ritj, _għad, مبیا,
   {{0x673a5f07,0x63a40435,0x6aa800f0,0x00000000}},	//   sitj, _bwin, _hedf, --,
   {{0xd79400e3,0x673a5f08,0x2120033b,0x2d5c1277}},	//   _التخ, pitj, dkih_, líes_,
   {{0x63a404e2,0x3cfd009f,0x673a023b,0x79880027}},	//   _dwin, _रोने_, qitj, _kudw,
   {{0x27290019,0x6aa80c2e,0x63a45f09,0x212900bf}},	//   _súng_, _medf, _ewin, thah_,
   {{0x644d01bb,0xdb1906a3,0xd3a703fb,0xba3c0138}},	//   _txai, ntwò, _кроп, _neįm,
   {{0x7ae35f0a,0xc05b0a8d,0x64480092,0x69c30a00}},	// [5810] yent, тів_, şdir, zune,
   {{0x7ae35f0b,0x6d5b5f0c,0x21295f0d,0x39490087}},	//   xent, _skua, shah_, časi_,
   {{0x7ae35f0e,0x62850134,0x63a45f0f,0x06e10081}},	//   vent, _igho, _zwin, বাচি,
   {{0x7ae35f10,0x212004a3,0x753d0018,0x5c7501a0}},	//   went, ckih_, nisz, блет,
   {{0x7ae35f11,0x2d9a0036,0xa2ce1178,0x00000000}},	//   tent, appe_, _ताम्, --,
   {{0x69c31219,0x8ccc08d4,0x628502a1,0x2d5c00b3}},	//   tune, _हाथो, _jgho, fíes_,
   {{0xd2b800ca,0x6aa80178,0x291f007b,0x00000000}},	//   בלות_, _dedf, tkua_, --,
   {{0x69c35f12,0xe0df02f1,0x09051d68,0x6d5b0239}},	//   rune, _akòz_, спин, _ukua,
   {{0x69c35f13,0x6d595f14,0x2bda0260,0xe8f604d9}},	//   sune, mowa, _مالک_, слы_,
   {{0x69c35f15,0x291f5f16,0x6d59262a,0x62855f17}},	//   pune, skua_, lowa, _ngho,
   {{0x9985054f,0x63a45f18,0x58d500ae,0x2d5c00b3}},	//   _الصو, _swin, _гоет, cíes_,
   {{0x753d0068,0x6d590067,0x62855f19,0x6b8125a8}},	//   gisz, nowa, _agho, _hilg,
   {{0x6b8900c7,0xdcf500d9,0x6b815f1a,0x21200117}},	//   _jueg, _atzī, _kilg, vkih_,
   {{0x6b81003d,0x6d93009e,0x6d595f1b,0xe6950568}},	//   _jilg, _mħab, howa, _الغد,
   {{0x6d590067,0x21200b27,0x6b890081,0x412a0058}},	//   kowa, tkih_, _lueg, гово_,
   {{0x6d595f1c,0x753d153c,0x62850ac1,0x00000000}},	//   jowa, cisz, _egho, --,
   {{0x6d590067,0x612a003e,0x63a45f1d,0x60d61f60}},	// [5820] dowa, _nýle, _uwin, rfym,
   {{0xd9f704a9,0xbeaa00cd,0x6b815f1e,0x2fd20212}},	//   ंटात_, اهان_, _nilg, rtyg_,
   {{0x248d025b,0x6d590c95,0xc33300c1,0x2120033b}},	//   žeme_, fowa, _מוז_, pkih_,
   {{0x6d595f1f,0x395d022e,0x6b810150,0x2d5c0314}},	//   gowa, _nkws_, _ailg, víes_,
   {{0x6b81074e,0x798802ac,0x4c560076,0xdcfc00e8}},	//   _bilg, _sudw, حضار, _strē,
   {{0x2d5c037a,0x6b815805,0x00000000,0x00000000}},	//   tíes_, _cilg, --, --,
   {{0x6d595f20,0x3eaa0072,0x798800dc,0xbea3008f}},	//   bowa, _iebt_, _qudw, _хаск,
   {{0x3eaa0505,0x6b8905e6,0x6d5900a5,0x3b860c3f}},	//   _hebt_, _fueg, cowa, _глаг,
   {{0x0c2659b2,0x6b810078,0x2fc05f21,0x3eb80167}},	//   _уман, _filg, nrig_, _kdrt_,
   {{0x2d8a0060,0x6b815f22,0x95d80396,0x8afc0034}},	//   _kube_, _gilg, адот_, _chęt,
   {{0x2f5b0341,0x9f40058a,0x753d0103,0x2d8a00bc}},	//   רדינ, lvió_, tisz, _jube_,
   {{0x6ed8030b,0x2fc00073,0x38cb001c,0x3eaa0364}},	//   न्तु, krig_, _ماهی_, _lebt_,
   {{0x6d43020d,0x753d01f9,0x48e3007f,0x00000000}},	//   énai, risz, _फ़ोटो_, --,
   {{0x2fc05f23,0x6d595f24,0x87b70327,0xa2ce023a}},	//   drig_, zowa, _פלוס_, _ताण्,
   {{0x2d8a04d8,0x6d595f25,0x2fc05f26,0x6f151670}},	//   _nube_, yowa, erig_, _rozc,
   {{0x61fa04c8,0x2fc05f27,0x90993ebe,0x00000000}},	//   ætla, frig_, рват_, --,
   {{0x50672c4c,0x2d8a00fd,0xe7ed00c3,0xa05b0018}},	// [5830] ства, _aube_, ड़िया_, اؤزر_,
   {{0x6b890487,0x2d8a5f28,0x6d595f29,0x00000000}},	//   _rueg, _bube_, wowa, --,
   {{0x6d5929e0,0x6ed8030b,0xe7ea00a5,0xa2ce0af1}},	//   towa, न्धु, _जैसा_, _तात्,
   {{0x2d8a5f2a,0x2fc003a8,0x21390415,0x00000000}},	//   _dube_, brig_, _umsh_, --,
   {{0x6d590067,0x2d98025a,0x6b8900e5,0x6b815f2b}},	//   rowa, _etre_, _queg, _pilg,
   {{0x6d590067,0x612a025b,0x6ed80abe,0x49952105}},	//   sowa, _výle, न्दु, ошит,
   {{0x80ac00c7,0x6d595f2c,0x7bc60120,0x8c3d0233}},	//   _ছাত্, powa, _åkun, _keşk,
   {{0x3f8b0ca7,0xf41f007b,0x6b815f2d,0x63800139}},	//   _kucu_, kyä_, _wilg, _kánì,
   {{0x6b815f2e,0xe0df0154,0x798200cd,0xf41f00c2}},	//   _tilg, _ajòk_, _diow, jyä_,
   {{0x3cfd0789,0x2caf0ec9,0x2d98004d,0x3f830065}},	//   _रोते_, lagd_, _ytre_, _jiju_,
   {{0x3f8b5f2f,0x36691b4d,0x6123007a,0x6d5a2b39}},	//   _lucu_, рано_, _põll, _ítac,
   {{0x27e000d3,0x26dc010a,0xe0df0154,0x3f83007e}},	//   _ţine_, _ebvo_, _djòk_, _liju_,
   {{0x4424023c,0x9cd600ca,0x27e90113,0xe4570120}},	//   ám_, חורה_, _èan_, жжя_,
   {{0x59dd03a2,0x60cf01dc,0x2fc0004d,0xe5a51272}},	//   _महार, _accm, vrig_, _дики,
   {{0x6372052f,0xdddc05db,0x636001f9,0x7ec00139}},	//   hæng, _ogrš, dönt, _lápà,
   {{0x3f8b0063,0x09be0033,0x2fc0550e,0x2d8a0169}},	//   _bucu_, _আহমা, trig_, _rube_,
   {{0x78ab0068,0x3f8b5f30,0x2d8a1ea5,0x2fc05f31}},	// [5840] _megv, _cucu_, _sube_, urig_,
   {{0xe6b71344,0x2fc05f32,0x3f83015c,0xfe4624ec}},	//   _आयोज, rrig_, _ciju_, онзо,
   {{0xcb0302d5,0x3f830139,0x0caa0451,0xee3a0291}},	//   लाईड_, _diju_, атли_, јне_,
   {{0xed5a00c2,0xdca35f33,0xbc66037e,0x00000000}},	//   шое_, даци, овек, --,
   {{0xfbcf2b38,0x0b935f34,0xed4f0103,0x63720537}},	//   نتو_, وجود, ڑھے_, gæng,
   {{0x9f4005e6,0x2d8a5f35,0x61fe0a39,0x09be0033}},	//   rvió_, _tube_, _krpl, _আহবা,
   {{0xcebf00b6,0xdd921ac9,0x637202b6,0x9f40037a}},	//   _úřad_, _آور_, mænd, svió_,
   {{0x48145598,0x637202b6,0xed570095,0x14c60096}},	//   змис, lænd, _дос_, _वागण,
   {{0x8c43007e,0xc173040a,0xfbd1030b,0x78ab01d3}},	//   _жете, וחה_, _समयम, _degv,
   {{0xf41f007b,0x00000000,0x00000000,0x00000000}},	//   vyä_, --, --, --,
   {{0x7bc24e5d,0x2d850018,0x6123007a,0x636001bf}},	//   lrou, _élet_, _sõlm, höns,
   {{0xe4e702ec,0xf41f00c2,0x2bb10034,0x63720537}},	//   ціон, tyä_, ुंचा, hænd,
   {{0x39490335,0x7d04007b,0x63605f36,0x27fd03a8}},	//   čast_, öisy, yönt, _grwn_,
   {{0x7c2f0b88,0x98a300c6,0x63b600c6,0x78ab0381}},	//   _ücre, ėją_, _dvyn, _zegv,
   {{0xd13b0465,0xf41f00c2,0x3f8b5f37,0x3f830095}},	//   аха_, syä_, _sucu_, _riju_,
   {{0x2d84007a,0xbdfb00cd,0x7bc25f38,0x3f8b020a}},	//   _nime_, یرضا_, krou, _pucu_,
   {{0x6360007b,0xb28700d3,0x2489030a,0x00000000}},	// [5850] tönt, _мынк, _igam_, --,
   {{0x2d84025a,0x26cc5f39,0x6e67322c,0x3f8b015c}},	//   _aime_, ngdo_, отеж, _vucu_,
   {{0x27290220,0x8c3d5f3a,0x0c980174,0x2caf029a}},	//   _júna_, _ieşi, _ịhụl, tagd_,
   {{0x2d840580,0x5c755f3b,0x6295007f,0x0ec700a4}},	//   _cime_, плет, lczo, _लाकड,
   {{0x7bc25f3c,0x60cd0051,0x799a003d,0x78ab057a}},	//   grou, mgam, _attw, _regv,
   {{0x60cd5f3d,0xdefb01b3,0x2fc9023e,0x637202b6}},	//   lgam, _тым_, muag_, ræng,
   {{0x27290088,0x2fc95f3e,0x38690a39,0x13e40033}},	//   _núna_, luag_, _šar_, মিয়,
   {{0x60cd2149,0x637202b6,0x24895f3f,0x00000000}},	//   ngam, mæne, _ngam_, --,
   {{0x853d01b3,0xd90c00bf,0x2572025b,0x7bc23ecf}},	//   ipėd, شیو_, nále_, crou,
   {{0x24895f40,0xc6140081,0x6b9b5f41,0x78ab1570}},	//   _agam_, াননা_, _itug, _wegv,
   {{0xf9f9110a,0x2fc901fa,0x63600103,0x2d840027}},	//   _دفاع_, huag_, zöns, _yime_,
   {{0x60cd023b,0x691c020d,0x6295007f,0x672a4900}},	//   jgam, _dées, eczo, _elfj,
   {{0x8c3d0587,0x68e95f42,0x93c6020a,0x9d1a006e}},	//   _beşi, meed, _orăş, צושט,
   {{0xe2973b21,0x68e9008a,0x69c318f0,0x27ed02f1}},	//   зар_, leed, orne, mwen_,
   {{0xc6920130,0x6d4b0a69,0xd00409dd,0x613100f3}},	//   _טאג_, knga, रम्भ_, _målf,
   {{0x39915f43,0x60cd4e06,0x55ba0054,0x2cad37da}},	//   _más_, ggam, _המקו, _need_,
   {{0x6372052f,0x6b9b5ba2,0x212b01ec,0x69c35f44}},	// [5860] tænd, _ntug, _dlch_, hrne,
   {{0x68e9008a,0x7bc25f45,0x6d4b5f46,0x60cd5f47}},	//   heed, vrou, enga, agam,
   {{0x39910871,0x44220185,0x6b9b5f48,0x0d860396}},	//   _nás_, lyk_, _atug, член,
   {{0x7bc25f49,0x6372052f,0x6d4b259e,0xe0df026e}},	//   trou, sænd, gnga, _gbò_,
   {{0x68e95f4a,0x8c3d01e8,0x442200c6,0x63720537}},	//   deed, _yeşi, nyk_, pænd,
   {{0x6d4b5f4b,0x6b9b00e3,0x399100e3,0xf7670018}},	//   anga, _dtug, _bás_, _سا_,
   {{0xdca658aa,0x2d84004f,0x39910037,0xfd4d0134}},	//   _нави, _time_, _cás_, _jehọ,
   {{0x44225e18,0x07980831,0x68e90188,0x7bc25f4c}},	//   kyk_, овић_, geed, prou,
   {{0xb8d40251,0x69c33a9d,0x6d4215e7,0xba3c00c6}},	//   _जज_, arne, mioa, _neįv,
   {{0x6d425f4d,0x39910037,0x44225f4e,0x1de000c3}},	//   lioa, _fás_, dyk_, _नहात,
   {{0x39915f4f,0x7c2206a3,0x60cd026a,0xba9b00ca}},	//   _gás_, lyor, ygam, _הסבי,
   {{0x6d4220ac,0x7aea5f50,0x68e95f51,0x69ca010a}},	//   nioa, left, ceed, mufe,
   {{0x7c225f52,0x645a00d3,0x8c3d01e8,0xf76f00cd}},	//   nyor, ştin, _peşi, ضای_,
   {{0x612300aa,0x490400b6,0x6d425f53,0xdce20141}},	//   _tõlk, वाको_, hioa, dloč,
   {{0xe9ff00ef,0x69d816f3,0xd6db00ca,0x6d4b0150}},	//   _phẩm_, ntve, _החול, ynga,
   {{0x6131017a,0x7aea0656,0x60cd00c6,0x46d80b76}},	//   _målg, heft, ugam, ब्रह,
   {{0x205400ae,0x752d5f54,0x2cad3d0f,0x00000000}},	// [5870] ектя, _ilaz, _reed_, --,
   {{0x69ca5f55,0x51875f56,0x6d4b06a8,0x69d80aab}},	//   kufe, _нума, wnga, ktve,
   {{0x27ed0c56,0xe9ff0019,0x6d4b5f57,0x9f400653}},	//   zwen_, _thẩm_, tnga, rvið_,
   {{0x39915f58,0x6d420a34,0x6372052f,0x6d4b5f59}},	//   _rás_, gioa, ræne, unga,
   {{0x6d932751,0x68e90033,0x752d0106,0x2ca00143}},	//   _għan, veed, _mlaz, ñida_,
   {{0x69d85f5a,0x7aea052f,0x39910146,0x68e9363c}},	//   ftve, geft, _pás_, weed,
   {{0x44221671,0x68e95f5b,0x2cad00aa,0x25480103}},	//   zyk_, teed, _teed_, lőle_,
   {{0x39910897,0x6d42002d,0xc2e90033,0x7c220ff4}},	//   _vás_, cioa, খাটি_, byor,
   {{0x27ed0ab2,0x68e955d5,0xf1b803e5,0x69dc0149}},	//   uwen_, reed, ġġi_, _ären,
   {{0x27ed5f5c,0x7d1b0054,0x752d5f5d,0xa3d7277c}},	//   rwen_, _hous, _alaz, _सहज_,
   {{0x752d5f5e,0x7bcb5f5f,0x7d1b5f60,0x68e900aa}},	//   _blaz, lugu, _kous, peed,
   {{0xc3295f61,0x7d1b2a60,0x44225f62,0xd46a283b}},	//   _דו_, _jous, tyk_, жиме_,
   {{0x394d5f63,0x7bcb0d1f,0xd90f0018,0x7d1b14b8}},	//   mnes_, nugu, _لیں_, _mous,
   {{0x6d4203f3,0x7d1b5f64,0x44225f65,0x395f5f66}},	//   zioa, _lous, ryk_, lous_,
   {{0x394d0eb8,0xaca30174,0x7bcb5f67,0x44224415}},	//   ones_, _anọn, hugu, syk_,
   {{0x394d5f68,0x752d5f69,0x7d1b0084,0x7bcb5f6a}},	//   nnes_, _glaz, _nous, kugu,
   {{0xef1a4f07,0xa0672de0,0x394d5f6b,0xdb0b0018}},	// [5880] ома_, дата_, ines_, zsgá,
   {{0x7bcb5f6c,0xe7e500a5,0x9f4b028d,0xe9ff0023}},	//   dugu, _कहना_, _uscì_, _nhắm_,
   {{0x2d9c01e5,0x7d1b5f6d,0x394d5f6e,0x6d425f6f}},	//   ëve_, _bous, knes_, tioa,
   {{0x7d1b5f70,0x395f0472,0x53d2048a,0x2d9c01d3}},	//   _cous, jous_, _तमाश, īve_,
   {{0x6d425f71,0x7bcb25b9,0x7d1b5f72,0x394d1b62}},	//   rioa, gugu, _dous, dnes_,
   {{0x394d2e86,0x7d095f73,0x6d425f74,0x69d8004d}},	//   enes_, _enes, sioa, ttve,
   {{0x7aea5f75,0x8e834e08,0x7c2208d3,0x7bcb00d9}},	//   reft, _агре, syor, augu,
   {{0x69d85f76,0x394d0be6,0x69ca02e2,0xa2be034d}},	//   rtve, gnes_, rufe, वृत्,
   {{0x6d405f77,0x6f1c5f78,0x69ca0027,0x00000000}},	//   _imma, _korc, sufe, --,
   {{0x752d04a3,0x394d4034,0x7d090087,0x65645f79}},	//   _slaz, anes_, _znes, _akih,
   {{0x6f1c5f7a,0x395f5f7b,0x645a00d3,0xd6d71402}},	//   _morc, bous_, ştil, фты_,
   {{0x2ca616b4,0x394d015c,0x6b880124,0xc7a60fd6}},	//   nbod_, cnes_, _hidg, _жидк,
   {{0x248d0106,0x68e21561,0x27320028,0x752d0542}},	//   žemo_, _ibod, _nâng_, _vlaz,
   {{0x613102fe,0x6d9304f9,0x27e65f7c,0x2ef80072}},	//   _måle, _bħal, _ipon_, _narf_,
   {{0x6d405f7d,0x2002293a,0x6b885f7e,0x7bcb5f7f}},	//   _omma, _arki_, _midg, zugu,
   {{0x752d02e6,0x39445f80,0x6d9300bd,0x645a020d}},	//   _ulaz, nims_, _dħal, écié,
   {{0x51841c2a,0x6f1c5f81,0x7d1b5f82,0xa2d70096}},	// [5890] тура, _borc, _rous, _बाप्,
   {{0x394d5f83,0xce6b07f3,0x6f1c5f84,0x6d405f85}},	//   znes_, оред_, _corc, _amma,
   {{0x7d1b5f86,0x6d932751,0x68e206c0,0x6f1c02bc}},	//   _pous, _għal, _obod, _dorc,
   {{0x63ad5f87,0x7bcb5f88,0x200202ef,0x6d5a003e}},	//   _kwan, tugu, _frki_, _ítal,
   {{0xbbeb0f43,0x7d0902dd,0x61310149,0x6f1c5f89}},	//   ترام_, _vnes, _våld, _forc,
   {{0x63ad4671,0x26e300c7,0x68e223c0,0x7bcb5f8a}},	//   _mwan, _কোনো_, _abod, rugu,
   {{0x7d1b5f8b,0x394d5f8c,0x7bcb007a,0x63ad5f8d}},	//   _tous, tnes_, sugu, _lwan,
   {{0x21295f8e,0x394d025a,0x7bcb02a4,0x3d060096}},	//   nkah_, unes_, pugu, _सोपे_,
   {{0x394d5f8f,0x8b671629,0xd7e600c2,0x63ad00ac}},	//   rnes_, _قائم, емые_, _nwan,
   {{0x395f5f90,0x2129005a,0x394d5f91,0x2d910060}},	//   sous_, hkah_, snes_, _kuze_,
   {{0x21290918,0x63ad5f92,0x395f5f93,0x39443571}},	//   kkah_, _awan, pous_, bims_,
   {{0x63ad1652,0x67b9029e,0x2d915f94,0xa6a70033}},	//   _bwan, _فاتح_, _muze_, _খাওয়,
   {{0x782716c4,0x25720037,0xdcfc01d3,0x2d9101e9}},	//   _تعال, gála_, _strī, _luze_,
   {{0x27320012,0x63ad5f95,0x3d06245a,0x68f90150}},	//   _când_, _dwan, _सोने_, _hawd,
   {{0x63ad5f96,0xc7b90018,0x291d006d,0xc0e614fa}},	//   _ewan, lső_, _kowa_, новк,
   {{0x68fb46fa,0x6f1c5f97,0x63ad05aa,0x5ec70033}},	//   ndud, _sorc, _fwan, র্মে,
   {{0x63ad5f98,0x291d007f,0x68f95f99,0x2d910350}},	// [58a0] _gwan, _mowa_, _mawd, _auze_,
   {{0x27325f9a,0x2d915f9b,0x62920031,0xe8df0134}},	//   _vâng_, _buze_, ékoľ, diọn_,
   {{0x63ad5f9c,0xaac9034d,0x613102fe,0x6b885f9d}},	//   _zwan, _राजक, _såle, _ridg,
   {{0x8fa60f6a,0x6d9303e5,0x0b8a3db3,0xe9ff00de}},	//   _паме, _għam, пски_, _chậm_,
   {{0x6f1c5f9e,0xead4088c,0x4af80084,0x6123007a}},	//   _torc, воль, делю_, _põlv,
   {{0x61310120,0x45160033,0xdd9201c3,0x6d930090}},	//   _våle, াসিক_, _موس_, _mħaj,
   {{0x39440472,0x2d910559,0x291d0139,0xae940af0}},	//   tims_, _guze_, _bowa_, _fẹra,
   {{0x6d405f9f,0x68fb1ba1,0x3f8a5fa0,0x8c3d00ae}},	//   _umma, gdud, _hibu_, _peşt,
   {{0x39444315,0x291d0027,0x20000036,0x3d0600c3}},	//   rims_, _dowa_, nvii_, _सोये_,
   {{0x63ad5fa1,0x3f8a0010,0x39441fbc,0xccf90034}},	//   _rwan, _jibu_, sims_, _zaś_,
   {{0x63ad5fa2,0x66030f39,0x273200ae,0x18a65fa3}},	//   _swan, _crnk, _rând_, _заем,
   {{0x80e00f71,0x7afa5fa4,0x68e20995,0x63ad0051}},	//   _পোস্, _hatt, _ubod, _pwan,
   {{0x27e600a1,0x2129033b,0x67d400d3,0x657d5fa5}},	//   _upon_, vkah_, _ролу, rmsh,
   {{0x25723e1d,0x7afa0078,0x938800c2,0x291d03e3}},	//   rála_, _jatt, есса_, _zowa_,
   {{0x4ac90789,0x31c40fa5,0x069700a1,0x7afa1d22}},	//   _राघव, лств, _אדום_, _matt,
   {{0x21295aa9,0x63ad5fa6,0x3f8a5fa7,0x2d91031a}},	//   ukah_, _twan, _aibu_, _ruze_,
   {{0x21290496,0x63ad5fa8,0x6d9303e5,0x2d91005f}},	// [58b0] rkah_, _uwan, _għaj, _suze_,
   {{0x7afa09ce,0x2129159d,0x238a0031,0xbf9b014b}},	//   _natt, skah_, ľujú_, _frên,
   {{0x21292048,0x238a0220,0x22640146,0x6235002d}},	//   pkah_, žujú_, čské_, _рену,
   {{0xa3e5009f,0x7afa007b,0x00000000,0x00000000}},	//   _नहा_, _aatt, --, --,
   {{0x7afa188c,0x255600d9,0x291d0a40,0x68f9078e}},	//   _batt, nāla_, _rowa_, _rawd,
   {{0xbbd10386,0x68f95fa9,0x2fc90124,0x290301d3}},	//   _समीक, _sawd, mrag_, ējam_,
   {{0x7afa5faa,0xe9ff00de,0x62880307,0xbe6533c6}},	//   _datt, _thậm_, ždov, _شهري,
   {{0xdb0b02c3,0x2cbf01dc,0x7d16007b,0x8d7700d1}},	//   dsgå, _udud_, öyst, _سازا,
   {{0x7afa5fab,0x69ce01c5,0x68fb5fac,0xdc1300a7}},	//   _fatt, _åben, rdud, pşır,
   {{0x7afa5fad,0xecd100a3,0x27ff0653,0x00000000}},	//   _gatt, _हाँफ, rvun_, --,
   {{0x64a60f6b,0xdb260281,0x25ae03a8,0x27ff00ce}},	//   кана, _جولی, _cwfl_, svun_,
   {{0x2fc90313,0x2b4705db,0xe894013f,0x981500d1}},	//   krag_, linc_, _баць, _لبتا,
   {{0x7afa5fae,0x78a95faf,0x00000000,0x00000000}},	//   _yatt, mbev, --, --,
   {{0x03a302fd,0x20000036,0x798b0169,0x7afa026d}},	//   риро, vvii_, _higw, _xatt,
   {{0x3f8a5fb0,0x80e00081,0xe2975d76,0x798b1e59}},	//   _ribu_, _পোষ্, тас_, _kigw,
   {{0x78a903ee,0x3f8a5fb1,0x2b4705db,0x798b0090}},	//   nbev, _sibu_, hinc_, _jigw,
   {{0xf8b20130,0x54a50037,0x21672611,0x798b294f}},	// [58c0] ישן_, _صحيف, тити_, _migw,
   {{0x6123007a,0x6d9302a1,0x20005fb2,0x798b084e}},	//   _sõlt, _għak, rvii_, _ligw,
   {{0x7afa5fb3,0x7bdb00b3,0xba3c0138,0xb6060328}},	//   _ratt, _aquu, _neįp, _ibáñ,
   {{0x7afa4562,0x2fc95fb4,0x629c13ea,0x80e00033}},	//   _satt, brag_, lcro, _পোর্,
   {{0xeb971bb8,0x7afa5fb5,0x30752436,0x612300bc}},	//   вич_, _patt, _бурс, _võlt,
   {{0x7afa0078,0x2b47173c,0xd788020b,0x00000000}},	//   _qatt, ginc_, _yểu_, --,
   {{0x7afa070a,0x3cfd007a,0x798b5fb6,0xe45f5fb7}},	//   _vatt, _रोके_, _bigw, ngör_,
   {{0x7afa5fb8,0x5ec70081,0x78a95fb9,0x00000000}},	//   _watt, র্দে, gbev, --,
   {{0x798b02ad,0x2bc9055c,0x7afa5fba,0x3b860077}},	//   _digw, _रिया, _tatt, _алаг,
   {{0x61310160,0xa2d75fbb,0x255601d3,0x00000000}},	//   _måla, _बाध्, vāla_, --,
   {{0x2d8c0103,0xa37b0131,0x00000000,0x00000000}},	//   _édes_, ntõe, --, --,
   {{0xc4bf05a5,0x779209e5,0x64bf02d5,0x255600d9}},	//   ्लेख, _پیدا, ्लेश, tāla_,
   {{0xd6d212eb,0xe9ff00de,0x9abc0090,0xd04403e3}},	//   _نقش_, _thảm_, _eoċe, mfiɗ,
   {{0x2d870af3,0x70cb000d,0x45d4246b,0x44395fbc}},	//   ínez_, िल्ल, _бокс, rzs_,
   {{0x442d00e9,0x673d0216,0x798b246c,0xe45f02c3}},	//   še_, ësje, _yigw, ggör_,
   {{0x3998429b,0x2fc95fbd,0x69ca0037,0x30a40f0a}},	//   _més_, trag_, irfe, ирув,
   {{0xaad2000f,0x70594d95,0xbf9b014b,0xa0750284}},	// [58d0] _सांक, хаар_, _grêl, угач,
   {{0x656f5a54,0xa2f5004d,0x985500a7,0x629c014b}},	//   llch, _споч, _ləğv_, ccro,
   {{0x3998020d,0xe8df0023,0x2b47013c,0x656f5fbe}},	//   _nés_, hiền_, vinc_, olch,
   {{0xf65300ca,0xdcfc0092,0x00000000,0x00000000}},	//   בצע_, _vurğ, --, --,
   {{0x798b003d,0xf09f0139,0xfc301374,0x69ca02db}},	//   _rigw, _ifà_, يحه_, erfe,
   {{0xab6401b3,0xc5e90033,0x798b5fbf,0x63bd02ac}},	//   авіл, গিতা_, _sigw, issn,
   {{0xa9693c1a,0xf9915f34,0xee8404d9,0x00000000}},	//   ника_, حبت_, _выто, --,
   {{0xe9ff00de,0x6c850018,0x399800fd,0x8d740103}},	//   _chạm_, _ملزم, _dés_, _ناقا,
   {{0x78a901be,0x6c551f75,0x2b490037,0xfd440077}},	//   rbev, _скау, éacs_, _тэрн,
   {{0x656f5fc0,0x46f5117f,0x78a92e7f,0xe619037e}},	//   elch, учит, sbev, едо_,
   {{0x45860f50,0x63bd063a,0x78a90120,0x2d8d0113}},	//   лгов, essn, pbev, _kiee_,
   {{0xaadf0efd,0x629c01c2,0x4adf3162,0x5f05115b}},	//   प्रक, wcro, प्रव, _होस्_,
   {{0x66e5101b,0x290f0ce7,0xc98400ae,0xbf9b00fc}},	//   _бола, _inga_, _туфи, _brêm,
   {{0xcc3a00c1,0x656f0441,0xa3d5007a,0xdc3a006e}},	//   געשט, alch, _हमर_, געשר,
   {{0x6d9302a1,0x00000000,0x00000000,0x00000000}},	//   _iħaw, --, --, --,
   {{0x6d930090,0x613117d2,0x255600e8,0x00000000}},	//   _għai, _påla, mālo_, --,
   {{0xb4d0007d,0xe29a5fc1,0xe0df009c,0xf5570076}},	// [58e0] शली_, _пап_, _smòc_, _حليب_,
   {{0x63a45fc2,0x6566067d,0xe8d0000d,0xbf9b0161}},	//   _itin, lokh, _सञ्च, _grêm,
   {{0x290f3779,0x255601d3,0x63a4009c,0x6d9300bd}},	//   _onga_, nālo_, _htin, _mħaw,
   {{0xa37b001f,0xac9700cd,0x290f0009,0x273200ae}},	//   rtõe, هنما_, _nnga_, _mâna_,
   {{0x77f20b2b,0x26f3007d,0xa37b0396,0x3998002b}},	//   _अनेक_, _असूर_, stõe, _sés_,
   {{0x81c900c7,0x3998137f,0x81e70081,0x290f5fc3}},	//   োবর_, _pés_, পির_, _anga_,
   {{0x82970054,0xe9ff0028,0x656f0150,0xa2d70569}},	//   נדקס_, _phạm_, ylch, _बास्,
   {{0x399805fe,0x63a401c0,0xa9670b1b,0x63bd5fc4}},	//   _vés_, _otin, лија_, yssn,
   {{0x3d1102e8,0x63a40129,0xfaa61c00,0x4734017b}},	//   णारे_, _ntin, _базо, инис,
   {{0x583700c2,0x290f5fc5,0x39980143,0x3eba029a}},	//   узья_, _enga_, _tés_, napt_,
   {{0x63a45fc6,0x49ca0303,0xaa931487,0xca560291}},	//   _atin, _член_, _المث, _стањ,
   {{0x9f490102,0xa2d71fb4,0x63a4009c,0xd6ac0033}},	//   hvað_, _बाह्, _btin, _খাওয,
   {{0x394608a8,0xbf9b001f,0x5f170167,0x613800b3}},	//   _imos_, _prêm, नाम्_, _míld,
   {{0x3946022e,0x6d93003d,0x43940aa8,0x63a41467}},	//   _hmos_, _għaw, сарс, _dtin,
   {{0x2d9c00c9,0x63a400ac,0x5fc70006,0xaad2152c}},	//   ível_, _etin, _लिहल, _साईक,
   {{0xddcb03e5,0x00000000,0x00000000,0x00000000}},	//   ċiżj, --, --, --,
   {{0x3eba020a,0xbf9b0231,0x00000000,0x00000000}},	// [58f0] fapt_, _trêm, --, --,
   {{0x63600103,0x3cfd5fc7,0x9ed800ae,0x00000000}},	//   köny, _रोजे_, лмут_, --,
   {{0x62880146,0x39465d82,0xaca30174,0x60ce020e}},	//   ždor, _omos_, siọb, _şimş,
   {{0xe7e500aa,0x80dc074c,0xc0180139,0x00000000}},	//   _कहला_, _फाये, _léṣe_, --,
   {{0x6e950c5b,0x8d740076,0xfe700103,0x00000000}},	//   _вигу, حالا, _ہدف_, --,
   {{0xa3d61fbb,0x290f0124,0xeb96075f,0x6566019f}},	//   ांत_, _snga_, шиш_, zokh,
   {{0x2bd104dd,0x316b0095,0x6566019f,0x290f0062}},	//   _समका, _kkcz_, yokh, _pnga_,
   {{0xa925021c,0x5ec70033,0x61312ca7,0x00000000}},	//   рдил, র্শে, _målo, --,
   {{0x6d4b5fc8,0x64c800c6,0xead50b2f,0x00000000}},	//   miga, nčių, _возь, --,
   {{0x3cff0d7d,0x57454911,0xe9ff00de,0xeaf80281}},	//   _hauv_, рноб, _nhầm_, _مرمت_,
   {{0xbb8400e3,0x3cff01fa,0x65660103,0x7c2b5fc9}},	//   _اللي, _kauv_, tokh, lygr,
   {{0x6d4b5fca,0x290f5fcb,0x399a0089,0x693300cd}},	//   niga, _unga_, _סינד, _دکتر,
   {{0xe72e1ae2,0x3cff022e,0x6d9300bd,0x00000000}},	//   _де_, _mauv_, _tħaw, --,
   {{0x3cff5fcc,0x6d4b5fcd,0x46a507c8,0x05160081}},	//   _lauv_, higa, _такв, াসের_,
   {{0x6d4b5fce,0xa2d705a5,0x00000000,0x00000000}},	//   kiga, _बार्, --, --,
   {{0x10a65fcf,0x057a0037,0xa3d60285,0xa0a600c6}},	//   риан, _جمعة_, ांद_, раад,
   {{0x6d4b5fd0,0x67235fd1,0x63a45fd2,0xdfa50037}},	// [5900] diga, _konj, _utin, محلي,
   {{0x6131070a,0x3f8e003e,0x6d4b32a7,0x60d60e37}},	//   _håll, öfu_, eiga, sgym,
   {{0xc0e6018a,0x67235fd3,0x613800e1,0x316b0095}},	//   _конк, _monj, _píld, _fkcz_,
   {{0xb64c0130,0xfce65fd4,0x672306a3,0x645a00ae}},	//   עגאָ, родо, _lonj, ştiu,
   {{0x3cff023e,0x2ca90fb6,0x613800b6,0x69c14796}},	//   _dauv_, ñada_, _cíle, _avle,
   {{0xa9c61edc,0x05c50789,0x67235fd5,0x9f420154}},	//   асик, _विंब, _nonj, _eskò_,
   {{0x6d4b5fd6,0xd90d09b4,0x2fc05fd7,0xd6bb0033}},	//   biga, کین_, lsig_, ংলায,
   {{0x752435ee,0x7c2b5fd8,0x3eb85fd9,0x67230350}},	//   _noiz, bygr, _hert_, _aonj,
   {{0x67235fda,0x69c101e8,0x14a70af1,0xa2d742d4}},	//   _bonj, _evle, _क्षण, _बाल्,
   {{0x67235fdb,0x2d985fdc,0xf1bf0181,0x47345fdd}},	//   _conj, _kure_, žšie_, снос,
   {{0x3eb80068,0x672300e9,0x3cff022e,0x5f170374}},	//   _mert_, _donj, _yauv_, नात्_,
   {{0x7d02300c,0x7d005fde,0x2d985fdf,0x354732ac}},	//   ndos, _jams, _mure_, рхов,
   {{0x67233925,0xb7960291,0xe9ff00fe,0x7d025fe0}},	//   _fonj, _трећ, _phầm_, idos,
   {{0x6d4b5705,0x7d005cf1,0x7d0200c2,0x2bc9142e}},	//   ziga, _lams, hdos, _रिसा,
   {{0x6d4b5fe1,0x48dd058f,0x9f40029a,0x2fc0084e}},	//   yiga, क्को_, atië_, esig_,
   {{0x75240a00,0x6723023b,0x7d005fe2,0xd138131b}},	//   _goiz, _zonj, _nams, аху_,
   {{0x3eb85fe3,0x2d985fe4,0x3cff01fa,0xe9ff00de}},	// [5910] _bert_, _aure_, _rauv_, _thầm_,
   {{0x3eb85fe5,0x2d985fe6,0x3cff01fa,0x9f4006a3}},	//   _cert_, _bure_, _sauv_, ntiè_,
   {{0x2bc906ed,0x3cff0197,0x7d005fe7,0x6d4b0d18}},	//   _रिहा, _pauv_, _bams, tiga,
   {{0xe1f04f89,0x7d005fe8,0x2d985fe9,0x3cff0197}},	//   _کسی_, _cams, _dure_, _qauv_,
   {{0x6d4b5fea,0xfc050058,0x2d985feb,0xf09200a1}},	//   riga, спло, _eure_, _מנכ_,
   {{0x6d4b04b5,0x3eb85fec,0x3da70396,0x61310f3c}},	//   siga, _gert_, _враб, _målm,
   {{0x2d9802a7,0x6d4b5fed,0x7d00023b,0x3cff01fa}},	//   _gure_, piga, _fams, _tauv_,
   {{0x672306a3,0xe9a800e3,0x7d005fee,0xe8f908e5}},	//   _sonj, جدون_, _gams, ули_,
   {{0x6d495fef,0xb8ff04df,0x2d9802a7,0x6d5b2e6b}},	//   _imea, _ता_, _zure_, _ijua,
   {{0x3f995ff0,0x257201cd,0x656d4513,0x49b80103}},	//   _musu_, máli_, _akah, _چاند_,
   {{0x3ea102e2,0x67232788,0x7524033b,0x1e3a00c1}},	//   icht_, _vonj, _poiz, ָגרא,
   {{0xc329004f,0xb8950080,0x200b5ff1,0x2fc002ad}},	//   _או_, _الإع, _orci_, ysig_,
   {{0x394d5ff2,0x3f990051,0x291f411d,0x67235ff3}},	//   mies_, _nusu_, mjua_, _tonj,
   {{0x673a0126,0x6d9300bd,0x656d0372,0x00000000}},	//   chtj, _jħas, _ekah, --,
   {{0x2bd1000f,0x200b0451,0x434332a2,0x6d93009e}},	//   _समझा, _arci_, черв, _mħas,
   {{0x3eb85ff4,0x3f4f01d3,0x2fc05ff5,0x3f910634}},	//   _sert_, kļus_, tsig_, _aizu_,
   {{0x4e9616cc,0x2d9800a1,0xb4b413cc,0x2fc05511}},	// [5920] مشار, _sure_, टरी_, usig_,
   {{0x6d495ff6,0x3f9903d6,0x60dd00e7,0x2fc05ff7}},	//   _amea, _dusu_, _ecsm, rsig_,
   {{0x394d2d27,0xa3d60006,0x3eb85ff8,0x2fc05ff9}},	//   kies_, ांव_, _vert_, ssig_,
   {{0x61fe02e6,0x3ea10080,0x394d5ffa,0x3eb855eb}},	//   _ispl, acht_, jies_, _wert_,
   {{0x200b08a9,0x394d5ffb,0xe6070260,0x6d5b0085}},	//   _grci_, dies_, _کش_, _djua,
   {{0x8fa3013d,0x7d02023b,0x63b60150,0x7d00413e}},	//   _харе, sdos, _mwyn, _wams,
   {{0x7d005ffc,0x394d5ffd,0x27290072,0x63b6030a}},	//   _tams, fies_, _lúns_, _lwyn,
   {{0x21200660,0x6d5b0052,0xfce35ffe,0x7d005fff}},	//   njih_, _gjua, _носо, _uams,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x19ba6000,0xcafc0557,0x7bc2022b,0xfe6f0018}},	//   _будь_, _एसिड_, msou, _آگے_,
   {{0x394d6001,0xd9462ed0,0xb99600e3,0x25a7002b}},	//   bies_, _лежи, _الصب, _ctnl_,
   {{0x673a01e5,0x394d3166,0x63b600f0,0x31690634}},	//   shtj, cies_, _bwyn, xoaz_,
   {{0x7d7b00a1,0xdb090088,0xe7861720,0xb4db0428}},	//   טרטג, _kveð, _луко, diàt,
   {{0x799a5c7b,0x3f99592d,0x61fe6002,0x6d93009e}},	//   _kutw, _rusu_, _bspl, _mħar,
   {{0x3f9926f7,0x61fe0072,0xe9ff00de,0x41770604}},	//   _susu_, _cspl, _thấm_, مارس,
   {{0xa3d60c16,0x799a2ea9,0x29046003,0x6d586004}},	//   ांश_, _mutw, ndma_, éval,
   {{0x61fe6005,0x645a0b88,0x63b602ad,0x6edd0176}},	// [5930] _espl, ştir, _gwyn, _पादु,
   {{0x3ea102e2,0x394d6006,0x6d496007,0x16b60096}},	//   ucht_, zies_, _smea, _आजोब,
   {{0x2ca90fb6,0x3f9108a9,0x2cbd023e,0x6d930090}},	//   ñado_, _vizu_, tawd_, _aħar,
   {{0x3ea102e2,0x5c75062a,0x200b2461,0xb4db00b3}},	//   scht_, олет, _trci_, ciàt,
   {{0xb6070871,0x394d6008,0xab5d00bd,0xeab916de}},	//   _koší, vies_, _avża, айл_,
   {{0x394d6009,0x9abc02a1,0x799a600a,0x200900ae}},	//   wies_, _doċo, _butw, mvai_,
   {{0x394d600b,0xb5290139,0xf2d4006e,0x291f007b}},	//   ties_, _akọ̀, לעס_, tjua_,
   {{0x5d5417de,0x6d49600c,0x63723e59,0x799a0169}},	//   _екст, _umea, ræni, _dutw,
   {{0x394d600d,0xe8df00de,0xdcff00c6,0x00000000}},	//   ries_, hiện_, _žvėr, --,
   {{0x394d600e,0x6d930078,0x6b9b00f9,0x85e91f37}},	//   sies_, _għar, _iuug, адов_,
   {{0x6d5902ac,0x799a2cd0,0xf409021e,0x394d600f}},	//   onwa, _gutw, _שפ_, pies_,
   {{0x29030029,0x6b9b6010,0x63b600f0,0x2c200033}},	//   ējas_, _kuug, _pwyn, _মেয়ে_,
   {{0x4ae0009d,0x69c32084,0x255601d3,0x29dc007e}},	//   _नामव, lsne, nāli_, ršaš_,
   {{0x6d590364,0x68e96011,0x6b9b6012,0xcb9a006e}},	//   hnwa, lfed, _muug, יסשט,
   {{0xcb1217f5,0x320c00b6,0x2120033b,0x6d9302a1}},	//   ולם_, ídy_, tjih_, _lħaq,
   {{0x61380088,0x69c35190,0x255600e8,0x753d6013}},	//   _bíla, isne, kāli_, chsz,
   {{0xfe78013f,0x21200087,0x25a06014,0xb4db015e}},	// [5940] _šį_, rjih_, _čili_, riàt,
   {{0xef172aab,0x69c36015,0x6721015c,0x49100034}},	//   ому_, ksne, njlj, _दोनो_,
   {{0xe4d309e5,0x6aba02b6,0x273b020d,0x69c33001}},	//   _عقید, _retf, _gêne_, jsne,
   {{0x7bc26016,0x6b9b008a,0xb4db0428,0x69c34559}},	//   tsou, _buug, liàr, dsne,
   {{0x61380065,0x255600e8,0x69c36017,0x00000000}},	//   _gíla, gāli_, esne, --,
   {{0xaff900c1,0x79a60dc3,0x39a600c2,0x6b9b54ce}},	//   _פּרי, орие, ошив, _duug,
   {{0x7bc2350b,0x68e96018,0x69c36019,0x00000000}},	//   ssou, ffed, gsne, --,
   {{0x2bd20490,0x63a900d3,0x20070034,0x6b8101ff}},	//   _सिपा, ţeni, łnie_, _ehlg,
   {{0xd83a00c6,0x29020220,0x25720146,0x6d930078}},	//   рэй_, ľka_, nálu_, _għaq,
   {{0x29021999,0xf72a0a29,0x6a160037,0x799a47fd}},	//   žka_, рций_, _وبار, _tutw,
   {{0x28ab022d,0x5ec70081,0xff7b00c1,0x7e9b00ca}},	//   _ट्वि, র্কে, שטימ, יסיו,
   {{0x20090138,0x00000000,0x00000000,0x00000000}},	//   yvai_, --, --, --,
   {{0x2bd21317,0x69d8601a,0xb4db00b3,0xc7a30293}},	//   _सिफा, luve, fiàr, _жичк,
   {{0xdcfc01b3,0x491200b6,0x48f400b6,0x00000000}},	//   _turė, थाको_, ्यको_, --,
   {{0x6138266c,0x69d8601b,0xf5b30037,0x92940fe6}},	//   _síla, nuve, _قصيد, дарц,
   {{0x6edd2183,0xa2d71757,0x9099008f,0x79820113}},	//   _पाहु, _बाक्, сват_, _jhow,
   {{0xe57207a6,0x442f052f,0x4fd5004c,0xb4db015e}},	// [5950] _אַז_, _æg_, яжат, siàs,
   {{0x6131038c,0x69d8601c,0x69c3601d,0xb4db00ee}},	//   _måli, kuve, ysne, ciàr,
   {{0x69d8601e,0x6b9b008a,0x68e900f0,0x2d9e0103}},	//   juve, _suug, yfed, _étel_,
   {{0x2fd202b6,0x6d5901c2,0x69d8601f,0x6b9b00bc}},	//   bryg_, unwa, duve, _puug,
   {{0x69c30178,0xfaa53333,0xbf9b020d,0xeb990aca}},	//   wsne, пало, _crêt, щил_,
   {{0x69c32fa7,0x25720103,0x62830094,0x00000000}},	//   tsne, lált_, _únos, --,
   {{0x69d86020,0xa9220206,0x69c36021,0xd2b800d7}},	//   guve, _šľac, usne, חלות_,
   {{0x25720018,0x69c31183,0x6b9b6022,0x79826023}},	//   nált_, rsne, _tuug, _chow,
   {{0x79820694,0x2bd2000f,0x1bd50084,0x68e92522}},	//   _dhow, _सिया, _хозя, rfed,
   {{0x61310222,0x28ab0fdd,0x7af8033b,0x7982039f}},	//   _dåli, _ट्रि, cevt, _ehow,
   {{0x36694cb0,0xb9e700d6,0xa50a078b,0x7bd96024}},	//   сано_, _фізи, бена_, luwu,
   {{0x798201b9,0x2bd200b6,0x00000000,0x00000000}},	//   _ghow, _सिमा, --, --,
   {{0xc952040a,0x889a00ca,0x613801cd,0xa49b009c}},	//   _אמא_, _הבני, _bíln, cdòm,
   {{0x443e007f,0x3f83020b,0x00000000,0x00000000}},	//   ąt_, _nhju_, --, --,
   {{0xd2520103,0x613800b6,0x661c0e74,0x69ce00f3}},	//   رنر_, _díln, ärkt, _åbet,
   {{0x25aa058a,0x5fc70006,0x25720094,0x3f8300bc}},	//   íble_, _लिखल, tálu_, _ahju_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [5960] --, --, --, --,
   {{0xdfcf00ab,0x37bd0033,0x4f652519,0x257200d4}},	//   ايل_, _আমার, والف, rálu_,
   {{0x6edd007a,0xe29b00ca,0x69d8002b,0x2d9c014b}},	//   _पारु, _לשיר, xuve, êve_,
   {{0xbf9b0257,0xdca33816,0x65c20065,0x3ce700c3}},	//   _prêt, еаци, _híhá, छ्ले_,
   {{0xa806002b,0x628300b6,0x798200f0,0x7bd96025}},	//   _mañó, _únor, _rhow, guwu,
   {{0x79826026,0x69d81dfc,0x20026027,0xbb433b40}},	//   _show, tuve, _iski_, нечк,
   {{0x7d7a00cd,0xdce9009e,0x00000000,0x00000000}},	//   _همسر_, _wieġ, --, --,
   {{0x6131017a,0xad6600d1,0x7a530076,0x00000000}},	//   _påli, _رازه, عضوا, --,
   {{0x7af8033b,0x255601d3,0x2d84007b,0x69d86028}},	//   pevt, nālu_, _ihme_, suve,
   {{0x6b661ad1,0xb8d339d4,0x200d21d5,0x9b461790}},	//   _экза, _ज्_, _šeik_, _عناو,
   {{0x24806029,0x3d110096,0x79820113,0x7ec701f9}},	//   _azim_, णाचे_, _thow, lépí,
   {{0x4a7b00c1,0xa80605e6,0xda650037,0xba3700ca}},	//   _פראב, _cañó, _غالي, _מטבח_,
   {{0x25720103,0x5ec70033,0x00000000,0x00000000}},	//   vált_, র্টে, --, --,
   {{0x3b050092,0x9abc03e5,0x661c0704,0x613802c6}},	//   _xalq_, _soċj, ärks, _bílo,
   {{0x2002602a,0x6131320e,0x2480010a,0x613802c6}},	//   _aski_, _målv, _ezim_, _cílo,
   {{0x59dd0096,0x672a01cb,0xdce900e8,0xd67700d7}},	//   नंतर, _hofj, _okeā, _מתוק_,
   {{0x656f0067,0xb4d9277c,0x5f950c79,0x25720103}},	// [5970] moch, ाली_, диат, rált_,
   {{0x63ad602b,0xd24e0068,0x09b20081,0xa9250094}},	//   _itan, اچی_, _ঘটনা, možň,
   {{0x200201e8,0xdce9003d,0xe52105d6,0xf2d20a41}},	//   _eski_, _jieħ, यापि_, _בעי_,
   {{0x656f602c,0x7bd9602d,0x853003e3,0x63ad0167}},	//   noch, tuwu, _kiɗa, _ktan,
   {{0x69c80578,0x220700b6,0xc1720470,0x00000000}},	//   _avde, bíhá_, _شگفت, --,
   {{0x63ad0010,0x68e2602e,0xb4d906ed,0x212b01bf}},	//   _mtan, _acod, ालु_, _hoch_,
   {{0x656f602f,0xa3df0789,0x63ad0009,0x2bc903a2}},	//   koch, दंड_, _ltan, _रिका,
   {{0x63ad6030,0x26de6031,0x29060231,0x853d00c6}},	//   _otan, egto_, _caoa_, ipės,
   {{0x63ad6032,0x7989005c,0x69c8026a,0x68e2037a}},	//   _ntan, rmew, _evde, _dcod,
   {{0x212b2bc6,0x2bd200a5,0x68e26033,0xfbd200a5}},	//   _loch_, _सिता, _ecod, _सितम,
   {{0x63ad6034,0x7a3500e3,0x76440022,0xfd640023}},	//   _atan, _تفاص, _ƙiya, _nhuộ,
   {{0x212b02d6,0x656f6035,0xdce9009e,0x6f07056d}},	//   _noch_, goch, _dieħ, _lajc,
   {{0x394f6036,0xad1a00ca,0x69ce320e,0x2cbf0441}},	//   _imgs_, קושר, _åber, _meud_,
   {{0x6f076037,0xaca30134,0x63ad0167,0x68fb6038}},	//   _najc, _baịn, _dtan, leud,
   {{0xe2976039,0x656f00ac,0xfd640019,0xd04800a7}},	//   дар_, boch, _chuộ, ələs,
   {{0x656f603a,0x212b00f0,0x255601d3,0x2cbf00f0}},	//   coch, _coch_, tālu_, _neud_,
   {{0x212b02dc,0xa49400bf,0x1b040033,0x2732020a}},	// [5980] _doch_, _سیست, লাতে_, _sâni_,
   {{0x03d7006e,0x394f0090,0x68fb603b,0xbf9b02ac}},	//   _קוים_, _lmgs_, heud, _prêr,
   {{0xa3d60d7e,0x68fb0084,0x6146162b,0x831b00c1}},	//   ांक_, keud, _жена, _וויז,
   {{0xa2aa0251,0x2cbf0441,0x212b603c,0xec7a4447}},	//   जुर्, _ceud_, _goch_, опе_,
   {{0x60c4603d,0x0b8a075f,0xe4e600b7,0x68fb603e}},	//   maim, оски_, _कानि_, deud,
   {{0x656f603f,0x68e20036,0x64460634,0x00000000}},	//   zoch, _scod, izki, --,
   {{0x656f3aca,0x62980074,0x255601d3,0x9f4b00ee}},	//   yoch, _úvod, nāls_, _escó_,
   {{0x3f9802a7,0x60c46040,0x3d060f53,0x4ae000b7}},	//   _hiru_, naim, _सोचे_, _नावव,
   {{0x6f07023e,0x3f9803e3,0x656f0d8d,0xdce9009e}},	//   _yajc, _kiru_, voch, _sieħ,
   {{0x644600a5,0x60c46041,0x656f6042,0x63ad0095}},	//   dzki, haim, woch, _rtan,
   {{0x60c46043,0xd5b70ab3,0x6138002b,0xdce90090}},	//   kaim, мся_, _píll, _qieħ,
   {{0xb4d9000c,0x2bd2009d,0x20000174,0x6d424ac9}},	//   ाले_, सळपा, kwii_, nhoa,
   {{0x656f6044,0x69a400a5,0xdce903e5,0x212b1428}},	//   roch, _चंडी, _wieħ, _roch_,
   {{0xf64f00fb,0xc87f01bf,0xdce9003d,0xfd6400fe}},	//   ائی_, üße_, _tieħ, _phuộ,
   {{0x656f6045,0x439444aa,0x212b6046,0xc80800de}},	//   poch, тарс, _poch_, _hở_,
   {{0x60c403b4,0x3f986047,0x61380575,0x8afe0022}},	//   gaim, _airu_, _fílm, moƙu,
   {{0xe8110d0b,0x3f9826f7,0xbf9b020d,0x6d422aea}},	// [5990] ़िया_, _biru_, _crêp, dhoa,
   {{0x212b05aa,0xc8080028,0xfd640028,0x63ad01d3}},	//   _woch_, _mở_, _thuộ, ķinā,
   {{0x212b0505,0x7bc91912,0x3f980a00,0x60c46048}},	//   _toch_, _sveu, _diru_, baim,
   {{0x27ff0150,0xd9f80096,0x60c40503,0xa3d619af}},	//   ywun_, ंबईत_, caim, _हिम_,
   {{0xc80800de,0x256429e4,0x00000000,0x00000000}},	//   _nở_, nıla_, --, --,
   {{0xfbd00979,0x394f0090,0x00000000,0x00000000}},	//   شته_, _smgs_, --, --,
   {{0x18a504a1,0x2ca002ef,0x2cbf01b9,0xa49b009c}},	//   найм, žida_, _teud_, ceòg,
   {{0x6d426049,0xb4d9604a,0x752d010a,0xc80800fe}},	//   choa, ालो_, _noaz, _bở_,
   {{0x69dc00d6,0x0bd50037,0x68fb443b,0x2fc9604b}},	//   _åren, _سياح, reud, nsag_,
   {{0x7d090113,0x7c84604c,0x60c4604d,0xc80800de}},	//   _haes, _русе, zaim, _dở_,
   {{0x7d09604e,0x7d1b0170,0x752d604f,0x68fb00c2}},	//   _kaes, _knus, _boaz, peud,
   {{0x6131017a,0x255601d3,0x777a01ff,0x644602db}},	//   _måls, vāls_, altx, tzki,
   {{0xd90f0434,0x752d6050,0x60c41fef,0x7d1b024a}},	//   _میں_, _doaz, vaim, _mnus,
   {{0xa85600a1,0x66e5002d,0x255601d3,0x395f00e4}},	//   _אינה_, _чока, tāls_, lnus_,
   {{0x60c46051,0x7d1b6052,0x64466053,0x6d42020b}},	//   taim, _onus, szki, yhoa,
   {{0x395f6054,0x26c50372,0x752d0634,0x7d1b0172}},	//   nnus_, lalo_, _goaz, _nnus,
   {{0x03964faa,0x01632c22,0x60c43d31,0x3f981c16}},	// [59a0] _проя, укто, raim, _piru_,
   {{0x60c46055,0x752d01c8,0x61310973,0x00000000}},	//   saim, _zoaz, _sålt, --,
   {{0x60c46056,0x3f986057,0x7d09010a,0xb3450052}},	//   paim, _viru_, _baes, saçë,
   {{0x26c56058,0x9f400428,0x395f023e,0x0ee20980}},	//   halo_, stià_, jnus_, _पावड,
   {{0x26c56059,0x3f98605a,0x7d09605b,0x62810220}},	//   kalo_, _tiru_, _daes, ýlov,
   {{0xdd3101d4,0x26c5605c,0x06d50081,0x23a60181}},	//   _təşk, jalo_, ত্তি, _môj_,
   {{0xc8080028,0x7c220072,0x7d09030a,0xc3330142}},	//   _sở_, sxor, _faes, רוו_,
   {{0x7d1b00e7,0x395f605d,0x2bc943e2,0x25644881}},	//   _gnus, gnus_, _रिचा, yıla_,
   {{0xb9084883,0x6d401f4f,0x752d01b9,0x9a6a0260}},	//   _बा_, _ilma, _roaz, _کمال_,
   {{0x47340394,0x6564605e,0x78a90451,0xc8080023}},	//   тнос, _ajih, acev, _vở_,
   {{0x0f570054,0x7d0901af,0x613101df,0xd6d71402}},	//   תיים_, _yaes, _målr, хты_,
   {{0x98a3188d,0x613802c6,0x256429e4,0x39810231}},	//   _бице, _dílk, tıla_, pósa_,
   {{0x26c5605f,0x29570130,0xdb00023b,0x6b9a0172}},	//   balo_, _אסאך_, _numë, _kitg,
   {{0xdb000149,0xd9f4009d,0x25640abd,0x6b9a0078}},	//   _utmä, _आहात_, rıla_, _jitg,
   {{0x6d4008fd,0x6b9a02dc,0x9268513e,0x69ca6060}},	//   _olma, _mitg, ерта_, nsfe,
   {{0x867b00ca,0xab66007f,0x6f1c078e,0x00000000}},	//   _מרוו, leżą, _anrc, --,
   {{0x69d80364,0xdfd4007b,0x7d1d00ee,0x00000000}},	// [59b0] hrve, лоты, _òssi, --,
   {{0x6d406061,0xa3d6049d,0x7d096062,0x657d6063}},	//   _alma, _हित_, _saes, llsh,
   {{0x7d09013d,0x316003a9,0x31720063,0x69ca007e}},	//   _paes, bniz_, boyz_, jsfe,
   {{0x62850087,0x2fcb0095,0x69ca0973,0x00000000}},	//   _izho, _tvcg_, dsfe, --,
   {{0x26c50c69,0x69d82819,0x7d0900aa,0x7999084e}},	//   yalo_, erve, _vaes, _riww,
   {{0x6d406064,0x2129033b,0xe0df01f7,0x6b9a6065}},	//   _elma, ljah_, _blòg_, _citg,
   {{0xa96936e9,0x78a900d3,0x69ca3318,0x00000000}},	//   мика_, tcev, gsfe, --,
   {{0x26c56066,0x1a6800cd,0x21296067,0x6d585750}},	//   walo_, رینی_, njah_, évat,
   {{0x395f6068,0xfbd000cd,0x78a96069,0x69d8606a}},	//   rnus_, _هتل_, rcev, arve,
   {{0x78a900e5,0x395f0683,0xdb00015e,0x65762c28}},	//   scev, snus_, _numè, _skyh,
   {{0x99d40f43,0x69d80106,0x2c870032,0x00000000}},	//   _متنا, crve, _fìdí_, --,
   {{0xb4ac1349,0x26c5606b,0x2129606c,0x2bf5007a}},	//   गडे_, salo_, jjah_, _इहां_,
   {{0x21290167,0x8afe03e3,0x00000000,0x00000000}},	//   djah_, moƙr, --, --,
   {{0x43750d84,0x290d02a7,0x27ed606d,0x491900b6}},	//   густ, ldea_, mten_, भाको_,
   {{0x27ed02d6,0xdb0003a9,0x2732020a,0x00000000}},	//   lten_, _dumè, _vânt_, --,
   {{0x290d606e,0x27ed606f,0x65640350,0x01636070}},	//   ndea_, oten_, _ujih, аксо,
   {{0x27ed6071,0x31606072,0xe0df022b,0xd5ac0018}},	// [59c0] nten_, rniz_, _amòs_, _وہی_,
   {{0x27ed4a37,0x6d9302a1,0x7bcb6073,0x127a0037}},	//   iten_, _għaz, dsgu, _يحدث_,
   {{0x27ed6074,0x200d00d9,0x333b040a,0x291d0129}},	//   hten_, _šeit_, _חתימ, _onwa_,
   {{0x27ed4ea6,0x63a46075,0x6b9a6076,0x6dac0491}},	//   kten_, _kuin, _sitg, _ağac,
   {{0x27ed6077,0xead4088c,0x6b9a0090,0x7bcb0973}},	//   jten_, голь, _pitg, gsgu,
   {{0x63a46078,0x291d0134,0x27ed038c,0x69ca6079}},	//   _muin, _anwa_, dten_, tsfe,
   {{0x2d96004b,0x27ed607a,0x61ee5968,0x63a43486}},	//   _арас, eten_, ntbl, _luin,
   {{0x27ed50db,0x69ca607b,0x69d8607c,0x6138607d}},	//   ften_, rsfe, rrve, _bíli,
   {{0x27ed607e,0xed5705b6,0x6138016d,0xa77400c2}},	//   gten_, _рот_, _cíli, ллич,
   {{0x6b9a1d19,0x779109b4,0x779200cd,0x61380076}},	//   _uitg, مینا, جیتا, _díli,
   {{0xdb0004ea,0x27ed607f,0x2cad00f0,0xe5140442}},	//   _numé, aten_, _yfed_, _तोहि_,
   {{0xa927013f,0x63a40cc2,0x29240146,0x291d00f9}},	//   gužė, _buin, ávač_, _gnwa_,
   {{0x0ee233d9,0x27ed0505,0x63a46080,0x67d4139c}},	//   _पांड, cten_, _cuin, _солу,
   {{0x63a40514,0x9f40007b,0xf09f009c,0x00000000}},	//   _duin, ntiä_, _sgà_, --,
   {{0x671f000f,0x35a3001f,0xf1a42887,0x00000000}},	//   बारक_, _кајг, иртн, --,
   {{0x63a40a6c,0xe807009d,0x62850087,0x12e30033}},	//   _fuin, वटचा_, _vzho, য়েদ,
   {{0x403402fd,0x212908d3,0xdb002d28,0xf1942458}},	// [59d0] аетс, rjah_, _eumé, рить,
   {{0x44396081,0x02b7303f,0xdb0000fd,0x7ed41487}},	//   mys_, _अभिभ, _fumé, لزما,
   {{0x44396082,0xa3df152c,0x27ed02a7,0xb05b01bf}},	//   lys_, दूर_, zten_, _geän,
   {{0x27ed5575,0x753d01f9,0x628a0231,0x7bcb45d9}},	//   yten_, nksz, _ºfor, tsgu,
   {{0x44396083,0x27ed0704,0x50da00ca,0x4ea74444}},	//   nys_, xten_, _אקרא, _арба,
   {{0x7ae3023e,0x7bcb07ee,0xc43c006e,0x00000000}},	//   ugnt, rsgu, ותדי, --,
   {{0x2b890181,0x61386084,0x49991278,0xe8df0129}},	//   júce_, _síli, нтия_, shọn_,
   {{0x09f600e3,0x44390138,0x2b890031,0x98a300c6}},	//   افية_, kys_, dúce_, ėjį_,
   {{0x290d6085,0x6d593628,0x27ed6086,0xb8cb04f1}},	//   rdea_, miwa, uten_, _खल_,
   {{0x6d596087,0x44396088,0xfb876089,0x26c33906}},	//   liwa, dys_, _рыбн, újo_,
   {{0xa01b0084,0x28dc0f35,0x443901ee,0x00000000}},	//   _hyöd, _याचि, eys_, --,
   {{0x6d59608a,0x63a4608b,0x6e2105fe,0x44390178}},	//   niwa, _puin, _àlbu, fys_,
   {{0x63a4608c,0xd456004d,0x4439608d,0x2007007f}},	//   _quin, утнь, gys_, łnij_,
   {{0x6d5900a6,0x03a300c2,0x91e60b9e,0x61ee304c}},	//   hiwa, сиро, логе, ttbl,
   {{0x6d592418,0xc5d500d6,0x32434c66,0xdde20234}},	//   kiwa, _сіль, берг, _žužu,
   {{0x63a4608e,0x6d59608f,0x44396090,0x61ee6091}},	//   _tuin, jiwa, bys_, rtbl,
   {{0xe81609d0,0x6d596092,0xd9d0142e,0x61ee6093}},	// [59e0] तिया_, diwa, _सट्ट, stbl,
   {{0x06d50081,0x73060cfc,0x2bc60285,0x00000000}},	//   ত্রি, _споз, रीफा, --,
   {{0x2bc6074c,0x00000000,0x00000000,0x00000000}},	//   रीना, --, --, --,
   {{0x6d596094,0xd7d4000f,0xe816030b,0x869a006e}},	//   giwa, _दिलच, तिमा_, גיעז,
   {{0x9f4000c2,0xa2ba1677,0xafe3468d,0x00000000}},	//   ttiä_, ्रप्, _лоял, --,
   {{0xe0df05aa,0x69c10178,0x00000000,0x00000000}},	//   _glòb_, _bwle, --, --,
   {{0x6d596095,0x443916c3,0x7ec800e8,0x637b044c}},	//   biwa, zys_, rūpē, mînt,
   {{0x9f400084,0xaea10491,0x443900c2,0x237a0167}},	//   stiä_, ğışl, yys_, _lkpj_,
   {{0x3b860e18,0x273b0019,0xbc660831,0x69c103e5}},	//   _благ, _kênh_, _свак, _ewle,
   {{0x17f70080,0x370623f9,0x07f70037,0xf3fa0033}},	//   ارية_, учив, اريع_, ইটার_,
   {{0xb52106ec,0x44396096,0xab930080,0xa2ba06ed}},	//   यालय_, wys_, _اللغ, ्रन्,
   {{0x44390ff8,0x3ce66097,0x98a60c79,0x2b890031}},	//   tys_, ngov_, _сиде, rúce_,
   {{0x78a2039f,0x00000000,0x00000000,0x00000000}},	//   _igov, --, --, --,
   {{0x44396098,0x6d596099,0x237a02a1,0xae0409a1}},	//   rys_, ziwa, _ckpj_, रबान_,
   {{0x443f0029,0x4439609a,0x6d430138,0xd5af00ae}},	//   šu_, sys_, ūnai, _ыс_,
   {{0x6ee200b6,0xb3570103,0x0ee2320a,0x00000000}},	//   _पाउँ, ئیگا_, _पाउड, --,
   {{0x7d02609b,0x2bc6030b,0x9099008f,0x9f552b66}},	// [59f0] deos, रीमा, тват_, авач,
   {{0x6d59609c,0x24890063,0x3e6b00e5,0x00000000}},	//   wiwa, _izam_, ншен_, --,
   {{0x6d5900a6,0x539a00a1,0x78a20580,0xa01b00c2}},	//   tiwa, _שיתו, _ogov, _syöd,
   {{0x6138609d,0x78a20372,0x2dd80076,0x91ba00d7}},	//   _sílv, _ngov, ابلة_, _שמרי,
   {{0x6d59609e,0x9f4900e3,0x6f0e0154,0x50f43f54}},	//   riwa, ltaí_, _fabc, _узят,
   {{0x6d59609f,0x78a260a0,0xe1f00504,0x61380503}},	//   siwa, _agov, _بسی_, _dílu,
   {{0xdea400bf,0x2ba1250d,0x2d8760a1,0x69251e65}},	//   _ایمی, _ओंका, ïnes_, имка,
   {{0x7c3960a2,0xa3d602d5,0x8cc8177a,0x7d020956}},	//   pywr, _हिल_, _موفق_, ceos,
   {{0x9f490080,0xaae70867,0x24890063,0x00000000}},	//   htaí_, _مساو, _nzam_, --,
   {{0x78a20036,0x2d8d0167,0x7a1c00ae,0x2d9e0956}},	//   _egov, _hhee_, _bătă, _éter_,
   {{0x2d8d023e,0x248953e1,0xa3e860a3,0x36690d86}},	//   _khee_, _azam_, मून_, тано_,
   {{0x201960a4,0xf8b00103,0x7a1c078e,0x00000000}},	//   _orsi_, _ٹکٹ_, _dătă, --,
   {{0x5ed00081,0x61380037,0x03a623b8,0x60c602ac}},	//   স্টে, _mílt, риго, _rekm,
   {{0x290f60a5,0x60c660a6,0x9af303e3,0x2b1e007f}},	//   _haga_, _sekm, _ƙeƙe_, पाएँ_,
   {{0x290f0694,0xf67900c1,0x248960a7,0x26d100d4}},	//   _kaga_, _באַמ, _ezam_, ózou_,
   {{0x26c700f0,0x00000000,0x00000000,0x00000000}},	//   _heno_, --, --, --,
   {{0xb4e2007d,0x6f0e006c,0x290f60a8,0xaca30134}},	// [5a00] दली_, _pabc, _maga_, ghọb,
   {{0x290f081d,0xdce90181,0x200b009c,0x20190141}},	//   _laga_, _cieľ, _dsci_, _drsi_,
   {{0x26c760a9,0x60c602dd,0x38690102,0x32db040a}},	//   _meno_, _tekm, _þarf_, _בחינ,
   {{0x2d8d0129,0x290f60aa,0x2d9f009c,0xe5f6006e}},	//   _chee_, _naga_, _ciue_, יזער_,
   {{0x7d0260ab,0x2d8d1443,0x3ceb0094,0x6f0e026d}},	//   reos, _dhee_, _živá_, _tabc,
   {{0x26c760ac,0x386000cb,0xc60c0033,0x7d0260ad}},	//   _neno_, _žiro_, ষমতা_, seos,
   {{0x290f60ae,0xe60703ef,0x2bd2030b,0x84e60caf}},	//   _baga_, _بش_, _सिका, _कांट_,
   {{0x2d8d0134,0x290f041c,0xf98f0190,0x98b700e5}},	//   _ghee_, _caga_, وبي_, алът_,
   {{0x8ad65d50,0x290f2bc2,0x1ae602fd,0x8c434db9}},	//   _نتائ, _daga_, _возм, _дете,
   {{0x61fe02ec,0x6618025b,0x26c702dd,0xaae01efb}},	//   _oppl, _prvk, _ceno_, _नाटक,
   {{0x290f60af,0x333360b0,0x63b62f77,0x248003a9}},	//   _faga_, _roxx_, _atyn, _ayim_,
   {{0x78a202e6,0x26c70172,0x7a1c020a,0x25a060b1}},	//   _ugov, _eeno_, _vătă, _ciil_,
   {{0x61fe3181,0x25720146,0x26c70231,0x7d1d016d}},	//   _appl, nály_, _feno_, _ósse,
   {{0x290460b2,0x3946023e,0x290f60b3,0x7a1c044c}},	//   lema_, _hlos_, _zaga_, _tătă,
   {{0x26cc0d9f,0x290f60b4,0x659500d3,0x27e460b5}},	//   mado_, _yaga_, _лаку, lumn_,
   {{0x26cc0b0b,0xa37b0161,0x9f490037,0x290f0188}},	//   lado_, drõe, rtaí_, _xaga_,
   {{0x9f490037,0x4ea75cac,0x2904010a,0x83870b2f}},	// [5a10] staí_, ареа, iema_, _выне,
   {{0x26cc0b0b,0x290460b6,0x20191197,0x26c73401}},	//   nado_, hema_, _vrsi_, _xeno_,
   {{0x290460b7,0x2b890181,0xadf50508,0x26cc0558}},	//   kema_, júca_, спеш, iado_,
   {{0x26cc60b8,0x290460b9,0x2bd20cce,0x61380076}},	//   hado_, jema_, _सिखा, _díls,
   {{0x26cc60ba,0x290f60bb,0x29040239,0x60cd60bc}},	//   kado_, _raga_, dema_, maam,
   {{0x60cd60bd,0x26cc60be,0x7db71a37,0x394660bf}},	//   laam, jado_, _نصرا, _alos_,
   {{0x26cc0d9f,0xdd9b002d,0xa2ba0f38,0xd20a0142}},	//   dado_, _аша_, ्रत्, ָלפֿ,
   {{0x290460c0,0x394660c1,0x26cc0d5a,0x6f05061d}},	//   gema_, _clos_, eado_, lehc,
   {{0x290f60c2,0x26cc60c3,0x25a000ec,0x26c760c4}},	//   _vaga_, fado_, _riil_, _peno_,
   {{0x26cc2733,0xbb8500e3,0x60cd60c5,0x394660c6}},	//   gado_, _الطي, haam, _elos_,
   {{0x290f4db4,0x26c70141,0x78ac00c4,0x49da01f9}},	//   _taga_, _veno_, _šovš, _مانگ_,
   {{0x60cd03cf,0x2009006d,0x26c72df7,0x394660c7}},	//   jaam, kwai_, _weno_, _glos_,
   {{0xe72e02fd,0x60cd0694,0xa3df04f1,0x6dac028e}},	//   _ее_, daam, दंग_, _ağal,
   {{0x26cc60c8,0x25a0008a,0x9f400037,0x68e960c9}},	//   cado_, _wiil_, stiú_, lged,
   {{0x25a0019c,0x5ede0033,0x60cd1cab,0x9f400231}},	//   _tiil_, ন্ডে, faam, quié_,
   {{0x60cd008a,0x661c052f,0x2ca000e7,0xa37b0131}},	//   gaam, ærke, židi_, vrõe,
   {{0x75245a3d,0xa2ba009d,0x200903e3,0x69dc00f2}},	// [5a20] _iniz, ्रद्, gwai_, _årev,
   {{0x2bab000f,0x32461e6d,0xa37b0231,0x00000000}},	//   _चढ़ा, _геог, trõe, --,
   {{0x61fe60ca,0xa75a07a6,0x75240a7f,0x139b0327}},	//   _uppl, נדער, _kniz, _תביע,
   {{0x26cc0b0b,0xeabf00de,0x0c26084c,0x68e9029a}},	//   zado_, _đùa_, ймен, jged,
   {{0x26cc60cb,0x6b460088,0x68e91030,0xd57b006e}},	//   yado_, _aðga, dged, אָגר,
   {{0xf767172a,0x26cc137f,0x257210a8,0x290460cc}},	//   _را_, xado_, rály_, wema_,
   {{0x26cc0d9f,0x290460cd,0x68e9443d,0xdce260ce}},	//   vado_, tema_, fged, lnoč,
   {{0x2be00b94,0x26cc00ac,0x57b460cf,0x68e960d0}},	//   _निपा, wado_, обит, gged,
   {{0x26cc0b0b,0x290460d1,0xdb010131,0x394602ac}},	//   tado_, rema_, _milê, _vlos_,
   {{0x29041ee3,0x60cd60d2,0x3ae800bf,0xeb9a037e}},	//   sema_, zaam, _خبری_, _сиз_,
   {{0x26cc60d3,0x29040010,0x60cd60d4,0xe816074c}},	//   rado_, pema_, yaam, तिहा_,
   {{0x26cc222b,0xdb0208a8,0x394600c2,0x6d4201e9}},	//   sado_, mpoñ, _ulos_, nkoa,
   {{0xb8960080,0x60cd60d5,0x6d420634,0x4aac00aa}},	//   _الشع, vaam, ikoa, _चलाव,
   {{0x60cd3064,0x1659001c,0xdb0b0f63,0x752448d3}},	//   waam, اسیک_, ppgå, _eniz,
   {{0x6fa2149b,0x644f60d6,0xdce901d3,0x6d4260d7}},	//   _कंजू, szci, _pieļ, kkoa,
   {{0x777a01ff,0x00000000,0x00000000,0x00000000}},	//   lotx, --, --, --,
   {{0x60cd1f85,0xddd40206,0x00000000,0x00000000}},	// [5a30] raam, _čašn, --, --,
   {{0x60cd60d8,0x20096025,0xdb0000ee,0xed5900c4}},	//   saam, rwai_, _numà, _smž_,
   {{0x6d4b0150,0x60cd00c2,0xa295018a,0xdce20206}},	//   thga, paam, _фані, anoč,
   {{0x60cd026d,0x777a01ff,0x6d420113,0x00000000}},	//   qaam, hotx, gkoa, --,
   {{0x777a0634,0x656d60d9,0xffe4004b,0x00000000}},	//   kotx, _mjah, _нюрн, --,
   {{0x3da73b21,0x7ae70f1e,0xeb992de9,0x6ef2003e}},	//   _граб, сюдж, шил_, rðbó,
   {{0x68e90a9f,0xdb000610,0x777a0062,0x00000000}},	//   tged, _atmó, dotx, --,
   {{0x5ede0081,0x05240033,0x656d3c0d,0x00000000}},	//   ন্দে, _পত্র_, _njah, --,
   {{0xfbe005a5,0x68e960da,0x2be0142e,0xdd94004b}},	//   _नियम, rged, _निया, _хаты,
   {{0xf7710678,0x75240ca7,0x68e960db,0x6d4901b9}},	//   باب_, _sniz, sged, _hlea,
   {{0xa2ba034d,0xf50660dc,0x6d491175,0x63bd0381}},	//   ्रस्, озно, _klea, epsn,
   {{0xc3290054,0x2bc6143d,0x2f0a007f,0x2be00b3a}},	//   _בו_, रीवा, mógł_, _निमा,
   {{0x395f60dd,0x656d03a9,0x777a01ff,0x00000000}},	//   mius_, _djah, botx, --,
   {{0x395f60de,0x394d00c9,0x957d00a5,0x6d4202a7}},	//   lius_, lhes_, stąp, zkoa,
   {{0xe29a2e98,0x69dc0d3e,0x2be00b7f,0x6d5b06b0}},	//   рав_, _året, _निभा, _omua,
   {{0x2bcf00a3,0xa2ba009d,0x395f60df,0xd0120018}},	//   _सौभा, ्रह्, nius_, ولز_,
   {{0xdb0101e5,0x2b890206,0x00000000,0x00000000}},	// [5a40] _cilë, júco_, --, --,
   {{0x6d493963,0x25e01b79,0xdee32657,0x6d5b60e0}},	//   _alea, _किमी_, дофи, _amua,
   {{0x395f013f,0x6d4260e1,0x6d4960e2,0x10a614fb}},	//   kius_, tkoa, _blea, _минн,
   {{0x6d49378d,0x4c864c88,0xa2ba0ed5,0x395f0483}},	//   _clea, олев, ्रव्, jius_,
   {{0xa01b60e3,0x394d60e4,0x6d490a02,0x6d420634}},	//   _szöv, dhes_, _dlea, rkoa,
   {{0x6d4201e9,0x6d5b010a,0xdb010154,0x68400139}},	//   skoa, _emua, _jilè, _ládú,
   {{0x6d492bc0,0x8fa30aeb,0xb53a0139,0x6d5b01b9}},	//   _flea, _царе, _akọ́, _fmua,
   {{0x6d4909f7,0x394d60e5,0x684000e3,0xa01b0084}},	//   _glea, ghes_, _nádú, _myön,
   {{0xdb0222e7,0xd7c40096,0x777a01ff,0xa01b00ce}},	//   spoñ, लींच, totx, _lyön,
   {{0x656d0449,0x9abc0090,0x2d8601ff,0x00000000}},	//   _sjah, _inċo, lloe_, --,
   {{0x2bc613ae,0xceb300ca,0x31600174,0xd0130033}},	//   रीरा, וית_, kiiz_, সময়_,
   {{0xd90e00d0,0x394d128b,0x395f60e6,0xe9b70068}},	//   _شیخ_, ches_, cius_, _بچوں_,
   {{0xd7ef00e3,0x68400139,0xb7181d62,0xd11b0be5}},	//   _لكن_, _dádú, _голф_, _पोषण_,
   {{0xb4db00ee,0x00000000,0x00000000,0x00000000}},	//   ckàn, --, --, --,
   {{0xdb0160e7,0x656d0483,0x00000000,0x00000000}},	//   _dilè, _tjah, --, --,
   {{0xa3e80096,0x656d60e8,0x9f400381,0x00000000}},	//   मूह_, _ujah, brië_, --,
   {{0x657d434a,0x00000000,0x00000000,0x00000000}},	// [5a50] mosh, --, --, --,
   {{0x657d60e9,0x3ea7038c,0x6d49152f,0xa2950f1e}},	//   losh, ønt_, _slea, _напі,
   {{0x6d4960ea,0xa01b0018,0x63ad60eb,0x200200c4}},	//   _plea, _gyön, _huan, _epki_,
   {{0x63ad1ee3,0x395f05fe,0x394d0052,0xd5fb006e}},	//   _kuan, xius_, xhes_, שפאר,
   {{0x395f0138,0x2bc6030b,0xdb0060ec,0x63a50f18}},	//   vius_, रीला, _sumá, _kihn,
   {{0x657d60ed,0x63ad60ee,0x21390167,0xdb0131bb}},	//   hosh, _muan, _hosh_, _kilé,
   {{0x395f60ef,0x2bd702e8,0xeaf800e3,0x657d60f0}},	//   tius_, _ठिका, ترنت_, kosh,
   {{0x6d5b0129,0xe0df0154,0x657d60f1,0x628560f2}},	//   _umua, _amòz_, josh, _myho,
   {{0x395f1536,0x657d36d4,0xd04d0022,0x63ad0707}},	//   rius_, dosh, rgaɗ, _nuan,
   {{0x673860f3,0x395f013f,0x394d60f4,0x998700c6}},	//   _covj, sius_, shes_, tynų_,
   {{0x628560f5,0x394d00fd,0x395f004b,0xdce90ac3}},	//   _nyho, phes_, pius_, _lječ,
   {{0xa3d70067,0x657d60f6,0xdcfb0234,0xdb0100b3}},	//   ाओं_, gosh, _okuč, _silè,
   {{0x63ad0eb8,0x9fd600c7,0x63a51528,0xdb0160f7}},	//   _cuan, _সঙ্গ, _bihn, _ailé,
   {{0x63ad60f8,0x7bc90239,0x63a50113,0x6285084e}},	//   _duan, _mweu, _cihn, _byho,
   {{0x628502e0,0x3cff025b,0x657d0201,0x21390c2f}},	//   _cyho, _obuv_, bosh, _bosh_,
   {{0x25e002e8,0x55da0130,0x3860042d,0x2002005c}},	//   _किती_, _פֿונ, _žiri_, _ppki_,
   {{0x63ad60f9,0xb4d809a0,0xa3d609b0,0x213960fa}},	// [5a60] _guan, ाणी_, _हिट_, _dosh_,
   {{0x442060fb,0xdce90292,0xa01b0084,0xdb01300f}},	//   _iri_, _dječ, _työn, _filé,
   {{0x62850150,0x764132dd,0xdb0103a9,0x63ad6072}},	//   _gyho, nyly, _gilé, _zuan,
   {{0x8fa61d7b,0x63ad0022,0x442060fc,0x2be0034d}},	//   _наме, _yuan, _kri_, _निदा,
   {{0xa2c10096,0x63ad0023,0x7c2605db,0x00000000}},	//   वरच्, _xuan, _škrb, --,
   {{0x60c401b3,0x7bc902ad,0x657d60fd,0x69c800f9}},	//   lbim, _dweu, zosh, _pwde,
   {{0x657d60fe,0x66e20139,0x00000000,0x00000000}},	//   yosh, _líkà, --, --,
   {{0x442060ff,0x4ddb00ca,0x23dc53b8,0x386905db}},	//   _ori_, _לחלו, _बिंद, _žara_,
   {{0x67380ea3,0x442006c0,0xb9046100,0xebe30a28}},	//   _povj, _nri_, _भए_, _потп,
   {{0x63ad0496,0x442700ef,0xd7dd009d,0x95d80396}},	//   _ruan, _ăn_, _मिरच, одот_,
   {{0x44206101,0x657d6102,0x63ad6103,0x644000f2}},	//   _ari_, tosh, _suan, ømin,
   {{0x44206104,0x63ad01e8,0xe0df0154,0x6dac0233}},	//   _bri_, _puan, _elòj_, _işad,
   {{0x63ad1a91,0x657d6105,0x4420260a,0x9f400314}},	//   _quan, rosh, _cri_, ntió_,
   {{0x44200162,0x657d6106,0xdce90ea3,0x63a20036}},	//   _dri_, sosh, _rječ, _èonl,
   {{0x44206107,0xb9090019,0xdce9053f,0x657d6108}},	//   _eri_, _nghề_, _sječ, posh,
   {{0x62850074,0x657d1ffb,0x442000ca,0x94ab0a3a}},	//   _vyho, qosh, _fri_, _утка_,
   {{0x44206109,0xf485015a,0xe81f0bf5,0x00000000}},	// [5a70] _gri_, _تاثی, बिया_, --,
   {{0x2bcf110f,0xdce90268,0x26ce610a,0xda1c0d75}},	//   सीफा, _vječ, _jefo_, पटात_,
   {{0x2139030a,0xc5f801d3,0x60c404a8,0x00000000}},	//   _tosh_, ntē_, bbim, --,
   {{0x79820134,0x270900a3,0x00000000,0x00000000}},	//   _nkow, _वस्र_, --, --,
   {{0xfc460019,0x1be9004d,0x26dc007e,0x6dac00ae}},	//   _đích_, ідки_, _odvo_, _aşad,
   {{0xdb0903a3,0x7982610b,0x25ed0285,0x98bf00c4}},	//   _önün, _akow, _अमली_, rkuč_,
   {{0xa3b440c1,0x60cf610c,0x6b4f02b6,0x7d1d00ee}},	//   _जून_, _kecm, _nøge, _ósso,
   {{0x3a3a0212,0x18a50565,0x673c0212,0xdb0009a1}},	//   äppa_, майм, örjn, _aumä,
   {{0x24c50081,0xd7ee0076,0x7d0b610d,0x02bf12f2}},	//   ্লাহ, لكي_, megs, ्राभ,
   {{0x6b4f01c5,0xb4e6022d,0x25790103,0x4420610e}},	//   _bøge, कल्प_, mély_, _rri_,
   {{0x6ad30081,0x26ce0383,0xa50a1d3f,0x4420610f}},	//   _সাপো, _defo_, оена_, _sri_,
   {{0x44206110,0xb4d802e8,0x9f400610,0x52c61687}},	//   _pri_, ाणे_, rrié_, वर्स,
   {{0x78ab0090,0x799b6111,0x00000000,0x00000000}},	//   _iggv, mmuw, --, --,
   {{0x889a00a1,0x79896112,0x9f4000fd,0x442004e3}},	//   _ובני, llew, prié_, _vri_,
   {{0x03a324d3,0x26c55cf2,0x79890a4b,0x66030062}},	//   тиро, mblo_, olew, _upnk,
   {{0x61e10103,0xa01b00c2,0x799b0d2a,0x26ce6113}},	//   álla, _työl, nmuw, _zefo_,
   {{0x44206114,0x60c46115,0x7d0b0d5b,0xa01b0103}},	// [5a80] _uri_, rbim, degs, _ször,
   {{0x60c40063,0x25790103,0x00000000,0x00000000}},	//   sbim, dély_, --, --,
   {{0x2be00251,0xe29a6116,0xb7d40139,0x798902ac}},	//   _निहा, _фан_, _iṣeb, klew,
   {{0x25e00067,0xe8df0019,0x2fc01cab,0xf3910af0}},	//   _किसी_, _trộm_, ppig_, _iṣan_,
   {{0xdca3124c,0x00000000,0x00000000,0x00000000}},	//   ваци, --, --, --,
   {{0x9f406117,0x79890051,0xe457006e,0x7d0b00bc}},	//   rtió_, elew, וינט_, aegs,
   {{0x9f400472,0xdb000e74,0xdee31009,0x26ce0381}},	//   stió_, _rumä, _јоси, _refo_,
   {{0xa8140237,0xb81419e8,0x6b4f02b6,0x26ce010a}},	//   едиш, едиј, _røge, _sefo_,
   {{0x6b4f0021,0x36d41bb8,0xa91d14f3,0x2afb00aa}},	//   _søge, нопр, dožd, ल्हु_,
   {{0xeeeb0019,0x4b2633c6,0x998908c5,0x7bc26118}},	//   _đừng_, _تعرف, ćaš_, mpou,
   {{0x79896119,0x6aba0113,0x00000000,0x00000000}},	//   blew, _iftf, --, --,
   {{0xc86623a3,0x69d83b56,0xe3c703be,0xc5f800d9}},	//   _отли, msve, íños_, rtē_,
   {{0x69d85748,0x249200a5,0x7bc2611a,0xc5f801d3}},	//   lsve, _czym_, npou, stē_,
   {{0x69d80a13,0xc5f800e8,0xa2a02647,0x79800350}},	//   osve, ptē_, _गृह्, lomw,
   {{0xe8160be4,0x442d00d3,0xd13b2768,0xf1a7232c}},	//   तिका_, ţe_, оха_, дран,
   {{0x69d8611b,0x5ec80081,0x24780129,0x00000000}},	//   isve, _লাগে, ọma_, --,
   {{0x2be004f1,0xa01b00c2,0x60cf01d3,0xe01c0861}},	// [5a90] _निषा, _työm, _vecm, निषद_,
   {{0xa91d0660,0xa01b00c2,0x69d8611c,0x7d0b5c63}},	//   može, _hyök, ksve, wegs,
   {{0xa91d28f9,0x7d0b0018,0x69d80126,0x25a9611d}},	//   lože, tegs, jsve, _kial_,
   {{0x2be004dd,0x656f611e,0x69d8611f,0x24890022}},	//   _निशा, nnch, dsve, _kyam_,
   {{0x7bc4002d,0x7d0b6120,0x656f6121,0x69da0141}},	//   ţiun, regs, inch, _avte,
   {{0xfbe00b94,0x98af0067,0x656f042c,0x69d86122}},	//   _निरम, _mogą_, hnch, fsve,
   {{0x69d86123,0x533800c1,0xf9850c3f,0xa91d0206}},	//   gsve, ונגן_, нгко, hože,
   {{0x6e94571b,0x3f810146,0x2d78077e,0x25a9009c}},	//   _рису, lohu_, včeg_, _nial_,
   {{0x248901fa,0x2d9d0a15,0x79896124,0xa0e301d3}},	//   _nyam_, mmwe_, rlew, dēļā_,
   {{0x656f0396,0xa91d0335,0x27e20146,0xe7310037}},	//   ench, dože, ákna_, اصة_,
   {{0x24890496,0x2b890038,0x25a94b7c,0xcb3400e5}},	//   _ayam_, júci_, _bial_, _шефъ,
   {{0x92c100c7,0xdb013536,0x2b890220,0x2bc618ff}},	//   ুলো_, _milí, dúci_, रीका,
   {{0xf9920105,0xab5d00bd,0x3f816125,0x2d9d19a2}},	//   _ערד_, _awżi, kohu_, imwe_,
   {{0x212b008f,0x883a00a1,0xa91d6126,0x656f1c5d}},	//   _anch_, _מתנו, sožd, anch,
   {{0x27ed0634,0x25a92e6a,0x7bc200d2,0x2b890206}},	//   luen_, _fial_, zpou, rúch_,
   {{0xa91d0146,0x41e12171,0xa01b01f9,0x290d020a}},	//   bože, _फिरस, _gyök, neea_,
   {{0xd007524d,0x27ed6127,0x65666128,0x9f4001cd}},	// [5aa0] нете_, nuen_, mikh, ftið_,
   {{0xe1fa0d64,0x80ac04a9,0x65666129,0xa01b0084}},	//   _его_, _झलके, likh, _myöh,
   {{0x6446612a,0x7bdb0361,0x7980612b,0x00000000}},	//   lyki, _avuu, yomw, --,
   {{0x41bb00a1,0xfd4d0174,0x27ed612c,0x65660415}},	//   _מצטע, _ighọ, kuen_, nikh,
   {{0x60d6612d,0x644611b3,0x69da0062,0xa49b00b3}},	//   maym, nyki, _svte, mfòc,
   {{0x69d8612e,0x60d6612f,0x27ed0634,0xdb016130}},	//   tsve, laym, duen_, _filí,
   {{0xfce61d1c,0x7bc26131,0x7bdb0172,0x61ee58d4}},	//   _пово, spou, _evuu, nubl,
   {{0x69d86132,0xeeeb0019,0x64460138,0xf41f00c2}},	//   rsve, _đứng_, kyki, yvä_,
   {{0x27ed38c4,0x25a957f4,0x69d84469,0x79800078}},	//   guen_, _rial_, ssve, romw,
   {{0xd6da0747,0x61ee6133,0x79803223,0x25a90947}},	//   чти_, kubl, somw, _sial_,
   {{0x248902e7,0xa3d30f8f,0xfd4d0129,0x79806134}},	//   _syam_, हीन_, _nghọ, pomw,
   {{0xb4eb0782,0xeabf0023,0xa91d033b,0xf9920b9f}},	//   मले_, _đùi_, tože, _صبا_,
   {{0xfd4d0129,0xf746017b,0x9abc02a1,0x9f40003e}},	//   _aghọ, _педо, _anċi, ytið_,
   {{0x61e10103,0x752801d3,0x00000000,0x00000000}},	//   állo, ēdza, --, --,
   {{0xa01b0084,0x41e4224a,0x8afc007f,0x00000000}},	//   _työk, літа, _zmęc, --,
   {{0xfc460019,0xa91d08a9,0xf8b2007f,0x00000000}},	//   _đính_, pože, ीडिय, --,
   {{0xd3a76135,0x7a1301d4,0xb4bf022d,0x3f816136}},	// [5ab0] _проп, _vətə, ेरी_, tohu_,
   {{0x20e100de,0xdb016137,0x6d9100d6,0x00000000}},	//   ỗi_, _milã, gåan, --,
   {{0x3f81023b,0x27ed01e9,0x9f4001cd,0x7bc4020a}},	//   rohu_, zuen_, rtið_, ţiul,
   {{0xf42a0031,0x9f40003e,0x3f816138,0x00000000}},	//   späť_, stið_, sohu_, --,
   {{0x752d0239,0x8d740dce,0x9f4001cd,0x27ed01c8}},	//   _mnaz, دالا, ptið_, xuen_,
   {{0x8c424a09,0x65660060,0x3f98009c,0x6d4a0052}},	//   реше, zikh, _ghru_, ëfar,
   {{0x7bd90365,0x15e502d5,0x65660201,0x7ceb071d}},	//   sswu, _किधर_, yikh, görü,
   {{0x27ed03f3,0x8afe03e3,0x752d0361,0xdb080383}},	//   tuen_, riƙa, _nnaz, _lidè,
   {{0x5b151b4d,0xa91d0087,0x290d00ae,0x8afe03e3}},	//   _имат, tožb, reea_, siƙa,
   {{0x7d1b0652,0x27ed38ff,0x752d2824,0x6d4b0072}},	//   _haus, ruen_, _anaz, lkga,
   {{0x6b836139,0x7d1b613a,0x65663466,0x752d02a1}},	//   mong, _kaus, tikh, _bnaz,
   {{0x644640f2,0x7d1b613b,0x6b830c40,0xaa641e20}},	//   tyki, _jaus, long, _стук,
   {{0x27ed613c,0x7d1b613d,0x6566613e,0x44240076}},	//   quen_, _maus, rikh, ím_,
   {{0x7d1b613f,0x6b836140,0x6566067d,0xfbc60789}},	//   _laus, nong, sikh, रीटम,
   {{0xdb0801dc,0x764d01c2,0x64466141,0x62636142}},	//   _didè, _ƙayu, syki, авра,
   {{0x6b836143,0x7d1b6144,0x61ee6145,0x6d4b0381}},	//   hong, _naus, rubl, jkga,
   {{0xa0671510,0x6b836146,0xef1a0084,0x61fc11bc}},	// [5ac0] вата_, kong, мма_, strl,
   {{0x6b836147,0x03a60e4f,0xdfcf0037,0xdb080154}},	//   jong, _шипо, تيك_, _gidè,
   {{0x7d1b3657,0x6b836148,0xf2d309c1,0x69c16149}},	//   _baus, dong, _דעת_, _ntle,
   {{0xfce62863,0x69de0211,0xdb0001df,0x6146384f}},	//   тодо, špek, _humø, _рема,
   {{0x7d1b5cd9,0x6b4f12dc,0x6d98037a,0x3f980133}},	//   _daus, _søga, víad, _thru_,
   {{0x6b832ac5,0xf41300ca,0x7ceb0233,0xef1f007f}},	//   gong, יפד_, törü, ążce_,
   {{0x2b890220,0x6f1c0076,0x00000000,0x00000000}},	//   júcu_, _iarc, --, --,
   {{0xdce202e6,0x7d1b614a,0x6f1c614b,0xb7d40032}},	//   dnoć, _gaus, _harc, _aṣab,
   {{0x6d4010f0,0x6b830ad9,0xdca30c33,0x3d17009d}},	//   _ioma, bong, _вати, _नसते_,
   {{0x7d1b03ce,0x65645b24,0x6b83614c,0x6f1c09ac}},	//   _zaus, _amih, cong, _jarc,
   {{0xd00b0081,0x7d1b0044,0xa4d50426,0x00000000}},	//   রিয়_, _yaus, лоні, --,
   {{0xb4bf018b,0x6f1c614d,0x7d02614e,0x6d40614f}},	//   ेरे_, _larc, nfos, _joma,
   {{0x6d406150,0x1836177a,0x68e2260a,0x7c226151}},	//   _moma, _جراح, _idod, nvor,
   {{0x52bf000c,0x36d46152,0x6d406153,0x65640201}},	//   ्रेस, _сокр, _loma, _emih,
   {{0x96f7029e,0x6d40008c,0x6b540065,0x7c220ba1}},	//   _شعور_, _ooma, _kàgb, hvor,
   {{0x6d406154,0x44f500ce,0x6b834e8c,0xdb0100d4}},	//   _noma, _спис, zong, _milá,
   {{0x6f1c0428,0x6b833289,0x7d1b6155,0xa91d01ac}},	// [5ad0] _barc, yong, _raus, noža,
   {{0x7d1b5139,0x7c22153a,0xdb0800fd,0x6d4001ec}},	//   _saus, dvor, _fidé, _aoma,
   {{0x3ea70222,0x6b830154,0x6d406156,0x6f1c6157}},	//   änt_, vong, _boma, _darc,
   {{0x6d406158,0x68e26159,0x6b83615a,0xbd1800d6}},	//   _coma, _ndod, wong, кції_,
   {{0x6f1c615b,0x6b4f038c,0x6b83615c,0x200600fd}},	//   _farc, _døgn, tong, çoit_,
   {{0x6f1c0328,0x68e2615d,0x6d400090,0x7d1b615e}},	//   _garc, _adod, _eoma, _waus,
   {{0xa3d302e8,0x3da7615f,0x6d400383,0x6a851ad1}},	//   हीत_, _араб, _foma, ылка,
   {{0x6d406160,0x6b836161,0x6f1c6162,0x316901e9}},	//   _goma, song, _zarc, niaz_,
   {{0x6b836163,0x6b540af0,0x5c751907,0x68e20178}},	//   pong, _dàgb, _слат, _ddod,
   {{0x6d406164,0xdb010072,0xdce22a6c,0x6b83019f}},	//   _zoma, _filá, tnoć, qong,
   {{0x8c420b88,0x69c1004d,0x6b540065,0x20196165}},	//   _öğre, _utle, _fàgb, _lssi_,
   {{0x6b54015e,0x20190dd8,0xdce214f3,0x673a0216}},	//   _vàge, _ossi_, rnoć, ajtj,
   {{0x2d8f054f,0xdce2005f,0x27e903be,0x6d9826e0}},	//   ilge_, snoć, _ían_, líac,
   {{0x291d6166,0x291f01e9,0x6d5a0138,0x00000000}},	//   _hawa_, ldua_, _įtam, --,
   {{0x291d6167,0x20196168,0xc0e6107e,0x6d980145}},	//   _kawa_, _assi_, ловк, níac,
   {{0xdb086169,0x291f616a,0x291d616b,0x6f1c616c}},	//   _vidé, ndua_, _jawa_, _sarc,
   {{0x6d40060b,0x27ff616d,0x291d00cd,0xe0df616e}},	// [5ae0] _roma, ntun_, _mawa_, _alòs_,
   {{0x6d40616f,0x6b4f01c5,0x291d6170,0x4ed20033}},	//   _soma, _søgn, _lawa_, াল্ল,
   {{0x2019008f,0x394d0856,0x6f1c6171,0x6ce6004b}},	//   _essi_, kkes_, _varc, гіле,
   {{0x7c226172,0x6f1c6173,0x291d6174,0xed573d77}},	//   tvor, _warc, _nawa_, лох_,
   {{0x0b8a11d9,0x27ff0078,0x399a023b,0x6f1c6175}},	//   нски_, jtun_, nëse_, _tarc,
   {{0x7c2201f4,0x6d406176,0x2d8700fd,0x20006177}},	//   rvor, _woma, îner_, mtii_,
   {{0x2be006ec,0x2741000d,0x7c226178,0xfbe0049d}},	//   _निका, _méně_, svor, _निकम,
   {{0xdb010068,0x21205b9d,0xdca60d86,0x20006179}},	//   _vilá, ndih_, _баби, otii_,
   {{0x2000617a,0xcaf6300d,0x291d617b,0xed570379}},	//   ntii_, _مساب, _dawa_, _сот_,
   {{0xa01b00c2,0x31690634,0xda5a00d3,0xdb010231}},	//   _työv, ziaz_, _преш_, _tilá,
   {{0xd5b702fd,0xa37b0396,0x64400084,0x55750f00}},	//   лся_, nsõe, ämin, игот,
   {{0xa91d617c,0x291d617d,0x23af00bd,0x394d13c5}},	//   ložn, _gawa_, _ażja_, ckes_,
   {{0x6fb00251,0x67d400d3,0x765a617e,0x7c2605db}},	//   _अंगू, _толу, szty, _škrj,
   {{0x77f70054,0x6b4f052f,0xa01b00c2,0xae050006}},	//   _עמוד_, _nøgl, _myöt, _रहलन_,
   {{0x31c4617f,0x291d6180,0xf3ff016d,0x200000ae}},	//   йств, _yawa_, stã_, etii_,
   {{0x20190510,0x3869033b,0x9f5200c2,0x2000008c}},	//   _pssi_, _žari_, htyä_, ftii_,
   {{0xc05b00d6,0x31690634,0x20000188,0x2be00c8c}},	// [5af0] хів_, riaz_, gtii_, _निगा,
   {{0x7a0a01d4,0x2bcf121d,0x316901c8,0x00000000}},	//   _mətb, _सौगा, siaz_, --,
   {{0xc3320132,0x44290579,0xc2080018,0x6369033b}},	//   _ווי_, _hra_, _یقین_, lžno,
   {{0x2019022e,0x44296181,0x20000188,0xdb26015a}},	//   _tssi_, _kra_, btii_, یونی,
   {{0x291d6182,0x60cd2d76,0x200000d3,0x00000000}},	//   _rawa_, mbam, ctii_, --,
   {{0x291d6183,0xdcfb2cc8,0x60cd6184,0x2fc96185}},	//   _sawa_, _okuć, lbam, mpag_,
   {{0xba7700cd,0x44296186,0x27ff01c2,0x394d6187}},	//   داشت, _lra_, wtun_, tkes_,
   {{0x44296188,0x27ff6189,0x6d98002b,0x60cd01c2}},	//   _ora_, ttun_, ríac, nbam,
   {{0x394d618a,0x4429618b,0xa91d04e9,0x6d98065b}},	//   rkes_, _nra_, božn, síac,
   {{0x753d0067,0x394d14e3,0x7c29618c,0xab870d4f}},	//   ejsz, skes_, _irer, _субк,
   {{0x4429352c,0x27ff618d,0x291d618e,0x394d0167}},	//   _ara_, stun_, _tawa_, pkes_,
   {{0x4429618f,0x6e210b0b,0x399a023b,0x6d5a0138}},	//   _bra_, _álbu, tëse_, _įtak,
   {{0xf7700470,0x7d096190,0x998400e3,0xa01b00c2}},	//   _کان_, _mbes, _النو, _myös,
   {{0x44296191,0x399a023b,0x27ed6192,0x331901b3}},	//   _dra_, rëse_, mren_, ліся_,
   {{0x29d30012,0xc5d502ec,0x44296193,0x82a6004d}},	//   nţa_, _тіль, _era_, равж,
   {{0x4429191c,0x92d600c7,0x90c6022a,0x7c290634}},	//   _fra_, হলে_, рбае, _orer,
   {{0x657d0018,0x44296194,0x27ed6195,0x1f6603fb}},	// [5b00] érhe, _gra_, nren_, акам,
   {{0x20006196,0x7d0956c0,0x27ed6197,0x67210117}},	//   rtii_, _abes, iren_, ndlj,
   {{0x27ed02dc,0x20006198,0xa01b0084,0x60cd6199}},	//   hren_, stii_, _syöt, bbam,
   {{0x442908a1,0x0c26619a,0xa37b0161,0x7c29028d}},	//   _yra_, имен, rsõe, _brer,
   {{0xa37b001f,0x9f520084,0xa91d2449,0x27ed619b}},	//   ssõe, ttyä_, tožn, jren_,
   {{0x27ed619c,0x7d090415,0x69dc004d,0x67210117}},	//   dren_, _ebes, _ærek, jdlj,
   {{0x27ed619d,0x7c29619e,0xa91d619f,0x12e900c1}},	//   eren_, _erer, rožn, אַפּ,
   {{0xa01b0084,0x6d5961a0,0x7c2961a1,0x7d09026e}},	//   _työt, chwa, _frer, _gbes,
   {{0xdce903c6,0x27ed61a2,0x06da0081,0xdcfb007e}},	//   _sjeć, gren_, _দাবি, _skuć,
   {{0x442961a3,0x9abc02a1,0xa91d033b,0x6b540441}},	//   _rra_, _baċe, ložl, _fàga,
   {{0xe8fa61a4,0x27ed17c6,0x09360018,0x60cd1d4f}},	//   _але_, aren_, _پراج, ybam,
   {{0x442961a5,0x997502fd,0x69ca02e2,0x7a0a0092}},	//   _pra_, _лучш, mpfe, _tətb,
   {{0x75c101d3,0x53473d00,0x27ed01ff,0x60cd0f1c}},	//   _rēze, ахва, cren_, vbam,
   {{0x44290665,0x8387004b,0x389b0266,0x35f7001c}},	//   _vra_, рыме, _סיגנ, درید_,
   {{0xdcfb0335,0xe1670831,0x6dac026a,0x2d78033b}},	//   _ukuć, ађан, _aşam, včen_,
   {{0x442961a6,0x74f90161,0x00000000,0x00000000}},	//   _tra_, _сеир_, --, --,
   {{0x60cd61a7,0x61ee61a8,0x909961a9,0xa01b007b}},	// [5b10] rbam, arbl, уват_, _ryös,
   {{0xbf020179,0x2be0000c,0x2d7802ef,0x7d0961aa}},	//   र्लभ_, _निजा, učen_, _sbes,
   {{0x6d5961ab,0xa3d30096,0xf2d20089,0x27ed4311}},	//   thwa, हीर_, _מעי_, zren_,
   {{0xa2cb007d,0x27ed61ac,0x00000000,0x00000000}},	//   _त्त्, yren_, --, --,
   {{0xf1a40fe9,0x00000000,0x00000000,0x00000000}},	//   _фрэн, --, --, --,
   {{0x6d5961ad,0x6b740231,0x27ed61ae,0xab64036c}},	//   shwa, олчу, vren_, овіл,
   {{0xa96961af,0xa01b61b0,0x00000000,0x00000000}},	//   лика_, _työs, --, --,
   {{0x27ed61b1,0x7d0961b2,0x991500d6,0x29d300ae}},	//   tren_, _ubes, ські, rţa_,
   {{0x27ed5b2f,0xccf200ca,0xf3910139,0x2d8d0433}},	//   uren_, _מכן_, _eṣin_, _ikee_,
   {{0x27ed03f3,0x33330072,0x6d980072,0x9abc009e}},	//   rren_, _nnxx_, nían, _paċe,
   {{0xe81c0251,0xaa9500e3,0x27ed0062,0x442e0154}},	//   _बैठा_, _الاث, sren_, _ōf_,
   {{0x055661b3,0x27ed61b4,0x6e3600ca,0x38690128}},	//   стоя, pren_, צטרף_, _žaru_,
   {{0x6c7900c1,0xa3d30096,0x00000000,0x00000000}},	//   ראָפ, हील_, --, --,
   {{0x66010abd,0x2be0009d,0x61f5013c,0x00000000}},	//   ptlk, _निघा, fuzl, --,
   {{0x450d00c7,0xe81f02d5,0xe5a60183,0x6d981c9d}},	//   ষয়ক_, बिका_, _лики, dían,
   {{0x31bc0018,0x21670fe3,0x00000000,0x00000000}},	//   _víz_, биси_, --, --,
   {{0x61431525,0x41270465,0x442661b5,0x7d010103}},	// [5b20] чета, щото_, _éo_, záró,
   {{0xa01b0084,0x79891507,0x66f9045f,0xf0a717de}},	//   _pyör, hoew, ्भिक_, скул_,
   {{0x216a00ae,0x25dd00c3,0xa2b700ca,0x00000000}},	//   _бини_, _कौमी_, _לפיד_, --,
   {{0xdb08025b,0xb5fa00c1,0xd5fa00c1,0x00000000}},	//   _vidí, טלעכ, טפער, --,
   {{0x3075007e,0x9f4000c2,0x6d980072,0xdd8f01c3}},	//   _дурс, triä_, bían, روه_,
   {{0x2d8d0134,0xa3da02d5,0x6d980042,0x3333020b}},	//   _ekee_, डीय_, cían, _xnxx_,
   {{0x0f57006e,0x00000000,0x00000000,0x00000000}},	//   _פילם_, --, --, --,
   {{0xa51702e8,0xa3d861b6,0xed5705b8,0x69ca042c}},	//   _तसेच_, ाठा_, _лос_, rpfe,
   {{0x64a7009d,0xeafa00e3,0xec7a2b99,0x37aa4a09}},	//   _गणेश, _مرات_, _спа_, лтон_,
   {{0xa91d0095,0x501b00a1,0x25a0007e,0x9f4901cd}},	//   nožj, נויו, _ahil_, ntað_,
   {{0xb0b800bc,0x00000000,0x00000000,0x00000000}},	//   _अलंग, --, --, --,
   {{0x9f470871,0xd10a02d5,0x3a2c0079,0x61f50342}},	//   čné_, ह्मण_, _irdp_, vuzl,
   {{0x589600d0,0xa3d305a7,0x25a061b7,0x1c1e0592}},	//   _اجاز, हीं_, _dhil_, पिटल_,
   {{0x3946008a,0x661c052f,0x96ba61b8,0x61f500e7}},	//   _hoos_, ærks, _суду_, tuzl,
   {{0xe5c6125c,0x26de61b9,0x394661ba,0xa3e5030b}},	//   _усло, mato_, _koos_, _पटक_,
   {{0x26de61bb,0x25a01ab6,0x7a0a00a7,0x39460b8e}},	//   lato_, _ghil_, _xəta, _joos_,
   {{0x3946006c,0x656f61bc,0x61f503e0,0x9ed93703}},	// [5b30] _moos_, mich, suzl, имат_,
   {{0x656f61bd,0x26de1ac8,0x394661be,0x2572007e}},	//   lich, nato_, _loos_, ršle_,
   {{0x6d9861bf,0x212201c2,0x644f01b6,0x00000000}},	//   rían, _fakh_, lyci, --,
   {{0x656f61c0,0x7ae861c1,0x26de61c2,0x9f490037}},	//   nich, _addt, hato_, mraí_,
   {{0x26de61c3,0x07080e19,0x69c800e8,0x00000000}},	//   kato_, वभाव_, _atde, --,
   {{0x656f61c4,0xdea40260,0x752801d3,0x00000000}},	//   hich, _کیمی, ēdzi, --,
   {{0x9f49054f,0x656f61c5,0x39463bf2,0xdb080428}},	//   nraí_, kich, _boos_, _didà,
   {{0x394661c6,0x656f61c7,0x57e92156,0x47c51f3e}},	//   _coos_, jich, адим_, обив,
   {{0x5fe210ed,0xa91d0074,0xf8ae00bf,0x394661c8}},	//   _पिछल, ložk, نکه_, _doos_,
   {{0x26de61c9,0x060919cb,0x7b770dd0,0x25a061ca}},	//   gato_, анок_, _اطرا, _shil_,
   {{0xb8ff00c7,0x656f61cb,0x3946022e,0xf8bf46b4}},	//   _তা_, fich, _foos_, ñés_,
   {{0x656f61cc,0x9f490076,0x3946008c,0x957d00c6}},	//   gich, draí_, _goos_, drąs,
   {{0x26de61cd,0x66e50ce5,0x9d1a0266,0x6d980072}},	//   bato_, _дола, בורט, díal,
   {{0x26de0465,0xa91d025b,0x7a0a0092,0x16390037}},	//   cato_, kožk, _mətn, _نسبة_,
   {{0x9f4900e3,0xa01b00c2,0x224700ae,0xe7780103}},	//   graí_, _syöp, опри_, _دلوں_,
   {{0x68fb61ce,0x656f002b,0x3cff023e,0x24800197}},	//   ngud, cich, _ncuv_, _txim_,
   {{0x6723067d,0x9f4901cd,0x7b110206,0xdb010956}},	// [5b40] _kanj, ttað_, _kľuč, _dilú,
   {{0x442061cf,0x672303ec,0x752461d0,0xb3580068}},	//   _isi_, _janj, _haiz, _ایسا_,
   {{0x672361d1,0x442001af,0x61460396,0x7bc961d2}},	//   _manj, _hsi_, _дена, _ateu,
   {{0x672306ee,0x629e02dd,0xa01b0084,0x9f490088}},	//   _lanj, _izpo, _työp, stað_,
   {{0x394661d3,0x752450ba,0x4420030b,0x26de61d4}},	//   _roos_, _maiz, _jsi_, yato_,
   {{0x3946040c,0x656f61d5,0x672361d6,0x60c40542}},	//   _soos_, zich, _nanj, lcim,
   {{0x26de0465,0x394661d7,0x2d780631,0x644f00a5}},	//   vato_, _poos_, nček_, zyci,
   {{0x442061d8,0xdb081f9f,0x26de61d9,0x752461da}},	//   _osi_, _didá, wato_, _naiz,
   {{0x672361db,0x656f61dc,0x44200a15,0x394661dd}},	//   _banj, vich, _nsi_, _voos_,
   {{0x656f0bb7,0x6723006d,0x68fb61de,0x103700a1}},	//   wich, _canj, agud, קטים_,
   {{0x26de61df,0x656f61e0,0x672361e1,0x2d7839a2}},	//   rato_, tich, _danj, jček_,
   {{0x26de61e2,0x60c40106,0xe7f30096,0x6d4261e3}},	//   sato_, jcim, _आमचा_, njoa,
   {{0x656f61e4,0x26de61e5,0x6d980314,0x6369033b}},	//   rich, pato_, víal, lžni,
   {{0x656f61e6,0x68e061e7,0x60c40161,0x6d982ad4}},	//   sich, lamd, ecim, díam,
   {{0x442061e8,0x752420e5,0x9f400037,0x777a01fa}},	//   _esi_, _faiz, briú_, mntx,
   {{0x9f490080,0x672361e9,0x752401e9,0xd13803a0}},	//   rraí_, _zanj, _gaiz, оху_,
   {{0x656d20c1,0x672361ea,0x60c60188,0x9f490076}},	// [5b50] _imah, _yanj, _dfkm, sraí_,
   {{0x68e03edf,0x75240a00,0x6b5d0154,0x26dc0141}},	//   hamd, _zaiz, _kège, _jevo_,
   {{0x7bc9157c,0xa3b40179,0x3dd80178,0x777a0634}},	//   _steu, _जूट_, _cwrw_, intx,
   {{0x26dc03f1,0x6d9809d3,0x621a00ca,0x3dd803a8}},	//   _levo_, bíam, _פורק, _dwrw_,
   {{0x9f401ea5,0x656d0124,0x6d980165,0x6b5d03a9}},	//   guió_, _mmah, cíam, _lège,
   {{0x656d0124,0x777a023e,0x8b22166f,0xa91d13be}},	//   _lmah, jntx, едше, moži,
   {{0x7de00068,0x656d00cd,0x7c26501f,0x60dd026a}},	//   _vásá, _omah, _škrt, _kesm,
   {{0x627c0105,0x60dd08c5,0xceb200ca,0x777a01e9}},	//   ינונ, _jesm, _טים_, entx,
   {{0x60dd1379,0x672361eb,0x6d5b09a1,0x7bc90051}},	//   _mesm, _panj, _ilua, _uteu,
   {{0x656d61ec,0x60dd4341,0x6d5b01bb,0x70b80179}},	//   _amah, _lesm, _hlua, _अल्ल,
   {{0x672361ed,0x442061ee,0x26dc2a3b,0x6d5b048e}},	//   _vanj, _ssi_, _devo_, _klua,
   {{0x7d1961ef,0x60dd2efd,0x67232161,0x68e061f0}},	//   news, _nesm, _wanj, camd,
   {{0x672361f1,0x752401b3,0x60c4005f,0x6d5b023e}},	//   _tanj, _vaiz, vcim, _mlua,
   {{0x44200b27,0x656d019f,0x395f17d2,0xa91d3fa3}},	//   _vsi_, _emah, lhus_, doži,
   {{0x60c40559,0xe29a61f2,0x752461f3,0x06a90033}},	//   tcim, сав_, _taiz, _খ্রি,
   {{0x442001bb,0x629e61f4,0x216761f5,0x27e661f6}},	//   _tsi_, _vzpo, писи_, _yvon_,
   {{0xb4d81362,0x442061f7,0x557700c1,0x2fd900eb}},	// [5b60] िरी_, _usi_, _מעקן_, _cwsg_,
   {{0x60c4075f,0xc2ea0068,0x6d9861f8,0x60dd007a}},	//   scim, _اعظم_, ríam, _eesm,
   {{0x60c4005f,0x395f0149,0x9cca1402,0xf53f00f3}},	//   pcim, khus_, была_, kmål_,
   {{0x6d5b02bc,0x60dd1507,0xeeeb00de,0xcad80033}},	//   _clua, _gesm, _đụng_, _সাইফ,
   {{0x395f61f9,0x6d5b0994,0x6d420084,0x6d4961fa}},	//   dhus_, _dlua, rjoa, _doea,
   {{0xa09b006e,0x6d5b00aa,0x00000000,0x00000000}},	//   _ליכט, _elua, --, --,
   {{0x68e0026a,0x6d5b2514,0x60dd61fb,0x00000000}},	//   tamd, _flua, _yesm, --,
   {{0x6d5b0099,0x6d4902a1,0x8b66001c,0x395f093e}},	//   _glua, _goea, _کارم, ghus_,
   {{0x68e00256,0x36d437f2,0x6b5d0113,0x00000000}},	//   ramd, мопр, _sège, --,
   {{0x23a402c3,0x68e061fc,0x656d0206,0x00000000}},	//   nöjd_, samd, _smah, --,
   {{0xe7e8007a,0xd6d700c2,0x7a0a013c,0x00000000}},	//   _टटका_, чты_, _xətl, --,
   {{0x395f61fd,0xd5b700c2,0x23a402c3,0x00000000}},	//   chus_, ясь_, höjd_, --,
   {{0x60dd61fe,0x1b1f0081,0x8ca40034,0x8afe01c2}},	//   _resm, পারে_, _औरफो, siƙu,
   {{0xda20009d,0x2fcb02ef,0x7c2d0092,0xa91d4480}},	//   _मनात_, _rtcg_, çirə, voži,
   {{0x60dd61ff,0x623400d3,0xa79b0266,0x673802a1}},	//   _pesm, неру, _השגח, _invj,
   {{0x9f47033a,0xf67b00a1,0x656d6200,0xa3da009f}},	//   ční_, _לאומ, _umah, डीह_,
   {{0x60dd2347,0x00000000,0x00000000,0x00000000}},	// [5b70] _vesm, --, --, --,
   {{0x657d22d4,0x6d5b09f7,0xa91d6201,0x00000000}},	//   lnsh, _slua, roži, --,
   {{0x6d5b006c,0x6d5a013f,0x0ea70789,0x7a0a0092}},	//   _plua, _įtar, केंड, _qətl,
   {{0x6b4f066a,0xa91d0031,0x5c752178,0x657d22b7}},	//   _løgt, poži, млет, nnsh,
   {{0x69da009e,0x45270033,0x2bdd02d5,0x395f17d2}},	//   _awte, যাপক_, _नौशा, vhus_,
   {{0x20090138,0xfbd00214,0x00000000,0x00000000}},	//   mtai_, اتن_, --, --,
   {{0xc9a92f17,0x395f2522,0xf4130081,0x20096202}},	//   овке_, thus_, িটির_, ltai_,
   {{0x21290496,0x17c92c13,0x629703a9,0x8caa0034}},	//   ndah_, огии_, _myxo, जेहो,
   {{0x2009125d,0x395f0d78,0xf53f038c,0x98bd0034}},	//   ntai_, rhus_, rmål_, _nową_,
   {{0x2d8f60d1,0xf53f02ec,0x21295c73,0x2009013f}},	//   loge_, smål_, hdah_, itai_,
   {{0x7ae36203,0x395f6204,0xdb030076,0x62850231}},	//   mant, phus_, nmní, _nxho,
   {{0x200901b3,0xa2cb0d75,0x61f500cc,0x2d8f6205}},	//   ktai_, तुस्, drzl, noge_,
   {{0x21296206,0x26c73959,0x6b54009c,0x6285039f}},	//   ddah_, _tfno_, _bàgh, _axho,
   {{0x2129061d,0x657d0188,0x62970212,0x63bf01ee}},	//   edah_, ansh, _byxo, _duqn,
   {{0x6dbe0181,0xe0df01b5,0x2bdd2231,0x6b4f00f3}},	//   _vďak, _beò_, नीता, _høgs,
   {{0x7ae36207,0x2d1c009d,0xe0df01ec,0x63bf00bd}},	//   hant, _नसेल_, _ceò_, _fuqn,
   {{0x628534c5,0x490f030b,0xd00729db,0xe0df01b9}},	// [5b80] _exho, थ्यो_, мете_, _deò_,
   {{0x7ae3555e,0x2d780d12,0xef1700c2,0x21296208}},	//   jant, nčev_, мму_, adah_,
   {{0x44320074,0x7bdb06b0,0x764d0022,0x795c01dc}},	//   _hry_, _awuu, _ƙayy, _léwa,
   {{0x44320665,0x2b00074c,0x60c20220,0x61fc6209}},	//   _kry_, _राहु_, žomb, murl,
   {{0x7ae3620a,0x7c831d6e,0x6c1a00b1,0x9abc003d}},	//   fant, куше, تتاح_, _faċl,
   {{0x6aa500aa,0xd04f013c,0x3ced00b7,0x00000000}},	//   गे्र, _necə, _edev_, --,
   {{0x61fc620b,0x7bdb06b0,0xdce90141,0x00000000}},	//   nurl, _ewuu, _zmeč, --,
   {{0xbea3620c,0x6b5405fe,0x2d8f058a,0xf70e0023}},	//   _раск, _màgi, coge_, _củng_,
   {{0x7ae3620d,0xdb0800c2,0x79a300e5,0x395d030a}},	//   bant, _pidä, ърше, _dlws_,
   {{0xddc900d3,0x61fc15a4,0x795c00d1,0x29020034}},	//   _înţe, kurl, _déwa, żka_,
   {{0x7bc0620e,0xdceb00d9,0x61fc00dc,0xf4130033}},	//   _humu, ligā, jurl, িয়ার_,
   {{0x7bc0012d,0x61fc620f,0x44326210,0x20096211}},	//   _kumu, durl, _bry_, ytai_,
   {{0x7bc00010,0xa3da009d,0xed5f0220,0x21292d11}},	//   _jumu, डील_, úžia_, vdah_,
   {{0x289b0054,0x7bc06212,0xd04f00a7,0x6b4f00f3}},	//   _וידא, _mumu, _gecə, _høgr,
   {{0x44320283,0x7bc06213,0xa2cb04f8,0xa29400d6}},	//   _ery_, _lumu, तुष्, варі,
   {{0x7ae36214,0x00000000,0x00000000,0x00000000}},	//   zant, --, --, --,
   {{0x7ae36215,0xc05b02ec,0x443200a5,0x7bc06216}},	// [5b90] yant, ців_, _gry_, _numu,
   {{0x20096217,0x628501bb,0xa91d0146,0xdce90dd9}},	//   rtai_, _txho, ložt, _rjeđ,
   {{0x20096218,0x6b5d0113,0xf1c400d4,0xb7d50032}},	//   stai_, _nèga, raší_, _iṣes,
   {{0x7bc06219,0xe51000de,0x20090138,0xa2cb0980}},	//   _bumu, _lặng_, ptai_, तुर्,
   {{0xa3d3009d,0x0c75001c,0x78a20169,0x7ee700e5}},	//   हीच_, رگرد, _nzov, _оцве,
   {{0xe5100019,0x7bc000bf,0xfaa514fb,0x79820139}},	//   _nặng_, _dumu, нало, _ajow,
   {{0x78a2621a,0x00000000,0x00000000,0x00000000}},	//   _azov, --, --, --,
   {{0xd2b80054,0xaa560037,0x7bc0020a,0x3ced01ff}},	//   ולות_, عليا_, _fumu, _udev_,
   {{0x7bc03907,0x798200d1,0x6d59621b,0x395d0231}},	//   _gumu, _djow, mkwa, _vlws_,
   {{0xd7090084,0x6d59621c,0x399a023b,0x79820065}},	//   чное_, lkwa, hësh_, _ejow,
   {{0x7bc0621d,0x6dac03a3,0xcf92040a,0x29c3034f}},	//   _zumu, _işar, רטי_, _uña_,
   {{0x7ae1621e,0x7bc0621f,0xb7d50139,0xab5d0034}},	//   _helt, _yumu, _aṣes, _duże,
   {{0x7ae16220,0x649a0ffe,0x6d590044,0x69c16221}},	//   _kelt, ятор_, ikwa, _hule,
   {{0x61fc0501,0x6b540990,0x69c13e80,0x4432057a}},	//   turl, _pàgi, _kule, _vry_,
   {{0x69c16222,0x6d596223,0xf67900c1,0xff8f0134}},	//   _jule, kkwa, _מאַמ, ọọkw,
   {{0xdb016224,0x64402a3c,0x443200a1,0x61fc6225}},	//   _kiló, ämis, _try_, rurl,
   {{0x69c16226,0x6d590044,0x61fc6227,0xe4330037}},	// [5ba0] _lule, dkwa, surl, _مفيد,
   {{0x6d596228,0xdceb01d3,0x69c100fc,0x00000000}},	//   ekwa, vigā, _oule, --,
   {{0x7bc06229,0xe29a22fb,0x1756006e,0x69c1622a}},	//   _sumu, _хан_, עסער_, _nule,
   {{0x9f471cf3,0x7bc000a6,0xac8642e0,0x6d592791}},	//   čná_, _pumu, нгел, gkwa,
   {{0xdca30cfc,0xe5052010,0x7ae1622b,0x69c128fd}},	//   гаци, ष्टि_, _belt, _aule,
   {{0x69c1622c,0x6d590361,0xbb430497,0x8a18456d}},	//   _bule, akwa, лечк, докс_,
   {{0x7ae102fe,0x69c1622d,0x1e952a84,0xab5d02a1}},	//   _delt, _cule, _артр, _bużb,
   {{0x7bc0622e,0xd90e110a,0x69c1622f,0x799b33bf}},	//   _tumu, صیت_, _dule, gluw,
   {{0x7ae15c75,0x7c24008e,0xd90d12eb,0x69c16230}},	//   _felt, çird, تین_, _eule,
   {{0x7c226231,0x7d020072,0x7ae16232,0x69c16233}},	//   mwor, lgos, _gelt, _fule,
   {{0x160000a5,0x399a0216,0xa4d50120,0x00000000}},	//   लंधर_, hësi_, коні, --,
   {{0x7d026234,0x7a0a01d4,0x7ae16235,0xdb012f7b}},	//   ngos, _nəti, _zelt, _filó,
   {{0xf48408c3,0xe5100028,0x69c102e2,0xe73a2f98}},	//   гурн, _tặng_, _zule, _нед_,
   {{0xdbc70006,0xb4bb015a,0xd3241aad,0x69c1024a}},	//   _tööt, _کاغذ_, льси, _yule,
   {{0xd05601d4,0x399a023b,0x225800b6,0xf1a76236}},	//   mayə, tësh_, _čeká_, еран,
   {{0x7c226237,0xd05600a7,0xf8e0074c,0x00000000}},	//   kwor, layə, नरिय, --,
   {{0x442f38d5,0x399a023b,0x7d026238,0x00000000}},	// [5bb0] _ég_, rësh_, dgos, --,
   {{0x7f4e023e,0xd0560092,0x2d842d5a,0x68e26239}},	//   _cobq, nayə, _ajme_, _leod,
   {{0x6d59029a,0xf773006e,0x7c22084e,0x672a302f}},	//   tkwa, נקע_, ewor, _mafj,
   {{0x7ae1623a,0x7a0a01d4,0x9f4005e6,0x69c1623b}},	//   _selt, _gəti, frió_, _rule,
   {{0x6d59623c,0xd0560092,0x7c22623d,0x7ae100c2}},	//   rkwa, kayə, gwor, _pelt,
   {{0x69c1623e,0x6d59623f,0x212b6240,0x00000000}},	//   _pule, skwa, _hach_, --,
   {{0x7ae127c0,0xc334040a,0xee8400c2,0xda622c37}},	//   _velt, טוס_, _быто, ивши,
   {{0x7ae16241,0x6ecd0789,0x9f406242,0x991500d6}},	//   _welt, दुरु, brió_, тькі,
   {{0x212b6243,0x7c2202e5,0xd05600a7,0xe67a02c6}},	//   _mach_, cwor, fayə, _děčí,
   {{0x69c16244,0x25a902a7,0x7c24026a,0xd7630a85}},	//   _tule, _ahal_, çire, اندی,
   {{0x391500bf,0xdb016245,0x799b2783,0x25a90078}},	//   _لواز, _filò, pluw, _bhal_,
   {{0x212b6246,0x20190510,0x25a96247,0x2d7800c4}},	//   _nach_, _opsi_, _chal_, lčer_,
   {{0x25a96248,0xa01b007b,0x291f024a,0x6e2702c3}},	//   _dhal_, _työy, meua_, _lsjb,
   {{0x987a00c1,0x00000000,0x00000000,0x00000000}},	//   _קאסט, --, --, --,
   {{0xe2971f37,0x212b0150,0x27ff0084,0xf796097d}},	//   вар_, _bach_, luun_, _جنوب_,
   {{0x212b6249,0x399a023b,0x25a9003d,0x7c22624a}},	//   _cach_, tësi_, _ghal_, ywor,
   {{0xf5770080,0x212b624b,0x27ff293a,0x6b5d020d}},	// [5bc0] _جميع_, _dach_, nuun_, _règn,
   {{0x93fb0130,0x212b624c,0xd36f00e3,0x399a023b}},	//   _קליי, _each_, _وهي_, rësi_,
   {{0x212b624d,0x7c220381,0x399a0216,0x00000000}},	//   _fach_, wwor, sësi_, --,
   {{0x212b445f,0x7c22624e,0x27ff0084,0x202700c2}},	//   _gach_, twor, kuun_, äviä_,
   {{0x0b8a08c3,0x7d02624f,0x399a023b,0x3ce600e7}},	//   мски_, rgos, qësi_, raov_,
   {{0x67130c9c,0x9f403a2f,0x7d022b12,0x27ff008c}},	//   त्मक_, rrió_, sgos, duun_,
   {{0x212b00ec,0x35c6009f,0xd05600a7,0xdb0105aa}},	//   _yach_, _रूढ़, vayə, _pilò,
   {{0xdb091d2b,0xf98f00e3,0x6da61e61,0x212b00fe}},	//   _dueñ, يبي_, _риба, _xach_,
   {{0xc173040a,0x6dac0092,0x29060063,0x5963008f}},	//   יחה_, _uşaq, _vcoa_, ръща,
   {{0x5ba70012,0x473305b6,0x95d80161,0x00000000}},	//   _акум_, аньс, ндот_, --,
   {{0xb9080f71,0x0f5700ca,0x6b7b22fe,0xdb0901ff}},	//   _বা_, דיים_, _קרבנ, _gueñ,
   {{0x6d980072,0xd7fa0265,0xa91d00d4,0xd5b8022a}},	//   mías, _жук_, sožr, кся_,
   {{0x212b6250,0x161e007f,0x27ff008c,0xf3ff0231}},	//   _rach_, _बनकर_, cuun_, rzão_,
   {{0x27f90220,0x212b6251,0x6b5400b3,0x00000000}},	//   ásne_, _sach_, _tàgu, --,
   {{0x31c411d9,0x9abc009e,0xab5d003d,0x20190ece}},	//   иств, _baċi, _juża, _spsi_,
   {{0x65666252,0x2ee31733,0x248901fa,0xfba91a09}},	//   chkh, _sejf_, _txam_, _चीनम,
   {{0x212b6253,0x3d1600b6,0xf3ff0231,0x6b5d00fc}},	// [5bd0] _vach_, नभने_, quã_, _bègl,
   {{0x44296254,0xdb1a01e5,0x2ee30052,0x212b6255}},	//   _isa_, _ditë, _qejf_, _wach_,
   {{0x733a00c1,0x212b6256,0x9abc003d,0x80e20081}},	//   _װערס, _tach_, _faċi, _ফার্,
   {{0x6d982ee8,0x867b00ca,0xff5f020a,0xdb1a0216}},	//   días, ורבו, _atît_, _fitë,
   {{0xdb0922ed,0xed5904a3,0x752d6257,0x2019061d}},	//   _sueñ, _niže_, _maaz, _upsi_,
   {{0x3d0800aa,0x27ff00ce,0x00000000,0x00000000}},	//   _हाथे_, vuun_, --, --,
   {{0x291f0239,0xdb010e43,0xc879044c,0x25620139}},	//   teua_, _uhlí, maşi_, _lóla_,
   {{0x4429198c,0xc87900d3,0xa925294a,0x27ff007b}},	//   _osa_, laşi_, удил, tuun_,
   {{0x7d0905bd,0xdce2173c,0x00000000,0x00000000}},	//   _ices, lioğ, --, --,
   {{0x7c296258,0xed590106,0x27ff6259,0x6d98002b}},	//   _iser, _diže_, ruun_, bías,
   {{0x4429625a,0xa50a1a0e,0x752d083e,0x394f0212}},	//   _asa_, нена_, _baaz, _togs_,
   {{0xd76312eb,0x25621c9d,0xaca30294,0x27ff00c2}},	//   انگی, _bóla_, _nrịa, puun_,
   {{0xe72e625b,0xde5101c2,0x7c290078,0x7d0902a1}},	//   _ле_, rƙƙa, _jser, _mces,
   {{0x752f0067,0x27ed5cfe,0x60cd0062,0x2120625c}},	//   adcz, msen_, ecam, weih_,
   {{0x442911ce,0x27ed0c2e,0x67211e68,0x6b5d5dd1}},	//   _esa_, lsen_, melj, _règl,
   {{0x66010694,0x68e9100b,0xc87900d3,0x752d625d}},	//   mulk, naed, eaşi_, _gaaz,
   {{0x27ed4e3d,0xa0670114,0x7a0a0092,0x43762ca3}},	// [5be0] nsen_, гата_, _hətt, _бунт,
   {{0x7d09625e,0x27ed625f,0x32460831,0xdd9905aa}},	//   _aces, isen_, _беог, _akň_,
   {{0x277607a6,0x7c296260,0x67060775,0x68e900f9}},	//   נגען_, _aser, _शासक_, kaed,
   {{0x27ed3903,0x60cd6261,0x7d090072,0x61466262}},	//   ksen_, ccam, _cces, _сема,
   {{0x5ee300c7,0x7c290018,0x67216263,0x27ed6264}},	//   _পারে, _cser, kelj, jsen_,
   {{0x672103ce,0x27ed6265,0x6be300e3,0xdb0101b5}},	//   jelj, dsen_, حكوم, _chlà,
   {{0x67216266,0x7c296267,0xa3b5086d,0x27ed2a0d}},	//   delj, _eser, जगत_, esen_,
   {{0x68e96268,0x63be6269,0x6d982a96,0x63740092}},	//   gaed, _lipn, rías, _dünə,
   {{0x6d403261,0xb6e60f1e,0x67212a4e,0x7b0900c2}},	//   _inma, люнк, felj, ästö,
   {{0x25620018,0x6564626a,0x60cd5009,0xdb01009c}},	//   _róla_, _alih, zcam, _ghlà,
   {{0x49060cd2,0x4429626b,0x66010167,0xc7c800de}},	//   _مواق, _ssa_, gulk, _bốc_,
   {{0x27ed57d4,0xc5f800d9,0x659559b2,0xc7c800de}},	//   bsen_, dzēt_, раму, _cốc_,
   {{0xb9930b05,0xc99300e3,0x69d824e7,0x27ed626c}},	//   _النب, _النظ, lpve, csen_,
   {{0x4429626d,0x66011405,0x6721007e,0xaca40134}},	//   _vsa_, bulk, celj, _nsọp,
   {{0x60cd07a5,0xdb1a626e,0x6601626f,0x752d01c2}},	//   tcam, _cité, culk, _taaz,
   {{0x44290197,0x7aea02e2,0x29ca0028,0xc7c80019}},	//   _tsa_, haft, _mùa_, _gốc_,
   {{0x44296270,0x60cd1d32,0x9f406271,0x765a00c2}},	// [5bf0] _usa_, rcam, ksiä_, lyty,
   {{0xa3da1376,0x63be0124,0x7d090451,0xdb010146}},	//   डीओ_, _gipn, _sces, _ohlá,
   {{0x7aea6272,0x539c00ca,0x7a0a00a7,0xab5d02a1}},	//   daft, _איזו, _xətt, _bużn,
   {{0x7c2901c8,0xc5f3021e,0xdb0101f7,0x777a0062}},	//   _pser, מדע_, _shlà, hitx,
   {{0x1aee00c7,0x8c451be2,0x705801b6,0x3b090feb}},	//   চ্ছে_, реле, _баяр_, вело_,
   {{0x6d4004d8,0x9219009f,0x29ca0023,0xf09f0032}},	//   _enma, _पहाड़_, _bùa_, _iyà_,
   {{0xdb0100e3,0x06e30081,0x27ed4e7c,0x777a0062}},	//   _chlá, _মালি, wsen_, ditx,
   {{0x7c29006d,0x7d092a6c,0x765a6273,0x8e840076}},	//   _tser, _uces, dyty, _الفه,
   {{0x27ed1a02,0x68e91aae,0x57e601b6,0x777a01ff}},	//   usen_, raed, адым_, fitx,
   {{0x27ed17d2,0x66016274,0xf7710dd0,0xb8fc0176}},	//   rsen_, tulk, تاب_, _त्_,
   {{0x27ed453c,0x672107c0,0xcb681f11,0xc5f801d3}},	//   ssen_, relj, _حمله_, dzēs_,
   {{0x27ed16f9,0xc98415c3,0x00000000,0x00000000}},	//   psen_, _лучи, --, --,
   {{0x672106b8,0x66016275,0x45270081,0xa3b1009d}},	//   pelj, sulk, যাংক_, _ओळख_,
   {{0x394d6276,0xb4e50251,0xdb1a231d,0x4375007e}},	//   ljes_, _पड़ी_, _pité, буст,
   {{0xa3da0455,0xc7c80019,0xe29a4a4e,0x63be6277}},	//   डीज_, _tốc_, тав_, _vipn,
   {{0x629e025b,0x395f013f,0x394d0813,0x61ee1e71}},	//   _vypo, nkus_, njes_, rsbl,

   {{0x629e0067,0x386d459a,0x3fc80260,0x395f17b1}},	// [5c00] _wypo, nzer_, ادری_, ikus_,
   {{0x629e5874,0x386d6278,0xe0df0154,0x394d023b}},	//   _typo, izer_, _anòd_, hjes_,
   {{0x394d2202,0x395f007a,0x6d980072,0x324600ce}},	//   kjes_, kkus_, fíap, _тенг,
   {{0xf1bf011b,0x29ca0023,0x7aea03e3,0x00000000}},	//   _giá_, _rùa_, waft, --,
   {{0x394d6279,0xac073e28,0xd24f12eb,0x386d0126}},	//   djes_, инца_, _فنی_, jzer_,
   {{0x395f01d3,0xdce6071d,0x386d0877,0x316001ff}},	//   ekus_, ımın, dzer_, lkiz_,
   {{0x7aea627a,0x394d627b,0xca4800cd,0x636b0364}},	//   raft, fjes_, العه_, _fünf,
   {{0x6d40627c,0x394d627d,0xed572436,0x671316e2}},	//   _unma, gjes_, _кос_, त्सक_,
   {{0xed57261d,0x201200c2,0x777a0634,0x6af601f9}},	//   _тот_, ntyi_, titx, _نثار,
   {{0xab5c00d9,0x27f90220,0x394d0487,0x765a00ce}},	//   _biļe, ásna_, ajes_, tyty,
   {{0x56943c7c,0x777a627e,0xed5900c4,0x2012007b}},	//   сант, ritx, _hiža_, htyi_,
   {{0x69c8627f,0x6b986280,0x2bdd136b,0x394d01cb}},	//   _iude, lovg, नीका, cjes_,
   {{0xb7d416c4,0x69c86281,0x9f470181,0x636b41ba}},	//   _اقتب, _hude, čnú_, _jüng,
   {{0x69c80a00,0x938800c2,0x23650103,0x00000000}},	//   _kude, асса_, ólj_, --,
   {{0x69c80012,0x7ae86282,0x2b0942c3,0x75d3020a}},	//   _jude, _medt, _सासु_, _răzg,
   {{0x69c86283,0xeeeb00de,0xd5430065,0x7ae86284}},	//   _mude, _đựng_, _dẹ́b, _ledt,
   {{0x657d6285,0xb4e3034c,0xed590335,0xdb01071a}},	// [5c10] mish, धरी_, _niža_, _kilô,
   {{0x69c804ee,0x657d6286,0x7ae80073,0x394d023b}},	//   _oude, lish, _nedt, zjes_,
   {{0x645d00a1,0x69c86287,0xa1951248,0x75d300ae}},	//   lysi, _nude, _ганч, _găzd,
   {{0x657d6288,0x00000000,0x00000000,0x00000000}},	//   nish, --, --, --,
   {{0x3d080251,0xa6be0081,0xac276289,0x7ae8211d}},	//   _हारे_, োরিয়, рфек, _bedt,
   {{0x657d628a,0x7dd3009e,0xda183350,0x636b042c}},	//   hish, _aħse, _दहशत_, _düng,
   {{0x657d628b,0x394d628c,0x9f490037,0x0a6b008f}},	//   kish, tjes_, nsaí_, ърди_,
   {{0x386d628d,0x248d00a5,0x29190088,0x657d628b}},	//   tzer_, żemy_, ýsa_, jish,
   {{0x25620eb8,0x657d628e,0x394d00dd,0x7d1b628f}},	//   _sólo_, dish, rjes_, _ibus,
   {{0x394d6290,0x395f6291,0x69c8001f,0x386d01bf}},	//   sjes_, skus_, _fude, rzer_,
   {{0x386d0068,0x394d6292,0x657d6293,0x7bc100f9}},	//   szer_, pjes_, fish, _iilu,
   {{0x657d023f,0x7a7a0130,0x645d6294,0x20120084}},	//   gish, _גרעס, fysi, ytyi_,
   {{0x7d1b6295,0x7bc16296,0x69c801bf,0x7bc90428}},	//   _mbus, _kilu, _zude, _jueu,
   {{0x69c84b5f,0x04fa0033,0x6aa15509,0x80d50386}},	//   _yude, েজের_, _kylf, युसे,
   {{0x657d628b,0x7bc110e1,0x7d1b45e9,0x69c80432}},	//   bish, _milu, _obus, _xude,
   {{0x7c3b6297,0x657d4dae,0x7bc16298,0x201200c2}},	//   _orur, cish, _lilu, ttyi_,
   {{0xef1a0ac6,0x9f400037,0x80aa4d0e,0x7fd601b6}},	// [5c20] лма_, msiú_, ував_, сібі,
   {{0x7bc16299,0x9f400037,0x7d1b38a5,0x4420629a}},	//   _nilu, lsiú_, _abus, _ipi_,
   {{0xb3bb00a1,0x7c3b52d9,0x7dd30090,0x201200c2}},	//   _תמיכ, _arur, _aħsb, styi_,
   {{0x69c8629b,0xdb1b0088,0xa2d40285,0x7526629c}},	//   _rude, _stuð, बुर्, nekz,
   {{0x69c80fb0,0x9f400037,0x44200a4b,0x636b042c}},	//   _sude, isiú_, _jpi_, _fünd,
   {{0x636b0390,0x657d1801,0x4420434c,0xc7c800de}},	//   _günd, zish, _mpi_, _bốn_,
   {{0x657d1658,0x44201a3a,0x7ae800d6,0xdb080072}},	//   yish, _lpi_, _vedt, _sidó,
   {{0x4420629d,0x636b0364,0xafdb0b81,0xb9100065}},	//   _opi_, _zünd, _drøf, _halẹ_,
   {{0x96ea4441,0xdce920e4,0x657d629e,0x7bc900fd}},	//   льна_, _smeć, vish, _gueu,
   {{0x7bc1629f,0x657d62a0,0x69c862a1,0x35f44cb0}},	//   _gilu, wish, _tude, опор,
   {{0x657d62a2,0x44200808,0x69c802fd,0xa3be08fa}},	//   tish, _api_, _uude, ेदन_,
   {{0xd56724e9,0x6b5d05fe,0x645d62a3,0x7bc162a4}},	//   стоп, _règi, tysi, _zilu,
   {{0x657d62a5,0x97430542,0x636b042c,0xdb1a62a6}},	//   rish, _šćep, _lüne, _lití,
   {{0x657d62a7,0x645d62a8,0x27e60065,0x78a2063d}},	//   sish, rysi, _iwon_, _iyov,
   {{0x442014b1,0x657d0010,0xa77b00a1,0xdce96126}},	//   _epi_, pish, _תרופ, _umeć,
   {{0x657d00dd,0x636b007a,0x9f4900e3,0x4420171d}},	//   qish, _sünd, rsaí_, _fpi_,
   {{0x44200113,0x9f55372e,0x200062a9,0x2d8702c6}},	// [5c30] _gpi_, овач, grii_, énem_,
   {{0x80d9277c,0x78a20350,0x7d1b039f,0x27e64031}},	//   _फ्रे, _myov, _sbus, _mwon_,
   {{0x7bc10dda,0xab5d009e,0x2000020a,0xb6050032}},	//   _rilu, _fużj, arii_, _ifáà,
   {{0x9c390e21,0x02b502d5,0xa69b006e,0x6f1c007e}},	//   ипет_, ंधीन, נשאפ, _ebrc,
   {{0x7bc90054,0x6aa10150,0x44200124,0xfbd30421}},	//   _queu, _sylf, _xpi_, ستش_,
   {{0xc1ed00aa,0x7d1b0085,0x7645003e,0x00000000}},	//   _जबाब_, _wbus, _áhyg, --,
   {{0x27e602b4,0x81cb00c7,0x636b03a3,0x78a20372}},	//   _awon_, রীর_, _güne, _ayov,
   {{0x7d1b5dd6,0xc7c80019,0x27ff62aa,0x7bc1001c}},	//   _ubus, _vốn_, trun_, _wilu,
   {{0x7c3b62ab,0x7d040037,0x69c201e9,0x7bc10630}},	//   _urur, óise, _dioe, _tilu,
   {{0x70c61376,0x27ff62ac,0xe61908f9,0x75d300d3}},	//   _वल्ल, rrun_, адо_, _răzb,
   {{0xda02000f,0xc7c80023,0x27e662ad,0xaa670e2c}},	//   रूआत_, _uốn_, _ewon_, _утак,
   {{0x80d90455,0x69c2028d,0x44390036,0x27e60383}},	//   _फ्ले, _gioe, fvs_, _fwon_,
   {{0x3333003d,0x00000000,0x00000000,0x00000000}},	//   _baxx_, --, --, --,
   {{0x43753f37,0x798934bb,0x69c20634,0x00000000}},	//   пуст, lnew, _zioe, --,
   {{0x6b840037,0x6f000139,0x798962ae,0x00000000}},	//   éigi, _lábà, onew, --,
   {{0xe0da1941,0x442062af,0x798962b0,0x200062b1}},	//   рва_, _tpi_, nnew, trii_,
   {{0x88bd00a5,0xd00a002d,0x291d4671,0x1b010081}},	// [5c40] ześn, резе_, _mbwa_, ল্যে_,
   {{0x7c24008e,0x799b0126,0x7989009c,0x2d8d2211}},	//   çirm, houw, hnew, _ajee_,
   {{0x644100d9,0x4e2a3703,0x291d0517,0x25dd00a4}},	//   ālie, роен_, _obwa_, कीची_,
   {{0xcbd500c7,0x68eb02e6,0x200000d3,0xafdb13b9}},	//   _হয়েছ, _negd, prii_, _brød,
   {{0xead40ff8,0x798962b2,0x4e080034,0x09d20096}},	//   поль, dnew, ांहै_, सऱ्य,
   {{0x636b0230,0x291d4599,0x7989000b,0x00000000}},	//   _tüne, _abwa_, enew, --,
   {{0x291d0172,0xf96a002d,0x798900f0,0x6b8d0076}},	//   _bbwa_, ирий_, fnew, éaga,
   {{0xa37b016d,0xfafa015a,0x1d070e06,0x7989026d}},	//   mpõe, _چراغ_, _меси_, gnew,
   {{0x6da31167,0x274a2a61,0x478a0743,0x68eb0188}},	//   _цита, ачно_, исом_, _degd,
   {{0x25620102,0x636b586a,0x78a20239,0x7c2d62b3}},	//   _fólk_, _münc, _vyov, çare,
   {{0x799b043e,0xdb1a016d,0x333302a1,0x00000000}},	//   bouw, _titâ, _raxx_, --,
   {{0x69da62b4,0xe45f00c2,0x79892454,0x27e6022b}},	//   _itte, työ_, cnew, _twon_,
   {{0xd5b81476,0xccf300ca,0x94ab13c7,0x79800172}},	//   юсь_, וכר_, ртна_, mimw,
   {{0x79804671,0x3946037a,0x443962b5,0x68eb0381}},	//   limw, _hnos_, rvs_, _zegd,
   {{0x2d870018,0x623462b6,0x00000000,0x00000000}},	//   ének_, меру, --, --,
   {{0x349517df,0x66081470,0xd5cf00bc,0x79800350}},	//   _найр, mudk, _संतज, nimw,
   {{0x656f00e3,0xb4d7007a,0x660862b7,0x3a3e0154}},	// [5c50] mhch, िडी_, ludk, _lrtp_,
   {{0x69da0927,0x67280292,0x8ca40034,0x644002b6}},	//   _otte, nedj, _औरजो, æmie,
   {{0x79803565,0x798901ee,0xe7fe02d5,0x660800bc}},	//   kimw, ynew, ोंडा_, nudk,
   {{0x8d740e11,0xf6530327,0x656f00fe,0x14af0096}},	//   وانا, וצע_, nhch, _घराण,
   {{0x69da62b8,0x636b01e8,0xa91d031a,0x60d600c1}},	//   _atte, _günc, niže, _מורא_,
   {{0x39461379,0x67280477,0x3c1e00d9,0xab290114}},	//   _anos_, jedj, dāvā_, сока_,
   {{0x6608005a,0x798962b9,0x1df8055b,0x05c602d5}},	//   judk, tnew, _меры_, _रंगब,
   {{0x3f8162ba,0xab5d003d,0x2d9f0350,0x00000000}},	//   lihu_, _mużi, _ukue_, --,
   {{0x02a81000,0x69da5ccb,0xa91d26dd,0x656f117b}},	//   _गर्न, _ette, jiže, dhch,
   {{0x3ced01bb,0x798962bb,0x2d9d62bc,0x25a023ff}},	//   _heev_, snew, lowe_, _skil_,
   {{0x63703114,0xe5a61ac8,0x79800512,0x00000000}},	//   _häng, зини, bimw, --,
   {{0x2d9d00a5,0x3f8102ef,0x291d02a4,0x63702a40}},	//   nowe_, hihu_, _ubwa_, _käng,
   {{0xed5962bd,0x672862be,0x3f810022,0x33d5004d}},	//   _mož_, bedj, kihu_, діст,
   {{0x637062bf,0x69da038b,0x3ced023e,0x200901c2}},	//   _mäng, _ytte, _leev_, duai_,
   {{0x637062c0,0x2d9d62c1,0x32434ead,0xd2aa359e}},	//   _läng, kowe_, нерг, скве_,
   {{0x9f471cf3,0x29d10649,0x290d62c2,0x3ced023e}},	//   čný_, _máa_, ngea_, _neev_,
   {{0x2d9d00a5,0x20095c31,0x7bdb083e,0xdb0100da}},	// [5c60] dowe_, guai_, _ntuu, _dhlú,
   {{0x161f62c3,0x3f810027,0x00000000,0x00000000}},	//   _बहार_, gihu_, --, --,
   {{0x7bdb0517,0x1d26002d,0x79804835,0x753662c4}},	//   _atuu, змем, yimw, _kayz,
   {{0x3ced006c,0xed59030b,0x1d0a2a84,0x2d9d62c5}},	//   _ceev_, _což_, седи_, gowe_,
   {{0x3ced022e,0x850a0096,0x75360063,0xd6c30033}},	//   _deev_, _वाईट_, _mayz, োরিয,
   {{0x88bd00a5,0xdb1a08a8,0x29d10065,0x6c831374}},	//   reśl, _bitá, _báa_, علوم,
   {{0xfce629b7,0x2d9d62c6,0x7bdb4986,0x321800a1}},	//   _ново, bowe_, _etuu, ntry_,
   {{0x63701680,0x636b01d4,0x29d10032,0x66082ba4}},	//   _händ, _müna, _dáa_, vudk,
   {{0x63700003,0x39460087,0x672804e9,0x798002a4}},	//   _känd, _vnos_, tedj, rimw,
   {{0x29d162c7,0xf53f01df,0x23c30d79,0x00000000}},	//   _fáa_, glån_, _méjì_, --,
   {{0xaadb0054,0x672803d6,0x656f117b,0x44320d17}},	//   _החבר, redj, thch, _asy_,
   {{0x2c200067,0x394662c8,0x63701680,0xa91d0106}},	//   _यहां_, _unos_, _länd, tiže,
   {{0x98d20174,0x66080094,0xf8bf1515,0x637002c3}},	//   _dịtụ, sudk, žér_, _oänd,
   {{0xa91d033b,0x2d9d0034,0x4acc3ec9,0xc7d7021e}},	//   riže, zowe_, ाशिव, _צווי_,
   {{0x321800f9,0x80a20d7a,0x61e90095,0x4de10033}},	//   gtry_, _कुबे, ćelo, _পটভূ,
   {{0x200917b6,0xdb0101ec,0x636b00bc,0x00000000}},	//   tuai_, _dhlù, _düna, --,
   {{0x3015147c,0x3f8162c9,0x637062ca,0xed590117}},	// [5c70] ьдар, tihu_, _bänd, _rož_,
   {{0x3ced006c,0x29030138,0x656d62cb,0x23c30139}},	//   _seev_, ėjai_, _hlah, _déjì_,
   {{0x7bdb38ca,0x200903b4,0x636b008e,0x63703448}},	//   _stuu, suai_, _güna, _säng,
   {{0x3f8162cc,0x26040285,0x6b5d1022,0x00000000}},	//   sihu_, _विनी_, _nègr, --,
   {{0x2d9d62cd,0xa156028c,0xac0900d6,0xca6b0077}},	//   rowe_, _חברה_, інка_, _бiлi,
   {{0x7c9400bf,0x656d62ce,0x2d9d00a5,0x8c420c79}},	//   رشنا, _llah, sowe_, теше,
   {{0x3ced01bb,0x656d072f,0x2d9d0034,0x80c20033}},	//   _teev_, _olah, powe_, ষুদ্,
   {{0x9f52034f,0xdb1a446d,0x7bdb0361,0x3eae042c}},	//   buyó_, _vitá, _ttuu, üfte_,
   {{0x637002fd,0x6d4962cf,0x290d044c,0x7bdb0172}},	//   _häne, _inea, rgea_, _utuu,
   {{0x656d62d0,0x6362016d,0x6d4901b9,0x657f039f}},	//   _alah, _tôni, _hnea, _amqh,
   {{0x656d291d,0x6d5b62d1,0xdc8e0174,0x637000bc}},	//   _blah, _koua, sịtụ_, _jäne,
   {{0x443262d2,0x6d5b00fd,0xf53f032e,0x00000000}},	//   _psy_, _joua, slån_, --,
   {{0x2eaa0efb,0x63700149,0x6b8362d3,0x6d5b62d4}},	//   _कर्त, _läne, oing, _moua,
   {{0x7c240253,0x36690cf5,0x6d5b17f9,0x656d0415}},	//   çiri, _мало_, _loua, _elah,
   {{0xc7b200a1,0x6d490634,0x637062d5,0xf09f00b3}},	//   _שבו_, _onea, _ränd, _ocàs_,
   {{0x6b8362d6,0x63700149,0x320a62d7,0x6d49009c}},	//   hing, _sänd, ruby_, _nnea,
   {{0xb4ea0b7f,0x321862d8,0x6e29007e,0x00000000}},	// [5c80] यरी_, stry_, _ćeba, --,
   {{0x6b8362d9,0x656d0117,0x6d492bc0,0x00000000}},	//   jing, _zlah, _anea, --,
   {{0x6b830a0a,0x637062da,0x6d5b62db,0x9f49042c}},	//   ding, _vänd, _boua, spaß_,
   {{0xbc6a0190,0x9f5200e1,0x973c0559,0x6370042c}},	//   يمان_, tuyó_, moće, _wänd,
   {{0x6b8362dc,0x63700149,0x6faf0789,0x6d5b62dd}},	//   fing, _tänd, _जीवं, _doua,
   {{0x6b8362de,0x7c2d2542,0xf7670dce,0x6d490062}},	//   ging, çara, _شا_, _enea,
   {{0x7f5c20df,0xfb190103,0x3a250956,0x00000000}},	//   _iorq, سروں_, _cplp_, --,
   {{0x3834320c,0xed43121c,0xa3b5009f,0x7f5c62df}},	//   енир, _инсп, _छीन_, _horq,
   {{0xc2f40081,0x26ca0106,0x3ce60117,0x1c050861}},	//   _জানি_, žbom_, mbov_, _रियल_,
   {{0x6b8362e0,0xf41400c7,0x7f5c62e1,0xe0df0154}},	//   cing, িবার_, _jorq, _anòl_,
   {{0xc9560084,0xc7c80019,0x656d62e2,0xaa8a0d7f}},	//   _отды, _mối_, _plah, _بنام_,
   {{0x7bc810f3,0xc7c800de,0x1bf5007a,0x00000000}},	//   _hidu, _lối_, ुंचल_, --,
   {{0x7bc862e3,0x9f400472,0xe73a0a7c,0x636b0364}},	//   _kidu, nsió_, _мед_, _dünn,
   {{0xb4af62e4,0x56945008,0x7bc8024a,0xa91d00c4}},	//   _करी_, _палт, _jidu, miža,
   {{0xc7c80019,0x3d0f0251,0x7bc862e5,0x656d62e6}},	//   _nối_, _डाले_, _midu, _tlah,
   {{0x6b836099,0x656d62e7,0xdb0105aa,0x7bc862e8}},	//   zing, _ulah, _eklè, _lidu,
   {{0x46d2000f,0xfe70001c,0x6d5b014b,0xa29f1178}},	// [5c90] _सलाह, یدم_, _roua, _खुर्,
   {{0x6d491db0,0x673a0149,0xc7c800de,0x63620161}},	//   _snea, ndtj, _bối_, _bônu,
   {{0xdb1a02fd,0x6b8362e9,0xc332006e,0xb4af009d}},	//   _mitä, ving, _גוי_, _करु_,
   {{0x6b8362ea,0xc7c80023,0x63700212,0x0edf0179}},	//   wing, _dối_, _väne, _प्रड,
   {{0xa91d08a9,0x7bc862eb,0x7f5c15c1,0xdce9026a}},	//   jiža, _bidu, _forq, _emeğ,
   {{0x67380344,0xe1f00504,0xc5f800e8,0x21390133}},	//   _navj, _حسی_, ksē_, _hash_,
   {{0x7bc862ec,0x4ea4147c,0x213962ed,0xc7c800de}},	//   _didu, _арта, _kash_, _gối_,
   {{0x261804ea,0x6b8362ee,0xb4af009d,0x7bc862ef}},	//   déo_, sing, _करू_, _eidu,
   {{0x7bc862f0,0x6b8362f1,0xed590106,0x636b00aa}},	//   _fidu, ping, _niži_, _rünn,
   {{0x81e500c7,0x636b62f2,0x7bc8019c,0xdce903f1}},	//   _নিন_, _sünn, _gidu, _mleč,
   {{0xa29f0c38,0xe6160ff1,0xc7c8020b,0x2d8f0350}},	//   _खुल्, ндэ_, _xối_, onge_,
   {{0x7bc862f3,0x224600c4,0xa91d0357,0xb4ea06eb}},	//   _zidu, _čok_, biža, यरे_,
   {{0x2d8f151d,0x291f0350,0x00000000,0x00000000}},	//   inge_, mfua_, --, --,
   {{0x29030138,0x31690062,0x00000000,0x00000000}},	//   ėjau_, ekaz_, --, --,
   {{0xdce9015c,0x41b60e3a,0x7f5c00b3,0x7bdd0956}},	//   _aleč, есат, _rorq, _ésuf,
   {{0x67380268,0xc7c800de,0xdce90580,0x213962f4}},	//   _zavj, _rối_, _omeđ, _cash_,
   {{0x7f5c0d9f,0x752462f5,0x636b0abd,0x21390158}},	// [5ca0] _porq, _ibiz, _güno, _dash_,
   {{0xe3b20308,0x316901c8,0x69dc0231,0x7f5c62f6}},	//   _حرب_, akaz_, _éreg, _qorq,
   {{0xe8ac4275,0x7bc862f7,0x69d70072,0x00000000}},	//   _चर्च, _ridu, íxel, --,
   {{0x64441d2d,0x7bc862f8,0x6b8100eb,0xafe60161}},	//   _krii, _sidu, _amlg, _помл,
   {{0x7bc800aa,0xdce9007e,0x75243179,0x6aa80537}},	//   _pidu, _gleč, _mbiz, _sydf,
   {{0x9f400472,0xc7c80028,0x81be0174,0x63620231}},	//   rsió_, _tối_, _ọchọ_, _tônu,
   {{0x9f400990,0x7bc85873,0xf9c662f9,0x99660c37}},	//   ssió_, _vidu, нщин, етпл,
   {{0x67380292,0xdca609e0,0xdb1a007b,0x2d870103}},	//   _savj, _заби, _sitä, énet_,
   {{0xdb1a0d64,0x7bc82c09,0xb4af0b89,0x764300f0}},	//   _pitä, _tidu, _करे_, _arny,
   {{0x26180257,0x752462fa,0xed590357,0x7bdf0143}},	//   téo_, _abiz, _riži_, íque,
   {{0x644462fb,0x7524010a,0xa91d00c6,0x673a02c3}},	//   _arii, _bbiz, siža, rdtj,
   {{0xa91d0106,0xe4a71681,0xe0df0154,0x644462fc}},	//   ližn, ерго, _pnòm_, _brii,
   {{0xb4fb00aa,0x00000000,0x00000000,0x00000000}},	//   ्लौप_, --, --, --,
   {{0x636b0702,0xafdb4b39,0x75245784,0x65b602c6}},	//   _günl, _brøn, _ebiz, váhe,
   {{0xb5a702ec,0xdcfb02dd,0xf2042917,0xa5d700e3}},	//   _прий, _smuč, лято, _كبير_,
   {{0x64440f05,0x31690031,0xdce962fd,0xafdb00f2}},	//   _frii, ukaz_, _pleč, _drøn,
   {{0x64440f20,0x316901c2,0xc05b004d,0x20981402}},	// [5cb0] _grii, rkaz_, чів_, екты_,
   {{0x442962fe,0xa91d62ff,0xdce939a2,0x752f0034}},	//   _ipa_, jižn, _vleč, lecz,
   {{0xafdb0939,0xdce908c5,0x2139023b,0xa91d033b}},	//   _grøn, _smeđ, _tash_, dižn,
   {{0x753d0068,0x80a2033a,0x2d8f53b2,0x752f0034}},	//   ndsz, _कुवे, unge_, necz,
   {{0xb4af32ec,0x44296300,0xaacc0fef,0x5bcb1178}},	//   _करो_, _jpa_, ाशंक, ादेव,
   {{0x996c00b6,0x395d24da,0xdb030094,0xb4af034c}},	//   měř_, _sows_, plní, _करै_,
   {{0x2d870033,0x533800ca,0x6995008f,0x00000000}},	//   énes_, גנון_, крих, --,
   {{0x752f007f,0x00000000,0x00000000,0x00000000}},	//   jecz, --, --, --,
   {{0x44296301,0x626503e3,0x20096302,0x00000000}},	//   _npa_, lɗod, nrai_, --,
   {{0x7c296303,0x7524028d,0xe64500e5,0xab622ddc}},	//   _iper, _sbiz, веоп, şürm,
   {{0x44294263,0x39150562,0xa50a0b2c,0x98af020a}},	//   _apa_, _амер, мена_, _bagă_,
   {{0x200901b3,0x44296304,0x64446305,0x7c290294}},	//   krai_, _bpa_, _prii, _kper,
   {{0x68e96306,0xe72e016c,0xe0df05aa,0x00000000}},	//   mbed, _ке_, _enòk_, --,
   {{0x7c296307,0x44296308,0x76430479,0x27f90206}},	//   _mper, _dpa_, _trny, ásnu_,
   {{0x69cb5fa6,0xd29901ce,0xcb120341,0x20096309}},	//   _kige, етті_, ילם_, erai_,
   {{0x644400aa,0x973c00cc,0x389e0129,0x7524630a}},	//   _trii, moća, ịre_, _ubiz,
   {{0x69cb630b,0x2fca061d,0x41d20e52,0x6444630c}},	// [5cc0] _mige, _pibg_, _दूरस, _urii,
   {{0x69cb630d,0xafdb004d,0x00000000,0x00000000}},	//   _lige, _trøn, --, --,
   {{0x7c293535,0x81dc00c7,0x20090f1f,0x8e4a0037}},	//   _aper, _ঠিক_, arai_, بلاك_,
   {{0x69cb630e,0x7c860b1e,0xafdb00f2,0xc7c80023}},	//   _nige, куле, _krøl, _hốt_,
   {{0xed590995,0x68e9630f,0x0ffa22aa,0x00000000}},	//   _nižu_, dbed, _تعجب_, --,
   {{0x752f00a5,0x2d8737b9,0x69cb2e6a,0x68e96310}},	//   zecz, éner_, _aige, ebed,
   {{0x69cb0549,0xa91d0128,0xc7c80023,0x68e90eb3}},	//   _bige, rižn, _mốt_, fbed,
   {{0x68e96311,0xd90e015a,0x58381bc1,0xc7c800fe}},	//   gbed, زیت_, езия_, _lốt_,
   {{0x61e91197,0x2d8400e7,0xaca40294,0xa5c7003e}},	//   ćeli, _imme_, _kpọp, _ljóð,
   {{0x69cb6312,0x44296313,0x61fe0220,0xc7c80023}},	//   _eige, _rpa_, _ovpl, _nốt_,
   {{0x752f00a5,0x69cb6314,0x44296315,0x7af802c3}},	//   tecz, _fige, _spa_, mavt,
   {{0x798200a5,0x69cb6316,0x291200f3,0xeeeb0023}},	//   _umow, _gige, _øya_, _đọng_,
   {{0x94a8249c,0xc45800c2,0x61e200cc,0x752f153c}},	//   втра_, виях_, _čola, recz,
   {{0xd90e07d9,0xa5c70088,0x69cb6317,0x20096318}},	//   _ایک_, _bjóð, _zige, vrai_,
   {{0x69cb02a4,0xc7c800fe,0x2d840ac9,0x6b8d014b}},	//   _yige, _dốt_, _omme_, éagi,
   {{0x20096319,0x69cb008a,0x0eeb014e,0xbeeb245a}},	//   trai_, _xige, टर्स_, टर्न_,
   {{0x7ff418a9,0x25a90da3,0x90993549,0x29d820ed}},	// [5cd0] لسلا, _ikal_, хват_, _léa_,
   {{0x68e90291,0x63700006,0x65b6025b,0x2009631a}},	//   zbed, _täna, máha, rrai_,
   {{0xf41f0d64,0x637009fc,0x4fc40e20,0x0ccb06ed}},	//   ltä_, _känn, рста, िश्म,
   {{0x5bcb16f8,0x637000c2,0x20090036,0x9cb50076}},	//   ाद्व, _jänn, prai_, همات,
   {{0x6370072a,0x69cb631b,0xf41f02fd,0x8d770421}},	//   _männ, _rige, ntä_, _یارا,
   {{0x69cb0170,0xf41f0084,0x2d84631c,0x29d838df}},	//   _sige, itä_, _emme_, _béa_,
   {{0x69cb631d,0xdb0101b9,0x68e96310,0xdb030052}},	//   _pige, _bhlò, tbed, lonë,
   {{0xe9a900cd,0xdb0101f7,0x644101d3,0xd5e80174}},	//   رگان_, _chlò, ālij, ̣ọl,
   {{0x69cb631e,0x68e9631f,0xccf200ca,0x9c64001c}},	//   _vige, rbed, _לכן_, _پهلو,
   {{0x25a90496,0xc2e900c7,0x68e931ae,0x69cb02a4}},	//   _akal_, কৃতি_, sbed, _wige,
   {{0x39150f36,0x8f9c00a1,0xcb6800cd,0x25a90167}},	//   _مواز, ויזי, _جمله_, _bkal_,
   {{0xc7c800de,0xceb222fe,0xc984001f,0x69cb57be}},	//   _sốt_, מיי_, _кучи, _uige,
   {{0x973c02e6,0xa5c7003e,0x636b04a8,0x00000000}},	//   moćn, _sjóð, _günk, --,
   {{0xdb1a0cda,0xe0df026e,0x3dcd00dc,0x69dc6320}},	//   _sitú, _afò_, _liew_, _érec,
   {{0x412a1b10,0xafdb1484,0xe297136e,0x637000aa}},	//   ново_, _drøm, гар_, _fänn,
   {{0x973c0106,0x798900a5,0x00e4001c,0x00000000}},	//   noćn, niew, شتری, --,
   {{0xc7c800ef,0xd0076321,0x00000000,0x00000000}},	// [5ce0] _tốt_, лете_, --, --,
   {{0xe0df02f1,0x79890134,0xdb0301cd,0x3860009c}},	//   _efò_, hiew, llnæ, _àire_,
   {{0x9d46013d,0xdb030161,0x69c059a4,0x7af802c3}},	//   лежд, ponê, ymme, vavt,
   {{0xdb036322,0x29d800fc,0x0cd20033,0x798902ac}},	//   lonè, _réa_, ার্ত, jiew,
   {{0x2d9e6323,0x6acc6324,0x7af86325,0x798918f0}},	//   _ítem_, ाश्र, tavt, diew,
   {{0x394f6326,0x201201c2,0xdb01009c,0x00000000}},	//   _angs_, muyi_, _shlò, --,
   {{0xbf103245,0x7af80b6a,0x39a600e5,0x00000000}},	//   ालीन_, ravt, лшив, --,
   {{0xdd920434,0xf41f02fd,0x6e9316c4,0x5e930cc8}},	//   _اور_, ytä_, _الفا, _الفط,
   {{0xd6d00080,0x8c43090f,0xa7741111,0xdb0306a3}},	//   يقة_, _лете, илич, konè,
   {{0x25a90170,0x65b63171,0x103700a1,0x61e20087}},	//   _skal_, váha, נטים_, _čoln,
   {{0xb80609c3,0xda6533e7,0xdb036327,0x0f5700d7}},	//   _शिवम_, _پالي, zonë, איים_,
   {{0x1a9b07a6,0xf41f02fd,0x00000000,0x00000000}},	//   _איבע, ttä_, --, --,
   {{0x63700222,0x69da007a,0xf76f001c,0x2012083e}},	//   _vänn, _पंडी, زای_, juyi_,
   {{0x25bb02e5,0xdb030428,0xa6660dd0,0xd6cf450f}},	//   _whql_, gonè, _مطبو, _فقه_,
   {{0xf41f4043,0x637000c2,0xa3b60ff9,0xe7fe0285}},	//   stä_, _tänn, _जठर_, ोंका_,
   {{0x810f0e52,0x3f980078,0x210f0034,0x65b6003e}},	//   िलेख_, _ajru_, िलेश_, páha,
   {{0x2ef56328,0xdb010a7f,0xdb0300b3,0x26ca0206}},	// [5cf0] изар, _sklí, bonè, ľbou_,
   {{0x26de4569,0x3dcd6329,0x26ca0146,0xdb030428}},	//   ncto_, _siew_, žbou_, conè,
   {{0x2cad0332,0x63a70052,0xa7fd0103,0xecf9085f}},	//   _syed_, mojn, gyűj, вееш_,
   {{0x63a700dd,0x973c0995,0x656f632a,0x00000000}},	//   lojn, koćo, nkch, --,
   {{0x3dcd632b,0x79893220,0xc0ab09f4,0xdca50859}},	//   _view_, view, _ساحل_, јали,
   {{0xfbd000cd,0x63a700dd,0xab291942,0xda6500e5}},	//   سته_, nojn, тока_, ивли,
   {{0x79890185,0xc3340289,0xdb0100d2,0x00000000}},	//   tiew, מוס_, _uklí, --,
   {{0xa8050e45,0x7c3e00a5,0xd04401c2,0x63a70052}},	//   азил, łpra, cciɓ, hojn,
   {{0x63a7632c,0x23a5632d,0x79895e36,0x00000000}},	//   kojn, ओवाद, riew, --,
   {{0x7989632e,0x7c3b4131,0x63a7023b,0x38620212}},	//   siew, _isur, jojn, äkra_,
   {{0x63a7023b,0xdb031f20,0x61e2007e,0xfbe00065}},	//   dojn, joné, _čolo, _iṣọ_,
   {{0xe5a608d9,0xdb0300bf,0xdb08022b,0x69dc016d}},	//   рими, doné, _akdè, _érea,
   {{0x7d040037,0x7d1b037a,0x61e5632f,0x68fb6330}},	//   óisi, _mcus, _athl, maud,
   {{0x63a76331,0xafdb02b6,0x27ff6332,0x7c3b0a4b}},	//   gojn, _trøj, msun_, _msur,
   {{0xdb1a01e5,0x0cb205cd,0xdb036333,0x27ff6334}},	//   _shtë, _जर्म, goné, lsun_,
   {{0x00e65e0c,0x68fb013f,0x7a400018,0xdb036335}},	//   ржан, naud, látá, sonè,
   {{0x63a70660,0xe0430205,0x7c3b6336,0xa3dd0096}},	// [5d00] bojn, онти, _nsur, _तूप_,
   {{0xc3fb040a,0x93fb0089,0xfe720037,0x65640381}},	//   _שליש, _שליי, يدا_, _hoih,
   {{0x68fb2a3c,0x1fb5055b,0x7c3b0194,0x3eae34da}},	//   kaud, сстр, _asur, æft_,
   {{0xe29b0054,0x614621fd,0x77630933,0xfbe0026e}},	//   _ישיר, _тема, _lonx, _aṣọ_,
   {{0x68fb6337,0x20da0117,0x3a2c026d,0xfbe60033}},	//   daud, ršič_, _spdp_, _নিহত,
   {{0xc5eb0081,0x7d1b6338,0xd84f0032,0x00000000}},	//   _কিনা_, _ecus, _kọfi_, --,
   {{0x65bd0c90,0x3f8f020d,0x6b8a1aab,0x68fb014b}},	//   léhe, ègue_, rifg, faud,
   {{0x63a7023b,0x7d1b0037,0x68fb6339,0x3d070096}},	//   zojn, _gcus, gaud, हणणे_,
   {{0xa3b6009d,0x497300d6,0x44200197,0x27ff633a}},	//   जता_, ільс, _nqi_, gsun_,
   {{0xe5680132,0x6d40633b,0x77630933,0x250909b4}},	//   _אַ_, _hama, _conx, گردی_,
   {{0x6d40633c,0x2d9e025a,0x63700149,0x68fb633d}},	//   _kama, _êtes_, _vänl, baud,
   {{0x6d405fb1,0x6d42633e,0x68fb05e6,0x65b600b6}},	//   _jama, ndoa, caud, sáhn,
   {{0x6d405a08,0x63a700dd,0x61e50212,0x385700d1}},	//   _mama, tojn, _sthl, _نشود_,
   {{0x6d40633f,0x7c226340,0x7c2d6341,0xd6d00604}},	//   _lama, itor, çari, _عقب_,
   {{0x63a76342,0x43943e1c,0x7c226343,0x60cc0092}},	//   rojn, царс, htor, ənmə,
   {{0x6d406344,0x63a76345,0x75d300ae,0xdb0305ef}},	//   _nama, sojn, _căzu, roné,
   {{0xdefb02fd,0x7c2200dd,0x63a72acb,0xdfd10037}},	// [5d10] вые_, jtor, pojn, سيا_,
   {{0x7d1b008f,0xdb0304d8,0xd9d70033,0x77630072}},	//   _scus, poné, _সবসম, _xonx,
   {{0x6d4018e0,0x7c226346,0x2ef8037a,0x68fb03e3}},	//   _bama, etor, _derf_, yaud,
   {{0x29066347,0xbd1800d6,0xa5d9006e,0x7bdf0131}},	//   _ndoa_, иції_, אַסי, íquo,
   {{0x8c45385a,0x92d900c7,0x44396348,0x8d740068}},	//   селе, ারী_, nws_, غاما,
   {{0xa03a00c1,0x6d4001ff,0x6f0000d2,0x68fb2659}},	//   _געשפ, _eama, rábí, waud,
   {{0x7c226349,0xf1bf0019,0x6d40634a,0x27e602c9}},	//   ator, _khá_, _fama, _aton_,
   {{0x6d40634b,0x27ff634c,0x7c3b634d,0x2d8e020d}},	//   _gama, tsun_, _tsur, éfet_,
   {{0x7c221647,0x68fb634e,0xb4b637b3,0x973c007e}},	//   ctor, raud, _झरे_, moćj,
   {{0x8aa7634f,0x6d406350,0xfbd01850,0x27ff6351}},	//   _кред, _zama, _قتل_, rsun_,
   {{0x6d406352,0x9a876353,0x27ff6354,0xb8dd0081}},	//   _yama, _туал, ssun_, _আল_,
   {{0x6d40008a,0xf1bf00de,0x29020103,0xaca30134}},	//   _xama, _nhá_, ókat_, _ndịn,
   {{0x5f0a009d,0x65b60103,0xc8da006e,0x644b037a}},	//   ाणम्_, sáho, _עקסט, _ágil,
   {{0xf1bf0065,0x3cfd022e,0x395f6355,0x437518c6}},	//   _ahá_, hawv_, ljus_, оуст,
   {{0x386d6356,0xf1bf0503,0x637000ce,0x91e61102}},	//   lyer_, _bhá_, _hänk, собе,
   {{0xf1bf6357,0x659307ed,0x44220085,0xdfd20037}},	//   _chá_, _нају, ptk_, كير_,
   {{0xf1bf0080,0x386d6358,0x75d300d3,0x2ef8014b}},	// [5d20] _dhá_, nyer_, _văzu, _perf_,
   {{0x395f007a,0x65bd0677,0x7c226359,0x2000635a}},	//   hjus_, réhe, vtor, rsii_,
   {{0x6d40635b,0x63700222,0x386d00dd,0x2ef804e2}},	//   _pama, _länk, hyer_, _verf_,
   {{0x7c222cc5,0x6d40635c,0x2ef81507,0xf1bf0076}},	//   ttor, _qama, _werf_, _ghá_,
   {{0xcb6a2aae,0xdb01033d,0x0b8a11b7,0x6d42635d}},	//   ладе_, _sklá, лски_, rdoa,
   {{0x6d40635e,0x386d2a0b,0x68e2028d,0x395f0138}},	//   _wama, dyer_, _sfod, ejus_,
   {{0x6d40635f,0x27e66360,0x63ab0072,0x5a34004d}},	//   _tama, _ston_, _ígne, інит,
   {{0x637009b5,0x8d960cc8,0x7d960037,0x6d4001c2}},	//   _bänk, _الرش, _الرؤ, _uama,
   {{0x637002c3,0xdb1a01f9,0x00000000,0x00000000}},	//   _vänj, _kitü, --, --,
   {{0x8b65054f,0xdce06361,0xfafe01d3,0x7d04003e}},	//   _والم, _momč, šība_, ðisf,
   {{0x68f902a1,0xdb0102c6,0x636b6362,0xa92a00f3}},	//   _fewd, _uklá, _münt, _біле_,
   {{0x7afa6363,0xd5b82b69,0x68e20294,0x386d6364}},	//   _hett, йся_, _ufod, byer_,
   {{0x4439533f,0x07a61cda,0x69da6365,0x684600ae}},	//   uws_, _ладн, _hute, _ында,
   {{0x69da6366,0x7afa6367,0x32556368,0x44390178}},	//   _kute, _jett, овгр, rws_,
   {{0x7afa6369,0xf1bf0028,0xf77300ca,0x5693636a}},	//   _mett, _phá_, _מקס_, _нашт,
   {{0x92d900c7,0x69da636b,0x3f8a03a9,0xdcfb00cc}},	//   ারে_, _mute, _ambu_, _imuć,
   {{0x69da636c,0x657d00e3,0xc7b90103,0x636b0103}},	// [5d30] _lute, mhsh, ktől_, _bünt,
   {{0x7afa0a8d,0x644d0a00,0xa91d033b,0xdce0636d}},	//   _nett, _irai, riži, _domč,
   {{0x69da636e,0xdb1a0072,0x3cfd01fa,0x3a3e061d}},	//   _nute, _litó, tawv_, _nstp_,
   {{0x644d636f,0x3f8a6370,0xdce00154,0x61e8023c}},	//   _krai, _embu_, _fomč, ídle,
   {{0x69da4bd5,0x7afa00a1,0x752d149c,0x07180e4c}},	//   _aute, _bett, _mbaz, _दांव_,
   {{0x7afa10af,0x69da6371,0x661d00a5,0x3cfd023e}},	//   _cett, _bute, ński, sawv_,
   {{0x7afa3696,0x637015bd,0xaca30174,0x2e48008f}},	//   _dett, _sänk, _idọn, _лято_,
   {{0x69da03f3,0x644d6372,0x636b01bf,0xdb030610}},	//   _dute, _orai, _küns, moní,
   {{0xb90100e2,0x7d096373,0x657d00dd,0x7afa0970}},	//   _दल_, _ides, dhsh, _fett,
   {{0x2d8f6374,0x69da6375,0x752d1a05,0x7afa00a1}},	//   lige_, _fute, _abaz, _gett,
   {{0x69da6376,0x644d6377,0x752d02a1,0x9fe50033}},	//   _gute, _arai, _bbaz, _ফটোগ,
   {{0x6370070a,0x2d8f6378,0x7afa0ab2,0x29d1005f}},	//   _tänk, nige_, _zett, _išao_,
   {{0x69da02a7,0x7afa08f3,0x3211007f,0x00000000}},	//   _zute, _yett, erzy_, --,
   {{0x752d0a00,0x289a0089,0xdb0302c6,0x2d8f6379}},	//   _ebaz, _דינא, koní, hige_,
   {{0x644d637a,0x27ed637b,0x7d09637c,0x2129005c}},	//   _erai, lpen_, _odes, ffah_,
   {{0x644d637d,0x7d09637e,0x752d0134,0xaca30134}},	//   _frai, _ndes, _gbaz, _adọn,
   {{0x2d8f637f,0x1f662863,0x7bc16380,0x42d6325f}},	// [5d40] dige_, окам, _ohlu, _міну,
   {{0x7d096381,0xdb0304d8,0x27ed6382,0x59df00a4}},	//   _ades, foní, ipen_, _पंढर,
   {{0x7afa05a3,0x07211344,0xee3a61af,0x2d8f6383}},	//   _rett, _मानव_, рне_, fige_,
   {{0x7afa6384,0x7bc16385,0x2d8f6386,0x61ee0231}},	//   _sett, _ahlu, gige_, mpbl,
   {{0x69da6387,0x7afa6388,0x636b6389,0x27ed0126}},	//   _sute, _pett, _güns, jpen_,
   {{0x69da638a,0xafdb0170,0x09b422a3,0x7d0900c2}},	//   _pute, _prøv, ुष्य, _edes,
   {{0x27ed638b,0x7e230a28,0x7bc101b9,0xfce6004d}},	//   epen_, _одрж, _dhlu, _мово,
   {{0x7afa1ffe,0x7d09007e,0x2d8f0995,0xdb1a0143}},	//   _wett, _gdes, cige_, _pitó,
   {{0x7afa638c,0xfc034177,0x69da0294,0xdce90095}},	//   _tett, _опто, _wute, _sleć,
   {{0x69da638d,0xdce90995,0xdb1a001f,0xd6da638e}},	//   _tute, _pleć, _vitó, шти_,
   {{0x644d638f,0x657d6390,0x69da032c,0xe8060096}},	//   _srai, thsh, _uute, _शिका_,
   {{0x644d6391,0x1bfe00c3,0x32186392,0x758b00c2}},	//   _prai, _उबाल_, dury_, рсов_,
   {{0xf7460097,0xdb03034f,0x65bd0113,0x2bdd023a}},	//   _медо, zoní, géha, मदया,
   {{0x644d025a,0x2d8f6393,0x657d50cb,0xe7370e48}},	//   _vrai, zige_, shsh, _меч_,
   {{0x2129005c,0x644d00f0,0x443201dc,0x32050103}},	//   tfah_, _wrai, _epy_, ély_,
   {{0x644d1b14,0xab5d0034,0xa91d0138,0x59ca0096}},	//   _trai, _duży, sižv, ागिर,
   {{0x2d8f6394,0x644d6395,0x644100d9,0x4395013d}},	// [5d50] vige_, _urai, ālis, _наис,
   {{0x2d8f1507,0x9f4901cd,0xdb031177,0x00000000}},	//   wige_, gsað_, toní, --,
   {{0x2d8f4af8,0x636b02e2,0x27ed0a00,0x14c7034d}},	//   tige_, _wüns, zpen_, रेरण,
   {{0xb23a0130,0x7bc101b5,0xf53800c1,0x31590037}},	//   _פערז, _shlu, ַטור_, _الحج_,
   {{0x2d8f6396,0x61e203d6,0x7d09023b,0xab5d0034}},	//   rige_, _čoli, _vdes, _zuży,
   {{0x2d8f6397,0xdb030e4d,0x00000000,0x00000000}},	//   sige_, poní, --, --,
   {{0xef2301d3,0x00000000,0x00000000,0x00000000}},	//   _ceļš_, --, --, --,
   {{0x7d096398,0x9d181693,0x69c26399,0xe29c00ca}},	//   _udes, _мост_, _choe, ישור,
   {{0x2d8d639a,0x69e11197,0x25620146,0x27ed639b}},	//   _imee_, _šveđ, _góly_, upen_,
   {{0x27ed3697,0x63700212,0xa91d00c6,0x7bc10415}},	//   rpen_, _hänv, vižu, _uhlu,
   {{0x29d104a3,0x27ed2fb8,0xdbc60302,0x3218639c}},	//   _ušao_, spen_, töön, xury_,
   {{0x7aba00ca,0x69c218f0,0x798b0415,0x00000000}},	//   _הצעו, _ghoe, _umgw, --,
   {{0x69c9639d,0x2d8d0174,0x46ab007a,0x2d9f0a4b}},	//   mmee, _mmee_, _घुरह, _mjue_,
   {{0xe820000f,0x69c90be9,0x32183212,0x00000000}},	//   _ममता_, lmee, tury_, --,
   {{0xaacb0d7e,0x2d8d0174,0x02c300ae,0x14ae0096}},	//   ाधिक, _omee_, ейро, _घडवण,
   {{0xe0da013d,0x69c92004,0x799b0d2a,0x64404d6f}},	//   сва_, nmee, nnuw, æmis,
   {{0x21674064,0xd00a00d3,0xdce000e8,0x00000000}},	// [5d60] чити_, сезе_, _nomā, --,
   {{0xa3bf000d,0x2d9f0a4b,0x2b4500c4,0x69c9639e}},	//   ेषण_, _ajue_, _nalc_, hmee,
   {{0x69c9639f,0x63790065,0x32db00d7,0x00000000}},	//   kmee, _kìnn, _לחינ, --,
   {{0x21a600ae,0x69c901cb,0x63790af0,0x225e0206}},	//   _химм, jmee, _jìnn, ätku_,
   {{0x2b4521b0,0x69c90250,0x00000000,0x00000000}},	//   _balc_, dmee, --, --,
   {{0x2b4563a0,0xdce000d9,0x2d8d0174,0x69c200ca}},	//   _calc_, _domā, _emee_, _shoe,
   {{0xa7fd010a,0x00000000,0x00000000,0x00000000}},	//   kyűs, --, --, --,
   {{0xd90d0177,0x7e9b00a1,0xafdb00f3,0x00000000}},	//   لیم_, _הסלו, _trøt, --,
   {{0x6da3187c,0x7d0263a1,0x3ce663a2,0x63ae015c}},	//   _чита, maos, mcov_, kobn,
   {{0x25a063a3,0x3ce60031,0x69c90188,0x7d0263a4}},	//   _ajil_, lcov_, amee, laos,
   {{0x69c9006c,0xf1bf0206,0x00000000,0x00000000}},	//   bmee, úške_, --, --,
   {{0x3ce60181,0x7d0263a5,0x69c90188,0xdb030437}},	//   ncov_, naos, cmee, moná,
   {{0x94ab30cf,0x00000000,0x00000000,0x00000000}},	//   стна_, --, --, --,
   {{0x394663a6,0xa85700ca,0xc7d700ca,0xb4bd023a}},	//   _haos_, _מידה_, _זוגי_, _अरी_,
   {{0x82a463a7,0x7d0263a8,0xa29504a1,0x63790139}},	//   еште, kaos, фаві, _fìnn,
   {{0xdb0a0222,0x673a626d,0x2d9c0018,0xc0d10065}},	//   llfä, letj, ével_, _abíọ,
   {{0x40341cef,0x3946001c,0x3ce60220,0xa0680396}},	// [5d70] нетс, _maos_, dcov_, паѓа_,
   {{0xdb0315f2,0x673a4052,0xdce001d3,0x2d8d084e}},	//   koná, netj, _romā, _smee_,
   {{0xb4bd000d,0x31e70033,0x00000000,0x00000000}},	//   _अरु_, _ফিকশ, --, --,
   {{0x6fd80455,0x8c3d0092,0x3ce6023e,0x9f490037}},	//   _भूकं, _axşa, gcov_, mpaí_,
   {{0x673a0084,0xbb452cde,0x661a63a9,0xcb690b36}},	//   ketj, делк, hutk, жале_,
   {{0x072140ba,0x661a02e7,0x65bd0146,0x673a63aa}},	//   _माधव_, kutk, kého, jetj,
   {{0x661a063f,0x995100b6,0x69c963ab,0xafdb00f2}},	//   jutk, _zář_, tmee, _trøs,
   {{0xeeeb00ef,0x7d0263ac,0x637000c2,0xdb0a0364}},	//   _động_, caos, _hänt, elfä,
   {{0xfc300397,0x69c93bfa,0xb8e504f1,0x799b63ad}},	//   _محل_, rmee, _एर_, rnuw,
   {{0x378900d6,0x673a052f,0x69c963ae,0xeaf800cd}},	//   ібно_, getj, smee, _فرمت_,
   {{0xe5a62edb,0x6370007b,0x2d9d0294,0xf1bf0096}},	//   дини, _mänt, onwe_, ्षान,
   {{0xe8df0134,0x39460072,0xd04d01c2,0x6abe042c}},	//   _kpọm_, _gaos_, ncaɓ, üpfe,
   {{0x673a0f04,0x63ae0220,0x3d140139,0x3f9301ff}},	//   betj, tobn, _húwà_, kixu_,
   {{0x661a005a,0x81e50081,0x291f01c8,0x00000000}},	//   butk, _নিজ_, lgua_, --,
   {{0x661a3466,0x7bdd028d,0x232700e5,0x3f9301ff}},	//   cutk, _èsuf, ьори_, dixu_,
   {{0x291f63af,0x850633e7,0x00000000,0x00000000}},	//   ngua_, _کوکن, --, --,
   {{0x3ce60220,0x6fd802d5,0x75240027,0x3d140065}},	// [5d80] vcov_, _भूखं, _iciz, _lúwà_,
   {{0x2be1000f,0x644463b0,0x27f90031,0x69dc0036}},	//   _पढ़ा, _isii, ásny_, _èreg,
   {{0xdb1a0103,0x7d024a77,0x216a0451,0xe6bb0442}},	//   _kitö, taos, _дини_, _उरोज,
   {{0x6d910146,0xa3dd007a,0x389e0174,0xdb0301f9}},	//   sťan, _तूँ_, ịri_, voná,
   {{0x3ce65cf0,0x3946001c,0x7d0263b1,0xdd8f0568}},	//   rcov_, _raos_, raos, جون_,
   {{0x3ce663b2,0x637000aa,0x76430167,0x21200117}},	//   scov_, _tänu, _osny, lgih_,
   {{0x394663b3,0x673a0087,0x63700212,0x3ce60031}},	//   _paos_, vetj, _häns, pcov_,
   {{0xd9100979,0x63700222,0x212063b4,0x644452f2}},	//   ایش_, _käns, ngih_, _osii,
   {{0xb4bd1133,0xa3dd34fd,0x673a2ab3,0x64440361}},	//   _अरे_, _तूं_, tetj, _nsii,
   {{0x7d0031c1,0x661a0a56,0x63700149,0x70db0285}},	//   _hems, tutk, _mäns, _भल्ल,
   {{0x6370333a,0x394663b5,0x644463b6,0x76430167}},	//   _läns, _taos_, _asii, _csny,
   {{0x661a63b7,0x673a63b8,0x7d000095,0x00000000}},	//   rutk, setj, _jems, --,
   {{0x290463b9,0x00000000,0x00000000,0x00000000}},	//   mama_, --, --, --,
   {{0x290463ba,0x661a01a5,0x7d000052,0xf7720103}},	//   lama_, putk, _lems, _جاؤ_,
   {{0xd8480028,0x03200251,0x637063bb,0x64440084}},	//   _họ_, _बारह_, _ränt, _esii,
   {{0x212000bf,0x2fd8009c,0x200f016d,0x7524039f}},	//   ggih_, _airg_, ágio_, _gciz,
   {{0xd8480af0,0x6ab90033,0x0094002d,0x00000000}},	// [5d90] _jọ_, েখযো, витэ, --,
   {{0x290463bc,0xd8480d79,0x753d0018,0x656d00fe}},	//   hama_, _mọ_, lesz, _hoah,
   {{0x290463bd,0xd8480649,0x63700222,0x7d00063d}},	//   kama_, _lọ_, _vänt, _bems,
   {{0x29d10618,0x3eb802fe,0x0dcb2b79,0x55d9006e}},	//   _však_, _dyrt_, цузи_, פֿענ,
   {{0xd84806c0,0xe800030b,0x201b0092,0xe6bb0d88}},	//   _nọ_, लीमा_, quqi_, _उर्ज,
   {{0x442900dc,0x7d0001cb,0x00000000,0x00000000}},	//   _mqa_, _eems, --, --,
   {{0x628703e5,0x3ce00146,0x6f0500ec,0x442b0085}},	//   nzjo, živa_, mahc, htc_,
   {{0xd84863be,0x291f0a4b,0x00000000,0x00000000}},	//   _bọ_, ugua_, --, --,
   {{0x44290197,0xaca30134,0xc7950ae3,0xb4ae0096}},	//   _nqa_, _mpịa, ерны, _कडे_,
   {{0x6d4b2059,0x20090138,0x6d4900f0,0x6f050231}},	//   ldga, isai_, _haea, nahc,
   {{0x3c290031,0x7de50138,0xf1db5a5f,0x29045809}},	//   lúv_, _mėso, _मंगन, bama_,
   {{0x290402e6,0xc3290054,0x656d0314,0x200b0234}},	//   cama_, _לו_, _coah, _ovci_,
   {{0x7c2b63bf,0xb4e002d5,0x200f0623,0x6d490113}},	//   ntgr, _तली_, ágil_, _maea,
   {{0x68e963c0,0x76430085,0x6b830023,0x61e80094}},	//   lced, _tsny, nhng, ídlo,
   {{0x69d963c1,0x6f05005c,0x753d0103,0x4429039f}},	//   _kiwe, dahc, besz, _eqa_,
   {{0x6143021c,0x69d90a4b,0x63790139,0x64440f06}},	//   леса, _jiwe, _jìnj, _tsii,
   {{0x7d0063c2,0x64440255,0x69d906b0,0x7c2902a1}},	// [5da0] _rems, _usii, _miwe, _nqer,
   {{0x290463c3,0x6d5b63c4,0x63700222,0x69d963c5}},	//   zama_, _anua, _väns, _liwe,
   {{0x290463c6,0x2009005a,0x2776006e,0x6d4903a8}},	//   yama_, asai_, עגען_, _baea,
   {{0x2ac6030b,0x69d963c7,0x3218061d,0xd5b901d3}},	//   _líbí_, _niwe, mrry_, stāv_,
   {{0x6d4900f0,0xdb03007b,0x92e20033,0x4f340103}},	//   _daea, konä, দরী_, _لڑائ,
   {{0x753d00a5,0xd84863c8,0x290463c9,0x68e9016d}},	//   zesz, _rọ_, wama_, eced,
   {{0xd8484fe2,0x81e20081,0x3ebe0088,0x7d00026a}},	//   _sọ_, নীর_, _átt_, _tems,
   {{0xaca40129,0x6d4900f0,0xb4db00b3,0x2bdd0285}},	//   _arụp, _gaea, ldàv, मदशा,
   {{0x628763ca,0x69d963cb,0x753d0018,0x2ac60af0}},	//   zzjo, _diwe, vesz, _bíbí_,
   {{0x29043aa6,0x6d620039,0x69d90364,0xdb0101dc}},	//   sama_, štač, _eiwe, _njlè,
   {{0x672102d5,0x69d9026e,0x753d0103,0x442901b9}},	//   _मारक_, _fiwe, tesz, _sqa_,
   {{0x7bda63cc,0x68e9008f,0xaaa93613,0x69d90361}},	//   _hitu, cced, _चुटक, _giwe,
   {{0x7bda63cd,0x753d3c90,0x00000000,0x00000000}},	//   _kitu, resz, --, --,
   {{0x69d92826,0x7bda0044,0x9f400036,0x442b0a84}},	//   _ziwe, _jitu, ppiù_, rtc_,
   {{0x7bda63ce,0x63790065,0x81c7007b,0x753d3e15}},	//   _mitu, _hìnk, ещае, pesz,
   {{0xb6bb00a1,0x61d8163d,0x05770037,0xa53500d3}},	//   _מצוי, емся_, _ساعد, _рнич,
   {{0xe13400ae,0x7bda20a3,0x200900c6,0x81e20a43}},	// [5db0] ынты, _oitu, usai_, নীল_,
   {{0x20094e2f,0xa3090068,0x7bda5a12,0xf53f0149}},	//   rsai_, _کرکے_, _nitu, leå_,
   {{0x6d910220,0xe7170327,0x6f050063,0xcfa4468c}},	//   sťam, תחבר_, rahc, ушти,
   {{0x7bda0139,0x5c7543f7,0x7c2b50f2,0x63bf02c6}},	//   _aitu, клет, ttgr, ůzně,
   {{0x8c455014,0x7bda63cf,0x6d4b01d0,0x69da0034}},	//   теле, _bitu, rdga, _पंजी,
   {{0x7bda282c,0x9f9401bf,0x69d963d0,0x7bc8009c}},	//   _citu, mäß_, _siwe, _chdu,
   {{0x7bda63d1,0xfebb09b4,0x69d963d2,0xdcfb0146}},	//   _ditu, _راست_, _piwe, _hluč,
   {{0xb4e00ee0,0x7bda63d3,0x27ef0063,0x6d5b066a}},	//   _तले_, _eitu, _ptgn_, _unua,
   {{0x7bda63d4,0xf77154c8,0xa3dd0251,0x69d90a4b}},	//   _fitu, لاد_, _तंग_, _viwe,
   {{0x7bda63d5,0x68e9217f,0xd5b901d3,0x00000000}},	//   _gitu, sced, ktās_, --,
   {{0xab84163d,0x7bdd0036,0xdb010113,0xcfe80033}},	//   _сутк, _èsub, _njlé, _পিছন,
   {{0xa3e6417e,0x7bda4ffe,0xb9060081,0x7bc8023b}},	//   _बंद_, _zitu, _বড়_, _zhdu,
   {{0xe8180d1b,0x394d63d6,0x7bda0079,0x00000000}},	//   _दिया_, mdes_, _yitu, --,
   {{0xc88308f5,0x394d63d7,0x66e207ed,0xe0df0139}},	//   ığı_, ldes_, _коша, _agò_,
   {{0x69dc0103,0x00000000,0x00000000,0x00000000}},	//   _éret, --, --, --,
   {{0x320a298b,0xaad30be4,0x00000000,0x00000000}},	//   rsby_, धेयक, --, --,
   {{0x394d63d8,0xdb1a0084,0x42c40033,0xd007193d}},	// [5dc0] ides_, _yhtä, ্ডেশ, кете_,
   {{0x1acc0081,0xef17001f,0x64560079,0xd5b900e8}},	//   রুয়া, кму_, _iryi, stāt_,
   {{0x394d0167,0x00000000,0x00000000,0x00000000}},	//   kdes_, --, --, --,
   {{0x6b8102e2,0x394d63d9,0xdb0a004d,0x00000000}},	//   _allg, jdes_, llfø, --,
   {{0x3d070454,0x7bda63da,0xdb0a04d8,0x394d63db}},	//   हणजे_, _pitu, sofí, ddes_,
   {{0x7bda1175,0xfca963dc,0x395d03a8,0x394d63dd}},	//   _qitu, رانو_, _anws_, edes_,
   {{0x7bda63de,0x79a663df,0x394d0313,0x539b0142}},	//   _vitu, крие, fdes_, ויסו,
   {{0x2902003e,0x394d63e0,0x7bda0027,0x3c9200d1}},	//   úka_, gdes_, _witu, _پیتز,
   {{0xa3b263e1,0xebe602ec,0x8c430e05,0xb90a099d}},	//   टका_, _розп, _кете, _मल_,
   {{0x394d05fe,0x00000000,0x00000000,0x00000000}},	//   ades_, --, --, --,
   {{0x64560027,0xa92623b8,0xf53f0212,0x00000000}},	//   _aryi, _адел, teå_, --,
   {{0xceb30054,0xd9460831,0x7bdd028d,0x66150094}},	//   יית_, _једи, _èsuc, ázka,
   {{0x261602d5,0x89d7001c,0x4813004d,0x64565263}},	//   पूजी_, _شوهر_, _вміс, _cryi,
   {{0x645663e2,0x00000000,0x00000000,0x00000000}},	//   _dryi, --, --, --,
   {{0xdcfb02e6,0x798263e3,0xd5b901d3,0x69dc20df}},	//   _sluč, _klow, utās_, _éres,
   {{0xdcfb00c4,0xc6d9006e,0xd5b900e8,0x00000000}},	//   _pluč, _אַפר, rtās_, --,
   {{0xd5b901d3,0x636b0364,0xbbe100b6,0x7982024a}},	// [5dd0] stās_, _münz, _पढेक, _mlow,
   {{0xdc8e0294,0x2ef4001f,0x798203a8,0x00000000}},	//   tịnụ_, изур, _llow, --,
   {{0x645a00d9,0x394d052f,0xdebc01c2,0x657d0124}},	//   ātie, ydes_, _karƙ, oksh,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x394d05e8,0xe4ff02c6,0xdc8e0134,0x00000000}},	//   vdes_, _štěň, sịnụ_, --,
   {{0x447c00c1,0x61e50060,0x399a01d3,0x7982083e}},	//   ונדע, _kuhl, zīst_, _alow,
   {{0x61e50084,0xe8000251,0x79823d0f,0x52c10285}},	//   _juhl, लीसा_, _blow, _एरोस,
   {{0x394d63e4,0x61e5209b,0xca7400c6,0x2d86002b}},	//   udes_, _muhl, рушы, choe_,
   {{0x61e50415,0x63b50103,0x00000000,0x00000000}},	//   _luhl, kozn, --, --,
   {{0x7c3b63e5,0x9c130174,0x00000000,0x00000000}},	//   _ipur, pọbi, --, --,
   {{0xf77100bf,0x798263e6,0x98b800e8,0xba740d7f}},	//   لاگ_, _flow, īzāk_, _پالت,
   {{0x78a45455,0x7a7a006e,0xda7a006e,0x798263e7}},	//   _žive, _ארעס, _אנער, _glow,
   {{0x1b060081,0x69dc0451,0x81ac0081,0x3f830117}},	//   _রাতে_, _èrea, গতম_, _olju_,
   {{0xade308c0,0x68fb038c,0x63b563e8,0x289a006e}},	//   गदान_, lbud, gozn, _אינא,
   {{0x443b0113,0xdb0a2b12,0x00000000,0x00000000}},	//   _epq_, nofá, --, --,
   {{0xdebc01c2,0x645600ca,0xd5b23a1d,0x00000000}},	//   _garƙ, _tryi, _دفع_, --,
   {{0x7dda00b6,0xefca00c2,0x64560027,0x7d0401cd}},	// [5de0] _důsl, елал_, _uryi, ðism,
   {{0x44220706,0x7dda030b,0x00000000,0x00000000}},	//   muk_, _půso, --, --,
   {{0x7c3b63e9,0x3ebc02b6,0xe29a037e,0x2b5e0154}},	//   _apur, ævt_, _чан_, _rntc_,
   {{0xac0a11b6,0x2b4c63ea,0x3f8363eb,0x00000000}},	//   енда_, _sadc_, _elju_, --,
   {{0x442263ec,0x68fb63ed,0xdca33028,0x6b9846a1}},	//   nuk_, dbud, баци, tivg,
   {{0xdee305e1,0x7c3b00e7,0xcb671e33,0x636b0367}},	//   _гори, _dpur, лаче_, _büny,
   {{0x4422001c,0xb4db05fe,0xee3a00c2,0x7c3b0b1c}},	//   huk_, ndàr, _янв_, _epur,
   {{0x636b35f8,0x442236c6,0x661a0094,0xd90e0421}},	//   _düny, kuk_, vrtk, سیت_,
   {{0x442263ee,0x7f4e023e,0xc173040a,0xa3b60034}},	//   juk_, _kabq, מחה_, ड़ता_,
   {{0x44224263,0x3f9a063f,0x9f40275a,0xdebc03e3}},	//   duk_, nipu_, mpió_, _sarƙ,
   {{0x7c2263ef,0x06d70081,0x63b563f0,0xe8fa63f1}},	//   luor, _দ্বি, vozn, _зле_,
   {{0x443b0113,0x61e50555,0x442263f2,0x6d4201c8}},	//   _ppq_, _ruhl, fuk_, neoa,
   {{0x68e20129,0xa8772729,0x442263f3,0x657d63f4}},	//   _igod, _محور_, guk_, rksh,
   {{0xb86500d0,0x69c033e8,0xc7a3032d,0x69cb0052}},	//   _خامو, llme, _личк, _zhge,
   {{0xf1a70f80,0x3f9a00b3,0x6d420062,0x00000000}},	//   гран, dipu_, keoa, --,
   {{0xeeeb00de,0x443b0167,0x7c2263f5,0x44b60294}},	//   _đống_, _tpq_, kuor, ọsụ_,
   {{0x442263f6,0x6d4263f7,0x200f0018,0x68e20239}},	// [5df0] cuk_, deoa, égi_, _mgod,
   {{0x27e600de,0xeeab002d,0x61e514d2,0x2bc40469}},	//   _muon_, нтек_, _tuhl, _लीला,
   {{0x7f4e07b4,0x4fc463f8,0x68fb0150,0xa3b2167f}},	//   _dabq, сста, ybud, टकर_,
   {{0x714700a9,0x68e2019f,0x7c22028d,0x69c063f9}},	//   _схож, _ngod, fuor, jlme,
   {{0x27e663fa,0xab29430b,0x7c220036,0xf3ff0131}},	//   _nuon_, вола_, guor, ixão_,
   {{0xaa150a28,0x3f830106,0xab620511,0x447c00c1}},	//   афиј, _ulju_, şünm, ענגע,
   {{0x442263fb,0x25a9037a,0x00000000,0x00000000}},	//   zuk_, _ojal_, --, --,
   {{0x27e663fc,0x442263fd,0xdb0a00d4,0x00000000}},	//   _buon_, yuk_, rofá, --,
   {{0x7785004c,0x7c8763fe,0x68fb00f2,0x7d0b63ff}},	//   илиз, _суве, rbud, mags,
   {{0x7d0b6400,0x6c840080,0x25a90006,0x47593457}},	//   lags, _الكم, _ajal_, трия_,
   {{0x391509b4,0x44222f91,0xa8060328,0x00000000}},	//   _نواز, wuk_, _peñó, --,
   {{0x442217fb,0x386004a3,0x7d0b2846,0xd5440139}},	//   tuk_, _šire_, nags, _dé̟s,
   {{0x660b0138,0x25a90052,0x00000000,0x00000000}},	//   _šokė, _djal_, --, --,
   {{0x68e26401,0x44226402,0x7d0b0088,0x799b024a}},	//   _zgod, ruk_, hags, liuw,
   {{0x442203b4,0xe2970036,0xd19600c9,0x12191402}},	//   suk_, аар_, ашањ, люты_,
   {{0x44221084,0x394f0f5a,0x799b0350,0x6d4201ff}},	//   puk_, _jags_, niuw, xeoa,
   {{0xe0da339a,0x55bb0054,0x7d0b5748,0x3f9a6403}},	// [5e00] тва_, _במקו, dags, tipu_,
   {{0x6fc20220,0x7c2200c2,0x7f4e0188,0xa3ba4175}},	//   môck, vuor, _qabq, _جابر_,
   {{0x6f070b14,0x3f9a6404,0xcd0623bf,0x4e2a171b}},	//   _dejc, ripu_, ачли, тоен_,
   {{0x163607a6,0x3f9a30cd,0x7c222cdb,0x799b0350}},	//   ינער_, sipu_, tuor, jiuw,
   {{0x6c545861,0xcb6a11b4,0xdca62ac0,0x7afd0103}},	//   склу, каде_, шади, _ősta,
   {{0xe457006e,0x6d4201e9,0x7c220634,0x5bb7224a}},	//   יינט_, seoa, ruor, алія_,
   {{0x80db0081,0x7d0b6405,0x27e66406,0xbea31107}},	//   যুদ্, bags, _suon_, _дарк,
   {{0x63790139,0x00000000,0x00000000,0x00000000}},	//   _hìnt, --, --, --,
   {{0xab660315,0x394f1d10,0x2cbf1098,0x7c22028d}},	//   _квал, _dags_, _gyud_, quor,
   {{0x103700a1,0x27e600fe,0x25a90e37,0x7bdd0131}},	//   סטים_, _vuon_, _sjal_, _ésup,
   {{0x9a6a0192,0x5a962fad,0x628e09ac,0x70c30034}},	//   _جمال_, _траф, jzbo, _शर्ल,
   {{0xd5b80a8d,0x68e22388,0xd6d70138,0x27e60084}},	//   ися_, _ugod, шты_, _tuon_,
   {{0x28d200e2,0x0f110081,0xd91b0266,0xf76f00d1}},	//   देशि, স্টঃ_, _יואל, سای_,
   {{0xf743015f,0xafdb0120,0x39446407,0x00000000}},	//   _мечо, _frøy, lems_, --,
   {{0xdce0030b,0x41e7004d,0xdcef080e,0x6f070141}},	//   _pomě, ріга, _šeče, _rejc,
   {{0x3f986408,0xd6db00ca,0x25a900d4,0x39443e30}},	//   _amru_, _בחול, _ujal_, nems_,
   {{0x0f150426,0x752d0092,0xc31c0033,0x2eaf0034}},	// [5e10] ймаю, _icaz, দ্ধি_, _जुड़त,
   {{0x7d1d00fb,0xeeeb00ef,0x644d0f33,0x5eab00c7}},	//   _össz, _đồng_, _isai, _করবে,
   {{0x7d0b6409,0xdfd8013d,0x6f0702c6,0x42552259}},	//   tags, рът_, _vejc, _انجر,
   {{0xb6d900c1,0x00000000,0x00000000,0x00000000}},	//   אַנט, --, --, --,
   {{0xa3ae14e5,0x7d0b640a,0x1fe50033,0x394f640b}},	//   _कदम_, rags, _পৌরস, _rags_,
   {{0x7f850080,0xdb030257,0x3dcd00f9,0x644d0051}},	//   _السن, onné, _whew_, _msai,
   {{0x752d002d,0x79890060,0x7d0b1331,0x799b0167}},	//   _ocaz, thew, pags, tiuw,
   {{0xe8180e72,0x21290655,0x78a42956,0x644d007b}},	//   _दिशा_, ngah_, _živa, _osai,
   {{0xa3b7412e,0x2d9d0384,0x79890313,0x628e0063}},	//   जवा_, miwe_, rhew, zzbo,
   {{0x2d9d640c,0xab740080,0x9b7400e3,0x7d09008a}},	//   liwe_, _والإ, _والص, _hees,
   {{0xd90f07d9,0x7d09640d,0x394f05d0,0x644d640e}},	//   _ہیں_, _kees, _tags_, _asai,
   {{0x7d09640f,0xaca300de,0x2d9d1937,0x7bc30ba1}},	//   _jees, _ngừn, niwe_, llnu,
   {{0x7d09226b,0x2b1b033a,0xe7392c95,0x3f810167}},	//   _mees, _नयाँ_, _бел_, kkhu_,
   {{0x7d0917f8,0xd8d600ca,0x2d9d0201,0x628e5530}},	//   _lees, _פוסט_, hiwe_, tzbo,
   {{0xa2bb2172,0x15f50391,0x2d9d628a,0x27ed023b}},	//   _शुद्, _استح, kiwe_, lqen_,
   {{0x7d0900d9,0x21296410,0x2d9d6411,0x3f81008c}},	//   _nees, ggah_, jiwe_, ekhu_,
   {{0xa06701c9,0x656400a6,0x2d9d2d76,0xfbb905d6}},	// [5e20] бата_, _inih, diwe_, ेताम,
   {{0xdfcf0037,0xe457021e,0x00000000,0x00000000}},	//   فيق_, _פייט_, --, --,
   {{0x65640074,0x7d096412,0xa91d0138,0x2d9d6413}},	//   _knih, _bees, sižy, fiwe_,
   {{0x10a6090f,0xe818009d,0x7d09047b,0x2d9d0193}},	//   _гимн, _दिला_, _cees, giwe_,
   {{0xe3bf04d8,0x7d096414,0xdca311d9,0xbf9b02ac}},	//   luña_, _dees, паци, _kwêl,
   {{0xdd92010d,0x3f98015c,0x00000000,0x00000000}},	//   _کور_, _umru_, --, --,
   {{0x3ce90335,0x7d09043e,0x8e8600e3,0x2d9d08c2}},	//   žava_, _fees, _الأه, biwe_,
   {{0x7d096415,0x2d9d02a4,0x57f42c22,0x6564010a}},	//   _gees, ciwe_, опит, _nnih,
   {{0x20126416,0xdb180216,0xa3d8521f,0x63790139}},	//   nsyi_, novë, िषा_, _mìnr,
   {{0x752d00d3,0x5eab0081,0x7d093149,0x644d01ec}},	//   _scaz, _করতে, _zees, _rsai,
   {{0x7d090c1a,0x6ac60dd0,0x61fc00e7,0x20120063}},	//   _yees, _اقام, jprl, hsyi_,
   {{0x290d6417,0x398a0139,0x6576037a,0x26c201d3}},	//   caea_, _bùse_, _coyh, āko_,
   {{0xb4e91d72,0x3211007f,0xdb1a00d4,0x7e7e007b}},	//   _बली_, wszy_, _akté, hypp,
   {{0x2d9d6418,0xf41f00c2,0x65640372,0x00000000}},	//   ziwe_, rrä_, _enih, --,
   {{0x63790032,0x1b7b006e,0x4394180b,0x00000000}},	//   _bìnr, נטלע, чарс, --,
   {{0x644d6419,0x60f90761,0x35a407ed,0x32110034}},	//   _tsai, рная_, _најг, rszy_,
   {{0x644d641a,0x212929e4,0xdb180216,0x6b88066a}},	// [5e30] _usai, rgah_, govë, _oldg,
   {{0x7d09641b,0x32110034,0x3f87641c,0x2d8e0052}},	//   _sees, pszy_, ónu_, ëfen_,
   {{0x2d9d0384,0x9f40003e,0xf3eb0033,0xe3bf034f}},	//   tiwe_, rpið_, _কবির_, cuña_,
   {{0x05c9046e,0xa159641d,0x20121d49,0xd5c90569}},	//   रतिब, _таму_, bsyi_, रतिज,
   {{0x78a4025b,0x2d9d023f,0xdc69180b,0x7d09641e}},	//   _živn, riwe_, ралд_, _vees,
   {{0x7d090f51,0x2d9d641f,0x823405bc,0xef930504}},	//   _wees, siwe_, _بریا, _عیاد,
   {{0x7d096420,0x2d9d417b,0x00000000,0x00000000}},	//   _tees, piwe_, --, --,
   {{0xa3e903a2,0x09e2036a,0x7de50138,0x38600995}},	//   यदा_, мощн, _dėst, _šira_,
   {{0x52fb030b,0xacf800ae,0x00000000,0x00000000}},	//   ्राउ_, _ынту_, --, --,
   {{0xbca400ab,0x00000000,0x00000000,0x00000000}},	//   _عملي, --, --, --,
   {{0x2b4700ee,0x05aa00c2,0x6370042c,0x65bd02c6}},	//   menc_, ивой_, _tänz, véhr,
   {{0x69d00378,0x9596004d,0x2b4009ac,0xe82100a4}},	//   _डीपी, ішні, đice_, _मिपा_,
   {{0x98c70080,0x80db0285,0x00000000,0x00000000}},	//   _اغان, पेमे, --, --,
   {{0x2b470428,0xf1bf6421,0xd3ba004d,0x7e7e007b}},	//   nenc_, _aká_, румі_, yypp,
   {{0xe7960100,0xa3e6058f,0x2b4700ee,0x00000000}},	//   _بانک, _बंक_, ienc_, --,
   {{0xe3bf22e7,0x65c30c79,0x00860a3a,0xdb180052}},	//   ruña_, _обща, олбо, tovë,
   {{0x387f0821,0x386d0072,0x10a63ac9,0x00000000}},	// [5e40] nyur_, nxer_, циан, --,
   {{0xbc6a1ac9,0xf1bf0139,0xe3bf002b,0x386d00ee}},	//   یمان_, _eká_, puña_, ixer_,
   {{0xdb1801e5,0x2b475703,0xecea1c16,0x00000000}},	//   sovë, denc_, адел_, --,
   {{0x302a0938,0x63bc0348,0x973c00cb,0x387f0270}},	//   _комп_, lorn, miće, kyur_,
   {{0x973c0039,0xdb181e6a,0x9b6a0cc6,0x9c130134}},	//   liće, lové, ишка_, lọji,
   {{0x63bc6422,0x5fc50096,0x2b4742ef,0x7de500c6}},	//   norn, वतःल, genc_, _pėst,
   {{0xdb186423,0x973c08c5,0xdd922827,0x00000000}},	//   nové, niće, _قوس_, --,
   {{0x63bc0a47,0xdb0360d6,0xb4e900b7,0x3ea7037a}},	//   horn, fonó, _बले_, únte_,
   {{0xd90d001c,0xdb180146,0x973c00cc,0x00000000}},	//   ایه_, hové, hiće, --,
   {{0x473428b9,0x3dc66424,0xdb18033d,0x973c0335}},	//   чнос, llow_, kové, kiće,
   {{0x63bc6425,0x973c0335,0xdb180146,0x295600e5}},	//   dorn, jiće, jové, _мъдр,
   {{0x7d020a9f,0x973c01ac,0xdb180146,0x3ce00094}},	//   nbos, diće, dové, živu_,
   {{0x81b20033,0x7d02084e,0x27f800d1,0x00000000}},	//   য়গা_, ibos, _افتد_, --,
   {{0x63bc201a,0x3dc60167,0xdceb0218,0x7d0204e9}},	//   gorn, hlow_, _čičo, hbos,
   {{0x973c03d6,0x44220ac9,0xdb186426,0x7dd134cb}},	//   giće, ark_, gové, låse,
   {{0xdb180149,0x3f8a6427,0x44220218,0xf77000d1}},	//   llvä, _albu_, brk_, _تاچ_,
   {{0x63bc5cc1,0x12e7004b,0xfbca00b6,0x40340c3f}},	// [5e50] born, _мінг, िताम, метс,
   {{0x973c2461,0x2484038c,0xdb180146,0x7c2201ff}},	//   biće, ømme_, bové, dror,
   {{0x78a40b27,0xc33200f5,0xdea10018,0x973c007e}},	//   _živl, _אוי_, ریری, ciće,
   {{0xf1a76428,0x3dc61470,0x387f01c2,0x7c22573b}},	//   _фрон, glow_, yyur_, fror,
   {{0xdfdb0465,0xe3b003ed,0x661d00a5,0x2b476429}},	//   _във_, _سری_, ąski, tenc_,
   {{0x9f4300dd,0x50da00ca,0x92bf0081,0x7d02009c}},	//   _mijë_, _לקרא, েশী_, abos,
   {{0x7d02178b,0x2b47642a,0x3da707bf,0x3179153c}},	//   bbos, renc_, _драб, _kosz_,
   {{0x63bc1b32,0xdb03642b,0x98af08a9,0x386d05fe}},	//   zorn, tonó, šače_, txer_,
   {{0x7d1b04ff,0xdb181054,0x973c09ac,0x5b3300ae}},	//   _idus, zové, ziće, _омаӂ,
   {{0x63bc0d34,0xdb033e6a,0x386d002b,0x6a67109d}},	//   xorn, ronó, rxer_, _وطال,
   {{0xa2bb1c0a,0x98ab03a3,0x387f12f5,0xb4b400c3}},	//   _शुल्, ıcı_, syur_, _जुड़_,
   {{0x973c00e9,0x7c2400e3,0xdb030037,0x28df142e}},	//   viće, áirg, inní, _पृथि,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27ff00bf,0xdb18025b,0x973c0335,0x9f430216}},	//   mpun_, tové, tiće, _dijë_,
   {{0x7d1b02e6,0x63bc642c,0x69d002d5,0x27ff0967}},	//   _odus, rorn, _डीडी, lpun_,
   {{0x973c01ac,0xdb180146,0x31660951,0x7d1b642d}},	//   riće, rové, ñoz_, _ndus,
   {{0xef1a0c2b,0x27ff159d,0x30760e58,0x973c0106}},	// [5e60] йма_, npun_, чувс, siće,
   {{0x98a608c5,0x7d1b642e,0xdb0a0149,0x7778023e}},	//   šiće_, _adus, llfö, _xovx,
   {{0xee3a2c6b,0x27ff17b6,0xdd8f00cd,0x7d025cf1}},	//   сне_, hpun_, گون_, tbos,
   {{0x27ff0da3,0xdd9900d6,0x25a202c6,0x93250103}},	//   kpun_, оші_, nikl_, _ٹرین,
   {{0xdd8f1487,0x00000000,0x00000000,0x00000000}},	//   دون_, --, --, --,
   {{0x7d1b0084,0xa3b20789,0x69dc0103,0x7d0244cb}},	//   _edus, टकट_, _érez, sbos,
   {{0xdb030428,0x61e60433,0xed5a0a52,0x6e43007e}},	//   tonò, _kikl, _лов_, _перз,
   {{0x7bc102c3,0x645a01d3,0x6f0e01b9,0x61e602a1}},	//   _eklu, ātij, _hebc, _jikl,
   {{0x61e6642f,0xdb036430,0xdcfb04e9,0x7dda02c6}},	//   _mikl, ronò, _sluć, _důst,
   {{0x1b0f0f71,0xdcfb0039,0x35f40c64,0x5fbe00b6}},	//   _সাথে_, _pluć, мпор, ्तिल,
   {{0x6444104d,0xb34720df,0x7c246431,0x7bdf020d}},	//   _apii, _liçõ, šird, ïque,
   {{0x61e66432,0xb7d70068,0x2bca0034,0xc7b90103}},	//   _nikl, _ہونا_, ितवा, lről_,
   {{0x6fbe2234,0x5fbe04d7,0x6d400141,0x00000000}},	//   ्तां, ्ताल, _mbma, --,
   {{0x7dda030b,0x9f430052,0x237a028d,0x466a1e54}},	//   _zůst, _vijë_, _copj_, _грим_,
   {{0x6d400335,0x200708c5,0xa3ae2918,0x00000000}},	//   _obma, ćnim_, _कदर_, --,
   {{0x5eab0081,0x25a22c0a,0x31c40396,0x0ef50980}},	//   _করলে, cikl_, есув, इड्स_,
   {{0x78a41cb4,0xdb1a19a3,0x92bf0081,0x61e66433}},	// [5e70] _živj, _aktí, েশে_, _dikl,
   {{0x4439509a,0x442b4336,0x7dca003e,0x6d400364}},	//   mts_, muc_, sýsl, _abma,
   {{0x44396434,0x7f550143,0x6d400167,0x442b6435}},	//   lts_, _vazq, _bbma, luc_,
   {{0x260100c3,0x7bc10213,0x7d1b009e,0x6f1c03a8}},	//   वीटी_, _sklu, _qdus, _edrc,
   {{0x44390930,0x442b6436,0x657d023b,0x7dda02c6}},	//   nts_, nuc_, ërhy, _růst,
   {{0x44395624,0xbb42008f,0x61e601e9,0x6f1c0072}},	//   its_, вешк, _zikl, _gdrc,
   {{0x44396437,0x442b6438,0xdce80233,0x1b060033}},	//   hts_, huc_, _çoğa, _রাখে_,
   {{0x44390029,0x27ff3231,0x9f4306a3,0x7d1b6439}},	//   kts_, tpun_, _sijè_, _udus,
   {{0x27ff06ee,0x6d4b005a,0x442b08a9,0x44390078}},	//   upun_, mega, juc_, jts_,
   {{0x442b643a,0x27ff17b6,0x6d595537,0x44390973}},	//   duc_, rpun_, ldwa, dts_,
   {{0x4439643b,0x25a20234,0x7c2b643c,0x27ff643d}},	//   ets_, tikl_, lugr, spun_,
   {{0x6d4b643e,0x7c240039,0x6d59643f,0x64a601b6}},	//   nega, šire, ndwa, дама,
   {{0x61e66440,0xe72e0a7c,0x7c2b6441,0x44396442}},	//   _rikl, _ие_, nugr, gts_,
   {{0x69c912f1,0x61e66443,0x6d4b6444,0x69db0052}},	//   llee, _sikl, hega, lmue,
   {{0x0caa05d4,0x44396445,0x2d8d00ac,0x76430167}},	//   _कश्म, ats_, _olee_, _upny,
   {{0x6d4b6446,0x69c96447,0x27e76448,0x290f6449}},	//   jega, nlee, _hinn_, _jega_,
   {{0x44390054,0x6d4b644a,0x6f0e023e,0x61e6644b}},	// [5e80] cts_, dega, _pebc, _vikl,
   {{0x78a41386,0x290f644c,0x6d59644d,0xef1a07bf}},	//   _živk, _lega_, edwa, іме_,
   {{0x27e7644e,0x69c9644f,0x27ef0212,0x61e66450}},	//   _minn_, klee, _lugn_, _tikl,
   {{0x27e71f4e,0x290f6451,0x3ea70080,0x6d4b6452}},	//   _linn_, _nega_, únta_, gega,
   {{0x6f0e0197,0x6aa62c5d,0xc7b90103,0x69c90188}},	//   _tebc, गप्र, tről_, dlee,
   {{0x290f007a,0x69c25742,0xaa580acf,0x6f1c0b14}},	//   _aega_, _skoe, зику_, _udrc,
   {{0x6d4b6453,0x6da6430b,0xcf570796,0x25a0058f}},	//   bega, _жива, _קבלת_, _omil_,
   {{0xd90d00d0,0x290f04a3,0xaca40174,0xdb180161}},	//   میم_, _cega_, _asụp, moví,
   {{0x290f6454,0x274a0084,0x27e703ea,0x6da35861}},	//   _dega_, очно_, _binn_, _рита,
   {{0x27e70a62,0x61fe005f,0xfc6700cd,0xf69807c8}},	//   _cinn_, _otpl, _تخفی, звој_,
   {{0x69c92d04,0xdce00029,0xe5353d7b,0x443900f9}},	//   blee, _tomē, нень, wts_,
   {{0x27e70102,0x44396455,0x442b4d42,0x3869042d}},	//   _einn_, tts_, tuc_, _šare_,
   {{0x27e700f3,0x20070039,0x61fe250f,0x00000000}},	//   _finn_, ćnik_, _atpl, --,
   {{0x44396434,0xf8ad0018,0x6d4b007f,0x645d21ad}},	//   rts_, _چکی_, zega, rvsi,
   {{0x44396456,0xeb9100c1,0x7d0d01cd,0x7c2b0364}},	//   sts_, אָן_, ðask, zugr,
   {{0x69c06457,0xd5b901d3,0x44391dc2,0x6d4b6458}},	//   nome, irāk_, pts_, xega,
   {{0x629a0220,0x9099008f,0x4fd52bbb,0xc2eb0076}},	// [5e90] útor, чват_, ежат, _وعدم_,
   {{0x69c06459,0x6d4b0517,0xdceb0146,0x6e95231c}},	//   home, wega, čičk, низу,
   {{0x69c0645a,0x6d4b645b,0x3d0b05fa,0x6fcb042c}},	//   kome, tega, ारले_, lück,
   {{0x69c00034,0x7c2b5228,0x00000000,0x00000000}},	//   jome, tugr, --, --,
   {{0x69c0645c,0x290f645d,0x69c901c0,0x6d591665}},	//   dome, _rega_, vlee, rdwa,
   {{0x290f645e,0x6d4b4047,0x7c3912ba,0x7c2b645f}},	//   _sega_, sega, rtwr, rugr,
   {{0x6d4b5553,0x290f3916,0x27e70013,0x69c924a9}},	//   pega, _pega_, _rinn_, tlee,
   {{0x27e76460,0x26c70f5a,0xeab001c3,0x7bca02ac}},	//   _sinn_, _ryno_, جعه_, alfu,
   {{0x69c96461,0xb7bd002d,0x69db6364,0xdb030216}},	//   rlee, luţi, rmue, ninë,
   {{0x290f0134,0x69c96462,0x2007005f,0x25a00170}},	//   _wega_, slee, ćnih_, _smil_,
   {{0x290f0b27,0x27e76463,0xaa9500e3,0x69c91044}},	//   _tega_, _vinn_, _ثلاث, plee,
   {{0x69c02733,0xceb2028c,0x6a5301d4,0x27e76464}},	//   come, ריט_, _nəfə, _winn_,
   {{0x394d0006,0x27e76465,0x1869235c,0x61fe009c}},	//   mees_, _tinn_, _хали_, _stpl,
   {{0x33d5116d,0x394d0185,0x987a00c1,0x39910042}},	//   віст, lees_, _מאנט, _dáse_,
   {{0x3243007b,0xe5a60d76,0x00000000,0x00000000}},	//   лерг, _пики, --, --,
   {{0x394d42cc,0x79894b2d,0x69dc0036,0x6a5300a7}},	//   nees_, nkew, _èret, _cəfə,
   {{0xf99207a6,0xe3b20688,0x1f665be9,0x8c9f0034}},	// [5ea0] ארן_, _مرد_, нкам, _खेलो,
   {{0xdb186466,0x69c028c0,0x6fb600e3,0x996c00b6}},	//   toví, zome, رمضا, měť_,
   {{0x7dca003e,0x69c06467,0xa3bd0179,0x79890313}},	//   lýsi, yome, इकर_, kkew,
   {{0xdb1854fc,0x6fd000c3,0x69c00072,0x6fcb042c}},	//   roví, _तीरं, xome, hüch,
   {{0x69c06468,0x8ba6008f,0x394d02ac,0xae1c0096}},	//   vome, нидж, dees_, _पटकन_,
   {{0xdb18030b,0x69c06469,0xb7bd00d3,0x79890172}},	//   poví, wome, buţi, ekew,
   {{0x1c1c05d4,0x394d057a,0xc333006e,0xb7bd00ae}},	//   _निकल_, fees_, אוו_, cuţi,
   {{0xdb030113,0x00000000,0x00000000,0x00000000}},	//   hinè, --, --, --,
   {{0xdcef02e6,0xd84e0134,0x57a63b21,0x00000000}},	//   _šeće, _gọlf_, ешна, --,
   {{0x69c0646a,0x5a962c52,0x65ab00c2,0x9f42007b}},	//   some, _преф, köhä, _etkö_,
   {{0x69c000d2,0x64560991,0x394d646b,0xa61300ae}},	//   pome, _asyi, bees_, лмэч,
   {{0xceb3004f,0x394d646c,0x399a01d3,0x6fcb0364}},	//   טית_, cees_, gūst_, tück,
   {{0xa3bd045f,0x6fcb0364,0x00000000,0x00000000}},	//   इकल_, büch, --, --,
   {{0x6fcb02e2,0x6a5301d4,0xdb0a3210,0xdb030216}},	//   rück, _səfə, mofó, vinë,
   {{0x69dc028d,0x21671a0c,0xdb0a646d,0xf7730142}},	//   _ères, нтаг, lofó, _תקצ_,
   {{0xdb03023b,0xf1a407bf,0x04950076,0x00000000}},	//   tinë, грун, _للبح, --,
   {{0x656d646e,0xb50716e2,0xdb03098c,0xd6df007f}},	// [5eb0] _inah, _व्यय_, binè, ąłem_,
   {{0xb7bd002d,0xdb03646f,0x00000000,0x00000000}},	//   tuţi, rinë, --, --,
   {{0x1b0f0081,0xa295084c,0x661a6470,0x394d00ca}},	//   _সালে_, _рані, nstk, yees_,
   {{0xe82105d4,0x63a76471,0xdb036472,0x661a6473}},	//   _मिला_, lijn, miné, istk,
   {{0xbde50139,0x2fd900e3,0xd11600a1,0x657f02ac}},	//   _abèé, _يوجد_, _בקרה_, _moqh,
   {{0x63a76474,0x394d0185,0xfaa54ce6,0xc4d422fe}},	//   nijn, wees_, кало, נגס_,
   {{0xbd050257,0x661a6475,0x00000000,0x00000000}},	//   _créé, jstk, --, --,
   {{0x63a76476,0x657f063d,0x00000000,0x00000000}},	//   hijn, _noqh, --, --,
   {{0xdd9400c6,0xc8db39d4,0x79892612,0x6fcb042c}},	//   _саты, मेंट, rkew, tüch,
   {{0xfd4d0028,0x656d6477,0x66e5017b,0xdb03016d}},	//   _ngoạ, _anah, копа, gonô,
   {{0x63a70146,0x6d5b6478,0x6fcb01bf,0x394d6479}},	//   dijn, _kaua, rüch, pees_,
   {{0xe5a62dd1,0x7bc3647a,0xdb033e1d,0xdb1800b6}},	//   тими, lonu, diné, mová,
   {{0x6d5b1ee3,0x399a0130,0xdb18647b,0xe739007e}},	//   _maua, _קינד, lová, _жел_,
   {{0x6d5b647c,0x7bc3647d,0x63a7647e,0xc35500e5}},	//   _laua, nonu, gijn, лъсъ,
   {{0xdb18647f,0x80df0033,0x69d9063d,0x00000000}},	//   nová, _ফ্ল্, _khwe, --,
   {{0x3860042d,0xfe720e27,0x6d5b01ff,0x7bc36480}},	//   _širi_, یدا_, _naua, honu,
   {{0xdb180363,0x91e34dff,0x7bc36481,0x4fea6482}},	// [5ec0] hová, роте, konu, дман_,
   {{0xcfb500c7,0xe0d74268,0xdb18030b,0x63a701c0}},	//   _জীবন, тву_, ková, cijn,
   {{0x1fb50508,0xe3b20100,0x6d5b6483,0x7bc36484}},	//   устр, _مرگ_, _baua, donu,
   {{0x5bca2cb6,0xdb180363,0x6d930233,0x00000000}},	//   ित्व, dová, _açab, --,
   {{0x7bc36485,0x6d5b6486,0xb4db00ee,0x00000000}},	//   fonu, _daua, leàr, --,
   {{0x661a6487,0x7bc36488,0xfe462a84,0xdb1802c6}},	//   ystk, gonu, _инго, fová,
   {{0x5ee000c7,0x6d5b009c,0xdb180447,0xcb670284}},	//   _প্রে, _faua, gová, таје_,
   {{0x69d902ad,0x63a701c0,0x38690580,0x41d800a8}},	//   _chwe, zijn, _šara_, _भीमस,
   {{0xdb341e49,0x69d942e9,0xe5770138,0x2e3c003e}},	//   _مذاک, _dhwe, _nėšč, líf_,
   {{0x656d0146,0x81d80081,0x69d91b99,0xdb0a604f}},	//   _snah, াদি_, _ehwe, rofó,
   {{0x7f5c4071,0xdb18035c,0xdb03016d,0xdce000c6}},	//   _marq, cová, ronô, _pomė,
   {{0x891a0688,0x661a6489,0x63a7648a,0x644800d3}},	//   _آغاز_, rstk, wijn, ădin,
   {{0x6dbc4072,0x81d80081,0x63a7648b,0x26c20034}},	//   mčad, াদা_, tijn, łko_,
   {{0xdb030349,0xc4d300c3,0x6235001f,0xdbcf0206}},	//   tiné, _सरीख, легу, _sľúb,
   {{0x248d13ad,0x63a73dfd,0x00000000,0x00000000}},	//   šem_, rijn, --, --,
   {{0x7bc3648c,0x656d648d,0xe5c400d6,0x6dbc0542}},	//   zonu, _unah, _всьо, nčad,
   {{0x7bc3008e,0xdb18030b,0x7f5c041c,0xdb0300e3}},	// [5ed0] yonu, zová, _barq, siné,
   {{0x2fc7561d,0x248400c2,0x7f5c648e,0xb35503a0}},	//   ông_, ämme_, _carq, _скош,
   {{0x20020233,0x63a5009c,0xb7bd044c,0x7bc3648f}},	//   _etki_, _imhn, cuţu, vonu,
   {{0xdb1800b6,0x7bc80113,0x6dbc007e,0x9f4a05aa}},	//   vová, _akdu, jčad, _libè_,
   {{0x7c2400e9,0xa3b800bf,0x7f5c008c,0x68fb00a7}},	//   širn, _سایر_, _farq, vcud,
   {{0xdb180fc5,0x442b152f,0x764a052f,0x6d5b0051}},	//   tová, irc_, _opfy, _waua,
   {{0xa9a53bba,0x00000000,0x00000000,0x00000000}},	//   ликд, --, --, --,
   {{0xdb18000d,0x3866017a,0x1db70980,0xdcfb00d8}},	//   rová, _bror_, _अदित, _kouč,
   {{0xdb1800b6,0x7bc36490,0x7d1900f9,0xf7710397}},	//   sová, ponu, maws, ماد_,
   {{0x68fb6491,0xdb1800b6,0xdcfb02c6,0x7bc30abd}},	//   scud, pová, _mouč, qonu,
   {{0x6f156492,0x38666493,0xdcfb02c6,0x1bec00aa}},	//   _mezc, _eror_, _louč, _छूटल_,
   {{0x3ce904a3,0x6b816494,0x78b9023e,0x7dd80131}},	//   žavu_, _holg, _txwv, mísc,
   {{0xf7451940,0xdce902f7,0x9f4a0032,0x28f800c2}},	//   _бело, _oneč, _fibè_, _речь_,
   {{0xf7730678,0x395f6495,0xe7390497,0x63a501b9}},	//   _خاص_, ldus_, _чек_, _cmhn,
   {{0x395d022e,0x442b0527,0x6b816496,0x321e1515}},	//   _kaws_, arc_, _molg, éty_,
   {{0x395f6497,0x7d190034,0x00000000,0x00000000}},	//   ndus_, jaws, --, --,
   {{0x7f5c1f84,0xdb010018,0x645a01d3,0xdfd20568}},	// [5ee0] _parq, _emlé, ātis, مير_,
   {{0xe3b2177a,0x7f5c6498,0x395f00c2,0xdcfb0094}},	//   _درب_, _qarq, hdus_, _douč,
   {{0x11d609e5,0x7c2b0381,0x6fd002c3,0x78ad05db}},	//   _متحد, ergr, läck, _žavl,
   {{0x7bda00dd,0x7f5c008a,0x51562a84,0x427b006e}},	//   _shtu, _warq, _стоу, _נאכג,
   {{0x395f02ad,0x7f5c028d,0x6d42044c,0x67230357}},	//   ddus_, _tarq, rfoa, _odnj,
   {{0x6b816499,0x7c24015c,0x3160649a,0x8f76004d}},	//   _colg, širo, ldiz_, _сумі,
   {{0x6b81649b,0x2d9c0257,0x26110087,0x3d0b0096}},	//   _dolg, èves_, jšo_, ारखे_,
   {{0x3160649c,0x395d649d,0x7d0d0088,0x7524649e}},	//   ndiz_, _caws_, ðast, _ndiz,
   {{0x6b81649f,0x395d01bb,0xa3c4000d,0x5b3606f6}},	//   _folg, _daws_, एका_, _معار,
   {{0x75240062,0x973c1197,0x3dc60188,0x7bdd0036}},	//   _adiz, mićk, loow_, _èsup,
   {{0x9f4a00e3,0xd6d008ba,0x35b51087,0x973c031a}},	//   _cibé_, تقد_, ибор, lićk,
   {{0x38660d3e,0xd6d7055b,0x386000cc,0x6d460212}},	//   _tror_, ыты_, _širu_, _ökad,
   {{0x98a30562,0xe4a70097,0x5eab0081,0x442005db}},	//   _лице, урно, _করছে, _cvi_,
   {{0x752464a0,0x4420013f,0x395d022e,0x7d190034}},	//   _ediz, _dvi_, _zaws_, zaws,
   {{0xdcfb000d,0x442064a1,0x395d023e,0x79820188}},	//   _souč, _evi_, _yaws_, _koow,
   {{0x6fd00e74,0x395d022e,0x398a0139,0x48db030b}},	//   läch, _xaws_, _bùsi_, खेको_,
   {{0x0f150686,0x3dc6008c,0x69dc023a,0x00000000}},	// [5ef0] имаю, doow_, _पठनी, --,
   {{0x6fd001bf,0x644d0eac,0x973c00e7,0x7d190124}},	//   näch, _ipai, dićk, waws,
   {{0x644e0087,0xe0df0032,0x6b8101cb,0x98af0090}},	//   čniš, _gbòn_, _rolg, _tagħ_,
   {{0x6b810856,0x79820172,0x7d0e00fe,0x442064a2}},	//   _solg, _noow, _đbsc, _yvi_,
   {{0xf41f02fd,0x395d01bb,0x6b810018,0x7d1964a3}},	//   nsä_, _raws_, _polg, raws,
   {{0x200903b4,0x395d64a4,0x6a850450,0x7d190270}},	//   mpai_, _saws_, илла, saws,
   {{0x6b8113f4,0x395d37fe,0x6fd0042c,0xbb1801c3}},	//   _volg, _paws_, däch, ازها_,
   {{0xaca30294,0x395d0b06,0xdce902a1,0x2ba609c4}},	//   _agụn, _qaws_, _eleġ, कोबा,
   {{0x3f830106,0x5d840b05,0x395f64a5,0x644d26a6}},	//   _koju_, _القل, rdus_, _npai,
   {{0x442002ef,0x395f2375,0x07a54ce6,0x61ef00b3}},	//   _rvi_, sdus_, раон, _licl,
   {{0x442003ce,0x3f8345ca,0x395d0197,0x2d8500fd}},	//   _svi_, _moju_, _taws_, _îles_,
   {{0x61ef64a6,0x629c02dd,0x8afc00a5,0x657d023b}},	//   _nicl, vzro, _wnęt, gjsh,
   {{0x6d490080,0x290d0010,0xdff100c3,0xdb03392c}},	//   _mbea, mbea_, _अंगद_, minâ,
   {{0x66e518e4,0x6fd00222,0x61ef15d8,0x44200172}},	//   _кола, räck, _aicl, _vvi_,
   {{0x629c0ca7,0x644d0a00,0xf53f052f,0xb6a200d3}},	//   uzro, _epai, rnår_, _мишл,
   {{0xd1325c4d,0x6026004d,0x6fd01489,0x6fba2647}},	//   تمر_, идба, päck, ्वभू,
   {{0x3f830995,0x2087004d,0xcef60b1b,0xf53f0572}},	// [5f00] _boju_, айти_, ачењ, pnår_,
   {{0x6d49002b,0x973c042d,0xdb030fd9,0x61ef01b9}},	//   _abea, vićk, finí, _eicl,
   {{0xed5a02ec,0xee3a64a7,0x76415fb9,0x6d4901b9}},	//   кож_, тне_, ntly, _bbea,
   {{0x6d49009c,0x973c037d,0x61ef014b,0x39980139}},	//   _cbea, tićk, _gicl, _kése_,
   {{0x61e464a8,0x6d4901b9,0x3f830af0,0xdb030131}},	//   mmil, _dbea, _foju_, dinâ,
   {{0x61e464a9,0x973c00c4,0xca260161,0xa49b00b3}},	//   lmil, rićk, афии, mbòt,
   {{0x34d309c4,0x973c00c4,0x39980139,0xdce900bd}},	//   _सर्द, sićk, _lése_, _vleġ,
   {{0x61e464aa,0x39910065,0xdd920397,0x6fd00364}},	//   nmil, _dáso_, _بور_, wäch,
   {{0x973c0477,0x61e4003e,0x7dd8002b,0x7d0d0072}},	//   lići, imil, císa, ñase,
   {{0x2d8464ab,0xe6660077,0x798206b0,0x61e464ac}},	//   _home_, атмо, _woow, hmil,
   {{0x2d84530e,0x61e464ad,0x7982250c,0x6fd001bf}},	//   _kome_, kmil, _toow, räch,
   {{0x61e408a9,0x7c2d1197,0x6fd00364,0x20090085}},	//   jmil, šare, säch, ypai_,
   {{0x94a864ae,0x2d840106,0x61ef0036,0xb447013f}},	//   атра_, _mome_, _ricl, шэнк,
   {{0x2d84031a,0x24840149,0xa5c7003e,0x973c015c}},	//   _lome_, ämma_, _blóð, kići,
   {{0xf41f4043,0xf1a700c5,0x973c00e7,0x76410a4b}},	//   ssä_, аран, jići, ctly,
   {{0x2d8464af,0x3d1000a5,0x3f8364b0,0x973c08a9}},	//   _nome_, ारों_, _soju_, dići,
   {{0xc10400e3,0x53350e2d,0x61ef044c,0x25a964b1}},	// [5f10] توقي, _лепт, _vicl, _imal_,
   {{0x9951025b,0x68f5030b,0x973c042d,0x6e67008f}},	//   _máš_, ězdi, fići, итеж,
   {{0x2d8464b2,0x25a905db,0x973c0357,0x61ef078e}},	//   _bome_, _kmal_, gići, _ticl,
   {{0x2d8464b3,0xd2560089,0xdce90090,0xdb0a01cd}},	//   _come_, _פשרה_, _jleħ, nnfæ,
   {{0x99510074,0x2d840158,0x00000000,0x00000000}},	//   _náš_, _dome_, --, --,
   {{0x2bbb0080,0xdb0a64b4,0x973c09ac,0x09af0096}},	//   خاصة_, nifè, bići, जच्य,
   {{0xfee500c7,0x5e9500e3,0x8e855c4d,0x2d8464b5}},	//   _প্রধ, _الأط, _الزه, _fome_,
   {{0xd2b809c1,0x7dd80038,0x7e620034,0x3a290218}},	//   ילות_, písa, łopc, čap_,
   {{0xf8a900bf,0x290d2a9a,0x94100022,0x48e50033}},	//   دگاه_, rbea_, ɗaɗa_, নড্র,
   {{0x25a906e1,0x236101c2,0x99510094,0x00000000}},	//   _amal_, _nahj_, _dáš_, --,
   {{0x85ea0012,0xdb0300ee,0x61e464b6,0x00000000}},	//   лдов_, minà, ymil, --,
   {{0xceb200f5,0x76410f5a,0x25a9009c,0xdb0300ee}},	//   ליי_, rtly, _cmal_, linà,
   {{0xa5c701cd,0x764164b7,0x61e40407,0x00000000}},	//   _slóð, stly, vmil, --,
   {{0x39980072,0x799b01c2,0x69c40174,0x25a964b8}},	//   _vése_, lhuw, ịstị_, _emal_,
   {{0xe29764b9,0x412a1111,0x00000000,0x00000000}},	//   бар_, лово_, --, --,
   {{0xc24364ba,0x973c0ca7,0x61e409a1,0x00000000}},	//   янск, vići, umil, --,
   {{0xe0da64bb,0x61e464bc,0xa3ba00cd,0xdb0100da}},	// [5f20] ува_, rmil, _مادر_, _amlí,
   {{0xe47b0054,0x2d840054,0xef175566,0x973c0a9e}},	//   _עריכ, _some_, йму_, tići,
   {{0x44223502,0xc7d600a1,0xdb0305fe,0x3dcd0090}},	//   lsk_, צועי_, dinà, _bkew_,
   {{0x628e0138,0x80a600d1,0x973c0880,0x44220653}},	//   mybo, _همجن, rići, osk_,
   {{0x44224e21,0x628e64bd,0x996c00b6,0x653b00c1}},	//   nsk_, lybo, těž_, רענד,
   {{0xd00f03ef,0x442221ad,0xdb03015e,0x973c0234}},	//   _سلف_, isk_, ginà, pići,
   {{0x2d8402e6,0x628e64be,0xdb0a4b71,0x66040218}},	//   _tome_, nybo, nifé, _čiko,
   {{0xed5a02ec,0x6f1e0244,0xd90d12eb,0x799b0009}},	//   _щоб_, lapc, نیم_, ghuw,
   {{0x628e0146,0x00000000,0x00000000,0x00000000}},	//   hybo, --, --, --,
   {{0x99510871,0x7d02013d,0x628e013f,0x7c2d03d6}},	//   _váš_, lcos, kybo, šarc,
   {{0x63ae0188,0x9f94007b,0x628e00c6,0x00000000}},	//   dibn, mää_, jybo, --,
   {{0x7d0264bf,0x628e64c0,0x799b0126,0xdb1a0856}},	//   ncos, dybo, chuw, _aktø,
   {{0xdb032257,0x6f1e0018,0x9f4a00da,0x44220537}},	//   liná, kapc, _aibí_, gsk_,
   {{0x569412d3,0xa85700ca,0x63ae0141,0x9f94007b}},	//   _малт, _לידה_, gibn, nää_,
   {{0x1b1d0081,0xdb030094,0xdb0a18ae,0x78ad0206}},	//   _নামে_, niná, rifè, _ľavi,
   {{0x26dc1528,0x7c2264c1,0x78ad00c6,0x44220ac1}},	//   _izvo_, ksor, _žavi, bsk_,
   {{0x9f9400c2,0x7d020124,0x00000000,0x00000000}},	// [5f30] kää_, dcos, --, --,
   {{0x32554e08,0x1ae30081,0x7c22526d,0x9f9400c2}},	//   _двор, নুয়া, dsor, jää_,
   {{0xdb03035d,0xdfd8008f,0xaaa700bc,0x28af142e}},	//   jiná, сът_, _केंक, _जेनि,
   {{0xdb032c2d,0xfe7000e3,0x3cd52c13,0x3cf80076}},	//   diná, عدل_, ожес, معهد_,
   {{0x7c220407,0x913a00c1,0xcfc30081,0x46cf08d4}},	//   gsor, _דערק, ্গবন, _सुनह,
   {{0x7e620034,0xdb031f20,0xeb96162b,0x60dd00e8}},	//   łopa, finá, жиш_, _izsm,
   {{0xdb0364c2,0x4999413c,0xfbd00190,0x2a6c0a4b}},	//   giná, ития_, رته_, _crdb_,
   {{0xe8f94e66,0x442233cc,0x7d020a53,0xe9d90396}},	//   шли_, ysk_, ccos, јки_,
   {{0x2eb90b95,0x7c2264c3,0x6a4a00a7,0x628e007f}},	//   _आशुत, csor, _vəfa, zybo,
   {{0x6dbc0106,0x7d1b04aa,0x80c60081,0x799b64c4}},	//   nčan, _heus, লেক্, shuw,
   {{0x98b907d1,0x7d1b64c5,0xcb120327,0xdb0364c6}},	//   ısı_, _keus, _חלב_, ciná,
   {{0x3cf00251,0x44220407,0x24ea123a,0x7d1b024a}},	//   ुँचे_, tsk_, имни_, _jeus,
   {{0x442464c7,0x628e00f0,0x7d1b64c8,0x44220138}},	//   ém_, wybo, _meus, usk_,
   {{0x442200f3,0x628e013f,0x7d1b64c9,0x2b9001f7}},	//   rsk_, tybo, _leus, _càch_,
   {{0x6f1e00e7,0x5275002d,0x6d930233,0x154630c0}},	//   vapc, путу, _açam, _дейм,
   {{0x63ae64ca,0x7c24005f,0x7c224279,0x7bca4100}},	//   sibn, širi, ysor, zofu,
   {{0xef1a64cb,0xdb0300b6,0x7bca52cd,0x9f86021a}},	// [5f40] има_, ziná, yofu, огад,
   {{0xafdb05a3,0x656464cc,0x291f0ab4,0x7dec071d}},	//   _spør, _haih, haua_, _işsi,
   {{0x9f9402fd,0x7d1b01b9,0x2eee0149,0x776364cd}},	//   vää_, _beus, äff_, _manx,
   {{0xdb03025b,0x7d1b01ec,0xb6ba00ca,0x776364ce}},	//   viná, _ceus, בצעי, _lanx,
   {{0x9f940d64,0x6564363d,0x7d1b64cf,0x644653b3}},	//   tää_, _maih, _deus, ntki,
   {{0x7c2264d0,0x7d021230,0x656400c2,0xdb03045e}},	//   rsor, scos, _laih, tiná,
   {{0x7bca64d1,0x644600aa,0x9f9400c2,0xda7a036a}},	//   rofu, htki, rää_, рял_,
   {{0x6f1c0477,0x9f9402fd,0x81d800c7,0xdb031ad9}},	//   _herc, sää_, াদক_, riná,
   {{0xa3da00a5,0xb9020b3f,0x9f94032c,0x6f1c150c}},	//   ़ता_, _धर_, pää_, _kerc,
   {{0x399800bf,0xdb03291d,0x776364d2,0x7d1b64d3}},	//   _désa_, piná, _canx, _zeus,
   {{0x6f1c0b87,0x656421dc,0x4efb00c1,0x9f510154}},	//   _merc, _baih, יליג, _dizè_,
   {{0x6564009c,0x00000000,0x00000000,0x00000000}},	//   _caih, --, --, --,
   {{0x65642bb2,0xe786037e,0xf3ff016d,0x69c70096}},	//   _daih, _муко, rvão_, ावरी,
   {{0x77630428,0x8c4807e7,0x65760103,0x7dd1032e}},	//   _ganx, mağı, _enyh, låst,
   {{0x6dbc02e6,0x92681940,0x8c4803e0,0x7dec0233}},	//   včan, орта_, lağı, _eşsi,
   {{0x60f91119,0x65c404f5,0x1a9b006e,0x6b885410}},	//   сная_, _обја, בילע, _lodg,
   {{0x6f1c21fc,0x7d1b64d4,0x8c4803e0,0x2b90009c}},	// [5f50] _berc, _reus, nağı, _tàch_,
   {{0x6f1c64d5,0xdfd10080,0x7d1b64d6,0x65640063}},	//   _cerc, ريا_, _seus, _zaih,
   {{0x443964d7,0x3ea70065,0x6dbc64d8,0x2d9d0201}},	//   lus_, ànt_, rčan, thwe_,
   {{0x753d64d9,0xdce003a3,0x443964da,0xd5b900e8}},	//   ngsz, _almı, ous_, ksām_,
   {{0x6dbc0995,0x6f1c0150,0x3d0a009f,0x6ecb64db}},	//   pčan, _ferc, ाड़े_, _तुरु,
   {{0xf1bf0682,0x2d9d628a,0x291f0051,0x7d1b0239}},	//   _hjá_, shwe_, waua_, _weus,
   {{0x6fba080f,0x69c464dc,0x539c0266,0x776300b3}},	//   ्वरू, čien, שיוו, _ranx,
   {{0x776364dd,0x6dbc07c0,0xf1bd00b6,0x9f51022b}},	//   _sanx, nčal, ्किन, _sizè_,
   {{0x443964de,0xa3bd033a,0x65640918,0xa2cd0dba}},	//   jus_, ेका_, _raih, _दुस्,
   {{0x443964df,0x6d4b042c,0x656401e9,0xe7390291}},	//   dus_, lfga, _saih, љен_,
   {{0xb9010081,0x443964e0,0xf1bd1e05,0x41bd07ad}},	//   _দল_, eus_, ्कान, ्कास,
   {{0x6d5964e1,0x99510031,0x8c4807e7,0x2c5d022b}},	//   newa, _báť_, bağı, _kňd_,
   {{0x656402fd,0x8c480702,0xe72e016a,0x9f430065}},	//   _vaih, cağı, _пе_, _dijú_,
   {{0x244464e2,0x291d0051,0xf1bf026e,0x65640565}},	//   röm_, _hewa_, _ajá_, _waih,
   {{0x64460d1b,0x672100e9,0xf7701e49,0x443901b3}},	//   stki, malj, _جان_, aus_,
   {{0x6f1c64e3,0x6d590022,0xdb034638,0x28e23613}},	//   _serc, jewa, linä, _परमि,
   {{0x6f1c0a5f,0x6d5964e4,0x212031c7,0x671f000f}},	// [5f60] _perc, dewa, raih_, _मजाक_,
   {{0x80c10033,0x26010065,0x6d4b1168,0x7c390381}},	//   _শৃঙ্, _kóo_, efga, duwr,
   {{0x6d5964e5,0x21200063,0x02fb00ca,0x26270234}},	//   fewa, paih_, _ללימ, nđo_,
   {{0x7e6200a5,0x6d59342c,0x6f1c0381,0x291d06b0}},	//   łopo, gewa, _werc, _newa_,
   {{0x0b8a013d,0x6b8864e6,0x7dd82255,0x25fd0751}},	//   йски_, _podg, lísk, _रूसी_,
   {{0xa136001c,0x2c5d0154,0x00000000,0x00000000}},	//   _برگش, _dňd_, --, --,
   {{0x67215a6e,0x6d5964e7,0x9ea71d2e,0x291d08dd}},	//   dalj, bewa, _евра_, _bewa_,
   {{0x291d2bc2,0x6d5964e8,0x8c4664e9,0x8c480491}},	//   _cewa_, cewa, _небе, tağı,
   {{0x291d64ea,0xdb0a00e3,0xdca35334,0x61fe05db}},	//   _dewa_, lifí, _зати, _lupl,
   {{0x443964eb,0x9f9d0649,0x672164ec,0xdce064ed}},	//   vus_, yìí_, galj, _jamč,
   {{0x443964ee,0x3f8a019c,0xe535013f,0x9f4b028d}},	//   wus_, _mobu_, мень, _cucù_,
   {{0x7c240995,0xa2cd0f82,0xdb03016d,0x8c48020e}},	//   širu, _दुष्, tinç, pağı,
   {{0x67211e31,0xf09f0139,0xddce00e4,0x2bb6007f}},	//   balj, _afàn_, _arbū, ałce_,
   {{0xf1bf0102,0xdce000e7,0x6d590034,0x00000000}},	//   _sjá_, _namč, zewa, --,
   {{0x443964ef,0xa2cd2dfd,0x61fe64f0,0xf2c43140}},	//   sus_, _दुश्, _cupl, естн,
   {{0x61fe48c2,0xdb0a1ba6,0xdb1a047e,0x59cc2b6e}},	//   _dupl, difí, _aktü, ाविर,
   {{0xa2cd046e,0x752d02a7,0xfbdc02c6,0xf53f1842}},	// [5f70] _दुर्, _idaz, यताम, mgå_,
   {{0x442964f1,0xa85700ca,0x39b7044c,0x4fd40ed4}},	//   _iva_, הימה_, răsi_, ежут,
   {{0x44290a8d,0x3f8a025b,0xb81e00af,0xc3320089}},	//   _hva_, _dobu_, _मौसम_, _בוי_,
   {{0xdb1a4028,0x672100cc,0x442900f3,0xf53f00d6}},	//   _októ, zalj, _kva_, ngå_,
   {{0x291d64f2,0x6b65245c,0x61e1000b,0x986f0206}},	//   _rewa_, дкла, ïllu, túče_,
   {{0x291d0d17,0x6d5964f3,0x6dbc211b,0x442964f4}},	//   _sewa_, sewa, nčaj, _mva_,
   {{0x752d0ca7,0xbe880012,0xdb0a0131,0xaca30139}},	//   _odaz, _есте_, cifí, _ifọn,
   {{0x442903ce,0xdb180146,0x7d04334c,0x3f8a01d3}},	//   _ova_, mový, ñist, _zobu_,
   {{0xdb18025b,0x7c2400e3,0xf53f01c5,0xf7710dd0}},	//   lový, áirt, dgå_, ناد_,
   {{0x7c2964f5,0x386f0381,0x5fbf521f,0x00000000}},	//   _iver, _vrgr_, ्विल, --,
   {{0x442964f6,0x7c294c7e,0x672164f7,0xdb18025b}},	//   _ava_, _hver, ralj, nový,
   {{0x672104a3,0x7c2964f8,0xdb033851,0x44290668}},	//   salj, _kver, sinä, _bva_,
   {{0x61fe64f9,0x6fbf009d,0x893400e3,0xdb180146}},	//   _supl, ्वां, _أعما, hový,
   {{0x99800038,0xdb18025b,0x28e20ff9,0x61fe302f}},	//   čiť_, kový, _परति, _pupl,
   {{0xdb180146,0x386d1647,0x0eac02d5,0x7d090294}},	//   jový, lver_, _टेंड, _ofes,
   {{0x7c2964fa,0x3f8a005f,0xaca30139,0xdb180579}},	//   _over, _sobu_, _afọn, dový,
   {{0x442964fb,0x1f66141b,0xd5490037,0x386d64fc}},	// [5f80] _gva_, мкам, _رجيم_, nver_,
   {{0x7d090139,0x61fe00c2,0x386d1a7a,0xdb0a45f8}},	//   _afes, _tupl, iver_, tifí,
   {{0xdfcf054f,0x7c2929b0,0x386d0856,0x28af0557}},	//   جيل_, _aver, hver_, _जेसि,
   {{0x7c29042c,0x798b64fd,0x00000000,0x00000000}},	//   _bver, _nogw, --, --,
   {{0xa3e306ed,0x419700cd,0x386d0126,0xdb0a002b}},	//   _फीड_, _آشپز, jver_, sifí,
   {{0x7c290181,0x7d0964fe,0xdb18033d,0x64560079}},	//   _dver, _efes, bový, _mpyi,
   {{0x7c290054,0x394d5b0a,0xdb180094,0x7d0900f0}},	//   _ever, ffes_, cový, _ffes,
   {{0xd91a004d,0x394200aa,0x9abc0078,0xdce20206}},	//   цьк_, üks_, _neċe, mkoľ,
   {{0x660d19be,0x7c29003d,0x6dbc0220,0x798b01c2}},	//   _čaka, _gver, yčaj, _dogw,
   {{0x7dd8305b,0x44290fcf,0x00000000,0x00000000}},	//   dísi, _rva_, --, --,
   {{0x7c290181,0x386900e7,0x2b140403,0x56940077}},	//   _zver, _šart_, _न्यु_, хант,
   {{0x5693249c,0x9f9f029a,0x7c290519,0x798b00eb}},	//   тают, _véél_, _yver, _gogw,
   {{0x2edb05d4,0xf8e20782,0xdb180146,0xf53f057e}},	//   _भर्त, _परिय, zový, rgå_,
   {{0x237a001f,0x69c2066a,0x4429010a,0x75fe00e8}},	//   _cnpj_, _hjoe, _vva_, _līzi,
   {{0xe2f80565,0xdce20031,0x00000000,0x00000000}},	//   дері_, jkoľ, --, --,
   {{0x442964ff,0xd5b80450,0x2b491197,0xdb180146}},	//   _tva_, _осы_, đaci_, vový,
   {{0x44296500,0x2d860113,0x00000000,0x00000000}},	// [5f90] _uva_, djoe_, --, --,
   {{0xdb180074,0x7c2943fc,0x9c130174,0x00000000}},	//   tový, _rver, lọgw, --,
   {{0x7c290572,0x63b50087,0xdde200c4,0x00000000}},	//   _sver, mizn, _šušu, --,
   {{0xdb18025b,0x68e26501,0x386d0d00,0x63b56502}},	//   rový, _ozod, yver_, lizn,
   {{0x61ed6503,0x80270f43,0xdb180146,0x62950094}},	//   mmal, _ترجم, sový, lyzo,
   {{0x61ed6504,0xdb180094,0xa3df2397,0x69c20131}},	//   lmal, pový, तति_, _ajoe,
   {{0xd90f0688,0x61ed6505,0x68e2063d,0xa3c009a1}},	//   لیا_, omal, _azod, ंचत_,
   {{0x9f590618,0x61ed6506,0xa2d60b89,0x7c296507}},	//   _musí_, nmal, _मुफ्, _tver,
   {{0x386d04ea,0x7c296508,0xa2d62a24,0xa3df178c}},	//   uver_, _uver, _मुन्, तता_,
   {{0x7dd8003e,0x61ed6509,0xbf1d1c05,0x63b52281}},	//   vísi, hmal, _फ़ोन_, jizn,
   {{0x7d043723,0xc7a80037,0x386d650a,0x81d60033}},	//   žise, بديل_, sver_, িগত_,
   {{0xb8e50f71,0x7dd81de7,0x39912159,0x6dbc0234}},	//   _এর_, tísi, _pásu_, včak,
   {{0x61ed01d3,0x00000000,0x00000000,0x00000000}},	//   dmal, --, --, --,
   {{0x69db023b,0x7dd8650b,0xf745001f,0x61ed650c}},	//   llue, rísi, _чеко, emal,
   {{0x2176650d,0x7dd80328,0x9f5102c6,0x0cdc1f88}},	//   нуар, sísi, _cizí_, _बर्म,
   {{0x61ed650e,0x600a1510,0x7dd8034f,0x6b53047e}},	//   gmal, знам_, písi, lıgı,
   {{0x3fe64a4a,0x63b5650f,0x69db6510,0xd05401c2}},	// [5fa0] ежав, bizn, ilue, _ɗaɗa,
   {{0x63b5042d,0x2d9f0084,0x61ed5e37,0x69db02db}},	//   cizn, _alue_, amal, hlue,
   {{0x2d9f6511,0xdee600c2,0x00000000,0x00000000}},	//   _blue_, хожи, --, --,
   {{0x61bd1fb4,0xd2b70266,0xbd67004d,0x6da3007e}},	//   ्कृष, _טלית_, ерше_, лиха,
   {{0x200400d3,0x00000000,0x00000000,0x00000000}},	//   _îmi_, --, --, --,
   {{0x9f5801e5,0xaa6659bc,0x69c26512,0xa3c01101}},	//   _mirë_, етик, _sjoe, ंचि_,
   {{0xdee31456,0x9f58023b,0xa2d60abe,0x69db6513}},	//   _бори, _lirë_, _मुम्, flue,
   {{0x20026514,0x68e20090,0x2d9f0158,0x00000000}},	//   _kuki_, _pzod, _glue_, --,
   {{0xa3c002e8,0x6da35c24,0x75260634,0x6bda01f9}},	//   ंचा_, _сита, dakz, _فورس_,
   {{0x27f805be,0x999f00d9,0xc6a6002d,0x61ed071d}},	//   örn_, ārši_, ерми, zmal,
   {{0x61ed6515,0x63b52029,0x20026516,0x69c20abf}},	//   ymal, vizn, _luki_, _tjoe,
   {{0x6d420a00,0x69db6517,0x7cf60233,0x61ed013c}},	//   ngoa, clue, _gürü, xmal,
   {{0x200200e7,0x19b7006e,0x58930281,0x9c130134}},	//   _nuki_, _אפאר_, _مجوز, rọgw,
   {{0x27e7009c,0x39ac02c6,0xb36400e5,0x25a0058f}},	//   _ghnn_, věsy_, лъск, _elil_,
   {{0x7cf603a3,0x6673012b,0x20026518,0x00000000}},	//   _yürü, _مدير, _auki_, --,
   {{0x26db040a,0x20026519,0x2509001c,0x69c03200}},	//   _מקומ, _buki_, _غربی_, nnme,
   {{0x69c0651a,0x40341f46,0x00000000,0x00000000}},	// [5fb0] inme, летс, --, --,
   {{0x200f0029,0x2002007e,0xdb0300e1,0x25a005db}},	//   īgi_, _duki_, sinú, _zlil_,
   {{0x4fc40459,0x44390154,0x39460042,0x61ed0367}},	//   уста, lrs_, _ocos_, pmal,
   {{0xdce00a84,0x442b651b,0x200203e3,0x386600b3}},	//   _samā, osc_, _fuki_, _osor_,
   {{0xc8af0285,0xdce000e8,0x00000000,0x00000000}},	//   _जेंट, _pamā, --, --,
   {{0x7cf608bb,0x6d4201e9,0x4439651c,0x442b0076}},	//   _sürü, agoa, irs_, isc_,
   {{0x660d651d,0xdb0a0088,0xdddc0103,0xab280cc8}},	//   _čako, kifæ, _errő, رسول_,
   {{0xa3e30251,0x44392f54,0x69c000d7,0x00000000}},	//   _फीस_, krs_, gnme, --,
   {{0x442b0034,0x4439651e,0xdce00a84,0x00000000}},	//   jsc_, jrs_, _tamā, --,
   {{0x8aa758a7,0x93e00251,0x394604c3,0x7c2b4a77}},	//   _пред, _खींच_, _ecos_, msgr,
   {{0x44393e29,0xe5a62549,0x442b00d3,0x9f580154}},	//   ers_, вини, esc_, _dirè_,
   {{0x9f580216,0x394600da,0x00000000,0x00000000}},	//   _pirë_, _gcos_, --, --,
   {{0x7c2b651f,0x5fd108c0,0x7dd802c6,0x6fd10096}},	//   nsgr, तकाल, míst, तकां,
   {{0x33d5013a,0x395f6520,0x6a4a0092,0x7526007e}},	//   гіст, leus_, _səfi, sakz,
   {{0x25e305d4,0x442b0037,0x799b0051,0x9f430072}},	//   _टीवी_, asc_, okuw, _lijó_,
   {{0x7dd86521,0x20026522,0x25a009a4,0x395f6523}},	//   níst, _puki_, _ulil_, neus_,
   {{0x66036524,0xf5930037,0x78a90381,0x00040103}},	// [5fc0] _hunk, _خليج, nzev, اثری,
   {{0x44200139,0x66036525,0x67230194,0x752401bf}},	//   _iwi_, _kunk, _jenj, _heiz,
   {{0x67231268,0x75246526,0x44200085,0x395f00c2}},	//   _menj, _keiz, _hwi_, keus_,
   {{0x66033b69,0x442056d7,0xdd9900f3,0x67236527}},	//   _munk, _kwi_, нші_, _lenj,
   {{0x395f6528,0x7dd86529,0xcfaa0f43,0x6d42652a}},	//   deus_, díst, _قاسم_, rgoa,
   {{0x394600d3,0x9f430139,0xdb010031,0x75240634}},	//   _scos_, _dijó_, _zmlú, _leiz,
   {{0x6603652b,0x395f00ee,0x26060096,0x442005aa}},	//   _nunk, feus_, _संधी_, _lwi_,
   {{0x75240877,0x7dd8652c,0x2d9c00d9,0x799b06a8}},	//   _neiz, gíst, īves_, gkuw,
   {{0xf1b309c1,0x4420652d,0x69c0652e,0x6603034f}},	//   יסה_, _nwi_, rnme, _aunk,
   {{0x6603652f,0x99890128,0xdb1a5fb7,0x67236530}},	//   _bunk, čaš_, _aktö, _cenj,
   {{0xa3d6147f,0x659500d3,0xd5b901d3,0x44390150}},	//   िकन_, гану, ksāt_, wrs_,
   {{0x66036531,0x443900d9,0x9f586532,0x44206533}},	//   _dunk, trs_, _diré_, _bwi_,
   {{0x443910af,0x3866002d,0x442d025a,0x9f58002b}},	//   urs_, _usor_, ée_, _eiré_,
   {{0x442002ad,0x61bd0473,0x67236534,0x316b6535}},	//   _dwi_, ्क्ष, _genj, _sacz_,
   {{0x66030d27,0x752401c2,0x7dd82f0b,0xf7720018}},	//   _gunk, _feiz, níss, _ماں_,
   {{0x7c2d6536,0x44396537,0x7c2b00f0,0x7524042c}},	//   šari, prs_, ysgr, _geiz,
   {{0x660301c2,0x225a0062,0x107504d9,0x260600c3}},	// [5fd0] _zunk, _eppk_, ылаю, _सूती_,
   {{0x2d5302b4,0x67286538,0x6603006d,0xcebb0291}},	//   _ṣe_, nadj, _yunk, мље_,
   {{0xdfd8013d,0x7c2b6539,0x656d293a,0x44200415}},	//   тът_, wsgr, _kaah, _zwi_,
   {{0xf6530341,0x7dd8653a,0x672833ef,0x7c2b19ce}},	//   יצע_, xíst, hadj, tsgr,
   {{0x656d653b,0x21291bd6,0x395f00ee,0x40842105}},	//   _maah, maah_, veus_, _курб,
   {{0xdd0306d7,0x2129653c,0x656d008a,0x7c2b611f}},	//   ırıl, laah_, _laah, rsgr,
   {{0x61fd653d,0x6723003d,0x395f653e,0xba520037}},	//   _kisl, _renj, teus_, منوع,
   {{0x6723048e,0x6603653f,0x21291470,0x61fd6540}},	//   _senj, _runk, naah_, _jisl,
   {{0x75246541,0x6723117e,0x66036542,0x644d0197}},	//   _reiz, _penj, _sunk, _nqai,
   {{0x66036543,0x67286544,0x21296545,0x395f6546}},	//   _punk, gadj, haah_, seus_,
   {{0x656d0694,0x4420022b,0x395f6547,0x67236548}},	//   _baah, _swi_, peus_, _venj,
   {{0x8aa40002,0x2d9d003d,0xe81e0abe,0x44206549}},	//   _труд, nkwe_, _मौका_, _pwi_,
   {{0x69d90129,0x656d008a,0xa3c00006,0x2129061d}},	//   _ikwe, _daah, ंचल_, daah_,
   {{0x61fd654a,0x6603654b,0x290d00d3,0x9f58654c}},	//   _aisl, _tunk, lcea_, _tiré_,
   {{0x442022d4,0x61fd654d,0x656d0188,0xdb030037}},	//   _wwi_, _bisl, _faah, ghné,
   {{0x2fd8063f,0x290d00d3,0x7641654e,0xd2e42ebd}},	//   _skrg_, ncea_, muly, _गरीब_,
   {{0x316000d9,0x6a4a0092,0x44200bb6,0x3f910063}},	// [5fe0] reiz_, _həft, _uwi_, _bozu_,
   {{0x6d490a29,0x61fd654f,0x33664064,0xa3df0b42}},	//   _acea, _eisl, _свог, ततः_,
   {{0x69d96550,0x527659b2,0x3f9161da,0x656d0051}},	//   _okwe, _супу, _dozu_, _yaah,
   {{0x6dbc0146,0x69d95080,0x7dd81f4a,0x5bdc00a4}},	//   jčat, _nkwe, víss, यत्व,
   {{0xa3ab00aa,0x00000000,0x00000000,0x00000000}},	//   _खतम_, --, --, --,
   {{0x76416551,0x437600c1,0x0a6a3e0c,0x09cc052c}},	//   kuly, רײַן_, ерии_, ाव्य,
   {{0xad5a6552,0x00000000,0x00000000,0x00000000}},	//   _прах_, --, --, --,
   {{0x38341f37,0x7bc36553,0x6d490080,0x7dd81f32}},	//   анир, annu, _gcea, ríss,
   {{0xfce32c22,0x656d007b,0xf0b7006e,0x62830231}},	//   _гото, _raah, ָליר_, _ànov,
   {{0x69d906c0,0x385700e3,0x656d6554,0x3cf10206}},	//   _ekwe, اشيد_, _saah, ňovú_,
   {{0x67284f61,0x76416555,0x7fd700c1,0xd6da00ae}},	//   radj, guly, רויס_, эти_,
   {{0xceb300a1,0x67280a39,0x290d3c59,0xdb01020d}},	//   מית_, sadj, ccea_, _allè,
   {{0x58961b49,0xa3c0009d,0xdb18016d,0x656f240a}},	//   _حجاز, ंचं_, vivê, rdch,
   {{0x656d6556,0x60dd02ac,0x76416557,0x00000000}},	//   _waah, _rysm, buly, --,
   {{0x61fd6558,0x212911a6,0x6dbc6559,0x3f910357}},	//   _pisl, taah_, nčas, _rozu_,
   {{0xb11512d1,0x80d30081,0xdb030146,0x00000000}},	//   рмаш, _দৃষ্, diný, --,
   {{0x60f92787,0x7bda0d3d,0x61fd655a,0x644d061d}},	// [5ff0] тная_, _oktu, _visl, _uqai,
   {{0xb4c3277c,0x6d493a38,0x9f410037,0x60dd0094}},	//   ्थी_, _scea, lmhú_, _vysm,
   {{0x6dbc025b,0x62670604,0x61fd655b,0x3f911a36}},	//   jčas, _صادق, _tisl, _vozu_,
   {{0x7bda655c,0x61fd0010,0x6dbc2449,0x531412eb}},	//   _aktu, _uisl, dčas, _پذیر,
   {{0x6dbc035d,0x8b251612,0x7a1101d3,0x3f91020e}},	//   včat, адле, _māte, _tozu_,
   {{0x0ed0009d,0x69d9655d,0xe0df0af0,0x00000000}},	//   _तुकड, _skwe, _iyò_, --,
   {{0xa3d6007d,0x98bf0b14,0x00000000,0x00000000}},	//   िकत_, rguč_, --, --,
   {{0x6283020d,0x7a0a007f,0x00000000,0x00000000}},	//   _ànou, _tętn, --, --,
   {{0x0cd900cd,0xf09200c1,0x290d00d3,0x6dbc16aa}},	//   _شارژ_, ַנט_, rcea_, rčat,
   {{0x7641655e,0xed590234,0xe1ff015e,0x22a0007b}},	//   tuly, _hbž_, _lió_, näkö_,
   {{0x6dbc03d6,0xdb1801cd,0x00000000,0x00000000}},	//   mčar, fnvæ, --, --,
   {{0x58d50465,0x69d9655f,0x2875055b,0x764120a8}},	//   _коет, _ukwe, _выкр, ruly,
   {{0xdd140220,0xdb010257,0x76416560,0x00000000}},	//   núši, _allé, suly, --,
   {{0x6dbc28fc,0x764100a7,0x98a24a09,0xa6950284}},	//   nčar, puly, _фише, _вриј,
   {{0xa2d605d4,0x412a6561,0xe0df026e,0x41b610a6}},	//   _मुश्, ково_, _ayò_, асат,
   {{0xe1ff00ee,0xdb180052,0x2b4901c2,0x00000000}},	//   _ció_, tivë, ɗace_, --,

   {{0x21674064,0x02db097c,0xd0070c59,0x2fda00d1}},	// [6000] шити_, _मुठभ, иете_, نورد_,
   {{0xef175912,0x2d8001d3,0x2b990113,0x00000000}},	//   иму_, ķiem_, _kècu_, --,
   {{0x63bc02e6,0xe8e20557,0x433b0089,0x9e6640c9}},	//   mirn, _पर्च, _בעיב, рвед,
   {{0xe1ff0019,0x6b810154,0x63bc6562,0x50466563}},	//   _gió_, _anlg, lirn, _кемб,
   {{0x2ca0054f,0x629c01b9,0x7d0401d3,0xdb186564}},	//   áid_, lyro, žiso, livé,
   {{0x63bc36d6,0x3998003e,0xc47700d7,0x00000000}},	//   nirn, _lést_, יתנו_, --,
   {{0x2ca002ef,0x6283020d,0xdb180094,0xa49b00ee}},	//   šid_, _ànot, nivé, ncòr,
   {{0x63bc06ee,0x7c6609e5,0x99d300e3,0x290200f3}},	//   hirn, _پارل, يتيا, øka_,
   {{0xbee602e8,0x63bc6565,0x629c08b2,0xdca32b49}},	//   _करुन_, kirn, hyro, _дати,
   {{0x473408d8,0x7bc800e7,0xb8ee0096,0x6dbc0995}},	//   щнос, _ujdu, _रश_, pčas,
   {{0xc98618be,0xa2d60179,0x7bd86566,0xeb970291}},	//   _вули, _मुल्, movu, _њих_,
   {{0x998008a1,0x2a6c03a9,0x7bd86567,0x5bb66568}},	//   čių_, _isdb_, lovu, _अगुव,
   {{0xb4c300b6,0xe1ff037a,0xdb032bb5,0xf1650174}},	//   ्थे_, _rió_, cinó, shị̀_,
   {{0xbee602e8,0x7bd86569,0x99890220,0x63bc01ab}},	//   _करून_, novu, čať_, girn,
   {{0x798200a1,0xe5c700c2,0xa3f4004b,0x63a500d8}},	//   _know, _вспо, іпсі, _vlhn,
   {{0x7bd8656a,0x200f016d,0x66154df5,0x3d0d0032}},	//   hovu, ígio_, ízke, _mówó_,
   {{0x63bc656b,0x644005fe,0x20980ab3,0x88d80081}},	// [6010] birn, àmit, акты_, দেরক,
   {{0x63bc52fa,0x9f580139,0xed5900c4,0xdb180e4b}},	//   cirn, _firí_, _sbž_, bivé,
   {{0x27e9006d,0xdb1800c2,0x7bd8656c,0xa3bc00aa}},	//   _ɗan_, invä, dovu, _आगत_,
   {{0x3dc6656d,0x00000000,0x00000000,0x00000000}},	//   gnow_, --, --, --,
   {{0x65a60088,0x3d0f030b,0x8d7401c3,0x00000000}},	//   _jóha, ाडौं_, تالا, --,
   {{0xdcfb0995,0x3e1700cd,0xda650037,0x3d0d0139}},	//   _unuč, _نظرس, ماعي, _bówó_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63bc0559,0x26c900cc,0x2b4c3079,0x00000000}},	//   zirn, _ćao_, _ecdc_, --,
   {{0x79820124,0x629c0034,0xe8f9007b,0xb4c30b42}},	//   _dnow, zyro, ыли_, ्थो_,
   {{0x7c2d00e7,0x3d0d0032,0x3998003e,0x63bc5d82}},	//   šars, _fówó_, _sést_, xirn,
   {{0xdce008c5,0x63bc0660,0xb8fe1117,0x69c40206}},	//   _pamć, virn, _दु_, čier,
   {{0x629c16ac,0xdb0300ee,0x00000000,0x00000000}},	//   vyro, cinò, --, --,
   {{0x291f0010,0x63bc656e,0x99d402a3,0x6d5b1ced}},	//   mbua_, tirn, _بتلا, _mbua,
   {{0x629c656f,0xdb180257,0xa01b0088,0xb4e800af}},	//   tyro, tivé, _kröf, _भरी_,
   {{0xd29900d6,0x61ef02ef,0x1db70034,0x3dc6041c}},	//   атті_, _bhcl, _आगंत, ynow_,
   {{0xdb180257,0xa06a1c0f,0x63bc6570,0xa52600ae}},	//   rivé, лаба_, sirn, _умид,
   {{0x7bd86571,0x61ef009c,0x351b00ca,0x629c02c3}},	// [6020] yovu, _dhcl, _גופנ, syro,
   {{0x64466572,0x6d5b005c,0x6566332f,0x447700ca}},	//   muki, _abua, lekh, _פעיל_,
   {{0x64466573,0xe29a1f65,0x3dc602a1,0xee3a0012}},	//   luki, _сан_, tnow_, уне_,
   {{0x3f830361,0x60c900c6,0x2b4c009c,0xa3c00dc4}},	//   _enju_, _žeme, _scdc_, ंचक_,
   {{0x64466574,0x61e46575,0x98a400d9,0xa3bc00aa}},	//   nuki, mlil, kamā_, _आगा_,
   {{0x61e46576,0x2a6c016d,0x98a401d3,0x00000000}},	//   llil, _psdb_, jamā_, --,
   {{0x6e96003f,0x7bd86577,0x644660b6,0x32020449}},	//   _الزا, rovu, huki, _kiky_,
   {{0xd90e00d0,0x61e43ce7,0x64466578,0x48142d89}},	//   ریت_, nlil, kuki, омис,
   {{0xa01b01bf,0x6446083e,0x7bd8024a,0xe81100d4}},	//   _eröf, juki, povu, _píšť,
   {{0x64466579,0x61e4657a,0xc3010033,0x7ae10120}},	//   duki, hlil, ্রতি_, _fylt,
   {{0xdb180149,0x61e42b57,0x212000e7,0x994a5f34}},	//   rnvä, klil, kbih_, _ملال_,
   {{0x644663c1,0x6566657b,0x7982657c,0x758b00c2}},	//   fuki, gekh, _unow, усов_,
   {{0xe894333f,0x2ec40285,0x212000e7,0x64460c50}},	//   _фаль, वपुत, dbih_, guki,
   {{0x58f700ca,0x18370266,0x68e2657d,0xa2b700b6}},	//   _המדע_, _פאול_, _iyod, ोपल्,
   {{0xf1a728b9,0x65950219,0x212000e7,0x65660201}},	//   бран, _маку, fbih_, bekh,
   {{0x61e40256,0x6446657e,0x672a003e,0x212000e7}},	//   glil, buki, _hefj, gbih_,
   {{0x752f00a5,0x32020146,0x6446657f,0xf1942458}},	// [6030] macz, _diky_, cuki, чить,
   {{0x6d5b005c,0xb17b0149,0xdb030037,0x613f0032}},	//   _sbua, _skåd, thní, _bàlà,
   {{0x61e46580,0x9f58481d,0x212000e7,0x660a0880}},	//   blil, _dirà_, bbih_, _jufk,
   {{0x752f0067,0xcd2b00cd,0x853001c2,0x61e40113}},	//   nacz, اسان_, _koɗa, clil,
   {{0x673816a2,0x212b030a,0x7ae10073,0x660a1216}},	//   _odvj, _iech_, _sylt, _lufk,
   {{0x212b0abd,0x65663581,0x7ae10313,0xc5cf0033}},	//   _hech_, zekh, _pylt, রতিপ,
   {{0x64464041,0x68e26581,0x65666582,0x539c006e}},	//   zuki, _ayod, yekh, ריוו,
   {{0x200b04a3,0x64462cb9,0x68e20154,0x00000000}},	//   _kuci_, yuki, _byod, --,
   {{0xb4e80251,0x9f4700de,0x660a01bf,0x6d4b0124}},	//   _भरे_, _điên_, _aufk, mgga,
   {{0x25a96583,0x6d4a03a3,0x20036584,0x61e40367}},	//   _alal_, ılaş, _jiji_, zlil,
   {{0x20035fa7,0x8aa7585a,0x9f4a022b,0x673805db}},	//   _miji_, _урад, _kibò_, _ddvj,
   {{0x64466585,0x2019007a,0x212b0220,0x9f580314}},	//   tuki, _otsi_, _nech_, _mirá_,
   {{0x201901fa,0x92e60081,0x69db015e,0x32020036}},	//   _ntsi_, _ফলে_, moue, _riky_,
   {{0x64466586,0xb6a524d3,0x65660201,0x69c94902}},	//   ruki, _милл, sekh, lnee,
   {{0x752f00a5,0x69c96587,0x61e46588,0x212b6589}},	//   bacz, onee, tlil, _bech_,
   {{0x69c93ba3,0x6446658a,0xa3ba010d,0x69db51ec}},	//   nnee, puki, _چادر_, noue,
   {{0x2003048e,0x200b063f,0x212b1bd2,0x69c9658b}},	// [6040] _biji_, _cuci_, _dech_, inee,
   {{0x200308a9,0x2120658c,0x69c957f2,0x200b658d}},	//   _ciji_, sbih_, hnee, _duci_,
   {{0x201900c2,0x2003022b,0x212002ef,0x6604658e}},	//   _etsi_, _diji_, pbih_, _kiik,
   {{0xed5a0dc0,0x69c9023e,0xec7a3b9d,0xa01b0149}},	//   род_, jnee, ипе_, _bröd,
   {{0x0b8a0163,0x200b658f,0xb4e80285,0x9f5800b3}},	//   иски_, _guci_, _भरो_, _tirà_,
   {{0x660413e3,0xdce0030b,0x20036590,0xf7670d5b}},	//   _liik, _zamě, _giji_, _غا_,
   {{0xada600c2,0x6da60fbe,0x7a110a84,0x200b6591}},	//   _давл, _дива, _pāta, _zuci_,
   {{0x8c461773,0xa9c300d6,0x69c96592,0x69db014b}},	//   _мебе, дськ, gnee, goue,
   {{0x80dc00c7,0x180400aa,0x995800b6,0x386f0027}},	//   _মৃত্, रदेव_, _též_, _csgr_,
   {{0x69c9008c,0x752f0034,0x81d00033,0x7a30033c}},	//   anee, wacz, ষতি_, _cótá,
   {{0x3f98084f,0xf09f6593,0x7a1101d3,0x69c9006c}},	//   _moru_, _ngàn_, _tāta, bnee,
   {{0x69c9008c,0x69db014b,0x3f986594,0x00000000}},	//   cnee, coue, _loru_, --,
   {{0xf76f00bf,0x6604005a,0x69c00084,0x212b6595}},	//   رای_, _diik, mime, _rech_,
   {{0x212b0113,0xfbbc20cd,0x200b005f,0x67ef052f}},	//   _sech_, ्चिम, _ruci_, tøje,
   {{0x200b0484,0x6d4b0160,0xdce0030b,0x212b04aa}},	//   _suci_, ygga, _pamě, _pech_,
   {{0x3015002e,0xdb186596,0x200300bf,0x66046597}},	//   здар, diví, _siji_, _giik,
   {{0x9abc03e5,0x3f986598,0x6ab802d5,0xd2db009f}},	// [6050] _deċi, _boru_, ेपुर, _मुरझ,
   {{0xa2d60861,0x4429026e,0x212b02db,0xa3d62647}},	//   _मुक्, _iwa_, _wech_, िकः_,
   {{0x752d4218,0x69c06599,0x69c9659a,0x212b1ef7}},	//   _keaz, kime, ynee, _tech_,
   {{0x4429659b,0x69c0659c,0x9f580558,0xdd910103}},	//   _kwa_, jime, _virá_, رڈز_,
   {{0x69c9006c,0x442905aa,0x3f980a00,0x0c2400d6}},	//   vnee, _jwa_, _foru_, дмін,
   {{0x4429659d,0xb09a00a1,0x3f980335,0xeb9628b9}},	//   _mwa_, _הישר, _goru_, зиш_,
   {{0x69c0659e,0x4429659f,0x69c91044,0x260600c3}},	//   fime, _lwa_, tnee, _संगी_,
   {{0x442965a0,0xa2ce0be4,0xdb030076,0x69c0202c}},	//   _owa_, _सशस्, ghná, gime,
   {{0x442965a1,0x69c919fb,0x6604007a,0xa3db0251}},	//   _nwa_, rnee, _riik, ़वा_,
   {{0x69c965a2,0x7c2965a3,0xb1130174,0x9c130294}},	//   snee, _iwer, _tụwa, họkw,
   {{0x69c065a4,0x672118b4,0x7a300037,0x66040302}},	//   bime, rblj, _vótá, _piik,
   {{0x69c065a5,0x7c2965a6,0x442965a7,0xf09f00de}},	//   cime, _kwer, _bwa_, _ngào_,
   {{0x660402fd,0x442965a8,0xb88601cd,0x316901c8}},	//   _viik, _cwa_, rtíð, deaz_,
   {{0x442965a9,0xf7711e56,0x394d14e3,0xaca365aa}},	//   _dwa_, _سات_, lges_, _ngọn,
   {{0xa2d60961,0x442965ab,0x386d17a7,0x66e20291}},	//   _मुख्, _ewa_, lwer_, _поша,
   {{0x7d09067d,0x44290c56,0xaca30174,0x3f9801e8}},	//   _nges, _fwa_, _agọn, _soru_,
   {{0x7c290857,0x6ed40251,0xb9280294,0x44291cc7}},	// [6060] _nwer, _बुजु, _agwụ_, _gwa_,
   {{0x7d09104d,0xe4570130,0x69c065ac,0xdb1865ad}},	//   _ages, _צייט_, zime, tiví,
   {{0xdfcf0080,0x3f980102,0x386d01bf,0x44290154}},	//   ديل_, _voru_, hwer_, _zwa_,
   {{0x248005aa,0x7c2965ae,0x69c065af,0x21020138}},	//   _krim_, _bwer, xime, _ačiū_,
   {{0x657665b0,0xdca30c58,0x3f9865b1,0x394d65b2}},	//   _mayh, наци, _toru_, dges_,
   {{0x7fd6116d,0x7c291030,0xdbd60139,0x98a400c6}},	//   _хімі, _dwer, _bùáy, namą_,
   {{0x69c065b3,0x7c290129,0x89d808ba,0xaca40032}},	//   time, _ewer, يوتر_, _iwọp,
   {{0x394d0400,0x29f70134,0xed5701a0,0x386d0063}},	//   gges_, _ṅara_, _нос_, fwer_,
   {{0x752d162d,0x7c2965b4,0x8c432c22,0xc0b600fe}},	//   _reaz, _gwer, _пете, _rưỡi_,
   {{0x4429023f,0x764820c1,0xb1130174,0x2c5e00d9}},	//   _rwa_, tudy, _hụta, rādā_,
   {{0x45d50303,0x442906a3,0x6b8801c5,0xd7f800d3}},	//   донс, _swa_, _indg, rmă_,
   {{0x442902f1,0x6b9a0023,0x248065b5,0x7c290f5a}},	//   _pwa_, _hotg, _brim_, _ywer,
   {{0x24800428,0xb1130294,0xd7fa01a0,0xdb010072}},	//   _crim_, _mụta, _лук_, _illá,
   {{0x083b0054,0x75ff0029,0xb4bd1376,0x442906a3}},	//   _פעול, _mūzi, _आधी_, _vwa_,
   {{0xdb0a65b6,0xcfc40081,0xd6cf2917,0x316901e9}},	//   lifó, ্তান, _чт_, teaz_,
   {{0x442965b7,0x2480061d,0x2ba900c3,0x6b9a0629}},	//   _twa_, _frim_, _कत्थ, _lotg,
   {{0x442965b8,0x248065b9,0x9c130294,0x31690bd2}},	// [6070] _uwa_, _grim_, rọkw, reaz_,
   {{0xdefb00c2,0x7c2905bd,0xedc509a1,0x06fd02c6}},	//   бые_, _rwer, लच्छ, čívá_,
   {{0x7c2965ba,0xdb010042,0x3ea706f0,0xa3ca0285}},	//   _swer, _ollá, ánt_, लचर_,
   {{0x23490470,0x386d0313,0x7c2965bb,0x00000000}},	//   _اسکی_, ywer_, _pwer, --,
   {{0xeb992de9,0x79990f5a,0x6b9a078e,0x00000000}},	//   жил_, _roww, _botg, --,
   {{0xbd050139,0x1af10033,0x92580103,0x00000000}},	//   _apéé, _চলবে_, _بشیر_, --,
   {{0x394d16c8,0x386d65bc,0x00000000,0x00000000}},	//   tges_, wwer_, --, --,
   {{0x394d65bd,0x7d0965be,0xcda900cd,0x7c2965bf}},	//   uges_, _uges, _بهره_, _twer,
   {{0x394d65c0,0x386d01c0,0x7aed03e3,0x6b9a2c28}},	//   rges_, uwer_, ƙato, _fotg,
   {{0x6615025b,0xdb010018,0x79990113,0xb1130294}},	//   ízko, _ellá, _woww, _zụta,
   {{0x7bc365c1,0x0f5800f5,0x386d00a1,0xc9870399}},	//   minu, ליזם_, swer_, _нуди,
   {{0x386d07ac,0x80dd00aa,0x00000000,0x00000000}},	//   pwer_, _मडूं, --, --,
   {{0xe73900c9,0xa2d60eeb,0xdb18028a,0x00000000}},	//   _дел_, _मुज्, livá, --,
   {{0x7bc365c2,0x98140037,0xf1bf0231,0x28ca2a09}},	//   ninu, _أبنا, _amá_, ापरि,
   {{0x91e602b3,0x98a400c6,0x21761c32,0x7bc30350}},	//   дове, ramą_, муар, iinu,
   {{0x7bc311b9,0x24800158,0xf8e100a4,0x00000000}},	//   hinu, _trim_, _पडाय, --,
   {{0x91e3349e,0x2480312a,0x00000000,0x00000000}},	// [6080] тоте, _urim_, --, --,
   {{0xdfcf0080,0x7bc365c3,0x249f0364,0x00000000}},	//   ليق_, jinu, äume_, --,
   {{0x7e56249c,0x7bc365c4,0xb11300ac,0xe12600d3}},	//   ьтац, dinu, _pụta, _омни,
   {{0x26130396,0x644626db,0xdb1805f1,0x00000000}},	//   _mão_, orki, divá, --,
   {{0x4ac3007d,0x3ea60029,0x26130019,0x6b9a0a88}},	//   _वेबव, ņot_, _lão_, _potg,
   {{0x6ac91677,0xbf9b00fd,0x09d60096,0xa3c001e4}},	//   िपूर, _quêt, डक्य, ूचि_,
   {{0x26134794,0xb1130174,0x00000000,0x00000000}},	//   _não_, _tụta, --, --,
   {{0xdd1d044c,0x98740c3f,0xc808020b,0x00000000}},	//   râţi, елиц, _hởi_, --,
   {{0xa3c03db8,0x7bc365c5,0xb4bd0034,0x00000000}},	//   ूचा_, binu, _आधे_, --,
   {{0x6b8801c5,0x26130019,0x2607009f,0x7bc32bd6}},	//   _undg, _bão_, _सूजी_, cinu,
   {{0x7c2265c6,0x26130161,0x644665c7,0xae0e5660}},	//   lpor, _cão_, erki, िदिन_,
   {{0x26130161,0xf64f0018,0xfaa345b1,0x00000000}},	//   _dão_, گئی_, _шахо, --,
   {{0x7c2265c8,0x79fb00ca,0xe4e4004d,0x644065c9}},	//   npor, _ולאח, вірн, šmin,
   {{0xf1bf0088,0x29020138,0x1af10033,0xae0e0bf5}},	//   _smá_, žkas_, _চলতে_, िदान_,
   {{0xa27844b2,0x644665ca,0xdd140206,0xdce20233}},	//   мбру_, arki, dĺži, ydoğ,
   {{0x26070851,0x250900d0,0x7bc365cb,0x06fd02c6}},	//   _सूची_, _عربی_, zinu, čítá_,
   {{0x7bc365cc,0x765a00ce,0x00000000,0x00000000}},	// [6090] yinu, ltty, --, --,
   {{0x7c22134c,0xc80800ef,0x645a020a,0x443965cd}},	//   dpor, _bởi_, ătit, mss_,
   {{0x2bdd05a5,0xc80800de,0x443965ce,0x00000000}},	//   यवसा, _cởi_, lss_, --,
   {{0x44390113,0x38660062,0x7c22084e,0x7bc30027}},	//   oss_, _opor_, fpor, winu,
   {{0x7c2265cf,0x628a65d0,0x443965d1,0xa3b6030b}},	//   gpor, _àfor, nss_, चोक_,
   {{0xdb184873,0x5ba900a8,0x25bc2172,0x00000000}},	//   tivá, कसेव, _उष्ण, --,
   {{0xc8080028,0x38660af0,0xdb1a0103,0x2ca902ef}},	//   _gởi_, _apor_, _ajtó, šad_,
   {{0x2bdd05a5,0x443900d9,0xceb2040a,0x644665d2}},	//   यवहा, kss_, _עין_, yrki,
   {{0x26130303,0x31790067,0xf771177a,0x7bc365d3}},	//   _são_, _masz_, هاد_, pinu,
   {{0x26130161,0x7c3b05bd,0x6a670076,0x765a0ac9}},	//   _pão_, _ivur, _يطال, ftty,
   {{0x65c62b19,0x443b00a7,0x75f600b6,0x60c93fa3}},	//   ебна, _avq_, háze, _žeml,
   {{0x26130396,0xb17b0fbc,0x998400e3,0x317900a5}},	//   _vão_, _skån, _للمو, _nasz_,
   {{0xa8a711a2,0x798b65d4,0xb6060139,0xf74500ae}},	//   _تصاو, _ingw, _akáá, _зело,
   {{0x26130396,0x7c3b4829,0x289a0266,0x889a00d7}},	//   _tão_, _mvur, _מינא, _מבני,
   {{0x3666013d,0x80ec0081,0x387f0088,0x63830109}},	//   _защо_, _কলেজ_, lvur_, ыгра,
   {{0x15e80f35,0x395f3f82,0x7d1b009e,0xb4db00ee}},	//   _टीचर_, nfus_, _nfus, rgàr,
   {{0xa067538c,0x6564023f,0x25d7006e,0x64a60db2}},	// [60a0] ната_, _ibih, _רופן_, _чапа,
   {{0x442065d5,0x7d1b65d6,0x7c220572,0x00000000}},	//   _iti_, _afus, vpor, --,
   {{0x44200085,0xe1f202a3,0x7c3b0079,0x818a1374}},	//   _hti_, _مسح_, _avur, _فندق_,
   {{0x7c226361,0x7bc1063d,0xd1ba01f9,0x442065d7}},	//   tpor, _amlu, _راجا_, _kti_,
   {{0x61e6003d,0x7c2265d8,0x65640079,0xf53f224d}},	//   _ikkl, upor, _mbih, dkål_,
   {{0xa01b0149,0x7c222bd4,0x798b65d9,0x442065da}},	//   _krön, rpor, _angw, _mti_,
   {{0x386606a7,0x690501d4,0x44200139,0xed6300b6}},	//   _spor_, ərdə, _lti_, íží_,
   {{0x442065db,0xdee328f1,0x443965dc,0xdbd200aa}},	//   _oti_, _соси, yss_, lüüs,
   {{0x44203bc5,0x6d400092,0xa3e010e9,0xc7c617e9}},	//   _nti_, _idma, तवा_, есни,
   {{0x31600332,0x200a65dd,0x656405bd,0x798b65de}},	//   hfiz_, _jibi_, _abih, _engw,
   {{0x442065df,0xb9070e1f,0xffb700c1,0x200a02a4}},	//   _ati_, _मु_, גליש_, _mibi_,
   {{0x7bc10181,0xf41f0149,0x798b00f9,0xd6d702e3}},	//   _zmlu, nväg_, _gngw, эты_,
   {{0x07a62ac1,0x499b00ca,0x38660117,0x938b00e5}},	//   _падн, _משאב, _upor_, псва_,
   {{0x443965e0,0x61e60090,0x27460065,0x6564083e}},	//   rss_, _akkl, _dínà_, _ebih,
   {{0x6d4002e6,0x442065e1,0xa78500cd,0x81c90081}},	//   _odma, _eti_, _جشنو, _লীগ_,
   {{0x443b023e,0x200a03e3,0xdb1801a5,0x44200653}},	//   _tvq_, _aibi_, livä, _fti_,
   {{0x656f65e2,0x62980131,0x9f6b14fb,0x00000000}},	// [60b0] mech, _àvon, зрез_, --,
   {{0xdb010084,0x6d4065e3,0x200a00e5,0x75f6030b}},	//   _yllä, _adma, _cibi_, ráze,
   {{0xa01b0222,0x645d65e4,0x200a612f,0x00000000}},	//   _grön, ltsi, _dibi_, --,
   {{0x657d65e5,0x656f65e6,0x7bc100b6,0x200a010a}},	//   ndsh, nech, _smlu, _eibi_,
   {{0x212926f7,0x645d65e7,0x6ac91efb,0x61ed65e8}},	//   mbah_, ntsi, िप्र, mlal,
   {{0x200a074e,0x61ed65e9,0x69c265ea,0xcb6602b3}},	//   _gibi_, llal, _amoe, ваше_,
   {{0x644f00e1,0x9e350243,0x656f65eb,0x645d00aa}},	//   huci, _шевч, kech, htsi,
   {{0x645d007a,0x9f4100dd,0x61ed265b,0x644f65ec}},	//   ktsi, kohë_, nlal, kuci,
   {{0x644f1197,0x645d5d91,0x61ed65ed,0x7c3b65ee}},	//   juci, jtsi, ilal, _uvur,
   {{0x61ed067d,0x81d70081,0x387f0090,0xb17b0073}},	//   hlal, িতি_, rvur_, _skål,
   {{0x656f65ef,0x628501fa,0x2129005c,0x2d9f057a}},	//   fech, _nrho, kbah_, _koue_,
   {{0x2d9f56e5,0x645d65f0,0x656f024a,0x00000000}},	//   _joue_, ftsi, gech, --,
   {{0x81d700c7,0x61ed0060,0x645d65f1,0xdbe40065}},	//   িতা_, dlal, gtsi, _béèy,
   {{0xf74506b2,0xf8b600ca,0x2d9f17f9,0x657d65f2}},	//   _реко, _בפני_, _loue_, adsh,
   {{0x645d41cb,0x39980103,0x200a65f3,0xf7700dd0}},	//   atsi, _rész_, _ribi_, _دان_,
   {{0x61ed65f4,0x200a65f5,0x656f21e1,0x44200f23}},	//   glal, _sibi_, cech, _tti_,
   {{0x442065f6,0x644f3964,0x6e3c4480,0x628501bf}},	// [60c0] _uti_, cuci, _svrb, _erho,
   {{0x61ed65f7,0xc61000bc,0x00000000,0x00000000}},	//   alal, _ठूँठ_, --, --,
   {{0x2129606c,0x25a00479,0x27e70063,0xdb181f60}},	//   bbah_, _koil_, _mknn_, nivå,
   {{0x290f0096,0x71a620e6,0x200a0113,0x00000000}},	//   _ngga_, _рамз, _wibi_, --,
   {{0x200a65f8,0x2d9f65f9,0x61e465fa,0xdb1800c2}},	//   _tibi_, _doue_, moil, yivä,
   {{0x656f0067,0x61e400c2,0x69c20629,0xdce000e8}},	//   zech, loil, _smoe, _samē,
   {{0x644f0034,0x656f65fb,0x25a0009c,0xdce000e8}},	//   zuci, yech, _ooil_, _pamē,
   {{0x68eb02ec,0x61e400c2,0x49742064,0x69340470}},	//   _bygd, noil, улис, اکار,
   {{0x656f65fc,0x645d65fd,0x6da30b9e,0xdb183851}},	//   vech, xtsi, _тита, tivä,
   {{0x656f65fe,0x25a01909,0x644f037d,0x645d023e}},	//   wech, _aoil_, vuci, vtsi,
   {{0xe53521f4,0x61e40084,0x61ed65ff,0x2baf34fd}},	//   лень, koil, ylal, जघरा,
   {{0xb5a723a3,0x68466600,0xa01b0149,0x645d00d6}},	//   трой, _анда, _bröl, ttsi,
   {{0x656f6601,0x61e46602,0x00000000,0x00000000}},	//   rech, doil, --, --,
   {{0x645d6603,0x656f6604,0xa4f30096,0x25a0009c}},	//   rtsi, sech, _घरीच_, _eoil_,
   {{0x656f6605,0x764f0067,0x21290947,0x644f02fa}},	//   pech, ącyc, tbah_, suci,
   {{0x645d1d7e,0xa01b0212,0x25a00cc2,0x81ab0033}},	//   ptsi, _fröl, _goil_, কোন_,
   {{0x61ed383f,0x2d9f00fd,0x50f518e4,0x33330231}},	// [60d0] rlal, _roue_, узат, _texx_,
   {{0x2129061d,0x660d0113,0x62851515,0x4ea73f9c}},	//   sbah_, _hiak, _trho, креа,
   {{0x660d6606,0xe45f0084,0xdbdc0088,0x2129007e}},	//   _kiak, ltö_, _ráðh, pbah_,
   {{0x61e40037,0x660d0113,0x1c3900c2,0x65a60139}},	//   coil, _jiak, езды_, _fóhu,
   {{0x660d068d,0xfeb8001c,0xef93001c,0xe45f007b}},	//   _miak, _یافت_, _پیاد, ntö_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68eb052f,0x75f60103,0xe45f007b,0x2d9f0f5a}},	//   _sygd, háza, htö_, _toue_,
   {{0x75f60074,0x16191362,0x77ad0042,0x660d1206}},	//   káza, _नंबर_, _púxo, _niak,
   {{0x76b300a7,0x25a0009c,0x00000000,0x00000000}},	//   məyə, _roil_, --, --,
   {{0xe8f600c6,0x76b30092,0x660d0b4a,0x25a06607}},	//   ылы_, ləyə, _aiak, _soil_,
   {{0x660d045d,0xadc30019,0x25a000fd,0xe5a60221}},	//   _biak, _giản, _poil_, гини,
   {{0x660d028d,0x00000000,0x00000000,0x00000000}},	//   _ciak, --, --, --,
   {{0x660d1084,0x61e46608,0xa78500b1,0x25a00231}},	//   _diak, voil, _مشغو, _voil_,
   {{0xb882033d,0x69c96609,0xdb0a09a8,0x00000000}},	//   čítk, liee, rifö, --,
   {{0xa01b0222,0x61e40084,0x61461602,0xb7da0089}},	//   _dröm, toil, лева, _אקסי,
   {{0x660d0009,0x69c91044,0xc5d60120,0x00000000}},	//   _giak, niee, _щіль, --,
   {{0xbfa30649,0x1f665566,0x78a9660a,0x61e4660b}},	// [60e0] _àwọn_, лкам, nyev, roil,
   {{0x649700ca,0xb3580018,0xb4c21f88,0x00000000}},	//   _עדיף_, _جیسا_, ्पी_, --,
   {{0xaac317ff,0x4d4a09b9,0xc8f00179,0x61e400ce}},	//   _वेलक, епен_, _चर्म_, poil,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4c940221,0x8ba600ae,0x00000000,0x00000000}},	//   рилс, лидж, --, --,
   {{0x443202e0,0xdee616e6,0xdb08002b,0xeb972bcf}},	//   _mwy_, _боги, _aldá, лич_,
   {{0x69c901d0,0x4432047c,0x2baa0d75,0x16040285}},	//   fiee, _lwy_, _कवठा, रगार_,
   {{0xdb080149,0x69c900aa,0x60c90138,0x6e2301f9}},	//   _omdö, giee, _žemi, ínbe,
   {{0x443200f0,0x00000000,0x00000000,0x00000000}},	//   _nwy_, --, --, --,
   {{0x660d0808,0x4734660c,0x75f602c6,0x8b6501f3}},	//   _siak, шнос, váza, _نامم,
   {{0x44320139,0x17f70037,0x7bca0415,0x9f5800da}},	//   _awy_, درية_, mifu, _chré_,
   {{0x7bca660d,0xe9da00d6,0x69c901c0,0xe45f0084}},	//   lifu, _яке_, ciee, ttö_,
   {{0xe97300cd,0x2bdb110d,0x00000000,0x00000000}},	//   _دهند, _बदमा, --, --,
   {{0x44320150,0x75f6660e,0xa01b02c3,0x00000000}},	//   _dwy_, ráza, _fröj, --,
   {{0x171b00c1,0xe45f0084,0x6235660f,0x753604a8}},	//   _אווע, stö_, ребу, _feyz,
   {{0x161902e8,0x443202ad,0x75f61f20,0x27fc020b}},	//   _नंतर_, _fwy_, lázn, _hhvn_,
   {{0x7bca6610,0x443200eb,0x00000000,0x00000000}},	// [60f0] kifu, _gwy_, --, --,
   {{0x7bca0010,0xd101000c,0x24896611,0x673a6612}},	//   jifu, लेषण_, _iram_, natj,
   {{0x76b30092,0x0dcb125f,0xa01b5509,0xaac33ec4}},	//   təyə, нуди_, _krök, _वेंक,
   {{0x24896613,0x673a6614,0x00000000,0x00000000}},	//   _kram_, hatj, --, --,
   {{0xa91d6615,0x657f063d,0x00000000,0x00000000}},	//   ndže, _maqh, --, --,
   {{0x7bca0a2a,0x673a0052,0x657f0372,0x00000000}},	//   gifu, jatj, _laqh, --,
   {{0x3f910193,0xa91d00e7,0x69c901cb,0x2489009c}},	//   _inzu_, hdže, tiee, _lram_,
   {{0x13d20469,0x629a00c2,0x3eae13c8,0x24890503}},	//   _सद्भ, ätoi, øfte_, _oram_,
   {{0xa91d1419,0x2489006c,0x69c96616,0x80cb0557}},	//   jdže, _nram_, riee, _सेमे,
   {{0x69c90185,0x3f8100bf,0x44320150,0x673a0103}},	//   siee, ndhu_, _rwy_, gatj,
   {{0x2c1d00c7,0x7bfa0130,0x24896617,0x69c96618}},	//   _নিয়ে_, _ספעצ, _aram_, piee,
   {{0x24893ee5,0x69330260,0x44320150,0x2d9d3a09}},	//   _bram_, _اکثر, _pwy_, njwe_,
   {{0x27e5033b,0x673a6619,0xb4c00336,0x7529213e}},	//   poln_, batj, ंछे_, ñeza,
   {{0xf7710b05,0x2489661a,0xa01b0212,0xd348001c}},	//   _ذات_, _dram_, _tröj, دیده_,
   {{0x2489661b,0xa01b13da,0x75360233,0x7aed0022}},	//   _eram_, _frök, _teyz, ƙatu,
   {{0x2489487c,0x6d5b006c,0x3126004b,0x7bca661c}},	//   _fram_, _ncua, рдаг, zifu,
   {{0x00830036,0x7bca1621,0xa91d0095,0xbfc6041f}},	// [6100] олто, yifu, cdže, абак,
   {{0xee0e10e9,0x6d5b661d,0xc43b00ca,0x33661fbf}},	//   िद्ध_, _acua, _שתיי, _твог,
   {{0x7bca0a4b,0xdb010052,0x75f664c6,0x00000000}},	//   vifu, _dolë, názo, --,
   {{0x932500cd,0x75f6291d,0x4c86107a,0x7bca0079}},	//   _پرین, zázn, илев, wifu,
   {{0x2722030b,0x6e290087,0x2e3c0139,0xeb9a661e}},	//   nční_, _čebe, _báfá_, кид_,
   {{0x6d5b5e47,0x81d70081,0x2a6c1d13,0x2120033b}},	//   _ecua, িতঃ_, _ppdb_, lcih_,
   {{0x2d96499a,0x7bca661f,0x2e3c0032,0x6e430392}},	//   _крас, rifu, _dáfá_, _мерз,
   {{0xdca643cb,0x7bca0060,0x272200b6,0x386900d3}},	//   _каби, sifu, kční_, _ţara_,
   {{0x673a0018,0xb99700c2,0x62830072,0x75fd01f9}},	//   tatj, рвых_, _ánov, néze,
   {{0x07b8054f,0xcb6700ae,0x75f605f1,0x657f0372}},	//   اهدة_, _вафе_, fázo, _saqh,
   {{0x673a6620,0xdb0103a9,0xdce000c6,0x00000000}},	//   ratj, _nolè, _pamė, --,
   {{0x588608a1,0xc8c70421,0xa01b0364,0xdceb01d3}},	//   _выка, اوین_, _fröh, legā,
   {{0x5454007b,0x212005db,0x00000000,0x00000000}},	//   овят, dcih_, --, --,
   {{0x9f583dc1,0xa91d00cb,0x53341bec,0x00000000}},	//   _miró_, rdže, жерт, --,
   {{0x31c704d9,0xdb0100fd,0x272202c6,0x00000000}},	//   асав, _colè, ační_, --,
   {{0xbf070789,0x4e1d0251,0xdb0100b3,0xa5356621}},	//   _वृषभ_, _बंबई_, _dolè, _унич,
   {{0xd7aa0ccb,0x4059010d,0x753d07ff,0x7bc801c2}},	// [6110] _चकाच, طلاح_, masz, _omdu,
   {{0x753d00fb,0x2fc700ef,0xdf3900e3,0x6d5b6622}},	//   lasz, òng_, اكات_, _scua,
   {{0x3f810b19,0x39460138,0x3ea76623,0xdb0100cd}},	//   rdhu_, _odos_, ânt_, _golè,
   {{0x753d0103,0xac192178,0x7bc8063d,0x67380141}},	//   nasz, году_, _amdu, _levj,
   {{0x2d5800d3,0x629a0031,0x63a51a4a,0x442b0227}},	//   ричь_, ätov, _kohn, npc_,
   {{0x67380ea3,0x39466624,0x63a56625,0x753d0103}},	//   _nevj, _ados_, _john, hasz,
   {{0xe1ff0028,0xdb016626,0x2139023b,0x753d07ff}},	//   _khó_, _kolé, _kesh_, kasz,
   {{0x20110010,0x63a501bf,0x2139023b,0x52d8006e}},	//   _hizi_, _lohn, _jesh_, יווע_,
   {{0xdb0106fc,0x9f59016d,0x0dc8385a,0x9f586627}},	//   _molé, _fusô_, _тури_, _giró_,
   {{0x2019286e,0x291f0610,0x279500c2,0xdcfb0138}},	//   _musi_, scua_, сшир, _jauč,
   {{0x20196628,0x6b9c05fe,0x66e54214,0x20116629}},	//   _lusi_, _òrga, сона, _mizi_,
   {{0x6d591f6e,0x75f6662a,0xe1ff662b,0x6b81008a}},	//   ngwa, rázo, _nhó_, _halg,
   {{0xdb0106a3,0xb0c7009f,0x9f580036,0x6b81026d}},	//   _solè, _रेलग, _mirò_, _kalg,
   {{0x6b81007a,0xe1ff0032,0xdb0105fe,0x272200b6}},	//   _jalg, _ahó_, _polè, rční_,
   {{0x6b81662c,0x21390052,0x644f662d,0x63a500d8}},	//   _malg, _besh_, arci, _dohn,
   {{0x2019662e,0xe1ff00de,0xdb01662f,0x75fd01f9}},	//   _busi_, _chó_, _colé, téze,
   {{0x20116630,0x212001e8,0x3ff60037,0xe1ff0037}},	// [6120] _bizi_, rcih_, مكرر, _dhó_,
   {{0x6b810cda,0xc49b00ca,0x2a69007f,0xdb01014b}},	//   _nalg, _עשית, łaby_, _tolè,
   {{0x201101e8,0x0e66129e,0xdd8f0421,0x76416631}},	//   _dizi_, скен, کون_, nsly,
   {{0x20196632,0x7e4b0018,0x395d01c2,0xddd40031}},	//   _fusi_, اسلہ_, _ncws_, ťaži,
   {{0x20190da3,0xeb100251,0x9f580451,0x20116633}},	//   _gusi_, ाश्त_, _dirò_, _fizi_,
   {{0x6b816634,0x20113c1c,0x2d802347,0x6fb60fba}},	//   _calg, _gizi_, žie_, _امسا,
   {{0x75240a00,0x37cd0081,0x6b816635,0xdb030037}},	//   _ofiz, রকার, _dalg, dhnó,
   {{0x442b0154,0x9f586636,0x6b81033c,0x764113ea}},	//   ypc_, _girò_, _ealg, dsly,
   {{0xa3c95516,0xa3e82a29,0x6b816637,0x753d0103}},	//   लोड_, यका_, _falg, vasz,
   {{0x6b816638,0x2fca1197,0xc07b0089,0xe7d60081}},	//   _galg, _jmbg_, נטיש, হত্য,
   {{0x7bdf025a,0x63a56639,0x64443585,0x96f8002d}},	//   éque, _rohn, _avii, рент_,
   {{0xd6d7663a,0x63a502db,0x3946063d,0x00000000}},	//   сть_, _sohn, _udos_, --,
   {{0x753d663b,0xb0c7412e,0x8b0300b6,0x63a50094}},	//   rasz, _रेंग, ěřen, _pohn,
   {{0x442b57df,0x9f5800e3,0x38cb0260,0x75240062}},	//   rpc_, _bhrí_, _حامی_, _efiz,
   {{0x2019663c,0x753d0018,0xe1ff0019,0xdb01663d}},	//   _susi_, pasz, _phó_, _polé,
   {{0x63a502dc,0x20110511,0xdcfb1711,0x2019663e}},	//   _wohn, _sizi_, _sauč, _pusi_,
   {{0x270e0253,0x656d0256,0xa91d5609,0x64400fb6}},	// [6130] lən_, _ibah, ndža, ámit,
   {{0x4429663f,0x20110abd,0x60c90357,0x213900fc}},	//   _ita_, _qizi_, _žems, _wesh_,
   {{0x270e0092,0xdcfb2461,0x20116640,0xdb0100fd}},	//   nən_, _vauč, _vizi_, _tolé,
   {{0x4ac3009d,0x20110051,0x2019204a,0x44296641}},	//   _वेगव, _wizi_, _tusi_, _kta_,
   {{0xa3bd428a,0x2019069d,0x7ae401e8,0x6d596642}},	//   _आता_, _uusi_, şitl, rgwa,
   {{0x1ae20081,0x270e0092,0x62830072,0xf41f007b}},	//   গেছে_, kən_, _ános, yvän_,
   {{0x6b816643,0xb16e003e,0x9f580036,0x4ea400ae}},	//   _valg, _þýði, _tirò_, _ерта,
   {{0x270e0253,0x44296644,0x6b81243f,0x7bd8084e}},	//   dən_, _ota_, _walg, anvu,
   {{0x44296645,0x6b816646,0xa01b02c3,0x764f007f}},	//   _nta_, _talg, _eröv, ącym,
   {{0x7c29023f,0x656d4dce,0x75240451,0x2cb20120}},	//   _iter, _abah, _sfiz, øyde_,
   {{0x44296647,0x998600e7,0xdb180094,0x69e701b3}},	//   _ata_, žiše_, nivý, _людз,
   {{0x7c29033a,0x3f836648,0x96040789,0xa50a0396}},	//   _kter, _laju_, रगेट_, иена_,
   {{0xf745121c,0x76416649,0x7c290090,0x00000000}},	//   _дело, ssly, _jter, --,
   {{0xf8070a80,0x76430167,0x3f83033b,0x7c290a4b}},	//   _учен, _tvny, _naju_, _mter,
   {{0x4429664a,0x316900dc,0x613a00f6,0x628300d4}},	//   _eta_, ffaz_, ичар_, _šnor,
   {{0x7c29664b,0x6d490037,0x2fca0063,0xdb1800d4}},	//   _oter, _ndea, _smbg_, divý,
   {{0xa2ca033a,0x3f8306ee,0x7c29664c,0x20870686}},	// [6140] _हेर्, _baju_, _nter, ойти_,
   {{0x248001e8,0x75f600b6,0x3f830131,0xe0df022b}},	//   _isim_, kázk, _caju_, _idòl_,
   {{0x69cb0934,0x7c29664d,0xe29a0c3f,0xdd1c0146}},	//   _omge, _ater, _тан_, rážo,
   {{0xf53f1484,0x4429664e,0x7c29080e,0x3ea70212}},	//   lkår_, _yta_, _bter, änta_,
   {{0xac0a031e,0xdca35a65,0x270e0092,0x6d4900f0}},	//   анда_, маци, zən_, _ddea,
   {{0x270e01d4,0xa01b0149,0x1c39097a,0x69cb0178}},	//   yən_, _pröv, сяць_, _amge,
   {{0x225800bc,0x0ef901b3,0xaca40032,0x67ef0537}},	//   nurk_, _гэты_, _itọp, højs,
   {{0x248002e6,0xdd9200cd,0x298a321c,0xed5711db}},	//   _osim_, _تور_, рско_, _мос_,
   {{0x60100032,0x656d00bd,0x22580b8e,0x00000000}},	//   _gómì, _rbah, hurk_, --,
   {{0x2d84664f,0x270e0092,0x37aa01a0,0xa91d00e7}},	//   _hame_, tən_, ртин_, rdža,
   {{0x24806650,0x2d846651,0xa2ca2853,0x656d0124}},	//   _asim_, _kame_, _हेल्, _pbah,
   {{0x270e01d4,0x2d846652,0x2d866653,0x186a0b1e}},	//   rən_, _jame_, ndoe_, _вади_,
   {{0x270e01d4,0x7c290090,0x44290085,0xf9d900c1}},	//   sən_, _xter, _qta_, _פֿעל,
   {{0x98a30284,0x2d845244,0xa7fd01f9,0x00000000}},	//   _циље, _lame_, ltűn, --,
   {{0xd13b013d,0x24800084,0xf1a705e1,0x69cb0150}},	//   иха_, _esim_, оран, _ymge,
   {{0x2d846654,0x224d6655,0x656d1a78,0x44296656}},	//   _name_, ček_, _ubah, _tta_,
   {{0x44296657,0x2bdb2fbd,0x1af10081,0x3169058a}},	// [6150] _uta_, _बदला, _চলছে_, rfaz_,
   {{0x59ca0251,0x31690131,0x22586658,0x00000000}},	//   ़ोतर, sfaz_, burk_, --,
   {{0x2d840d6a,0x3f836659,0x80cb0e28,0x00000000}},	//   _bame_, _vaju_, _सेरे, --,
   {{0x7c2902e5,0x427a00c1,0x127a00c1,0x2d8400ca}},	//   _pter, _פארג, _פארע, _came_,
   {{0x50640423,0xf41f0212,0xdce900bd,0x320901ee}},	//   _отра, kväm_, _mneħ, mmay_,
   {{0x3209665a,0xd0fa08fa,0x447c00c1,0x61ed0e1d}},	//   lmay_, ्धरण_, ינדע, loal,
   {{0xb1130174,0x629800fd,0x8d770dce,0x3209008c}},	//   _bụga, _àvot, _وارا, omay_,
   {{0x75f60074,0x3209665b,0x2d8400a1,0xd90f1ac9}},	//   rázk, nmay_, _game_, نیا_,
   {{0xa01b07ee,0x00000000,0x00000000,0x00000000}},	//   _gröt, --, --, --,
   {{0x2d84665c,0x61ed0062,0xdb0100d4,0x3209008c}},	//   _zame_, hoal, _holí, hmay_,
   {{0xdb010146,0x25a90072,0x00000000,0x00000000}},	//   _kolí, _boal_, --, --,
   {{0x69cb25ea,0x2480665d,0x67ef02b6,0x25a900d7}},	//   _umge, _psim_, tøjs, _coal_,
   {{0x60020161,0x3209041c,0xb5290065,0xdce90357}},	//   lôme, dmay_, _gbọ̀, _obeč,
   {{0x232705cb,0x2258665e,0x00000000,0x00000000}},	//   зори_, turk_, --, --,
   {{0x60020161,0x41b600e5,0x61ed665f,0x00000000}},	//   nôme, псат, foal, --,
   {{0x248001bb,0x320902c9,0xd5b900d9,0x61ed01e9}},	//   _tsim_, gmay_, spār_, goal,
   {{0x61f6010a,0x2480061d,0x55bb00ca,0x66040113}},	// [6160] rlyl, _usim_, _למקו, _ihik,
   {{0x2d842423,0xdee66660,0x3209008a,0xb4b83845}},	//   _same_, пози, amay_, चनी_,
   {{0x64466661,0xa01b0149,0xdb012df7,0x27460037}},	//   lski, _brös, _bolí, líní_,
   {{0x32090188,0x6002016d,0xe80202d5,0x61ed6662}},	//   cmay_, dôme, _रीना_, coal,
   {{0xa2d40bd9,0xbd43001c,0x2d840141,0x9f58009c}},	//   णपक्, رنوي, _vame_, _thrà_,
   {{0x64466663,0x60c40201,0x2d84024a,0x60020131}},	//   iski, mzim, _wame_, fôme,
   {{0xdee31469,0xd35700c1,0x66040a00,0xdb01266c}},	//   _зори, ליסי_, _ohik, _folí,
   {{0xa01b0003,0x6edb00ca,0x6446075b,0x497400ae}},	//   _tröt, _החלפ, kski, флис,
   {{0x60c46664,0x1b1b0033,0x6d420231,0xf98f0037}},	//   nzim, _নজরে_, maoa, طبي_,
   {{0x25a9042b,0x66046665,0x600220df,0x64462b18}},	//   _soal_, _ahik, lômb, dski,
   {{0xb8f313b4,0x32090eac,0x66040483,0x25a900ee}},	//   _हे_, ymay_, _bhik, _poal_,
   {{0x66046666,0xd5bb5d27,0x1a9b00c1,0xba9b00ca}},	//   _chik, ссо_, _ליבע, _לסבי,
   {{0xafdb038c,0x64466667,0x66046668,0x25a92972}},	//   _svøm, gski, _dhik, _voal_,
   {{0x60c46669,0xa01b02c3,0x75fd00d4,0xc7a303bf}},	//   dzim, _orör, cézn, _пичк,
   {{0x61ed666a,0x2b4c00e7,0xd37800d6,0x6446666b}},	//   toal, _mddc_, ччя_, aski,
   {{0x52144aa9,0x65bf01e5,0x777a0a00,0x765a0361}},	//   едст, _bëhe, letx, muty,
   {{0x32094ebd,0x765a666c,0x6d420062,0xf1c6110d}},	// [6170] rmay_, luty, daoa, रोइन,
   {{0xdb01666d,0x320934bb,0x61ed666e,0x3f980027}},	//   _solí, smay_, soal, _cnru_,
   {{0x4fc449cc,0x3d0f0096,0x60c42d30,0xf3ff0231}},	//   хста, तेने_, azim, ltão_,
   {{0xa3c91115,0x224500d4,0x3209026d,0xdb07014b}},	//   लोर_, álku_, qmay_, _émér,
   {{0x69c0666f,0x8ccd00a5,0xf3ff0161,0xdb016670}},	//   dhme, _देशो, ntão_, _volí,
   {{0x765a6671,0xeb961b4d,0x600200fd,0xdb08022b}},	//   kuty, диш_, tôme, _kodè,
   {{0xa01b00a2,0xdb1800d4,0x777a0062,0x7ccf01f9}},	//   _trös, chví, detx, _bőrö,
   {{0xdb086672,0x69c00078,0x3a2c0072,0x64466673}},	//   _modè, ghme, _dtdp_, yski,
   {{0x69db6674,0x7d1b22a9,0xdb010131,0x777a01ff}},	//   rnue, _igus, _bolã, fetx,
   {{0x660401e5,0x64464105,0x69c002ef,0x7c3b0af0}},	//   _shik, vski, ahme, _iwur,
   {{0x644600a5,0x7d030065,0x9be4004d,0xf3ff0131}},	//   wski, _fìrí, _чітк, etão_,
   {{0x644602e6,0xe94500bf,0xd7f800d3,0x7c3b06c0}},	//   tski, _آرای, ală_, _kwur,
   {{0xb4b8417e,0x6446055b,0x777a01e9,0xd7f800ae}},	//   चने_, uski, betx, blă_,
   {{0x395f5c8a,0x765a6675,0xd7f8020a,0x7c3b0027}},	//   lgus_, buty, clă_, _mwur,
   {{0x64466676,0x6604023b,0xe2f80018,0x7d1b0517}},	//   sski, _thik, سورڈ_, _ogus,
   {{0x64460335,0x395f6677,0x7d1b6678,0x79896679}},	//   pski, ngus_, _ngus, ndew,
   {{0xa067667a,0x60c400e9,0xa7c6001c,0x61e14c36}},	// [6180] мата_, uzim, _رژیم_, élla,
   {{0x7d1b4e69,0xe4570341,0x60c4667b,0x79890113}},	//   _agus, _קייט_, rzim, hdew,
   {{0x4420667c,0x7c3b0af0,0x21490076,0xa206004d}},	//   _hui_, _awur, áthú_, _опод,
   {{0x44203b30,0x7c3b0169,0x60260215,0x00000000}},	//   _kui_, _bwur, _одма, --,
   {{0x75e803a3,0x7989667d,0x442000fd,0x0c7a00b9}},	//   mızd, ddew, _jui_, تصاب_,
   {{0x44202a69,0x6fc00233,0x7d1b078e,0x777a0062}},	//   _mui_, _böce, _egus, xetx,
   {{0x4420667e,0x69c0667f,0x7c3b6680,0x6f1c05db}},	//   _lui_, thme, _ewur, _igrc,
   {{0x31606681,0x442004ea,0x75e803a3,0x201801e9}},	//   ngiz_, _oui_, nızd, _hiri_,
   {{0xf4d900c7,0x6d406682,0xdb08025a,0x7c3b0134}},	//   _সর্ব, _iema, _modé, _gwur,
   {{0x201806c0,0x69c06683,0x6d406684,0x909b0341}},	//   _jiri_, shme, _hema, קסיק,
   {{0x6d400d17,0x20186685,0x0f5700a1,0x777a0a00}},	//   _kema, _miri_, ויים_, retx,
   {{0x6d406686,0x20186687,0xadc300de,0x7c206688}},	//   _jema, _liri_, _miến, _kumr,
   {{0x6d401268,0x44200465,0xf9c712eb,0x3944013f}},	//   _mema, _cui_, _تحلی, mams_,
   {{0xf3ff00c9,0xa3c90067,0x6d400655,0x44206689}},	//   rtão_, लों_, _lema, _dui_,
   {{0xf3ff00c9,0xdb01025b,0xd6cf0f2e,0x7c2064ea}},	//   stão_, _kolá, _рт_, _lumr,
   {{0x4420668a,0x3944013f,0x66271054,0x2018668b}},	//   _fui_, nams_, žské, _airi_,
   {{0x7c20668c,0x2018668d,0x5f95668e,0xdbd60084}},	// [6190] _numr, _biri_, ниат, _kään,
   {{0x645d668f,0x201826f7,0xdbd61d2d,0x657d6690}},	//   musi, _ciri_, _jään, lesh,
   {{0x5d550379,0x20186691,0x6d406692,0x3944522a}},	//   екет, _diri_, _bema, kams_,
   {{0x62856693,0x39446694,0x657d2f79,0x3f870039}},	//   _isho, jams_, nesh, žnu_,
   {{0x6d404768,0x394412b8,0x645d14a5,0x7c206695}},	//   _dema, dams_, nusi, _cumr,
   {{0x657d6696,0x6d40007a,0x20186697,0xf789016d}},	//   hesh, _eema, _giri_, _maçã_,
   {{0x645d068d,0xadc30023,0x6d4000ca,0x387f0063}},	//   husi, _giến, _fema, wwur_,
   {{0x6d403994,0x657d174a,0x20186698,0x645d6699}},	//   _gema, jesh, _ziri_, kusi,
   {{0x657d3513,0x20180c5d,0x395f669a,0x645d5873}},	//   desh, _yiri_, rgus_, jusi,
   {{0x6b88669b,0x645d2a3f,0x32190d46,0x6285669c}},	//   _gadg, dusi, _lisy_, _osho,
   {{0x4420669d,0xf1bf669e,0x62851ba4,0x6d40669f}},	//   _sui_, _olá_, _nsho, _yema,
   {{0x4420002d,0x321900b7,0x6d4066a0,0x394401d3}},	//   _pui_, _nisy_, _xema, cams_,
   {{0x442066a1,0x645d66a2,0x62850193,0x291d0dd5}},	//   _qui_, gusi, _asho, _igwa_,
   {{0x442000ef,0x66e52223,0x43751756,0xa3ab0789}},	//   _vui_, _пола, куст, कॉल_,
   {{0x645d08a1,0x61e903ce,0xe297162c,0xf7700177}},	//   ausi, čeln, нар_, _خان_,
   {{0x201866a3,0x645d66a4,0x442066a5,0x657d66a6}},	//   _siri_, busi, _tui_, cesh,
   {{0x628562d7,0x6d401c8d,0x394f2ae7,0x2f560127}},	// [61a0] _esho, _rema, _mdgs_, етес,
   {{0x047900bf,0x7bc366a7,0x7f8615ae,0x75e8173c}},	//   _کلیک_, jhnu, علان, sızd,
   {{0x6d401bd6,0x20180087,0x6146322c,0x7c2066a8}},	//   _pema, _viri_, _пена, _sumr,
   {{0x10a608d8,0x2018009e,0x291d06c0,0xadc300de}},	//   _зимн, _wiri_, _ngwa_, _viến,
   {{0x201866a9,0x628549ec,0x39440138,0xdb010146}},	//   _tiri_, _zsho, vams_, _rolá,
   {{0xf09f011b,0xadc300ef,0xdb0166aa,0x7bc366ab}},	//   _ngày_, _tiến, _solá, ghnu,
   {{0x6d4066ac,0x3944282c,0x657d0239,0xdb01321f}},	//   _tema, tams_, yesh, _polá,
   {{0x7bc30181,0xdbd60084,0xc5f900d9,0x657d0372}},	//   ahnu, _sään, ntēt_, xesh,
   {{0x657d66ad,0x394466ae,0xdb01045e,0x7bc3023e}},	//   vesh, rams_, _volá, bhnu,
   {{0x7bc33d11,0x645d66af,0x95fb1fb4,0x3f8a2d17}},	//   chnu, vusi, ृष्ट_, _jabu_,
   {{0x657d66b0,0xd6da02ec,0xdbd6032c,0x29020094}},	//   tesh, яти_, _vään, ťka_,
   {{0x3f8a66b1,0xdb180146,0x45d51146,0x291d010a}},	//   _labu_, chvá, томс, _ggwa_,
   {{0x7afa66b2,0x657d66b3,0xc8b3001c,0xe1260033}},	//   _hytt, resh, _مصوب, বরাহ_,
   {{0x657d66b4,0x5ea60081,0x7ae400ae,0xf1bf003e}},	//   sesh, _গেছে, şitu, _slá_,
   {{0x645d66b5,0x657d66b6,0x61e10143,0x7afa0537}},	//   susi, pesh, éllo, _jytt,
   {{0x657d66b7,0x61e966b8,0x645d66b9,0x628500d2}},	//   qesh, čelo, pusi, _vsho,
   {{0x3f8a1114,0x7afa038c,0x21290167,0xfd4a03a8}},	// [61b0] _babu_, _lytt, rcah_, _fflẅ,
   {{0x62850197,0x752d03e3,0x6002016d,0x644d00c6}},	//   _tsho, _hfaz, tôma, _ivai,
   {{0x7afa00f3,0x628566ba,0x88d40033,0x8e990037}},	//   _nytt, _usho, _হুমক, بناء_,
   {{0x644d0138,0x3eae0212,0x75e80233,0x00000000}},	//   _kvai, äfta_, mızc, --,
   {{0x23bd0065,0x752d0372,0x00000000,0x00000000}},	//   _jìjo_, _mfaz, --, --,
   {{0x7afa02fe,0xa91d66bb,0x8234001c,0x3f8a3d42}},	//   _bytt, mdži, _جریا, _gabu_,
   {{0xa91d013f,0xda622917,0x68fc0092,0xf9910037}},	//   ldži, авщи, ərdi, لبة_,
   {{0x644d413a,0xa91d0138,0x7bc30052,0xdcfb00c4}},	//   _ovai, odži, shnu, _nauć,
   {{0xa91d013f,0xa3d100c3,0x3f8a0174,0x644d009c}},	//   ndži, वफा_, _yabu_, _nvai,
   {{0xa91d0138,0x752d0131,0xd7ee0037,0xdbdf0af0}},	//   idži, _afaz, يكي_, _kìín,
   {{0x644d2be9,0xd7090084,0x66e536bf,0x7bc14de0}},	//   _avai, ьное_, тона, _illu,
   {{0x2b4766bc,0x291d0169,0x00000000,0x00000000}},	//   lanc_, _ugwa_, --, --,
   {{0x2bb802d5,0x850c0ccb,0x81d70081,0xa91d050d}},	//   _अवमा, सेंट_, াকা_, jdži,
   {{0x69e30477,0x386d66bd,0x2b4766be,0x23bd0065}},	//   šteđ, mter_, nanc_, _dìjo_,
   {{0x3f8a66bf,0x4343013d,0x386d128b,0xdb0166c0}},	//   _rabu_, ресв, lter_, _dolç,
   {{0x3f8a3436,0x75f60103,0xc17401c2,0x00000000}},	//   _sabu_, rázs, kiɗe_, --,
   {{0x386d40d5,0x7bc102fd,0x798b66c1,0xa3c2417a}},	// [61c0] nter_, _ollu, _magw, ंसद_,
   {{0x443214d0,0x386d66c2,0x798b60a2,0xe29a0284}},	//   _ity_, iter_, _lagw, _жао_,
   {{0x386d0505,0x644d00d9,0x75f60328,0x00000000}},	//   hter_, _zvai, lázq, --,
   {{0x386d66c3,0x7afa017a,0x798b66c4,0x069600c1}},	//   kter_, _rytt, _nagw, כדעם_,
   {{0x3f8a66c5,0x386d6091,0xa3c92231,0x7afa2458}},	//   _tabu_, jter_, लोक_, _sytt,
   {{0xa3c20d75,0x4432037a,0x7afa66c6,0x798b0350}},	//   ंसि_, _mty_, _pytt, _aagw,
   {{0xe9e62984,0x798b2964,0x29000138,0xbea31231}},	//   кцио, _bagw, _šia_, _карк,
   {{0x386d09ce,0x7bc166c7,0xa9670291,0x236d007e}},	//   fter_, _ellu, вића_, đeji_,
   {{0x386d66c8,0xbc6a2876,0xa3c23f50,0x798b02c9}},	//   gter_, _زمان_, ंसा_, _dagw,
   {{0x7afa0084,0x2cc407aa,0xdb080181,0x00000000}},	//   _tytt, ırdı_, _hodí, --,
   {{0x443200dd,0x06d50081,0xa91d013f,0x644d129d}},	//   _aty_, _সুবি, zdži, _svai,
   {{0x798b0172,0x386d042c,0x3dc60231,0x00000000}},	//   _gagw, bter_, nhow_, --,
   {{0x386d5459,0x443200de,0xdb1800aa,0x79805ee5}},	//   cter_, _cty_, rivõ, memw,
   {{0x9f9a007a,0x61e600bd,0xdb1800bc,0xa91d0218}},	//   _jääb_, _ajkl, sivõ, vdži,
   {{0x24182787,0x69c20b8e,0x2167004b,0x798b16da}},	//   торы_, _kloe, ктаг, _yagw,
   {{0x11d90080,0x31c42363,0x200a0090,0x644d00e8}},	//   روءة_, асув, _ahbi_, _tvai,
   {{0xa91d013f,0x7bd85478,0x3495013f,0x25f20096}},	// [61d0] udži, kivu, _сапр, ीतरी_,
   {{0xdb1a3536,0x69c20150,0xa91d66c9,0xa283110a}},	//   _altí, _lloe, rdži, _پیرو,
   {{0xa91d479c,0xa3c207d5,0x7bd80094,0x7e283f54}},	//   leže, ्फर_, divu, віча_,
   {{0x1eea09b4,0x386d13f8,0xdb030364,0x629700bd}},	//   رونی_, yter_, rknü, _irxo,
   {{0x386d66ca,0x6adb0af1,0x2b4766cb,0x6002016d}},	//   xter_, यप्र, tanc_, cômo,
   {{0xadc30019,0x798b0112,0xbb420cba,0x7aed071d}},	//   _thắn, _sagw, бешк, şatm,
   {{0x69c20db8,0x798b1281,0x386d03c3,0xdfd4065c}},	//   _bloe, _pagw, wter_, _торы,
   {{0x386d0073,0x248900e9,0xceb200c1,0x69c266cc}},	//   tter_, _osam_, _פין_, _cloe,
   {{0x386d04ea,0x7bd866cd,0xa91d0dd9,0xdbd100aa}},	//   uter_, bivu, ježe, _küün,
   {{0x798b040c,0x7bc166ce,0x1db9009d,0xa91d0087}},	//   _wagw, _ullu, _आवडत, deže,
   {{0x248934ac,0xb8fa1492,0x2bb80521,0x61e91912}},	//   _asam_, _डे_, _अवता, čelj,
   {{0xf41f0084,0x64a60077,0x69c2511f,0x386d66cf}},	//   yvät_, гама, _gloe, pter_,
   {{0x3a250934,0xa01b0018,0x442400de,0x81e90033}},	//   _hulp_, _csök, êm_, যতা_,
   {{0xf74566d0,0x3f810dd9,0x48520103,0x00000000}},	//   _секо, jehu_, _اپوز, --,
   {{0x248900d9,0x2b45044c,0x00000000,0x00000000}},	//   _esam_, _melc_, --, --,
   {{0x05663898,0xc4862edd,0x443266d1,0x7bd82e60}},	//   _свин, _блик, _tty_, zivu,
   {{0x600a66d2,0x10a314e0,0xa91d033b,0x44320a0a}},	// [61e0] енам_, битн, ležb, _uty_,
   {{0x351b0054,0x728a0831,0x2bb866d3,0x2d9f01ff}},	//   _אופנ, _због_, _अवधा, _anue_,
   {{0xdb0866d4,0xee3a3898,0x798066d5,0x25a04341}},	//   _podí, хне_, yemw, _knil_,
   {{0x65663695,0x6ce61acf,0x2b4500ee,0x2d9f0090}},	//   ngkh, ліле, _aelc_, _cnue_,
   {{0x7bd866d6,0x61e466d7,0x3200023e,0xdb080e43}},	//   tivu, mnil, mliy_, _vodí,
   {{0x61e42052,0xa91d0559,0x69c20371,0x61f604a6}},	//   lnil, ndžu, _sloe, loyl,
   {{0x69c266d8,0x79803128,0x7bd866d9,0x61e466da}},	//   _ploe, temw, rivu, onil,
   {{0x61e466db,0x48aa4941,0x7bd866dc,0x75fd1275}},	//   nnil, етом_, sivu, pézi,
   {{0x69c20934,0x61e4601a,0x76aa0092,0x798002a4}},	//   _vloe, inil, məyi, remw,
   {{0x76aa0092,0x61e466dd,0x79800239,0x06fd00b6}},	//   ləyi, hnil, semw, číná_,
   {{0xa91d03f1,0x61e466de,0x61f6019c,0x00000000}},	//   veže, knil, koyl, --,
   {{0xb1130134,0x61e40146,0x25a000fd,0x9f5f003e}},	//   _bụla, jnil, _cnil_, ðrún_,
   {{0xa91d07c0,0x29060174,0xdb080131,0x00000000}},	//   teže, _uzoa_, _fodã, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa91d0660,0x9f5e0174,0x7bdf020d,0x61e4003e}},	//   reže, _òtù_, équi, fnil,
   {{0xa91d0087,0x24890197,0x61e466df,0x11d40037}},	//   seže, _tsam_, gnil, متقد,
   {{0x361c0054,0x24890161,0x2d8d028d,0x660d4829}},	// [61f0] _אוהד, _usam_, _raee_, _ihak,
   {{0xb4c10454,0x44392e30,0x600b026a,0xf367020a}},	//   ंनी_, mps_, küme, _стин,
   {{0xa3c200a5,0x443966e0,0x644f0503,0x3f81028a}},	//   ंसर_, lps_, lsci, rehu_,
   {{0x39460095,0x645d0313,0xe80b0ccb,0xf65300ca}},	//   _neos_, orsi, _सीना_, מצע_,
   {{0xdca566e1,0x6e2966e2,0x3f8166e3,0xcb69016c}},	//   рали, _čebu, pehu_, вале_,
   {{0x443905fe,0x644f152f,0x660d0113,0x645d66e4}},	//   ips_, isci, _lhak, irsi,
   {{0xdce902e6,0xadc300fe,0x00000000,0x00000000}},	//   _obeć, _chản, --, --,
   {{0x39463521,0x76aa0092,0x645d00e7,0x644f00c6}},	//   _ceos_, cəyi, krsi, ksci,
   {{0x6d4b423d,0x39460231,0xc9a600c2,0x2d210285}},	//   maga, _deos_, рвые_, यशील_,
   {{0x6d4b66e5,0x660d66e6,0x61e466e7,0x7d0966e8}},	//   laga, _ahak, znil, _izes,
   {{0x61e466e9,0x660d66ea,0x645d3994,0x394666eb}},	//   ynil, _bhak, ersi, _feos_,
   {{0x6d4b66ec,0x6b8366ed,0x660d068d,0x58d93edd}},	//   naga, leng, _chak, _идея_,
   {{0xe72e1121,0x660d66ee,0xdb080037,0x61e466ef}},	//   _ме_, _dhak, _iodá, vnil,
   {{0x6b8366f0,0x6d4b66f1,0x60cd66f2,0x660d0062}},	//   neng, haga, dzam, _ehak,
   {{0x6d4b66f3,0x2bb8049d,0x645d66f4,0x6723077e}},	//   kaga, _अवसा, arsi, _ignj,
   {{0x6b8366f5,0x61e400d3,0x69c901d0,0x39460072}},	//   heng, unil, nhee, _xeos_,
   {{0x6b8366f6,0x75240384,0xdb010076,0x78a9002b}},	// [6200] keng, _igiz, _colú, nxev,
   {{0xe80b034c,0x6b8366f7,0x69c9023e,0xf41f0212}},	//   _सीमा_, jeng, hhee, svär_,
   {{0x76aa01d4,0x6d4b66f8,0x7f4700bd,0x61e4103b}},	//   təyi, faga, _dejq, pnil,
   {{0x6d4b66f9,0xed5a3051,0x6444570a,0xdb016130}},	//   gaga, тод_, _kwii, _folú,
   {{0x69c9008a,0x672307c0,0xdd8f08ba,0x69db023b}},	//   dhee, _ognj, بون_, diue,
   {{0x6b8366fa,0x35a80fef,0xdb1a291d,0x394666fb}},	//   geng, गाड़, _altá, _seos_,
   {{0x6d4b4263,0xdee3002d,0x6e270d2a,0x237a0063}},	//   baga, _дори, _gujb, _mbpj_,
   {{0x6d4b66fc,0x75240060,0x69c901cb,0xdce20117}},	//   caga, _ngiz, ghee, lgoč,
   {{0xdb0818ed,0x6b8366fd,0x2d970146,0x6e2066fe}},	//   _dodá, beng, ádež_, _iimb,
   {{0x645d04eb,0x61e9050d,0x75241ba4,0x6b831937}},	//   vrsi, čeli, _agiz, ceng,
   {{0x6e20068d,0x37a70ff1,0x660d0060,0x60cd66ff}},	//   _kimb, ртын_, _phak, zzam,
   {{0x6e206700,0x69c92096,0xaadb00ca,0x44396701}},	//   _jimb, chee, _בחבר, tps_,
   {{0xb4c10067,0xb3b410e9,0x6e206702,0xdddc129d}},	//   ंने_, ुसंख, _mimb, _aprū,
   {{0x660d6703,0x75246704,0x6d4b6705,0x60cd033b}},	//   _whak, _egiz, zaga, vzam,
   {{0x6d4b6706,0x88e80081,0xd62715de,0x6e2000e7}},	//   yaga, _পরিক, _које_, _oimb,
   {{0x44396707,0x6e2004da,0x6b836708,0xa91d6709}},	//   pps_, _nimb, zeng, leža,
   {{0x6b83670a,0xb1130294,0x656d0027,0xdb010032}},	// [6210] yeng, _tụma, _icah, _dolù,
   {{0x60cd670b,0x6d4b670c,0x667100cd,0xdb010328}},	//   rzam, waga, _بگیر, _volú,
   {{0x6d4b4208,0x6e20670d,0x6b83670e,0x3ed900bf}},	//   taga, _bimb, veng, دواج_,
   {{0x4429670f,0x6b833090,0xb1130174,0x656d01af}},	//   _kua_, weng, _jụka, _jcah,
   {{0x6d4b6710,0x44296711,0x6e206712,0x7f47023e}},	//   raga, _jua_, _dimb, _tejq,
   {{0x44296713,0x6d4b4208,0x44215de7,0xa91d4e00}},	//   _mua_, saga, _jih_, ježa,
   {{0x6d4b12f5,0x0d670465,0x44296714,0xdb08025b}},	//   paga, _възм, _lua_, _podá,
   {{0x6b830a2a,0x2bd90751,0x6e206715,0x49980084}},	//   seng, _भगवा, _gimb, атья_,
   {{0x4429054f,0x6b836716,0x3f9100cc,0x69c924ab}},	//   _nua_, peng, _kazu_, rhee,
   {{0x69c96717,0x656d0027,0x38bc0076,0x7bca042c}},	//   shee, _acah, _sárú_, chfu,
   {{0x7c291277,0x44296718,0xb1130294,0x3f916719}},	//   _huer, _aua_, _bụka, _mazu_,
   {{0xc32900f5,0x4429671a,0x3f91015c,0x4421671b}},	//   _טו_, _bua_, _lazu_, _aih_,
   {{0x4429671c,0x442104eb,0x69a40966,0x69d90078}},	//   _cua_, _bih_, कारी, _imwe,
   {{0x4429671d,0x7c2914e2,0xf7710018,0x4421128c}},	//   _dua_, _muer, _رات_, _cih_,
   {{0x44292e75,0x4421671e,0x00000000,0x00000000}},	//   _eua_, _dih_, --, --,
   {{0xe80b143d,0x7c290185,0xb1130134,0x6444007b}},	//   _सीता_, _ouer, _gụka, _twii,
   {{0x4429005a,0x0ce200c7,0x6e2018ba,0x4421003d}},	// [6220] _gua_, _বর্ত, _rimb, _fih_,
   {{0x4421671f,0x43860037,0x7d0002ac,0x31690634}},	//   _gih_, _الدق, _ryms, agaz_,
   {{0x3f9102dc,0x6002001f,0x69d96720,0x7e65061d}},	//   _dazu_, nômi, _omwe, guhp,
   {{0x237f02e6,0x442901fa,0xa2d102d5,0x7c2902db}},	//   đuje_, _yua_, _डेट्, _buer,
   {{0x3f910106,0x7c2914e2,0x89d800bf,0x44296721}},	//   _fazu_, _cuer, یوتر_, _xua_,
   {{0x7c296722,0x6e200010,0x69d96723,0xac25084c}},	//   _duer, _wimb, _amwe, іфік,
   {{0x69a4121d,0xe80b6724,0xc33300a1,0xa91d6725}},	//   काली, _सीधा_, לוג_, veža,
   {{0x7c290eb8,0x383421fd,0xadc30023,0x28d9009f}},	//   _fuer, онир, _thạn, _बेहि,
   {{0x8c433b2f,0x3f9101c2,0x00000000,0x00000000}},	//   _нете, _yazu_, --, --,
   {{0x44296726,0x7c2f025a,0x69d9010a,0x69c06727}},	//   _rua_, _écra, _emwe, skme,
   {{0x44296728,0x7c2901bf,0x6d490154,0xa91d042d}},	//   _sua_, _zuer, _yeea, reža,
   {{0x4429670f,0xceb30054,0x442102e8,0x6fc00149}},	//   _pua_, לית_, _sih_, _böck,
   {{0x442900ef,0xa91d1c54,0xdb010154,0xe0df01b5}},	//   _qua_, ležn, _anlè, _ceòl_,
   {{0x44290019,0x600b0233,0x53341e46,0x00000000}},	//   _vua_, küma, зерт, --,
   {{0x44216729,0x69d902ad,0xd5bb013d,0x3f910034}},	//   _vih_, _ymwe, _бсп_, _razu_,
   {{0x4429672a,0x463b0130,0x6fc001bf,0x44210085}},	//   _tua_, _געהע, _höch, _wih_,
   {{0x7bc808f5,0x442102e6,0xb3eb0080,0xdb0100fd}},	// [6230] _oldu, _tih_, _معدل_, _enlè,
   {{0x2fc70019,0x6aa80034,0x3fd70033,0x00000000}},	//   óng_, _कपूर, তক্ষ, --,
   {{0x6fc002dc,0x7c29672b,0xa91d0268,0xa3be0006}},	//   _möch, _suer, ježn, _आवत_,
   {{0x7c29672c,0x7bc8672d,0x29d300d3,0xa91d0087}},	//   _puer, _aldu, nţat_, dežn,
   {{0x7c290b0b,0x6d49672e,0x7bc600c6,0xe9e90031}},	//   _quer, _veea, _įkur, nkúš_,
   {{0xeb992863,0x40343602,0xda591412,0x00000000}},	//   рик_, _херс, ариш_, --,
   {{0x853003e3,0x7c29042c,0x2d990143,0xe1ff0139}},	//   _haɗe, _wuer, _óseo_, _kkó_,
   {{0x7c29456c,0x08c5672f,0x7bc86730,0x22450146}},	//   _tuer, жбин, _eldu, álky_,
   {{0x7c216731,0x394d223a,0x00000000,0x00000000}},	//   _tilr, raes_, --, --,
   {{0xeb9b0814,0x290300d9,0x6002016d,0xaa59007b}},	//   _حضرت_, āja_, tômi, _вижу_,
   {{0x6b9c3531,0x85ea176e,0x28d9121d,0x7bc36732}},	//   _órga, идов_, _बेरि, mknu,
   {{0x69d96733,0x78a40307,0x248000dc,0x26cb007f}},	//   _umwe, _šive, _ppim_, ąco_,
   {{0xb8fe0081,0xe91900d6,0x26c3033b,0x81c10033}},	//   _দু_, _тоді_, šjo_, ্চা_,
   {{0xe73907c8,0xe1ff0af0,0xaca30129,0xa91d0357}},	//   _тек_, _akó_, _ntọa, ležo,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8c92918,0xe1f7224a,0x7bc3003e,0x543603c5}},	// [6240] िनिय, ігу_, kknu, _بربر,
   {{0x85300022,0xe1ff0065,0x64560169,0xd00f00d1}},	//   _daɗe, _ekó_, _ivyi, پلم_,
   {{0xd37b00c1,0x00000000,0x00000000,0x00000000}},	//   _דריט, --, --, --,
   {{0xa3c2000f,0xc8c90789,0x2c720150,0x9f5801b9}},	//   ंसक_, िनाट, tâd_, _chrò_,
   {{0xf1b30327,0x629e0234,0xa3be09a1,0xa91d00c4}},	//   _חסר_, _hrpo, _आवा_, dežo,
   {{0x629e0995,0x749b0142,0x649b0142,0x0eba065c}},	//   _krpo, יינפ, יסנד, _кубы_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa91d0087,0xa3be00aa,0x00000000,0x00000000}},	//   režn, _आवऽ_, --, --,
   {{0xc21300a1,0x6d4221d8,0xa91d0128,0xbf0a0096}},	//   והה_, mboa, sežn, _वरुन_,
   {{0xc07b00c1,0x7bc80092,0xa91d3fa3,0x907b0796}},	//   סטיש, _uldu, pežn, סטיי,
   {{0xa91d6734,0x600b00aa,0x00000000,0x00000000}},	//   bežo, kümn, --, --,
   {{0x6d426735,0x6fc00364,0xe4a72887,0x00000000}},	//   nboa, _wöch, орго, --,
   {{0x29d3020a,0x6fc0042c,0x00000000,0x00000000}},	//   rţat_, _töch, --, --,
   {{0xbf0a0096,0x00000000,0x00000000,0x00000000}},	//   _वरून_, --, --, --,
   {{0x64560027,0x9294468c,0xe6580076,0x00000000}},	//   _evyi, марц, _البث_, --,
   {{0x225e033d,0x26d80031,0xc0350859,0x3cdb00aa}},	//   átka_, úrou_, знај, _खइले_,
   {{0x657f0197,0x7bc30e4b,0x00000000,0x00000000}},	// [6250] _ibqh, yknu, --, --,
   {{0xdb180102,0xdb21025b,0x6d4200d4,0x00000000}},	//   mkvæ, _štít, eboa, --,
   {{0x68e400b6,0x00000000,0x00000000,0x00000000}},	//   _židl, --, --, --,
   {{0xb50f009f,0xb17b040f,0x8367001c,0x00000000}},	//   _सराय_, _småf, _ادکل, --,
   {{0xa1360089,0xd59c00c1,0xc1051374,0x7bc32347}},	//   _מארק_, יבאל, _روسي, tknu,
   {{0x443b0899,0x2005003e,0x00ba00ca,0x46ca0d7e}},	//   _mtq_, _óli_, _המשמ, ानाह,
   {{0xf1bf0019,0x6d42022b,0xa91d09ac,0x00000000}},	//   _giác_, bboa, težo, --,
   {{0x3e750149,0x7c2f020d,0x7bc36736,0x00000000}},	//   måt_, _écro, sknu, --,
   {{0x3e750973,0x00000000,0x00000000,0x00000000}},	//   låt_, --, --, --,
   {{0x7c3b6737,0x77f7009d,0x61b82397,0x59a900b6}},	//   _itur, ुतेक_, _इक्ष, काहर,
   {{0x38ca001c,0xa91d0e4b,0x3e751e8f,0x443b020b}},	//   لایی_, pežo, nåt_, _atq_,
   {{0xca9600ca,0x69dc00c6,0x00000000,0x00000000}},	//   _מדעי_, _įreg, --, --,
   {{0xe8ee6738,0x69cb6739,0x6d5b024a,0xc9522252}},	//   _чл_, _ilge, _mdua, _טמא_,
   {{0x9f5a023b,0x889a00ca,0x31980134,0x3e750212}},	//   ropë_, _לבני, _ọz_, kåt_,
   {{0xf09f0139,0x00000000,0x00000000,0x00000000}},	//   _arà_, --, --, --,
   {{0x7c3b03a3,0x5bb80789,0xf09f01b9,0x629e0218}},	//   _otur, _अव्व, _brà_, _vrpo,
   {{0x7c3b05bd,0xdb01673a,0x3cdb1784,0x00000000}},	// [6260] _ntur, _koló, _खेले_, --,
   {{0x6d5b08d3,0x7d041ba8,0x629e05db,0x00000000}},	//   _adua, üism, _trpo, --,
   {{0x6d42673b,0x7c3b673c,0x69cb673d,0x0cc405d6}},	//   tboa, _atur, _olge, वन्म,
   {{0x600b026a,0xf09f0036,0xdb010032,0x7989010a}},	//   lüml, _frà_, _loló, jeew,
   {{0x629c0abf,0xb17b34cb,0x6d5b471a,0x7989010a}},	//   lvro, _småg, _ddua, deew,
   {{0x69cb673e,0x6d420062,0xa91d015c,0x3e751f60}},	//   _alge, sboa, režl, båt_,
   {{0x629c1cab,0x7c3b673f,0x9d46004d,0x6d426740}},	//   nvro, _etur, _невд, pboa,
   {{0x89d83862,0x583800d3,0x7c3b00b3,0x00000000}},	//   توبر_, озия_, _ftur, --,
   {{0xa91d6741,0x600b026a,0x67d42efa,0x7c3b00da}},	//   ležj, küml, допу, _gtur,
   {{0x69c501e5,0x6e2e6742,0x37aa52a5,0xdb015bef}},	//   ëher, _kubb, стин_, _coló,
   {{0x6e2e0188,0xdb010065,0xb886003e,0x32020ece}},	//   _jubb, _doló, fsíð, _okky_,
   {{0xd6d71845,0x6e2e06b0,0xdb1801cd,0x69cb033c}},	//   яты_, _mubb, tkvæ, _glge,
   {{0x629c6741,0xb53a0139,0x9f840233,0xdb01217f}},	//   evro, _gbọ́, _göç_, _foló,
   {{0x64921100,0x481300d6,0x6e2e0154,0x00000000}},	//   džić, _зміс, _oubb, --,
   {{0x3a260154,0xa77b00ca,0x36330076,0x629c02ac}},	//   _kiop_, _הרופ, _كريس, gvro,
   {{0x225f02ef,0xdb010383,0xe51a00b7,0x00000000}},	//   čuk_, _kolò, नेहि_, --,
   {{0x600b0233,0x81c10033,0x00000000,0x00000000}},	// [6270] büml, ্চল_, --, --,
   {{0xfd550129,0x6e2e4a59,0xdb016743,0xa2b500a8}},	//   bsaị, _bubb, _polü, _उपप्,
   {{0x7c3b6744,0x85300d2a,0x25a90b8e,0x51f926fd}},	//   _stur, _haɗa, _knal_, _мною_,
   {{0x216702fd,0xf09f0019,0x62856745,0x3e756746}},	//   _этог, _trà_, _ipho, råt_,
   {{0x61ed00d3,0x53d100aa,0x320907ac,0xf09f00b3}},	//   mnal, _हताश, mlay_, _urà_,
   {{0x32096747,0x3e750212,0x85300022,0x61ff00a7}},	//   llay_, påt_, _maɗa, loql,
   {{0x6e2e6748,0xdb180212,0xf8ae00d1,0x00000000}},	//   _gubb, jkvä, یکه_, --,
   {{0x61ed6749,0xa2b504dd,0x3209009c,0xdb01674a}},	//   nnal, _उपन्, nlay_, _soló,
   {{0x7c3b674b,0xdb01674c,0x853003e3,0x3a26674d}},	//   _utur, _colò, _naɗa, _diop_,
   {{0x6285674e,0x600b1d7e,0x3209041c,0x00000000}},	//   _opho, kümm, hlay_, --,
   {{0x628501fa,0x320907ac,0x657d674f,0x5975004b}},	//   _npho, klay_, ffsh, _жылу,
   {{0x61ed6750,0xdbd70302,0xceb200ca,0xdd1c00d4}},	//   jnal, sääs, דיט_, lášo,
   {{0xb8860088,0x32096751,0xdcfb0039,0xdbd70673}},	//   rsíð, dlay_, _obuč, pääs,
   {{0x660e0181,0x853003e3,0x225e2347,0xdd1c0031}},	//   _ďaku, _daɗa, átko_, nášo,
   {{0xe2976752,0x628e0126,0xdb180212,0x61ed003e}},	//   мар_, uwbo, ckvä, fnal,
   {{0x61ed6753,0x32096754,0xb6860068,0x629c04e2}},	//   gnal, glay_, _کھیل_, rvro,
   {{0x660400ac,0x62856380,0x629c1044,0xe45f0103}},	// [6280] _ikik, _epho, svro, ször_,
   {{0x6e2e6755,0x7e7b3df1,0x9f4a022b,0x3dcd022b}},	//   _pubb, _ćupr, _akbò_, _alew_,
   {{0x32093606,0x3dcd627c,0x66040172,0x00000000}},	//   blay_, _blew_, _kkik, --,
   {{0xa91d0087,0x7f4e6756,0x853001c2,0xf09f0139}},	//   režj, _webq, _yaɗa, _iyàn_,
   {{0x61e46757,0x361b006e,0x3dc66758,0x6604024a}},	//   miil, קונד, rkow_, _mkik,
   {{0xdb210181,0x1ae90081,0x61e46759,0x3dc6274c}},	//   _štát, য়েছে_, liil, skow_,
   {{0xa9341736,0x66045518,0xa91d675a,0x0a6a0120}},	//   нейш, _okik, bežk, ірки_,
   {{0xa9c302ec,0x61e4675b,0xdb01675c,0x66040435}},	//   вськ, niil, _polò, _nkik,
   {{0x60d622d4,0x3f98675d,0x3cf10206,0x00000000}},	//   nzym, _karu_, čovú_, --,
   {{0x8c430183,0x6604675e,0x85300022,0xdcf70281}},	//   _рефе, _akik, _raɗa, _غفلت_,
   {{0x61e4008a,0x61ed675f,0xdb1a0216,0x32096760}},	//   kiil, ynal, _motë, ylay_,
   {{0x2bbe0096,0x28d90096,0xdb180212,0xdb1a0052}},	//   ्सवा, _बेकि, rkvä, _lotë,
   {{0x657d6761,0x61ed04ad,0x61e46762,0xf09f0139}},	//   rfsh, vnal, diil, _ayàn_,
   {{0x66044d8c,0x80d90179,0x7c2800bd,0x00000000}},	//   _ekik, _नेगे, _jidr, --,
   {{0x53340e38,0x61e46763,0x8530006d,0x61ed2ce2}},	//   тест, fiil, _waɗa, tnal,
   {{0xdb1a001f,0xb17b0d3e,0x61e400ae,0x66040167}},	//   _potê, _småb, giil, _gkik,
   {{0x3f9848d4,0x32096764,0x752d513b,0xdb1a01e5}},	// [6290] _baru_, rlay_, _igaz, _botë,
   {{0xed5902e6,0xb4cb143d,0x32093d54,0xf1bf0023}},	//   _može_, लनी_, slay_, _gián_,
   {{0x61e46765,0x3f986766,0x62856767,0x798200a5}},	//   biil, _daru_, _upho, _obow,
   {{0x61e4002d,0x644d6768,0xafdb0f04,0x7c285271}},	//   ciil, _kwai, _stød, _aidr,
   {{0x7c283696,0x3f98006d,0xed590146,0x394f057a}},	//   _bidr, _faru_, _nože_, _regs_,
   {{0x7c2838df,0x394f6769,0x79820f20,0x644d0239}},	//   _cidr, _segs_, _abow, _mwai,
   {{0x798206b0,0x78a205db,0x752d0172,0x37e40033}},	//   _bbow, _arov, _ogaz, নকার,
   {{0xa91d16ac,0x752d4958,0xed590995,0x60100149}},	//   leži, _ngaz, _bože_, nämn,
   {{0xb4be02e8,0xed590a39,0xdb1a02f1,0xe7ca007f}},	//   _इथे_, _vožd_, _lotè, िसंप,
   {{0x752d676a,0x7c2802ef,0x6604411f,0xdce933db}},	//   _agaz, _gidr, _skik, _ubeđ,
   {{0x2bac009d,0xd5e61107,0x78a201c0,0x7d090085}},	//   चारा, ежни, _erov, _hyes,
   {{0x20010044,0x58d5385a,0x644d06b0,0xaa642503}},	//   hohi_, _поет, _bwai, _штук,
   {{0x61e431e8,0xdb08022b,0x78a2676b,0x69c9676c}},	//   viil, _andè, _grov, mkee,
   {{0x6e2902dc,0x69c9676d,0x799903e3,0xa91d0480}},	//   _lieb, lkee, _haww, ježi,
   {{0x61e41cbf,0x386d0257,0x78a200b6,0x7d0906b0}},	//   tiil, luer_, _zrov, _lyes,
   {{0x3f98676e,0x6e2900a5,0xaca30065,0x799b676f}},	//   _saru_, _nieb, _ayọn, nduw,
   {{0x61e4002d,0x644d02ad,0x7d096770,0xe0da013d}},	// [62a0] riil, _gwai, _nyes, чва_,
   {{0x61e46771,0x60d60067,0xe47b00a1,0x447b0089}},	//   siil, rzym, _צריכ, _צניע,
   {{0xf1bf0028,0x61e4002d,0x44320019,0x3f9801d3}},	//   _giáo_, piil, _huy_, _varu_,
   {{0x6e2900a5,0x3f982253,0xa2b5030b,0x7d090361}},	//   _cieb, _waru_, _उपत्, _byes,
   {{0xdca30cfc,0x63be042d,0xdb086772,0x3f986773}},	//   лаци, _kopn, _indé, _taru_,
   {{0x44320eb8,0xdb1a001f,0x7d0951fa,0x69c96774}},	//   _muy_, _hoté, _dyes, ekee,
   {{0x7c285cd8,0x78a26775,0x44326776,0x6e294c2f}},	//   _vidr, _srov, _luy_, _fieb,
   {{0x69c91044,0x799b0124,0x68ed6777,0x386d4bcb}},	//   gkee, gduw, _žada, fuer_,
   {{0x386d15c9,0x79996778,0x3b861628,0xdb1a0131}},	//   guer_, _daww, _плаг, _moté,
   {{0xdb1a6779,0x00000000,0x00000000,0x00000000}},	//   _loté, --, --, --,
   {{0x644d677a,0x7999677b,0x69c90188,0xa5f90581}},	//   _swai, _faww, bkee, дену_,
   {{0x78a2677c,0x443200a1,0xdce00092,0x386d677d}},	//   _trov, _buy_, _hamı, buer_,
   {{0xb4cb0067,0x94a8344d,0xc4580084,0x4432677e}},	//   लने_, нтра_, ниях_, _cuy_,
   {{0x7bca0691,0x44320019,0x26c500b6,0xdb1a5c16}},	//   nkfu, _duy_, bylo_, _potè,
   {{0xd6cf677f,0x4432171d,0xa91d6780,0xdb1a03a9}},	//   _ст_, _euy_, veži, _boté,
   {{0x6b9a01d3,0x9b1700ca,0x752d6781,0xdb1a020d}},	//   _latg, תחלה_, _ugaz, _coté,
   {{0x765a01b3,0x644d21dc,0x6e296782,0x443200ca}},	// [62b0] lsty, _uwai, _rieb, _guy_,
   {{0x7c2f04ea,0x6e296783,0x69c901e9,0x201801b9}},	//   _écri, _sieb, zkee, _chri_,
   {{0x765a6784,0xa91d31cd,0x6e2901d3,0x69c90313}},	//   nsty, reži, _pieb, ykee,
   {{0x24890134,0x41a51e9f,0x7d096785,0x765a6786}},	//   _kpam_, _ऑफिस, _pyes, isty,
   {{0xeb991e13,0x24890063,0x69c901fa,0x79990090}},	//   дил_, _jpam_, vkee, _raww,
   {{0xf1bf0019,0x765a6787,0x79996788,0x6e290acb}},	//   _hoá_, ksty, _saww, _wieb,
   {{0x6b9a02ad,0x386d0113,0xc33400ca,0xa3e9034c}},	//   _datg, wuer_, נוק_, _मगन_,
   {{0x765a0d00,0x386d020d,0x7999003d,0xceb20327}},	//   dsty, tuer_, _qaww, _דיל_,
   {{0x69c92ddf,0x2489022e,0x7d096789,0xed5905db}},	//   rkee, _npam_, _uyes, _tožb_,
   {{0xf3ff0396,0x2d8f678a,0x69c92fa2,0x765a0313}},	//   drão_, lege_, skee, fsty,
   {{0x44320019,0x24890063,0x63be109b,0x4975678b}},	//   _suy_, _apam_, _ropn, _алес,
   {{0x4432678c,0x2d9d5502,0x89370037,0xf3ff0131}},	//   _puy_, ndwe_, _أعضا, frão_,
   {{0x386d678d,0x44320028,0x88c4001c,0xf3ff016d}},	//   quer_, _quy_, _متول, grão_,
   {{0xd7052723,0xf1bf037a,0x765a678e,0x2d8f3b1e}},	//   _изли, _diám_, bsty, hege_,
   {{0x63be01cd,0xf3ff0231,0x00000000,0x00000000}},	//   _vopn, arão_, --, --,
   {{0x44320028,0xa3be0789,0x01630fe3,0x2d8f03a9}},	//   _tuy_, _आवक_, иксо, jege_,
   {{0xf1bf0019,0x63be678f,0x31722414,0x2d8f0193}},	// [62c0] _giám_, _topn, rgyz_, dege_,
   {{0x64466790,0xe0df009c,0x00000000,0x00000000}},	//   mpki, _reòt_, --, --,
   {{0x6b9a01bf,0x661600b6,0x324630c0,0xdb1a00d2}},	//   _ratg, ůzku, _шенг, _toté,
   {{0x8c4636c9,0x6b9a0449,0xa91d033b,0xdb080328}},	//   веде, _satg, ležu, _undé,
   {{0xdf7400cd,0x2c0e0096,0x6b9a3195,0xe0d7002d}},	//   _مگاب, ितलं_, _patg, _авя_,
   {{0x765a6791,0x64460138,0x2018007b,0x6b9a009e}},	//   ysty, ipki, _uhri_, _qatg,
   {{0x6b9a00de,0xafe30d62,0xa50f09c4,0xb50f142e}},	//   _vatg, _торл, _सर्च_, _सर्प_,
   {{0xa2b50a30,0xf1bf0023,0x765a29d2,0x64460113}},	//   _उपस्, _xoá_, vsty, kpki,
   {{0x0c263e1c,0x3e7c6792,0xd7fa3bbc,0x00000000}},	//   _аман, lít_, дун_, --,
   {{0x765a351f,0x76b80012,0xf3ff0131,0x00000000}},	//   tsty, елор_, vrão_, --,
   {{0xdb01052f,0x765a02e3,0x6ae00033,0xa01b0212}},	//   _anlæ, usty, _পুরো, _spök,
   {{0x25ad0072,0x25bf01ab,0xd9462549,0xf3ff016d}},	//   ñel_, ðul_, _реди, trão_,
   {{0x765a0429,0xed590433,0xe0df01b5,0x66cb01f9}},	//   ssty, _joža_, _leòr_, tökö,
   {{0xf3ff0161,0x7c2f0036,0xed59033b,0x765a2c94}},	//   rrão_, _ècre, _moža_, psty,
   {{0xf2c423a3,0x3e7c000d,0x59b604f8,0xf1bf016d}},	//   астн, jít_, _आचार, _poá_,
   {{0xa3cf0592,0x2ba46793,0x00000000,0x00000000}},	//   _शतक_, _गोसा, --, --,
   {{0x21f703e5,0x24890087,0x2246007e,0x2d8f6794}},	// [62d0] għha_, _upam_, _čoke_, vege_,
   {{0xceeb212c,0x2d8f6795,0x645d0324,0xcaf20714}},	//   وران_, wege_, mssi, _अखंड_,
   {{0x2d8f6796,0x69dc013f,0xc332040a,0xa3d002d5}},	//   tege_, _įren, _לוי_, वघर_,
   {{0xe81902d5,0xdb080034,0xed590141,0x00000000}},	//   _नीना_, _lodó, _boža_, --,
   {{0x645d0084,0x50f42917,0x2d8f6797,0x2ba4009f}},	//   nssi, _взят, rege_, _गोहा,
   {{0x2d8f6798,0x645d6799,0x3e7c02c6,0x00000000}},	//   sege_, issi, bít_, --,
   {{0x2d8f0ac1,0x00000000,0x00000000,0x00000000}},	//   pege_, --, --, --,
   {{0xfaa6001c,0xdb1a00da,0x00000000,0x00000000}},	//   اجوی, _altó, --, --,
   {{0x6d59679a,0x7d041e3b,0x6ce7004d,0x00000000}},	//   mawa, üist, _ріве, --,
   {{0x6d59580a,0xdb08002b,0x645d32e1,0x279500d3}},	//   lawa, _codó, dssi, ушир,
   {{0x645d679b,0xdb010161,0x7f55167e,0x64b4013c}},	//   essi, _colô, _mezq, _məiş,
   {{0x6d59679c,0x04461166,0xb17b05e8,0x6010679d}},	//   nawa, лемн, _smån, vämm,
   {{0x7bc100dc,0x9879006e,0xaca40174,0xa879006e}},	//   _kolu, _נאַט, vaịs, _נאַר,
   {{0x6d59679e,0xadc300de,0x387f023b,0x6010679f}},	//   hawa, _khẳn, mtur_, tämm,
   {{0x35a60036,0x6d5967a0,0x7bc167a1,0x29c3058a}},	//   _байг, kawa, _molu, _uñas_,
   {{0xdb011424,0x6d5967a2,0xa2b50557,0x7bc167a3}},	//   _inlä, jawa, _उपर्, _lolu,
   {{0x6d5967a4,0xa06714cc,0x64a667a5,0x26011ae6}},	// [62e0] dawa, лата_, _сапа, रवरी_,
   {{0x660667a6,0x7bc10adf,0x76430085,0xa4b70796}},	//   lokk, _nolu, _ktny, _עליה_,
   {{0x25b700cd,0x6da64e08,0x6d590022,0xdb080139}},	//   _شهید_, лижа, fawa, _lodò,
   {{0x6d5967a7,0x660667a8,0x5bbe0bba,0x2bbe08c0}},	//   gawa, nokk, ्स्व, ्स्थ,
   {{0x7bc167a9,0x387f01e5,0xa3b8045f,0x3e7c0103}},	//   _bolu, jtur_, छाप_, sít_,
   {{0xafe667aa,0x7bc167ab,0x660667ac,0x3c39022b}},	//   _согл, _colu, hokk, _dèv_,
   {{0xadc30019,0x660667ad,0x656467ae,0x7bc167af}},	//   _chẳn, kokk, _odih, _dolu,
   {{0x656401e5,0x6444010a,0x6d5943b5,0x387f01cd}},	//   _ndih, _otii, cawa, ftur_,
   {{0xdca3091c,0xdb010003,0x7643005c,0xbb46164d}},	//   _лати, _anlä, _atny, _безк,
   {{0xa09700c1,0xdb014c7d,0x807b006e,0xa91d00c6}},	//   נדיק_, _polô, עניצ, vežt,
   {{0xe5b51119,0x387f2a52,0x96f852c3,0x3c3902f1}},	//   айны, atur_, тент_, _zèv_,
   {{0xd6d72082,0x645d42f0,0x7bc1063d,0xd5af0179}},	//   уть_, tssi, _zolu, टाइज,
   {{0x7bc167b0,0xb4c10455,0xdb1a37b9,0x656400eb}},	//   _yolu, ूने_, _motí, _ddih,
   {{0x6d5967b1,0x645d322d,0x6444009c,0x00000000}},	//   zawa, rssi, _dtii, --,
   {{0x6d5967b2,0x45d54ea4,0xcb3700a1,0x6d4b008a}},	//   yawa, _войс, ראלי_, ybga,
   {{0xdb1a67b3,0x660667b4,0x29d80037,0x645d43c6}},	//   _notí, cokk, _déag_, pssi,
   {{0x6e3504a3,0x9f5504d2,0xdb0102c3,0x9099028d}},	// [62f0] _suzb, ивач, _inlå, ъват_,
   {{0xdefb0d64,0x6d5967b5,0x6aa83696,0x2ba40fdd}},	//   ные_, wawa, _ordf, _गोला,
   {{0x6d5967b6,0x7bc167b7,0xdb1a167e,0x9315001c}},	//   tawa, _rolu, _botí, _خودش,
   {{0x6e2267b8,0x387f67b9,0xdb1a002b,0x00000000}},	//   gmob, ytur_, _cotí, --,
   {{0x6d593aa6,0x7bc10335,0x6aa800da,0xe7b50285}},	//   rawa, _polu, _ardf, _अचलप,
   {{0x6d59113a,0x6e35015c,0x8f34141b,0xadc30023}},	//   sawa, _tuzb, _герц, _phẳn,
   {{0x6d595dbf,0x69c20113,0xdb1a00d4,0xdb0805aa}},	//   pawa, _booe, _fotí, _sodò,
   {{0x387f67ba,0xc9a90747,0x7bc167bb,0xdb1a0131}},	//   ttur_, твие_, _wolu, _botâ,
   {{0xa9220465,0x7bc167bc,0x6606007b,0x00000000}},	//   одъл, _tolu, vokk, --,
   {{0x387f2085,0xadc30019,0xed590087,0xb17b057e}},	//   rtur_, _thẳn, _kožo_, _smål,
   {{0x387f0102,0x644467bd,0x85300044,0x660667be}},	//   stur_, _stii, _haɗi, tokk,
   {{0xa2c41006,0x29d80037,0x7d16007f,0x00000000}},	//   रहस्, _céad_, żyse, --,
   {{0x660667bf,0x893454c8,0x394d67c0,0x65640117}},	//   rokk, _اعما, mbes_, _vdih,
   {{0x394d67c1,0xb6a502ec,0x69c20154,0xe73608f9}},	//   lbes_, _викл, _zooe, _кеш_,
   {{0x76430ec9,0x3f930094,0x00000000,0x00000000}},	//   _utny, dexu_, --, --,
   {{0xb1460f2e,0x386d0257,0x27e700f9,0xa5bb0042}},	//   рнал, orer_, _hmnn_, lmón,
   {{0xaca40294,0x644467c2,0x3fe65c37,0x386d2222}},	// [6300] _kwụp, _utii, ажав, nrer_,
   {{0x823600bf,0x25a01064,0xb4c2009d,0x853001c2}},	//   _پردا, _hail_, ंही_, _naɗi,
   {{0x386d02e2,0xed5a67c3,0x25a067c4,0xdb1a00b6}},	//   hrer_, вое_, _kail_, _potí,
   {{0x386d038c,0x61e667c5,0x225e0094,0x7bc567c6}},	//   krer_, _umkl, átku_, öhun,
   {{0x25a0128b,0x386d02b6,0x61e167c7,0x2d9f01ff}},	//   _mail_, jrer_, ëlle, _daue_,
   {{0xaa6623e3,0x386d0856,0x7fd504a1,0x25a067c8}},	//   атик, drer_, _лісі, _lail_,
   {{0x15f8007d,0x160605d4,0x85300d2a,0x386d40d7}},	//   ीवार_, रवार_, _daɗi, erer_,
   {{0x386d001f,0x61f667c9,0x298a15a9,0x7e9b00ca}},	//   frer_, nnyl, тско_, _בסלו,
   {{0xb9c30080,0xdb1a0396,0x386d67ca,0x8c4367cb}},	//   تقيي, _botã, grer_, _мете,
   {{0x1ae6078b,0x3d1b0336,0x00000000,0x00000000}},	//   _козм, _बरते_, --, --,
   {{0x386d67cc,0x290f041c,0xb4c10efb,0x25a067cd}},	//   arer_, _eyga_, ून्_, _bail_,
   {{0x386d0990,0x29180092,0x25a001f7,0xe8ea00ae}},	//   brer_, əran_, _cail_, _имед_,
   {{0x25a067ce,0x2246007e,0x386d020d,0x00000000}},	//   _dail_, _čoka_, crer_, --,
   {{0x25a00124,0x00000000,0x00000000,0x00000000}},	//   _eail_, --, --, --,
   {{0x9f5e0174,0x29d80076,0x25a000d7,0x00000000}},	//   _ótù_, _téad_, _fail_, --,
   {{0xdce00154,0xed5905db,0x00000000,0x00000000}},	//   _admč, _rožo_, --, --,
   {{0x660d67cf,0x7a350138,0x3f9300d4,0x00000000}},	// [6310] _ikak, _ište, texu_, --,
   {{0x6ab667d0,0x539908cb,0x2ca60094,0x33754033}},	//   _अपूर, _своя_, dvod_, _угор,
   {{0x853003e3,0x660d010a,0x394d00c6,0xa19537f2}},	//   _raɗi, _kkak, ybes_, _ланч,
   {{0x237f02e6,0xf2d200c1,0x386d00f3,0x26de01ff}},	//   đuju_, _זעט_, yrer_, izto_,
   {{0x61ed00c2,0x660d0051,0xdca50095,0x9b450037}},	//   mial, _mkak, сали, منشو,
   {{0x8234037f,0x386d00fd,0xf778003d,0xdb1a015e}},	//   _دریا, vrer_, jgħ_, _botà,
   {{0x7a3500e9,0xf21c000f,0x60cd67d1,0xdcfb00e9}},	//   _ošte, _भीड़_, lyam, _obuć,
   {{0xadc30019,0x82f800a1,0x386d67d2,0x660d67d3}},	//   _thằn, יצוב_, trer_, _nkak,
   {{0x60cd1a0f,0xe73905b8,0x394d67d4,0x386d67d5}},	//   nyam, леп_, rbes_, urer_,
   {{0x386d25a5,0x660d2b7f,0x61ed67d6,0x60100084}},	//   rrer_, _akak, hial, tämi,
   {{0x61ed67d7,0xa5bb67d8,0xe5a600d3,0x60cd02a4}},	//   kial, rmón, бини, hyam,
   {{0x60cd0517,0xed5900b6,0xafdb004d,0x601067d9}},	//   kyam, _jež_, _støl, rämi,
   {{0x61ed67da,0x60cd0193,0xb4c2074c,0x18690da5}},	//   dial, jyam, ंहे_, _сали_,
   {{0x43432e57,0x60cd40ab,0x660d1d61,0x69db0131}},	//   зерв, dyam, _ekak, lhue,
   {{0xa3e90abe,0x216a0476,0x4df75660,0x25a000d7}},	//   _मगर_, ливи_, ंचाई_, _tail_,
   {{0xed59033a,0xa22a3967,0x61ed67db,0x463a00c1}},	//   _než_, ужба_, gial, _געקע,
   {{0xe3b20dd0,0xc2e60033,0x637d0139,0x60cd67dc}},	// [6320] _فرد_, _খুশি_, _kàǹ, gyam,
   {{0x637d0139,0x00000000,0x00000000,0x00000000}},	//   _jàǹ, --, --, --,
   {{0x61ed67dd,0xed590d5d,0x7d1b0350,0x60cd06b0}},	//   bial, _bež_, _azus, ayam,
   {{0x629e02e6,0xed5a0037,0x60cd149c,0x2619014b}},	//   _ispo, اشات_, byam, héon_,
   {{0xed5925d1,0x69db0052,0x78ad007e,0x629e0131}},	//   _dež_, dhue, _šavn, _hspo,
   {{0x50431e33,0x78bb0072,0x69db0131,0xe58c02c6}},	//   _херб, dxuv, ehue, jížď,
   {{0xdb1a67de,0x6da64070,0x2ca64651,0x7d1b67df}},	//   _botá, _лива, svod_, _ezus,
   {{0x85300022,0x26cc00c6,0x00000000,0x00000000}},	//   _haɗu, vydo_, --, --,
   {{0x637d0139,0x853001c2,0xdb1a67e0,0xb17b1842}},	//   _bàǹ, _kaɗu, _dotá, _småk,
   {{0x61ed67e1,0x660d0665,0x629e04a3,0x6d42044c}},	//   zial, _skak, _ospo, lcoa,
   {{0xadc30023,0x37a7004b,0x59860138,0x00000000}},	//   _chặn, стын_, _глеб, --,
   {{0xca3700f5,0x69db0850,0x89a50076,0x00000000}},	//   _הנאה_, chue, _وإنم, --,
   {{0x629e67e2,0x7a3567e3,0x6d4201ff,0x261903a9}},	//   _aspo, _všte, icoa, béon_,
   {{0x07a3163d,0x69c00b18,0x645600f0,0x61ed007f}},	//   _начн, ljme, _dwyi, wial,
   {{0x61ed67e4,0xd7f800d3,0x98a4026a,0xd9ec0096}},	//   tial, mnă_, mamı_, _जगात_,
   {{0x7a35084f,0x60cd67e5,0x98a40511,0x660d08cc}},	//   _ušte, tyam, lamı_, _ukak,
   {{0x629e67e6,0xa2b5009d,0x35f809b4,0xdb010231}},	// [6330] _espo, _उपक्, _درود_, _calê,
   {{0x61ed67e7,0x60cd02a4,0xdb1f0103,0x2fd8033c}},	//   sial, ryam, űvés, _clrg_,
   {{0x61ed1d4c,0x3d3e0134,0x6e99256d,0x00000000}},	//   pial, _ịwa_, рвер_, --,
   {{0x443b023b,0x443367e8,0xdb0120df,0xd7f8020a}},	//   _kuq_, _hix_, _falê, hnă_,
   {{0x85300022,0x61fd029a,0xdb1a3f96,0x443301ee}},	//   _faɗu, _ijsl, _rotá, _kix_,
   {{0x78ad0995,0xaa49001f,0xb17b032e,0xf09f0065}},	//   _šavo, апка_, _småh, _isà_,
   {{0xdb1a1ad9,0x41e00442,0x442167e9,0x443300ca}},	//   _potá, _नतमस, _mhh_, _mix_,
   {{0x49c9490c,0x3cff023e,0x443367ea,0x3eae02b6}},	//   рлин_, _txuv_, _lix_, æfte_,
   {{0xf77100ab,0x69db00b3,0xc7950ab3,0x7d1b0239}},	//   واد_, rhue, орны, _uzus,
   {{0x443301bf,0x166500a9,0xf1bf0037,0x69db0052}},	//   _nix_, овом, _fhág_, shue,
   {{0x7c3b5542,0x6d5b1f12,0xdb1a2f31,0xdb010052}},	//   _huur, _keua, _totá, _malë,
   {{0x8c3d01e8,0xd7f800d3,0x7c3b67eb,0x443367ec}},	//   _arşi, ană_, _kuur, _aix_,
   {{0x7c3b13e3,0x395f67ed,0x4433009e,0xdffb277c}},	//   _juur, maus_, _bix_, ्वाद_,
   {{0x395f67ee,0x7c3b67ef,0xa3e40034,0x98b2007f}},	//   laus_, _muur, पों_, _żyć_,
   {{0x44330257,0xf09f0065,0x232a1b4d,0x66df0065}},	//   _dix_, _asà_, рови_, _dáké,
   {{0x443b2751,0x6d5b67f0,0x395f67f1,0x443305fe}},	//   _fuq_, _neua, naus_, _eix_,
   {{0xdfd267f2,0x629e00a5,0x7c3b0188,0x4fea0905}},	// [6340] وير_, _wspo, _nuur, аман_,
   {{0x395f67f3,0x6e3b0580,0x69d9010a,0xdb010131}},	//   haus_, _čubr, _llwe, _valê,
   {{0x35af417a,0x69d95784,0x2d8d0113,0x2ba40442}},	//   _जोड़, _olwe, _bbee_, _गोगा,
   {{0x7c3b2851,0x395f022c,0x2cad2ca7,0xbc4a0284}},	//   _buur, jaus_, _bred_, ачке_,
   {{0x2cad002d,0xdb01023b,0x395f0138,0x6d5b0178}},	//   _cred_, _falë, daus_, _deua,
   {{0x443367f4,0xe0fb00a1,0x7c3b67f5,0x2d8d0134}},	//   _xix_, _כלכל, _duur, _ebee_,
   {{0x98a4008e,0x291d0063,0x7c2101b9,0x8e834070}},	//   vamı_, _azwa_, _dhlr, _огре,
   {{0x395f013f,0x2246033b,0x2d8d0139,0x6e3c67f6}},	//   gaus_, _čokl_, _gbee_, _iurb,
   {{0x7c3b0694,0x2cad67f7,0x6e3c0a00,0x61410018}},	//   _guur, _gred_, _hurb, _háló,
   {{0x6e3c67f8,0xd7f800d3,0xa5bb0165,0xd7f706c4}},	//   _kurb, ună_, rmóm, жую_,
   {{0x21270019,0x443b03e5,0x443300bd,0xd7f800d3}},	//   ̀nh_, _suq_, _rix_, rnă_,
   {{0x395f67f9,0x6e3c67fa,0x443367fb,0x7bc831f2}},	//   caus_, _murb, _six_, _hodu,
   {{0x7bc80006,0x6fda0096,0xe3b32ce3,0x7a350138}},	//   _kodu, णसां, ورس_, _išta,
   {{0xdb0167fc,0x00000000,0x00000000,0x00000000}},	//   _balè, --, --, --,
   {{0x38661a08,0x31600167,0x9f84003e,0xdb013d56}},	//   _hvor_, faiz_, _röð_, _calè,
   {{0xdb010139,0x39440072,0x7bc867fd,0xd6db00d7}},	//   _dalè, ncms_, _lodu, _כחול,
   {{0x7f5c02a1,0xdb01023b,0x4433008c,0x7bda160b}},	// [6350] _berq, _palë, _tix_, _oltu,
   {{0x6e3c67fe,0x7bc867ff,0x7658023e,0x7f5c5a95}},	//   _burb, _nodu, _kwvy, _cerq,
   {{0x7c3b6800,0x2cad0335,0x7a3509ac,0x6e3c6801}},	//   _suur, _sred_, _ošta, _curb,
   {{0x2cad3f64,0x6e3c6802,0x7c3b6803,0xee3804a1}},	//   _pred_, _durb, _puur, іні_,
   {{0x2fc700ef,0x63a501af,0x395f0ab3,0x26f60034}},	//   ưng_, _kahn, vaus_, ँपुर_,
   {{0xfaa56804,0x7bc8002d,0x7c3b0305,0x6e3c4f43}},	//   зако, _codu, _vuur, _furb,
   {{0x7bc804a3,0x6e3c6805,0x63a56806,0xdb016807}},	//   _dodu, _gurb, _mahn, _kalé,
   {{0x7c3b189e,0x7e650052,0x08c500ae,0x2cad6808}},	//   _tuur, mshp, збин, _tred_,
   {{0xb4ea009d,0x395f6809,0x2cad0ea3,0xdb014849}},	//   _मधे_, raus_, _ured_, _malé,
   {{0x395f03a0,0x7afc033b,0x386602c8,0xdb010113}},	//   saus_, _žrte, _dvor_, _lalé,
   {{0x395f00c2,0xe5a6680a,0x02ba4080,0x394600eb}},	//   paus_, пини, _उपेन, _ffos_,
   {{0xe8df0294,0xdb0102c6,0xed5905db,0x69d90415}},	//   nrịa_, _nalé, _boži_, _ulwe,
   {{0x63a5680b,0xb9c40037,0x993a0327,0x6285039f}},	//   _bahn, _تقني, _התנה, _aqho,
   {{0xc87903a3,0xe1ff0139,0x63a50428,0x62850131}},	//   muş_, _ajó_, _cahn, _bqho,
   {{0xc879680c,0x8c1a00ca,0xe1ff01cd,0xdb013d56}},	//   luş_, מושי, _bjó_, _balé,
   {{0xdb013435,0xdddc0580,0x2b8f0233,0xb46600d3}},	//   _valè, _sprž, lıcı_, _екил,
   {{0x7f5c0990,0x9103028d,0x395d5202,0xdb01680d}},	// [6360] _perq, епте, _mews_, _dalé,
   {{0x2b8f01e8,0xe1ff0065,0x395d01b9,0xdb0103a9}},	//   nıcı_, _ejó_, _lews_, _talè,
   {{0x6e3c680e,0x6146021c,0xe35700f5,0x7f5c680f}},	//   _qurb, _нена, _משיח_, _verq,
   {{0x395d6810,0xdb0119a3,0x63a53d11,0x568c00c1}},	//   _news_, _galé, _zahn, שטאַ,
   {{0x7bc86811,0xc1730054,0xa11600cd,0x6036022b}},	//   _podu, _אחר_, _روست, _fņma,
   {{0x6e3c6812,0x9f4a03a9,0x00000000,0x00000000}},	//   _turb, _ombé_, --, --,
   {{0x80d100c7,0x29d80080,0x395d0090,0x2b8f013c}},	//   _সেপ্, _déan_, _bews_, dıcı_,
   {{0x6da30b99,0x3f9a00a5,0xada301b3,0x7bc86813}},	//   _писа, lepu_, _пасл, _wodu,
   {{0x290200dd,0xeb36001c,0xcb6a1b77,0x00000000}},	//   çka_, _فراخ, _газе_, --,
   {{0xf1bf00ef,0xfaa614da,0x7bda6814,0x3b8311c0}},	//   _khác_, _назо, _ultu, _плуг,
   {{0xf11905d4,0xadf3034d,0x63a56815,0x98b80342}},	//   _दर्द_, _आगमन_, _rahn, ğrı_,
   {{0x63a50eef,0x26c20335,0x7c2a0795,0x00000000}},	//   _sahn, ćko_, lmfr, --,
   {{0x80d10081,0x7df500c6,0x63a51abe,0x657d0324}},	//   _সেন্, mąst, _pahn, rgsh,
   {{0x3f9a0268,0xdb016816,0x78a26817,0xa9230094}},	//   jepu_, _salé, _isov, ážem,
   {{0x764a0120,0x61e10052,0xdb016818,0x7a0100e8}},	//   _utfy, ëllo, _palé, lēta,
   {{0xc2c40037,0x067b0796,0x63a50364,0xed590117}},	//   ريقي, _הנהל, _wahn, _toži_,
   {{0x628703e5,0x63a56819,0x7a0101d3,0xdb01681a}},	// [6370] stjo, _tahn, nēta, _valé,
   {{0x660f0ec6,0x30142b94,0xe9e200a5,0x644d4543}},	//   lock, едур, leźć_, _itai,
   {{0x3a3e061d,0x1d4a0294,0xdb010113,0x7f4502db}},	//   _nutp_, _ịdịm, _talé, rchq,
   {{0xfe70012b,0x78a20335,0xf1bf00de,0x660f305d}},	//   ادل_, _osov, _giáp_, nock,
   {{0x0db800e3,0x2b8f008b,0x656d0a4b,0x29d80154}},	//   ثالث_, yıcı_, _mdah, _péan_,
   {{0x660f227a,0xb17b0b97,0xc8790555,0x644d0d0a}},	//   hock, _blåg, vuş_, _mtai,
   {{0x2b5e0124,0x660f681b,0x78a20095,0xf41f007b}},	//   _detc_, kock, _asov, ytän_,
   {{0x656d681c,0x60100853,0xfaf01f11,0xd2b80327}},	//   _ndah, lämp, دثه_, ללות_,
   {{0x644d022e,0x2b8f564a,0xc8c9001c,0x37751402}},	//   _ntai, tıcı_, زودن_, мынс,
   {{0x79820d2a,0x656d681d,0xc879681e,0x6b810027}},	//   _ecow, _adah, ruş_, _uclg,
   {{0x9f84007a,0x38ca00cd,0x66e54daa,0x2b8f0491}},	//   _töö_, مایی_, фона, rıcı_,
   {{0xb8f30033,0x00000000,0x00000000,0x00000000}},	//   _হই_, --, --, --,
   {{0x6010681f,0x7a0101d3,0x656d02a1,0x799b024a}},	//   kämp, cēta, _ddah, meuw,
   {{0xe7871681,0x69cb2807,0x644d0037,0xdb18003e}},	//   _худо, _hoge, _dtai, rkvö,
   {{0x69cb6820,0x644d0257,0x60100e74,0xd2520401}},	//   _koge, _etai, dämp, ئنر_,
   {{0xed590995,0x3f9a0239,0xe45f00c2,0x644d01ec}},	//   _kožu_, wepu_, työt_, _ftai,
   {{0x69cb533f,0x3eb101bf,0x20070087,0xdce9009e}},	// [6380] _moge, _arzt_, čnin_, _ddeċ,
   {{0x24970979,0x69cb6821,0xb17b6822,0xf1bf00fe}},	//   _کنید_, _loge, _småt, _phác_,
   {{0x29d800e3,0x7a0101d3,0x0d8600c2,0x3f9a0095}},	//   _béal_, zēta, длен, repu_,
   {{0x69cb08dc,0xdc480294,0x00000000,0x00000000}},	//   _noge, _aṅụ_, --, --,
   {{0xdca3336f,0x8c431011,0x9588013f,0xac0a43c7}},	//   каци, вече, _grąž, онда_,
   {{0xdb086823,0xa91d013f,0xafdb038c,0xf1bf00de}},	//   _indú, igžd, _støv, _thác_,
   {{0x69cb6824,0xb17b0537,0x160006ec,0x00000000}},	//   _boge, _flåd, ोकार_, --,
   {{0x78a204eb,0x69cb6825,0xdb1a0031,0xdde90286}},	//   _psov, _coge, _kotú, _فرقه_,
   {{0x7a356826,0xfcaa0281,0x00000000,0x00000000}},	//   _ešto, _بازو_, --, --,
   {{0x6d440181,0xb8e619af,0x291800d9,0x7a0100d9}},	//   žiad, _उप_, āra_, rēta,
   {{0x644d6827,0x69cb6828,0x6a830231,0xa5bb016d}},	//   _stai, _foge, _алха, imóv,
   {{0x69cb6829,0xafdb004d,0xa2cd0167,0x28db014e}},	//   _goge, _utøv, सहस्, यनशि,
   {{0x3a260222,0x443f0028,0xb8f30033,0xd94341c0}},	//   _ihop_, êu_, _হে_, _речи,
   {{0x69cb682a,0x660f682b,0xacd9006e,0x00000000}},	//   _zoge, sock, פֿרי, --,
   {{0x69cb682c,0xa195004d,0x26070859,0xdb08682d}},	//   _yoge, навч, _очиг, _andú,
   {{0x656d0fbd,0xdb1a0076,0x00000000,0x00000000}},	//   _udah, _botú, --, --,
   {{0x92c100c7,0x644d0239,0xb17b682e,0x29d838df}},	// [6390] ্ছে_, _utai, _smås, _réal_,
   {{0x25a901a2,0x7a2511e9,0x00000000,0x00000000}},	//   _haal_, móte, --, --,
   {{0x25a926a9,0xf3ff016d,0xd35600ca,0xaca40174}},	//   _kaal_, lsão_, _איתי_, bsịt,
   {{0x201a028d,0x41d30096,0xc05b004d,0x2d5800ae}},	//   alpi_, _सविस, _міг_, диць_,
   {{0xf3ff0396,0x25a9682f,0x644b014b,0xe81100b6}},	//   nsão_, _maal_, _égid, ठकमा_,
   {{0x7afc04a3,0x69cb6830,0x6a855fa3,0x8b254447}},	//   _žrta, _soge, елка, ндле,
   {{0xb606033d,0x41d300aa,0x160f00c3,0x799b024a}},	//   _hláš, _सवास, सवार_, teuw,
   {{0xb6060146,0xdbcc0139,0xb17b0537,0x00000000}},	//   _kláš, _bóól, _flåe, --,
   {{0xe8f91c00,0x69cb6831,0x2d9d3223,0x799b0178}},	//   яли_, _voge, mewe_, reuw,
   {{0xeb900391,0x2d9d6832,0x69cb6833,0x612a01f9}},	//   _نظم_, lewe_, _woge, lölé,
   {{0x25a96834,0x69cb4bf9,0x7ac4203c,0x7a3500c4}},	//   _baal_, _toge, _исце, _ušto,
   {{0x2d9d0193,0xa95400d6,0xa50a171b,0x25a9041c}},	//   newe_, _акці, зема_, _caal_,
   {{0x67d51087,0xdb060018,0x25a96835,0xdb016836}},	//   _поду, ümöl, _daal_, _malí,
   {{0xdb0103be,0xbf1f0096,0x8afe01c2,0xa91d00c6}},	//   _lalí, _भरून_, laƙa, rgžd,
   {{0xb7da00ca,0xcb1200c1,0x41b60f21,0x25a96837}},	//   _מקסי, ָלן_, нсат, _faal_,
   {{0x25a96838,0x67236839,0xb17b20ab,0x2d9d0027}},	//   _gaal_, _iznj, _smår, jewe_,
   {{0x34b300e3,0x65660060,0x66040129,0x69c0009d}},	// [63a0] _مميز, makh, _ijik, वाती,
   {{0x7524683a,0x25a901c0,0x65660620,0x8afe03e3}},	//   _iziz, _zaal_, lakh, haƙa,
   {{0x24460028,0xee3a3277,0xdb01025b,0xb17b052f}},	//   _hôm_, чне_, _balí, _slåe,
   {{0xafdb0939,0xdb010072,0x6566683b,0x200306b0}},	//   _støt, _calí, nakh, _ejji_,
   {{0x443a683c,0xf1bf0019,0x61f6026a,0x8afe03e3}},	//   _kip_, _khán_, miyl, daƙa,
   {{0x3a2606e5,0x443a683d,0xfaa644b2,0x75240a4b}},	//   _shop_, _jip_, ешин, _mziz,
   {{0xed5a08c3,0x2d963ba4,0xdbcc0065,0x65660201}},	//   _нов_, _прас, _bóòl, kakh,
   {{0x61f6683e,0xdb010428,0xf1e00789,0x69c00c3c}},	//   niyl, _galí, नसिन, वाधी,
   {{0x7e7e294c,0x65660899,0x75243834,0x60c4002b}},	//   lupp, dakh, _nziz, nxim,
   {{0x443a683f,0x66040af0,0x25a96840,0xa5bb6841}},	//   _nip_, _ajik, _saal_, ológ,
   {{0x75246842,0xd6d725a7,0x61e46843,0x7e7e30c1}},	//   _aziz, етя_, khil, nupp,
   {{0x7c3a0b27,0x65660201,0xdbcc0065,0x48e60e3a}},	//   _hitr, gakh, _góòl, _поев,
   {{0x61e46844,0x99e90018,0x66e60103,0x6604007e}},	//   dhil, _تعلق_, _béké, _djik,
   {{0xf8b30105,0xf3ff0396,0x443a2af5,0x660400ac}},	//   _תשס_, rsão_, _cip_, _ejik,
   {{0xf3ff00c9,0x25a91f49,0xdce902dd,0x65660201}},	//   ssão_, _taal_, _rdeč, bakh,
   {{0x7c3a6845,0x61e46846,0xda100abe,0x7a2518c8}},	//   _litr, ghil, ावित_, póte,
   {{0x20981ad1,0x70bb007f,0x2489014b,0x85740fe9}},	// [63b0] нкты_, ईमेल, _uqam_, _слых,
   {{0x7c3a6847,0x251c0130,0x661d24a3,0x443a6848}},	//   _nitr, _צוזא, llsk, _gip_,
   {{0x2d9d0193,0x61e40201,0x63ad01d3,0x61f6020e}},	//   tewe_, bhil, ļinā, biyl,
   {{0x61e401c0,0x7c3a6849,0xdb1a684a,0x443a0133}},	//   chil, _aitr, _intè, _zip_,
   {{0xdca5684b,0x2d9d684c,0xdb010143,0xdb0302c6}},	//   тали, rewe_, _valí, rdní,
   {{0x65660201,0x443a0428,0xeb960aec,0x7c28009c}},	//   zakh, _xip_, виш_, _chdr,
   {{0x7c3a684d,0x9ad30134,0xed59033b,0x2fc70088}},	//   _ditr, _bịak, _anže_, öngu_,
   {{0x7c3a3feb,0x00000000,0x00000000,0x00000000}},	//   _eitr, --, --, --,
   {{0x7c3a31c7,0xdb010161,0x6d590453,0x6d440220}},	//   _fitr, _balã, mbwa, žiac,
   {{0x7c3a019c,0xdb010161,0x7d09039f,0x65660201}},	//   _gitr, _calã, _ixes, wakh,
   {{0x65660da3,0xba74110a,0x443a684e,0x6e3b684f}},	//   takh, _مانت, _rip_, _kiub,
   {{0x7d1b06b0,0xdd99022b,0x7c3a6850,0x75e6007f}},	//   _kyus, _akňz_, _zitr, _mózg,
   {{0x656603b4,0x60c40078,0xf1bf00de,0x3e410138}},	//   rakh, xxim, _phán_, _dėti_,
   {{0x65666851,0x6b836852,0xe819009f,0x387f28ac}},	//   sakh, ngng, _नीचा_, muur_,
   {{0x61e40060,0xf1bf0023,0x61f66853,0xdb0800b3}},	//   thil, _cháo_, tiyl, _cadè,
   {{0x244600de,0xdb080113,0x6e3b26ae,0x69c90643}},	//   _tôm_, _dadè, _niub, njee,
   {{0xa0676854,0x7d1b6855,0xdb1a0c56,0x76436856}},	// [63c0] ката_, _nyus, _entè, _huny,
   {{0x764334f0,0xafdb0170,0x61e46857,0x3fe36858}},	//   _kuny, _stør, shil, ажув,
   {{0x7c3a2fce,0x61e4067d,0x69db0084,0x7d1b0bb6}},	//   _ritr, phil, kkue, _ayus,
   {{0x6e296859,0x76430c50,0x973c01ac,0x7c3a685a}},	//   _cheb, _muny, meće, _sitr,
   {{0xdb1a685b,0xdd8f0e11,0x6e3b685c,0xf7671ac9}},	//   _inté, تون_, _diub, _پا_,
   {{0x6564685d,0x387f685e,0x57e00034,0xdb010032}},	//   _leih, duur_, _फतेह, _balà,
   {{0x628e685f,0xdb080113,0x7d09037a,0xdb0100b3}},	//   ntbo, _kadé, _exes, _calà,
   {{0x6e3b6860,0x7c3a00a5,0x225e025b,0xdb01001f}},	//   _giub, _witr, átky_, _salã,
   {{0x7c3a6861,0x8c462e57,0x6d406862,0x387f04e2}},	//   _titr, _резе, _igma, guur_,
   {{0x7c3a0a9f,0x69c9010a,0xdb08014b,0x628e0b6a}},	//   _uitr, ajee, _ladé, ktbo,
   {{0x973c04a3,0x9635036a,0x628e6863,0xdce901d3}},	//   jeće, лноц, jtbo, _ideā,
   {{0x76436864,0x973c0039,0x387f0188,0x7a250034}},	//   _duny, deće, buur_, rótc,
   {{0x661d0149,0x628e6165,0x76430167,0x64440113}},	//   rlsk, etbo, _euny, _cuii,
   {{0xdb014873,0xdb1a6865,0x201800ec,0xf1bf00de}},	//   _halá, _anté, _nkri_, _pháo_,
   {{0x56943456,0x76436866,0x6d4006a3,0xed5f0146}},	//   _сайт, _guny, _ogma, ážka_,
   {{0x291801e8,0x6d4000f9,0x201801dc,0x656401ff}},	//   ğraf_, _ngma, _akri_, _geih,
   {{0x62346867,0x764303e3,0x6e3b01b9,0x6fb9007e}},	// [63d0] рету, _zuny, _riub, нгар_,
   {{0xa5bb0080,0xdefb0084,0xdb1a0575,0x6e296868}},	//   slód, мые_, _enté, _sheb,
   {{0xf77300f5,0x6d40005c,0x628e03a9,0x387f029a}},	//   שקע_, _bgma, ctbo, zuur_,
   {{0x20180c56,0xf1bf0019,0x63bb01c2,0x6f1c0178}},	//   _ekri_, _khám_, ɓuna, _dyrc,
   {{0x7a2501cd,0xf1bf6869,0x7e6e03a9,0xbc1901b3}},	//   jóta, _iná_, _evbp, нікі_,
   {{0xe50404dd,0x7a35013f,0x387f0a88,0xe4f6152c}},	//   रपति_, _išti, vuur_, ीपति_,
   {{0xfb8401b3,0xdb01686a,0x6e3b0076,0xab8430fd}},	//   рычн, _balá, _tiub, ручк,
   {{0x387f686b,0xf8a9686c,0xc3340796,0x7643686d}},	//   tuur_, евик_, סוק_, _runy,
   {{0x69c9686e,0xdb012897,0x76436206,0x656401bf}},	//   rjee, _dalá, _suny, _reih,
   {{0x68e90d1b,0x76432c09,0x47c50ac6,0x973c0335}},	//   rzed, _puny, убов, zeće,
   {{0x200703f1,0x68e9663b,0xdce000b6,0xaa550215}},	//   čnih_, szed, _odmě, _свеш,
   {{0x261904ea,0xdb01686f,0x7a2501cd,0x00000000}},	//   déos_, _galá, bóta, --,
   {{0x973c0542,0xdb1a0146,0x69c0052c,0x2bc707ad}},	//   veće, _motý, वारी, लापा,
   {{0x394d6870,0x656401bf,0x386d6871,0xdb0801dc}},	//   lces_, _weih, mser_, _sadé,
   {{0xe2970424,0x386d3502,0x973c00e9,0x64443fef}},	//   лар_, lser_, teće, _wuii,
   {{0x394d6872,0xafdb00f3,0x386d5411,0x00000000}},	//   nces_, _støp, oser_, --,
   {{0x973c005f,0x628e6873,0x59b608d4,0x394d6874}},	// [63e0] reće, stbo, _अफसर, ices_,
   {{0xd84800ef,0x973c0307,0x53a60291,0x5f760037}},	//   _học_, seće, _саоб, طائر,
   {{0x2bc71e05,0x973c007e,0x394d007f,0x00000000}},	//   लाना, peće, kces_, --,
   {{0xc27b07a6,0x386d0400,0x9ad30134,0xa155008f}},	//   _ארטי, kser_, _pịnk, _върш,
   {{0x386d01c5,0xd84800de,0xdb1a0094,0x291d6875}},	//   jser_, _mọc_, _dotý, _nywa_,
   {{0x386d01c5,0xdb016876,0xd8480019,0x394d6877}},	//   dser_, _salá, _lọc_, eces_,
   {{0xdb011177,0xdee6002d,0x291d0113,0x386d14d9}},	//   _palá, _сови, _aywa_, eser_,
   {{0xdd920241,0xef175cb1,0xaca40174,0x987403fc}},	//   _دور_, _смс_, _atụp, алиц,
   {{0x1d070161,0x78ad0141,0x00000000,0x00000000}},	//   _бети_, _šavr, --, --,
   {{0x0897054f,0x189700e3,0x97a60012,0x7a256878}},	//   اضيع_, اضية_, урил, róta,
   {{0xdb0100fb,0x6c330080,0xd84800de,0x00000000}},	//   _talá, _افلا, _bọc_, --,
   {{0x394d6879,0xd8480023,0xd9460859,0x386d0313}},	//   cces_, _cọc_, _седи, bser_,
   {{0xd84800de,0xf8a800bc,0xe61f0231,0x00000000}},	//   _dọc_, _कनिय, rlô_, --,
   {{0xdce00631,0x25ad030b,0x60360154,0x00000000}},	//   _nemč, žel_, _fņmi, --,
   {{0x6b950233,0x7528007f,0x268a0076,0x00000000}},	//   _özge, ędza, _أختي_, --,
   {{0xf1bf00de,0x3f980090,0x7a0101d3,0xd244002d}},	//   _thám_, _abru_, vētk, сэри,
   {{0x2bc70469,0xdb1a007f,0x00000000,0x00000000}},	// [63f0] लामा, _kotó, --, --,
   {{0x1e0d0034,0x00000000,0x00000000,0x00000000}},	//   िक्ष_, --, --, --,
   {{0xa1954c3e,0x9ac506b0,0x5f1800bc,0xb5c8001c}},	//   _канч, _kiŋŋ, _बुद्_, _شویم_,
   {{0x386d1b06,0x0dc813c0,0x6d440138,0xdd9500c6}},	//   yser_, лучи_, žian, рады,
   {{0xd2640029,0x6b650138,0xdb080233,0x25fd00aa}},	//   _viņš_, акла, _endü, _लगनी_,
   {{0xeb992863,0x9ac50172,0xdb1a0131,0x207a006e}},	//   тик_, _liŋŋ, _notó, _באשא,
   {{0x7a0100d9,0x2bc713ae,0x386d687a,0x543c006e}},	//   lēti, लाबा, wser_, געגא,
   {{0x386d687b,0x28b106ec,0x00000000,0x00000000}},	//   tser_, जिलि, --, --,
   {{0xdb1a0fb6,0x394d04e4,0x386d687c,0x7a0101d3}},	//   _botó, rces_, user_, nēti,
   {{0x386d0b97,0x2cb80241,0xdb1a0072,0xd8480023}},	//   rser_, _حافظ_, _cotó, _sọc_,
   {{0xf1220034,0x65c64587,0xe975001c,0x7a0800d2}},	//   _मर्द_, абна, _نهاد, mětn,
   {{0x1959055b,0x386d687d,0xdb0102b6,0x248200dc}},	//   _рады_, pser_, _palæ, tukm_,
   {{0xdb1a687e,0xb6060032,0xb17b0212,0xa5bb0072}},	//   _fotó, _aláá, _plån, rmóp,
   {{0xdb0124ba,0xdb1a0034,0xa4060033,0x443e007b}},	//   _calç, _gotó, োগ্য_, öt_,
   {{0x6fc90789,0x98140037,0xdce005aa,0x00000000}},	//   रानं, _ابنا, _remč, --,
   {{0x65bb02fd,0xd8480019,0x24f6004d,0xdce005aa}},	//   _vähä, _họa_, _вчор, _semč,

   {{0x973c084f,0x1f6600d5,0x7bc1687f,0x80b20789}},	// [6400] meća, икам, _onlu, ीमें,
   {{0x65bb02fd,0x2f561ff1,0xa3ea09a1,0x04db021e}},	//   _tähä, ртас, _मति_, _סקיל,
   {{0xd37b193b,0x1eca008f,0xdfcf08ba,0x37e70033}},	//   _בריט, ължи_, بيل_, _পদার,
   {{0x629e2555,0x7bc100f9,0x0696006e,0x00000000}},	//   _ippo, _anlu, ידעם_, --,
   {{0xf3c9001c,0xdb1a00ee,0xa5bb01f9,0x7a0100e8}},	//   _شبیه_, _notò, nlóa, cēti,
   {{0x3eaa005c,0x3e68001c,0x635302c6,0xdb0100a7}},	//   _tsbt_, _مجری_, mění, _xalç,
   {{0xb4db0428,0x3ce0042d,0x09af0033,0x6da65e66}},	//   ncàr, šiv_, কানা, _кива,
   {{0x973c0292,0xf41f54e4,0x00000000,0x00000000}},	//   jeća, ltät_, --, --,
   {{0xc7c64036,0xfce30b1e,0x973c0307,0xdb1a6880}},	//   асни, _дото, deća, _intí,
   {{0x629e2faa,0x38790103,0x2ca900fd,0x5fc9052c}},	//   _oppo, ásra_, çade_, रायल,
   {{0x09e6013a,0xd84800de,0x7a350138,0x7a0101d3}},	//   _кожн, _dọa_, _aštu, zēti,
   {{0xdb1a0428,0xc9830a7c,0xe8fa0e05,0xdb01047e}},	//   _fotò, _души, _иле_, _salç,
   {{0x629e6881,0x53470291,0x4dc80033,0xb7b50134}},	//   _appo, ихва, _শতাং, fọd,
   {{0x6e220060,0x26f7015a,0xdb1a044c,0x00000000}},	//   hlob, اریخ_, _intâ, --,
   {{0x25b000c2,0x69c201d0,0x00000000,0x00000000}},	//   öllä_, _knoe, --, --,
   {{0x31c400d6,0xf1bf00de,0x5187001f,0x7a25003e}},	//   осув, _khái_, јува, jótl,
   {{0x629e0036,0xb4db00b3,0x00000000,0x00000000}},	// [6410] _eppo, rcàs, --, --,
   {{0x3d1a00a5,0xdb1a6882,0x7a0100d9,0x09d300a4}},	//   _बड़े_, _antí, rēti, _तव्य,
   {{0x6fc90034,0x442309ac,0x629e0350,0x98bd00bd}},	//   राबं, mlj_, _gppo, _mewġ_,
   {{0x442301cd,0x7a0100e8,0x00000000,0x00000000}},	//   llj_, pēti, --, --,
   {{0x6aba6883,0xf1bf0023,0xf3f0001c,0x7eb00103}},	//   _artf, _nhái_, _رأی_, tópá,
   {{0x2bc702d5,0x69c26884,0xf09f0139,0x3b091230}},	//   लाधा, _anoe, _ipà_, лело_,
   {{0xbab51402,0x1a68001c,0x7eb00103,0x539c021e}},	//   сёлы, لیلی_, rópá, דיוו,
   {{0x3ebe003e,0xf9910037,0xdb030216,0xf53f0120}},	//   _átta_, سبب_, lenë, ndås_,
   {{0x973c00e9,0x5ef90081,0x68f600c6,0x00000000}},	//   veća, _অডিও_, _žydr, --,
   {{0x59c5030b,0x7d040076,0x7d1e007f,0xdb01042c}},	//   वाहर, úise, ępst, _palä,
   {{0x38ca00cd,0x7cfd01df,0xc4d002c6,0xdce001d3}},	//   نایی_, _færø, सङ्ख, _iemā,
   {{0xb17b032e,0x1a640103,0x8afa006e,0xeab00214}},	//   _blåm, _بیٹی_, _גלעז, _زعم_,
   {{0x49b80b05,0xd8480023,0xf74500ae,0x79891aab}},	//   _خالد_, _tọa_, _лело, mgew,
   {{0xf8b60054,0xb05b1680,0x973c0d62,0x798901f4}},	//   _לפני_, _kräf, seća, lgew,
   {{0xd8480129,0x12b80081,0x973c0d62,0xd5ad0018}},	//   _jọn_, ীন্দ, lećn, رہی_,
   {{0x68ec07d1,0xa5bb0933,0x79892a8f,0xa3b800a3}},	//   _öldü, llón, ngew, _घोर_,
   {{0xb4db05fe,0x25fd0034,0x395f0764,0xd84800fe}},	// [6420] scàr, _लगती_, ibus_, _lọn_,
   {{0xe0df022b,0xd12f02a3,0x4423007e,0x7989042c}},	//   _afòs_, رمل_, clj_, hgew,
   {{0x6d44013f,0x6e226885,0xa13600cd,0xd8480174}},	//   žiam, tlob, _گردش, _nọn_,
   {{0x79890126,0xdfd233e7,0x09b6007f,0x29d8033c}},	//   jgew, _کيس_, _अफेय, _léar_,
   {{0x973c0268,0xa13600e3,0x79896886,0x6e226887}},	//   jećn, _دردش, dgew, rlob,
   {{0x628110d9,0x69c26888,0x80d10081,0xd8480019}},	//   álog, _snoe, _সেক্, _bọn_,
   {{0xb7b50174,0x79896889,0x200f014b,0x22420c09}},	//   kọb, fgew, égie_, _kikk_,
   {{0xf1bf0019,0x6281005f,0x79893994,0x2fd4003d}},	//   _phái_, šlog, ggew, żagħ_,
   {{0x8b96686c,0xdd8f0103,0x224200bc,0x29d800da}},	//   _греч, _سول_, _mikk_, _béar_,
   {{0xd8480139,0x6abc01f9,0x37aa0095,0x00000000}},	//   _fọn_, _árfo, утин_, --,
   {{0xd8480019,0x501b00a1,0xfd4d0134,0xf41f0212}},	//   _gọn_, רויו, _nshọ, ktär_,
   {{0xdb1a00c9,0xf1bf0028,0x569300a9,0xdce000d9}},	//   _entã, _thái_, чают, _zemā,
   {{0x999f07aa,0x394607ac,0xa5bb0031,0x29d800da}},	//   lmuş_, _igos_, blón, _féar_,
   {{0xa5bb1de1,0xf64f0103,0x29d80076,0x00000000}},	//   clón, بئی_, _géar_, --,
   {{0x999f0740,0x7a350138,0x201a688a,0x9f5a00fd}},	//   nmuş_, _ištr, dopi_, cipé_,
   {{0x22420018,0x2a8e0092,0x3ebf166d,0x2fc32ae7}},	//   _cikk_, _həbs_, _čut_, _snjg_,
   {{0x656f688b,0x7a0800b6,0x4fd52105,0x00000000}},	// [6430] mach, větl, ожат, --,
   {{0x656f0fab,0x752d0335,0x9f450511,0x539927a5}},	//   lach, _izaz, _ölü_, _твоя_,
   {{0x543c0130,0x394629cb,0x224202ec,0x2bc70096}},	//   _געזא, _ogos_, _fikk_, लासा,
   {{0x656f688c,0x63a7688d,0x224200d6,0x660d010a}},	//   nach, lejn, _gikk_, _jjak,
   {{0x61ed688e,0x7a35005f,0x6287688f,0x629501e9}},	//   mhal, _oštr, lujo, ltzo,
   {{0x61ed6890,0x656f6891,0xdb036892,0x32096893}},	//   lhal, hach, lené, lnay_,
   {{0xdce90284,0x7989401f,0x656f6894,0x973c0335}},	//   _odeć, tgew, kach, dećo,
   {{0x61ed01ce,0x32096895,0x656f6896,0x395f0009}},	//   nhal, nnay_, jach, ubus_,
   {{0x656f6897,0x79896898,0x2cad0054,0x395f22bb}},	//   dach, rgew, _used_, rbus_,
   {{0xb05b0222,0x660d007a,0x79891c81,0x61ed6899}},	//   _träf, _ajak, sgew, hhal,
   {{0x46f50e38,0x61ed0060,0x63a71770,0x752d689a}},	//   ючит, khal, dejn, _azaz,
   {{0x656f1840,0xd8480174,0x67e4022b,0x62871abe}},	//   gach, _kọl_, _fòjo, dujo,
   {{0x61ed689b,0x3e4801e8,0x660d689c,0xdb030146}},	//   dhal, _işte_, _djak, dené,
   {{0x31605675,0x66e5689d,0x8afe01c2,0x656f009c}},	//   wbiz_, _мола, waƙi, aach,
   {{0x656f689e,0xc744012b,0x752d4189,0x224200aa}},	//   bach, _عضوي, _ezaz, _pikk_,
   {{0x61ed689f,0x660d00dd,0x32094ea7,0xb7b50134}},	//   ghal, _gjak, gnay_, bọc,
   {{0x201a0141,0x6d440031,0xdb0125b0,0x63a70052}},	// [6440] topi_, žiak, _calú, bejn,
   {{0xb4e6269c,0x62870033,0x32090188,0x63a700b6}},	//   पनी_, bujo, anay_, cejn,
   {{0x444468a0,0x61ed067d,0x7e67022e,0x61461ef0}},	//   _ii_, bhal, _cwjp, _мена,
   {{0x444468a1,0xdb08033d,0x201a00f9,0xb05b0212}},	//   _hi_, _nadá, sopi_, _bräd,
   {{0x444468a2,0xf1bf0019,0xa6de00de,0x93fe0096}},	//   _ki_, _cháu_, _ngưn, _उगाच_,
   {{0x444468a3,0x2ca968a4,0x61e468a5,0xd8480174}},	//   _ji_, çada_, lkil, _dọl_,
   {{0xb05b0f3a,0x656f68a6,0x38660090,0x00000000}},	//   _präg, yach, _swor_, --,
   {{0x444468a7,0xdb085bef,0x999f008b,0x7a250037}},	//   _li_, _cadá, rmuş_, nóth,
   {{0x61e468a8,0xb05b0212,0x63a7023b,0x973c09ac}},	//   ikil, _gräd, yejn, tećo,
   {{0x444468a9,0xc7b8215e,0x656f68aa,0x109b00a1}},	//   _ni_, kođe_, wach, סביב,
   {{0xb05b160c,0xf1bf00de,0x656f4f4e,0x32090188}},	//   _träg, _khát_, tach, ynay_,
   {{0x69a1110f,0x2fd80a21,0x75240193,0x764401c2}},	//   _कॉपी, _lorg_, _byiz, _ciiy,
   {{0xf7720018,0xdb030146,0x752402a4,0x67230172}},	//   _ہاں_, vené, _cyiz, _eynj,
   {{0x656f0a21,0x628768ab,0xdb08025b,0x9c8300b6}},	//   sach, tujo, _zadá, _účet,
   {{0x444468ac,0x656f68ad,0x61ed68ae,0x63a70038}},	//   _di_, pach, thal, rejn,
   {{0x444468af,0x244f074e,0x61e4265b,0x63a72acb}},	//   _ei_, _tüm_, gkil, sejn,
   {{0x444468b0,0x61ed6378,0x2fd868b1,0x320968b2}},	// [6450] _fi_, rhal, _borg_, rnay_,
   {{0x444468b3,0x61ed68b4,0x320968b5,0x2fd8009c}},	//   _gi_, shal, snay_, _corg_,
   {{0x61ed68b6,0x656d0d17,0x644d152f,0x644500f9}},	//   phal, _keah, _huai, _iihi,
   {{0x444468b7,0x644523ea,0xdb010037,0x61ff013c}},	//   _zi_, _hihi, _talú, qiql,
   {{0x444468b8,0x69ce68b9,0xe7bc0acc,0x644568ba}},	//   _yi_, थानी, ्ञाप, _kihi,
   {{0x444404f9,0x656d01b9,0x644501c2,0x7a25003e}},	//   _xi_, _leah, _jihi, móti,
   {{0x4cd300c7,0x644568bb,0x644d0099,0x661d68bc}},	//   _দেখু, _mihi, _luai, kosk,
   {{0xb05b0222,0x2fd80ab2,0x5fc90455,0x644568bd}},	//   _träd, _zorg_, रावल, _lihi,
   {{0x644d4450,0xd8480134,0xdb080103,0xafdb004d}},	//   _nuai, _fọm_, _vadá, _støy,
   {{0x76440694,0x200168be,0xe8f6013f,0x61e40634}},	//   _siiy, nihi_, ялы_, zkil,
   {{0x444468bf,0x61fd68c0,0xdb1a0161,0x98ab0511}},	//   _ri_, _omsl, _botõ, ımız_,
   {{0x644d1519,0x200168c1,0x656d020a,0x7a0100e8}},	//   _buai, hihi_, _ceah, rēts,
   {{0x444414b1,0x644d006b,0x644568c2,0x7a1300ae}},	//   _pi_, _cuai, _bihi, găte,
   {{0x644d0091,0x69d900a1,0x444468c3,0x225a0063}},	//   _duai, _howe, _qi_, _ptpk_,
   {{0x44440501,0x644529dd,0x61e46351,0x442100f9}},	//   _vi_, _dihi, tkil, _dkh_,
   {{0x444435a6,0x644d003b,0x2fd868c4,0x6d490037}},	//   _wi_, _fuai, _sorg_, _ngea,
   {{0x444468c5,0x61e468c6,0x64456503,0x7a25124d}},	// [6460] _ti_, rkil, _fihi, góti,
   {{0x644511b9,0x444468c7,0xaabd0c38,0x69d900a1}},	//   _gihi, _ui_, ्माक, _lowe,
   {{0xf1bf68c8,0x61e40342,0x644d01ff,0x998d4582}},	//   _phát_, pkil, _zuai, zmeš_,
   {{0x69d968c9,0x2cbf2c14,0x5edb0033,0x644568ca}},	//   _nowe, _brud_, _যেহে, _zihi,
   {{0x64450694,0x200146c3,0xc1bb00ca,0x25a00167}},	//   _yihi, bihi_, _המכש, _mbil_,
   {{0xf1bf0076,0xaa660208,0x2cbf00eb,0x00000000}},	//   _fhás_, птик, _drud_, --,
   {{0x6fc9110f,0x69d968cb,0xa3cd009d,0x78a268cc}},	//   रारं, _bowe, ळात_, _spov,
   {{0x2d9f0294,0x69d91881,0x1dd000a8,0xe0df0154}},	//   _gbue_, _cowe, _सचित, _ogòl_,
   {{0x69d958b2,0x2cbf03a8,0x00000000,0x00000000}},	//   _dowe, _grud_, --, --,
   {{0x656d22d4,0x644d09f7,0x25a000aa,0x7b070103}},	//   _seah, _ruai, _abil_, ártá,
   {{0x47343840,0x2ab50649,0x644d02bc,0x661d68cd}},	//   ьнос, rùbá_, _suai, tosk,
   {{0x7bda68ce,0x69d968cf,0x973c0b14,0x442100c4}},	//   _hotu, _gowe, lećk, _skh_,
   {{0x644d0396,0x7bda006d,0xd7e6116d,0x644568d0}},	//   _quai, _kotu, _ніко, _pihi,
   {{0x493b09c1,0x69d90ab2,0x7bda00f3,0x661d68d1}},	//   _הגדו, _zowe, _jotu, sosk,
   {{0x7bda68d2,0x661d5d4d,0x69d90fa8,0x7bc80063}},	//   _motu, posk, _yowe, _mndu,
   {{0x644d0a62,0x82341363,0x7a251789,0xdb1a0212}},	//   _tuai, فرقا, tóti, _intä,
   {{0x644568d3,0x7bda00bc,0xd0110d5b,0xc05b004d}},	// [6470] _tihi, _ootu, پلا_, сіб_,
   {{0x44270080,0x7bda68d4,0x44210167,0x7a25065b}},	//   _ón_, _notu, _ukh_, róti,
   {{0x200168d5,0x0ef9030b,0xb05b0c19,0xdb0a227a}},	//   rihi_, ्पेस_, _bräc, ndfä,
   {{0x7bc868d6,0x20011e9a,0x2ca90161,0x2cbf0b68}},	//   _andu, sihi_, çado_, _prud_,
   {{0xee3802ec,0x69d968d7,0x7bda68d8,0x20010141}},	//   їні_, _rowe, _botu, pihi_,
   {{0x69d968d9,0xfaa55e6c,0xfbc70179,0x7bda078e}},	//   _sowe, дако, लाइम, _cotu,
   {{0x69d968da,0x752800a5,0x34aa0f02,0xb05b02c3}},	//   _powe, ędzi, _छन्द, _fräc,
   {{0xceb200f5,0x6d4902b6,0x7bc868db,0x08c500f6}},	//   _ביל_, _ugea, _endu, дбин,
   {{0xf8a900cd,0xdb03581b,0x7bda00ee,0x80df0033}},	//   تگاه_, mení, _fotu, _নেত্,
   {{0xdb032e16,0x69d9039f,0xd70900c2,0x7bda68dc}},	//   lení, _wowe, жное_, _gotu,
   {{0xff5600ca,0x69d968dd,0x00000000,0x00000000}},	//   ובתך_, _towe, --, --,
   {{0xf3e909c1,0x2d8f00bf,0xfb1a00c1,0xdb030031}},	//   _דף_, ngge_, _וועמ, není,
   {{0x6d443173,0x63b7008c,0xdb1a1c61,0x00000000}},	//   žiav, _baxn, _entä, --,
   {{0x33d568de,0x67d42e81,0xf77100ab,0xe1ff0850}},	//   ніст, _почу, _شات_, _amó_,
   {{0x04431357,0x00000000,0x00000000,0x00000000}},	//   терн, --, --, --,
   {{0xdb030146,0xbbda09c3,0x290e02ef,0x25a00117}},	//   jení, _बक्क, šmaš_, _ubil_,
   {{0xdb03025b,0xd8480174,0x4127261f,0x63b70d87}},	// [6480] dení, _rọk_, дото_, _faxn,
   {{0xdfa600e3,0xdee60284,0x7a25003e,0x00000000}},	//   بحري, мози, mótu, --,
   {{0x442d0022,0x7bda68df,0x2d9d0172,0xb05b042c}},	//   ɓe_, _rotu, ffwe_, _präc,
   {{0x7bda2251,0x00000000,0x00000000,0x00000000}},	//   _sotu, --, --, --,
   {{0x3ead02e6,0xa3b210ed,0x68ed00a5,0xc17300a1}},	//   _ćete_, _ऐसा_, _żadn, _בחר_,
   {{0x2d8f00e5,0x2ac60291,0x00000000,0x00000000}},	//   agge_, дљив, --, --,
   {{0x160e2272,0x7bda68e0,0x2d961469,0xc6e80081}},	//   ाचार_, _votu, _орас, _পশ্চ,
   {{0x80b50034,0x2d950c06,0xdb0302c6,0x00000000}},	//   _उनमे, _прус, cení, --,
   {{0x7bda68e1,0xd9100281,0x394268e2,0x25b90036}},	//   _totu, دیش_, äks_, vdsl_,
   {{0x7bc868e3,0x973c00cc,0xa5c70072,0xdb180052}},	//   _undu, leći, _opóñ, ndvë,
   {{0xd8480028,0xcb0a0c5e,0xeb9700d6,0xa5bb0076}},	//   _mọi_, _بيان_, _цих_, llói,
   {{0x6d44013f,0x7c2a1f16,0x236600e7,0xf1bf00fe}},	//   žiau, llfr, _đoja_, _nháp_,
   {{0xdb01025b,0x00000000,0x00000000,0x00000000}},	//   _malý, --, --, --,
   {{0xd7c80037,0x7a1300d3,0xdb0300b6,0xf90700d1}},	//   _روعه_, măta, zení, _تأمی,
   {{0x2d8f3502,0x212d0357,0xa2940120,0x7c2a0113}},	//   ygge_, _šeh_, карі, ilfr,
   {{0x973c005f,0x63b70188,0xb6080094,0x442a01b9}},	//   jeći, _waxn, _vyší, alb_,
   {{0x973c02e6,0x60f90fdf,0x7a1300d3,0xdb032e3f}},	// [6490] deći, чная_, năta, vení,
   {{0xceeb0604,0x5fc9152c,0x7ae3007b,0x7c2a0537}},	//   يران_, राइल, yynt, jlfr,
   {{0xb17b68e4,0xdb0368e5,0x00000000,0x00000000}},	//   _blåt, tení, --, --,
   {{0x7bde003e,0x00000000,0x00000000,0x00000000}},	//   öpun, --, --, --,
   {{0x7ae30150,0xdb030031,0x415a0796,0xa5bb0076}},	//   wynt, rení, _מדרג, glói,
   {{0xdb030146,0x69a100b6,0x9f5a015e,0x09a7023a}},	//   sení, क्नी, cipà_, कज्य,
   {{0xd8480028,0xe7d20034,0xdb031054,0x3ce91726}},	//   _gọi_, तानप, pení, šav_,
   {{0xc7b808a9,0xfe4300d0,0xa5bb0076,0x030d00fe}},	//   vođa_, _شکای, blói, _đều_,
   {{0x7a250102,0xa5bb00e3,0x7ae368e6,0x6d5b0051}},	//   dótt, clói, synt, _ifua,
   {{0x5fd20961,0xb8d73751,0x00000000,0x00000000}},	//   सायल, _चन_, --, --,
   {{0x66e5004b,0xd62a1c76,0x7a0802c6,0x00000000}},	//   хона, зоне_, větv, --,
   {{0x98a0013f,0x2bc7046e,0x6d590060,0x6abd0861}},	//   _šią_, लाका, ncwa, ्मीर,
   {{0x8cc21bc3,0xe8ee34dc,0x6d5b0a4b,0x7a13044c}},	//   लियो, _сл_, _mfua, căta,
   {{0x973c0335,0xb60202c6,0xdd0c007f,0xdb0300d4}},	//   zeći, _žáda, _różo, zdný,
   {{0xf1bf00ef,0x764e0e43,0x6281007e,0x5fc900b6}},	//   _pháp_, íbyt, šlon, राईल,
   {{0x3ebe0088,0xd84800fe,0x442a0350,0x00000000}},	//   _átti_, _rọi_, slb_, --,
   {{0x045700e3,0x6606389d,0xbf081b79,0x69cb4339}},	// [64a0] _كلية_, mikk, वप्न_, _mnge,
   {{0x660668e7,0xb17b0b85,0x61ef037a,0xdb01037a}},	//   likk, _blås, _elcl, _jaló,
   {{0x69cb3ba3,0x0d860f32,0xdcf40335,0x973c0335}},	//   _onge, елен, đači, teći,
   {{0x66060f06,0x63ae68e8,0x628e68e9,0x6d590201}},	//   nikk, lebn, mubo, gcwa,
   {{0x628e68ea,0x973c0106,0x270b0557,0xfa150033}},	//   lubo, reći, हपुर_, াতাল_,
   {{0x69cb68eb,0x031f0da9,0x660668ec,0xa5bb415a}},	//   _ange, _मुँह_, hikk, rlói,
   {{0x660668ed,0x628e0d1f,0x69cb0085,0x9f5a037a}},	//   kikk, nubo, _bnge, cipá_,
   {{0x629c68ee,0x7e9b00a1,0xdb010113,0x00000000}},	//   itro, _מסלו, _mblè, --,
   {{0xdb0168ef,0x8c95013a,0x6c860dd0,0xbc6a00cd}},	//   _baló, _архі, _سلام, _رمان_,
   {{0x69cb68f0,0x6e2268f1,0x628e0060,0xdb010a61}},	//   _enge, loob, kubo, _caló,
   {{0x031f000f,0x660617d2,0x63ae030b,0x629c0095}},	//   _मुंह_, fikk, debn, jtro,
   {{0x629c68f2,0x628e03e3,0x660668f3,0x7a13020a}},	//   dtro, dubo, gikk, păta,
   {{0x37e61369,0x7a250088,0x629c01af,0xdb032347}},	//   _подг, rótt, etro, mená,
   {{0x63ae02e2,0xb05b68f4,0xdb01037a,0xdb032e16}},	//   gebn, _brän, _galó, lená,
   {{0x66060283,0xdbc7007a,0x628e68f5,0xdb1a037a}},	//   bikk, _töös, gubo, _antú,
   {{0x59a60789,0xb05b00a2,0xdb0105aa,0xdb0a00ee}},	//   _कॉमर, _drän, _kalò, refè,
   {{0x6e22008a,0xb17b0572,0xc61d0d77,0x00000000}},	// [64b0] doob, _slås, नवीय_, --,
   {{0xa0c400e3,0xdb080139,0x6fb868f6,0xb05b3341}},	//   ديكو, _dadú, нгур_, _frän,
   {{0x442303ce,0x63a900e9,0xb05b0149,0x629c1b14}},	//   moj_, đend, _grän, ctro,
   {{0xaf340037,0x127a006e,0x6e2268f7,0x00000000}},	//   اركت, _קארע, goob, --,
   {{0x973c077e,0x672a0088,0xdb030146,0xa176021e}},	//   meću, _lyfj, dená, _בערד_,
   {{0x442302e6,0xed150068,0x660668f8,0xeab10037}},	//   noj_, _یہاں_, zikk, لعب_,
   {{0x9f3400f3,0xdea400cd,0x69cb0085,0x6e22399b}},	//   _бері, _میلی, _pnge, boob,
   {{0x442368f9,0xdb010328,0x63ae1bc3,0x6d5b0239}},	//   hoj_, _saló, zebn, _ufua,
   {{0x442302e6,0x6d440220,0x80c4417e,0x660631e8}},	//   koj_, žiar, रिये, vikk,
   {{0x442302e6,0x66060305,0xf0940089,0x3a2613fb}},	//   joj_, wikk, אנץ_, _ekop_,
   {{0x660601ce,0xdb0168fa,0x63ae0618,0x442368fb}},	//   tikk, _való, vebn, doj_,
   {{0x3ddf0ab2,0x7a13002d,0xdce0030b,0x63a5009c}},	//   _jouw_, măto, _nemě, _abhn,
   {{0x6606242f,0x63ae030b,0xf41f09df,0x7a1300d3}},	//   rikk, tebn, rrän_, lăto,
   {{0x629c68fc,0x660668fd,0x628e68fe,0x3ddf0313}},	//   ttro, sikk, tubo, _louw_,
   {{0x23271756,0xe2972e57,0x63ae0181,0x7a1300d3}},	//   вори_, кар_, rebn, năto,
   {{0x629c1311,0x212b000d,0x628e0169,0x7c2368ff}},	//   rtro, _bych_, rubo, honr,
   {{0x442315f4,0x66046900,0x628e6901,0xa3ba0dd0}},	// [64c0] boj_, _imik, subo, _قادر_,
   {{0xb05b070a,0x629c6902,0x0fc90034,0x212b6903}},	//   _trän, ptro, रागढ, _dych_,
   {{0x224b070a,0x6e224d4e,0x3ddf0126,0x443a0063}},	//   _fick_, toob, _bouw_, _ihp_,
   {{0x224b070a,0x98b100b6,0x443a009c,0xf8d1023a}},	//   _gick_, íběh_, _hhp_, तमाय,
   {{0x6fc939d4,0x224000aa,0x6e221971,0x7c9600d3}},	//   राखं, mmik_, roob, трец,
   {{0x3a266904,0x22406905,0xdce000b6,0x67e40154}},	//   _skop_, lmik_, _země, _jòjt,
   {{0x7a1300d3,0x66046906,0x63a36907,0x443a6908}},	//   găto, _omik, _önne, _mhp_,
   {{0xada60805,0x442348a3,0xa93402e3,0xd8486909}},	//   _шабл, zoj_, лейш, _lọt_,
   {{0xdb1a00dd,0xdca600c9,0x1c46065c,0x224000f9}},	//   _katë, _јази, _анам, imik_,
   {{0x66040068,0x4423690a,0xdb0100b3,0x394f00d7}},	//   _amik, xoj_, _valò, _eggs_,
   {{0x7a13002d,0xadc30139,0x7a250072,0x61f6169c}},	//   căto, _ajẹn, rótr, khyl,
   {{0x6f030396,0x3a2602ef,0x3ebe003e,0x672a0f5a}},	//   únci, _ukop_, _áttu_, _vyfj,
   {{0xf8b61677,0xd848690b,0x79820065,0xdb030537}},	//   _अनिय, _bọt_, _idow, genæ,
   {{0xdb1a00dd,0x660445e9,0x443a026a,0x9f4a00b3}},	//   _natë, _emik, _chp_, _albí_,
   {{0x4423690c,0xaad2099d,0xf83700ca,0x973c0995}},	//   roj_, थमिक, _שנות_, teću,
   {{0xed5903ce,0x661601e5,0x442300dd,0xf8b600df}},	//   _kaže_, _gjyk, soj_, _अनाय,
   {{0x973c08a9,0x442316aa,0x7a13020a,0x3ddf01cb}},	// [64d0] reću, poj_, zăto, _rouw_,
   {{0x224b1821,0x25ff5c65,0x973c049c,0xed590117}},	//   _wick_, शोरी_, seću, _maže_,
   {{0xdb030990,0xdb1a023b,0x212b00f0,0x764d024a}},	//   menç, _datë, _wych_, _kiay,
   {{0x212b3430,0xed5802ec,0xdb035b59,0x7c3a690d}},	//   _tych_, вої_, lenç, _ahtr,
   {{0xdca54906,0x61ed0f05,0xb05b09b5,0xab07003e}},	//   уали, mkal, _kräm, _íbúð_,
   {{0x7a1300ae,0x32092b7c,0x764d690e,0xdb1a4ca5}},	//   tăto, liay_, _liay, _katè,
   {{0x3ddf029a,0x752d0172,0x7a0802c6,0x00000000}},	//   _touw_, _lyaz, větr, --,
   {{0x61ed690f,0xdb1a6910,0x7c236911,0x7a1300ae}},	//   nkal, _matè, sonr, răto,
   {{0x7a1300d3,0x6e3b0201,0x61ed6912,0x752d0512}},	//   săto, _ihub, ikal, _nyaz,
   {{0x79826913,0xe8f61cfb,0x660400c4,0xa7b5016c}},	//   _edow, уль_, _smik, усиј,
   {{0x764d009d,0xb99500e3,0x61ed6914,0x752d0adf}},	//   _biay, _ملاب, kkal, _ayaz,
   {{0x61ed6915,0x3a246916,0x394f0381,0x752d149c}},	//   jkal, comp_, _uggs_, _byaz,
   {{0x764d00d1,0x61ed6917,0xc7a50cba,0x752d05bd}},	//   _diay, dkal, _билк, _cyaz,
   {{0x61ed4dc0,0xdb1a0383,0xec35006e,0xdb0300ee}},	//   ekal, _batè, טאָר_, genç,
   {{0xdb1a00b3,0x752d2712,0xd84800fe,0x6e2906b0}},	//   _catè, _eyaz, _vọt_, _okeb,
   {{0x61ed152a,0x764d6918,0x6e290294,0x69db0143}},	//   gkal, _giay, _nkeb, njue,
   {{0x68e906ee,0xb05b0222,0x22406919,0x3eaa0063}},	// [64e0] nyed, _främ, rmik_, _spbt_,
   {{0xdb030396,0x6e3b023f,0x61ed691a,0x6e29691b}},	//   cenç, _ahub, akal, _akeb,
   {{0xa2e61d62,0x7d1b03be,0xd8480134,0xbd8a0037}},	//   _сонд, _axus, _kọr_, فنان_,
   {{0x7c3a01e5,0x61ed08c5,0x645639af,0xed5a34ca}},	//   _shtr, ckal, _kuyi, ход_,
   {{0x6456006d,0xa3a90789,0x6e3b691c,0x63be0103}},	//   _juyi, _गॉड_, _dhub, _kapn,
   {{0xdb1a0103,0x69a10569,0x6456170c,0x6e3b0372}},	//   _haté, क्सी, _muyi, _ehub,
   {{0x60c4691d,0xdb1a1b21,0x66f300a7,0x75e60103}},	//   lvim, _katé, bəkə, _józs,
   {{0x248003ce,0x6e3b0a4b,0xbc76001c,0x69db691e}},	//   _ovim_, _ghub, _مهرب, gjue,
   {{0xdb1a691f,0x26c76920,0x68e90103,0x20180167}},	//   _maté, _arno_, gyed, _kjri_,
   {{0x26c7030b,0xed5903d6,0x61ed6921,0xdb1a00fd}},	//   _brno_, _važe_, zkal, _laté,
   {{0x26c700e9,0xdb036922,0x752d061d,0x3a241507}},	//   _crno_, venç, _syaz, pomp_,
   {{0x64566923,0xdb0a001f,0x244f0090,0xa5bb016d}},	//   _buyi, nefí, _ażma_, coól,
   {{0xdb030396,0x55076924,0x67d46328,0x7aea6925}},	//   tenç, учна, _волу, lyft,
   {{0xdb1a6926,0x69c06927,0xe4540ab3,0x60c90234}},	//   _patè, ldme, скры, _šemo,
   {{0xdb036928,0x61ed00ce,0xdb1a0220,0x59b80034}},	//   renç, tkal, _baté, _आसार,
   {{0xdb1a04ea,0x673803c6,0xdb03001f,0x777a6929}},	//   _caté, _izvj, senç, latx,
   {{0x6e3b692a,0x9f4a00ee,0x64560361,0x752d0201}},	// [64f0] _rhub, _albà_, _guyi, _uyaz,
   {{0x61ed692b,0x6e3b692c,0xf3ff016d,0x6aba02db}},	//   skal, _shub, mpão_, _ostf,
   {{0x1dc600a5,0x60c4013f,0x5d551469,0xf3ff016d}},	//   _रोहत, avim, акет, lpão_,
   {{0x63be025b,0x777a0634,0x6e3b019f,0x7095004b}},	//   _zapn, hatx, _qhub, _камф,
   {{0x6aba0012,0x66f30092,0xeb99692d,0x317a0142}},	//   _astf, rəkə, вил_, _בארד,
   {{0x68fb00a7,0xa3cb5ed7,0x3f830e94,0x8c4500ce}},	//   vzud, _रोम_, _udju_, шеле,
   {{0x69c00126,0x6e3b5e57,0x25a90146,0x09f540c9}},	//   fdme, _thub, _obal_, ичия,
   {{0x09e51312,0x6e3b6868,0x7d1b01ff,0x6e29692e}},	//   роин, _uhub, _txus, _ukeb,
   {{0x69a1277c,0x682f00f2,0xf7713a1d,0x26c70141}},	//   क्षी, lødi, ياد_, _srno_,
   {{0x25a9005c,0xdb0343a6,0x59d3030b,0x64564b29}},	//   _abal_, tenä, थाहर, _ruyi,
   {{0x248003ce,0x68fb374f,0x68e9692f,0x00000000}},	//   _svim_, szud, syed, --,
   {{0x78b9006c,0x63be6930,0x75e60103,0x661e00d4}},	//   _tswv, _sapn, _rózs, čsko,
   {{0xdb036931,0xf8a900aa,0xb05b02c3,0xdb1a014b}},	//   senä, _कहिय, _dräk, _raté,
   {{0xdb1a124d,0x69a1022d,0x25a94c4c,0x80c4023a}},	//   _saté, क्री, _ebal_, रिसे,
   {{0xdb01030b,0x232a1121,0xdb1a266c,0xf1bf0139}},	//   _oblí, тови_, _paté, _baá_,
   {{0x60c403ce,0x716600e3,0xd84800de,0x6456170c}},	//   tvim, شارك, _họp_, _tuyi,
   {{0xdfd200ab,0x422300d6,0xb8860139,0x661d0103}},	// [6500] يير_, ідув, _idíó, érke,
   {{0x60c46932,0x38600037,0x387f0063,0x00000000}},	//   rvim, _éire_, isur_, --,
   {{0xdfcf0c5e,0x69c00188,0x71a613a4,0x60c4242f}},	//   ظيم_, ydme, _канз, svim,
   {{0x6da62436,0x387f6933,0x248d0094,0x28b602d5}},	//   рида, ksur_, šeme_, _अनलि,
   {{0xa3cb0789,0x61eb0155,0x7e690146,0xf1bf0023}},	//   _रोड_, ögle, _čepe, _nháy_,
   {{0x628e0381,0x22b80154,0x9e660a85,0xdfd20076}},	//   orbo, _kōk_, _نارن, _بيس_,
   {{0x81b900c7,0xd00700ae,0x80c409c4,0x777a00b3}},	//   চার_, _тере_, रिवे, vatx,
   {{0x98740097,0xa8a65e39,0x387f03a9,0x00000000}},	//   блиц, арок, fsur_, --,
   {{0x25a9009c,0xf1bf0019,0x69c0004d,0x387f366c}},	//   _rbal_, _cháy_, rdme, gsur_,
   {{0x57f41828,0xd84800fe,0xdb0100d4,0xdcfb009e}},	//   спот, _cọp_, _zblí, _sbuħ,
   {{0x8f7b00f5,0xdb01016d,0xcf5700ca,0x6aba0063}},	//   כניק, _balõ, יבית_, _ustf,
   {{0x98a62321,0x777a01c8,0x00000000,0x00000000}},	//   _виде, satx, --, --,
   {{0x69fb006e,0x628e0b8e,0x777a0062,0xb05b02c3}},	//   _בלאק, erbo, patx, _vräk,
   {{0xf3ff016d,0x77921ac9,0xed5900c6,0x74250033}},	//   rpão_, _بیدا, _maža_, পষ্ট_,
   {{0xf8b600c3,0xf2c408d8,0xa5c400a5,0x3e4800d3}},	//   _अनुप, остн, _spół, _eşti_,
   {{0x33f40212,0xd4b9125c,0xdb010231,0x115532df}},	//   _växa_, _блиц_, _galõ, скаю,
   {{0x657d6934,0x80d10789,0x628e112f,0xe81d6935}},	// [6510] mash, समें, arbo, _पदमा_,
   {{0x657d6936,0x38660167,0x3f675cac,0x22b8022b}},	//   lash, _mtor_, ртаб, _fōk_,
   {{0x63b502dd,0x656f025b,0x00000000,0x00000000}},	//   mezn, obch, --, --,
   {{0x63b51420,0x59a6007d,0x657d6937,0x66ea0092}},	//   lezn, _कॉलर, nash, məkd,
   {{0xfd100adb,0x62956938,0x00000000,0x00000000}},	//   وجه_, luzo, --, --,
   {{0x657d59bf,0xdd1102a1,0xdb030031,0x22b80154}},	//   hash, _iżża, menú, _yōk_,
   {{0x657d6939,0xd90f0068,0x3866001f,0x629500e7}},	//   kash, ڈیا_, _ator_, nuzo,
   {{0xdb1a693a,0x657d00dd,0x9f430052,0xdb010094}},	//   _antó, jash, _lojë_, _ublí,
   {{0x657d28d5,0x63b50018,0xd7d20096,0xd8480174}},	//   dash, kezn, तांच, _pọp_,
   {{0x31790068,0xdb080072,0x62954e64,0xdb01016d}},	//   _lesz_, _cadó, kuzo, _salõ,
   {{0x657d092f,0x387f693b,0x79800174,0x7bc1693c}},	//   fash, ssur_, _ịweb, _ialu,
   {{0x7bc12344,0x657d693d,0xdb1a08a8,0xf3e9028c}},	//   _halu, gash, _entó, _אף_,
   {{0x5a0a006e,0xdb08033c,0x00000000,0x00000000}},	//   _גלײַ, _fadó, --, --,
   {{0xe29a065c,0x7bc1693e,0xe7080068,0xe3635779}},	//   лаг_, _jalu, اتین_, зкри,
   {{0x657d693f,0x2ba902e8,0x7bc16940,0xe69500e3}},	//   bash, च्या, _malu, _العد,
   {{0x80c4007d,0x7bc118c4,0x657d2e10,0x628e0212}},	//   रिले, _lalu, cash, rrbo,
   {{0x63b50087,0x61430db2,0x7a1300d3,0xc8620174}},	// [6520] bezn, зета, găti, _kọọd,
   {{0x7bc16941,0x2f565d76,0x62956942,0x9f430052}},	//   _nalu, стас, buzo, _gojë_,
   {{0x442a6943,0x66ea0092,0x683d020d,0x81e40033}},	//   mob_, cəkd, cède, ভোগ_,
   {{0x442a6944,0x7bc100f9,0x7e630103,0xdb0a6945}},	//   lob_, _aalu, ínpa, ánít,
   {{0x7bc16946,0x6281030b,0x442a023e,0x7c8300ba}},	//   _balu, álov, oob_, пуще,
   {{0x7bc13dc2,0x657d02a4,0x92df0081,0x68f6007f}},	//   _calu, zash, _দেয়_, _żydo,
   {{0x38660501,0x657d6947,0x7bc16948,0xdb1a6949}},	//   _stor_, yash, _dalu, _antò,
   {{0xada30609,0x442a01bb,0x63b5423b,0xc27b0266}},	//   _насл, hob_, zezn, ארקי,
   {{0xc8620134,0x7bc1694a,0x657d694b,0x224c02c6}},	//   _bọọd, _falu, vash, ídky_,
   {{0x657d694c,0x442a694d,0x7bc1694e,0x6c36010d}},	//   wash, job_, _galu, _افطا,
   {{0x657d694f,0x6e4501cd,0x442a6950,0xe5b5163d}},	//   tash, _útbú, dob_, ойны,
   {{0x7bc12c99,0x61e600d9,0xa2cc0d88,0xbb3b00c1}},	//   _zalu, _nokl, हिन्, _געבי,
   {{0x657d6951,0xd90e1e49,0x200a0051,0x7bc14a16}},	//   rash, _سید_, _ombi_, _yalu,
   {{0x63a903ce,0x657d0a75,0xb05b0222,0x67d40f32}},	//   đeno, sash, _kräv, _фоку,
   {{0x6fd204a9,0x63b56952,0x657d6953,0x6fd70096}},	//   साईं, rezn, pash, ठासं,
   {{0x245d00ef,0x657d6954,0xe4d90d7f,0x7a13044c}},	//   _tìm_, qash, _نوبت_, tăti,
   {{0x660f0074,0x69c20113,0x31790103,0x62956955}},	// [6530] mick, _maoe, _vesz_, suzo,
   {{0xd5a5009d,0xa3b04ff1,0x60090092,0xdefb00c2}},	//   ग्रज, _टॉप_, _kömə, лые_,
   {{0x41c4034d,0x7bc100ae,0x31790103,0xdb010094}},	//   _लोकस, _ralu, _tesz_, _oblá,
   {{0x660f0871,0x7bc16956,0x200a0502,0xa69b006e}},	//   nick, _salu, _embi_, רשאפ,
   {{0x7bc16957,0xdb18052f,0x628a0120,0x00000000}},	//   _palu, ndvæ, _åfor, --,
   {{0xdfdb0465,0x660f3d11,0x547c006e,0x7c2a2f0e}},	//   _съм_, hick, נטוו, gofr,
   {{0x7bc13181,0x7bc301bf,0xbb421e20,0x1a68001c}},	//   _valu, rdnu, мешк, میلی_,
   {{0x7bc16958,0x6b88010a,0x2aa16053,0x39e9235c}},	//   _walu, _eddg, rób_, рдио_,
   {{0x2aa10067,0x442a022e,0x660f025b,0x7bc16959}},	//   sób_, yob_, dick, _talu,
   {{0x6e2b5956,0xdb1a695a,0x2cbf0124,0x7bc1023e}},	//   logb, _zatí, _isud_, _ualu,
   {{0xe7391c47,0x660f0074,0x38ca00cd,0xb05b0212}},	//   рен_, fick, هایی_, _gräv,
   {{0x660f0074,0x58d502b3,0xc8620174,0xa2bd007f}},	//   gick, _моет, _wọọd, शबन्,
   {{0x442a695b,0xb05b0364,0x62850727,0x682f00f2}},	//   tob_, _kräu, _avho, født,
   {{0x386d695c,0x61e63c0d,0xdce90031,0x2b4000b6}},	//   mper_, _sokl, _oceľ, řice_,
   {{0x660f695d,0xfbd200ca,0x27e701b9,0x386d695e}},	//   bick, ותם_, _ionn_, lper_,
   {{0x799b695f,0x26880037,0x2cbf0e43,0x660f0e43}},	//   nguw, _اخوي_, _osud_, cick,
   {{0x27e70c56,0x600a6924,0x3fe61510,0xe0da20f8}},	// [6540] _konn_, анам_, ожав, шва_,
   {{0xdb1a5593,0xa91d0031,0x386d6960,0x27e76961}},	//   _satí, mažd, iper_, _jonn_,
   {{0x91e60315,0x27e70383,0xdb1a6962,0x7a13020a}},	//   _доне, _monn_, _patí, lătu,
   {{0x5eac0081,0xdb1a016d,0x386d0063,0x27e7022b}},	//   ছিলে, _latã, kper_, _lonn_,
   {{0xa01b0102,0x5046002d,0x20340018,0xae00009f}},	//   _kvöl, _мемб, _فہرس, लोगन_,
   {{0x660f068e,0x200a0498,0xa3b00789,0xaa665833}},	//   zick, _umbi_, _टॉम_, отик,
   {{0xd5dd0285,0xdb1a6963,0xaab70037,0x05ca1981}},	//   यामज, _satâ, قدير_, ियाब,
   {{0xab5c00d9,0x48aa074b,0x98746964,0x660f0146}},	//   _daļa, атом_, плиц, xick,
   {{0x27e730e4,0xb7bc0029,0x660f0e31,0x59a60af1}},	//   _bonn_, loģi, vick, क्षर,
   {{0x274a0562,0xc6a61357,0x660f6965,0x27f80088}},	//   ично_, орми, wick, órn_,
   {{0x660f0871,0x1f5b00f5,0x27e76966,0xab5c01d3}},	//   tick, ידיא, _donn_, _gaļa,
   {{0x3dc63794,0x27e70167,0xdb0a02b6,0xc7b8042d}},	//   ndow_, _eonn_, tefæ, vođu_,
   {{0x660f0871,0xf8ad00bf,0x27e76966,0x2ca66967}},	//   rick, _یکی_, _fonn_, ntod_,
   {{0x660f0074,0x3dc401fa,0x79806968,0x27e7022b}},	//   sick, _lamw_, lamw, _gonn_,
   {{0x3d110067,0x660f025b,0x320b0036,0x00000000}},	//   _देने_, pick, ахан_, --,
   {{0x2ca60009,0x798029f7,0xb05b02c3,0x27e76969}},	//   ktod_, namw, _orät, _zonn_,
   {{0xdcfb005f,0x27e70c56,0xf8bc00a5,0x7a1300ae}},	// [6550] _iduć, _yonn_, ्टिय, cătu,
   {{0x7980696a,0x2cbf00ec,0x628100b6,0x2ca606a8}},	//   hamw, _rsud_, álos, dtod_,
   {{0xa2cc009d,0x7980696b,0x35d008d4,0xdb1830c1}},	//   हिण्, kamw, _तोड़, ndvä,
   {{0xa91d04a3,0x628102e6,0x386d017a,0x25b902c6}},	//   laže, šlos, yper_, nesl_,
   {{0x660d37de,0xb7b50174,0x6e2b696c,0x79800350}},	//   _mmak, kọp, rogb, damw,
   {{0x22490446,0xa91d696d,0x26ce002b,0x00000000}},	//   lmak_, naže, _orfo_, --,
   {{0xdb1a05fe,0x660d696e,0xf41400ca,0x683400b3}},	//   _catà, _omak, ופס_, càdi,
   {{0xe9d9064f,0x3f81696f,0x22496970,0x27e76971}},	//   ски_, lahu_, nmak_, _sonn_,
   {{0x63a903ce,0xb05b0364,0x386d06ad,0x799b03e3}},	//   đenj, _träu, uper_, rguw,
   {{0x660d3dd3,0x3f815cbf,0x386d091f,0xa91d33ae}},	//   _amak, nahu_, rper_, jaže,
   {{0x386d6972,0xdb0a3114,0xf5290327,0x2249026a}},	//   sper_, gefä, _עץ_, kmak_,
   {{0x2d9d6973,0x386d4bf9,0x224900cc,0x2ae800b6}},	//   ngwe_, pper_, jmak_, जहरु_,
   {{0x3f8100e7,0x27e73f83,0x2d9d0129,0x224905db}},	//   kahu_, _tonn_, igwe_, dmak_,
   {{0xdb1a0068,0xa91d0477,0x660d6974,0x33d516dd}},	//   _hatá, ražd, _emak, міст,
   {{0x7d020036,0x7a13020a,0x00000000,0x00000000}},	//   zzos, sătu, --, --,
   {{0xdddc2d5a,0x8066084c,0x91e33cf9,0x7a13020a}},	//   _ovrš, зваж, носе, pătu,
   {{0x76446975,0xdb1a0503,0x00000000,0x00000000}},	// [6560] _ihiy, _matá, --, --,
   {{0x79806976,0xd9b83acf,0x97420a39,0x2d9d010a}},	//   zamw, _आस्ट, šćem, egwe_,
   {{0x444402e6,0x59bd000c,0x2ec600e3,0x765601c2}},	//   _ih_, ्यार, ثقاف, _kiyy,
   {{0xdb1a6977,0x76560d2a,0x44442e9c,0xdb1805e8}},	//   _natá, _jiyy, _hh_, ndvå,
   {{0x44445411,0x6f020032,0x79800169,0x3f816978}},	//   _kh_, _bíbé, vamw, bahu_,
   {{0x44380332,0xdd990154,0x61f61e8f,0x7d026979}},	//   nlr_, _alňd_, lkyl, rzos,
   {{0x80c42a06,0x4444697a,0xb05b0704,0x79804376}},	//   रिके, _mh_, _fräs, tamw,
   {{0xdb1a0b0b,0x4444697b,0xdca63898,0xb05b0149}},	//   _catá, _lh_, _наби, _gräs,
   {{0xfc6400bf,0x6b561574,0xa9670396,0x7980697c}},	//   _آخری, _فضائ, чиња_, ramw,
   {{0x6d400b4b,0x1dda007d,0x660d697d,0xdb03025b}},	//   _izma, णावत, _smak, lený,
   {{0x65955f3b,0x765603e3,0xa91d0995,0x22490233}},	//   ману, _biyy, važe, ymak_,
   {{0x4444697e,0xaac21376,0xaadb00a1,0x76440154}},	//   _ah_, _वैयक, _לחבר, _chiy,
   {{0x4444697f,0x76560d2a,0xa91d02c6,0x76442e1a}},	//   _bh_, _diyy, taže, _dhiy,
   {{0x44446980,0x69a214db,0xdb1a1e15,0xdb180216}},	//   _ch_, _गाडी, _zatá, jevë,
   {{0x44440049,0xa91d0335,0x883b0054,0x224901e8}},	//   _dh_, raže, _התגו, tmak_,
   {{0x44446981,0x660d6982,0xdb03025b,0xbbb900df}},	//   _eh_, _umak, jený, _इस्क,
   {{0x3f814df2,0x44446983,0xdb03025b,0x22496984}},	// [6570] tahu_, _fh_, dený, rmak_,
   {{0xa3d409c3,0x22496985,0xd37b3a1f,0xb034037e}},	//   _सोप_, smak_, _учи_, енуш,
   {{0xb05b6986,0xdddc042d,0x224901e8,0x6d406987}},	//   _präs, _svrš, pmak_, _azma,
   {{0x661d6988,0x3f810074,0x645703be,0x442100dc}},	//   nnsk, sahu_, _hixi, _hjh_,
   {{0x44446989,0x628711d3,0x661d698a,0xdca50582}},	//   _yh_, lsjo, insk, фали,
   {{0x4444698b,0x3d11009d,0x645f68f7,0xdb1a00e1}},	//   _xh_, _देणे_, _muqi, _satá,
   {{0xdb030074,0x6287698c,0x60cd4847,0x644b028d}},	//   bený, nsjo, lvam, _ègiu,
   {{0xa3d404f1,0xdb03698d,0x661d1e4d,0x24890381}},	//   _सोन_, menü, jnsk, _ovam_,
   {{0x2d8d698e,0x3a2d04ee,0x9f5a0487,0xdddc0128}},	//   _idee_, roep_, cipó_, _uvrš,
   {{0x628702ec,0x7644006d,0x79630065,0x661d0f5a}},	//   ksjo, _shiy, _bíwó, ensk,
   {{0x4ac10789,0x3d111152,0xf4230081,0x7c240037}},	//   _शनिव, _देते_, ফতার_, éire,
   {{0x661d038c,0x64572b39,0x4421698f,0x60cd00cb}},	//   gnsk, _aixi, _ajh_, kvam,
   {{0x69d96990,0x64570694,0xdd0100b6,0x66ea00a7}},	//   _inwe, _bixi, _čtět, rəka,
   {{0x6b830498,0x661d0181,0x69c92552,0xdb030579}},	//   nang, ansk, ldee, zený,
   {{0xdb036991,0x2d8d0294,0x9f430094,0x6445009c}},	//   menó, _odee_, _bojí_, _dhhi,
   {{0x6b8334c1,0x69c96992,0x645f00dd,0x24440149}},	//   hang, ndee, _fuqi, döme_,
   {{0x78a96993,0x6b831a8b,0x44440054,0xdb03025b}},	// [6580] ntev, kang, _th_, vený,
   {{0x6d5b5cd8,0x6b836994,0x61f66995,0x64571b7b}},	//   _agua, jang, skyl, _gixi,
   {{0x6b836996,0x69d96997,0x78a96998,0x63bc6999}},	//   dang, _onwe, htev, mern,
   {{0xdd8f0391,0x63bc2222,0x629c699a,0x78a900dd}},	//   لوم_, lern, muro, ktev,
   {{0xdb0918ed,0x6b830571,0x6457699b,0x69c9699c}},	//   čnýc, fang, _yixi, ddee,
   {{0x63bc699d,0x69d9699e,0x64570479,0x6d5b699f}},	//   nern, _anwe, _xixi, _egua,
   {{0x661d0220,0xa3df0096,0x629c69a0,0x6d400034}},	//   ynsk, णात_, nuro, _wzma,
   {{0x63a900e9,0x69d5397e,0x9f5a028d,0x78a969a1}},	//   đeni, भागी, cipò_, ftev,
   {{0x6b8369a2,0x6d4069a3,0x63bc0c2e,0xdb1a0161}},	//   bang, _uzma, kern, _antô,
   {{0x63bc69a4,0x69d90857,0x629c69a5,0x6b8369a6}},	//   jern, _enwe, kuro, cang,
   {{0x7bda69a7,0xa5bb08a8,0x78a955b6,0x6457047b}},	//   _intu, olóx, atev, _rixi,
   {{0x629c0150,0x645769a8,0x7bc869a9,0x1de102d5}},	//   duro, _sixi, _hadu, फायत,
   {{0x7bc869aa,0xe9f700d6,0x661d6676,0xd5a50789}},	//   _kadu, _інші_, rnsk, ग्गज,
   {{0x63bc13cd,0xf8bc0251,0x7bc808d3,0xdb030072}},	//   gern, ्टीप, _jadu, cenó,
   {{0x645769ab,0x5334439e,0x7a3e023b,0x545407c8}},	//   _vixi, верт, nëto, тврт,
   {{0x64570694,0xf1bf0018,0x6b8354eb,0xa91d0542}},	//   _wixi, _akár_, zang, laža,
   {{0x63bc69ac,0x628704f9,0x9099013d,0x7e6e00f9}},	// [6590] bern, ssjo, яват_, _atbp,
   {{0x60cd257b,0x6d5b69ad,0xf1d80557,0x7bc869ae}},	//   rvam, _sgua, डाउन, _nadu,
   {{0x201301d4,0x629c2972,0x443169af,0x60cd69b0}},	//   rixi_, curo, moz_, svam,
   {{0x6b8369b1,0x7bda69b2,0x7bc80065,0x443169b3}},	//   wang, _antu, _aadu, loz_,
   {{0x6b8369b4,0x7bc846e1,0x7bda005c,0xcb6912e9}},	//   tang, _badu, _bntu, пале_,
   {{0x7bc826ae,0x443169b5,0x6cd20018,0x69c9008c}},	//   _cadu, noz_, اقوا, wdee,
   {{0x6b832d3b,0xeab10068,0x7bc869b6,0x69c9000b}},	//   rang, اعت_, _dadu, tdee,
   {{0x44310068,0x78a969b7,0x6d5b008f,0xaa560284}},	//   hoz_, ttev, _ugua, нију_,
   {{0x6b8369b8,0x69c904ee,0xf8c80028,0x63bc69b9}},	//   pang, rdee, _cứ_, yern,
   {{0x7bc800d9,0x44310487,0x78a969ba,0x60000103}},	//   _gadu, joz_, rtev, _töme,
   {{0x6811030b,0xc95900ab,0x26d1137f,0xe5a60d57}},	//   vědě, _فلاش_, ízo_, нини,
   {{0x6b8157a9,0x7bc803ce,0x63bc69bb,0xa2d3030b}},	//   _helg, _zadu, wern, डिन्,
   {{0x6b8109a1,0x7bc869bc,0x66ea00a7,0xdb0300b3}},	//   _kelg, _yadu, ləkl, cenò,
   {{0x629c69bd,0x6b8100d9,0xe1ff69be,0x443169bf}},	//   turo, _jelg, _aló_, goz_,
   {{0x63bc69c0,0xed5901d3,0xe73644c5,0x26120031}},	//   rern, _daži_, _пеш_, lšom_,
   {{0x63bc0c9b,0x629c69c1,0xe1ff0037,0x20110027}},	//   sern, ruro, _cló_, _amzi_,
   {{0x63bc69c2,0xf8c80019,0x629c69c3,0xa3cb2010}},	// [65a0] pern, _xứ_, suro, _रोक_,
   {{0xdb0110d9,0xd9bd28fb,0x44310610,0x59d1007a}},	//   _eclé, ्युट, coz_, _दोसर,
   {{0x225917d2,0x539b00a1,0x9f4a0113,0x399a047e}},	//   _fisk_, _ציטו, _kobé_, nüsü_,
   {{0x7bc869c4,0x9cca2787,0x60db6404,0xdd92001c}},	//   _sadu, зыка_, _šume, اوش_,
   {{0x6b8169c5,0x3ebf0e94,0x26120031,0xdce001d3}},	//   _belg, _ćute_, jšom_, _iemī,
   {{0x6b810042,0x22590146,0x6a670233,0xab38002d}},	//   _celg, _zisk_, _sıfa, мплу_,
   {{0xd9bd07e2,0x6b8169c6,0xf8c800de,0xa9bd02d5}},	//   ्यूट, _delg, _sứ_, ्यूए,
   {{0x443169c7,0x3d11007a,0x9f4a0154,0x3eb801ee}},	//   zoz_, _देवे_, _robè_, _iprt_,
   {{0xd7db0096,0x0c3a0037,0xa3c200b6,0xa91d00c6}},	//   बांच, _فكرة_, ृया_, taža,
   {{0x7bda43b4,0x7a3e023b,0x7bc80a4b,0x44313c30}},	//   _untu, pëto, _uadu, xoz_,
   {{0xa3cb04f8,0x4431163c,0xa3df009d,0x290b0a82}},	//   _रोग_, voz_, णास_, úcar_,
   {{0x63a502dc,0xf8c800de,0xb8e60033,0xa91d00c6}},	//   _schn, _tứ_, _উপ_, saža,
   {{0x443169c8,0xe61f0161,0x225900ca,0xa91d21f7}},	//   toz_, rnô_, _risk_, paža,
   {{0xdb0169c9,0x399a0233,0x00000000,0x00000000}},	//   _sclé, büsü_, --, --,
   {{0xed592cea,0x2fdf00e7,0x399a03e0,0x225900f2}},	//   _važi_, _đug_, cüsü_, _pisk_,
   {{0x644e69ca,0x28b7009f,0x443169cb,0x752212e8}},	//   ambi, _अहमि, soz_, _žoze,
   {{0x2139023b,0x0094002d,0x656d024a,0x64a400f6}},	// [65b0] _qysh_, литэ, _ifah, _бања,
   {{0xa91d00cb,0x00000000,0x00000000,0x00000000}},	//   kažn, --, --, --,
   {{0x22593933,0xa91d07c0,0xfbdf0023,0x3eb80113}},	//   _tisk_, jažn, _đê_, _cprt_,
   {{0x6b8169cc,0xdd9500c6,0x2eee0149,0x798200fc}},	//   _selg, тады, äffa_, _neow,
   {{0x3d1109a1,0x6b8169cd,0x61ef009c,0x656d0350}},	//   _देशे_, _pelg, _iocl, _mfah,
   {{0x5274001c,0xd11600ca,0x66ea013c,0x00000000}},	//   _جایز, _יקרה_, təkl, --,
   {{0xe9d10080,0x6b8169ce,0x63a30088,0x00000000}},	//   لغة_, _velg, _önnu, --,
   {{0x6b8169cf,0x2b5e02a1,0x9f34036c,0x66ea013c}},	//   _welg, _egtc_, _сесі, rəkl,
   {{0x6b8169d0,0x3f830533,0x6c554a52,0x26120095}},	//   _telg, _keju_, _акау, ušom_,
   {{0x3f831df6,0x399a0233,0x61ef009c,0x290300c6}},	//   _jeju_, tüsü_, _locl, ąja_,
   {{0xfdf51bc3,0xd5dd00aa,0x00000000,0x00000000}},	//   _आवास_, यांज, --, --,
   {{0x61ef69d1,0x26124480,0x24440212,0x27ee03a8}},	//   _nocl, pšom_, döma_, _eofn_,
   {{0xb6060065,0xa91d00c6,0x00000000,0x00000000}},	//   _aráà, mažo, --, --,
   {{0xd372012b,0x69cb69d2,0xe787385a,0x38ab01df}},	//   شهر_, _hage, _чудо, mør_,
   {{0x69cb69d3,0x66d70174,0x61ef009c,0xa8230018}},	//   _kage, _ịko, _bocl, _لکھن,
   {{0x61ef0036,0xdb0a09af,0x00000000,0x00000000}},	//   _cocl, refø, --, --,
   {{0xed5903ce,0x229b0649,0x3eb8005c,0x59a6034d}},	// [65c0] _kažu_, tàkì_, _sprt_, क्टर,
   {{0x69cb4796,0x09cd00c7,0x3eb800dc,0x61ef0cc2}},	//   _lage, িউটা, _pprt_, _eocl,
   {{0x0d8627c9,0xa3df02e8,0x38ab038c,0x61ef00e3}},	//   влен, णार_, hør_, _focl,
   {{0x61ef6709,0xa91d1ff3,0xed590106,0xbf22245a}},	//   _gocl, važn, _lažu_, _मशीन_,
   {{0xdca32120,0x6da31b10,0x60c90072,0x38ab004d}},	//   иаци, рича, _áemp, jør_,
   {{0x79820167,0x38ab00f2,0x26c705db,0x60c41103}},	//   _seow, dør_, _osno_, mwim,
   {{0xdee341bc,0x69cb1943,0x39405873,0x60c469d4}},	//   _кори, _bage, _šis_, lwim,
   {{0xa91d0e94,0xddc90034,0x38ab01df,0x5fe01e05}},	//   gažo, _mieś, før_, नावल,
   {{0x69cb69d5,0x6e220134,0x38ab052f,0xa91d69d6}},	//   _dage, mnob, gør_, sažn,
   {{0xdb184668,0x2d841423,0xa91d69d7,0xdb1a0206}},	//   leví, _heme_, pažn, _matú,
   {{0x69cb69d8,0x25df10e9,0x60c401bf,0xa3e669d9}},	//   _fage, गाली_, hwim, फान_,
   {{0xa3cb1133,0x69cb69da,0x60c421ef,0x45140033}},	//   _रोज_, _gage, kwim, _সড়ক_,
   {{0x69c069db,0x2d8469dc,0xe8942f68,0xa3df0e50}},	//   meme, _meme_, _саль, णाल_,
   {{0x69c069dd,0x69cb69de,0x61ef69df,0x2d8469e0}},	//   leme, _zage, _socl, _leme_,
   {{0xe8e00028,0x69cb01e2,0xdb18016d,0x7af80103}},	//   _đội_, _yage, levâ, nyvt,
   {{0xd9e5000f,0x2d8452b9,0x69c0535f,0x313503a0}},	//   कायत_, _neme_, neme, гебр,
   {{0x518469e1,0xa91d015c,0x69c03e29,0x6e220dab}},	// [65d0] руса, jažl, ieme, dnob,
   {{0xcbbd0081,0x9e67071c,0x6e220072,0x39460234}},	//   _ইচ্ছ, ناؤن, enob, _mzos_,
   {{0x69c069e2,0x33f40212,0x25a95411,0xf1ab007f}},	//   keme, _växt_, _kcal_, _छापन,
   {{0x69c069e3,0xfd660134,0x3a260085,0x9f4a00b3}},	//   jeme, _izuụ, _njop_, _albó_,
   {{0x69c069e4,0xa91d025b,0x6aba0167,0xc19a0089}},	//   deme, važo, _aptf, _אשרי,
   {{0x69cb69e5,0x30da00c1,0xb4fc00ca,0x60da006e}},	//   _sage, _אַלע, ופדי, _אַלג,
   {{0x69cb5388,0x39460072,0x69c069e6,0x9f4a0032}},	//   _page, _azos_, feme, _jobì_,
   {{0x69c01030,0x683d05fe,0x38ab038c,0xb05b0149}},	//   geme, mèdi, tør_, _osäk,
   {{0x69cb1fbc,0xf1ab2171,0xdd0301d3,0xa91d69e7}},	//   _vage, _छानन, ārēj, ražo,
   {{0x38ab01df,0x2d8469e8,0x69cb1cc0,0x95fe1179}},	//   rør_, _zeme_, _wage, ॉफ्ट_,
   {{0x69cb69e9,0x69c069ea,0x92000065,0x38ab01df}},	//   _tage, beme, _bọ́, sør_,
   {{0x69c069eb,0x8afa0341,0x15e40096,0x78a005bd}},	//   ceme, _אלעז, गाधर_, bumv,
   {{0x81cc0f71,0xa3df274c,0x92000065,0x20030117}},	//   লাম_, णां_, _dọ́, _olji_,
   {{0x3a3f69ec,0xd91a0796,0xa91d0031,0xb8920076}},	//   llup_, _אונל, nažm, _الوع,
   {{0x3ea100aa,0x75ff023b,0x92000032,0x60c40063}},	//   juht_, _gëzo, _fọ́, wwim,
   {{0x92000139,0xa3d400bc,0xb6ba00ca,0x00000000}},	//   _gọ́, _सोर_, _נצפי, --,
   {{0xc0e3550f,0x6604068d,0xb1463621,0x6e2269ed}},	// [65e0] ботк, _ilik, унал, vnob,
   {{0x69c069ee,0x2d8469ef,0xdee61a6d,0x7f860d59}},	//   zeme, _seme_, лози, الان,
   {{0x69c069f0,0x645e00f9,0x81cc0033,0x683d015e}},	//   yeme, _iipi, লাব_, gèdi,
   {{0x69c00990,0x0caa0752,0x831b00c1,0x78a0674b}},	//   xeme, етки_, _טויז, yumv,
   {{0x645e068d,0x224069f1,0x628e69f2,0x69c00e6c}},	//   _kipi, mlik_, lsbo, veme,
   {{0xa91d00cc,0x224069f3,0xbe861673,0x443a0542}},	//   gažm, llik_, _مجرو, _jkp_,
   {{0x660469f4,0x443a69f5,0x69c069f6,0x201a0270}},	//   _olik, _mkp_, teme, mipi_,
   {{0x224069f7,0x201a69f8,0x777a023e,0x78a069f9}},	//   nlik_, lipi_, wbtx, tumv,
   {{0x22400185,0xdd8f0867,0x2df700ca,0x443a0357}},	//   ilik_, _رول_, _עצמך_, _okp_,
   {{0x69c069fa,0x78a069fb,0x22401a4a,0x628e1e71}},	//   seme, rumv, hlik_, ksbo,
   {{0x10370054,0x224069fc,0x69c069fd,0xf1bf0220}},	//   רטים_, klik_, peme, ššie_,
   {{0x0f5700a1,0x628e0f05,0x443a69fe,0x660402a0}},	//   טיים_, dsbo, _akp_, _clik,
   {{0x224069ff,0x645e6a00,0x25a900ee,0x628e112f}},	//   dlik_, _bipi, _vcal_, esbo,
   {{0x66046a01,0x443a0332,0x22402988,0x645e6a02}},	//   _elik, _ckp_, elik_, _cipi,
   {{0x645e0498,0x22406a03,0x66046a04,0x731b0139}},	//   _dipi, flik_, _flik, _bìjẹ,
   {{0xdb0a6a05,0x6fa70455,0x22406a06,0x44f5044e}},	//   lefó, _चाहू, glik_, _впис,
   {{0x80df0789,0x764d0112,0x30156a07,0xb4271673}},	// [65f0] नमें, _ihay, адар, _معدو,
   {{0x645e6a08,0x764d0201,0xdb0a0072,0x629a0031}},	//   _gipi, _hhay, nefó, átoc,
   {{0x22406a09,0x764d0ff6,0xdb0a01bf,0x656f0451}},	//   blik_, _khay, gefü, occh,
   {{0x248d6a0a,0x443a1d67,0x645e024a,0x764d0154}},	//   šemu_, _zkp_, _zipi, _jhay,
   {{0xfce50e20,0x765f013c,0x61ed6a0b,0x764d0350}},	//   роло, _miqy, mjal, _mhay,
   {{0xb09a0054,0x201a6a0c,0x61ed6a0d,0x683d0472}},	//   _בישר, cipi_, ljal, pèdi,
   {{0x6d9c0220,0x5fce045f,0x66ea013c,0x00000000}},	//   _sťaž, _होटल, bəki, --,
   {{0x61ed6a0e,0xe9d93456,0x32096a0f,0xa5bb002b}},	//   njal, тки_, nhay_, lióf,
   {{0x97c51689,0xdb0300fd,0x6e3b6a10,0x38661cb2}},	//   айпе, igné, _ikub, _cuor_,
   {{0x764d025e,0x66043371,0x224007d1,0x998d0067}},	//   _ahay, _slik, zlik_, wień_,
   {{0x66040d1b,0xb4de231e,0xf7453967,0x22406a11}},	//   _plik, णम्_, рено, ylik_,
   {{0x645e6a12,0x7bc36a13,0x2c6b052f,0x38660036}},	//   _sipi, lenu, _kød_, _fuor_,
   {{0x6e3b0010,0x3209008a,0x9f4a0220,0x04463e0c}},	//   _mkub, dhay_, _robí_, иемн,
   {{0x7bc3007a,0x656f00e5,0x46f500d6,0x628e0407}},	//   nenu, acch, _вчит, tsbo,
   {{0x6e3b3ce4,0x68fb6a14,0x645e0010,0x7e67023e}},	//   _okub, lyud, _vipi, _nujp,
   {{0x66041b2e,0x61ed003e,0x628e6a15,0x6d496a16}},	//   _ulik, gjal, rsbo, _ozea,
   {{0x22406a17,0x6564092f,0x9f8642b9,0x443a6a18}},	// [6600] rlik_, _igih, игад, _tkp_,
   {{0x22400ffd,0x3209008a,0x6aa301bf,0x6e3b0b32}},	//   slik_, ahay_, kunf, _akub,
   {{0x670506ed,0x32460c2b,0x201a6a19,0x68fb14c4}},	//   शनिक_, _венг, ripi_, hyud,
   {{0x44386a1a,0x61ed6a1b,0x320902f1,0x7a3e023b}},	//   lor_, cjal, chay_, pëti,
   {{0xfbe2000d,0x0cd40f00,0xdb0a042c,0xd7a60096}},	//   पालम, солю, sefü, _खालच,
   {{0x7bc36a1c,0x2c6b0939,0x44386a1d,0x6e3b3944}},	//   genu, _død_, nor_, _ekub,
   {{0x6b8a1c4b,0x44381789,0x38666a1e,0x6d490634}},	//   rafg, ior_, _suor_, _ezea,
   {{0xada308a4,0x44386a1f,0x6000003e,0x6da30284}},	//   _масл, hor_, _mömm, _миса,
   {{0x44386a20,0xed5721a1,0x7e606a21,0xdddc0559}},	//   kor_, _вот_, _iimp, _kvrž,
   {{0x61ed3b3a,0x764d6a22,0x7e606a23,0x44386a24}},	//   zjal, _shay, _himp, jor_,
   {{0x4fd900c1,0x7e606a25,0x6d4000eb,0xb05b0364}},	//   אַרד, _kimp, _hyma, _präz,
   {{0x7e60003d,0x80a70034,0xa5bb6a26,0x7af702c3}},	//   _jimp, टूडे, cnól, äxte,
   {{0x7e600496,0x443800f3,0xd9430cfc,0x67d41087}},	//   _mimp, for_, _деци, _голу,
   {{0x44386a27,0x7c386a28,0x3cee00a5,0x60db00cb}},	//   gor_, novr, _आपने_, _šumo,
   {{0xd8380b27,0xe69400e3,0x3f870088,0x32090227}},	//   moč_, _البد, ðnum_, thay_,
   {{0x20180010,0xd7a600b6,0x00000000,0x00000000}},	//   _amri_, _खाँच, --, --,
   {{0x661d6a29,0xc95300c1,0x7c380128,0x6d400973}},	// [6610] misk, ַמע_, kovr, _nyma,
   {{0x32090694,0x6e3b6a2a,0x6b880073,0x2c6b0856}},	//   shay_, _skub, _nedg, _rød_,
   {{0xe8e00028,0x6d4001ee,0x7e605fce,0x7c386a2b}},	//   _đời_, _ayma, _bimp, dovr,
   {{0x661d6a2c,0x201800dd,0xb05b0212,0x7e606a2d}},	//   nisk, _emri_, _späd, _cimp,
   {{0x3d11116e,0xd8380087,0x6d400150,0x7e606a2e}},	//   _देखे_, koč_, _cyma, _dimp,
   {{0x00f6040a,0x7c380b18,0xd838033b,0x661d6a2f}},	//   _המשך_, govr, joč_, hisk,
   {{0xa91d0138,0x6d40022b,0x7d0600aa,0x7a3e0216}},	//   maži, _eyma, _üksn, hëtu,
   {{0x6e3b0e7a,0x290d03f3,0xa3d90336,0x888503d9}},	//   _ukub, tzea_, _ठोस_, ближ,
   {{0x44386a30,0x7bc34939,0x6d4000f0,0xfb85001c}},	//   yor_, penu, _gyma, _هدای,
   {{0x44386a31,0xdb180f04,0x30da00c1,0x57e9534f}},	//   xor_, devæ, אַטע, удом_,
   {{0x98b800e8,0x00000000,0x00000000,0x00000000}},	//   ārā_, --, --, --,
   {{0x661d09ce,0x44386a32,0xdb010037,0x9f430065}},	//   gisk, wor_, _gclá, _bojú_,
   {{0x44386a33,0xa91d0d12,0x5a0c00c1,0x12b90033}},	//   tor_, kaži, _בלאַ, ুমোদ,
   {{0xdd990154,0x9f430065,0xd9e510e9,0x00000000}},	//   _blňk_, _dojú_, कावत_, --,
   {{0x44386a34,0x81cc0081,0x91e61676,0x00000000}},	//   ror_, লাস_, бове, --,
   {{0x63bb03ce,0x661d1514,0x9f430af0,0x7cde020a}},	//   đuna, cisk, _fojú_, _hărţ,
   {{0x44386a35,0xe0da0109,0x6e3934bb,0x00000000}},	// [6620] por_, ыва_, dowb, --,
   {{0x7e6902dd,0xa91d6a36,0x443827d9,0x600002c3}},	//   _čepr, gaži, qor_, _tömm,
   {{0x7e600e64,0x8d1a00cd,0x6b880850,0x09a709c3}},	//   _pimp, گزار_, _redg, _गांठ,
   {{0x6da60a7c,0x81cc0081,0x3a3d0174,0x249f09ac}},	//   сида, লাহ_, _nkwp_, šume_,
   {{0x7c3803ce,0x8c46133d,0xc17300ca,0x7e7b00c4}},	//   tovr, беде, _מחר_, _čupe,
   {{0x661d6a37,0x6d40025b,0x20180010,0xdee622be}},	//   zisk, _vyma, _umri_, _логи,
   {{0x7e606a38,0x6d4000a5,0xbea33051,0x7c380ac1}},	//   _timp, _wyma, _нарк, rovr,
   {{0x18742a6e,0x987424e9,0x3f8a0051,0xd910001c}},	//   огия, олиц, _hebu_, ویض_,
   {{0xd8380ac3,0x661d6a39,0x050a0081,0x2902581b}},	//   toč_, visk, রপুর_, áka_,
   {{0x661d00a5,0x7cde00d3,0xdb1802b6,0x7a3e02ac}},	//   wisk, _cărţ, vevæ, eëtt,
   {{0x661d6a3a,0x44270390,0xc5e4009f,0xd83817a0}},	//   tisk, _ın_, गांठ_, roč_,
   {{0xd8380087,0x6f0900b6,0x3f8a01dc,0xa91d4f85}},	//   soč_, _řeck, _lebu_, zaži,
   {{0x661d6a3b,0x2ca612ff,0x05aa00b6,0x3f980117}},	//   risk, nuod_, _कारब, _odru_,
   {{0x661d6a3c,0x3f8a00cc,0x25ad003d,0xdb180537}},	//   sisk, _nebu_, żel_, revæ,
   {{0xdb1a02e2,0x661d6a3d,0xa91d013f,0xdb180537}},	//   _natü, pisk, važi, sevæ,
   {{0xdb1a0103,0x7a3e023b,0x71790077,0x68e4009c}},	//   _ható, pëtu, рбар_, _àids,
   {{0x3f8a005f,0xa5bb38c4,0x26dc00e7,0xdb1801a5}},	// [6630] _bebu_, riód, _hrvo_, levä,
   {{0x3f6713c9,0x20076a3e,0x00000000,0x00000000}},	//   стаб, óni_, --, --,
   {{0x3f8a6a3f,0xdb1800c2,0xdb1a0143,0x10481b60}},	//   _debu_, nevä, _mató, сяти_,
   {{0x8d870084,0xa91d2c5a,0x9f5c0301,0xa01b0364}},	//   сужд, saži, óvá_, _zwöl,
   {{0x69a2000f,0xa91d013f,0xda780220,0x6b656a40}},	//   _गाजी, paži, _atď_, окла,
   {{0x3eb301b9,0x3f8a2fc5,0xdb1800c2,0x7ea30174}},	//   ptxt_, _gebu_, kevä, _ọput,
   {{0x59da1e5e,0x81cc00c7,0x93fc00c1,0x39e9004d}},	//   _मोहर, লার_, רלוי, идко_,
   {{0xdb1a0065,0x2ca60270,0x60dd3360,0x3d1a0285}},	//   _aató, buod_, _krsm, _मेवे_,
   {{0x7cde00d3,0x26dc01a5,0x2d8f6a41,0x75ff023b}},	//   _părţ, _arvo_, mage_, _gëzi,
   {{0xdb1a08ec,0x39430029,0x2d8f6a42,0x2ca000e3}},	//   _cató, ājs_, lage_, áide_,
   {{0x65c63153,0x7e9c044c,0xdb181ee2,0x00000000}},	//   обна, căpă, gevä, --,
   {{0x26dc1419,0xd5aa009d,0x361600d6,0x2d8f2198}},	//   _drvo_, _काळज, ієнт, nage_,
   {{0x89371ea6,0x67d53898,0xa3ce02d5,0xc483141b}},	//   _اعضا, _моду, _रसद_, мляк,
   {{0x2d8f00d6,0xa3d4049d,0x3a29007e,0x798b030a}},	//   hage_, _सोख_, čapu_, _hegw,
   {{0xe36302ec,0x2d8f6a43,0x3f8a6a44,0x7c240076}},	//   дкри, kage_, _rebu_, éiri,
   {{0x91e30d86,0xdb1a0383,0x216761f2,0x260b00a4}},	//   мосе, _katò, жити_, ासणी_,
   {{0x2d8f6a45,0x81cc0081,0x61430131,0x00000000}},	// [6640] dage_, লাল_, дета, --,
   {{0xdfa60037,0x66ea00a7,0xa5bb01f9,0xdb1800f3}},	//   تحري, cəks, ciób, levå,
   {{0x15fe007d,0x2d8f0257,0xee3a2972,0x25df0096}},	//   _उकार_, fage_, анж_, गाची_,
   {{0x3f8a0618,0xee3a23d0,0x9f51037a,0xe0df05aa}},	//   _webu_, шне_, _alzó_, _dyòb_,
   {{0x61e6516f,0x3f8a0498,0x81b001c2,0x3f6a00ae}},	//   _inkl, _tebu_, jiɓi, _виго_,
   {{0xe7ae04f8,0x00000000,0x00000000,0x00000000}},	//   ज्ञप, --, --, --,
   {{0x3d1a0067,0xe8e00028,0xdb1a058a,0xd9e50592}},	//   _मेरे_, _đối_, _rató, कांत_,
   {{0x2d8f6a46,0x0d860b9e,0x00000000,0x00000000}},	//   cage_, _флан, --, --,
   {{0x225e0146,0x1d0700c2,0xdb1a3dc1,0xc5f403e3}},	//   ítky_, _дети_, _catò, _giɓi_,
   {{0xdb186a47,0xb8f200aa,0xd7fa11db,0x00000000}},	//   tevä, _हई_, руи_, --,
   {{0xdb1a6a48,0x61e66a49,0x1be0007f,0xec1300d1}},	//   _obté, _onkl, _गोयल_, _تولد,
   {{0xa5bb037a,0xdb182dd3,0x1b130033,0xf99201f3}},	//   dióc, revä, _ঢুকে_, _آبا_,
   {{0xdb186a47,0x00000000,0x00000000,0x00000000}},	//   sevä, --, --, --,
   {{0x61e64bf1,0x998d00a5,0x63bb2461,0xa91d366a}},	//   _ankl, kieś_, đuno, gažu,
   {{0x2d8f025a,0xf4851ac9,0x7c2a0565,0x00000000}},	//   yage_, _کابی, infr, --,
   {{0xceeb00cd,0x200a6a4a,0x63be0062,0x2d8f020d}},	//   یران_, _albi_, _ebpn, xage_,
   {{0x200a0167,0x3d1a0f35,0x2d8f0b87,0x236c0a39}},	// [6650] _blbi_, _मेले_, vage_, ždja_,
   {{0x61e66a4b,0x35b10378,0x00000000,0x00000000}},	//   _enkl, _झाड़, --, --,
   {{0x2d8f6a4c,0x9f51028d,0x998400c6,0x00000000}},	//   tage_, _alzò_, nomų_, --,
   {{0x24890ab2,0xdc1f0174,0x623500e5,0x80db023a}},	//   _kwam_, _ụ̀ch, _хему, निदे,
   {{0x2d8f6a4d,0x7c2a0088,0xdb030076,0xf1bf0af0}},	//   rage_, fnfr, rgní, _ibá_,
   {{0x798b6a4e,0x2d8f6a4f,0x60cd466b,0x64472024}},	//   _segw, sage_, mwam, nlji,
   {{0x27e900de,0x2c5d022b,0x62953e15,0x60cd6a50}},	//   _đan_, _jňdi_, nszo, lwam,
   {{0x629501c0,0x6447033b,0xdb1a00b3,0x6000042c}},	//   iszo, hlji, _patò, _römi,
   {{0x64470660,0x24896859,0xf1bf38e9,0x00000000}},	//   klji, _nwam_, _mbá_, --,
   {{0x798b2819,0x62956a51,0x2a6c007e,0xb17b0212}},	//   _wegw, kszo, _fudb_, _snål,
   {{0xb8f2550b,0xe739015f,0x24894939,0xa91d0579}},	//   _है_, сен_, _awam_, važu,
   {{0x60cd6976,0x62956a52,0xfa560421,0x00000000}},	//   kwam, dszo, _فرنگ, --,
   {{0xa8790130,0x5fac009d,0x998d0034,0x64470117}},	//   _פאַר, _चालल, zieś_, flji,
   {{0x987a00f5,0x387f2cb2,0x644702dd,0xf1bf0065}},	//   _האסט, mpur_, glji, _abá_,
   {{0x91e6090f,0xe0df0065,0x387f003e,0x62950103}},	//   пове, _arò_, lpur_, gszo,
   {{0x249f00d9,0x24890154,0xdb120103,0xa91d00c6}},	//   šuma_, _fwam_, égér, sažu,
   {{0x78a96a53,0xdb0a001f,0x7e7b6a54,0x24890174}},	// [6660] nuev, lefô, _čupa, _gwam_,
   {{0x81cc00c7,0x13a8037f,0xa3d40c8c,0x20cd0a39}},	//   লাই_, _بندی_, _सोच_, _dži_,
   {{0x324613c7,0x60cd0172,0x24890381,0x00000000}},	//   _неог, awam, _zwam_, --,
   {{0xe7e2007a,0x7d0600aa,0xed5a0ae3,0xf1bf0af0}},	//   _कोना_, _üksk, бое_, _gbá_,
   {{0xdd8f0604,0x75ff0052,0x6d5d037a,0x94000b2b}},	//   اوه_, _gëzu, _úsal, _उवाच_,
   {{0xdce00090,0xa5bb0076,0xddc9007f,0x00000000}},	//   _lemħ, rnói, _cheł, --,
   {{0x7c2a6a55,0x3961013c,0xb05b0dd8,0x671a0e4c}},	//   rnfr, ərsə_, _isäp, _फेंक_,
   {{0x644704fa,0xd9df00bc,0x7e9b00d7,0x00000000}},	//   zlji, _खोदत_, _לסלו, --,
   {{0x3ebf0542,0xdca35ee6,0xe8e00023,0x00000000}},	//   _ćuti_, _пати, _đồi_, --,
   {{0x779204c6,0x6e226a56,0xed5f0138,0xeb9700ae}},	//   ریبا, liob, įžta_, _ниу_,
   {{0xbb4a0fb7,0x7bca0051,0x660f023b,0x60cd6a57}},	//   _الان_, mefu, thck, zwam,
   {{0x6a1606f6,0x6e226a58,0x60cd0034,0x00000000}},	//   _عبار, niob, ywam, --,
   {{0x7e6e01fa,0x35471248,0x7d026a59,0x63a10034}},	//   _lubp, яхов, nyos, ólno,
   {{0x394600f9,0x62950103,0x59b40285,0x62530231}},	//   _iyos_, tszo, ंभकर, içoe,
   {{0x9f5800dd,0x60cd0d2a,0xd7bb00ca,0xb3541009}},	//   _dorë_, wwam, _הצור, екрш,
   {{0x64470087,0x60cd6a5a,0x7bca1ccd,0xe1f30018}},	//   slji, twam, hefu, رسز_,
   {{0x62950018,0x660d6a5b,0xe134004b,0x7bca3f83}},	// [6670] sszo, _ilak, енты, kefu,
   {{0x60cd01e2,0x660d6a5c,0x15eb00a4,0x6aaa6a5d}},	//   rwam, _hlak, टावर_, kuff,
   {{0xda0c3aee,0xd3410018,0x44236a5e,0xe7ed00a8}},	//   िघात_, _شہری, mij_, जाता_,
   {{0xe0df0028,0x44236a5f,0xb8120033,0x39460113}},	//   _trò_, lij_, িচিত_, _oyos_,
   {{0x660d6a60,0x20cd0542,0x3cf90034,0x9c59248c}},	//   _mlak, _uži_, ्नें_, ошку_,
   {{0x44230bbc,0xce6b321c,0x7bca6a61,0x6aaa0d2a}},	//   nij_, _град_, gefu, fuff,
   {{0x80db0490,0x660d02e6,0x39461281,0x7d020124}},	//   निवे, _olak, _ayos_, ayos,
   {{0x4423006c,0x22491d1e,0x2ca002ef,0x88e500e5}},	//   hij_, nlak_, šida_, джие,
   {{0x200e0138,0xdcfb001c,0x7bca6a62,0x70ab0034}},	//   škių_, _ارزش_, befu, _चमोल,
   {{0x660d6a63,0x22496a64,0x99dd025b,0x394607ac}},	//   _alak, hlak_, plňo, _dyos_,
   {{0xe5a64383,0x660d6a65,0x44232388,0x22496a66}},	//   мини, _blak, dij_, klak_,
   {{0x387f6a67,0x00000000,0x00000000,0x00000000}},	//   ppur_, --, --, --,
   {{0x22490270,0x44236a68,0x2101013f,0x78a900fc}},	//   dlak_, fij_, nčią_, quev,
   {{0xb05b0222,0x660d6a69,0x44236a6a,0x9f580383}},	//   _spän, _elak, gij_, _forè_,
   {{0xb7b50134,0xa5bb6a6b,0x7bc16a6c,0x660d6a6d}},	//   hịk, mión, _mblu, _flak,
   {{0x3cee02e8,0xa5bb0181,0x261a0789,0x3a2d2096}},	//   _आपले_, lión, मोशी_, nnep_,
   {{0x7e7c005f,0x44236a6e,0x2bae009d,0x76441dac}},	// [6680] _strp, bij_, _घाला, _ikiy,
   {{0x44230b27,0xa5bb08a8,0x7d020051,0x7c2d0037}},	//   cij_, nión, vyos, éarl,
   {{0x44444ff3,0x216a0752,0x2249231d,0x7bca003e}},	//   _ik_, _мини_, blak_, vefu,
   {{0xe9d900a5,0x7bc16a6f,0xa3e609c3,0x27e903e3}},	//   jdź_, _ablu, फाक_, _ɗana_,
   {{0x44446a70,0x09bc00c7,0x6e224cde,0xdd990154}},	//   _kk_, _অফলা, riob, _alňs_,
   {{0x44446a71,0x7d02620e,0x6aaa5eeb,0x7e6e023e}},	//   _jk_, ryos, tuff, _tubp,
   {{0x7e7c0f1c,0xa0676a72,0x9f430065,0xa5bb6a73}},	//   _utrp, _цара_, _dojó_, dión,
   {{0x44446a74,0x6aaa6a75,0x44236a76,0x7bca2b43}},	//   _lk_, ruff, zij_, sefu,
   {{0x6aaa6a77,0x2d866a78,0x7bca6a79,0xeb9a016d}},	//   suff, mboe_, pefu, _миа_,
   {{0x44446a7a,0x76446a7b,0x22496a7c,0xa5bb0220}},	//   _nk_, _akiy, zlak_, gión,
   {{0xe8e00028,0x2fd80795,0x7c3d01cd,0x44236a7d}},	//   _đổi_, _marg_, _ísra, vij_,
   {{0x44446a7e,0x2fd86a7f,0x6dc402ef,0x09062436}},	//   _ak_, _larg_, _učač, _опен,
   {{0x44236a80,0x224918f0,0x9f58020d,0x00000000}},	//   tij_, vlak_, _doré_, --,
   {{0xa5bb4b1f,0x3fd90081,0x68e20018,0xe1ff0328}},	//   ción, _দক্ষ, _irod, _ción_,
   {{0x44446a81,0x44236a82,0x660d50a5,0xdb1a02c6}},	//   _dk_, rij_, _tlak, _obtí,
   {{0x44441f30,0x44236a83,0x660d6a84,0x645c0a4b}},	//   _ek_, sij_, _ulak, amri,
   {{0x22496a85,0x44230141,0x29046a86,0x69c20113}},	// [6690] rlak_, pij_, nyma_, _mboe,
   {{0x68e26a87,0x224904d6,0x00000000,0x00000000}},	//   _mrod, slak_, --, --,
   {{0x290412ba,0x7c2d0037,0xe0df0154,0x22496a88}},	//   hyma_, éarm, _azòt_, plak_,
   {{0x68e26a89,0x1cb90080,0xa01b0ee1,0x7bc102e7}},	//   _orod, كاتب_, _stöd, _sblu,
   {{0x2fd802a4,0xdb090363,0x3079006e,0x44445123}},	//   _farg_, čníc, _מאָנ, _yk_,
   {{0x44446a8a,0xe9d900a5,0xa5bb08a8,0x2fd86a8b}},	//   _xk_, wdź_, xión, _garg_,
   {{0x7c236a8c,0xbb421510,0x442167e9,0x68e201d3}},	//   rinr, лешк, _mmh_, _arod,
   {{0x68e20106,0xe7d74883,0x656d61ec,0x44216a8d}},	//   _brod, _भोजप, _ngah, _lmh_,
   {{0xa5bb0072,0x61fd6a8e,0x4421036b,0x68e201f7}},	//   tión, _mosl, _omh_, _crod,
   {{0x644501fa,0x61fd0a2c,0x656d0193,0x68e20034}},	//   _nkhi, _losl, _agah, _drod,
   {{0xf62600b4,0x68e26a8f,0x99910018,0x3f910a00}},	//   едно, _erod, őző_, _mezu_,
   {{0x44446a90,0x64454263,0xa5bb0933,0x61fd0029}},	//   _sk_, _akhi, sión, _nosl,
   {{0x68e26a91,0x7e690381,0x3209026d,0x44440133}},	//   _grod, _miep, dkay_, _pk_,
   {{0x7e69282c,0x69d96a92,0x4444009e,0x69db01e9}},	//   _liep, _hawe, _qk_, ldue,
   {{0x42560f86,0x69d96a93,0xa5bb22bf,0x78bb2132}},	//   етат, _kawe, gnós, ltuv,
   {{0xe7ed04a9,0x7e6900a5,0x78bb01b3,0x69db4cae}},	//   जावा_, _niep, otuv, ndue,
   {{0x78bb6a94,0x25a06a95,0x69d96a96,0x10a30915}},	// [66a0] ntuv, _idil_, _mawe, литн,
   {{0x69d90150,0x444400a1,0x24800bb6,0x200e0155}},	//   _lawe, _uk_, _itim_, ófi_,
   {{0x78bb03cf,0x2fd856f7,0x93b700ca,0x3f9101c8}},	//   htuv, _varg_, _אליו_, _dezu_,
   {{0x69d96a97,0x320902e5,0x7e6900a5,0xdd8f048f}},	//   _nawe, ckay_, _ciep, موم_,
   {{0x7e6901a2,0x2fd86a98,0xa5bb037a,0x69db0113}},	//   _diep, _targ_, diól, ddue,
   {{0x69d9041c,0x62810143,0x2ca000c6,0x00000000}},	//   _aawe, ílog, šido_, --,
   {{0x69d96a99,0xada64a4e,0x68e2042d,0x3a24020a}},	//   _bawe, _павл, _srod, timp_,
   {{0x600000a7,0x7e6902ac,0x2480010a,0x69d96a9a}},	//   _gömr, _giep, _otim_, _cawe,
   {{0x2480006c,0x69d96a9b,0x3f910435,0x6253016d}},	//   _ntim_, _dawe, _yezu_, nçoa,
   {{0x25a00706,0x4c9b00a1,0x6253016d,0x2b1600d3}},	//   _adil_, _משמע, içoa, _пьер,
   {{0xddc702dd,0x442109a4,0x69db6a9c,0x25a0009e}},	//   _hujš, _rmh_, bdue, _bdil_,
   {{0x7bda6a9d,0x68e216f4,0xa5bb10d9,0x69d96a9e}},	//   _hatu, _trod, ciól, _gawe,
   {{0x7bda6a9f,0x68e200a5,0x61fd6aa0,0xb05b0329}},	//   _katu, _urod, _rosl, _späm,
   {{0x7bda005a,0x25a00143,0x69d96aa1,0x78ad0146}},	//   _jatu, _edil_, _zawe, ňový,
   {{0x7bda6aa2,0x53340fe9,0x69d92826,0xe7ed0c54}},	//   _matu, герт, _yawe, जारा_,
   {{0x7bda6aa3,0x80ca0081,0x61fd008c,0x656d05bd}},	//   _latu, রিন্, _qosl, _ugah,
   {{0x7e696aa4,0x3209008a,0x1fa76aa5,0x44210113}},	// [66b0] _riep, rkay_, ерег, _tmh_,
   {{0x60db00cc,0x320906a3,0xb4bf09b0,0x44210063}},	//   _šums, skay_, ीबी_, _umh_,
   {{0x7e696aa6,0x4fc4013f,0x3f9102e6,0x25e60efb}},	//   _piep, ыста, _vezu_, _जोडी_,
   {{0x78bb013f,0x7bda6aa7,0xddc700c4,0x09c50033}},	//   ytuv, _aatu, _bujš, _শোনা,
   {{0x7bda6aa8,0x3f911197,0x629a0146,0xddc000d3}},	//   _batu, _tezu_, átov, _simţ,
   {{0x7bda2aea,0x99dd030b,0x69d900bf,0xfaa56aa9}},	//   _catu, plňk, _sawe, вако,
   {{0xf7711e49,0x629a3b31,0x7e696aaa,0x69d96aab}},	//   یاد_, štov, _tiep, _pawe,
   {{0x78bb00c2,0x9f580451,0x09e528f1,0x4ac200c3}},	//   ttuv, _morì_, тоин, _शहरव,
   {{0x69db02a7,0x7bda6aac,0x290b0181,0x78bb1ad1}},	//   rdue, _fatu, áca_, utuv,
   {{0x7bda6aad,0x78bb5873,0x69d96aae,0xd70900c2}},	//   _gatu, rtuv, _wawe, дное_,
   {{0x78bb354b,0x24806aaf,0x69d96ab0,0x00000000}},	//   stuv, _stim_, _tawe, --,
   {{0x7bda6ab1,0xc3250033,0x78bb0d7c,0x3dcf010a}},	//   _zatu, _মুভি_, ptuv, negw_,
   {{0x7bda2ea9,0x59da19af,0x79890633,0x7d0600aa}},	//   _yatu, _मोटर, mbew, _ükst,
   {{0x33d50c10,0x79892cfe,0x2bc414db,0xbf210096}},	//   ліст, lbew, ल्पा, _मधून_,
   {{0x78a93530,0x41b66ab2,0xd4672914,0xb05b007b}},	//   lrev, ксат, тире_, _epäk,
   {{0x2011028d,0x79896378,0xd1320781,0x443102db}},	//   _alzi_, nbew, لمز_, anz_,
   {{0xf99207a6,0x41276ab3,0x91036ab4,0x60db0141}},	// [66c0] ירן_, вото_, апте, _šumr,
   {{0x25e609a1,0x00000000,0x00000000,0x00000000}},	//   _जोती_, --, --, --,
   {{0x78a90ab2,0xaad000c3,0xada20206,0xa01b1489}},	//   hrev, _थैंक, _ľúbi, _stöc,
   {{0xf53f0bc6,0x78a907d0,0x798901c0,0x23b200b6}},	//   mgår_, krev, jbew, _जाँद,
   {{0x77f10714,0x79890381,0x78a96ab5,0x00000000}},	//   _अचूक_, dbew, jrev, --,
   {{0x62536ab6,0x78a92096,0xaa851515,0xe0df022b}},	//   nçon, drev, zmýš, _izòp_,
   {{0x3cee0067,0xf53f004d,0x629c6ab7,0x63a10034}},	//   _आपके_, ngår_, nsro, ólni,
   {{0x7bda068d,0xc3330130,0x58d8167b,0x629c01bf}},	//   _watu, יוו_, едия_, isro,
   {{0xd83a0138,0x78a96ab8,0x9f586ab9,0xe786002d}},	//   дэн_, grev, _morí_, куно,
   {{0xad1b0054,0xa5bb0103,0x57f41543,0x9f580032}},	//   _חומר, ciój, упот, _lorí_,
   {{0xa3c8121d,0x65952f34,0x7e7b0218,0x00000000}},	//   ोजन_, лану, _čupk, --,
   {{0x78a90537,0xf53f052f,0xe7e20ff9,0xa92300c6}},	//   brev, dgår_, _कोरा_, _įžva,
   {{0x78a900c9,0x00000000,0x00000000,0x00000000}},	//   crev, --, --, --,
   {{0x3cf5009d,0xa3a40831,0xecc40033,0x6b986aba}},	//   ्हते_, ијск, _এছাড, navg,
   {{0x2bc46abb,0x442d02e6,0x333a0072,0x07a307c8}},	//   ल्या, đe_, _cxpx_, _тајн,
   {{0x22843051,0xa5bb0143,0x644e0381,0x35b500e5}},	//   рург, cnóp, albi, _сбир,
   {{0x9f580032,0x00000000,0x00000000,0x00000000}},	// [66d0] _dorí_, --, --, --,
   {{0x44276abc,0x2bc40251,0xfbc4030b,0x15eb00c3}},	//   _ön_, ल्मा, ल्मम, टाकर_,
   {{0x62670bf4,0x9f580af0,0x78a96abd,0xaca30023}},	//   _لاحق, _forí_, zrev, _trừn,
   {{0x6287003d,0x9f580af0,0x78a96abe,0x00000000}},	//   mpjo, _gorí_, yrev, --,
   {{0x61ef377e,0x3cf30096,0xada401b3,0x629e0141}},	//   _incl, ंमधे_, раіл, _zvpo,
   {{0xe7e200c3,0x1c4404a1,0xdddc04a8,0x00000000}},	//   _कोला_, анім, _turş, --,
   {{0x63b501d3,0xe458006e,0x7989091f,0x6e9460cf}},	//   igzn, דיגט_, tbew, _вису,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79892cfe,0xb4bf007f,0x00000000,0x00000000}},	//   rbew, ीबो_, --, --,
   {{0x7d0402fd,0x79894762,0x00000000,0x00000000}},	//   äise, sbew, --, --,
   {{0x61ef6abf,0x63b80149,0x79892ead,0xa5bb01f9}},	//   _oncl, _övni, pbew, ciók,
   {{0xb90c0065,0xa3c800aa,0x00000000,0x00000000}},	//   _jimọ_, ोड़न_, --, --,
   {{0xe8ee42a1,0xb05b0084,0x18a518d4,0x98a50cba}},	//   _ул_, _epäi, _салм, _силе,
   {{0x61ef2e86,0x629c01cb,0xe6120e27,0x2c790154}},	//   _ancl, tsro, _گشت_, _mèd_,
   {{0xdceb003d,0x62532db1,0xe9ff0023,0x629c6ac0}},	//   bagħ, rçon, _ngẫm_, usro,
   {{0xb5fb6ac1,0xf53f2dc9,0x00000000,0x00000000}},	//   rmác, rgår_, --, --,
   {{0x76460138,0x6253020d,0x463b006e,0x629c59ab}},	// [66e0] moky, pçon, _רעפע, ssro,
   {{0xb90c0065,0x28a600aa,0xe0d704d9,0x61ef620a}},	//   _aimọ_, _खिसि, ыву_, _encl,
   {{0x442a6ac2,0x0d861f3e,0x03d7006e,0xdd9900d4}},	//   mib_, глен, _גוים_, _soňa_,
   {{0x442a6ac3,0xf2d30341,0x3ea76ac4,0x76464b5e}},	//   lib_, _פער_, ánta_, noky,
   {{0x7bc301bf,0x40950291,0xcfcf0033,0x00000000}},	//   ffnu, _врст, রাজন, --,
   {{0x442a6ac5,0xd0120037,0x76460172,0x80ca0033}},	//   nib_, _الس_, hoky, রিদ্,
   {{0x47dc0033,0x6b980572,0x00000000,0x00000000}},	//   বামী, ravg, --, --,
   {{0x442a6ac6,0x6b980e3e,0xaa540291,0x249f00e8}},	//   hib_, savg, јвиш, šumi_,
   {{0x442a6ac7,0x48142863,0xdb08016d,0x7e7b6ac8}},	//   kib_, имис, _abdô, _čupi,
   {{0x442a584b,0x7e7500b3,0x99dd0206,0x2bae0961}},	//   jib_, _yuzp, dlňu, _घाटा,
   {{0x6fc602e8,0x442a6ac9,0x7c2a6aca,0x5fc60966}},	//   र्यं, dib_, mifr, र्यल,
   {{0x3f9a0134,0x7ae8009c,0x76460172,0x245601cd}},	//   hapu_, _irdt, goky, væma_,
   {{0x2ed10edf,0x3f9a267e,0x27f85748,0x00000000}},	//   _सन्त, kapu_, örns_, --,
   {{0x5fc6142e,0x249203a8,0xdb010503,0x00000000}},	//   र्मल, _dwym_, _gcló, --,
   {{0x1797040a,0xf1bf0139,0x32020094,0xd25b6acb}},	//   _גדול_, _amáa_, _boky_, еца_,
   {{0x2bc40034,0x7e6200c4,0x00000000,0x00000000}},	//   ल्ता, jmop, --, --,
   {{0x442a6acc,0xaca30019,0xb6341673,0x629a5374}},	// [66f0] bib_, _trứn, _دعوت, átor,
   {{0x442a6acd,0x351c00ca,0x2c7902f1,0x3f9a0113}},	//   cib_, _רוזנ, _rèd_, gapu_,
   {{0x09ac0081,0x629a43c5,0x2c796ace,0x00000000}},	//   ক্যা, štor, _sèd_, --,
   {{0x7bc86acf,0x64476ad0,0x6285019f,0x61ef3d0f}},	//   _abdu, loji, _itho, _uncl,
   {{0x563800c1,0x7ae3023e,0x3f9a0174,0x7ae80076}},	//   נאדע_, wvnt, bapu_, _ardt,
   {{0x644739c1,0xab291107,0xc31c0081,0x6a856752}},	//   noji, кола_, _দুটি_, алка,
   {{0x3d951bb8,0x62850b14,0x200f00c6,0x00000000}},	//   _вибр, _jtho, ūgis_, --,
   {{0x442a6ad1,0x64470010,0x6d5700a7,0x20036ad2}},	//   zib_, hoji, əxan, _hoji_,
   {{0x200303ce,0x442a31dd,0x64476ad3,0x7c2a6ad4}},	//   _koji_, yib_, koji, bifr,
   {{0x442a6ad5,0x64471114,0x62856ad6,0x6e2b01df}},	//   xib_, joji, _otho, ligb,
   {{0xe7396ab3,0x64476ad7,0x628501fa,0x442a6ad8}},	//   тен_, doji, _ntho, vib_,
   {{0x25e6034d,0x6e2b0032,0x20030332,0x6d5d0042}},	//   _जोशी_, nigb, _loji_, _úsas,
   {{0x320218ed,0x62856ad9,0x76466ada,0x661d023b}},	//   _roky_, _atho, roky, ërka,
   {{0x64476adb,0xb4d60f35,0x799b029a,0x25e600b7}},	//   goji, _सनी_, lauw, _जोरी_,
   {{0x442a6adc,0xe29700d3,0x6e2b0009,0x527600d3}},	//   rib_, иар_, kigb, ругу,
   {{0x442a6add,0x99dd0146,0xcb1200c1,0xb5fb48fd}},	//   sib_, plňu, קלן_, lmán,
   {{0x62856ade,0xd02600c6,0x442a6adf,0x3f9a6ae0}},	// [6700] _etho, амай, pib_, tapu_,
   {{0x8fa610f7,0x442a6ae1,0x64476ae2,0xc7b800e7}},	//   раже, qib_, coji, biđu_,
   {{0x81cb0f71,0x23fb040a,0x799b06a8,0x74da0179}},	//   লয়_, _ספטמ, kauw, _पैतृ,
   {{0x3f9a6ae3,0x66040e1d,0x00000000,0x00000000}},	//   sapu_, _joik, --, --,
   {{0x2ca000e3,0x799b01c2,0x3ddf0381,0x66046ae4}},	//   éid_, dauw, _dauw_, _moik,
   {{0x8aa62a59,0xfaa621be,0x225201ff,0x9f5800ee}},	//   арид, ашин, llyk_, _torà_,
   {{0xbea31d7b,0x7c2a6ae5,0x00000000,0x00000000}},	//   _марк, rifr, --, --,
   {{0x3f980085,0x4aa70789,0x3ddf01c0,0xce340470}},	//   _heru_, _गिरव, _gauw_, _اورک,
   {{0x64470051,0x9a670037,0xc9140033,0xb7bc01d3}},	//   yoji, جميل_, াপ্ত_, liģi,
   {{0xf8062436,0x6604009c,0x3f9801c2,0x9cd700ca}},	//   рчин, _aoik, _jeru_, _דומה_,
   {{0xd6d76ae6,0xbb46013d,0x66166ae7,0xf1d60034}},	//   атя_, _тежк, _blyk, डजान,
   {{0x47dc0081,0x3a2603a9,0xa01b0233,0x00000000}},	//   বাধী, _umop_, _atöl, --,
   {{0x64476ae8,0x0ca40034,0x66040062,0x79820032}},	//   toji, _ऑटोम, _doik, _ifow,
   {{0x224b0167,0x78a2007e,0x00000000,0x00000000}},	//   _skck_, _ivov, --, --,
   {{0x99dd025b,0x64476ae9,0x66166aea,0x443a0167}},	//   plňt, roji, _flyk, _djp_,
   {{0x52142c13,0x2003006d,0x644717a0,0x660401e9}},	//   одст, _soji_, soji, _goik,
   {{0x64476aeb,0xcf9b0396,0x443a0063,0x7c283286}},	// [6710] poji, вје_, _fjp_, _omdr,
   {{0x96da033a,0x3ea7058a,0xaaa702d5,0x3f9800e8}},	//   _बनाउ, ánto_, _गिलक, _ceru_,
   {{0x62856aec,0x22520f5a,0x9f580042,0x3ddf1cab}},	//   _utho, blyk_, _porá_, _pauw_,
   {{0x7d0b0149,0x09ac0081,0x249f01d3,0x3f980065}},	//   tygs, ক্তা, šumu_, _eeru_,
   {{0x224901e9,0xddce020a,0x764d0350,0xfce5290e}},	//   moak_, _subţ, _mkay, соло,
   {{0xda78025b,0x79820139,0x5fc60557,0x224901e9}},	//   _buď_, _afow, र्दल, loak_,
   {{0x60cf03a9,0x9f583536,0x7a3e00e8,0x3e7702a1}},	//   _hpcm, _torá_, zīte, _oħti_,
   {{0xe9d96aed,0x7c280ac1,0x22490a00,0xb05b00c2}},	//   уки_, _emdr, noak_, _epät,
   {{0x6e296aee,0x2bc4009d,0x9d154a30,0xb5fb0103}},	//   _imeb, ल्हा, _удач, tmán,
   {{0x764d55ba,0x2d9d6aef,0x9610097c,0x799b01c2}},	//   _akay, lawe_, ास्ट_, sauw,
   {{0x224903f3,0xb5fb0068,0x660402fd,0x26ce0154}},	//   koak_, rmán, _poik, _cpfo_,
   {{0xf409193b,0x645e01e5,0xa01b0ce3,0x2d9d6af0}},	//   _אפ_, _shpi, _stöl, nawe_,
   {{0x660400c2,0x6e290129,0x7c280150,0xddc9010a}},	//   _voik, _mmeb, _ymdr, _akeŋ,
   {{0x2d9d0193,0x16040096,0x638322fb,0xb5fb003e}},	//   hawe_, _लवकर_, згра, lmál,
   {{0x2d9d62c1,0x224901c8,0x00000000,0x00000000}},	//   kawe_, foak_, --, --,
   {{0x3f980d4c,0x22490a00,0x66160856,0x6e3b0361}},	//   _seru_, goak_, _ulyk, _njub,
   {{0x515607df,0x287a006e,0x487a006e,0x3f980133}},	// [6720] ству, ָנעמ, ָטעס, _peru_,
   {{0x6e296af1,0x3a2d00de,0x80ca0033,0x09d40285}},	//   _ameb, hiep_, রিল্, _दस्य,
   {{0x3f986af2,0xe9ff00de,0x22490a00,0x6d5b6af3}},	//   _veru_, _ngắm_, boak_, _azua,
   {{0xb05b6af4,0x2d9d00bf,0x443816f7,0x22490085}},	//   _spät, gawe_, lnr_, coak_,
   {{0xdd990038,0x6e3b031a,0x3a2d6af5,0xa5bb266c}},	//   _deň_, _djub, diep_, miót,
   {{0x69cb02dc,0x61e44295,0x60c4023b,0x6e2900ac}},	//   _abge, ldil, mtim, _emeb,
   {{0x8ae6004d,0xb05b007b,0x2d9d6af6,0x78a200f2}},	//   сілл, _epäs, bawe_, _svov,
   {{0x61e46af7,0x8f3700d7,0xb5fb01cd,0x00000000}},	//   ndil, _האלו_, gmál, --,
   {{0xd90e110a,0x799902a1,0x9f580233,0x26ce0090}},	//   عیت_, _deww, _borç_, _spfo_,
   {{0x47341da3,0x765f023b,0x22490a00,0x61e46af8}},	//   жнос, _shqy, zoak_, hdil,
   {{0x661d00dd,0x60c41d2d,0x4438020a,0xd5b10076}},	//   ërko, htim, dnr_, وفد_,
   {{0x0f5700a1,0x6b9a6af9,0x224901e9,0x7999009e}},	//   מיים_, _hetg, xoak_, _geww,
   {{0x60c400dd,0x61e46afa,0x00000000,0x00000000}},	//   jtim, ddil, --, --,
   {{0x4adc1e5e,0x61e45c3b,0x395901bf,0x65760103}},	//   _मनाव, edil, üsse_, _egyh,
   {{0x60c4013f,0x1dc86afb,0x6b9a6afc,0x9f41023b}},	//   etim, रभात, _metg, rdhë_,
   {{0x533407df,0x60c4023b,0x61e412ff,0x764d6afd}},	//   чест, ftim, gdil, _ukay,
   {{0x60c46afe,0x62536aff,0x22490a00,0x3e7e00fc}},	// [6730] gtim, nçoi, roak_, _aït_,
   {{0x22490a00,0x6b9a0138,0x2489061d,0x2d9d6b00}},	//   soak_, _netg, _itam_, wawe_,
   {{0xa3e2152c,0x61e43418,0x3f810150,0xa5bb2733}},	//   _नोट_, bdil, rchu_, biót,
   {{0x3f8101b5,0x64556b01,0x998d5c56,0x7c3802ac}},	//   schu_, llzi, kneš_, envr,
   {{0x2d9d6b02,0x60c46b03,0xfe70001c,0xeb9900f6}},	//   rawe_, ctim, ردم_, аил_,
   {{0x2bc4000d,0x31d10174,0x3ea10052,0x998d6b04}},	//   ल्ला, _ịrịọ_, psht_, dneš_,
   {{0xb4d61317,0xf99100e3,0x661d02ef,0x63a8007f}},	//   _सन्_, وبة_, khsk, ódni,
   {{0x6e296b05,0x291f0a00,0x6b9a0a88,0x8e74071c}},	//   _umeb, tzua_, _eetg, _رافض,
   {{0xb5fb6b06,0x2489023e,0x6b9a015e,0x3a2d01d0}},	//   rmál, _ntam_, _fetg, riep_,
   {{0xd82500d6,0xb5fb6b07,0xa7fc026a,0x61e416aa}},	//   ідни, smál, smın, zdil,
   {{0x09c300c7,0x61e46b08,0xfd640294,0xe0df0154}},	//   ্যবা, ydil, ktrọ, _kyòs_,
   {{0x3ced6b09,0x60c46b0a,0xe0df0383,0xe56a00d3}},	//   _krev_, ytim, _osò_, иинд_,
   {{0x9556300d,0x60c41a4a,0xdb0a0212,0x44386b0b}},	//   تخدا, xtim, uffö, tnr_,
   {{0xf1bf0a43,0x69c90b7c,0x44380169,0x00000000}},	//   _acá_, lfee, unr_, --,
   {{0xe7e23ffc,0xe0df0032,0xe29a35ca,0x25a900bd}},	//   _कोटा_, _asò_, раб_, _fdal_,
   {{0x60c46b0c,0x661d02db,0x69c901cb,0x64550131}},	//   ttim, chsk, nfee, alzi,
   {{0x68e90103,0xe9ff0023,0xa5bb002b,0xd01202d1}},	// [6740] nved, _ngậm_, riót, ولر_,
   {{0x2f561c66,0xe29a15de,0xb05b09b5,0xa3e20336}},	//   отес, _као_, _spär, _नोच_,
   {{0xdc2a001c,0x3e7702a1,0x69c96b0d,0x00000000}},	//   یسته_, _oħtu_, kfee, --,
   {{0x60c46b0e,0x3ced02fe,0x6b9a6b0f,0xdd8f08ba}},	//   ptim, _brev_, _setg, نوم_,
   {{0x973c0039,0x16b6218b,0xce340018,0x69c90503}},	//   maće, _अम्ब, _ہوسک, dfee,
   {{0x973c0039,0x70d900c1,0x7a3e00d9,0x3ced0e9f}},	//   laće, _פֿרו, dīta, _drev_,
   {{0x69c96b10,0x6b9a1cab,0x68e96b11,0x6d6300c6}},	//   ffee, _vetg, eved, _įvaž,
   {{0x6b9a0a9f,0xddc900d3,0xa8a60e20,0x973c007e}},	//   _wetg, _vieţ, орок, naće,
   {{0xdcf80068,0xd7fa311c,0xb4c9007a,0x3ced6b12}},	//   _دہشت_, аун_, _ईहे_, _grev_,
   {{0x7e7c6b13,0x973c0d62,0xe1ff0037,0x6253020d}},	//   _kurp, haće, _thóg_, rçoi,
   {{0x09ac00c7,0x8f7b0105,0xdb180006,0x24896b14}},	//   ক্ষা, יניק, tevõ, _stam_,
   {{0x7e7c6b15,0x973c0e94,0xe1ff00fe,0x270e013c}},	//   _murp, jaće, _khóe_, həng_,
   {{0x7e7c0634,0x973c0095,0xa9260037,0x628e1cab}},	//   _lurp, daće, _بعضه, epbo,
   {{0x7bd800aa,0xddc90031,0x3ceb00b7,0x7e7c0474}},	//   nevu, _mieš, चिते_, _ourp,
   {{0xfd560134,0x00000000,0x00000000,0x00000000}},	//   tubọ, --, --, --,
   {{0x25a90a00,0x09ac0081,0x973c0106,0xe1ff002b}},	//   _udal_, ক্রা, gaće, _riós_,
   {{0xa01b0149,0x64405ef4,0x7e7c01e9,0x628e0f5a}},	// [6750] _utök, émic, _aurp, apbo,
   {{0x2007003e,0x7bd800b6,0x37d80033,0x74280076}},	//   ðni_, jevu, তাকর, _وكيف_,
   {{0x44310390,0x7bd865e0,0x80a70557,0x88c20033}},	//   miz_, devu, _चिके, ্টিক,
   {{0x3cfd01fa,0xdb030364,0x3ced00d7,0x68e90565}},	//   txwv_, rgnü, _prev_, yved,
   {{0xe0df0036,0xddc901d3,0xb4c900aa,0x7c260154}},	//   _usò_, _cieš, _ईहो_, _ůkra,
   {{0x44316b16,0x7bd86b17,0x68e96b18,0x69c90381}},	//   niz_, gevu, vved, wfee,
   {{0x4ea40cc6,0x60d9008b,0x7e7c0634,0xb5fb0103}},	//   _орта, şamı, _gurp, rmáj,
   {{0xdce800a5,0x44310a00,0x13e40081,0x68e901d3}},	//   _śląs, hiz_, মায়, tved,
   {{0x44316b19,0x69c96b1a,0xe8f61402,0x25e61981}},	//   kiz_, rfee, злы_, _जोगी_,
   {{0x872561b3,0x7bd8013d,0x68e96b1b,0x69c90a9f}},	//   змож, cevu, rved, sfee,
   {{0x6c6a00fb,0x44316b1c,0x68e96b1d,0xe9450470}},	//   _اللہ_, diz_, sved, _کرای,
   {{0x3ebe004d,0x19b800ae,0x26c50231,0x00000000}},	//   _åtte_, _душь_, rtlo_, --,
   {{0x973c0039,0x44316b1e,0x26c500d8,0x00000000}},	//   vaće, fiz_, stlo_, --,
   {{0x44316b1f,0x00000000,0x00000000,0x00000000}},	//   giz_, --, --, --,
   {{0x973c0e94,0x366a0284,0x245601cd,0x00000000}},	//   taće, _лако_, næmi_, --,
   {{0x15466561,0x05764345,0xd5ed020b,0x00000000}},	//   _нейм, _عابد, _già, --,
   {{0x973c04a3,0x7e7c6b20,0x55bb00ca,0x2bdc030b}},	// [6760] raće, _surp, _המפו, _यसला,
   {{0xddc92a5d,0x7e7c00a1,0x44316b21,0x973c007e}},	//   _rieš, _purp, ciz_, saće,
   {{0x973c0106,0x7ae10154,0xa2a600b6,0x00000000}},	//   paće, _nslt, _छिट्, --,
   {{0xddc96b22,0x644e6b23,0x25a2061d,0x7bc16b24}},	//   _pieš, lobi, nakl_, _aclu,
   {{0x20170068,0x9f430383,0xf1b3021e,0x7bd80206}},	//   áció_, _lajè_, _אסר_, tevu,
   {{0x7e7c6b25,0xddc901b3,0x61e601e8,0x00000000}},	//   _turp, _vieš, _hakl, --,
   {{0x60120653,0x61e66b26,0x9cfe0033,0x644e0634}},	//   _næmi, _kakl, ্ছেন_, iobi,
   {{0xddc90029,0x2d800181,0x44316b27,0x644e6b28}},	//   _tieš, žieb_, ziz_, hobi,
   {{0x44316b29,0x61e66b2a,0x0c260b2e,0x200a6b2b}},	//   yiz_, _makl, _еман, _kobi_,
   {{0xe1ff0019,0x644e0106,0x7bc10037,0x9f51037a}},	//   _khóc_, jobi, _gclu, _gozó_,
   {{0x644e6b2c,0x44316b2d,0x61e61d91,0x6fc10f35}},	//   dobi, viz_, _oakl, र्टू,
   {{0xcb1307a6,0x8afb00a1,0x2d860154,0x60120088}},	//   _אלע_, _להבי, ncoe_, _dæmi,
   {{0x44316b2e,0xa9c500bf,0x2ca60bb6,0x7a3e00e8}},	//   tiz_, _آزمو, nsod_, līto,
   {{0x68e23cc2,0xb3472226,0x644e030a,0x237a00b3}},	//   _isod, _naçõ, gobi, _cgpj_,
   {{0x4431047e,0x268a0037,0xe1ff0023,0x25a26b2f}},	//   riz_, _اختي_, _nhóc_, bakl_,
   {{0x443107d1,0x61e60357,0x75480103,0x00000000}},	//   siz_, _cakl, észé, --,
   {{0x61e602e6,0x200a6b30,0x44310487,0x644e0d2a}},	// [6770] _dakl, _bobi_, piz_, bobi,
   {{0x200a6b31,0xdb1a1ba6,0x2ca60270,0x3f6700ae}},	//   _cobi_, _actí, dsod_, птеб,
   {{0x3ea70068,0x200a0c7e,0xe1ff00fe,0x00000000}},	//   ént_, _dobi_, _chóc_, --,
   {{0x5d350018,0x61e60063,0x9f4a016d,0xfd590af0}},	//   وفائ, _gakl, _robô_, _igbẹ,
   {{0x200a02c5,0x00000000,0x00000000,0x00000000}},	//   _fobi_, --, --, --,
   {{0x61e66b32,0xa3cd09c3,0x69c20231,0x764f0b87}},	//   _zakl, रभि_, _acoe, hocy,
   {{0x61e601e8,0x6281025b,0x68e26b33,0xe45f00c2}},	//   _yakl, íloh, _asod, ytön_,
   {{0x200a2ce5,0x00000000,0x00000000,0x00000000}},	//   _zobi_, --, --, --,
   {{0x68e20018,0x320b0034,0xa3cd42d4,0x629a0103}},	//   _csod, _mocy_, रभा_, átoz,
   {{0x69c20575,0xb9050965,0xe63000a7,0x00000000}},	//   _ecoe, _पन_, _bəşə, --,
   {{0x644e1100,0x68e26b34,0xfb150037,0x9f434231}},	//   vobi, _esod, _تواج, _bajé_,
   {{0xcb120054,0x320b0034,0xf93500e5,0x64a605b8}},	//   _שלא_, _nocy_, _охлю, мама,
   {{0xfd590032,0x00000000,0x00000000,0x00000000}},	//   _agbẹ, --, --, --,
   {{0xb4ce0b5f,0x61e66b35,0xe45f00c2,0x69db66cc}},	//   _रही_, _sakl, stön_, leue,
   {{0x61e66b36,0x200a4d75,0xb3470131,0x09e00033}},	//   _pakl, _robi_, _raçõ, ভারা,
   {{0x27e70682,0x2d9f02dc,0x644e6b37,0x69db0364}},	//   _hann_, _neue_, sobi, neue,
   {{0x27e702d6,0x037a010d,0x600a061b,0x6283020d}},	// [6780] _kann_, _وحدت_, онам_, _énon,
   {{0x27e70154,0x2ca60087,0x25a06b38,0x69db6b39}},	//   _jann_, vsod_, _heil_, heue,
   {{0x27e70e78,0x09be0033,0x25a00365,0x00000000}},	//   _mann_, _আসসা, _keil_, --,
   {{0xa3c80961,0x27e703ea,0x3eba21d8,0x3ea700ae}},	//   ोजक_, _lann_, rupt_, ânta_,
   {{0x3cfa0067,0x200a6b3a,0x25a0007a,0x6da31a57}},	//   ्हें_, _tobi_, _meil_, тича,
   {{0xb5fb00e3,0xfa8a1eca,0x2d9f0313,0xa01b02c3}},	//   rmái, осий_, _eeue_, _stöv,
   {{0x25a00257,0x2a7e43b5,0xa6e10088,0x69db0364}},	//   _oeil_, _qutb_, óðle, feue,
   {{0xe1ff0028,0x3162022e,0x27e701b9,0xc7ce00de}},	//   _khóa_, _kzkz_, _aann_, _cống_,
   {{0x27e76b3b,0xada300c6,0x973c14f3,0x00000000}},	//   _bann_, _шатл, daća, --,
   {{0x395800d9,0x00000000,0x00000000,0x00000000}},	//   ārs_, --, --, --,
   {{0x27e702d6,0x764f1670,0x25a06b3c,0x5c3722fe}},	//   _dann_, tocy, _beil_, _קרבן_,
   {{0xa01b0149,0x25a0010b,0x6e22338f,0x27e7036b}},	//   _utöv, _ceil_, nhob, _eann_,
   {{0xadc300de,0x27e732a7,0xd90f0018,0xc8c8001c}},	//   _hoản, _fann_, _نیٹ_, _روغن_,
   {{0xe72f00cd,0xe6300092,0x27e76b3d,0x24801044}},	//   اصی_, _təşə, _gann_, _duim_,
   {{0x6adc1f88,0x450700c7,0x2a66022e,0x25a000d6}},	//   _मनोर, _লেখক_, _khob_, _feil_,
   {{0x69c06b3e,0x25a06b3f,0x68ed0357,0x00000000}},	//   ngme, _geil_, _šadi, --,
   {{0x48bc0081,0x04670a11,0x27e76b40,0x2a6600f0}},	// [6790] _অনুর, _отом, _yann_, _mhob_,
   {{0x25a011c5,0xdb1a00b3,0x27e70231,0x6d5d009c}},	//   _zeil_, _octà, _xann_, _ùsai,
   {{0x53350012,0xb275689d,0x00000000,0x00000000}},	//   _чент, _плош, --, --,
   {{0xdb030131,0x62532c68,0xf2d20142,0x00000000}},	//   banê, rços, _געט_, --,
   {{0x2ca90080,0x69c000ca,0x656b01b5,0x69db0428}},	//   éad_, dgme, _ùghd, veue,
   {{0xc7ce00ef,0x6b656b41,0x660d076c,0x200500aa}},	//   _sống_, нкла, _loak, _õli_,
   {{0xe7e504a9,0x27e76b42,0xdb03023b,0x69db01bf}},	//   _कसबा_, _rann_, manë, teue,
   {{0x2a6601fa,0x27e76b43,0xaca30294,0x3ebe0149}},	//   _chob_, _sann_, _arụn, _åtta_,
   {{0xb4ce3922,0x2919446d,0x973c2cc8,0x27e76b44}},	//   _रहे_, ása_, vaća, _pann_,
   {{0x24806b45,0xddc90181,0x25a01f2c,0x69db00b3}},	//   _ruim_, _dieť, _seil_, seue,
   {{0x98ab0b88,0x27e76b46,0x2480009b,0xe9ff00de}},	//   ğlık_, _vann_, _suim_, _ngầm_,
   {{0x27e701bf,0xc7ce0028,0x98ab026a,0x660d0167}},	//   _wann_, _uống_, şlık_, _coak,
   {{0x27e706a3,0x973c04a3,0x660d6b47,0x24800428}},	//   _tann_, raća, _doak, _quim_,
   {{0x25a002dc,0x33d502ec,0x7d040084,0x26c70e27}},	//   _weil_, кіст, äisi, _قطعی_,
   {{0x78a90472,0x25a06b48,0x15eb00a3,0xaca40129}},	//   lsev, _teil_, _जोकर_, mpụt,
   {{0x79891114,0x91e36b49,0x6e220415,0xa3dc00a3}},	//   ncew, лосе, xhob, _ठसक_,
   {{0x527500d3,0x78a96b4a,0xdb0102b6,0x888c006e}},	// [67a0] туру, nsev, _udlæ, ַראַ,
   {{0x78a96b4b,0x6564348a,0xdb030052,0x2cbd01cb}},	//   isev, _izih, ganë, duwd_,
   {{0x6e220201,0x44446b4c,0x2cbd01c0,0xf41f007b}},	//   thob, _ij_, euwd_, rpät_,
   {{0xa01b0149,0x78a96b4d,0x6fc20096,0x645c0572}},	//   _stöt, ksev, _लावू, llri,
   {{0x22406b4e,0x98b800d9,0x644102c6,0xb4ce1024}},	//   mnik_, ārī_, čliv, _रहो_,
   {{0x22406b4f,0x6e22092f,0xb4ce0aa1,0x973c00c4}},	//   lnik_, shob, _रहै_, daćn,
   {{0x6e2200e3,0x63a30006,0x504336cd,0xddc90220}},	//   phob, _õnne, _серб, _sieť,
   {{0xfce60cf5,0x58d443a9,0x2a66023e,0x22406b50}},	//   _побо, воит, _qhob_, nnik_,
   {{0xdd8f0602,0xd7f000e3,0x69c06b51,0x1c461602}},	//   _طول_, لكة_, rgme, _знам,
   {{0x7644006d,0x22401abe,0x3867009c,0x2f260032}},	//   _ajiy, hnik_, _chnr_, _gígé_,
   {{0x65952644,0xdb0600c2,0x2cb00138,0x65646b52}},	//   кану, ämäl, žodį_, _azih,
   {{0x44446a90,0x39466b53,0x5fc70096,0xdb030216}},	//   _aj_, _txos_, _लाभल, zanë,
   {{0xba290037,0x44446b54,0x00000000,0x00000000}},	//   _تسلم_, _bj_, --, --,
   {{0xe45f003e,0x65640357,0x4ad40096,0x7644039f}},	//   mtök_, _dzih, _दहाव, _ejiy,
   {{0x24560088,0x81c50081,0x973c0335,0x65640201}},	//   væmt_, _এসব_, maćo, _ezih,
   {{0x4444032e,0xb5fb1f84,0xa75b00ca,0x00000000}},	//   _ej_, gmát, _מדור, --,
   {{0x661d0052,0xe1ff0503,0xdb030216,0x00000000}},	// [67b0] ërku, _fhón_, tanë, --,
   {{0x4ea711db,0x765d6b55,0x2240058f,0x44446b56}},	//   ерда, llsy, anik_, _gj_,
   {{0x224002dd,0xdb0300dd,0xdd9100e3,0x442100e7}},	//   bnik_, ranë, لوا_, _ilh_,
   {{0x63a76b57,0xee38004d,0xfe700c5e,0xed3500d3}},	//   lajn, ннє_, مدن_, кэлэ,
   {{0xfce50cf5,0x61fd6b58,0x61ed6b59,0x6e20009c}},	//   толо, _insl, mdal, _dlmb,
   {{0xa13600c1,0xd720074c,0x212906e1,0x61ed6b5a}},	//   _יארק_, मनाथ_, mzah_, ldal,
   {{0x44334b7c,0x60cd6b5b,0x44210167,0x00000000}},	//   _mmx_, ltam, _mlh_, --,
   {{0x78a91d2d,0x320914d0,0xdb0300d4,0x60cd6b5c}},	//   tsev, njay_, nané, otam,
   {{0x9f43030b,0x5c750859,0x60cd34d2,0x79896b5d}},	//   _mají_, _алат, ntam, rcew,
   {{0x22406b5e,0x78a90431,0x60cd6b5f,0x61ed00c2}},	//   znik_, rsev, itam, hdal,
   {{0x63a740a2,0x4444001f,0xb5fb030b,0x61ed6b60}},	//   dajn, _rj_, klád, kdal,
   {{0x60cd6b61,0x44213cd3,0x61ed6b62,0x44336b63}},	//   ktam, _alh_, jdal, _amx_,
   {{0x61ed6b64,0x442117b6,0xdb030094,0x60cd2a7d}},	//   ddal, _blh_, dané, jtam,
   {{0x22400067,0x63a7011d,0x2129005c,0x61fd1f60}},	//   wnik_, gajn, dzah_, _ansl,
   {{0x03a36b65,0x443300da,0xf09f0065,0x03e40033}},	//   рисо, _dmx_, _awà_, খালী_,
   {{0xc2434241,0x61ed6b66,0x7e7b0350,0x7866003e}},	//   анск, gdal, _niup, rðve,
   {{0x444408a9,0x6d5b01bb,0x60cd259e,0x63a76b67}},	// [67c0] _tj_, _nyua, gtam, bajn,
   {{0xa01b6b68,0x22406b69,0xb5fb1f84,0x61ed6b6a}},	//   _stör, snik_, smát, adal,
   {{0x22402281,0x60cd6b6b,0x61ed6b6c,0xf09f0065}},	//   pnik_, atam, bdal, _ewà_,
   {{0x44386b6d,0x7c213e54,0x7e7b00d3,0x60cd008c}},	//   lir_, _allr, _ciup, btam,
   {{0x60cd04d3,0x44380080,0x7e7b113a,0xc5f30089}},	//   ctam, oir_, _diup, ידא_,
   {{0x44386b6e,0x3e6700aa,0x2d8d0139,0xdb010113}},	//   nir_, võte_, _efee_, _kelè,
   {{0xaa584941,0x7a3e00d9,0x973c0995,0xbea3468f}},	//   нику_, līti, vaćo, _васк,
   {{0x2614001f,0xdbdf003e,0x7e7b019c,0x7e692f10}},	//   _mãos_, síðu, _giup, _ghep,
   {{0xfce30d64,0x44386b6f,0x48c200c7,0x984a008f}},	//   _кото, kir_, ্ট্র, дяна_,
   {{0xd7f70fdf,0x61ed6b70,0xb5fb0018,0x44386b71}},	//   вую_, zdal, ymás, jir_,
   {{0x44386b72,0x61ed07d1,0x26d81507,0xda6f00ae}},	//   dir_, ydal, ïro_, _вя_,
   {{0x7c381b59,0x44215c73,0x7e690052,0xc983007e}},	//   livr, _slh_, _xhep, _куши,
   {{0x67d40d62,0xdb03025b,0x9f470181,0x6d5b01bb}},	//   _болу, vané, ľné_, _xyua,
   {{0x9f470871,0x44386b73,0x7a3e01d3,0x00000000}},	//   žné_, gir_, dīti, --,
   {{0xd8380d12,0x23d207d5,0x682400ee,0x6a650076}},	//   mič_, द्धद, _còde, lófa,
   {{0x60cd6b74,0x44386b75,0x63a70a39,0xd83839a2}},	//   ttam, air_, sajn, lič_,
   {{0x44386b76,0xe7cf099d,0x61ed6b77,0x44210899}},	// [67d0] bir_, त्वप, rdal, _tlh_,
   {{0x443811ce,0xb5fb6b78,0x661d6b79,0x61ed65dc}},	//   cir_, slád, lksk, sdal,
   {{0x60cd239e,0x64556b7a,0xd37100cd,0x9f436b7b}},	//   stam, mozi, _دهد_, _tají_,
   {{0x60cd002d,0x661d2e7f,0xa7fc013c,0x387c0154}},	//   ptam, nksk, llıd, _livr_,
   {{0x91ba00a1,0xd838033b,0x7a3e01d3,0xdb180537}},	//   _אמרי, kič_, cīti, ngvæ,
   {{0xcb690f30,0xbfb800bf,0x64556b7c,0x251c0341}},	//   нале_, _لطفا_, nozi, וודא,
   {{0x7e7b2fc5,0x7bc30106,0x499300cd,0x62856b7d}},	//   _tiup, rgnu, لیار, _juho,
   {{0x44386b7e,0x62856b7f,0x3eda00c1,0x63a56b80}},	//   zir_, _muho, _אַמא, _lehn,
   {{0x443801d4,0x601201c5,0x64556b81,0xe1ff0028}},	//   yir_, _kæmp, kozi, _nhóm_,
   {{0x44386b82,0x63a50181,0xdb016b83,0x480509e4}},	//   xir_, _nehn, _lelé, упов,
   {{0xe5a612e7,0x35a628b0,0x7a3e01d3,0x62850113}},	//   лини, ланг, zīti, _nuho,
   {{0x44386b84,0xdb0100fd,0xe8f50037,0x9f580065}},	//   wir_, _relè, _مستخ, _korò_,
   {{0x44382890,0xd8381e4d,0x799b6b85,0x20110131}},	//   tir_, bič_, mbuw, _oozi_,
   {{0x64556b86,0x62856b87,0xd91a00c1,0x201100cb}},	//   gozi, _buho, _רוסל, _nozi_,
   {{0x44386b88,0xdb010018,0xb5fb6b89,0x63a5042c}},	//   rir_, _belé, rmár, _dehn,
   {{0xe7cf02e8,0x44386b8a,0xdb016b8b,0x7a3e00d9}},	//   त्रप, sir_, _celé, tīti,
   {{0x64555f53,0x41270cba,0xdb016b8c,0x00000000}},	// [67e0] bozi, гото_, _welè, --,
   {{0xdb016b8d,0x7a3e01d3,0x44386b8e,0x6b810113}},	//   _telè, rīti, qir_, _nglg,
   {{0x20116b8f,0xdb010018,0x628502a4,0x2d8001d3}},	//   _dozi_, _felé, _guho, žiem_,
   {{0xe1ff00e3,0x175600c1,0x52d700c1,0xdb016b90}},	//   _gnó_, אסער_, _גוטע_, _gelé,
   {{0x7a3e01d3,0x9f580231,0xa5bb01cd,0x00000000}},	//   nūte, _poró_, skóg, --,
   {{0x998d6b91,0x20110350,0x3f9a01f3,0x2bc902c6}},	//   vieš_, _gozi_, _سپرد_, _राणा,
   {{0xd83833ab,0x81e70081,0xa5bb374a,0xdddc00ae}},	//   vič_, পার_, rióz, _curţ,
   {{0x611a00d9,0x645552cd,0x799b6b92,0xd5e400fe}},	//   _tālā, zozi, gbuw, _nhì,
   {{0x02e110ed,0x6455413e,0x68ed00e7,0xd838103b}},	//   _पन्न, yozi, _šadr, tič_,
   {{0x6a656b93,0xb5fb0206,0x00000000,0x00000000}},	//   rófa, klác, --, --,
   {{0xd8383438,0x9f4a0113,0xeb9700c2,0x63a56b94}},	//   rič_, _babé_, _сих_, _rehn,
   {{0xd104147f,0x98a600c9,0x63a56b95,0xd8380146}},	//   रमाण_, _биде, _sehn, sič_,
   {{0x62852281,0x661d6b96,0xd8383fa3,0x00000000}},	//   _suho, rksk, pič_, --,
   {{0x62850433,0xdb016b97,0xa7fc0342,0x9f430139}},	//   _puho, _selé, rmıs, _lajá_,
   {{0x443f03ce,0x2bd60096,0x63a5007b,0xa7fc020e}},	//   đu_, ढ्या, _vehn, rlıd,
   {{0x973c050d,0x64556b98,0x2011010a,0x00000000}},	//   haćk, sozi, _sozi_, --,
   {{0x64556b99,0xbf1d0336,0x20116b9a,0x628500f9}},	// [67f0] pozi, पन्न_, _pozi_, _wuho,
   {{0x62856b9b,0x27ee003e,0xa7fc00a7,0x2bc909c4}},	//   _tuho, _jafn_, qlıd, _राधा,
   {{0xdb0111ce,0xdb1802c3,0x00000000,0x00000000}},	//   _telé, ngvä, --, --,
   {{0x51840095,0x5fc7009d,0x79826b9c,0xbdd52f34}},	//   _гура, _लावल, _ngow, родщ,
   {{0xfaf80b25,0x00000000,0x00000000,0x00000000}},	//   _arī_, --, --, --,
   {{0x27ee0088,0x3dc9003d,0x61ef030a,0x00000000}},	//   _nafn_, żaw_, _hacl, --,
   {{0x1b49013d,0x44fd0033,0x00000000,0x00000000}},	//   ъзки_, ুনিক_, --, --,
   {{0x61ef041c,0x00000000,0x00000000,0x00000000}},	//   _jacl, --, --, --,
   {{0x61ef6b9d,0x2d9d5fa6,0xdb030328,0xd9450a01}},	//   _macl, mbwe_, maní, репи,
   {{0xaaae009d,0x66db0084,0x1bab0018,0xdb036b9e}},	//   _टिचक, _näkö, _سائٹ_, laní,
   {{0xbb8400e3,0x9f5e00de,0x4e190fef,0x99d7071c}},	//   _المي, _ôtô_, _दवाई_, _متشا,
   {{0xdddc6b9f,0x1c0309c3,0x6a650328,0x61ef6ba0}},	//   _kurš, लावल_, mófo, _nacl,
   {{0xe0c000c7,0x5967008f,0x98b800ae,0xd5e40023}},	//   _উন্ন, _съжа, ără_, _chí,
   {{0xe78709e4,0xdddc0141,0x00000000,0x00000000}},	//   _судо, _murš, --, --,
   {{0x6a650328,0x68fc00e8,0x00000000,0x00000000}},	//   nófo, ārde, --, --,
   {{0xc4860c58,0x61ef009c,0x2fd80063,0x6824009c}},	//   _клик, _cacl, _sbrg_, _iòda,

   {{0xddc900d9,0x2d800220,0xdb036ba1,0x69d96ba2}},	// [6800] _biež, žiek_, daní, _mbwe,
   {{0xb5fb0146,0x9f58003e,0xcef60291,0xe7bd0179}},	//   plác, _borð_, ичењ, _एएफप,
   {{0x0d861787,0x61ef0013,0x69d90283,0x6824022b}},	//   ален, _facl, _obwe, _jòda,
   {{0xdb030042,0x61ef01ec,0x53d2136b,0x682401ec}},	//   ganí, _gacl, द्रश, _mòda,
   {{0x61e46ba3,0x9d240081,0xdb0a0c19,0x00000000}},	//   meil, বপ্ন_, ngfö, --,
   {{0x69d901bf,0x61e46ba4,0x798217c4,0x69d50103}},	//   _abwe, leil, _sgow, őzel,
   {{0x7f436ba5,0xdb036521,0x7aed0034,0x69d9010a}},	//   _держ, baní, łatn, _bbwe,
   {{0x78a20c56,0x61e40084,0xd90d00cd,0x68f90178}},	//   _pwov, neil, کیه_, _brwd,
   {{0x973c00e9,0x2d8400f9,0x2aac0139,0xa3d617ad}},	//   maći, _igme_, _bóbá_, सभा_,
   {{0x61e46ba6,0x69d90517,0x973c0995,0x7d28071d}},	//   heil, _ebwe, laći, ırsı,
   {{0x61e40084,0x442a00e3,0x7bda023e,0x09e657ff}},	//   keil, dhb_, _ibtu, _воен,
   {{0x7e626ba7,0xd5e400fe,0x78a20027,0x7982010a}},	//   nlop, _phí, _twov, _ugow,
   {{0xb894054f,0x61e46ba8,0x60c41a30,0x61ef483a}},	//   _التع, deil, juim, _racl,
   {{0xb4d72ebd,0x7e620415,0x320245cd,0x00000000}},	//   _सही_, hlop, _anky_, --,
   {{0xf1a709b9,0x61e40150,0xdb1a04d8,0x3a266ba9}},	//   иран, feil, _actú, _klop_,
   {{0x60dd061d,0xe1ff00de,0x61e46baa,0xd5e40023}},	//   _ppsm, _khói_, geil, _thí,
   {{0x60c42243,0x7bda6a26,0xdb030181,0x7e626bab}},	// [6810] guim, _obtu, vaní, dlop,
   {{0x9f47030b,0x7e6201c0,0x7afa010a,0x3a260428}},	//   žní_, elop, _ortt, _llop_,
   {{0xa1871736,0x644700e9,0x24890197,0xdb01052f}},	//   _выгл, mnji, _huam_, _udlø,
   {{0x24896bac,0x7e626bad,0x31040f8f,0x2bc90096}},	//   _kuam_, glop, रमशः_, _राहा,
   {{0x9ce70b3b,0x7afa026a,0xe1ff00fe,0x53f80504}},	//   рцел, _artt, _nhói_, _صریح_,
   {{0x2489006c,0xdb0335c9,0x1ee70018,0x99840138}},	//   _muam_, saní, _پوری_, kimų_,
   {{0x248901bb,0x6013030b,0x2003006d,0x99840138}},	//   _luam_, _výmě, _inji_, jimų_,
   {{0x09f900e3,0x99840138,0xa5bb0076,0xdddc0117}},	//   افظة_, dimų_, bhói, _turš,
   {{0x2489023e,0x64470128,0xa5bb0076,0xe1ff0023}},	//   _nuam_, knji, chói, _chói_,
   {{0x998d0181,0x64470995,0x61e41853,0xd90c0018}},	//   dieť_, jnji, zeil, ئیو_,
   {{0x6297006c,0x25a90076,0xdb011405,0x00000000}},	//   _ntxo, _beal_, _kelí, --,
   {{0x08f909b4,0xddc945a8,0x69d90193,0x248901b9}},	//   _مرتب_, _nież, _ubwe, _buam_,
   {{0x61e46bae,0x24890197,0xd6ce00cd,0x25a900ca}},	//   veil, _cuam_, وقی_, _deal_,
   {{0x61e402e2,0x2489023b,0x64470a39,0x68e96baf}},	//   weil, _duam_, gnji, mwed,
   {{0x61e46bb0,0x68e902ad,0xddc90034,0x25a90072}},	//   teil, lwed, _bież, _feal_,
   {{0x69c96bb1,0x26c56bb2,0x60c40084,0x2489023e}},	//   ngee, mulo_, tuim, _fuam_,
   {{0x61e46bb3,0x7e620c56,0xf6530089,0x973c0335}},	// [6820] reil, vlop, _מצה_, vaći,
   {{0x61e46bb4,0x60c46bb5,0xb4e4009f,0x262f01c2}},	//   seil, ruim, नबी_, nƙon_,
   {{0xd00f1823,0x68e901bf,0xdb0120df,0x6604354c}},	//   علم_, hwed, _belí, _knik,
   {{0xa5bb00e3,0x443a0270,0x24890197,0x32020124}},	//   thói, _hmp_, _yuam_, _unky_,
   {{0x27e5190f,0x7e626bb6,0x973c2461,0xdb016bb7}},	//   keln_, rlop, raći, _delí,
   {{0x26c56bb8,0x69c9008a,0x68e94494,0x7e626bb9}},	//   kulo_, egee, dwed, slop,
   {{0x66046bba,0x645e0294,0x27e534fe,0x6bd32ce3}},	//   _onik, _mkpi, deln_, ستور,
   {{0xae0c110f,0x4c860b2c,0xe45f5fb7,0x99840138}},	//   _सचिन_, _глав, ntör_, vimų_,
   {{0xdca36bbb,0x25a9377e,0xf98f00e3,0x270e0092}},	//   _нати, _real_, ربي_, məni_,
   {{0x2489006c,0x27e56986,0x66046bbc,0x443a0167}},	//   _ruam_, geln_, _anik, _nmp_,
   {{0x81046bbd,0xe45f6bbe,0x24896bbf,0x66166bc0}},	//   रमुख_, ktör_, _suam_, _boyk,
   {{0x2489006c,0x9984013f,0xe1ff00de,0xf1bf033c}},	//   _puam_, rimų_, _thói_, _alán_,
   {{0xb8d300cd,0x27e50f3a,0x64472cea,0x629c112f}},	//   _فتوش, beln_, tnji, epro,
   {{0x66046bc1,0x26c56bc2,0x2489006c,0x629c3155}},	//   _enik, bulo_, _vuam_, fpro,
   {{0x752f0d1b,0x26c51946,0x629c22c2,0x998d0031}},	//   szcz, culo_, gpro, sieť_,
   {{0x24890197,0x64470ca7,0x9f51016d,0x32f80154}},	//   _tuam_, snji, _fazê_, _dčy_,
   {{0x30150870,0x63ae063f,0x7c3a6bc3,0x764d0010}},	// [6830] одар, babn, _omtr, _ijay,
   {{0x656d6bc4,0x66040034,0x6440020d,0x32f8022b}},	//   _izah, _znik, émit, _fčy_,
   {{0xdb011946,0x4f6b05b8,0x69c9008c,0x00000000}},	//   _pelí, ушам_, ygee, --,
   {{0x9f4a0124,0x68e90150,0x31c744bd,0x443a0042}},	//   _babâ_, ywed, _усов, _zmp_,
   {{0x22490103,0x067c006e,0x1d0916bd,0x786f00f2}},	//   mnak_, אנאל, рели_, løve,
   {{0x22490018,0x973c2461,0x27e509b5,0x2a6f0167}},	//   lnak_, laću, xeln_, _shgb_,
   {{0x69c901c0,0x27e517a5,0x62830231,0x683f0139}},	//   tgee, veln_, _énos, _ládè,
   {{0x7c285d1f,0x22490068,0x3ced01bb,0x68e901bf}},	//   _eldr, nnak_, _tsev_, twed,
   {{0x69c96bc5,0x22496bc6,0x26c56bc7,0xb5fb381f}},	//   rgee, inak_, wulo_, tlán,
   {{0x764d277d,0x6e29077e,0x68e96bc8,0x63ae023e}},	//   _ajay, _hleb, rwed, xabn,
   {{0x22490068,0x6e296bc9,0x656d6bca,0x9b580a7c}},	//   knak_, _kleb, _azah, _лифт_,
   {{0xb5fb6bcb,0x63ae063f,0x443a6bcc,0xceb20341}},	//   slán, wabn, _smp_, ויט_,
   {{0x2249221d,0xf1bf025b,0xb5fb2159,0x63ae1d49}},	//   dnak_, _plán_, plán, tabn,
   {{0x26c56bcd,0xaadd08c0,0x656d3231,0x4add05a4}},	//   pulo_, _महाक, _dzah, _महाव,
   {{0x63ae2782,0x366a50b0,0x6e3b0283,0x656d019f}},	//   rabn, _како_, _omub, _ezah,
   {{0x443a6776,0x9fa30088,0x3a3f02e7,0x22490018}},	//   _wmp_, _síðu_, niup_, gnak_,
   {{0x1005000d,0x6440052d,0x7bdc0088,0x291f0239}},	// [6840] रांश_, émis, _örug, nyua_,
   {{0x6e292ba9,0x629c03e5,0x443a6bce,0xe3b20421}},	//   _aleb, ppro, _ump_, _کرک_,
   {{0x9f510154,0x1c0300bc,0x2c0300bc,0x270e013c}},	//   _jazè_, लाईल_, लाईं_, təni_,
   {{0xcbc60081,0x645c6b20,0x6e296bcf,0x6da30fec}},	//   _এসেছ, lori, _cleb, дица,
   {{0x6e22171d,0x9f470220,0xe45f0212,0x9f5102f1}},	//   rkob, ľná_, bröd_, _lazè_,
   {{0x9f470074,0x6e296bd0,0x62830257,0x7c830699}},	//   žná_, _eleb, _énor, муще,
   {{0xa3dc2172,0xb4c70378,0x60d60109,0xdb036bd1}},	//   ण्य_, _उम्_, ltym, taná,
   {{0x201803f3,0x645c6bd2,0xa2cb1fbb,0x6e29007f}},	//   _hori_, hori, तंत्, _gleb,
   {{0xdb032e24,0x60d66bd3,0x2120061d,0xb4e40442}},	//   raná, ntym, nyih_, नबो_,
   {{0x22490018,0x60d60138,0x473425e7,0xccf9007f}},	//   znak_, itym, знос, _myśl_,
   {{0x645c2b2f,0x20186bd4,0x224942f6,0x6fcf02d5}},	//   dori, _mori_, ynak_, स्टं,
   {{0x20180649,0x46db0557,0x656402a4,0x090600ae}},	//   _lori_, _बहरह, _byih, _мпен,
   {{0x61f600f0,0x656405bd,0x938b00e5,0xdb010131}},	//   ddyl, _cyih, исва_, _telã,
   {{0x20186bd5,0x9faf07aa,0x786f09af,0x7e600154}},	//   _nori_, _işçi_, tøve, _lkmp,
   {{0x22490018,0xb5fb0103,0x973c02ef,0x65640372}},	//   tnak_, llám, taću, _eyih,
   {{0x786f038c,0x22400270,0x2abb0266,0xdb080383}},	//   røve, giik_, ימלא, _vedè,
   {{0x20186bd6,0x765d159e,0x22496bd7,0x8387002d}},	// [6850] _bori_, mosy, rnak_, _мыне,
   {{0x22496bd8,0x20183c59,0x765d6bd9,0x68e200e7}},	//   snak_, _cori_, losy, _mpod,
   {{0x20186bda,0x161f0592,0xdb0300a7,0xbd980134}},	//   _dori_, _पवार_, manç, _ịpụt,
   {{0xdb036bdb,0xfe70001c,0x765d2e7f,0xb5fb00ea}},	//   lanç, ندن_, nosy, klám,
   {{0xeb990b70,0x201800e5,0xd9c20033,0xdca500ba}},	//   бил_, _fori_, ্জাম, чали,
   {{0x9f430181,0xdb0368a4,0x682405aa,0x6a650072}},	//   _majú_, nanç, _bòdm, mófi,
   {{0x765d6bdc,0x68e2167e,0x3a3f0da3,0xfb850018}},	//   kosy, _apod, tiup_, _ہدای,
   {{0x6e3b023f,0x290d0a00,0x68e20503,0x9f510154}},	//   _umub, txea_, _bpod, _razè_,
   {{0xa3dc099d,0x645c6bdd,0x20186bde,0x6a650143}},	//   ण्ड_, yori, _yori_, nófi,
   {{0x645c3787,0x656405bd,0x201801ff,0xdb0300b3}},	//   xori, _ryih, _xori_, janç,
   {{0xf1cb0b94,0xdb03001f,0xb5fb0103,0x765d6bdf}},	//   िलान, danç, plál, fosy,
   {{0x765d152a,0x60d600c2,0x3cff00c4,0x8afc010a}},	//   gosy, ytym, _kruv_, _kyęn,
   {{0x2bd206e4,0x645c6be0,0x280600b6,0xdb0800fd}},	//   _सामा, tori, ávní_, _redé,
   {{0x5fc702e8,0xa7fc008e,0x6a65124d,0x9f430031}},	//   _लागल, nlıl, dófi, _dajú_,
   {{0x2018283d,0x765d06a8,0x645c00db,0x6440020d}},	//   _rori_, bosy, rori, émiq,
   {{0x645c6be1,0x20186be2,0x60d60084,0x69db022b}},	//   sori, _sori_, ttym, nfue,
   {{0x20186be3,0xdd99022b,0x22406be4,0xa7fc0233}},	// [6860] _pori_, _enňk_, riik_, klıl,
   {{0x645c0092,0xdb03001f,0x60d66be5,0x20180188}},	//   qori, canç, rtym, _qori_,
   {{0x60d66be6,0x9f4a6be7,0x141b0089,0x1ee8001c}},	//   stym, _babá_, _הויב, توای_,
   {{0xdd8f00b9,0x00000000,0x00000000,0x00000000}},	//   هوم_, --, --, --,
   {{0x628607ac,0xdb010031,0x127b0142,0x00000000}},	//   _iiko, _relá, _לאטע, --,
   {{0x62866be8,0xa3ac2337,0xdb036be9,0x00000000}},	//   _hiko, खरि_, kanä, --,
   {{0x68e26bea,0x62866beb,0x3f8a0129,0xdee33f1d}},	//   _spod, _kiko, _igbu_, _пори,
   {{0xa9c302ec,0x8cc41784,0x62866bec,0x998d04a8}},	//   нськ, _रिपो, _jiko, rkeş_,
   {{0x62866bed,0xa3ac09f6,0xdb010328,0x7a3e00e8}},	//   _miko, खरा_, _velá, sūto,
   {{0x60c40080,0x2cb7030b,0x6b666bee,0x76b86bef}},	//   irim, ředí_, _екза, олор_,
   {{0xfaa311a1,0xe1ff00e3,0x3f8a0129,0x6286007b}},	//   _захо, _mhór_, _mgbu_, _oiko,
   {{0x60c46bf0,0xae020296,0xdb0102b6,0xf54f0174}},	//   krim, _रोमन_, _belæ, kụta_,
   {{0xdb032f0b,0x5fcc00b6,0xda09023a,0x00000000}},	//   tanç, ालाल, वारत_, --,
   {{0x3cef0251,0x62860084,0x60c46bf1,0x765d6bf2}},	//   _इनसे_, _aiko, drim, sosy,
   {{0xdb036bf3,0x62866bf4,0x60c40006,0x3cfe02d5}},	//   ranç, _biko, erim, लिडे_,
   {{0x62866bf5,0x7d0007bc,0x3f981f7b,0xdb034466}},	//   _ciko, _orms, _afru_, sanç,
   {{0x62861bd6,0xa6ae0081,0x60c46bf6,0xdb031529}},	// [6870] _diko, _কমিট, grim, panç,
   {{0x44ef6bf7,0xd7f8002d,0x601b044c,0x00000000}},	//   _iż_, ndă_, _cîmp, --,
   {{0x6a651f84,0x62866bf8,0x60c46bf9,0x2dd50686}},	//   sófi, _fiko, arim, джер,
   {{0x62866bfa,0x3f8a0129,0xfbdf030b,0x6a65124d}},	//   _giko, _egbu_, प्नम, pófi,
   {{0x60c46bfb,0xa7fc020e,0xdb1a0231,0x00000000}},	//   crim, tlıl, _octó, --,
   {{0x6f010161,0x62864681,0xaca30174,0x41cb030b}},	//   _álco, _ziko, _nsụn, िलवस,
   {{0xa7fc071d,0x6286050f,0x6f64007b,0x6e950120}},	//   rlıl, _yiko, _звёз, _цибу,
   {{0x09e000c7,0x68fb00aa,0x7d000653,0xa6d20033}},	//   _মোবা, tvud, _frms, তবায়,
   {{0xf1bf0139,0xa7fc0233,0x7d16004d,0x69db02db}},	//   _alák_, lmıy, øyst, rfue,
   {{0xb8d51091,0xa5bb0102,0x8afc00a5,0x63a209ac}},	//   _जब_, skól, _częs, _đono,
   {{0xe0200251,0x44ef00a5,0x68fb0234,0xa7fc026a}},	//   _मकसद_, _aż_, svud, nmıy,
   {{0x1b160f71,0xd7f800d3,0x60c46bfc,0x9959020a}},	//   _থেকে_, adă_, yrim, _câţi_,
   {{0x62866bfd,0x798b581c,0xdb010555,0x00000000}},	//   _riko, _iggw, _belç, --,
   {{0x62866bfe,0x60c4026a,0xe7290012,0xa7fc0233}},	//   _siko, vrim, _молд_, kmıy,
   {{0x62866bff,0xe2970077,0x44ef0078,0x2bdf277c}},	//   _piko, дас_, _eż_, प्या,
   {{0xf54f00ac,0x7aed007f,0x00000000,0x00000000}},	//   tụta_, łatw, --, --,
   {{0x216725ab,0x614314da,0x62866c00,0x754600d6}},	// [6880] дити_, вета, _viko, _іноз,
   {{0x2bd2178c,0x60c46c01,0xf1bf6c02,0x682401b9}},	//   _साधा, rrim, _lláh_, _còdh,
   {{0x62866c03,0x798b0172,0x1b1d0033,0x00000000}},	//   _tiko, _oggw, _ভেসে_, --,
   {{0xf54f06c0,0xf987046b,0x629e00f9,0xd5ed00de}},	//   pụta_, _لب_, _itpo, _khá,
   {{0xdb0a1de1,0xa7fc03a3,0x05b6009f,0x83170281}},	//   rafí, rmız, _अजनब, _فقیر_,
   {{0xdb0a04d8,0x798b06b0,0x3f8a06c0,0xdd9905aa}},	//   safí, _aggw, _ugbu_, _efň_,
   {{0x644e3e9f,0xb5fb6a48,0x15ee0034,0xda090096}},	//   inbi, noác, ज़ार_, वांत_,
   {{0xf2d3004f,0x7d000167,0x80e10033,0xb5fb6c04}},	//   דעה_, _trms, নির্, zoáb,
   {{0x26c56500,0x8d631a2b,0xe94405bc,0x81e00033}},	//   erlo_, _авте, عربی, _দফা_,
   {{0xdb010f3a,0x629e00e9,0xb5fb6c05,0x798b0517}},	//   _belä, _otpo, plák, _eggw,
   {{0xd7f800ae,0xb5fb0037,0xdb1a015e,0x787400b3}},	//   rdă_, llái, _ectò, jàve,
   {{0xa5f90084,0x644e6c06,0x78740428,0x7a2e01b9}},	//   чему_, enbi, dàve, _dùtc,
   {{0x26c56c07,0xdb0810d9,0xdd310092,0xa7fc026a}},	//   arlo_, _medí, _məşh, nlık,
   {{0xe94709e5,0x69d50103,0x7d0400c2,0x3e6e0031}},	//   _ترمی, őzet, äisy, kýto_,
   {{0x98a3013f,0xe7f3009d,0xb5fb0037,0xdb010364}},	//   ąją_, _असता_, hlái, _gelä,
   {{0x9099013d,0x644e6c08,0xa7fc026a,0x25580294}},	//   зват_, anbi, klık, ọla_,
   {{0x26cc6c09,0x22840f5e,0x682d0037,0x43955e0d}},	// [6890] ludo_, тург, _húda, _папс,
   {{0xe3c600c7,0x442700de,0xa3d603a2,0xdb0117d2}},	//   শ্বব, _ôn_, _हाय_, _helå,
   {{0xd25109b4,0x26cc6c0a,0xfd1000cd,0x787400b3}},	//   _مند_, nudo_, یجه_, càve,
   {{0x63b50335,0x682d0072,0x3d952249,0x69dc01f9}},	//   lazn, _múda, хидр, őrej,
   {{0xeb9912e7,0xdb086c0b,0x3438001c,0x61ed6c0c}},	//   пил_, _dedí, _رسید_, meal,
   {{0xeb990f94,0x60cd0239,0x62981e7d,0xa7fc0233}},	//   чик_, muam, _évoc, pmıy,
   {{0x999f0220,0x60cd00c2,0x998d00e8,0x9f5100d4}},	//   hnuť_, luam, riež_, _kazí_,
   {{0x999f0031,0x61ed4764,0x00000000,0x00000000}},	//   knuť_, neal, --, --,
   {{0x63b50074,0xa3c1007d,0xdb0100c2,0xd8253ac9}},	//   kazn, ुला_, _selä, едпи,
   {{0x61ed0091,0x63b56bea,0x699f022d,0xdb01007b}},	//   heal, jazn, _ग्री, _pelä,
   {{0x366a0f32,0x60cd6c0d,0x61ed00c2,0xf1bf030a}},	//   зано_, huam, keal, _elái_,
   {{0x60cd0051,0xd5ed0023,0x61ed044c,0x00000000}},	//   kuam, _phá, jeal, --,
   {{0x61ed6c0e,0x63b507c0,0x68240383,0x6faf0096}},	//   deal, fazn, _nòdw, टरां,
   {{0x26cc6c0f,0xb5fb0072,0x60cd058f,0xa92201cd}},	//   budo_, toác, duam, _óþar,
   {{0x80c2007d,0x91e61773,0x26cc10d9,0x58840109}},	//   _लिहे, нове, cudo_, _рыца,
   {{0x2bdf1fb4,0x60cd023e,0x11da0037,0x61ed6c10}},	//   प्ता, fuam, ثورة_, geal,
   {{0x63b504a3,0x60cd6c11,0x2bd22ebd,0x682400b3}},	// [68a0] bazn, guam, सलमा, _sòdi,
   {{0x25dc152c,0x76466c12,0x3c2b038c,0xdb080094}},	//   ग्री_, liky, _søvn_, _sedí,
   {{0xf09f68fc,0x2bc9277c,0xfbc90c9c,0xdb080610}},	//   _età_, _राजा, _राजम, _pedí,
   {{0x2bd2009d,0x61ed6c13,0xe29b00ca,0xa7fc026a}},	//   _साहा, ceal, _משטר, tlık,
   {{0xc3c909e5,0x26cc0231,0x1dd10285,0xdd110233}},	//   _عظیم_, zudo_, _हारत, rüşe,
   {{0xf1bf0146,0xa7fc026a,0x2cad030a,0x09c800a4}},	//   _zdá_, rlık, _dwed_, ळल्य,
   {{0x76463585,0x00000000,0x00000000,0x00000000}},	//   kiky, --, --, --,
   {{0x998d0034,0x63b500d8,0x26cc00c6,0x9f580216}},	//   cież_, zazn, vudo_, _larë_,
   {{0x29024098,0xd7fa0b2e,0x26cc0134,0x7e621d25}},	//   íka_, пун_, wudo_, moop,
   {{0x81c900c7,0x26cc0bfe,0xdb06002d,0x7e626c14}},	//   ল্প_, tudo_, ămân, loop,
   {{0x28c207e2,0x63b56c15,0xdb080231,0xa3c100b7}},	//   _शिवि, vazn, _dedã, ुलस_,
   {{0x26c20106,0x0ae90037,0x7e626c16,0xdb0301f9}},	//   čko_, _تركي_, noop, yanú,
   {{0x645a025b,0x63b505f1,0x28f800c2,0x61ed6c17}},	//   čtin, tazn, _цель_, veal,
   {{0xaad4000f,0x998d0034,0x9f470031,0x7e621cab}},	//   _धमाक, zież_, ľnú_, hoop,
   {{0x63b501d9,0xf09f0451,0x7e626c18,0x9f470031}},	//   razn, _stà_, koop, žnú_,
   {{0xfd260028,0xa3d60b89,0x60cd6c19,0xddcf6c1a}},	//   _đình_, _हाथ_, tuam, _žeže,
   {{0x660d6c1b,0x865c00a1,0xb5fb016d,0xf09f028d}},	// [68b0] _inak, _מדהי, fláv, _qtà_,
   {{0x61ed6c1c,0x60cd6c1d,0xc0580c10,0x9f580052}},	//   seal, ruam, ніх_, _garë_,
   {{0xa3d63087,0x64476c1e,0x53353051,0x61ed01cc}},	//   _हात_, miji, _рент, peal,
   {{0x64476c1f,0x7a3e00e4,0x660d00b3,0x00000000}},	//   liji, būti, _jnak, --,
   {{0x60cd028d,0x660d6c20,0x00000000,0x00000000}},	//   quam, _mnak, --, --,
   {{0x64472751,0x3e870065,0x661f0052,0xb5fb016d}},	//   niji, _bìtì_, _loqk, cláv,
   {{0x660d03ce,0x2bd2000d,0x7a470113,0x998d007f}},	//   _onak, _सारा, _nètè, pież_,
   {{0x68240428,0x660d0517,0xdb080231,0x7c2a01cb}},	//   _mòdu, _nnak, _sedã, akfr,
   {{0x09e00081,0x64470b33,0xac95008f,0x0ec90096}},	//   _মোহা, kiji, _разш, ांकड,
   {{0x7c2a6c21,0x644730ff,0x7a4701dc,0xbff80134}},	//   ckfr, jiji, _bètè, _ịṅụ_,
   {{0x76460798,0xaac70246,0x81c90033,0x810d0034}},	//   tiky, _ستان, ল্য_, समुख_,
   {{0xddc200cc,0x9f58022b,0x8be60033,0xeab000b9}},	//   ološ, _darè_, _গোপন_, _طعم_,
   {{0x9f58074a,0x76466c22,0x00000000,0x00000000}},	//   _parë_, riky, --, --,
   {{0x660d6c23,0x64476c24,0x764600c2,0xa8020233}},	//   _enak, giji, siky, şırk,
   {{0x9cff0081,0xc7d60796,0x7e62010a,0xb3d30096}},	//   ্নয়ন_, _יוסי_, yoop, _तारख,
   {{0xdb080220,0x05b60096,0xddc26c25,0x290000c6}},	//   _jedá, _अजिब, kloš, _šiai_,
   {{0x7bc102e6,0x64476c26,0x442a005c,0xddc20335}},	// [68c0] _odlu, biji, pkb_, jloš,
   {{0x25e30ed3,0x9f580314,0xddc22f54,0xf09f009c}},	//   ट्ठी_, _haré_, dloš, _sràc_,
   {{0x44446c27,0x00000000,0x00000000,0x00000000}},	//   _im_, --, --, --,
   {{0xdb08025b,0x78bb0673,0xdb010103,0x471a00c1}},	//   _nedá, ksuv, _felú, וועג,
   {{0x7e626c28,0x9f430314,0x998609ac,0x9f5813a9}},	//   roop, _bajó_, _ološ_, _maré_,
   {{0x8fa31c16,0x682d0220,0x9f5800d1,0xb5fb0103}},	//   _варе, _súdn, _laré_, llát,
   {{0x44446c29,0x7c2a003e,0x50430231,0xdddc00bd}},	//   _mm_, rkfr, _терб, _kurż,
   {{0xda090d7e,0xc98643f7,0x7bc10201,0xd6d70033}},	//   वागत_, купи, _edlu, তবায,
   {{0x444463e0,0x8e5500d6,0xb5fb0072,0x6e200350}},	//   _om_, _стрі, ilát, _iomb,
   {{0x6e2003cc,0x660d6c2a,0x88bd00a5,0x76446c2b}},	//   _homb, _snak, myśl, _amiy,
   {{0x6447042d,0x61e61999,0xa3d6007a,0x7d0204d9}},	//   viji, _obkl, हलन_, lvos,
   {{0x44446c2c,0x291100e3,0x644700bf,0x6e206c2d}},	//   _am_, ónaí_, wiji, _jomb,
   {{0xdd110740,0x9f510042,0xe1f30018,0x9f58034f}},	//   _müşa, _mazá_, یسر_, _daré_,
   {{0x76446c2e,0x2a6430e1,0x9f4305aa,0x61e6042c}},	//   _emiy, lomb_, _majò_, _abkl,
   {{0x64476c2f,0x6e200185,0x44446c30,0x9f580428}},	//   riji, _oomb, _dm_, _faré_,
   {{0x44446c31,0x6e206c32,0xe5e90084,0x660d6c33}},	//   _em_, _nomb, ämää, _unak,
   {{0x44446c34,0x64470078,0x7d020b14,0x00000000}},	// [68d0] _fm_, piji, jvos, --,
   {{0x2ca633aa,0x7d0200cc,0x53476c35,0x26de2a59}},	//   dpod_, dvos, _ахма, otto_,
   {{0x425504c6,0xdd910037,0x26de01ff,0x00000000}},	//   _مندر, موا_, ntto_, --,
   {{0x13b80033,0xdb010143,0x26de007b,0x656d0172}},	//   _জায়, _telú, itto_, _kyah,
   {{0x44446c36,0x6e206c37,0x44213fc8,0x44330167}},	//   _ym_, _domb, _koh_, _klx_,
   {{0x27fc0939,0x44216c38,0x224901e9,0xdb086c39}},	//   _navn_, _joh_, liak_, _sedá,
   {{0xe81602e8,0x6e200154,0xf414028c,0x2129005c}},	//   ताना_, _fomb, יפס_, lyah_,
   {{0xe8f92046,0x22496c3a,0x61fd6c3b,0x44216c3c}},	//   ели_, niak_, _jasl, _loh_,
   {{0xb5fb431e,0x656d6522,0x26de00e5,0x21290947}},	//   hlás, _nyah, etto_, nyah_,
   {{0x6e200584,0x4421397b,0x21290063,0x7bc16c3d}},	//   _zomb, _noh_, iyah_, _udlu,
   {{0x444429cb,0x656d456e,0x224902a7,0x9f58052d}},	//   _rm_, _ayah, kiak_, _paré_,
   {{0x61fd02fb,0x64a65c28,0xfbdf009d,0x629a025b}},	//   _nasl, лама, प्रम, ítom,
   {{0x44440133,0x37e52a61,0x44216c3e,0x656d0193}},	//   _pm_, _болг, _boh_, _cyah,
   {{0xdb01038c,0x44446c3f,0x656d00f9,0x21291d49}},	//   _belø, _qm_, _dyah, dyah_,
   {{0x44216c40,0x61fd0b12,0x60dd0090,0x22496c41}},	//   _doh_, _basl, _aqsm, fiak_,
   {{0xe811000f,0x224902a7,0x44446c42,0x44216c43}},	//   ़ावा_, giak_, _wm_, _eoh_,
   {{0xeb1f007d,0x6e203094,0xf1bf0032,0xb5fb0103}},	// [68e0] बहुत_, _romb, _alás_, rlát,
   {{0x44446c44,0x44216c45,0xb5fb3e43,0x644501ec}},	//   _um_, _goh_, slát, _gmhi,
   {{0x0dca24d3,0x22496c46,0xb5fb10d9,0x6e206c47}},	//   елей_, biak_, clás, _pomb,
   {{0xed5a0d64,0xe1f20241,0x7e7b6c48,0x7d020218}},	//   ное_, _اسد_, _chup, tvos,
   {{0x44216c49,0xe816030b,0x7e7b6c4a,0x2ca6019c}},	//   _yoh_, तामा_, _dhup, upod_,
   {{0x7e690174,0x7d026c4b,0x6e200415,0x7c2101cb}},	//   _ekep, rvos, _womb, _colr,
   {{0x78a25ae0,0xd6ae00c7,0x05d4009d,0xaa661a9c}},	//   _stov, _কম্প, _थांब, лтик,
   {{0x48aa00d5,0x29065593,0x27fc6c4c,0xdb180052}},	//   нтом_, _proa_, _savn_, lavë,
   {{0x383433d0,0x7c210428,0x27e70062,0xf1bf01cd}},	//   инир, _folr, _bbnn_, _klár_,
   {{0x224902a7,0xe45f0149,0x7c2100f9,0x61e44fba}},	//   ziak_, tröm_, _golr, hfil,
   {{0x9b93054f,0x44210484,0xab930080,0x656d10dd}},	//   _المت, _roh_, _المغ, _syah,
   {{0x21294bce,0x7a35030b,0x44216c4d,0x1a9b006e}},	//   yyah_, _páte, _soh_, _נידע,
   {{0x44216c4e,0xf09f0139,0x78a26c4f,0x34952d8c}},	//   _poh_, _aràn_, _utov, рагр,
   {{0xb4e50067,0x61fd6c50,0x61e42096,0xdb030094}},	//   _नही_, _sasl, efil, haný,
   {{0x0cd104dd,0x61fd6c51,0x62986c52,0x53340012}},	//   _सम्म, _pasl, _évol, берт,
   {{0x533461b3,0xb5fb0018,0x4421001c,0x34951d54}},	//   щест, rlás, _woh_, _каир,
   {{0x7bda6c53,0x224903f3,0x44216c54,0xdb03025b}},	// [68f0] _octu, riak_, _toh_, daný,
   {{0x7e691bf0,0xf1bf00e3,0x22496c55,0x61fd003d}},	//   _skep, _clár_, siak_, _wasl,
   {{0x2129063f,0x22496c56,0xaca30023,0x61fd6c57}},	//   syah_, piak_, _trịn, _tasl,
   {{0x61fd00e3,0xddc20034,0x7c211842,0x9f580503}},	//   _uasl, mnoś, _solr, _anró_,
   {{0xddc20067,0x7c216c58,0x212902e7,0xa7fc020e}},	//   lnoś, _polr, qyah_, nlıs,
   {{0x628f00dc,0x60cd03a9,0x62970415,0x00000000}},	//   _hico, mram, _kuxo, --,
   {{0xf99100e3,0x60cd0076,0xff04008f,0x628f010a}},	//   يبة_, lram, _лятн, _kico,
   {{0x60cd008f,0x6d5b0197,0x26c30220,0x7c216c59}},	//   oram, _txua, ájom_, _wolr,
   {{0x26cc14e2,0xa3d600af,0x60cd6c5a,0xe1ff015e}},	//   erdo_, _हाल_, nram, _maó_,
   {{0x200100cd,0xaae700e3,0x7d091913,0x3a2d057a}},	//   ndhi_, _مسؤو, _ires, skep_,
   {{0x2bab02e8,0x60cd6c5b,0x69a60d77,0xddc20034}},	//   _घ्या, hram, _ट्वी, jnoś,
   {{0x7d095352,0xddc200a5,0x645500e5,0x4a9a0796}},	//   _kres, dnoś, enzi, _סינג,
   {{0x60cd6c5c,0x99830138,0x44380178,0x7d09009e}},	//   jram, ėjų_, thr_, _jres,
   {{0x629711bc,0x26cc00cc,0xddc20034,0x17070018}},	//   _buxo, brdo_, fnoś, _مفتی_,
   {{0x61e46c5d,0x60cd2ea3,0x2a7d022e,0x41b6248d}},	//   tfil, eram, _khwb_, исат,
   {{0x60cd6c5e,0x98a2013f,0x20116c5f,0xaca30134}},	//   fram, šką_, _anzi_, _arọn,
   {{0xdb030074,0x628f6c60,0x9f470181,0x3e7c0146}},	// [6900] vaný, _dico, ľný_, níte_,
   {{0x9f47025b,0xf09f00de,0x628f00eb,0x00000000}},	//   žný_, _tràn_, _eico, --,
   {{0x628f6c61,0x91e63e78,0x60cd6c62,0x307500c2}},	//   _fico, _коне, aram, сутс,
   {{0xa3d6000f,0x20110051,0x0e6613a2,0x270500d9}},	//   _हाँ_, _enzi_, шкен, _mēn_,
   {{0x7d09387d,0x7afa00e7,0x3e7c0094,0xdb030094}},	//   _cres, _sstt, jíte_, raný,
   {{0x63bc5a85,0x3e7c025b,0x7d096c63,0xd0120076}},	//   narn, díte_, _dres, _بلس_,
   {{0xb5fb0094,0x661d007f,0x62846c64,0x7d096c65}},	//   kláp, yjsk, omio, _eres,
   {{0x628f0428,0x62830036,0x0a6a00e5,0x5ca600ae}},	//   _xico, _ènot, ърли_, _виаб,
   {{0xa3d66c66,0xdca302c1,0xb4d50034,0x9f58015e}},	//   हला_, _мати, _हमे_, _marí_,
   {{0x63bc14dd,0x69a639d4,0x29000138,0x9f580139}},	//   jarn, _ट्री, _šias_, _larí_,
   {{0x63bc472d,0xeb974064,0xcfcc0081,0x3cfe10e9}},	//   darn, _тих_, র্থন, लिके_,
   {{0x60cd07d1,0xc9861e79,0xf64700f3,0x3e7c0094}},	//   yram, _кули, рхон, bíte_,
   {{0x628f0465,0x62840067,0x63bc472d,0xddc200a5}},	//   _rico, dmio, farn, wnoś,
   {{0xddc20067,0x63bc6c67,0xcfcc0081,0x6455028d}},	//   tnoś, garn, র্তন, unzi,
   {{0x76560103,0x187b021e,0x00000000,0x00000000}},	//   ógyá, _שטוב, --, --,
   {{0x80c202b0,0xddc20034,0xdce90e94,0x229c1054}},	//   _लिखे, rnoś, _uzeć, _dík_,
   {{0x63b701d4,0x51870ba9,0x9f581718,0x628f42f9}},	// [6910] _texn, рува, _darí_, _vico,
   {{0x60cd1f84,0x7d0900dd,0x25e31e9f,0x53350f97}},	//   rram, _rres, ट्री_, _геот,
   {{0x7d0908a9,0x7a3531a2,0xf09f00de,0xa7fc00a7}},	//   _sres, _láta, _trào_, nlıq,
   {{0x7a3c0018,0xdb010146,0x9f5800b3,0x00000000}},	//   _hétf, _celý, _garí_, --,
   {{0xaca30028,0x60cd01d4,0x787d00fd,0x3c39020d}},	//   _trọn, qram, lève, _lève_,
   {{0x7d096c68,0x3e7c0363,0x8c67468c,0x00000000}},	//   _vres, víte_, штед, --,
   {{0xad9d00a5,0xa3dc0eeb,0x62830451,0xdef80012}},	//   _paźd, ण्ट_, _ènos, _кыт_,
   {{0x61e9007a,0x3e7c0146,0x7a356c69,0xa7fc00a7}},	//   _öeld, títe_, _báta, dlıq,
   {{0x63bc09a4,0x7d096c6a,0x7a2e0013,0xdb036c6b}},	//   yarn, _ures, _mùth, tanó,
   {{0x7a356c6c,0x3e7c6c6d,0xfc330cc8,0x68456c6e}},	//   _dáta, ríte_, _بحر_, ённа,
   {{0x78a90b27,0x3e7c0074,0xdb036c6f,0xa3d6007a}},	//   spev, síte_, ranó, हलस_,
   {{0x63bc34ac,0x80ad0081,0xb99500e3,0x78a9300e}},	//   warn, _চিন্, _الإب, ppev,
   {{0x682d2b39,0x998500e3,0x53dc1e9f,0x09e00033}},	//   _lúdi, _الشو, _बादश, _মোকা,
   {{0x53a3065c,0x03a31a52,0x5d7a2252,0x3c3900fc}},	//   зарб, зиро, טארק, _fève_,
   {{0x63bc6c70,0x7a2e01ec,0xf09f01b9,0x044316bd}},	//   rarn, _bùth, _dràm_, черн,
   {{0x984f00a7,0x00000000,0x00000000,0x00000000}},	//   _işıq_, --, --, --,
   {{0xdb180396,0x4fea12e9,0x7a2e0013,0x682d0231}},	// [6920] ravé, лман_, _dùth, _aúdi,
   {{0xdb010018,0x958800a5,0x3ae10103,0x04430012}},	//   _belü, _ciąż, kóp_, _неын,
   {{0xd9f902e8,0x93fb0130,0x644e6c71,0x232a21fd}},	//   ्यात_, _גליי, mibi, _сони_,
   {{0x0d863168,0x6d030e5f,0x00000000,0x00000000}},	//   блен, लिंग_, --, --,
   {{0xa7fc013c,0x201c0f81,0x61f60233,0xdb0100b7}},	//   zlıq, övis_, meyl, _eelü,
   {{0x6fd502ec,0xa0a3433f,0xdb010018,0x7a356c72}},	//   _місц, _хард, _felü, _ráta,
   {{0x7bd80371,0xa3d60971,0x0aea0568,0x00000000}},	//   rgvu, _हाई_, ارتي_, --,
   {{0x644e6c73,0x5fa4009d,0x3ea74842,0x6480007b}},	//   hibi, खुरल, ínte_, löid,
   {{0x644e6c74,0x261c0296,0x1d070fec,0x320200d8}},	//   kibi, यानी_, _лети_, _maky_,
   {{0x644e6c75,0x32020146,0xdb010034,0x74230033}},	//   jibi, _laky_, _celó, _নষ্ট_,
   {{0x644e6c76,0xb05b0212,0x7bc800bd,0xdca300d3}},	//   dibi, _ovän, _iddu, _маӂи,
   {{0xa7fc00a7,0x98c40233,0x60d6010a,0x00000000}},	//   rlıq, ştık_, kuym, --,
   {{0x9f58015e,0xda651374,0x00000000,0x00000000}},	//   _larà_, _بالي, --, --,
   {{0x3a260934,0xdb0100b3,0x6480007b,0x229500e5}},	//   _hoop_, _geló, jöid, живя,
   {{0x3a2604ee,0x25e1152c,0x2be02f4f,0xcfde0033}},	//   _koop_, _कापी_, _नाना, ড়ান,
   {{0x7a353fff,0x3a2601cb,0x926b6c77,0xdddb00c6}},	//   _látn, _joop_, урга_, _siuž,
   {{0x644e6c78,0x3207030b,0xf09f00fe,0xdb010233}},	// [6930] bibi, ěny_, _tràm_, _selü,
   {{0x644e11c4,0xdb080072,0x9f5800b3,0x764f6c79}},	//   cibi, _dedú, _barà_, licy,
   {{0xe7ea009d,0x3ea703ee,0xa1950b1e,0xf1951bc1}},	//   ज्या_, ënt_, _манч, _минь,
   {{0x25e105d4,0x7bc86c7a,0x9f580451,0xed5100cd}},	//   _काफी_, _addu, _darà_, وپا_,
   {{0x25e11006,0x9c7d0154,0x6fb50076,0x9ce7004b}},	//   _कानी_, _opōt, _ومحا, сцел,
   {{0x9f586c7b,0x00000000,0x00000000,0x00000000}},	//   _farà_, --, --, --,
   {{0xdb010396,0x3a260131,0x9e35007b,0xdea400d1}},	//   _reló, _boop_, _девч, _فیلی,
   {{0x20036c7c,0x644e6c7d,0xed150018,0x7bc8083e}},	//   _haji_, zibi, _وہاں_, _eddu,
   {{0x20036c7e,0x3a264902,0xdb01037a,0x8c190d5b}},	//   _kaji_, _doop_, _peló, _پيار_,
   {{0x9f580890,0x20030010,0x752f00a5,0xdb01022b}},	//   _hará_, _jaji_, dycz, _delò,
   {{0x2003068d,0x644e00e5,0xbb55001c,0xdb010131}},	//   _maji_, vibi, _بناب, _veló,
   {{0x29180076,0x366a0284,0x764f0169,0xa50a00e5}},	//   ófaí_, рамо_, gicy, аема_,
   {{0x2be00be4,0xfbe000b6,0x644e6c7f,0xf7730e27}},	//   _नामा, _नामम, tibi, _کاش_,
   {{0x69db1094,0xb05b0149,0x20030022,0xdb080042}},	//   lgue, _svän, _naji_, _redú,
   {{0x644e6c80,0xe8160e19,0x09e00033,0x320200d8}},	//   ribi, तारा_, _মোটা, _paky_,
   {{0x644e6c81,0x69db2a1d,0x41aa1102,0x3ebe0088}},	//   sibi, ngue, рван_, _ætti_,
   {{0x9f580465,0x7a350224,0x32020146,0x644e028d}},	// [6940] _sarà_, _láto, _vaky_, pibi,
   {{0x9f581622,0x200342bf,0xdb080220,0xdb1a0231}},	//   _aará_, _caji_, _vedú, _detê,
   {{0x66040d64,0x3202030b,0x20036c82,0x648000c2}},	//   _kaik, _taky_, _daji_, röid,
   {{0x0caa5cb1,0x9f4a6c83,0x660401c8,0xf1bf00fe}},	//   атки_, _babò_, _jaik, _hoán_,
   {{0x66046c84,0xb05b0222,0x9f5822bf,0x6eaa0018}},	//   _maik, _kväl, _dará_, انچہ_,
   {{0x66046c85,0x20035a01,0x8aa62a84,0x7a3c0103}},	//   _laik, _gaji_, орид, _méte,
   {{0x752f0067,0x3f98084f,0x443a6c86,0x7a3c0018}},	//   zycz, _igru_, _mlp_, _léte,
   {{0x1cba1574,0x66046c87,0x80ad0081,0x69db19a1}},	//   _نائب_, _naik, _চিত্, ggue,
   {{0x60c46c88,0x20030d2a,0xe8160096,0x00000000}},	//   nsim, _yaji_, ताला_, --,
   {{0xdb1a01e5,0x7b1600e3,0x59dc009d,0x60c46c89}},	//   _jetë, _وظائ, _यावर, isim,
   {{0x907b193b,0x66042c5c,0x6fdd009d,0x764f0027}},	//   שטיי, _baik, _पासू, ticy,
   {{0x752f0d1b,0xdb1a00dd,0x09b40081,0xdb186c8a}},	//   tycz, _letë, _টাকা, naví,
   {{0x3ce66c8b,0x08fa09b4,0x6604013f,0x5fba030b}},	//   ntov_, _خراب_, _daik, इराल,
   {{0xdb0801c5,0x7a3c025a,0x752f00a5,0x60c46c8c}},	//   _bedø, _déte, rycz, dsim,
   {{0x7c286c8d,0x443a02e5,0x20036c8e,0x43946c8f}},	//   _modr, _dlp_, _raji_, дарс,
   {{0xdb180102,0x3ce62e85,0x6fdd009d,0x69c0361a}},	//   javí, ktov_, _पाहू, name,
   {{0x7c3a0465,0xdb1814e2,0x60c400a6,0xdce000b6}},	// [6950] _oltr, daví, gsim, _vymě,
   {{0x69c06c90,0x7c280029,0x38a00013,0x69db037a}},	//   hame, _nodr, _mòr_, zgue,
   {{0xe7e204dd,0x69c06c91,0x66040979,0x629a0018}},	//   _खाना_, kame, _yaik, ítot,
   {{0x7c3a6c92,0x69c06c93,0x6e220018,0x7c28009c}},	//   _altr, jame, gjob, _aodr,
   {{0x7ec06c94,0x7c286c95,0x43d4015a,0x20036c96}},	//   _pápá, _bodr, _عزیز, _taji_,
   {{0xf1bf08a8,0x7c2800ae,0xb09a00ca,0x5fe209c4}},	//   _xoán_, _codr, _לישר, _पायल,
   {{0x7c286c97,0x69c06c98,0xdb1a022b,0xdb180094}},	//   _dodr, fame, _jetè, baví,
   {{0x69c065a5,0x6e22033c,0x3cff023e,0x69db6c99}},	//   game, cjob, _tsuv_, ugue,
   {{0x69db2e56,0xe8e00019,0xed590d62,0x66046c9a}},	//   rgue, _đợi_, _beže_, _raik,
   {{0x660400bf,0x764d21e9,0x68fb3653,0x6e3b6c9b}},	//   _saik, _amay, rwud, _hlub,
   {{0x66046c9c,0x69c06c9d,0xdb2300bf,0x6e293174}},	//   _paik, bame, _توضی, _koeb,
   {{0x7c280126,0x7a3c0103,0x443a6c9e,0xb5fb016d}},	//   _zodr, _péte, _slp_, zoáv,
   {{0x66044fee,0x69cb0124,0x399a0266,0x6e292c97}},	//   _vaik, _idge, _הינד, _moeb,
   {{0xf745036f,0xdb1a0383,0x7a3c0103,0x764d3b3f}},	//   _нело, _betè, _véte, _emay,
   {{0x66041736,0xd9e20251,0x290f005c,0x6e3b3fba}},	//   _taik, क्कत_, _hrga_, _olub,
   {{0x60c46c9f,0xdb1a02f1,0xae0b0034,0x7a3c0103}},	//   tsim, _detè, _सोलन_, _téte,
   {{0x60c401b3,0xf1bf0028,0x6f0e0b14,0xb1460832}},	// [6960] usim, _toán_, _srbc, чнал,
   {{0x88bd00c7,0x6e3b6ca0,0xaf9a1546,0xa3d6121d}},	//   _আমাক, _alub, стах_, _हाट_,
   {{0x60c46ca1,0xdb1a074a,0x7c282027,0x9f580990}},	//   ssim, _vetë, _rodr, _març_,
   {{0x69c06ca2,0x7c286ca3,0x0d8630da,0x629e019c}},	//   xame, _sodr, плен, _iupo,
   {{0x60c4003d,0xdb180146,0x629e6ca4,0x6e220fbf}},	//   qsim, raví, _hupo, rjob,
   {{0x26c5013f,0x68e40084,0x645c009c,0x63be023b}},	//   kslo_, _äidi, nnri, _jepn,
   {{0xd9f909ca,0x3ce66c8b,0x69c06ca5,0xed596ca6}},	//   ्यंत_, stov_, tame, _reže_,
   {{0x224007ac,0x3ce6230b,0xaf5b00ca,0x629e18fe}},	//   nhik_, ptov_, _הכלכ, _mupo,
   {{0xa3dd000f,0x629e6ca7,0xfe450260,0x98a40138}},	//   _डाल_, _lupo, _تکلی, kymą_,
   {{0x47341a29,0x645c62be,0x69cb226a,0x00000000}},	//   днос, jnri, _edge, --,
   {{0x69c06ca8,0x290f6ca9,0x4e000034,0x224053c4}},	//   pame, _erga_, _ईसाई_, khik_,
   {{0x0f5700a1,0x6b7b00c1,0x69c06caa,0x7a350103}},	//   ליים_, _פראנ, qame, _látj,
   {{0x786f6cab,0x290f04e9,0xdb1a0113,0xb05b02c3}},	//   røvr, _grga_, _setè, _sväm,
   {{0xa3dd0096,0x629e0172,0xdb1a02f1,0x00000000}},	//   _डाळ_, _bupo, _petè, --,
   {{0x629e6cac,0x63be0167,0x274200cd,0xdb1a01f9}},	//   _cupo, _depn, _déné_, _beté,
   {{0x764d6cad,0x20186cae,0xeb3b006e,0x645c02ac}},	//   _umay, _anri_, זעלש, anri,
   {{0x236d00a5,0xa3d60096,0x2007016d,0x629e02a1}},	// [6970] łej_, _हाच_, ônio_, _eupo,
   {{0x63870654,0x6e296caf,0x274200fc,0x00000000}},	//   géné, _soeb, _géné_, --,
   {{0x02a40978,0xbf150037,0x6e3b01b9,0xfe710d7f}},	//   _прям, بواب, _plub, نگر_,
   {{0x2240022b,0xdd912ba0,0x648b00bd,0x765d695e}},	//   chik_, نوا_, _eżit, nnsy,
   {{0xfce515ef,0xdb010018,0xf1bf0072,0x682d0031}},	//   фоло, _jelö, _joám_, _múdr,
   {{0x61ed6cb0,0x3209041c,0x00000000,0x00000000}},	//   lfal, lday_, --, --,
   {{0xdcfb015c,0x6e290db1,0x25a900f0,0x3209008c}},	//   _izuč, _toeb, _ofal_, oday_,
   {{0x5f941300,0x61ed6cb1,0x6e3b00a5,0x32096cb2}},	//   _чист, nfal, _ulub, nday_,
   {{0xa3dd009d,0x3dcd0154,0x261c1073,0xb5fb01f9}},	//   डला_, _idew_, यासी_, bláz,
   {{0xf54f0134,0x32096cb3,0x68240154,0x61ed042c}},	//   kụba_, hday_, _kòdy, hfal,
   {{0x7bc36cb4,0xfe700018,0xf7710246,0x27420113}},	//   manu, _شدہ_, ضاد_, _réné_,
   {{0xddc23fa3,0x7bc32b41,0x26c5013f,0x290f0128}},	//   zlož, lanu, rslo_, _trga_,
   {{0x32096cb5,0x7a350244,0x290300d9,0x61ed1307}},	//   dday_, _látk, ājas_, dfal,
   {{0x61ed08bc,0xe29a6cb6,0x765d0085,0x261c0980}},	//   efal, жав_, ansy, याही_,
   {{0xe7e21827,0x03a3107a,0xa2e367cb,0x224000cd}},	//   _खाता_, тисо, корд, thik_,
   {{0x7bc36cb7,0xb5fb0072,0x32096a95,0x61ed3e99}},	//   hanu, gnád, gday_, gfal,
   {{0x68e96cb8,0xf77803e5,0xdb0101bf,0x224000e7}},	// [6980] nted, mgħa_, _gelö, rhik_,
   {{0x7a3c0257,0x3209008a,0x261c009d,0x7bc36cb9}},	//   _méta, aday_, यावी_, janu,
   {{0x441b0130,0x141b00c1,0x7bc36cba,0x63870257}},	//   _וויס, _וויב, danu, réné,
   {{0x68e90b88,0x32090694,0xddc23b92,0xf09f00b3}},	//   kted, cday_, slož, _fuà_,
   {{0x25e30e72,0x7bc36cbb,0x68e96cbc,0x8c46008f}},	//   ट्टी_, fanu, jted, меде,
   {{0x7bc36cbd,0x2ca94772,0x3dcd05aa,0x7a3501f9}},	//   ganu, íada_, _edew_, _háth,
   {{0x5f0342d1,0x160e04dd,0xddc6455b,0x26ca03e5}},	//   _изра, ियार_, _обви, ġbok_,
   {{0x2be0009d,0x68e92864,0x7bc300f9,0x99860094}},	//   _नावा, fted, aanu, _vlož_,
   {{0x7bc3023f,0x68e902b6,0x7a35455c,0xa3c009c4}},	//   banu, gted, _máth, ुणा_,
   {{0x25e10454,0x7a352204,0x7a3c04ea,0x7bc36cbe}},	//   _काही_, _láth, _déta, canu,
   {{0x320959dc,0x99860146,0x61ed0b12,0xda6f2ba6}},	//   yday_, _ulož_, yfal, _ая_,
   {{0x3209008a,0xa4d5097a,0x00000000,0x00000000}},	//   xday_, номі, --, --,
   {{0x68e91423,0x09361915,0x765d01df,0x61ed2ba4}},	//   cted, _تراج, rnsy, vfal,
   {{0x3209008a,0x62860270,0x260f2f8f,0xed5900c4}},	//   wday_, _ahko, _तोरी_, _ježa_,
   {{0x61ed31b5,0x25a903e5,0x261c0096,0xed5901d3}},	//   tfal, _tfal_, याशी_, _meža_,
   {{0xe816030b,0x7bc3078e,0xc7ad0103,0x00000000}},	//   ताका_, zanu, _پڑی_, --,
   {{0xf09f0019,0x261c2ebd,0x60d60150,0x320913e2}},	// [6990] _quà_, यारी_, grym, rday_,
   {{0x61ed6cbf,0x47d00081,0x32096cb2,0xdb080364}},	//   sfal, ত্রী, sday_, _bedü,
   {{0x645567b0,0x2cad0939,0x47c30033,0x20070206}},	//   mizi, _sted_, _শামী, ľni_,
   {{0x3209008a,0x7bc363c1,0x648b0078,0x7c3802ac}},	//   qday_, wanu, _gżir, ekvr,
   {{0x7bc36cc0,0x4fc7231c,0xb5fb0072,0x79820350}},	//   tanu, _осва, onáb, _nzow,
   {{0xdb85002d,0x09c70096,0x628a028d,0x7a3c020d}},	//   нгли, ळण्य, _èfor, _réta,
   {{0x2be006ae,0x7bc36cc1,0x7a3c5432,0x648000c2}},	//   _नारा, ranu, _séta, köin,
   {{0x68e96cc2,0x64556cc3,0x7a3c1e7d,0x7bc36cc4}},	//   tted, hizi, _péta, sanu,
   {{0x64556cc5,0xdb1805f1,0x2d5800c2,0xe8f6163d}},	//   kizi, ravá, _жить_, елы_,
   {{0x68e96cc6,0x9bf416bd,0x7c380381,0x290d45f9}},	//   rted, _изуч, ckvr, rvea_,
   {{0x68e903f4,0x64556cc7,0x25e1000f,0x7a356cc8}},	//   sted, dizi, _काशी_, _láti,
   {{0xdd12026a,0x7bc16cc9,0x7a3c00fc,0x00000000}},	//   nüşt, _helu, _téta, --,
   {{0x7bc11bd6,0x64556cca,0x98e500e3,0x25e107d5}},	//   _kelu, fizi, _أكتو, _कारी_,
   {{0x6286074a,0x64556ccb,0x7bc1212d,0x443e0103}},	//   _shko, gizi, _jelu, ót_,
   {{0x7bc13665,0xdb010231,0x00000000,0x00000000}},	//   _melu, _telõ, --, --,
   {{0x7bc16ccc,0x60d66ccd,0xc3231ad1,0x628d0009}},	//   _lelu, trym, ымск, gmao,
   {{0xe0da6cce,0x64556ccf,0xe8141fbb,0x41e10296}},	// [69a0] ява_, bizi, _थोडा_, _फारस,
   {{0x64556cd0,0x7bc16cd1,0x7a350143,0x00000000}},	//   cizi, _nelu, _dáti, --,
   {{0xe7e20378,0x671f13ae,0x7a350076,0xed5905db}},	//   _खासा_, यमिक_, _táth, _reža_,
   {{0x7a355d81,0x5fe2052c,0xf7720266,0xb5fb00d2}},	//   _fáti, _पावल, נקא_, mnác,
   {{0x7bc12664,0x629800fd,0x00000000,0x00000000}},	//   _belu, _évoq, --, --,
   {{0xdee62f17,0x6aa10503,0x9f5800da,0x00000000}},	//   _поги, _bulf, _marú_, --,
   {{0x7bc16cd2,0x25e1099d,0x3e752ba4,0x61ef0037}},	//   _delu, _काली_, tått_, _éilí,
   {{0x64556cd3,0x3f7b006e,0xf09f01f7,0x200a6cd4}},	//   zizi, _זאלס, _gràs_, _habi_,
   {{0x200a019b,0x0d8615de,0x7bc16cd5,0xed590660}},	//   _kabi_, _члан, _felu, _teža_,
   {{0x7bc104ee,0xdca30231,0x2d8400c4,0x200a6cd6}},	//   _gelu, _сафи, _izme_, _jabi_,
   {{0x8ad60bf4,0x200a2d3b,0x998d00c4,0xb5fb1405}},	//   _ستائ, _mabi_, rkeš_, jnác,
   {{0x200a6cd7,0x2f5b0089,0x7bc16cd8,0x25e10096}},	//   _labi_, לדינ, _zelu, _काळी_,
   {{0x64556cd9,0x6aa13231,0xda6f0018,0xdb1a0328}},	//   tizi, _zulf, _اُن_, _metí,
   {{0x200a6cda,0xdb1a4a12,0x69c201ff,0x2906007b}},	//   _nabi_, _letí, _heoe, _isoa_,
   {{0x64556cdb,0xb05b02c3,0xb5fb0206,0x00000000}},	//   rizi, _kväv, gnác, --,
   {{0x64556b86,0xa3dd000f,0x26de025b,0xf60b00cd}},	//   sizi, _डाक_, muto_, _رتبه_,
   {{0x26de6cdc,0x628d6cdd,0xdb186cde,0x909900e5}},	// [69b0] luto_, rmao, lavä, дват_,
   {{0xd251037f,0xb881030b,0x78a21612,0x61e66cdf}},	//   _چند_, _říze, _muov, _eckl,
   {{0x26de6ce0,0x200a6ce1,0x7bc16ce2,0x78a200c2}},	//   nuto_, _dabi_, _relu, _luov,
   {{0x7bc16ce3,0x29060a00,0x7a35016d,0xf773006e}},	//   _selu, _osoa_, _táti, אקע_,
   {{0x78a20020,0x7bc13ad9,0x518415a6,0xdb1a0072}},	//   _nuov, _pelu, _бура, _detí,
   {{0x200a6ce4,0x2ef511d9,0x8d740d74,0x7a3c00fd}},	//   _gabi_, _изгр, داما, _béto,
   {{0x26de6ce5,0x48bd0081,0x69c21044,0xcb660f11}},	//   juto_, _আমের, _beoe, каше_,
   {{0x26de0303,0x200a0044,0x7bc16ce6,0x7a3c00fd}},	//   duto_, _zabi_, _welu, _déto,
   {{0x7bc16ce7,0x29060072,0x6aa16ce8,0x200a0d2a}},	//   _telu, _csoa_, _wulf, _yabi_,
   {{0xe73941c3,0x5d54311c,0x200a6ce9,0x39a70139}},	//   део_, _скут, _xabi_, _bísó_,
   {{0x366a1588,0x41e10034,0x290600b3,0xdbf9007f}},	//   дано_, _फांस, _esoa_, _włók,
   {{0x69c26cea,0xbbd140ba,0x64a66ceb,0x3ead00d2}},	//   _geoe, _सयुक, кама, _četl_,
   {{0xda1e0034,0x26de6cec,0xa3dd0096,0x00000000}},	//   भारत_, auto_, डलं_, --,
   {{0x26de6ced,0x98790130,0xa87900c1,0x0ed116f8}},	//   buto_, _קאַט, _קאַר, _हिंड,
   {{0x200a6cee,0x26de6662,0x00000000,0x00000000}},	//   _rabi_, cuto_, --, --,
   {{0x200a0256,0x244d02ef,0x69c20072,0xb5fb6cef}},	//   _sabi_, džmu_, _xeoe, rnác,
   {{0x2fc30090,0x28c402d5,0xdb1a45f8,0x21a32d06}},	// [69c0] _bejg_, लीपि, _retí, риум,
   {{0x161a1006,0x2d9f009c,0x33f600ae,0x00000000}},	//   धाकर_, _ague_, _рчис, --,
   {{0x200a033b,0xdb1a3857,0x036a0b21,0x03d7006e}},	//   _vabi_, _petí, _цинк_, _בוים_,
   {{0xee3a013a,0xed5a0084,0x200a1b63,0xdb1a0231}},	//   ьне_, мое_, _wabi_, _letã,
   {{0x200a6cf0,0xe7e24bc5,0x5ce3007b,0x44250d7f}},	//   _tabi_, _खाला_, ающа, _شریف,
   {{0x61e40b88,0x5c730f1e,0x7d026cf1,0xd7dd0096}},	//   lgil, аліт, rwos, _मागच,
   {{0x78a26cf2,0x7a350155,0xf1bf00fe,0x15f4074c}},	//   _suov, _látu, _soái_, ेजार_,
   {{0x61e4109c,0x26de008f,0x8c3d020a,0xab5c00e8}},	//   ngil, vuto_, _puşc, _ceļa,
   {{0x2d8404a3,0x7e62362c,0x6c060291,0xdb1a0231}},	//   _uzme_, mnop, _изаз, _betã,
   {{0x26de6cf3,0x7a3c5635,0x00000000,0x00000000}},	//   tuto_, _této, --, --,
   {{0xc01500c1,0xdb01592f,0x161400bc,0x00000000}},	//   אַרק_, _aflæ, _तोहर_, --,
   {{0xf1e107e2,0xd00b0081,0x25a000e5,0x78a200c2}},	//   _फाइन, রায়_, _cgil_, _tuov,
   {{0x0fe2009d,0x320b3ed7,0x26de06b0,0x58d41ab2}},	//   _पांढ, _racy_, suto_, _солт,
   {{0x7a356cf4,0x7e626cf5,0x26de6cf6,0x8c3d026a}},	//   _dátu, hnop, puto_, _kuşa,
   {{0xe81f14e5,0x82a40b1b,0x68e00555,0xf8ad0103}},	//   बारा_, иште, lumd, _وکی_,
   {{0x1fcb030b,0x61e46cf7,0x533423c3,0xdb1a0428}},	//   ाण्ड, ggil, шест, _metà,
   {{0x68e011b9,0xe134004b,0xc8796cf8,0xed590141}},	// [69d0] numd, анты, luşa_, _režo_,
   {{0x16210454,0x660d6cf9,0xc10400e3,0x7a35111c}},	//   यावर_, _haak, ؤولي, _hátt,
   {{0x660d6cfa,0x53356cfb,0xbdb00174,0xed590095}},	//   _kaak, _сент, _ịnọr, _pežo_,
   {{0xaee30139,0x2ca40085,0x68e06cfc,0x660d28b4}},	//   _aiṣa, _bumd_, kumd, _jaak,
   {{0x660d6cfd,0x7a35003e,0x28c40179,0xf09f01b9}},	//   _maak, _mátt, लीमि, _gràp_,
   {{0x660d2177,0x7a355d1b,0x2a660124,0x69c601cd}},	//   _laak, _látt, _ajob_, ðken,
   {{0x629d6cfe,0xed590087,0x9be4004d,0xaca30065}},	//   _kiso, _težo_, річк, _isọn,
   {{0x660d3c47,0x7a350088,0x20016cff,0x629d6d00}},	//   _naak, _nátt, lehi_, _jiso,
   {{0x629d6d01,0x68e06d02,0x3d9424d8,0xe81f0f35}},	//   _miso, gumd, _витр, बाला_,
   {{0x7b080084,0x200100cd,0x7d096d03,0x25a06d04}},	//   ästä, nehi_, _ises, _sgil_,
   {{0x660d0517,0xe2030096,0x7a35033c,0x6d68044c}},	//   _baak, _लसूण_, _bátt, ăsaţ,
   {{0x60cd6d05,0x20cf00d9,0x68e06d06,0x629d6d07}},	//   ksam, kļi_, bumd, _niso,
   {{0x61e403a3,0x7d0901ff,0x2a7f023e,0x660d2d01}},	//   vgil, _jses, mlub_, _daak,
   {{0x629d6d08,0x60cd6d09,0x64a3198a,0xf54f0134}},	//   _aiso, dsam, сара, mụla_,
   {{0x629d0d63,0x660d01ee,0x3e7c06f0,0xdb0300d4}},	//   _biso, _faak, síti_, ybný,
   {{0x41b54a4e,0x629d47ea,0x9695163d,0x660d083e}},	//   исут, _ciso, _крыш, _gaak,
   {{0x7644068d,0xdb1a10d9,0x60cd152a,0x7e62005f}},	// [69e0] _iliy, _metá, gsam, vnop,
   {{0x660d6d0a,0xdb1a0146,0x629d0150,0x840600d6}},	//   _zaak, _letá, _eiso, _спож,
   {{0x44446d0b,0x7d096d0c,0x7a350018,0x2a7f6d0d}},	//   _il_, _ases, _játs, klub_,
   {{0x5d6a0084,0xb05b0220,0x629d02a4,0x2a7f023e}},	//   нием_, _svät, _giso, jlub_,
   {{0x44446d0e,0x7a350103,0x6fe202d5,0x76440a4b}},	//   _kl_, _láts, _पाऊं, _mliy,
   {{0x44446d0f,0x6a7e0216,0x629d0a2a,0x7e620dd8}},	//   _jl_, mëfi, _ziso, snop,
   {{0xb5fb030b,0x764406b0,0xa3d50096,0x7d09019f}},	//   dnán, _oliy, हणत_, _eses,
   {{0x5a3421fd,0xdd080181,0x44446d10,0xdb1a1ba6}},	//   рнит, môže, _ll_, _cetá,
   {{0x44446d11,0xb05b0149,0x660d24ab,0xdb1a002b}},	//   _ol_, _tvät, _raak, _detá,
   {{0x44446d12,0x76446d13,0x660d6d14,0x68e008bb}},	//   _nl_, _aliy, _saak, rumd,
   {{0x764406a3,0x2a7f01fa,0x7bca019f,0x60cd6d15}},	//   _bliy, blub_, mafu, zsam,
   {{0xdb080149,0x7bca2227,0xd6d700c2,0x656204e9}},	//   _bedö, lafu, ыть_, _žoha,
   {{0x4444516f,0x629d6d16,0x3c3914b1,0xb4c1009d}},	//   _bl_, _riso, _sèvi_, ुळे_,
   {{0x7bca417d,0x660d6d17,0x76446d18,0x629d6d19}},	//   nafu, _waak, _eliy, _siso,
   {{0x629d5d08,0x43950a27,0xe2f80565,0x660d6d1a}},	//   _piso, равс, лері_, _taak,
   {{0x44446d1b,0xf1270d64,0x7a350103,0x7bca6411}},	//   _el_, льзо, _hátr, hafu,
   {{0xd49b6d1c,0x44442751,0x7bca6d1d,0xa3d5171b}},	// [69f0] _про_, _fl_, kafu, _копч,
   {{0x44446d1e,0x60cd584b,0x629d0169,0x2be00e28}},	//   _gl_, rsam, _wiso, _नागा,
   {{0x629d6d1f,0x2be8034c,0x7bca6d20,0x20016d21}},	//   _tiso, च्छू_, dafu, rehi_,
   {{0x20010498,0x60cd6d22,0xb5fb00b6,0xaca40134}},	//   sehi_, psam, znán, chịr,
   {{0x1d092457,0x7bca6d23,0xb05b02c3,0x16c10285}},	//   тели_, fafu, _dvär, _शब्ब,
   {{0x7bca6d24,0xab5c00d9,0x7d09033b,0xe29f003e}},	//   gafu, _ceļo, _vses, _hið_,
   {{0xb5fb030b,0x64570063,0xf54f0134,0x4421024a}},	//   vnán, _mmxi, wụla_, _mnh_,
   {{0x6eaa02d5,0xe8f92efb,0x4df9006e,0x4421014b}},	//   _जंतु, вли_, _שפּא, _lnh_,
   {{0x7a3c0257,0x7bca1a05,0xe29f003e,0x7d092149}},	//   _méth, bafu, _mið_, _uses,
   {{0xb8fd000f,0xe29f003e,0x2a7f6d25,0xc79500c2}},	//   _तट_, _lið_, slub_, ирны,
   {{0xb5fb0fb6,0xf62616a1,0x69cf0328,0x22490d1f}},	//   rnán, адно, óces, khak_,
   {{0x442100ef,0x7ae33129,0x64456c75,0x38a96d26}},	//   _anh_, munt, _alhi, _túr_,
   {{0x44446d27,0x64a6287c,0x443300a1,0x7ae3411b}},	//   _pl_, рага, _box_, lunt,
   {{0x7e690292,0x998400e3,0x93466d28,0x4421071a}},	//   _ljep, _الهو, анге, _cnh_,
   {{0x7e7b0372,0x425633d0,0x7ae36d29,0xb7790130}},	//   _okup, атат, nunt, _באַש,
   {{0xc243215f,0x7644612b,0x7a3c03a9,0x682d0031}},	//   онск, _uliy, _céth, _núdz,
   {{0x44446d2a,0xe2971bd8,0x7bca3990,0x394d6d2b}},	// [6a00] _tl_, рат_, yafu, nzes_,
   {{0x44446d2c,0x7ae36d2d,0x28dd3ec9,0xf1bf00de}},	//   _ul_, kunt, _मिनि, _soát_,
   {{0xeaf40454,0x645c6d2e,0x7ae36d2f,0xaf06085a}},	//   _आहेत_, miri, junt, рпел,
   {{0x645c6d30,0x13a809b4,0x22496d31,0x7e696d32}},	//   liri, _جنگی_, chak_, _cjep,
   {{0x7bca6d33,0xcfaa006f,0x44330092,0x61f6003e}},	//   tafu, _لازم_, _yox_, mfyl,
   {{0x645c6d34,0x394d00d9,0x7e7b0201,0xe7ea0bf5}},	//   niri, dzes_, _ekup, ज्ञा_,
   {{0x7ae36d35,0x7bca6d36,0xb05b0149,0xaa580b7b}},	//   gunt, rafu, _tvär, лику_,
   {{0x645c6d37,0xfb190068,0xb5fb045e,0x7bca6d38}},	//   hiri, اروں_, gnál, safu,
   {{0x645c21dd,0x7a352e19,0x3ead00e7,0x8c3d0233}},	//   kiri, _pátr, _četi_, _kuşl,
   {{0x645c6d39,0x7ae36d3a,0x7a3c025a,0xb5fb0037}},	//   jiri, bunt, _méti, anál,
   {{0x645c6d3b,0xcb67188d,0xdb0103a9,0x00000000}},	//   diri, _кафе_, _nglè, --,
   {{0x8c3c0b88,0xe7ea121d,0x645c3ef1,0x44210441}},	//   _diğe, ज्जा_, eiri, _snh_,
   {{0x645c6d3c,0x7bc82c09,0x6445022e,0x44330063}},	//   firi, _kedu, _plhi, _pox_,
   {{0x645c6d3d,0x5fe2121d,0xd7ef0037,0xad6400fe}},	//   giri, _पागल, _يكن_, _đừn,
   {{0x22490979,0xeaf4009d,0x31c71146,0x61f600f0}},	//   thak_, _आहोत_, исав, ffyl,
   {{0x645c00e3,0x7bc86d3e,0xd9f833dc,0x61d800c2}},	//   airi, _ledu, ्जित_, имся_,
   {{0xe29f38d5,0x645c6d3f,0x765d6d40,0x224929dd}},	// [6a10] _við_, biri, misy, rhak_,
   {{0x7e7b02fb,0x2fc700ef,0x765d6d41,0x645c6d42}},	//   _skup, úng_, lisy, ciri,
   {{0x261c13b4,0x7ae303be,0x753d0018,0x9259004c}},	//   याची_, xunt, lysz, _бант_,
   {{0x765d0c56,0xf1ab001c,0x7a3c5635,0xf1c40094}},	//   nisy, _جاده_, _féti, ruší_,
   {{0x7bc86d43,0x753d0103,0xe4500018,0x9f586d44}},	//   _bedu, nysz, _رضی_, _baró_,
   {{0x7ae36d45,0xfaa50265,0x7bc86d46,0xaca40134}},	//   tunt, бако, _cedu, chọr,
   {{0x25e802e8,0x8b94013d,0x53af009f,0x9f5800b3}},	//   _झाली_, оръч, जुएश, _daró_,
   {{0x7ae36d47,0x7e7b6d48,0x394d01bf,0x20116d49}},	//   runt, _ukup, tzes_, _hazi_,
   {{0x20116d4a,0x26de6d4b,0x645c6d4c,0x765d6d4d}},	//   _kazi_, erto_, yiri, disy,
   {{0x7bc86d4e,0x7d1b1130,0xdb1a2104,0x394d6d4f}},	//   _gedu, _irus, _betä, rzes_,
   {{0x394d0068,0x20116d50,0x442600de,0x7d1b6d51}},	//   szes_, _mazi_, _đo_, _hrus,
   {{0x7d1b1e29,0x645c697c,0x673c0565,0x7bc81d55}},	//   _krus, wiri, ørja, _zedu,
   {{0x645c668d,0xba740080,0xa8a720ec,0x753d0018}},	//   tiri, _بالت, _трек, gysz,
   {{0x628f0090,0x261804f1,0x9f58028d,0x7a3c5635}},	//   _ahco, _बोरी_, _marò_, _réti,
   {{0x765d1e37,0x28dd382b,0xf7730fba,0x7a3c6d52}},	//   bisy, _मिडि, _باش_, _séti,
   {{0x645c6d53,0x628f6d54,0x7a3c201c,0x28c40034}},	//   siri, _chco, _péti, लीवि,
   {{0x645c6d55,0x20116d56,0x66066d57,0x61f66d58}},	// [6a20] piri, _bazi_, mekk, rfyl,
   {{0x66066d59,0x2240057a,0xa3be00a3,0x2011020a}},	//   lekk, skik_, आरओ_, _cazi_,
   {{0x7d1b6d5a,0xb5fb0146,0x61f63052,0x2d8000d9}},	//   _arus, znám, pfyl, ļiem_,
   {{0x7bc86d5b,0x7a3c6d5c,0x8c3d6d5d,0x66066d5e}},	//   _sedu, _hétv, _duşm, nekk,
   {{0x7bc86d5f,0x51f70100,0x271700de,0xf1b300ca}},	//   _pedu, _اسپر, _lăn_, _מסר_,
   {{0x765d1e2a,0x20116d60,0x7d1b6d61,0x62844bf9}},	//   zisy, _gazi_, _drus, llio,
   {{0x753d00a5,0x245800a7,0xdee311db,0x271700fe}},	//   zysz, _cümə_, _нори, _năn_,
   {{0x26183e1b,0x9f5800e5,0x7bc86d62,0x66060dfb}},	//   _बोली_, _farò_, _wedu, jekk,
   {{0x7bc802e7,0x7d1b6d63,0x765d6d64,0x6606637f}},	//   _tedu, _grus, visy, dekk,
   {{0x6b812e6f,0x27170023,0x765d07ac,0x37c80033}},	//   _fylg, _băn_, wisy, _শাহর,
   {{0x907b0105,0x765d0c56,0x27170028,0xbb8600e3}},	//   רטיי, tisy, _căn_, _الاي,
   {{0xdb1a00c2,0x27ee00c6,0x66066d65,0x00000000}},	//   _vetä, _šoną_, gekk, --,
   {{0xb9960080,0x765d6d66,0x67d40120,0x00000000}},	//   _الشب, risy, _долу, --,
   {{0x765d1d11,0x26de02dd,0x769f0065,0x628403a8}},	//   sisy, prto_, _bàyì, elio,
   {{0x765d6d67,0x6606611c,0x6aa2024a,0x00000000}},	//   pisy, bekk, _kiof, --,
   {{0x62840465,0x7982010a,0x915e020b,0x2011019f}},	//   glio, _kyow, _sắc_, _sazi_,
   {{0x5187483b,0xc0350396,0xb0350da5,0xb5fb488f}},	// [6a30] сува, онај, онаш, riád,
   {{0x6aa201b9,0x7d1b0052,0x62840fe9,0x00000000}},	//   _liof, _rrus, alio, --,
   {{0x7d1b1197,0xdcfb0146,0x9f5800e5,0xb5fb0146}},	//   _srus, _vyuč, _sarò_, piád,
   {{0x20111b24,0x54ed023a,0x7982039f,0x00000000}},	//   _wazi_, _जमाए_, _oyow, --,
   {{0x798203a9,0x00000000,0x00000000,0x00000000}},	//   _nyow, --, --, --,
   {{0x7a3c0113,0x26c2031a,0x00000000,0x00000000}},	//   _métu, ćkoj_, --, --,
   {{0x1a291c00,0x447c006e,0x7982063d,0x00000000}},	//   ижки_, אנגע, _ayow, --,
   {{0x8c0900c7,0x6aa23c59,0x6480007b,0x271700fe}},	//   লাইন_, _ciof, löit, _răn_,
   {{0x2d996d68,0xdb180146,0xaca300de,0x271700de}},	//   _àse_, mavý, _trốn, _săn_,
   {{0x66063bb6,0x79820270,0x6480007b,0x00000000}},	//   wekk, _dyow, nöit, --,
   {{0x61fd06c2,0x1bb8177a,0x6aa26d69,0x62846d6a}},	//   _obsl, _طالع_, _fiof, ylio,
   {{0x271700ef,0x28f90084,0x78bb032c,0x7a3c00b3}},	//   _văn_, _ведь_, ppuv, _bétu,
   {{0xa5bb0102,0x6606637f,0xdb01052f,0x64400161}},	//   tjór, rekk, _aflø, êmio,
   {{0xf7451357,0x2d8d0010,0x66062075,0x80b00789}},	//   _мело, _mzee_, sekk, _अंबे,
   {{0x69cb005a,0x4911000d,0x2bfb0789,0x04fa0033}},	//   _kege, तिको_, ल्यू_, ইটের_,
   {{0x69cb6d6b,0xcb120796,0x00000000,0x00000000}},	//   _jege, ולל_, --, --,
   {{0x69cb6d6c,0x62846d6d,0x78a30172,0x3eaa058f}},	// [6a40] _mege, rlio, _kinv, _subt_,
   {{0x61ef158e,0x69cb202c,0x62840580,0xb5fb5991}},	//   _eccl, _lege, slio, ciáb,
   {{0xeda62f17,0x1eda00e3,0x62846d6e,0x232a171b}},	//   ошло, شباب_, plio, _тони_,
   {{0x69cb6d6f,0x0d866d70,0x5bb4439d,0x2bb42301}},	//   _nege, олен, ुर्व, ुर्थ,
   {{0xc27b0054,0xf6530289,0x00000000,0x00000000}},	//   _כרטי, וצא_, --, --,
   {{0x8cdb0296,0x69d96d71,0xdfd2001c,0x7a3c003e}},	//   _निरो, _adwe, _زير_, _létt,
   {{0x2d8d010a,0x290f01ee,0x9f5801cd,0x00000000}},	//   _ezee_, _asga_, _garð_, --,
   {{0x26d80224,0x4df400b6,0xa2cd0285,0xe45f6d72}},	//   árom_, _एउटै_, _तबस्, nsör_,
   {{0xed5a0303,0x69cb6d73,0x69d90150,0x78a3010a}},	//   _тоа_, _dege, _ddwe, _binv,
   {{0x290f0036,0x291d0154,0x69cb026d,0x69d9039f}},	//   _dsga_, _drwa_, _eege, _edwe,
   {{0x41aa22a3,0xd7f800ae,0x00000000,0x00000000}},	//   कशास, rfă_, --, --,
   {{0x69cb09ed,0x8b653862,0x78a36d74,0x7a3c6d75}},	//   _gege, _عالم, _einv, _pétu,
   {{0xb5fb00e3,0xb86512eb,0x7e9b0796,0x6480007b}},	//   nnái, _کانو, יסטו, jöis,
   {{0x61ef0124,0x69cb6d76,0xaaa9009f,0x00000000}},	//   _sccl, _zege, _चूँक, --,
   {{0x3a260629,0xd25b6d77,0xb5fb0103,0x69cb02a4}},	//   _knop_, аца_, riáb, _yege,
   {{0x78a3029a,0xa2dc00b6,0xdb1a037a,0xb21b02b6}},	//   _zinv, _फिर्, _betú, _skæb,
   {{0x25a9007a,0xc69400c1,0x3fab0291,0x7bda5de7}},	// [6a50] _igal_, _קאפ_, ањем_, _odtu,
   {{0x7a3c0103,0x7bde037a,0x644e6d78,0x00000000}},	//   _kéts, ópul, chbi, --,
   {{0xaaa90251,0x64800084,0xb5fb6d79,0x00000000}},	//   _चूंक, röit, ciác, --,
   {{0x9f580088,0x2d990094,0x3d9500d3,0x00000000}},	//   _varð_, _úsek_, пиер, --,
   {{0x69cb3b7a,0x5184141b,0x61ed01d3,0xdb180094}},	//   _rege, _жура, mgal, ravý,
   {{0x69cb6d7a,0x61ed6d7b,0x661a01d3,0x78ab00c4}},	//   _sege, lgal, ētki, _rugv,
   {{0x81ce00c7,0xfe730f43,0x78a36d7c,0x28dd0006}},	//   _রাত_, _قدر_, _rinv, _मिहि,
   {{0xefc80019,0x78a30313,0xed5914f3,0xf7710103}},	//   _đỉnh_, _sinv, _sežu_, ہاج_,
   {{0x7a3c0102,0x69cb6d7d,0x2d8d0a4b,0x8cc10179}},	//   _rétt, _vege, _uzee_, रीखो,
   {{0xa2dc0abe,0x69cb6d7e,0x25b60287,0x1bf20034}},	//   _फिल्, _wege, ूर्ण, _घायल_,
   {{0x69cb6d7f,0x2cad0090,0x7e6b020b,0x00000000}},	//   _tege, _hued_, ongp, --,
   {{0x63b500a5,0xaca30019,0x291d0034,0xd0140033}},	//   eczn, _trồn, _trwa_, সায়_,
   {{0x61ed6d80,0x78a3009e,0x04b62a6e,0xed5909ac}},	//   dgal, _tinv, ясня, _težu_,
   {{0x25a96d81,0xe1ff0af0,0x78a30167,0x61ed010a}},	//   _egal_, _abó_, _uinv, egal,
   {{0x68e903a8,0x7e6b0270,0xdb1a016d,0x25ad574a}},	//   lued, kngp, _setú, žela_,
   {{0xcb1207a6,0x61ed6d82,0x575600a1,0x673c01a5}},	//   עלן_, ggal, _מבצע_, ärje,
   {{0x80a613c3,0x9abc009e,0xb5fb0206,0x00000000}},	// [6a60] سمان, _irċe, siác, --,
   {{0x61ed0517,0x3ea46d83,0x5ed30081,0x66163810}},	//   agal, _simt_, _সহজে, _hayk,
   {{0x645e6d84,0x443a6d85,0xe4570130,0x7a3c0257}},	//   _impi, _iop_, _זייט_, _métr,
   {{0xe1ff0649,0x7a3c0018,0x2d8400e1,0x290d0d0a}},	//   _gbó_, _létr, _pyme_, kwea_,
   {{0x2ca50a6a,0x443a6d86,0x66166d87,0x7cd7004d}},	//   _bild_, _kop_, _mayk, змір_,
   {{0xb5fb00e3,0xe81b00aa,0xed4f0018,0x26d80103}},	//   rnái, _भोला_, چھے_, árok_,
   {{0x443a0284,0xaab81ac9,0x60230077,0x7f4a0076}},	//   _mop_, زگار_, _ядра, _الأق_,
   {{0x443a0023,0x98b81165,0x66160154,0x00000000}},	//   _lop_, олит_, _nayk, --,
   {{0x63b50067,0xfce35fdd,0x68e90150,0x588601b6}},	//   yczn, _пото, gued, зына,
   {{0x7e626d88,0xbc632c22,0x61ed6d89,0x315700ca}},	//   liop, _звук, zgal, פיין_,
   {{0x7a3c0257,0xa2b13ec4,0xb9140174,0x9f5800b3}},	//   _détr, _आंध्, _yadị_, _obrí_,
   {{0x645e6d8a,0x60d66d8b,0x61ed0188,0x7c3a0023}},	//   _ampi, ksym, xgal, _hotr,
   {{0x7aea3813,0x6d426d8c,0x66166d8d,0xab5c00e8}},	//   luft, nyoa, _dayk, _ceļv,
   {{0x7e626d8e,0x9f58034f,0xb8661516,0xe4a4044b}},	//   hiop, _abrí_, _عاشو, ерсо,
   {{0xb5fb0074,0x1dcc077d,0x61ed22bb,0x7c3a6d8f}},	//   dnáv, ारात, tgal, _motr,
   {{0x7c3a6d90,0x61ed6d91,0x62340396,0x645e6d92}},	//   _lotr, ugal, несу, _empi,
   {{0x61ed6d93,0x7c2852e8,0x764d6d94,0x443a084e}},	// [6a70] rgal, _ondr, _ilay, _fop_,
   {{0x7c3a6d95,0x61ed6d96,0x3014002d,0xc87900ae}},	//   _notr, sgal, ндур, tuşi_,
   {{0x61ed01f9,0x00000000,0x00000000,0x00000000}},	//   pgal, --, --, --,
   {{0x7c280501,0x28dd143d,0x7c3a01f7,0xf2d200c1}},	//   _andr, _मिलि, _aotr, _בעט_,
   {{0x2ab108ec,0xa3b1412e,0xc879020a,0x764d001c}},	//   _sáb_, _ओला_, suşi_, _mlay,
   {{0x7c3a020a,0xc879020a,0x443a40a0,0xf1c400d4}},	//   _cotr, puşi_, _xop_, prší_,
   {{0xfbd000e3,0x764d6d97,0x2ca5052f,0x7a3c0257}},	//   اته_, _olay, _vild_, _rétr,
   {{0x7c281d1b,0x7e6201b9,0xca06008f,0x2ca500ca}},	//   _endr, ciop, днъж_, _wild_,
   {{0x2cad007a,0x7a3c6d98,0x7c3a5703,0x261800c3}},	//   _uued_, _pétr, _fotr, _बोगी_,
   {{0x764d6d99,0xddc214f3,0xefc800ef,0x6e3b6d9a}},	//   _alay, mnoš, _định_, _houb,
   {{0x443a6d9b,0x6e3b6d9c,0x764d0383,0x6e294c92}},	//   _rop_, _koub, _blay, _kneb,
   {{0xb5fb025b,0x2b4f01e8,0x443a6d9d,0x6e3b0313}},	//   znáv, ımcı_, _sop_, _joub,
   {{0x68e91c9a,0x6e3b019c,0x443a00ca,0x7646007b}},	//   qued, _moub, _pop_, rkky,
   {{0x6e3b6d9e,0x7c3a0072,0x764d063d,0x7d04028e}},	//   _loub, _xotr, _elay, çisi,
   {{0x64a308a1,0xb5fb291d,0x638314f2,0x443a00d4}},	//   тара, vnáv, вгра, _vop_,
   {{0xd0480253,0x2a6d6d9f,0x6e290172,0x00000000}},	//   ələr, nneb_, _nneb, --,
   {{0x443a6da0,0xb5fb0146,0x321c02c6,0x10a63126}},	// [6a80] _top_, tnáv, ěvy_, диан,
   {{0x645e6da1,0xddc2005f,0x6d420051,0x6e2900b6}},	//   _umpi, dnoš, vyoa, _aneb,
   {{0x6e3b6da2,0xdfcf0604,0xaf0a1f9c,0x00000000}},	//   _boub, شين_, تقام_, --,
   {{0x7c2802e7,0x93ee099d,0x2a6d14c0,0xd3370266}},	//   _sndr, _जाँच_, jneb_, _חרטה_,
   {{0x6da3079c,0xc87903e0,0x00000000,0x00000000}},	//   вица, luşu_, --, --,
   {{0x7e626da3,0x6e290120,0x7c8300c2,0x00000000}},	//   siop, _eneb, куще, --,
   {{0x7c3a10af,0xb5fb15bf,0x2122061d,0x6e3b022b}},	//   _votr, dián, _hrkh_, _foub,
   {{0x20186cda,0x39140f7e,0xddc2042d,0x260018ff}},	//   _hari_, емир, bnoš, ष्मी_,
   {{0x93ee05d4,0x5fb20034,0xb5fb291d,0xd7e604a1}},	//   _जांच_, _जलाल, fián, міно,
   {{0x201856ba,0x47340cd7,0x7c2809a8,0x7e6000f9}},	//   _jari_, енос, _undr, _hmmp,
   {{0x764d6da4,0x26d8020d,0x9b460c5e,0xd5ed00fe}},	//   _play, éro_, _تناو, _nhạ,
   {{0x20186da5,0x81e40081,0x6e3b002b,0x8c3d6da6}},	//   _lari_, প্ত_, _xoub, _duşu,
   {{0x9813001c,0x25ad30c7,0x00000000,0x00000000}},	//   ربیا, želo_, --, --,
   {{0x20180ba7,0x36d400d6,0xb5fb0143,0x00000000}},	//   _nari_, _зокр, cián, --,
   {{0xd6cf6da7,0xd5ed00fe,0x02a7098a,0xddc26da8}},	//   _шт_, _chạ, драм, znoš,
   {{0x764d0010,0x20180bb6,0xd5b800d6,0x3ce66da9}},	//   _ulay, _aari_, _ось_, krov_,
   {{0x20186daa,0x6e3b6d52,0x394406f5,0x00000000}},	// [6a90] _bari_, _roub, nyms_, --,
   {{0x201803b4,0x6e3b000d,0xdfd10080,0x26000006}},	//   _cari_, _soub, ايا_, ष्ठी_,
   {{0x201843b4,0x6e3b1022,0x2dbc0294,0xd34700d1}},	//   _dari_, _poub, _ịkụ_, _غیره_,
   {{0xb05b1680,0xddc200cb,0x11eb1f11,0x201801ff}},	//   _städ, tnoš, _بعدي_, _eari_,
   {{0x20186dab,0x3ce66dac,0xe3a51ac9,0xfce52753}},	//   _fari_, grov_, _تشکی, холо,
   {{0x201868ce,0x6e3b0383,0x6b883720,0xb5fb0072}},	//   _gari_, _woub, _bydg, xián,
   {{0x6e3b2f1b,0x7e770018,0x290621c8,0x8cdb09c4}},	//   _toub, _قارئ, _apoa_, _निको,
   {{0xe9d926d0,0x20180193,0x7f940d84,0x2ecb009d}},	//   чки_, _zari_, _расх, ाठीत,
   {{0x2018092f,0x5c75321c,0x321908b6,0x8c3d6d5d}},	//   _yari_, _злат, _masy_, _buşt,
   {{0xc05200c1,0xb5fb0146,0x271e0090,0x2a6d00aa}},	//   ָזט_, znát, _bċn_, sneb_,
   {{0xb5fb1e6f,0x22b86dad,0x2249047e,0x6b8800eb}},	//   rián, _očka_, kkak_, _gydg,
   {{0xf65252c6,0xb21b02b6,0xfb1a00ca,0x00000000}},	//   ائد_, _skæn, _מועמ, --,
   {{0xe1ff0088,0xb7d50065,0x00000000,0x00000000}},	//   _ljós_, _aṣer, --, --,
   {{0x6f150034,0x8c3d0233,0x291f0a4b,0xd5ed00fe}},	//   _oszc, _tuşu, mvua_, _phạ,
   {{0x20186dae,0xaca30174,0x68fb6daf,0x32190d46}},	//   _rari_, _apịn, ltud, _basy_,
   {{0x2cbf00cc,0x3ddf03a9,0xdb1a0094,0xb5fb6db0}},	//   _otud_, _nduw_, _netý, niál,
   {{0x20184018,0x66046db1,0x26d80181,0x68fb0bfe}},	// [6aa0] _pari_, _ibik, árov_, ntud,
   {{0xb4fb0054,0x20186db2,0x321900a1,0x752401e9}},	//   _צפיי, _qari_, _easy_, _iriz,
   {{0x20186db3,0x68fb00aa,0x75240095,0xf1bf02c6}},	//   _vari_, htud, _hriz, _znám_,
   {{0x3ce65c44,0xee3a0c36,0x2018023f,0x6723015c}},	//   trov_, яне_, _wari_, _mrnj,
   {{0xb5fb6db4,0x20186db5,0x237200d9,0x6286003d}},	//   onár, _tari_, šajā_, _ikko,
   {{0x60c400a0,0x2bfb2235,0x00000000,0x00000000}},	//   mpim, ल्लू_, --, --,
   {{0x68fb5593,0x2cbf0154,0x66046db6,0xff0700ae}},	//   etud, _etud_, _obik, _перк_,
   {{0xdff00da9,0x98c6061b,0x75246db7,0xbea3246b}},	//   _चाँद_, нсол, _oriz, _баск,
   {{0x68fb6db8,0xc8660ce5,0x3f8a00f0,0xed570231}},	//   gtud, етни, _hybu_, _зот_,
   {{0x66046db9,0x672300cc,0x1bba00e3,0x2a6a0103}},	//   _abik, _brnj, _رائع_, őbb_,
   {{0x672308a9,0xd6d700d3,0xb5fb1515,0x75240fd1}},	//   _crnj, нтя_, dnár, _ariz,
   {{0xb5fb2299,0x212002e6,0xd0190033,0x224901c8}},	//   ciál, kvih_, ঠায়_, xkak_,
   {{0x752400d3,0x386505ae,0xdb080537,0xdff01115}},	//   _criz, bilr_, _afdø, _चांद_,
   {{0x62866dba,0xddc90ea3,0x66040a15,0xb5fb6dbb}},	//   _akko, _mješ, _ebik, gnár,
   {{0xddc92650,0x75246dbc,0x321912c5,0x00000000}},	//   _lješ, _eriz, _pasy_, --,
   {{0xdb1a023b,0x1fcd0033,0x998d191d,0xb5fb0844}},	//   _aftë, _লাইস, lješ_, rnás,
   {{0x60f90fdf,0x660f0074,0x067c040a,0x22496dbd}},	// [6ab0] ьная_, meck, _מנהל, rkak_,
   {{0x661d6dbe,0x660f4418,0xb4dd0096,0x62866dbf}},	//   ldsk, leck, डळी_, _ekko,
   {{0xc88501bf,0xdb1a0220,0x661d6dc0,0xc7d700ca}},	//   äßig_, _metó, odsk, גובי_,
   {{0x661d1842,0x660f025b,0xddc9015c,0x22b8080e}},	//   ndsk, neck, _bješ, _učka_,
   {{0xed580a8d,0x64480149,0x661d19fb,0xdd94013f}},	//   ної_, ödig, idsk, гацы,
   {{0xe5226dc1,0x660f013b,0x628d6dc2,0x9c870094}},	//   मिति_, heck, llao, dičá,
   {{0x6f150034,0xa7fc00a7,0x998d09ac,0x61f60537}},	//   _uszc, hnıs, dješ_, _æglø,
   {{0x68fb6dc3,0x78aa0036,0x661d6dc4,0xaca30065}},	//   ttud, _aifv, jdsk, _ipọn,
   {{0xb5fb0244,0x660f6dc5,0xdb1a0220,0x6723033b}},	//   riál, deck, _betó, _srnj,
   {{0x7d096dc6,0x68fb6dc7,0x67231197,0xdb1a0072}},	//   _ipes, rtud, _prnj, _cetó,
   {{0xdddb030b,0xf09200ca,0x6d595530,0x291f007b}},	//   _zkuš, שני_, lzwa, svua_,
   {{0x67236dc8,0x7d090134,0x6fcd0033,0xcb1200ca}},	//   _vrnj, _kpes, ালয়ে, _כלב_,
   {{0x69c93329,0x95991e78,0x6d596dc9,0x629a00d2}},	//   mbee, етру_, nzwa, ůtok,
   {{0xe73103ed,0x69c9008a,0xa2e600c2,0x672314f3}},	//   _نصب_, lbee, когд, _trnj,
   {{0xe73902ec,0x67150fef,0x2a9e0174,0xd0120421}},	//   _цей_, _तनिक_, _ọbia_, یلر_,
   {{0x26c51f84,0x69c96dca,0x628d6dcb,0x66046dcc}},	//   mplo_, nbee, glao, _ubik,
   {{0x21672060,0x75246dcd,0x00000000,0x00000000}},	// [6ac0] вити_, _uriz, --, --,
   {{0xddc90292,0x071534d8,0x68e90131,0x64a66dce}},	//   _rješ, _तनाव_, ired, _шапа,
   {{0x7d09001f,0x68e902ad,0xdddb0660,0xdb1a00ee}},	//   _apes, hred, _skuš, _letò,
   {{0xddc90ea3,0xdee30ef1,0x60c42490,0x6286007b}},	//   _pješ, роци, ppim, _ukko,
   {{0x9cb300e3,0x68e96dcf,0x69c96dd0,0xd7e100a4}},	//   لمنت, jred, dbee, पणाच,
   {{0xddc90ea3,0xddc20146,0x660f0094,0x5f061c47}},	//   _vješ, dnoť, zeck, _изга,
   {{0xdb1a2027,0x68e96dd1,0x661d35bc,0x7d0905aa}},	//   _retó, ered, ydsk, _epes,
   {{0x68e96dd2,0x69c96dd3,0xddc90ac3,0xf2d300ca}},	//   fred, gbee, _tješ, בעה_,
   {{0x660f6dd4,0x6da30cb0,0x22b800d4,0x6aab041c}},	//   veck, _вита, _očko_, _digf,
   {{0xad256dd5,0x63bc0580,0x660f6dd6,0xb5fb0072}},	//   _حرفو, jcrn, weck, riám,
   {{0x660f6dd7,0x7bd86dd8,0x2ac80065,0x6aab0154}},	//   teck, mavu, _dìbò_, _figf,
   {{0x26f2000f,0x68e92ca7,0x3ce90d5d,0x69dd003e}},	//   _अमीर_, bred, šave_, óset,
   {{0x660f6dd9,0x2cac01af,0x3dd70081,0x661d0c96}},	//   reck, _kidd_, _হামল, rdsk,
   {{0x7bd86dda,0x26d80103,0xd5c32647,0x00000000}},	//   navu, áros_, _व्रज, --,
   {{0xe5c7276c,0x07f70814,0xa3d4009d,0x38790103}},	//   _испо, _شروع_, _हजर_, ésre_,
   {{0x35f50977,0x62580076,0x7bd86ddb,0xb7d50065}},	//   _спир, _líof, havu, _iṣar,
   {{0x5187483b,0x7bd86ddc,0xaad900b6,0x00000000}},	// [6ad0] тува, kavu, _यौनक, --,
   {{0x7bd80031,0x25be02c6,0x9f351acf,0x00000000}},	//   javu, ětle_, лезі, --,
   {{0x7d096ddd,0xd2510604,0x7bd85c8a,0x6ad100aa}},	//   _spes, _هند_, davu, _सबेर,
   {{0x7bca023e,0x6d1e08e7,0x68e96dde,0x2cac030a}},	//   ebfu, पिंग_, yred, _aidd_,
   {{0xf1bf0649,0x00000000,0x00000000,0x00000000}},	//   _ifá_, --, --, --,
   {{0x68e90335,0x7bd86ddf,0xeb9916bd,0x6d596de0}},	//   vred, gavu, нил_, rzwa,
   {{0x9f3400d6,0x8c4208d8,0x69c91044,0xc43c00ca}},	//   _кері, сеще, tbee, ותגי,
   {{0xe81b00aa,0x00000000,0x00000000,0x00000000}},	//   _भोजा_, --, --, --,
   {{0x69c932c2,0x8cbb00cd,0x7bd81fa6,0xb7d50af0}},	//   rbee, _آدرس_, bavu, _aṣar,
   {{0x2ab80139,0x67210357,0x3ead01ce,0x2cac01ce}},	//   _féb_, tvlj, _hiet_, _gidd_,
   {{0x68e915f4,0x3ead020b,0x62840a4b,0x00000000}},	//   sred, _kiet_, yoio, --,
   {{0x3ead009e,0xcf9200ca,0x67210218,0x2cac013c}},	//   _jiet_, מטי_, rvlj, _zidd_,
   {{0x3ead0078,0x28dd0ded,0x6258033c,0x49da0a85}},	//   _miet_, _मिटि, _híog, _سانگ_,
   {{0xfbe500c7,0x3ead6de1,0x97250e00,0xfbc600a8}},	//   প্রত, _liet_, _مفتو, रुपम,
   {{0x91e61b48,0xc8a8008f,0x00000000,0x00000000}},	//   лове, _ръце_, --, --,
   {{0x3ead4ff3,0x425523e3,0x7bd86de2,0x2d8d0350}},	//   _niet_, атут, zavu, _oyee_,
   {{0x7bd86de3,0x2d8d0174,0x6284044c,0x00000000}},	// [6ae0] yavu, _nyee_, roio, --,
   {{0xfdcc07ad,0xc4d30327,0x8fa62b36,0x00000000}},	//   ार्फ, _הגז_, газе, --,
   {{0x93fb00c1,0x3ead00de,0x7bd80b2f,0xc7d600ca}},	//   _אליי, _biet_, vavu, רועי_,
   {{0x22161c00,0x201c0995,0x7bd816ed,0xd04d0d2a}},	//   _сфор, žvi_, wavu, kraɗ,
   {{0xa07600c2,0x8c46171b,0x3ead610f,0x2cac0113}},	//   _бывш, леде, _diet_, _pidd_,
   {{0x61f60150,0x644e6de4,0x6258033c,0x00000000}},	//   lgyl, nkbi, _bíog, --,
   {{0x7bd86de5,0x81d70033,0x3ead03a8,0x22426de6}},	//   ravu, _সাত_, _fiet_, _kokk_,
   {{0x3ead6de7,0x61f66be3,0x25ad6de8,0x62580076}},	//   _giet_, ngyl, želi_, _díog,
   {{0xa2bb1d96,0x286a185c,0xd7fa0dd8,0x2ba502d5}},	//   _शून्, ерно_, нун_, गेबा,
   {{0x0d750fdf,0x3ead0ab2,0x22422fa2,0x00000000}},	//   _тыся, _ziet_, _lokk_, --,
   {{0xfd5000fe,0x8037006e,0xa635018a,0xb05b02c3}},	//   _nghẽ, אניע_, анні, _otän,
   {{0x22426de9,0xe7e0030b,0x644e0381,0x00000000}},	//   _nokk_, _गएका_, ekbi, --,
   {{0xf9920246,0x80b000aa,0xd04d01c2,0x2a66044c}},	//   _ابا_, _अंगे, craɗ, _imob_,
   {{0x2a66023e,0x81ce0033,0x00000000,0x00000000}},	//   _hmob_, _রাগ_, --, --,
   {{0x56950465,0x04640686,0x05150033,0x4df60285}},	//   _какт, стям, ামের_, ीभाई_,
   {{0x1fdd06ec,0xea01020b,0x26de6dea,0x00000000}},	//   मण्ड, _đẫy_, msto_, --,
   {{0x3f9802ef,0x3ead6deb,0x00000000,0x00000000}},	// [6af0] _azru_, _riet_, --, --,
   {{0x26de2287,0x3ead6dec,0x2bc61d96,0x00000000}},	//   osto_, _siet_, रुमा, --,
   {{0x3ead0a9f,0x5335129c,0x62580037,0x22950120}},	//   _piet_, _тент, _bíod, _виня,
   {{0x51871fdb,0x9f5c00b6,0x26de6ded,0x62580076}},	//   _буга, ývá_, isto_, _ríog,
   {{0x3ead0019,0xb8140251,0x625803a4,0x2bc602d5}},	//   _viet_, तजाम_, _díod, रुभा,
   {{0x26de6dee,0xcb696def,0x3ead0629,0x13d90033}},	//   ksto_, кале_, _wiet_, _তাড়,
   {{0x26de389a,0x3ead6df0,0xfd4e0065,0x201300b3}},	//   jsto_, _tiet_, _kikọ, mexi_,
   {{0xfd4e0129,0x80da030b,0x2f18004d,0xdb240103}},	//   _jikọ, _पौडे, _щось_, ásáh,
   {{0x26de6df1,0x7e6b0270,0xbf05023a,0x00000000}},	//   esto_, migp, _रहुन_, --,
   {{0x7d1b6df2,0x7e6b01df,0x6fe000b6,0xf86542c7}},	//   _isus, ligp, mácí, рвоо,
   {{0xfb1509b4,0xb06401bf,0x6d4b6df3,0xa3d9007a}},	//   _خواج, lmäß, lyga, ारन_,
   {{0x7e6b0270,0xc17401c2,0x201302ac,0x00000000}},	//   nigp, haɗa_, hexi_, --,
   {{0xb064042c,0x69db02db,0x00000000,0x00000000}},	//   nmäß, maue, --, --,
   {{0xb05b3114,0x7e6b0bb6,0xb7d5026e,0xa879006e}},	//   _stän, higp, _iṣor, _שאַר,
   {{0x7e6b019c,0x03a64444,0xa1c50031,0x38670027}},	//   kigp, риво, _dážď_, _imnr_,
   {{0xbbd1000d,0x69db01bf,0x212d02ef,0x877a0a41}},	//   हरुक, naue, _šeha_, _באצי,
   {{0x7d1b6df4,0xe3b22ba0,0x61f62059,0xc1740022}},	// [6b00] _nsus, _ورد_, rgyl, faɗa_,
   {{0x69db02e2,0x629d0062,0x6d4b01ab,0x7bc10090}},	//   haue, _ehso, dyga, _nflu,
   {{0x44440465,0x7d1b6df5,0xe002009f,0xd5ba02d5}},	//   _io_, _asus, र्षद_, _इलाज,
   {{0x7bc16df6,0x72db00ca,0xcee700c2,0x00000000}},	//   _aflu, _בקטג, рдце_, --,
   {{0x44446df7,0xbbd1000d,0x69db01bf,0x55bb00ca}},	//   _ko_, हरूक, daue, דמנו,
   {{0x26de008a,0x9f580503,0x00000000,0x00000000}},	//   ysto_, _mbrú_, --, --,
   {{0x44446df8,0xdb1a0018,0xe3e900c1,0xdee3120a}},	//   _mo_, _letö, אַפֿ, _мори,
   {{0x44446df9,0x3ce900e9,0x5a34188d,0x6d4b6dfa}},	//   _lo_, šava_, снит, byga,
   {{0x4444697e,0x200a1a3a,0xb4e500b7,0x3eb86dfb}},	//   _oo_, _kbbi_, _पटे_, _hurt_,
   {{0x44443d46,0xb8fe0d0b,0x3eb82e9c,0x57a6261f}},	//   _no_, _तब_, _kurt_, ишна,
   {{0x61e64c54,0x2fd800d3,0x69db01bf,0xe6de0174}},	//   _odkl, _merg_, baue, _ohụụ_,
   {{0x44441371,0xf76f1e53,0x6e204584,0xe1ff0072}},	//   _ao_, باً_, _jamb, _amón_,
   {{0x44446dfc,0x6e206dfd,0x7d026dfe,0x3eb8004d}},	//   _bo_, _mamb, ntos, _lurt_,
   {{0x6e206dff,0x444400a1,0xea010019,0x25be00b6}},	//   _lamb, _co_, _đẩy_, ětla_,
   {{0x4444004f,0x883b00a1,0x7d026e00,0x27f10206}},	//   _do_, _בתגו, htos, ózne_,
   {{0x6e20220b,0x44446e01,0x09aa0081,0x200a6e02}},	//   _namb, _eo_, _গ্যা, _abbi_,
   {{0x44446e03,0x6e223634,0x2fd86e04,0xdb1a0364}},	// [6b10] _fo_, ddob, _berg_, _getö,
   {{0x444416cc,0xd7f800d3,0x83871402,0x6e206e05}},	//   _go_, ngă_, _выме, _aamb,
   {{0x4ea701b6,0x6e206e06,0x3eb80428,0x62580037}},	//   арда, _bamb, _curt_, _díob,
   {{0x44446e07,0x6e226e08,0x6e201647,0x200a6e09}},	//   _zo_, gdob, _camb, _ebbi_,
   {{0x44446e0a,0x6e206e0b,0x64450329,0x3eb8033c}},	//   _yo_, _damb, _kohi, _eurt_,
   {{0x44446e0c,0x4421007a,0x3eb81aef,0xb5fb0131}},	//   _xo_, _jah_, _furt_, ciáv,
   {{0x44216e0d,0x64456e0e,0x69db3106,0xeeab044b}},	//   _mah_, _mohi, taue, _атак_,
   {{0x6e205d10,0x44210496,0xe8f92240,0x64456e0f}},	//   _gamb, _lah_, гли_, _lohi,
   {{0x7e696e10,0x69db6e11,0x7d1b6e12,0x97d900d6}},	//   _imep, raue, _usus, льну_,
   {{0x4421009d,0x69db6e13,0xf1bf02c6,0x38bb0f5a}},	//   _nah_, saue, _znát_, _vêr_,
   {{0x44446e14,0x9b950080,0xab9500e3,0x6e201e52}},	//   _ro_, _الات, _الاغ, _yamb,
   {{0x44446e15,0xb05b070a,0xd7f800ae,0x6e200188}},	//   _so_, _stäl, agă_, _xamb,
   {{0x44216e16,0x7e690129,0x69d9057a,0x64456e17}},	//   _bah_, _mmep, _iewe, _bohi,
   {{0x6e220ac3,0x4421001c,0x69d903a9,0x2a6d0031}},	//   zdob, _cah_, _hewe, lieb_,
   {{0x44446e18,0x442110f3,0x7d020068,0x394d0018}},	//   _vo_, _dah_, ztos, lyes_,
   {{0x44446e19,0x69d96e1a,0x26c701c2,0x442103a9}},	//   _wo_, _jewe, _itno_, _eah_,
   {{0x44446e1b,0x394d3058,0x6e200947,0x3eb85968}},	// [6b20] _to_, nyes_, _ramb, _surt_,
   {{0x69d90665,0xd12f0cd2,0x7e690051,0x44216e1c}},	//   _lewe, عمل_, _amep, _gah_,
   {{0x6e206e1d,0xb5fb6e1e,0x290f01af,0x645c033f}},	//   _pamb, riáv, _lpga_, mhri,
   {{0x7d026e1f,0x291d0c56,0x6e221359,0xb21b02b6}},	//   ttos, _oswa_, udob, _skæv,
   {{0x6e226e20,0x4421009d,0x7e7b0572,0x395f023e}},	//   rdob, _yah_, _djup, jzus_,
   {{0x70560241,0x7d026e21,0x6e226e22,0x6e2003a5}},	//   _انسا, rtos, sdob, _wamb,
   {{0x69d90b5e,0xa3d9097c,0x7d026e23,0xa6f20081}},	//   _bewe, ारत_, stos, _জন্ম_,
   {{0x69d9009d,0xa3e80789,0x7d026e24,0x6e20394c}},	//   _cewe, मृत_, ptos, _uamb,
   {{0xed5000fb,0x69d96e25,0x645c11a6,0x02660023}},	//   _تھا_, _dewe, khri, _đến_,
   {{0x2bcf2231,0xd7f8002d,0x3ea6019c,0x7c213383}},	//   _स्पा, ugă_, lmot_, _galr,
   {{0x3aeb0260,0xd7f800ae,0xb5fb4e96,0x645c6e26}},	//   _مبنی_, rgă_, mnáz, dhri,
   {{0x69d90d50,0x44216e27,0x6445005c,0x291a09e5}},	//   _gewe, _sah_, _sohi, _مقصد_,
   {{0xa967121c,0x7bda6e28,0xb05b0222,0x44216e29}},	//   _лица_, _ketu, _stäm, _pah_,
   {{0x645c2f66,0xe9470068,0x7bda023b,0x9abc0078}},	//   ghri, _درمی, _jetu, _arċi,
   {{0x7bda6e2a,0xb865177a,0xe81d0096,0x442300fc}},	//   _metu, _بانو, _बघता_, rdj_,
   {{0x44216e2b,0x7bda3747,0x2bcf0179,0x2240023b}},	//   _wah_, _letu, _स्ना, gjik_,
   {{0x44216e2c,0x64456e2d,0x313400a9,0x62580037}},	// [6b30] _tah_, _tohi, петр, _síoc,
   {{0x645c3682,0x7bda6e2e,0x212b0094,0x752d46e1}},	//   chri, _netu, _vrch_, _iraz,
   {{0x752d0094,0x00000000,0x00000000,0x00000000}},	//   _hraz, --, --, --,
   {{0x752d06a3,0x395f0063,0xb5fb00d8,0x7bda09a1}},	//   _kraz, yzus_, ciát, _aetu,
   {{0x7bda6e2f,0x8c451055,0x660d6e30,0x2a6d0031}},	//   _betu, желе, _mbak, vieb_,
   {{0x7bda6e31,0x752d1c74,0x69d96e32,0x394d023e}},	//   _cetu, _mraz, _sewe, vyes_,
   {{0x7bda6e33,0xda590b21,0x9f5f00c2,0xeb99004d}},	//   _detu, ириш_, ärän_, шик_,
   {{0x752d1cb2,0x7e690051,0x08c52813,0xef220034}},	//   _oraz, _umep, обин, _dużą_,
   {{0x7bda6e34,0x60cd6e35,0x2a6d6e36,0x7c213348}},	//   _fetu, npam, rieb_, _talr,
   {{0x7bda6e37,0x660d2127,0x60cd6e38,0x69d92f91}},	//   _getu, _abak, ipam, _wewe,
   {{0x2bcf030b,0x752d6e39,0x69d96e3a,0xa5bb1041}},	//   _स्या, _araz, _tewe, rdón,
   {{0xd0220081,0x68ee0740,0xf5066e3b,0x25be00b6}},	//   নায়_, ündü, озмо, ětlo_,
   {{0x645c6e3c,0x37e525a4,0x2bc60961,0x7bda6e3d}},	//   thri, _долг, रुवा, _yetu,
   {{0x2bcf1362,0xe1ff0072,0x660d6e3e,0xa8a700d3}},	//   _स्मा, _acó_, _ebak, _урек,
   {{0x752d6e3f,0x645c003e,0x22520313,0xd3350792}},	//   _eraz, rhri, tkyk_, пэты,
   {{0x660d0129,0x316001e9,0x00000000,0x00000000}},	//   _gbak, tziz_, --, --,
   {{0x752d6e40,0x645c6e41,0x3d19000d,0x60cd2846}},	// [6b40] _graz, phri, _मैले_, gpam,
   {{0x32090188,0xb5fb0072,0xa49b00ee,0x81d70033}},	//   afay_, siát, ntòl, _সাঃ_,
   {{0xef1a5bb2,0x7bda1173,0xe29a1603,0x752d0220}},	//   рме_, _retu, _ван_, _zraz,
   {{0xb5fb6e42,0x7bda6994,0x1ea908ba,0x00000000}},	//   chád, _setu, ماني_, --,
   {{0x7bda0496,0x3ea66e43,0x6f05010b,0x00000000}},	//   _petu, rmot_, athc, --,
   {{0x98a6030b,0x8c430284,0x09d200a4,0x00000000}},	//   _proč_, деље, सर्य, --,
   {{0x7bda6e44,0x2bc60980,0xdee628b0,0x00000000}},	//   _vetu, रुषा, _фоби, --,
   {{0x7bda6e45,0x98a60117,0x769d03a9,0x00000000}},	//   _wetu, _vroč_, kéya, --,
   {{0x7bda6e46,0x49741b60,0x998d026a,0x00000000}},	//   _tetu, ялис, rdeş_, --,
   {{0x29046e47,0xa7fc0367,0xc8660037,0x1bba0103}},	//   rtma_, lnız, تطبي, _ضائع_,
   {{0xa3d90f53,0xb5fb077f,0x569523d0,0x660d0063}},	//   ारस_, diár, зант, _pbak,
   {{0x752d6e48,0xe667004d,0xb5fb0231,0x00000000}},	//   _praz, ітно, viás, --,
   {{0x769d00cd,0x00000000,0x00000000,0x00000000}},	//   géya, --, --, --,
   {{0xc1d30e19,0xb5fb6e49,0x00000000,0x00000000}},	//   तर्ग, giár, --, --,
   {{0x9f4707d1,0x926b016d,0xb1c800ac,0x6aa220e3}},	//   ünü_, араа_, _ọrịa_, _khof,
   {{0xa75b00a1,0x95cb00c9,0x212902dd,0xa3d95dda}},	//   _כדור, _тука_, tvah_, ारह_,
   {{0x50f502fd,0xb5fb6e4a,0x2fcb0dce,0xf19400a9}},	// [6b50] язат, siás, لباً_, дить,
   {{0xb5fb1097,0x2129033b,0xea0100fe,0x071e09a1}},	//   ciár, rvah_, _đậy_, _बनाव_,
   {{0xdefb01b6,0xb5fb0037,0x439501b6,0x00000000}},	//   рыз_, mháb, _ханс, --,
   {{0x60cd6e4b,0xa5bb01cd,0x6f056e4c,0x00000000}},	//   ppam, kdóm, rthc, --,
   {{0x260002e8,0x28da66d3,0x823a22fe,0xddc20034}},	//   ष्टी_, _मौलि, _הערצ, lkoś,
   {{0x64550126,0x2bc6030b,0x6aa2024a,0x00000000}},	//   nkzi, रुला, _ahof, --,
   {{0x62580076,0x00000000,0x00000000,0x00000000}},	//   _míon, --, --, --,
   {{0x625800e3,0x6aa26e4d,0xb7d50af0,0x7d0d0231}},	//   _líon, _chof, _iṣir, çass,
   {{0x2bcf0851,0x38ca00cd,0xa5bb0653,0x6e94004d}},	//   _स्था, یایی_, gdóm, _циту,
   {{0xa2a20336,0x00000000,0x00000000,0x00000000}},	//   _कीन्, --, --, --,
   {{0xb5fb0161,0xe7bc0378,0x00000000,0x00000000}},	//   viár, ोड़प, --, --,
   {{0xfbcf0490,0x6aa20167,0x62580037,0x628d0231}},	//   _स्तम, _ghof, _aíon, joao,
   {{0x4a9a0341,0x625800e3,0xdddb0087,0x6aa901df}},	//   _פינג, _bíon, _okuž, mmef,
   {{0xddc90480,0xb5fb01f9,0x00000000,0x00000000}},	//   _njež, gháb, --, --,
   {{0x42563eac,0x998d007e,0xa49b00b3,0x6258682d}},	//   птат, njež_, ctòm, _díon,
   {{0xb21b6e4e,0xa3b8034c,0x998f00c6,0x00000000}},	//   _skær, _छलक_, _uogų_, --,
   {{0xddc90268,0xb7d50af0,0x62580076,0x15fb00d7}},	// [6b60] _bjež, _aṣir, _fíon, _ההפע,
   {{0xb4d813b4,0xb5fb0072,0xd17900f3,0x645502db}},	//   ाठी_, cháb, істі_, ckzi,
   {{0x0dca004d,0xa3d900a3,0x389a0142,0x00000000}},	//   були_, ारर_, ציענ, --,
   {{0x9e651f11,0x00000000,0x00000000,0x00000000}},	//   وانن, --, --, --,
   {{0x20070428,0xe3b21ac9,0xacf8004d,0x00000000}},	//   ònic_, _ترک_, інку_, --,
   {{0x6aa26e4f,0xdfd26e50,0x00000000,0x00000000}},	//   _shof, _سير_, --, --,
   {{0x6aa2039f,0x00000000,0x00000000,0x00000000}},	//   _phof, --, --, --,
   {{0x201a6e51,0x9f58016d,0x22b800c4,0xce3403a9}},	//   lepi_, _ecrã_, _učku_, _تورک,
   {{0xd90e0de1,0x61eb0042,0x851b009f,0xbc666e52}},	//   ایت_, ógli, _पैंट_, _евак,
   {{0xe786487f,0xa5bb003e,0x201a6e53,0x00000000}},	//   зумо, rdóm, nepi_, --,
   {{0x09db0081,0x21270023,0x3e751405,0x20572252}},	//   _ধারা, ̉nh_, sťte_, פיטל_,
   {{0x201a03a9,0x6aa2039f,0x00000000,0x00000000}},	//   hepi_, _uhof, --, --,
   {{0x09aa00c7,0x3ce6393c,0xb5fb0076,0xb05b007b}},	//   _গ্রা, nsov_, tháb, _itäv,
   {{0x201a0268,0x00000000,0x00000000,0x00000000}},	//   jepi_, --, --, --,
   {{0x92956e54,0x201a1cb0,0x00000000,0x00000000}},	//   давц, depi_, --, --,
   {{0xdddb2d5a,0xd5c10557,0x3ce66404,0xc29907bf}},	//   _skuž, _एलिज, ksov_, іках_,
   {{0x66e20139,0x64411d4b,0x212f0076,0x2122020b}},	// [6b70] _fíká, ölis, ígh_, _cskh_,
   {{0x2fc70019,0x3a2603a9,0x201a01dc,0x00000000}},	//   ùng_, _laop_, gepi_, --,
   {{0xddc9239f,0x7f192b38,0xb5fb1054,0x9dca0174}},	//   _vjež, تياز_, chác, _ịpịg,
   {{0x7bc8008a,0x13e20033,0x00000000,0x00000000}},	//   _afdu, _বায়, --, --,
   {{0xf1ab00bf,0x51840450,0x3ce6007e,0xece8004d}},	//   _داده_, _зура, gsov_, зділ_,
   {{0x5fe16e55,0x224b00dc,0x201a6e56,0x00000000}},	//   _फ़िल, _hock_, cepi_, --,
   {{0x224b6e57,0x9aa50103,0x6e6700e5,0x00000000}},	//   _kock_, ومتو, _етаж, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c8700ae,0x6aa90429,0x2aa101f9,0x00000000}},	//   _еуже, rmef, tóbb_, --,
   {{0x6fdd0f35,0x6fb10096,0x224b6e58,0x00000000}},	//   यरिं, _जणां, _lock_, --,
   {{0xcb5506cf,0x2cbf01ee,0x00000000,0x00000000}},	//   _تناظ, _huud_, --, --,
   {{0x2cbf007a,0x81d30033,0xf3e900ca,0x00000000}},	//   _kuud_, হৃত_, _כף_, --,
   {{0x625800e3,0x25df00aa,0xa3d900a4,0xb4d80096}},	//   _díol, _कजरी_, ारं_, ाठे_,
   {{0x2cbf007a,0x68fb6e59,0x291f0d0a,0xe8d600ca}},	//   _muud_, muud, mwua_, _חוסר_,
   {{0x2cbf6e5a,0x224b3a23,0x23270950,0x68fb3846}},	//   _luud_, _bock_, мори_, luud,
   {{0x09b10081,0xcb1200ca,0x224b6e5b,0x82160076}},	//   _ট্যা, כלל_, _cock_, بورص,
   {{0x68fb6e5c,0x201a6e5d,0x224b4cda,0x66040079}},	// [6b80] nuud, tepi_, _dock_, _icik,
   {{0x39420084,0xa3d90bf5,0x75240201,0x2bcf0096}},	//   äksi_, ारः_, _isiz, सुमा,
   {{0x201a6e5e,0x68fb6e5f,0x645e0036,0xc43b00ca}},	//   repi_, huud, _ilpi, _ותיי,
   {{0x90c609fe,0x201a6e60,0x6492052f,0x2c004f3a}},	//   _обме, sepi_, pæis, _राहू_,
   {{0x61e46e61,0x92d600c7,0x443a09a4,0x60c90092}},	//   mail, _সময়_, _knp_, _çemp,
   {{0x13e200c7,0x3ddf0126,0x61e46e62,0x68fb0188}},	//   _বাড়, _eeuw_, lail, duud,
   {{0x60c4023b,0x62580076,0x09e20033,0x00000000}},	//   lqim, _líom, _যাবা, --,
   {{0x61e46e63,0x8fa340e6,0x66040027,0x32000027}},	//   nail, _расе, _ncik, ngiy_,
   {{0x2bcf1b92,0x60c20080,0x672301e5,0x2cbf0694}},	//   _स्वा, íomh, _asnj, _guud_,
   {{0x61e46e64,0x660444d2,0x0c2616dd,0x62580076}},	//   hail, _acik, _імен, _síol,
   {{0x61e46e65,0x7c3a6e66,0x60c400dd,0xc7b8053f}},	//   kail, _intr, hqim, jeđe_,
   {{0x443a1688,0x7c283bd7,0x7e625cf1,0x61e46e67}},	//   _anp_, _hadr, nhop, jail,
   {{0x6846232c,0x224b00ca,0x68fb0188,0xb956001c}},	//   _онда, _rock_, cuud, _تئات,
   {{0x7c28460e,0x7c2a0116,0x6604010a,0x62580076}},	//   _jadr, ndfr, _ecik, _díom,
   {{0x61e46e68,0xc6140081,0x7c2860c8,0x75240201}},	//   fail, িয়া_, _madr, _esiz,
   {{0x61e46e69,0x443a02a1,0x3ce914f3,0x442a009c}},	//   gail, _enp_, šavi_, adb_,
   {{0x661d006c,0x7c3a6e6a,0x7e6212d2,0xa294004d}},	// [6b90] mesk, _ontr, dhop, таті,
   {{0xd9bb0775,0xcf9b0831,0x443a3380,0x2cbf6e6b}},	//   _उल्ट, оје_, _gnp_, _ruud_,
   {{0x83350130,0x03d600a1,0x61e40a02,0x224b05db}},	//   _װאָס_, _אותם_, bail, _tock_,
   {{0x28df0d88,0x7c3a6e6c,0x61e40a6c,0x7c28007a}},	//   पीडि, _antr, cail, _aadr,
   {{0x7c286e6d,0x644e033b,0x51872105,0xc17401c2}},	//   _badr, žniš, _цуна, yaɗi_,
   {{0x7c286e6e,0x68fb00c2,0x78b800bd,0x661d00ce}},	//   _cadr, vuud, _nivv, hesk,
   {{0x661d198c,0x60cf1a70,0x7c286e6f,0xa5bb0076}},	//   kesk, _htcm, _dadr, adói,
   {{0x7c3a6e70,0x7e626e71,0xdd952787,0x68fb1d94}},	//   _entr, chop, _забы, tuud,
   {{0x59c10251,0x395901cd,0x6e3b0270,0x78b8010a}},	//   शखबर, áss_, _inub, _bivv,
   {{0x62580080,0x61e402a7,0x1cb800bf,0x2001008f}},	//   _ríom, zail, _قالب_, nghi_,
   {{0xe7391c47,0x68fb6c9c,0xd6ce00d0,0x6e2900aa}},	//   чен_, suud, یقی_, _kaeb,
   {{0x661d3deb,0x6e290085,0x443a6e72,0x26052231}},	//   gesk, _jaeb, _snp_, _वाणी_,
   {{0x61e46e73,0xdddb06b0,0xc7b800c4,0x6e29033c}},	//   vail, _aluŋ, veđe_, _maeb,
   {{0x61e401c2,0x7c285fea,0x68e96e74,0x2bac0e1f}},	//   wail, _xadr, msed, टेवा,
   {{0x61e46e75,0xa6962d16,0x68e96e76,0x9696598f}},	//   tail, _приј, lsed, _приш,
   {{0x69c96e77,0x64470098,0x20013292,0x661d6e78}},	//   ncee, ajji, eghi_, cesk,
   {{0x61e46e79,0x68e96e7a,0x5f460018,0x75240201}},	// [6ba0] rail, nsed, کنال, _usiz,
   {{0x61e40a00,0x2bcf0455,0x2a7f023e,0xfbcf02d5}},	//   sail, _स्ला, hnub_, _स्लम,
   {{0x91e61456,0x69cb517b,0xdfcf00e3,0x6e290f4c}},	//   _поне, _ofge, صين_, _baeb,
   {{0x7c2802e6,0x69c9023e,0xfce6036a,0x614607ed}},	//   _sadr, jcee, еодо, _зема,
   {{0x7e620149,0x6e2900ec,0xd4690260,0x6e3b009e}},	//   rhop, _daeb, _رحیم_, _dnub,
   {{0x68e961ff,0x69cb1d19,0x8c43225a,0x7c286e7b}},	//   dsed, _afge, лече, _qadr,
   {{0x8fa31510,0x4f956e7c,0x68eb00b3,0x27e501c2}},	//   _баре, _арту, _avgd, daln_,
   {{0x5a340fa5,0x7c2801c2,0x8938376e,0x0dc90076}},	//   тнит, _wadr, дпис_, _يبقى_,
   {{0x81e500c7,0x661d6e7d,0xbc760037,0x27ee01c8}},	//   _নাম_, vesk, _كهرب, _pdfn_,
   {{0x47340c58,0xbc6a0c5e,0x6e290172,0xa3c500b6}},	//   внос, _عمان_, _zaeb, उँछ_,
   {{0x661d6e7e,0x45d50315,0xa5f91e2f,0x68e96e7f}},	//   tesk, конс, мену_, ased,
   {{0xea010028,0xff7b040a,0xa3d3052c,0xc9860231}},	//   _đầy_, לטימ, हुन_, _пули,
   {{0x661d6e80,0x78b80078,0x00000000,0x00000000}},	//   resk, _tivv, --, --,
   {{0xb5fb6e81,0x661d6c4c,0x00000000,0x00000000}},	//   chán, sesk, --, --,
   {{0x93883d03,0x02a71272,0x661d0b6a,0xb4b100a4}},	//   еста_, ерам, pesk, _ओळी_,
   {{0x99860031,0x00000000,0x00000000,0x00000000}},	//   _množ_, --, --, --,
   {{0x2cff022d,0xddc9020a,0x00000000,0x00000000}},	// [6bb0] _ईमेल_, _aleş, --, --,
   {{0x6e3b6e82,0x6e290113,0x76880342,0x00000000}},	//   _snub, _saeb, rıye, --,
   {{0x2001008f,0xf41200ca,0xddc9078e,0x00000000}},	//   rghi_, _דפי_, _cleş, --,
   {{0xa3d9007d,0x68e90178,0xd1300103,0x00000000}},	//   ारक_, ysed, جمے_, --,
   {{0xddc96e83,0xdddb078e,0x00000000,0x00000000}},	//   _eleş, _ajuţ, --, --,
   {{0x224900e9,0x6e290a4b,0xeb9901a0,0xe0df0139}},	//   ljak_, _waeb, мил_, _iwò_,
   {{0x2bac3ec9,0x626c5c70,0x6b9a00eb,0x00000000}},	//   टेला, rşov, _cytg, --,
   {{0x5f9421b6,0x68e96e84,0xcd420018,0xc3340796}},	//   _сист, tsed, _چھوٹ, רוק_,
   {{0x69c901c0,0xee841855,0x33310113,0x00000000}},	//   rcee, _сыро, hvzx_, --,
   {{0x68e906ee,0x69c90381,0x245402c3,0x00000000}},	//   rsed, scee, _jämt_, --,
   {{0xf7710241,0x68e9618a,0x245d0065,0x0a1506cf}},	//   شاد_, ssed, _aìmo_, _لواح,
   {{0x3ce90234,0x00000000,0x00000000,0x00000000}},	//   šavu_, --, --, --,
   {{0xceb207a6,0xb5fb109d,0xd8250095,0x3a2d020b}},	//   ייט_, mhál, _адли, mdep_,
   {{0x5ed200c7,0x64a600c6,0xf1bf00da,0xf7710d83}},	//   _হিসে, тага, _agá_, _پات_,
   {{0x160a009d,0xe29a004d,0x290d6e85,0xc5e10033}},	//   _वापर_, дав_, ltea_, _ভারপ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe29717de,0x290d6e86,0x80c80081,0x00000000}},	// [6bc0] тат_, ntea_, _লিঙ্, --,
   {{0xb21b08dc,0xb05b3224,0xa2a216e2,0xc7b80234}},	//   _hjæl, _stär, _कीर्, leđa_,
   {{0xe81302e8,0x645c1483,0x52aa0291,0xe0df0139}},	//   त्या_, mkri, _овом_, _ewò_,
   {{0x75360034,0x00000000,0x00000000,0x00000000}},	//   _kryz, --, --, --,
   {{0x160a02d5,0xb5fb109d,0x425500ae,0x3a2d0027}},	//   _वानर_, dhál, _стэт, ddep_,
   {{0x645c5b5a,0x201e0c0a,0x00000000,0x00000000}},	//   nkri, _úti_, --, --,
   {{0x290d037a,0x7c65001c,0xdee60e2c,0x00000000}},	//   etea_, دانل, _шови, --,
   {{0x75360063,0x645c023b,0xc7b80dd9,0x290d020a}},	//   _oryz, hkri, jeđa_, ftea_,
   {{0xfe9100bf,0x645c6e87,0x0c260235,0x4c16001c}},	//   _اینج, kkri, _иман, _لباس,
   {{0xea010019,0x224907c0,0x2605009f,0x645c18f0}},	//   _đấy_, zjak_, _वाही_, jkri,
   {{0xadc30139,0xb5fb00e3,0x3ffb00ca,0x786405aa}},	//   _abẹn, bhál, ופיע, _nòve,
   {{0xcf9300ca,0x7b79006e,0x645c084e,0x00000000}},	//   יטת_, _אָנצ, ekri, --,
   {{0xd0480092,0x06e200aa,0xda650037,0x290d0328}},	//   şlər, _कौरव_, _حالي, ctea_,
   {{0x49170341,0x00000000,0x00000000,0x00000000}},	//   _סקול_, --, --, --,
   {{0x200705fe,0xa2af0096,0xdddb0995,0x224964d3}},	//   ònim_, ंगल्, _ljuš, tjak_,
   {{0x75360034,0x32646e88,0x17da0081,0xddc90206}},	//   _fryz, атув, _দায়ি, _omeš,
   {{0x30150036,0xdddb0f39,0xadc30065,0xe3e20033}},	// [6bd0] лдар, _njuš, _gbẹn, _বারব,
   {{0x200700b7,0x224905db,0xc05801b3,0xe1140033}},	//   üni_, sjak_, кіх_, সিংহ_,
   {{0x290d0a00,0x9ed902a0,0x2ef555de,0x9df90161}},	//   ztea_, хмет_, узер, енет_,
   {{0x765d06a3,0xe0df06a3,0x4ea46e89,0x2007007f}},	//   nksy, _twò_, арча, żni_,
   {{0x768803e0,0x66ec009f,0xa5bb0328,0x00000000}},	//   nıya, _झिझक_, cdót, --,
   {{0xc1b80426,0x00000000,0x00000000,0x00000000}},	//   _шлях_, --, --, --,
   {{0xeb962b49,0xb5fb3274,0x00000000,0x00000000}},	//   лиш_, thál, --, --,
   {{0x0b1600e3,0x645c6e8a,0x290d6e8b,0xfb160037}},	//   اقية_, zkri, ttea_, اقيع_,
   {{0xb60402c6,0xc7b800c4,0x290d0062,0x00000000}},	//   nkář, veđa_, utea_, --,
   {{0x290d6e8c,0xb21b01c5,0xe8f6055b,0x7d1b0027}},	//   rtea_, _sjæl, ыль_, _ipus,
   {{0x290d5f71,0xfc301363,0x6d5902cb,0x7bc10009}},	//   stea_, _بحق_, lywa, _iglu,
   {{0x290d00d3,0x98ad0087,0x89350286,0x00000000}},	//   ptea_, mveč_, _معتا, --,
   {{0x09b10081,0x6d596e8d,0xb5fb0146,0x69db6e8e}},	//   _ট্রা, nywa, chám, mbue,
   {{0x69db6e8f,0x68fb367f,0x7d1b0169,0x9879006e}},	//   lbue, mrud, _mpus, _ראַט,
   {{0x645c4c28,0xe739002d,0x63860e05,0x00000000}},	//   rkri, _чей_, угва, --,
   {{0x645c0e9f,0xe29711db,0x98a60559,0x68fb67c2}},	//   skri, гас_, _proć_, orud,
   {{0x68fb5c3d,0x645c013f,0xcfe80033,0xe47600ae}},	// [6be0] nrud, pkri, _পাবন, _бунэ,
   {{0x7bc10604,0xa5bb003e,0x68fb0063,0xf8c800fe}},	//   _nglu, rdót, irud, _hức_,
   {{0xddc93bbb,0xa5bb0088,0x68fb3e0b,0x98ad0087}},	//   _smeš, sdót, hrud, jveč_,
   {{0xe8130d7e,0x7bc10575,0x66060449,0xdee36e90}},	//   त्ता_, _aglu, ngkk, соци,
   {{0xf8c80019,0x68fb6e91,0x62966e92,0x9f4305aa}},	//   _mức_, jrud, moyo, _lejè_,
   {{0x61e65535,0xac184aaa,0x2733026e,0xddc90117}},	//   _hekl, току_, _ẹni_, _vmeš,
   {{0x26051085,0x1fb50084,0x60c60a4b,0xb5fb05f1}},	//   _वाली_, _встр, _hukm, riáz,
   {{0x61e60087,0x6d590034,0x7bc15dcd,0x62846e93}},	//   _jekl, bywa, _eglu, nnio,
   {{0x61e60029,0xddc92102,0xb9270174,0x8e75002d}},	//   _mekl, _umeš, _ijuọ_, _турч,
   {{0x7d02013f,0x60c61bd6,0xad1b040a,0x61e60324}},	//   muos, _mukm, _אומר, _lekl,
   {{0xb8cb1c37,0xf8c80019,0x60c66e94,0x7d026e95}},	//   _की_, _bức_, _lukm, luos,
   {{0x69dd0088,0x68fb6e96,0xe5b5007b,0x6296010a}},	//   ðset, brud, ийны, joyo,
   {{0x628400a5,0x550701b3,0x7d020138,0x4a7b00c1}},	//   dnio, ычна, nuos, _אראב,
   {{0x62840034,0xd7ef0284,0x00000000,0x00000000}},	//   enio, _ћу_, --, --,
   {{0x61e606a7,0x6d590034,0x00000000,0x00000000}},	//   _bekl, zywa, --, --,
   {{0x60c66e97,0x20186e98,0x7d0202e3,0x61e66e99}},	//   _bukm, _abri_, kuos, _cekl,
   {{0x61e66e9a,0x2018010a,0x7d020138,0x9f58033c}},	// [6bf0] _dekl, _bbri_, juos, _gcrú_,
   {{0x09d104dd,0x61e6029a,0x25a901ff,0xa49b00ee}},	//   _सभ्य, _eekl, _izal_, atòr,
   {{0x6d5921cd,0x44236e9b,0x62966e9c,0x200f007f}},	//   wywa, mej_, boyo, ęgi_,
   {{0x44236e9d,0x61e60418,0xa49b0472,0x6d5900a5}},	//   lej_, _gekl, ctòr, tywa,
   {{0x68e201c2,0x7d026e9e,0x00000000,0x00000000}},	//   _nwod, guos, --, --,
   {{0x44236e9f,0x69c2171d,0xb5fb0103,0xed561061}},	//   nej_, _agoe, nkáb, рош_,
   {{0x6d590034,0x68e20f20,0xfd660065,0x6e225fa4}},	//   sywa, _awod, _kupọ, beob,
   {{0x44236ea0,0x7f840080,0x68fb6ea1,0x68e205aa}},	//   hej_, _الفن, trud, _bwod,
   {{0x44236ea2,0x7d1b00cc,0x0d67008f,0xe40a00a7}},	//   kej_, _upus, _съвм, _çiçə,
   {{0x44233239,0x7ae758bd,0xf8c80028,0x69c202a7}},	//   jej_, _бюдж, _sức_, _egoe,
   {{0x366a2064,0x44236ea3,0x62840940,0x38ab004d}},	//   вано_, dej_, ynio, jøre_,
   {{0x443100d9,0x249a0063,0x38ab0537,0x00000000}},	//   edz_, _skpm_, døre_, --,
   {{0x9f430314,0x7c23029a,0x00000000,0x00000000}},	//   _dejé_, oenr, --, --,
   {{0x61e66ea4,0x38ab038c,0x7c236ea5,0x60c600d1}},	//   _sekl, føre_, nenr, _rukm,
   {{0x46a64ab5,0xf8c80028,0xf66a2b38,0x60c66994}},	//   _какв, _tức_, _لحظه_, _sukm,
   {{0x768801e8,0xf8c800de,0xb347016d,0x7c236ea6}},	//   mıyo, _hứa_, _seçõ, henr,

   {{0x44231221,0x768801e8,0x6f1c025b,0x6296677e}},	// [6c00] bej_, lıyo, _sprc, royo,
   {{0xa49b0990,0x26c76ea7,0x44236ea8,0x27e706a3}},	//   stòr, _kuno_, cej_, _jenn_,
   {{0x27e75d1f,0x768801e8,0x61e66ea9,0x7c235b5a}},	//   _menn_, nıyo, _tekl, denr,
   {{0xed5a6eaa,0x27e76eab,0x3ebf63d2,0x7d026eac}},	//   кое_, _lenn_, _ciut_, tuos,
   {{0x3ebf0134,0x26c70517,0x1bd4008f,0x2fd100c4}},	//   _diut_, _luno_, боля, _ffzg_,
   {{0x7c236ead,0x2d5717b9,0x768801e8,0x7d026eae}},	//   genr, ришь_, kıyo, ruos,
   {{0xaa662b49,0xb5fb0618,0x26c76eaf,0x7d020b2f}},	//   итик, nkác, _nuno_, suos,
   {{0x44236eb0,0x68e20c56,0xe813022d,0x7d026739}},	//   zej_, _pwod, त्सा_, puos,
   {{0x48aa6eb1,0x7c236eb2,0x7d020036,0x27e733e7}},	//   ктом_, benr, quos, _benn_,
   {{0xb5fb00e3,0x673800e7,0xe8060096,0x26c70517}},	//   mhái, _prvj, _शाळा_, _buno_,
   {{0x44236eb3,0x27e702dc,0x24986eb4,0xf8c800fe}},	//   vej_, _denn_, dorm_, _dứa_,
   {{0x44230d1b,0x6f030472,0x62580037,0x4b7b006e}},	//   wej_, ànci, _míos, _באבו,
   {{0x44230bdf,0x2a660124,0x24980703,0x7688026a}},	//   tej_, _ilob_, form_, mıyl,
   {{0x290400d9,0x2a660197,0x25a90094,0x27e76eb5}},	//   muma_, _hlob_, _vzal_, _genn_,
   {{0x44232e85,0x29046eb6,0x4df8000d,0x26c70517}},	//   rej_, luma_, ुलाई_, _guno_,
   {{0x44236eb7,0xd7bb00a1,0x7c230381,0x76880342}},	//   sej_, _בצור, zenr, nıyl,
   {{0xe81309c3,0x4423003d,0x3ebf0441,0x26c700d4}},	// [6c10] त्वा_, pej_, _riut_, _zuno_,
   {{0x6ecb0789,0xb5fb0037,0x27330139,0x752d6eb8}},	//   _तंदु, dhái, _ẹnu_, _isaz,
   {{0x2c000455,0x29046eb9,0x9295004b,0x26c75d82}},	//   _राजू_, huma_, _ганц, _xuno_,
   {{0x29046eba,0xf2d200a1,0x62580037,0x7c230124}},	//   kuma_, _מעט_, _díos, wenr,
   {{0x61ed6ebb,0x29040029,0x51846ebc,0xa5da00c1}},	//   maal, juma_, _дура, אַצי,
   {{0x61ed6ebd,0x29046ebe,0xa3be0775,0x3ce405c2}},	//   laal, duma_, ुँच_, _dwmv_,
   {{0x7c236ebf,0x21290063,0x27e700f3,0x660d6ec0}},	//   renr, lwah_, _renn_, _ocak,
   {{0xb5fb054f,0x61ed5b29,0x7c236ec1,0x32091d11}},	//   bhái, naal, senr, ngay_,
   {{0x29046ec2,0xb5fb6ec3,0xe939015a,0x7c233155}},	//   guma_, chái, اسبت_, penr,
   {{0x61ed6ec4,0xb8ff05a7,0x768801e8,0x2a6600e7}},	//   haal, _तऽ_, tıyo, _elob_,
   {{0x2bdd0a30,0x61ed2638,0x27e700d6,0x24984e0b}},	//   _न्या, kaal, _venn_, vorm_,
   {{0x27e702d6,0x21296ec5,0xb5fb0146,0x6b7a00c1}},	//   _wenn_, kwah_, vkác, _גרענ,
   {{0x61ed6ec6,0x1e3a00c1,0x29046ec7,0x76880233}},	//   daal, אגרא, cuma_, sıyo,
   {{0x3209025e,0xa3d30101,0x629d6ec8,0x768801e8}},	//   egay_, हुल_, _akso, pıyo,
   {{0x93595e0d,0x61ed6ec9,0xe79a00b6,0x4874001c}},	//   арту_, faal, _těší, _بدنس,
   {{0x61ed0fdc,0xe8130557,0x575600ca,0x00000000}},	//   gaal, त्रा_, _לבצע_, --,
   {{0x61430bd0,0xb5fb0094,0x41aa0cba,0x00000000}},	// [6c20] пета, skác, уван_, --,
   {{0x62580076,0x76882ddc,0xf5371777,0x00000000}},	//   _píos, zıyl, _פריז_, --,
   {{0x44446eca,0x61ed6ecb,0x290441e3,0xa3b4000c}},	//   _in_, baal, zuma_, जेश_,
   {{0x290401a6,0x44446ecc,0xb5fb0037,0x61ed0188}},	//   yuma_, _hn_, thái, caal,
   {{0x444436a4,0x62580037,0xfff812eb,0x5faa00aa}},	//   _kn_, _fíor, _نکات_, _करवल,
   {{0x29046ecd,0xa3d8030b,0x9f430d79,0x2a660381}},	//   vuma_, ाडि_, _kejì_, _slob_,
   {{0x907b00c1,0x2a6601fa,0x4444538b,0x76882ddc}},	//   _עטלי, _plob_, _mn_, tıyl,
   {{0x29043565,0xb5fb6ece,0x44446ecf,0x9f430065}},	//   tuma_, phái, _ln_, _mejì_,
   {{0x44441723,0x76880587,0xa3d8014e,0x6d466ed0}},	//   _on_, rıyl, ाडा_, _škaf,
   {{0x44446ed1,0x76880587,0x76446ed2,0x7e626ed3}},	//   _nn_, sıyl, _aniy, lkop,
   {{0xa09b00f5,0x61ed6ed4,0x29046ed5,0xab960037}},	//   רייט, yaal, suma_, _الضغ,
   {{0x44446ed6,0x29046ed7,0xe1ff0139,0x656f042c}},	//   _an_, puma_, _alón_, tzch,
   {{0x61ed6ed8,0x2c6b00f3,0x09360037,0x444400db}},	//   vaal, _fødd_, _دراج, _bn_,
   {{0x92d400c7,0x81e500c7,0x5ed900c7,0x76440649}},	//   _হয়ে_, _নাই_, _ডিসে, _eniy,
   {{0xa3d8000f,0x21296ed9,0xa87b00ca,0xa3b4201e}},	//   ाड़_, wwah_, _תאור, जेल_,
   {{0xe5c72138,0x7e6201cb,0x62580076,0x63a902c6}},	//   _уско, jkop, _síor, řeno,
   {{0x61ed2bc4,0x7e620cad,0x4444667f,0x90552b49}},	// [6c30] raal, dkop, _fn_, овац,
   {{0x61ed1e08,0x44446eda,0x91d925af,0x7e624c1d}},	//   saal, _gn_, _फ्रै, ekop,
   {{0x61ed6edb,0xb4b5136b,0x00000000,0x00000000}},	//   paal, जगी_, --, --,
   {{0xa3ae000f,0x61ed0694,0x7e626edc,0x2c6b052f}},	//   _औरत_, qaal, gkop, _møde_,
   {{0x44446edd,0x62580037,0xfbc55d83,0xccfb0284}},	//   _yn_, _tíor, обло, уће_,
   {{0x6ab31c83,0xb5fb0146,0x351c00ca,0x645701ff}},	//   ुद्र, cháv, טודנ, _joxi,
   {{0x645722d4,0xfcb20031,0x9f430065,0xb21b0537}},	//   _moxi, úšať_, _kejí_, _djæv,
   {{0xe8f91a29,0x9f43030b,0x6457002b,0x3ce000ae}},	//   али_, _její_, _loxi, ţiva_,
   {{0x4433037a,0x7e7b6ede,0x7e690065,0x644502ac}},	//   _oax_, _imup, _ilep, _onhi,
   {{0x2c6b02b6,0x7e6905db,0x5d5400ae,0xd83802f1}},	//   _bøde_, _hlep, _экут, blčm_,
   {{0x7e696edf,0xf6260070,0xdb1f0084,0xddc0026a}},	//   _klep, одно, äväs, _komş,
   {{0xa3bf4972,0x3cf0000f,0x9f4a001f,0x2c6b0856}},	//   ेशन_, ुंचे_, _bebê_, _døde_,
   {{0x44446ee0,0x443315fb,0x1c1e0034,0x7e690113}},	//   _pn_, _bax_, _मॉडल_, _mlep,
   {{0x66e5153d,0xe7390636,0x64570131,0x81c10033}},	//   _дока, _век_, _coxi, ুরা_,
   {{0x444400ef,0xa3b40067,0x42561773,0x76562190}},	//   _vn_, जें_, отат, _toyy,
   {{0xb5fb6c15,0x44440133,0xa49b00b3,0x00000000}},	//   lkán, _wn_, tròc, --,
   {{0x394d36fa,0x44336ee1,0xfc470094,0x7e62010f}},	// [6c40] nxes_, _fax_, _číny_, vkop,
   {{0x394d05fe,0x44330167,0xc4863b2f,0xa3eb2581}},	//   ixes_, _gax_, _флок, मरण_,
   {{0xb5fb00d4,0x00000000,0x00000000,0x00000000}},	//   rháv, --, --, --,
   {{0x61461107,0xf3f10023,0xddc0078e,0x00000000}},	//   _дема, ực_, _comş, --,
   {{0x7e622ba3,0xff0a00c7,0xa2b90640,0xbc4a0831}},	//   rkop, রবেশ_, ्दर्, ичке_,
   {{0xdee62a61,0x395f0270,0x653b006e,0x5ed90033}},	//   _моги, dyus_, יענד, _ডিরে,
   {{0x7e626ee2,0xbb430161,0x00000000,0x00000000}},	//   pkop, дејк, --, --,
   {{0x2c6b0856,0x7e6900d1,0x13c50033,0xdb01014b}},	//   _røde_, _glep, ্রয়, _mylè,
   {{0x2c6b052f,0xf98f0018,0xc7b800e7,0xbe130192}},	//   _søde_, ہبی_, međi_, _توقع,
   {{0x7e69025b,0x7d020085,0x3ea66ee3,0xd838033b}},	//   _zlep, mros, llot_, koče_,
   {{0xd8380087,0x7bc8019c,0x44331b7b,0x7d0245d9}},	//   joče_, _igdu, _rax_, lros,
   {{0x44336ee4,0x3ea60085,0x8f9b00ca,0x645a17e4}},	//   _sax_, nlot_, שיטי, ötin,
   {{0xa25b0231,0xae0d007f,0x26d800c6,0x00000000}},	//   _biôn, _हासन_, ūro_, --,
   {{0x7d0220df,0x684300ae,0x44336ee5,0x00000000}},	//   iros, _онча, _qax_, --,
   {{0xd83802dd,0x21220167,0x3ea600f9,0x23650103}},	//   goče_, _apkh_, klot_, álj_,
   {{0x2605009d,0x44f5086a,0x443313e2,0x478904a1}},	//   _वाटी_, _епис, _wax_, _усім_,
   {{0x1ad60081,0x443300ca,0x3ea66ee6,0xe0d00076}},	// [6c50] সওয়া, _tax_, dlot_, نزل_,
   {{0x44270d79,0x7e69279a,0x2a6d0b14,0xd838033b}},	//   _ún_, _slep, zheb_, ločb_,
   {{0xd2500018,0x3ea66ee7,0x7e696ee8,0x00000000}},	//   رنے_, flot_, _plep, --,
   {{0xb5fb033d,0x2a6d6ee9,0x38ab13b9,0x7eb1298b}},	//   chát, xheb_, jørn_, kåpe,
   {{0x61e209b3,0xb3bd0081,0xa5bb01f9,0x00000000}},	//   ñole, _অভিজ, deók, --,
   {{0x6d4f0231,0x00000000,0x00000000,0x00000000}},	//   _àcam, --, --, --,
   {{0x7d026eea,0x3ea66eeb,0x22591acc,0x00000000}},	//   aros, blot_, _kosk_, --,
   {{0x6d5c01d4,0x394d05fe,0x7e7b6eec,0x98af0106}},	//   _əraz, txes_, _umup, đače_,
   {{0x13a8022d,0xe8063245,0xa3eb417a,0xb5fb6eed}},	//   _गर्भ, _शाखा_, मरा_, tkán,
   {{0x394d6eee,0x9f4a481d,0xd709007b,0x9f58033c}},	//   rxes_, _bebè_, бное_, _gcró_,
   {{0x38ab02b6,0x786d003e,0xf74544ab,0xb5fb0103}},	//   børn_, _núve, чено, rkán,
   {{0xb5fb02c6,0x31600063,0xeaae004d,0xe81c6eef}},	//   skán, yyiz_, _їй_, ब्बा_,
   {{0x09e20033,0xe79a02c6,0xd9450a52,0x00000000}},	//   _যাচা, _měří, _хели, --,
   {{0xa7fc026a,0xd838110e,0x00000000,0x00000000}},	//   lkın, toče_, --, --,
   {{0x22590090,0x07a200d3,0xb5fb0076,0x290b0031}},	//   _bosk_, _пашн, thát, žiaľ_,
   {{0xb5fb0103,0x02c34c46,0x7afc0537,0xa7fc028e}},	//   nkál, ейсо, _ærte, nkın,
   {{0xb5fb3e43,0x64890b14,0xe7f200c3,0xd8380117}},	// [6c60] rhát, džif, _आजमा_, soče_,
   {{0xd3e4015a,0x752401ff,0xb53b00ca,0xb5fb01cd}},	//   _تقدی, _ipiz, _פגיש, shát,
   {{0xa7fc0b88,0xd00f1a13,0x442a0f5a,0xe29a007e}},	//   kkın, الم_, meb_, _ган_,
   {{0x442a20cd,0x8ca4007f,0x93250103,0x9f43014b}},	//   leb_, _चीजो, _کرین, _dejà_,
   {{0x61e46ef0,0xd1ba0281,0x6d460234,0xdca621be}},	//   mbil, _دادا_, _škab, пади,
   {{0x44386ef1,0x442a6ef2,0x3ea66ef3,0x7eb10120}},	//   ndr_, neb_, slot_, våpe,
   {{0x3ea66ef4,0xdee62249,0x00000000,0x00000000}},	//   plot_, _хоби, --, --,
   {{0x442a6ef5,0xdb0f003e,0x752400c4,0xbea328b0}},	//   heb_, _ódýr, _opiz, _заск,
   {{0xb21b00d6,0x61e400e5,0x442a6ef6,0x00000000}},	//   _kjær, ibil, keb_, --,
   {{0x6d406ef7,0x442a0880,0x645a00c2,0x987300c2}},	//   _irma, jeb_, ötil, ельц,
   {{0x1faa0c8c,0x9f4a2c90,0x442a0150,0x7bdb00ca}},	//   _करोड, _bebé_, deb_, _הקבו,
   {{0x7c2a4ada,0xfb870103,0x7c38000b,0x00000000}},	//   lefr, _عدلی, ldvr, --,
   {{0x61e4093e,0x44380095,0x2fca0113,0x442a0178}},	//   dbil, fdr_, _ogbg_, feb_,
   {{0x27e900ef,0xfd650139,0x442a510d,0x7c381183}},	//   _đang_, _aisọ, geb_, ndvr,
   {{0x752408a9,0x855700cd,0xc5ec0033,0x00000000}},	//   _epiz, زیگر_, _কারা_, --,
   {{0x6d406ef8,0xfbdf0028,0x61e44822,0x63a51054}},	//   _orma, _đêm_, gbil, _vyhn,
   {{0xd49b3e04,0x442a6ef9,0x44380234,0x7c2a6efa}},	// [6c70] _грн_, beb_, bdr_, kefr,
   {{0x61e4166a,0xb5fb6efb,0x442a008c,0x2f1502c3}},	//   abil, chár, ceb_, tåg_,
   {{0x61e404f9,0x06e000c7,0x6d400fda,0x7c2a6efc}},	//   bbil, _ভিডি, _arma, defr,
   {{0x6d40005c,0x7c3818f0,0x8d740103,0x00000000}},	//   _brma, edvr, کاما, --,
   {{0xc7b803ce,0x442102b6,0x2f150212,0x628d0b14}},	//   među_, _kbh_, såg_, mnao,
   {{0x7c2a6efd,0x6aa20139,0x998d4c54,0x629f01ee}},	//   gefr, _akof, jdeš_, loqo,
   {{0xff041736,0xe0df01b9,0x44216efe,0x00000000}},	//   _пятн, _bròg_, _mbh_, --,
   {{0xac7700bf,0x442a00a5,0x44212058,0x61ef6eff}},	//   _کارش, zeb_, _lbh_, _jecl,
   {{0x44212779,0xa7fc008b,0x61ef026a,0xe0df05aa}},	//   _obh_, rkın, _mecl, _dròg_,
   {{0xa3bf0101,0x68ed003d,0x60c702f1,0x61ef6f00}},	//   ेशा_, _ħadd, _jijm, _lecl,
   {{0x752f00a5,0xa2cd009f,0x752400c4,0x61e400f2}},	//   ewcz, _दूल्, _spiz, ybil,
   {{0x60c7029a,0x61ef6f01,0x61e40e37,0xc7b804e9}},	//   _lijm, _necl, xbil, jeđu_,
   {{0x442a6f02,0x629f023b,0x61e4169c,0x6aa90b6a}},	//   teb_, doqo, vbil, mlef,
   {{0x6aa9032e,0x60c70126,0xb5fb0103,0x291800ae}},	//   llef, _nijm, nkáj, ărat_,
   {{0x61e46f03,0x442a6f04,0x648902ef,0x44210634}},	//   tbil, reb_, džid, _dbh_,
   {{0x442a6f05,0x7d0b0124,0x60cf00c4,0x61e46f06}},	//   seb_, kugs, _bucm, ubil,
   {{0x61e46f07,0x8ffa003f,0x6e2b6f08,0x61ef39bc}},	// [6c80] rbil, قرار_, degb, _decl,
   {{0x61e43341,0x26ce03e3,0xc48305b6,0x00000000}},	//   sbil, _yufo_, _альк, --,
   {{0x69cb6f09,0x68eb023e,0xee3a0b7b,0x69d901c0}},	//   _ogge, _lwgd, жне_, _ofwe,
   {{0x0d860bd5,0xdee31d3f,0x69cb00cd,0x7c2a0150}},	//   млен, тоци, _ngge, wefr,
   {{0xdddb007e,0x7c2a6f0a,0x78a30172,0xb21b0ac9}},	//   _fjuž, tefr, _oknv, _tjær,
   {{0x69d92de1,0x69cb6f0b,0x6aa2084e,0x62845fff}},	//   _afwe, _agge, _skof, liio,
   {{0xd838033b,0x7d0b0138,0x1f590012,0xa49b00b3}},	//   joča_, augs, _ешть_, dròl,
   {{0xfe430231,0x7c2a6dc9,0x7d0b0270,0x6aa96f0c}},	//   _инсо, sefr, bugs, glef,
   {{0x6d406f0d,0x644000e8,0x20cd0117,0x00000000}},	//   _urma, ēmij, _vžig_, --,
   {{0x0c231b4d,0x69cb611c,0x2bc70336,0x6c86015a}},	//   _имун, _egge, _ललचा, _غلام,
   {{0xd83802dd,0xf4140033,0x25b230e6,0x78ba00f2}},	//   goča_, াজার_, _azyl_, rmtv,
   {{0x44210063,0x786400b3,0x6aa2039f,0x2bcc0386}},	//   _sbh_, _mòvi, _ukof, ाशवा,
   {{0x9f410076,0x661d1d4a,0x4421020b,0xa7fc0233}},	//   rbhé_, rfsk, _pbh_, lkım,
   {{0x26ce6f0e,0x00000000,0x00000000,0x00000000}},	//   _tufo_, --, --, --,
   {{0x3d080ed3,0xb86502fc,0x7d0b25bb,0xf2c70077}},	//   _समझे_, _ثانو, zugs, дсан,
   {{0x6aa06f0f,0xb5fb0146,0xe5c700b4,0x44210063}},	//   nomf, cháp, _оспо, _wbh_,
   {{0x61e204d8,0x44210441,0x60c76f10,0x4a5b00d7}},	// [6c90] ñola, _tbh_, _pijm, קדמו,
   {{0xa7fc026a,0x44210076,0x6d4f01ec,0x32c700eb}},	//   kkım, _ubh_, _àcai, _gŵyn_,
   {{0x61ef2b93,0x6aa06f11,0x91c00336,0x26c9010a}},	//   _tecl, komf, लेबै, _kiao_,
   {{0x7bda0102,0x5fdf1b92,0x25a901c2,0x3d9518e4}},	//   _aftu, _प्रल, _kyal_, ниер,
   {{0x6e2b2897,0x26c96f12,0xece8004d,0x60dd6f13}},	//   regb, _miao_, дділ_, _utsm,
   {{0x7d0b6f14,0x26c903e3,0xa3d3074c,0xc6230033}},	//   rugs, _liao_, हुच_, _বোমা_,
   {{0xfaa506b2,0xa7fc026a,0x6aa901ce,0x248101b9}},	//   нако, rkıl, tlef, _mmhm_,
   {{0xa3b413ae,0x26c90113,0xd8380206,0xa49b00ee}},	//   जेट_, _niao_, voča_, dròm,
   {{0x26d803be,0x9f4a0139,0x00000000,0x00000000}},	//   íron_, _lebì_, --, --,
   {{0x6aa91e95,0x69130995,0x00000000,0x00000000}},	//   slef, jžeš, --, --,
   {{0x44ed6f15,0x25a90085,0x7c8400b8,0x00000000}},	//   ež_, _ayal_, _руте, --,
   {{0x26c96f16,0xd8380087,0x49750a0e,0x7e79020e}},	//   _ciao_, roča_, _плес, _çapı,
   {{0x648902ef,0xf484001c,0x00000000,0x00000000}},	//   džib, ناسی, --, --,
   {{0xe1ff06f0,0x3a2d089a,0x00000000,0x00000000}},	//   _adó_, leep_, --, --,
   {{0xe0df6f17,0x25a9010a,0xa49b00b3,0x16180285}},	//   _atò_, _eyal_, cròm, _थापर_,
   {{0x26c90028,0xe0da416d,0x09c30081,0x3d000557}},	//   _giao_, зва_, _এ্যা, _रिले_,
   {{0x41276ab3,0xd5b21487,0xa3b4023a,0xd00a00d3}},	// [6ca0] ното_, _حفظ_, जेज_, зезе_,
   {{0x80a60100,0xfe0d3751,0xf0a700ae,0x6aa0484a}},	//   رمان, _हाउस_, екул_, zomf,
   {{0xb4be1376,0x3a2d2ad7,0xe0df0139,0xdd920421}},	//   ेदी_, keep_, _etò_, گوش_,
   {{0xe29a01b6,0x443a6f18,0x2bdd270a,0x35a50cce}},	//   _хам_, _hap_, नुसा, _गुड़,
   {{0x443a6f19,0x3a2d0090,0x78a13210,0xb7bc01d3}},	//   _kap_, deep_, kolv, reģi,
   {{0x443a6f1a,0x61f66f1b,0x645e6f1c,0x3d20097c}},	//   _jap_, layl, _jopi, _यहीं_,
   {{0x443a00a1,0x645e01af,0xa3b40096,0x00000000}},	//   _map_, _mopi, जेच_, --,
   {{0xada63f1a,0x443a6f1d,0x645e6f1e,0x61f66f1f}},	//   _забл, _lap_, _lopi, nayl,
   {{0x645e6f20,0x1d0704c9,0x999802c6,0xec7a0e06}},	//   _oopi, _пети_, ěrů_, _епа_,
   {{0x443a5cd5,0x645e00d9,0x92cb0033,0x49730c4a}},	//   _nap_, _nopi, রীয়_, ульс,
   {{0x61f66f21,0x25a90085,0x25ac013c,0x6aa0024a}},	//   kayl, _syal_, ədli_, pomf,
   {{0x443a6f22,0x5f080e4c,0x76880233,0x00000000}},	//   _aap_, _हिन्_, dıys, --,
   {{0x7c3a6f23,0x2bdd00b6,0xb1120033,0x645e0381}},	//   _katr, नुवा, হবুব_, _bopi,
   {{0x443a6f24,0x645e6f25,0x69dc00a5,0x7c3a2502}},	//   _cap_, _copi, śred, _jatr,
   {{0x083b0105,0x443a1c7a,0x439407c8,0x27e000de}},	//   _מעגל, _dap_, гарс, _đinh_,
   {{0x7c3a6f26,0x32c700f0,0x00000000,0x00000000}},	//   _latr, _gŵyl_, --, --,
   {{0x764d6f27,0x6d46230b,0x9f4a037a,0x645e0065}},	// [6cb0] _inay, _škan, _debí_, _fopi,
   {{0x7c3a6f28,0x24970018,0x301400d3,0xed51001c}},	//   _natr, _سمجھ_, лдур, یپا_,
   {{0x61f66f29,0xe8181757,0xdea10103,0x00000000}},	//   bayl, _दाना_, لیسی, --,
   {{0xa2d61362,0x78a16f2a,0x443a6f2b,0x61f60188}},	//   _मंत्, zolv, _zap_, cayl,
   {{0x443a6f2c,0x764d0239,0x74b70034,0xd838033b}},	//   _yap_, _mnay, ोगपृ, jočo_,
   {{0x7c3a6f2d,0xaca30174,0x80070265,0xc4d4006e}},	//   _catr, kwụb, _ячме, אגס_,
   {{0x764d01e8,0x7c3a00f0,0xeb960451,0x5a9500ae}},	//   _onay, _datr, киш_, криф,
   {{0x0b880037,0xcff60033,0x764d0361,0x7c3a3bf8}},	//   عضوي_, _চায়_, _nnay, _eatr,
   {{0x7c3a6f2e,0x3a2d04e2,0xdb08033d,0xdd94198b}},	//   _fatr, reep_, _vzdá, _баты,
   {{0x29031e68,0x764d6f2f,0x7c3a0194,0x788600fd}},	//   čja_, _anay, _gatr, _révè,
   {{0x6e3b6f30,0x25c70092,0x764d01c2,0x79670065}},	//   _kaub, ətlə_, _bnay, _béwú,
   {{0x645e02fd,0xf5ec0032,0xf772010d,0x6e3b0062}},	//   _sopi, _bẹẹ_, شاپ_, _jaub,
   {{0x443a0c56,0x645e6f31,0xba742c66,0x7c3a03a9}},	//   _pap_, _popi, _حالت, _yatr,
   {{0x232a00d6,0x68fb6f32,0x764d6f33,0x3d0941e8}},	//   моги_, msud, _enay, _सिने_,
   {{0xf8c80028,0x638301b3,0x61f601e8,0x889a00a1}},	//   _cứu_, агра, tayl, _קבצי,
   {{0x443a6f34,0x69db6f35,0x6e3b2a0b,0x200701cd}},	//   _wap_, ncue, _naub, ónin_,
   {{0x443a6f36,0x645e6f37,0x61f6071d,0x68fb6f38}},	// [6cc0] _tap_, _topi, rayl, nsud,
   {{0x61f66f39,0x443a2253,0x64890234,0x3fe3038a}},	//   sayl, _uap_, ržic, ижув,
   {{0xa3bf0179,0x7c3a0c45,0xdfcf0190,0x6e3b114b}},	//   ेशः_, _ratr, زين_, _baub,
   {{0x7c3a6f3a,0x68fb2d96,0x6e3b6f3b,0xfce61dde}},	//   _satr, ksud, _caub, водо,
   {{0xdd8f0080,0x786d05fe,0xa2d60469,0x6e3b6f3c}},	//   يوم_, _núvo, _मूत्, _daub,
   {{0x68fb130d,0x60c90231,0x7c3a00bd,0x6e3b00fc}},	//   dsud, _éemp, _qatr, _eaub,
   {{0x7c3a02e6,0x26131757,0xf8c800fe,0x6e3b014b}},	//   _vatr, _थाली_, _mứt_, _faub,
   {{0x5a340aec,0x2c700032,0x6e3b6f3d,0xdddb078e}},	//   унит, _dàda_, _gaub, _iluş,
   {{0x7c3a1b76,0x7e6000e3,0x68fb6f3e,0x27e00022}},	//   _tatr, _iomp, gsud, _ƙin_,
   {{0x7e60022e,0x3ce66f3f,0x47346f40,0x6e3b6f41}},	//   _homp, mpov_, гнос, _zaub,
   {{0x81cb0081,0xdeb501c2,0x00000000,0x00000000}},	//   রুপ_, _arzƙ, --, --,
   {{0x648908a1,0x09e61787,0x6b7b0341,0xf76f048f}},	//   džia, _родн, _קראנ, تاً_,
   {{0x39400080,0x02be00b6,0xf8c800fe,0xe61f0206}},	//   _éis_, ्दैन, _bứt_, dnôt_,
   {{0xdddb0b88,0x7e606f42,0x67d36f43,0xf00b0023}},	//   _oluş, _lomp, _кошу, _đắng_,
   {{0x81e400c7,0x248d084f,0x47c00081,0xf8c800de}},	//   _নয়_, đem_, _শ্রী, _dứt_,
   {{0x764d2822,0x20182f10,0x7e606f44,0xbb3b0289}},	//   _unay, _acri_, _nomp, ועלי,
   {{0x2ba9099d,0x3ce6023e,0x81cb0081,0xc05b325f}},	// [6cd0] _चुना, jpov_, রুন_, між_,
   {{0x6e3b6f45,0x3f676f46,0x200f00c6,0x00000000}},	//   _saub, ктеб, ėgio_, --,
   {{0x44316f47,0x2fc70222,0x6e3b6f48,0x68fb0146}},	//   mez_, äng_, _paub, zsud,
   {{0x44316f49,0xacf93739,0x38b9020d,0x39466f4a}},	//   lez_, енду_, mère_, _oros_,
   {{0x394601fa,0x38b90257,0x93c90018,0x867c00ca}},	//   _nros_, lère_, _تاکہ_, וראו,
   {{0x44316f4b,0x261a0251,0xa3b72172,0x67380ea3}},	//   nez_, _भाभी_, _जरा_, _osvj,
   {{0x4fc43e04,0x6d42002d,0x6e3b6f4c,0x39460150}},	//   _вста, avoa, _taub, _aros_,
   {{0x44313880,0x7e6003a8,0x68fb6f4d,0x39460133}},	//   hez_, _gomp, tsud, _bros_,
   {{0x44316f4e,0x69db3edc,0x39461e62,0x38b900fd}},	//   kez_, rcue, _cros_, hère_,
   {{0x394602e0,0x46e92249,0x68fb0cae,0x44316f4f}},	//   _dros_, ндон_, rsud, jez_,
   {{0x44315b28,0x68e200e7,0xf77108ba,0x6ec700bc}},	//   dez_, _etod, صاد_, ़गपु,
   {{0x39460063,0x38b900fd,0x69dc02c6,0x6d4f0231}},	//   _fros_, dère_, ěrec, _àcas,
   {{0x39466f50,0x44316f51,0x69da00c1,0xa68304a1}},	//   _gros_, fez_, _אַוו, сляд,
   {{0x44316f52,0x26d10558,0x38b900fd,0x00000000}},	//   gez_, ízos_, fère_, --,
   {{0xe818007a,0x291f0084,0x38b90257,0xf8c80023}},	//   _दाता_, ltua_, gère_, _vứt_,
   {{0x20031a3a,0x64891bf6,0x6d460ebd,0x00000000}},	//   _adji_, ržia, _škam, --,
   {{0x291f6bb4,0xe29700d3,0xd0260451,0x44314bcd}},	// [6ce0] ntua_, уат_, лмай, bez_,
   {{0x64896f53,0x7e606f54,0x291f2050,0x44316f55}},	//   lžin, _somp, itua_, cez_,
   {{0x441b07a6,0x141b00c1,0x7f862c9a,0x291f00c2}},	//   _אויס, _אויב, دلان, htua_,
   {{0x291f0a00,0xfdd20081,0x23650212,0xb5fb02c6}},	//   ktua_, ার্ড, älje_, skáv,
   {{0x5bcc02d5,0x291f0052,0xaff80103,0x127b0142}},	//   ाश्व, jtua_, _لہذا_, _טאטע,
   {{0x200300e7,0xdca300d6,0x22406f56,0x398a007a}},	//   _gdji_, бачи, ldik_, _हs_,
   {{0x291d003d,0x68e26f57,0x6fb800aa,0x6e2205bd}},	//   _aqwa_, _stod, _अरिं, pfob,
   {{0x44310d1b,0x22406f58,0x66046f59,0x6f9300e3}},	//   zez_, ndik_, _ndik, _الفض,
   {{0xa9c302ec,0xe8182480,0x4431025a,0x21206f5a}},	//   йськ, _दादा_, yez_, ntih_,
   {{0x66040da3,0xb8dc0179,0x3ea6685e,0x44316f5b}},	//   _adik, _आठ_, loot_, xez_,
   {{0x443104ea,0xa3d804f1,0x62864e21,0x291f0634}},	//   vez_, िशन_, _omko, atua_,
   {{0x39466f5c,0x1efb00c1,0x3ea604e2,0x2120033b}},	//   _tros_, עלכע, noot_, ktih_,
   {{0x44316f5d,0x9c830087,0x291f6f5e,0x6604009e}},	//   tez_, _ščit, ctua_, _ddik,
   {{0x66040c56,0x3ea66f5f,0xe0df01f7,0x38b9201c}},	//   _edik, hoot_, _bròn_, tère_,
   {{0xfe140251,0x3ea66f60,0x05a50336,0x00000000}},	//   _डांस_, koot_, _गुरब, --,
   {{0x44316f49,0xddc239a2,0xe61f0131,0x92b709f9}},	//   sez_, zkoš, rnôs_, احسا,
   {{0x44311d32,0x7c284c54,0x20cd0e94,0x38b9020d}},	// [6cf0] pez_, _obdr, _džin_, sère_,
   {{0x38b90257,0x752d0036,0x7d1d23ce,0x00000000}},	//   père_, _ipaz, _ässi, --,
   {{0x291f01e9,0x6368008f,0xf1bf0139,0x63a9042c}},	//   ztua_, _бряг_, _gbán_, ßend,
   {{0x4fc40084,0x63a901e8,0x3cfd023e,0xddc96f61}},	//   ссуа, ğend, tswv_, _aleš,
   {{0xddc9141f,0xddc21912,0xa3bf0469,0xd16700e5}},	//   _bleš, tkoš, ेशक_, _съни,
   {{0x6b65264b,0xa3d8009d,0x20030a39,0x752d04ff}},	//   икла, िशय_, _udji_, _mpaz,
   {{0x61ed6f62,0x5c0403fb,0xb5fb01f9,0x00000000}},	//   obal, сяча, nkás, --,
   {{0x291f6f63,0x752d02dd,0x81cb0033,0x38ab00f2}},	//   ttua_, _opaz, রুণ_, hørt_,
   {{0xe8f60761,0xaca30134,0x6e290270,0x291f00c2}},	//   алы_, _awụn, _ibeb, utua_,
   {{0xb5fb000d,0x291f6f64,0x6489013f,0x6d492dd0}},	//   cház, rtua_, džio, _irea,
   {{0x291f6f65,0x61ed6f66,0x3a3d0063,0x6d4f0072}},	//   stua_, kbal, _tawp_, _ácab,
   {{0xf1c5143d,0xa6de0019,0x5f080378,0x61ed0146}},	//   वधान, _trưn, _हिस्_, jbal,
   {{0x61ed6f67,0x38ab038c,0xe9ce3340,0x81cb0081}},	//   dbal, ført_, _фк_, রুত_,
   {{0x186622be,0xf7450058,0x6d460559,0x61ed6f68}},	//   _ваши_, _веко, _škak, ebal,
   {{0x68e90572,0xe3632b79,0x07d80037,0x6e296f69}},	//   lped, окри, _إذهب_, _obeb,
   {{0x61ed6f6a,0x2ca71044,0x6604198d,0x672100c4}},	//   gbal, hond_, _udik, mtlj,
   {{0x2ca70006,0xa2d66324,0x22406f6b,0x1fe70033}},	// [6d00] kond_, _मूर्, rdik_, _পয়স,
   {{0x6e295f6a,0xf00b0019,0xe0df00de,0x68e90138}},	//   _abeb, _đảng_, _tròn_, iped,
   {{0x212019d0,0x61ed6f6c,0x3ea61044,0x6d496f6d}},	//   stih_, bbal, toot_, _area,
   {{0x6d495d5b,0xa11600cd,0xa25b0031,0x9ac50172}},	//   _brea, _پوست, _chôd, _yaŋŋ,
   {{0x6d496f6e,0x62966f6f,0x3ea60d55,0x6cc6083c}},	//   _crea, mnyo, root_, айда,
   {{0x23ba000f,0x6d496f70,0x6e29063d,0xb5fb6f71}},	//   _इराद, _drea, _ebeb, nkár,
   {{0x2ba900a5,0xe45700c1,0x3ea66f72,0x290d15e7}},	//   _चुदा, ייסט_, poot_, erea_,
   {{0x6d490fab,0x62960283,0x7f3b040a,0xd8380087}},	//   _frea, nnyo, _בעלו, moči_,
   {{0xfce321fd,0x6d4960ea,0xd5a50e50,0xd8380087}},	//   _мото, _grea, _गुंज, loči_,
   {{0x2ca76f73,0x61ed0094,0xc7c66f74,0xc866085f}},	//   cond_, zbal, исни, ртии,
   {{0xa2d62fc2,0x752d6f75,0x290d00d3,0xd838033b}},	//   _मूल्, _spaz, area_, noči_,
   {{0xe8182ebd,0x290d6f76,0x62966f77,0x569400a9}},	//   _दावा_, brea_, jnyo, жают,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd83807c0,0xe0df022b,0xa7860281,0x00000000}},	//   koči_, _dròl_, _پشتو, --,
   {{0xe2870396,0xd8380087,0x83f800c2,0x38ab00f2}},	//   аѓан, joči_, ресс_, rørt_,
   {{0x2ca70126,0x78a864ed,0x277700ca,0xb5fb02c6}},	//   zond_, lodv, _כגון_, ujád,
   {{0xc1b93d77,0xf8ba0c22,0x63a90364,0x98ba0d77}},	// [6d10] улах_, _उठाय, ßenb, _उठाए,
   {{0x62960098,0xa5bb037a,0x6d49302f,0xae141cff}},	//   anyo, nfóm, _rrea, _डाउन_,
   {{0x62964e1d,0x2ca70ab2,0x6d490091,0xd838033b}},	//   bnyo, vond_, _srea, goči_,
   {{0x6d496f78,0x2ca70db1,0x61ed0188,0x42554345}},	//   _prea, wond_, qbal, _انحر,
   {{0x2ca76f79,0x2c790154,0x9d450b21,0x00000000}},	//   tond_, _lède_, селд, --,
   {{0x6d49002d,0xf21d009f,0x290d028d,0x78a80357}},	//   _vrea, _फाड़_, vrea_, jodv,
   {{0xa3d82b8a,0x2ca703ee,0x00000000,0x00000000}},	//   िशत_, rond_, --, --,
   {{0x6d490a91,0x290d6f7a,0x2ca7057a,0x628d6f7b}},	//   _trea, trea_, sond_, niao,
   {{0xa2ba439d,0x2ca70257,0x6d496f7c,0x3ead6f7d}},	//   ्षत्, pond_, _urea, _iket_,
   {{0x290d3868,0xa5bb2a6b,0x64890a7f,0xa85500f6}},	//   rrea_, rfól, užil, стиј,
   {{0xa5bb0088,0xb8fe0006,0xe94500cd,0x07a50bd5}},	//   sfól, _दू_, _گرای, санн,
   {{0x68e96f7e,0x15e300c3,0xb4d00354,0x00000000}},	//   pped, कुलर_, षद्_, --,
   {{0xe94500cd,0x67216f7f,0x98e50076,0x628d28b4}},	//   _درای, stlj, _اكتو, diao,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5fb6f80,0x786d6f81,0xa3b4007f,0x00000000}},	//   rkár, _núvi, ड़ें_, --,
   {{0xb5fb6eed,0x20cd007e,0x56930b1b,0x236533b9}},	//   skár, _džim_, _најт, älja_,
   {{0x62960103,0x26d201ee,0x00000000,0x00000000}},	// [6d20] rnyo, _iiyo_, --, --,
   {{0x26d21ee3,0x62966f82,0x6aa901a2,0x2f5614fa}},	//   _hiyo_, snyo, hoef, йтес,
   {{0x3ead00f9,0xdfcf0076,0x00000000,0x00000000}},	//   _bket_, فيك_, --, --,
   {{0x9f5801e5,0x786d00c9,0x290201b3,0xd83802dd}},	//   _herë_, _dúvi, škai_, roči_,
   {{0x64890b18,0x3ebf0013,0x3ead0167,0x26d26f83}},	//   džij, _dhut_, _dket_, _miyo_,
   {{0x6a75037a,0x653b006e,0xdca300d3,0x26d200d1}},	//   _ráfa, טענד, пачи, _liyo_,
   {{0x26d20113,0x26c000d7,0xbc19004d,0x6aa9084e}},	//   _oiyo_, _ohio_, річі_, foef,
   {{0x6e960080,0x25ad00a5,0x26d26f84,0x261a1757}},	//   _الرا, żeli_, _niyo_, _भाषी_,
   {{0x81aa00c7,0xa3d83fac,0x9f5a0558,0xd7fa075f}},	//   গের_, िशा_, dapé_, лун_,
   {{0x7c650080,0x290a4c54,0x7d026f85,0xfb1a0604}},	//   _والل, čba_, msos, _مقطع_,
   {{0x26d26f86,0x26c0009c,0x7d026f87,0xcb09004d}},	//   _biyo_, _bhio_, lsos, _вхід_,
   {{0x26d205e0,0x8f9b0327,0xe0df009c,0xa7fc0233}},	//   _ciyo_, ריטי, _sròm_, tkıs,
   {{0x92d50f71,0x261a0e72,0x98a60606,0x7d026f88}},	//   _হবে_, _भारी_, _лиде, nsos,
   {{0x2a6601fa,0xf484013d,0xd91b0266,0xa7fc026a}},	//   _hoob_, пусн, _עוול, rkıs,
   {{0x25a06f89,0x2a660197,0x7d020124,0x26d20027}},	//   _exil_, _koob_, hsos, _fiyo_,
   {{0x7d0212f1,0x9f5a20ed,0x00000000,0x00000000}},	//   ksos, capé_, --, --,
   {{0x786d0181,0x2a66022e,0xe0df009c,0x00000000}},	// [6d30] _súvi, _moob_, _tròm_, --,
   {{0x44276f8a,0x2a666f8b,0x3ead6f8c,0x26d2039f}},	//   _ùn_, _loob_, _sket_, _ziyo_,
   {{0x656f6f8d,0x273a01d3,0x2c6b02b6,0x3ebf00fe}},	//   lych, _jūn_, _mødt_, _phut_,
   {{0x2a6637fe,0x81cb0081,0x66e101d3,0x7d020022}},	//   _noob_, রুষ_, _jēka, fsos,
   {{0xed591bd8,0x656f00f0,0x61ff0092,0x7d026f8e}},	//   рол_, nych, maql, gsos,
   {{0x61ff013c,0xc05b00d6,0x2c6b01df,0xcb690012}},	//   laql, _сім_, _nødt_, иале_,
   {{0x2a666f8f,0x6aa90371,0x22420085,0x261a00a3}},	//   _boob_, toef, _yakk_, _भाली_,
   {{0xe9d9576c,0x2a660197,0x61ff00a7,0x2c4f00e8}},	//   шки_, _coob_, naql, _sēdē_,
   {{0x2ba900c3,0x6aa907e6,0x2b4c01b9,0x81cb0033}},	//   _चुरा, roef, _erdc_, রুর_,
   {{0x26d20010,0x26c01bdf,0x656f6f90,0xd83800e7}},	//   _siyo_, _shio_, dych, koču_,
   {{0x2a66022e,0x9b951673,0x3f8103e3,0x2ca00076}},	//   _foob_, _بلات, nzhu_, éide_,
   {{0x2a660188,0xe7360120,0x00000000,0x00000000}},	//   _goob_, цею_, --, --,
   {{0x2c6b0856,0x15ba00c6,0x6ef00154,0xe7f200a4}},	//   _født_, рыны_, _kòbò, _आजचा_,
   {{0x7d0400e3,0x26d20027,0xb5fb01cd,0x00000000}},	//   áisi, _wiyo_, skáp, --,
   {{0x81b10081,0xd252048f,0x3246008f,0x9f580052}},	//   টেম_, ونس_, оевг, _verë_,
   {{0x2a6601fa,0x66de00e8,0x6f0001f9,0xd6d20076}},	//   _xoob_, _mīkl, _lábá, _تقع_,
   {{0x25df000f,0x806614e7,0x8cd90e4c,0x5faf00c3}},	// [6d40] _गलती_, оваж, _फूलो, _जुबल,
   {{0x68e46f91,0x1fb6004d,0x6ecc020e,0xe3b20076}},	//   _éide, осер, _işbi, _يرد_,
   {{0x44444937,0xe82100a5,0x81cb0081,0x22426f92}},	//   _ia_, _माना_, রুল_, _takk_,
   {{0x44440fd1,0x61ff0092,0x87ac006e,0xa49b00b3}},	//   _ha_, caql, נשאַ, nsòn,
   {{0x2a666f93,0x76446f94,0x6ef0022b,0x61e4026a}},	//   _roob_, _maiy, _bòbò, mcil,
   {{0x44446f95,0x44386f96,0x2a6601fa,0x7d0255c5}},	//   _ja_, ner_, _soob_, rsos,
   {{0x44446f97,0x44386f98,0x7d026f99,0x66de00d9}},	//   _ma_, ier_, ssos, _rīko,
   {{0x44386f9a,0x61e46f9b,0xead30084,0x2a66006c}},	//   her_, ncil, мощь, _qoob_,
   {{0x44386f9c,0x44446f9d,0xe51c06ed,0xddc90146}},	//   ker_, _oa_, भूमि_, _pleť,
   {{0x6d406f9e,0x7e6200e9,0x44386f9f,0x656f0094}},	//   _isma, ljop, jer_, vych,
   {{0x76440044,0x673a01c0,0x656f0419,0x2a666fa0}},	//   _baiy, uwtj, wych, _toob_,
   {{0x44440188,0x368b0642,0x764401c2,0x656f0034}},	//   _aa_, рсон_, _caiy, tych,
   {{0x44446fa1,0x44381fdd,0x200a00e7,0x1dca0be4}},	//   _ba_, fer_, _odbi_, िधित,
   {{0x44446fa2,0x44381322,0x656f6fa3,0x6a7c0257}},	//   _ca_, ger_, rych, _défe,
   {{0x764401c2,0x9f41028d,0x29040b8e,0xd8380a39}},	//   _faiy, cchè_, lsma_, meč_,
   {{0x44446fa4,0x6d406fa5,0xd8386fa6,0x76440022}},	//   _ea_, _osma, leč_, _gaiy,
   {{0x44446fa7,0x61ff01d4,0xe82110e9,0x142b0426}},	// [6d50] _fa_, raql, _मामा_, _кіно_,
   {{0x44446fa8,0x7c3804a3,0xdb010031,0x76440022}},	//   _ga_, jevr, _vylú, _zaiy,
   {{0x44216fa9,0x6d406faa,0x1eea09b4,0x4ea71906}},	//   _ich_, _asma, مولی_, орда,
   {{0x51871ca7,0x9f416fab,0x64451103,0x236c0212}},	//   _дуга, nché_, _hahi, ädje_,
   {{0x44446fac,0x644534e1,0x61fd01d3,0x7c386fad}},	//   _ya_, _kahi, _iesl, fevr,
   {{0x44446fae,0x61fd0897,0xd8380292,0x64456faf}},	//   _xa_, _hesl, ječ_, _jahi,
   {{0x64456fb0,0x6d406fb1,0x20010510,0x6d464289}},	//   _mahi, _esma, mahi_, _škat,
   {{0x44386fb2,0x60d50b88,0x44210037,0x539c006e}},	//   zer_, _hizm, _lch_, ייוו,
   {{0x44216fb3,0x44386fb4,0xc1b902e8,0xdb08030b}},	//   _och_, yer_, _आरोग, _vydá,
   {{0x26dc08a1,0x44386fb5,0x64456fb6,0x44216fb7}},	//   _buvo_, xer_, _nahi, _nch_,
   {{0x44383f49,0x44446fb8,0xe821007d,0x7e7b02e6}},	//   ver_, _ra_, _माठा_, _klup,
   {{0x44446fb9,0x4421445f,0x44386fba,0x9f410465}},	//   _sa_, _ach_, wer_, rchè_,
   {{0x64456fbb,0x200137b7,0x69d9405f,0x29020018}},	//   _bahi, kahi_, _igwe, ákat_,
   {{0x3cfd007d,0x44386fbc,0x20016fbd,0x644525c7}},	//   रीये_, uer_, jahi_, _cahi,
   {{0x44446fbe,0x44381be0,0x61fd6fbf,0x644513b5}},	//   _va_, rer_, _besl, _dahi,
   {{0x44446fc0,0x60d500d9,0x61fd015c,0x9f410451}},	//   _wa_, _aizm, _cesl, cché_,
   {{0x44446fc1,0x6445111b,0x61fd0145,0x61e46109}},	// [6d60] _ta_, _fahi, _desl, rcil,
   {{0x44441071,0x8fa6013d,0x7e7b6fc2,0x61e46fc3}},	//   _ua_, пазе, _alup, scil,
   {{0x7d19029a,0x60dd009c,0x7e69084e,0x69d95dde}},	//   euws, _eusm, _boep, _ogwe,
   {{0x61fd6fc4,0x64456fc5,0x0dca0084,0x7e7b0072}},	//   _gesl, _zahi, блей_, _clup,
   {{0xa25b011b,0x64452328,0x7c386fc6,0x41b9045f}},	//   _khôn, _yahi, tevr, _आरएस,
   {{0x91bb00a1,0x81d50081,0x644500a7,0x69d96fc7}},	//   _למכי, _সড়ক_, _xahi, _agwe,
   {{0x8fa327c9,0x5e9652c6,0xd83802dd,0xe51c0557}},	//   _заре, _فلسط, več_, भूति_,
   {{0x7e7b02e6,0x60dd005c,0xb95400d6,0x26dc0036}},	//   _glup, _yusm, двищ, _ruvo_,
   {{0x6d4004b7,0x26dc077e,0x2d820212,0x48aa00ba}},	//   _usma, _suvo_, _åke_, йтом_,
   {{0x6c860f43,0xf80600d6,0x29046fc8,0xb8060018}},	//   _علام, ччин, rsma_, سکتے_,
   {{0x644553ab,0x7bda0009,0xd8386fc9,0xc1b92397}},	//   _rahi, _igtu, reč_, _आर्ग,
   {{0x64456fca,0xd6d73840,0xe82133d9,0x44216fcb}},	//   _sahi, ять_, _माथा_, _sch_,
   {{0x9f416fcc,0x64456fcd,0x20016fce,0x61fd6fcf}},	//   rché_, _pahi, yahi_, _resl,
   {{0x753d0067,0x2902013f,0x26dc6fd0,0x61fd01e8}},	//   rwsz, škas_, _tuvo_, _sesl,
   {{0x64456fd1,0x249107aa,0xe821320a,0x64470313}},	//   _vahi, rizm_, _माता_, rdji,
   {{0x20016fd2,0x60f91119,0x64456fd3,0x179b006e}},	//   wahi_, жная_, _wahi, _ליוב,
   {{0x20016fd4,0x64456fd5,0xd2500068,0x7e690cad}},	// [6d70] tahi_, _tahi, ھنے_, _roep,
   {{0x61fd6fd6,0x7e6927de,0x7e7b6fd7,0x660d0113}},	//   _wesl, _soep, _slup, _hdak,
   {{0x61fd4813,0x7e7b0257,0x7e695aff,0x00000000}},	//   _tesl, _plup, _poep, --,
   {{0xa15913a4,0x20015604,0xddd0013f,0x660d0154}},	//   _даму_, sahi_, _šešt, _jdak,
   {{0x8c452c13,0x6d46011d,0x60dd4880,0x00000000}},	//   деле, _škar, _uusm, --,
   {{0x7e7b0063,0x22496fd8,0x7e6902ac,0xe81800c3}},	//   _wlup, ldak_, _woep, _दागा_,
   {{0x7e6904ee,0x9f3400d6,0x6e950686,0x2f1800ae}},	//   _toep, _пері, _живу, _норь_,
   {{0x660d6fd9,0xcf9200c1,0x7e7b6fda,0xe8e934df}},	//   _ndak, _סטן_, _ulup, омид_,
   {{0x08c533d0,0x21291bd6,0x7d0400e3,0xe8210378}},	//   мбин, ntah_, áist, _मादा_,
   {{0x660d1a95,0x7d0403e5,0x2a7f128c,0xa88916dd}},	//   _adak, ġist, shub_, ійна_,
   {{0xa25b0257,0xb21b6fdb,0x395f006c,0x2249003a}},	//   _rhôn, _klæd, sxus_, kdak_,
   {{0x7bc108c5,0x21296fdc,0x49756cb6,0x660d0113}},	//   _izlu, ktah_, _олес, _cdak,
   {{0xddc00c27,0xd9450114,0xa25b0023,0x660d6fdd}},	//   _komš, _цели, _phôn, _ddak,
   {{0x2a7d006c,0x74160182,0x660d520f,0x02c608c0}},	//   _hlwb_, بوسا, _edak, लग्न,
   {{0x21296fde,0x394d6fdf,0x41eb0174,0x98a2455b}},	//   etah_, lves_, _ụsọ_, _шише,
   {{0x6489013f,0x7d096fe0,0x21292b78,0xf789015e}},	//   džiu, _oves, ftah_, _ençà_,
   {{0xa25b00ef,0x3ced0197,0xe2970131,0x412702b3}},	// [6d80] _thôn, _ntev_, фат_, мото_,
   {{0xa2be1687,0xb5fb01cd,0x22460031,0x22490062}},	//   _वीर्, hjál, žok_, adak_,
   {{0x7d096fe1,0xa3b5009f,0x72c61278,0x7eb80042}},	//   _aves, _छुप_, _обоз, lípi,
   {{0x200704c8,0xdddb00b6,0x3d0900c3,0x11d60076}},	//   ónir_, _kouř, _सिखे_, _يتحد,
   {{0x6489005f,0x98bd022b,0xb21b592f,0x66e101d3}},	//   rživ, _aswč_, _slæg, _sēkl,
   {{0x394d0018,0x7d096fe2,0x00000000,0x00000000}},	//   dves_, _dves, --, --,
   {{0x6489025b,0x2ac60284,0xa3e60285,0x7d096fe3}},	//   mžit, мљив, _फलन_, _eves,
   {{0xb21b01c5,0x2a7d0150,0xf27b006e,0x998f00c6}},	//   _glæd, _clwb_, ַריש, _nagų_,
   {{0xdb0800c2,0xd83e00d8,0x00000000,0x00000000}},	//   _sydä, _áčka_, --, --,
   {{0x6a7c0257,0x2ba90176,0x81cb0033,0x00000000}},	//   _défa, _चुका, রুক_, --,
   {{0x7d096fe4,0x00000000,0x00000000,0x00000000}},	//   _zves, --, --, --,
   {{0x787f0257,0xdddb00b6,0x63a9042c,0xb4d71678}},	//   _rêve, _bouř, ßenm, िद्_,
   {{0x63a9026a,0x660d1515,0xd05d00a7,0xdd9900d8}},	//   ğenm, _vdak, _etsə, _keňa_,
   {{0xe1ff0076,0x648900c6,0x00000000,0x00000000}},	//   _seó_, yžiu, --, --,
   {{0xa4d402ec,0x46a70084,0x6281013f,0xf83700a1}},	//   торі, _ошиб, ūlom, _חנות_,
   {{0xe0df0465,0x660d6fe5,0xd6c31ac9,0xddc21b32}},	//   _può_, _udak, _جمعی, dkož,
   {{0x7eb8001f,0xf1940686,0x22496fe6,0x00000000}},	// [6d90] cípi, вить, rdak_, --,
   {{0x69c2024a,0x00000000,0x00000000,0x00000000}},	//   _mzoe, --, --, --,
   {{0x7d091419,0x21296fe7,0x7a1500a7,0xddc00141}},	//   _sves, stah_, nətç, _romš,
   {{0xc3320130,0x6aa200dd,0x212900f9,0x00000000}},	//   _גוט_, _njof, ptah_, --,
   {{0xd1cb00ae,0x00000000,0x00000000,0x00000000}},	//   _фунд_, --, --, --,
   {{0x251c0266,0x6aa2020a,0x00000000,0x00000000}},	//   קווא, _ajof, --, --,
   {{0x1ee7001c,0x7e7800e8,0x6a7c03a9,0x81d40033}},	//   _آوری_, īvpr, _séfa, সুদ_,
   {{0x394d6fe8,0xe8f910a6,0x00000000,0x00000000}},	//   tves_, пли_, --, --,
   {{0x81b100c7,0x9f410080,0x7d090995,0x394d00fd}},	//   টের_, ichí_, _uves, uves_,
   {{0xe8f60109,0xb5fb0103,0x394d6fe9,0x6a750131}},	//   эль_, ckáz, rves_, _máfi,
   {{0xe7ee009f,0x394d6fea,0x47d20033,0x6a750032}},	//   छड़ा_, sves_, _দ্বী, _láfi,
   {{0x70bd05d6,0xda671b21,0x443300d8,0x00000000}},	//   ्गुल, _تائي, _abx_, --,
   {{0xa25b00fd,0x7ae16feb,0xf1bf00da,0x00000000}},	//   _chôm, _hult, _mbás_, --,
   {{0x44330231,0x98170a85,0x00000000,0x00000000}},	//   _cbx_, _آبشا, --, --,
   {{0x42560f99,0x7dd604a8,0x7ae16fec,0x987a00d7}},	//   нтат, _küsü, _jult, _מאסט,
   {{0x7ae16a1a,0x2215041f,0xb21b04c8,0x44330231}},	//   _mult, кфур, _smær, _ebx_,
   {{0x66066fed,0x563700c1,0xa69b00ca,0x61f66fee}},	// [6da0] makk, _טאקע_, _משקפ, rbyl,
   {{0x66066fef,0xf1bf0065,0x64890146,0x3e4c0023}},	//   lakk, _abás_, užit, _ớt_,
   {{0x15f40b2b,0xee3a0feb,0x7ae10218,0x44e600de}},	//   _आभार_, зне_, _nult, _hô_,
   {{0x66066ff0,0x44e60023,0xe1f21454,0x00000000}},	//   nakk, _kô_, _حسد_, --,
   {{0x629601e8,0x628402bc,0xdb0101e8,0x44e60131}},	//   miyo, mhio, _eylü, _jô_,
   {{0x62966ff1,0x7ae16ff2,0x44e60019,0xb5fb1515}},	//   liyo, _bult, _mô_, ukáz,
   {{0x66066ff3,0x1fb557a3,0x7ae151a2,0xc60b0081}},	//   kakk, _астр, _cult, ষ্টা_,
   {{0x62966ff4,0x66065ab2,0x9f5a0131,0x7ae16ff5}},	//   niyo, jakk, capá_, _dult,
   {{0x66062cf8,0xada36ff6,0x261a009d,0x44e60023}},	//   dakk, _батл, _भाजी_, _nô_,
   {{0xd7f729c2,0x62966ff7,0x32026ff8,0x89330037}},	//   ную_, hiyo, _leky_, اعيا,
   {{0x62966ff9,0x6606009e,0x7ae14a0f,0xe8211152}},	//   kiyo, fakk, _gult, _मारा_,
   {{0x6e22067d,0x6606063f,0x62966ffa,0x7a1500a7}},	//   ngob, gakk, jiyo, rətç,
   {{0x44e600ef,0x62966ffb,0x69c20051,0x44335eae}},	//   _cô_, diyo, _uzoe, _pbx_,
   {{0x66060167,0x44e66ffc,0xb4ab00b7,0x00000000}},	//   aakk, _dô_, गके_, --,
   {{0x66066ffd,0xd7f800d3,0x629632c0,0x62841ac3}},	//   bakk, mbă_, fiyo, fhio,
   {{0xb0ec0081,0x6d420174,0x44e60154,0xb21b02b6}},	//   _ওয়েব_, kwoa, _fô_, _slæb,
   {{0x68e2022c,0x51872e1b,0x32020094,0x81d40033}},	// [6db0] _juod, хува, _deky_, _স্ব_,
   {{0x68e20084,0x9f5800ee,0x6e220172,0x00000000}},	//   _muod, _berà_, egob, --,
   {{0x62966ffe,0x26c96fff,0x44e60023,0x68e2007b}},	//   biyo, _khao_, _zô_, _luod,
   {{0x62847000,0x3946299e,0x7ae101b9,0x9f580231}},	//   chio, _osos_, _rult, _serã_,
   {{0xe821049d,0x272a026e,0x44e600de,0x68e20138}},	//   _माला_, hùn_, _xô_, _nuod,
   {{0xd116040a,0x44237001,0x224b0158,0xd7f8020a}},	//   _בקשה_, ngj_, _hack_, jbă_,
   {{0x66067002,0x9f4a00ee,0x0ebb0e27,0xddc90147}},	//   yakk, _debó_, _فارغ_, _ulež,
   {{0xb4bf0167,0x6a7c00fd,0x68e27003,0x26c9020b}},	//   ेषु_, _défo, _buod, _nhao_,
   {{0x66067004,0x2003026e,0xdfe50fef,0x394600b3}},	//   vakk, _keji_, _औलाद_, _csos_,
   {{0x68e20138,0x62967005,0xb4ab030b,0x200326fa}},	//   _duod, ziyo, गको_, _jeji_,
   {{0x07a568de,0xf42700c7,0x394614e2,0x66067006}},	//   танн, য়ার_, _esos_, takk,
   {{0x26c97007,0xd7f800d3,0x44e67008,0xa802020e}},	//   _chao_, abă_, _pô_, çırm,
   {{0xb6a3319f,0x6296026a,0x69cd00a8,0x7d1900f0}},	//   риял, viyo, देशी, nrws,
   {{0x44e60028,0x44230653,0x291f0051,0x9f580072}},	//   _vô_, ggj_, muua_, _lerá_,
   {{0x224b7009,0x62960b88,0x6284700a,0xe5171bc3}},	//   _back_, tiyo, thio, _तिथि_,
   {{0x44e62812,0xcfb70081,0x3ddf039f,0x00000000}},	//   _tô_, জধান, _nguw_, --,
   {{0x6296700b,0x9f580990,0x20032e7d,0xe0da0237}},	// [6dc0] riyo, _serà_, _beji_, два_,
   {{0x6296700c,0x6604700d,0x628400ca,0x26db20df}},	//   siyo, _heik, shio, _épor_,
   {{0x3a3f700e,0x403300d6,0x660411cf,0x224b02c3}},	//   keup_, реєс, _keik, _fack_,
   {{0x6a7c0257,0x644e700f,0x20030139,0x66040062}},	//   _réfo, ldbi, _eeji_, _jeik,
   {{0x6e220383,0x3cfd030b,0x66047010,0xa3e6074c}},	//   rgob, रीले_, _meik, _फला_,
   {{0x66047011,0xdb1a0018,0x644e7012,0x3a2600d3}},	//   _leik, _aztá, ndbi, _scop_,
   {{0xa03709c1,0xfbd50081,0x38602bcb,0x68e2007b}},	//   _שאלה_, _স্বত, _đir_, _suod,
   {{0xeaaf00e3,0x60dc0673,0x68e20138,0x24980364}},	//   يعي_, _hirm, _puod, hirm_,
   {{0x60dc7013,0x63a9026a,0xfce67014,0x6b690138}},	//   _kirm, ğeni, _розо, _rūgš,
   {{0x68e202fd,0xe7ed00b6,0x63a93266,0x00000000}},	//   _vuod, चुला_, şeni, --,
   {{0x25be01d4,0xba261942,0xdc9b00a1,0xd7f800ae}},	//   ətli_, _адек, _קיבל, rbă_,
   {{0x645e14b1,0x6f030396,0xa3b60ed3,0x3946022e}},	//   _anpi, ânci, _जड़_, _tsos_,
   {{0x39463bf0,0xceb3040a,0xe0df0065,0x66040062}},	//   _usos_, שיר_, _asòn_, _deik,
   {{0xf75400e3,0x224b2e9c,0xc9770289,0x66de00e8}},	//   _منتج, _sack_, _בגדי_, _sīku,
   {{0x26c90028,0x35c70034,0x4423023b,0x224b54db}},	//   _thao_, रेज़, rgj_, _pack_,
   {{0x28c606ed,0x442d030b,0x645e7015,0x2003033b}},	//   _रीति, ře_, _enpi, _seji_,
   {{0x6a7c0257,0x21200063,0x442d03e3,0xd7ce0096}},	// [6dd0] _réfl, guih_, ƙe_, हेरच,
   {{0x9f580b0b,0x764d0188,0x6604029a,0x68ed0231}},	//   _será_, _haay, _zeik, _éade,
   {{0x224b070a,0x764d7016,0x60dc4e33,0x20cd0e94}},	//   _tack_, _kaay, _dirm, _džip_,
   {{0x60dc01ec,0xed590146,0xa7fc026a,0x764d010a}},	//   _eirm, _lyže_, rkıy, _jaay,
   {{0xed580a8d,0x764d1098,0x9f58222b,0x721a03c2}},	//   кої_, _maay, _verá_, _אורח,
   {{0x60dc7017,0x764d7018,0x66e8000d,0x32097019}},	//   _girm, _laay, _něko, laay_,
   {{0x9f580ba0,0xaca30134,0xeb35010d,0x66de01d3}},	//   _terá_, _ntụn, ارتخ, _mīks,
   {{0x66e8030b,0x764d701a,0x291f0350,0x00000000}},	//   _pěkn, _naay, tuua_, --,
   {{0x6604701b,0x6e29701c,0xaca30294,0x3a3f0085}},	//   _reik, _iceb, _atụn, reup_,
   {{0x6d49701d,0x798900a5,0x91bc00a1,0x66041d94}},	//   _isea, rzew, ומחי, _seik,
   {{0x764d701e,0x79890034,0x660400f3,0x3209041c}},	//   _baay, szew, _peik, kaay_,
   {{0x764d6ec9,0x89b40174,0x3ce40027,0x00000000}},	//   _caay, ịtọs_, _yumv_, --,
   {{0x6604701f,0x2240013f,0x764d008a,0xceb20266}},	//   _veik, veik_, _daay, מיט_,
   {{0xd8790076,0x00000000,0x00000000,0x00000000}},	//   _سمعت_, --, --, --,
   {{0x38780222,0x888300bf,0x6604593f,0x22401d82}},	//   örre_, _میکن, _teik, teik_,
   {{0x67217020,0x6d497021,0x614613f5,0x60dc7022}},	//   mulj, _osea, леба, _sirm,
   {{0x60dc6c85,0x22407023,0xd2a7004c,0x301a0076}},	// [6de0] _pirm, reik_, укте_, فتاة_,
   {{0x61ed0ef0,0x22403530,0x764d083e,0x00000000}},	//   acal, seik_, _zaay, --,
   {{0x6d497024,0x764d083e,0x60dc3c6f,0x61ef03a8}},	//   _asea, _yaay, _virm, _ffcl,
   {{0x61ed7025,0xdfcf00e3,0xfce619cb,0x127a0037}},	//   ccal, سين_, годо, _أحدث_,
   {{0x63a9042c,0x63be7026,0xdd905f34,0xa2b100a4}},	//   ßenv, _hypn, غوت_, ंवर्,
   {{0x1aeb00c7,0xafe30829,0x67215eb8,0x6e290372}},	//   _টিজে_, _горл, kulj, _eceb,
   {{0x6d49039f,0x6721015c,0x00000000,0x00000000}},	//   _esea, julj, --, --,
   {{0x672163e8,0x391401a0,0x00000000,0x00000000}},	//   dulj, амир, --, --,
   {{0x764d126e,0xf65f02b6,0x9806013f,0x00000000}},	//   _raay, llæg_, лянд, --,
   {{0x47343f1d,0x764d7027,0x61ed037a,0x67210357}},	//   анос, _saay, zcal, fulj,
   {{0x764d7028,0xf65f052f,0x66e802c6,0x3209008c}},	//   _paay, nlæg_, _věko, yaay_,
   {{0x7bc81386,0x61ed0314,0x45d505cb,0x3209008c}},	//   _izdu, xcal, ионс, xaay_,
   {{0xd90e0688,0x6d4f0072,0x25f433c5,0xb21b0537}},	//   _عید_, _ácat, ंड़ी_, _blæn,
   {{0x764d0694,0x67d40f30,0x2c7906a3,0x98a37029}},	//   _waay, _колу, _pèdi_, _личе,
   {{0xd25b6428,0xa3d50120,0x00000000,0x00000000}},	//   нца_, ровч, --, --,
   {{0xf65f08dc,0x5faf02d5,0x48fb030b,0xb713071c}},	//   dlæg_, _जुगल, लीको_, _ابوش,
   {{0x61ed702a,0x940a0092,0xb21b0537,0x00000000}},	// [6df0] rcal, hibə_, _flæn, --,
   {{0xf00b0019,0x629a014b,0xa5bb00b3,0x6e290090}},	//   _đẳng_, étor, ngóm, _sceb,
   {{0x2fc70222,0x61ed702b,0x00000000,0x00000000}},	//   ång_, pcal, --, --,
   {{0x5d551bd8,0x00000000,0x00000000,0x00000000}},	//   икет, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1bf0032,0xeb990e05,0x7bc8007f,0x1ee70e27}},	//   _iyá_, кил_, _bzdu, _موسی_,
   {{0x961d0033,0x3cf805db,0x00000000,0x00000000}},	//   ধ্যম_, _črve_, --, --,
   {{0x6d490080,0x6f03020a,0x6e2949c4,0x00000000}},	//   _tsea, âncu, _uceb, --,
   {{0x6d490084,0x290f0227,0x00000000,0x00000000}},	//   _usea, _qvga_, --, --,
   {{0x5d840080,0x290d702c,0x38b90036,0xdd740103}},	//   _الكل, rsea_, vèrs_, _دھمک,
   {{0x5ba70084,0xf771110a,0x290d702d,0x96660c59}},	//   _сраз, زاد_, ssea_, акне,
   {{0x6721702e,0x290d00ae,0xc4c90327,0x6d4f002b}},	//   rulj, psea_, _חג_, _ácas,
   {{0x05d0009d,0x920801d3,0x9f58015e,0xb21b0537}},	//   सेंब, ntāž, _terç_, _plæn,
   {{0x6721702f,0xdb1a00d8,0x00000000,0x00000000}},	//   pulj, _syté, --, --,
   {{0xe29a49a6,0xf1bf0139,0x64a314da,0xd7b9013c}},	//   вав_, _ayá_, цара, çədə_,
   {{0x63be025b,0xa8020555,0x00000000,0x00000000}},	//   _vypn, _çıra, --, --,
   {{0x6a7c033c,0x00000000,0x00000000,0x00000000}},	// [6e00] _défh, --, --, --,
   {{0x757b03c2,0x7e6000ec,0x2f560870,0x9c7c00e7}},	//   _סטיפ, _snmp, итес, _kiče,
   {{0xb4b204f1,0x661602c6,0xd2aa7030,0x63a9042c}},	//   टकी_, _kdyk, _акне_, ßent,
   {{0xb17b0222,0x2a6d03e5,0xed590141,0x69d60285}},	//   _igån, jjeb_, _brž_, मेडी,
   {{0x9c7c033b,0x62863f48,0xe3b2001c,0x00000000}},	//   _liče, _ilko, _درک_, --,
   {{0xed594582,0x8f76018a,0x00000000,0x00000000}},	//   _drž_, _кубі, --, --,
   {{0x2d807031,0x9c7c49d1,0xd8381e3a,0x8fa32f98}},	//   šie_, _niče, niče_, _даре,
   {{0x7bc81999,0x2a7f023e,0x940a00a7,0xa2cc02d5}},	//   _vzdu, gkub_, ribə_, _थीम्,
   {{0xc8665c84,0xd90d0260,0x5c1600b1,0x7e9c007e}},	//   атни, فین_, _نظار, sčps,
   {{0x9da500cd,0x6a7c020d,0xd838007e,0x00000000}},	//   _اصفه, _méfi, kiče_, --,
   {{0x6d4f10d9,0xaadf2231,0xd838007e,0x8b960b36}},	//   _ácar, _पंचक, jiče_, _трач,
   {{0xd83800b6,0x3ea67032,0x3cfd50da,0x00000000}},	//   diče_, nnot_, रीके_, --,
   {{0x443a7033,0x7ae8032e,0xe5c71f65,0x00000000}},	//   _bbp_, _hudt, рсно, --,
   {{0xb8cb00c7,0x68ed00e3,0x443a211d,0x656b01b9}},	//   _কী_, _éada, _cbp_, _àghm,
   {{0x443a061d,0x66e802c6,0x26c20094,0x00000000}},	//   _dbp_, _měkk, blko_, --,
   {{0x32641062,0xf00b00de,0x88bd007f,0x64587034}},	//   отув, _đằng_, puśc, _óvin,
   {{0x1bf80251,0x7c3a007e,0x3ea67035,0xdddb05db}},	// [6e10] ुराल_, _obtr, dnot_, _oluš,
   {{0x6a7c7036,0xd838025b,0x62867037,0x3cea0fef}},	//   _défi, biče_, _elko, _चढ़े_,
   {{0x60ce01b9,0xed590995,0x3f67441f,0x657d1175}},	//   _dhbm, _srž_, штаб, lysh,
   {{0xa2831e49,0x63bb03a3,0x4ea4013f,0x7c3a0364}},	//   _بیرو, ğund, орча, _abtr,
   {{0x067c006e,0x63bb0345,0xbd6b00e5,0x00000000}},	//   כנאל, şund, ърже_, --,
   {{0x308500e3,0x20850bf4,0xddc200e8,0x8af900a7}},	//   _السف, _السّ, ujoš, htəş,
   {{0xa3d700c0,0x7ae80441,0x920801d3,0x2a7f00aa}},	//   िधि_, _cudt, stāž, tkub_,
   {{0x76960138,0x9c7c05db,0xdb0e02c6,0x9f5300ee}},	//   ršyk, _riče, ídán, saxó_,
   {{0x6e3b7038,0xe9d9007b,0x00000000,0x00000000}},	//   _ibub, ыки_, --, --,
   {{0xac740080,0x7c2d1419,0x92e20081,0x657d0052}},	//   _والش, đars, নীয়_, dysh,
   {{0x25f440c1,0xe7390284,0x00000000,0x00000000}},	//   ंडली_, ћем_, --, --,
   {{0x443a00dc,0x8b9a00ca,0x9c7c015c,0xd83800d8}},	//   _sbp_, _גבעת, _viče, viče_,
   {{0x6e3b7039,0xaca30134,0x69cd0096,0x64e205d6}},	//   _mbub, _ndịo, देखी, पदेश,
   {{0xa9560105,0xd83800e9,0x69cb00e7,0x68fb703a}},	//   _לינק_, tiče_, _izge, mpud,
   {{0x6e3b0283,0xa3b5009f,0x637900ae,0xc7a2125c}},	//   _obub, _छुआ_, астр_, _нишк,
   {{0x27314af7,0xe2974447,0x6d5b009c,0x443a0381}},	//   mán_, бас_, _orua, _wbp_,
   {{0x2731703b,0x6d5b0197,0x21674064,0xd8380146}},	// [6e20] lán_, _nrua, бити_, siče_,
   {{0x6e3b0a75,0x76460407,0xd33600d3,0x291f0062}},	//   _abub, leky, _лэмы, irua_,
   {{0x27314ffa,0xef1a3e4b,0x547700ca,0x6d5b00aa}},	//   nán_, уме_, _הגיע_, _arua,
   {{0xdddb08a9,0x628602fd,0xe82102e8,0x6d5b703c}},	//   _sluš, _ulko, _माझा_, _brua,
   {{0x27310080,0x6d5b0091,0x7ae80036,0x325700ca}},	//   hán_, _crua, _sudt, _הסכם_,
   {{0x6e3b0129,0x76460124,0x2b4c0063,0x6d5b703d}},	//   _ebub, heky, _psdc_, _drua,
   {{0x7f860080,0x27314ce5,0x66df0138,0xe82110e9}},	//   _الأن, ján_, _būkl, _माजा_,
   {{0x2731703e,0xc33300a1,0x7bc10150,0x6d5b07ee}},	//   dán_, פוח_, _dylu, _frua,
   {{0x6d5b703f,0x200a01c2,0x6d4f0072,0xa3b500a3}},	//   _grua, _kebi_, _ácap, _छुई_,
   {{0x7ae80018,0x971409b9,0xb4b21592,0x2731003e}},	//   _tudt, омоц, टको_, fán_,
   {{0xb8ef0e72,0x2731119e,0x200a00dc,0xb21b003e}},	//   _वी_, gán_, _mebi_, _slæm,
   {{0x7c2a01df,0x466b0cf5,0x657d007b,0x9f587040}},	//   lgfr, уром_, tysh, _berú_,
   {{0xddc01820,0x6d400154,0x20186404,0xb5fb01cd}},	//   _lomž, _jpma, _odri_, fjár,
   {{0x657d074a,0xc91700a1,0x27310018,0x7c2a3341}},	//   rysh, _פחות_, bán_, ngfr,
   {{0x657d7041,0xd5ed0023,0x27312259,0xd6db0120}},	//   sysh, _toà, cán_, _йти_,
   {{0x46a40a28,0x78ba0106,0x6d401183,0x00000000}},	//   _најв, lotv, _opma, --,
   {{0x660f04eb,0x90990fa5,0x7ae27042,0x9fe700e3}},	// [6e30] mack, ават_, _miot, مساه,
   {{0x660f7043,0x7ae219d6,0x297b0089,0x6d5b0052}},	//   lack, _liot, אטמא, _rrua,
   {{0x200a7044,0x64557045,0x6d401dfc,0x64470051}},	//   _debi_, mdzi, _apma, meji,
   {{0x64477046,0x46c9007a,0xddc0033b,0x6d4001dc}},	//   leji, रतिह, _domž, _bpma,
   {{0x27317047,0x628d00e3,0x648900e7,0x69c20113}},	//   zán_, mhao, džiz, _nyoe,
   {{0x27317048,0x64557049,0x6447704a,0xf00b0023}},	//   yán_, ndzi, neji, _đặng_,
   {{0x78ba0477,0xb7b30033,0x6d40010a,0x6455704b}},	//   dotv, _ঘণ্ট, _epma, idzi,
   {{0x2731704c,0x6d5b704d,0x539c00c1,0x7ae2704e}},	//   ván_, _trua, טיוו, _ciot,
   {{0x3ebf06ee,0x6f07023e,0x644713bd,0x7ae20a00}},	//   _ikut_, _hwjc, keji, _diot,
   {{0x2731704f,0x48790747,0x645500a5,0x291f7050}},	//   tán_, рсия_, jdzi, rrua_,
   {{0xe7391b4d,0x68fb0234,0x64477051,0x660f0324}},	//   шен_, spud, deji, fack,
   {{0x27317052,0x9f587053,0x7ae27054,0x660f09ac}},	//   rán_, _perú_, _giot, gack,
   {{0x27317055,0x44ef01d4,0x3ead7056,0x99dd0031}},	//   sán_, _cü_, _mjet_, meňo,
   {{0x273106cf,0x7ae201e9,0x764601af,0x752601e9}},	//   pán_, _ziot, seky, rukz,
   {{0x68e30415,0x44ef7057,0x63a9042c,0x68eb01ab}},	//   _iind, _eü_, ßenp, _hugd,
   {{0x68e37058,0x2018005c,0x212004fa,0x442a0124}},	//   _hind, _sdri_, trih_, sgb_,
   {{0x68e3019e,0x32000167,0x81e20081,0x0ffa0037}},	// [6e40] _kind, rbiy_, নুন_, لعاب_,
   {{0x3ead3699,0x28cf0976,0x68e37059,0x394f0131}},	//   _ajet_, _सीमि, _jind, _msgs_,
   {{0x68e35c75,0x91e630fa,0x68eb0f5a,0xd838705a}},	//   _mind, _моне, _lugd, niča_,
   {{0x68e34f39,0x628d705b,0x200a705c,0x6a7c0113}},	//   _lind, chao, _webi_, _yéfu,
   {{0x7ae23521,0x395d705d,0x3ead00e7,0x8afc0034}},	//   _riot, _nrws_, _djet_, _kręg,
   {{0x68e3705e,0x9c7c705f,0x20180995,0x3ead0537}},	//   _nind, _biča, _udri_, _ejet_,
   {{0x78ba0880,0x7ae20034,0x80b92172,0xaff50103}},	//   votv, _piot, ्तरे, _رہنا_,
   {{0x68e37060,0x6284055b,0x645529aa,0xd83849a7}},	//   _aind, nkio, zdzi, diča_,
   {{0xfe4302ec,0xf2d3040a,0x48aa2f03,0x5ca6036a}},	//   _інфо, ועה_, итом_, _диаб,
   {{0x6a7c00fd,0xc19b006e,0x0b1a0037,0x395d00f0}},	//   _réfu, ישפי, _نقطة_, _drws_,
   {{0x7ae27061,0x67210039,0x9f58028d,0x3ead0052}},	//   _tiot, grlj, _perù_, _yjet_,
   {{0x68e30d50,0x645500a5,0x395d05bd,0xb90f0174}},	//   _eind, wdzi, _frws_, nanị_,
   {{0xd6d80a8d,0x68e37062,0xa3dd1462,0xfad700c1}},	//   ють_, _find, तेन_, _וואך_,
   {{0x68e37063,0x672100cc,0x6aa07064,0x645519db}},	//   _gind, brlj, limf, udzi,
   {{0x64557065,0x64477066,0x629f0808,0x628d7067}},	//   rdzi, reji, tiqo, thao,
   {{0x68e37068,0x44ef42dc,0x6728007e,0x2ee402ac}},	//   _zind, _tü_, mudj, _nimf_,
   {{0x628d363e,0x68e31621,0x629f7069,0x672814f3}},	// [6e50] rhao, _yind, riqo, ludj,
   {{0x660d00aa,0x628d706a,0x6ef3003d,0x6aa001c2}},	//   _heak, shao, _aħba, himf,
   {{0x660d0808,0x67280b18,0x6aa0024a,0x00000000}},	//   _keak, nudj, kimf, --,
   {{0x9c7c706b,0xf773021e,0x00000000,0x00000000}},	//   _riča, וקע_, --, --,
   {{0x3ead01e5,0x63ad0029,0x248c013f,0x224901e9}},	//   _vjet_, šinā, šimų_, meak_,
   {{0xe3df0f71,0x317a0054,0x224902a7,0x6d5d0088}},	//   _ব্যব, _הרשמ, leak_, _ásam,
   {{0x3ebf005c,0x68eb0009,0x21290063,0x6abb1022}},	//   _tkut_, _sugd, luah_, touf,
   {{0x6721706c,0x224901e9,0xd838706d,0xa3dd0096}},	//   vrlj, neak_, viča_, तेय_,
   {{0x6aa900bb,0xe5204eab,0x99dd0206,0x6abb706e}},	//   rnef, _बिधि_, reňo, rouf,
   {{0x6abb706f,0x68e3023b,0x62840a00,0x67210106}},	//   souf, _qind, zkio, trlj,
   {{0x68e3535f,0x629d3696,0x660d0125,0x22490634}},	//   _vind, _omso, _beak, keak_,
   {{0x7d097070,0x68e33794,0x6490007a,0x85170096}},	//   _kwes, _wind, _käig, _तिखट_,
   {{0x224902a7,0x660d42f0,0x7d0902a1,0x9c7c05db}},	//   deak_, _deak, _jwes, _mičn,
   {{0x9c7c215e,0x629d7071,0x7d0901e2,0x67210542}},	//   _ličn, _amso, _mwes, prlj,
   {{0x93597072,0x87040037,0x6728015c,0x7d090201}},	//   орту_, _قبيل, cudj, _lwes,
   {{0xc7b2040a,0x224901e9,0x7d093944,0xe297263d}},	//   _רבה_, geak_, _owes, пас_,
   {{0x66e8030b,0x21675e59,0xaca30065,0x62842c6f}},	// [6e60] _děku, пити_, _awọn, rkio,
   {{0x82360018,0x90c30084,0x3dd10033,0x2ee400b3}},	//   _کردا, ебуе, িশাল, _simf_,
   {{0x76567073,0x224901e9,0x7d0900ca,0x00000000}},	//   _kayy, beak_, _awes, --,
   {{0x21292c09,0xddcf16a1,0x76567074,0x491c009f}},	//   buah_, _šeše, _jayy, _मिलो_,
   {{0x78a10088,0x7d090150,0x00000000,0x00000000}},	//   kilv, _cwes, --, --,
   {{0x653b00c1,0x76560022,0x941100a7,0x394d0f5a}},	//   מענד, _layy, fizə_, dwes_,
   {{0x3af100de,0x5f270829,0x7d097075,0xdb080345}},	//   _cáp_, _норм_, _ewes, _ölür,
   {{0x32120124,0x3a2d2f91,0x00000000,0x00000000}},	//   nayy_, ggep_, --, --,
   {{0x7d090150,0x649000bc,0x6aa00169,0x00000000}},	//   _gwes, _käid, rimf, --,
   {{0xb0be0be4,0x50be06ed,0x660d7076,0x67280078}},	//   ्तिग, ्तिष, _seak, tudj,
   {{0x660d0006,0x76560a75,0x66e8030b,0x99e61612}},	//   _peak, _bayy, _někt, _ежед,
   {{0x224901e9,0x00000000,0x00000000,0x00000000}},	//   xeak_, --, --, --,
   {{0x67282c57,0x765603e3,0x78a10a1f,0x80be32f6}},	//   sudj, _dayy, bilv, ्ताइ,
   {{0xb9db0054,0x64901d2d,0x176a0b1e,0x660d7077}},	//   _החדש, _näid, _грип_, _weak,
   {{0x083b028c,0x224902a7,0x76560d2a,0x752800a5}},	//   _העול, teak_, _fayy, ądza,
   {{0xe8df0019,0x7656006d,0x212909a4,0x00000000}},	//   ược_, _gayy, tuah_, --,
   {{0x22490a00,0x66280094,0x769600c6,0x9c7c0206}},	// [6e70] reak_, šské, ršyt, _ničo,
   {{0x21290332,0x76560d2a,0x22490634,0x7d090079}},	//   ruah_, _zayy, seak_, _rwes,
   {{0x212908d3,0x3f877078,0x7d09063d,0x76560022}},	//   suah_, ánu_, _swes, _yayy,
   {{0x629d1d75,0x3f8f00a5,0x7d097079,0x3af10023}},	//   _umso, ągu_, _pwes, _ráp_,
   {{0x3f8704a3,0x3af10023,0x9c7c00c4,0x6457707a}},	//   šnu_, _sáp_, _vičn, _kaxi,
   {{0xd7e60080,0xea630018,0x4338001c,0x645701ee}},	//   _لك_, کھئی, _بسیج_, _jaxi,
   {{0x6a7c00fd,0x00000000,0x00000000,0x00000000}},	//   _réfr, --, --, --,
   {{0xe8f93a6f,0x94110092,0x7d093834,0x64573d54}},	//   оли_, rizə_, _twes, _laxi,
   {{0x81b100c7,0x443302e5,0x6ba60092,0x76560063}},	//   য়ের_, _ocx_, _əsgə, _rayy,
   {{0x7656707b,0x7e7b02c6,0x9f5a034f,0x00000000}},	//   _sayy, _houp, capó_, --,
   {{0x7e7b707c,0x765600f9,0xc5f401c2,0x7e690b97}},	//   _koup, _payy, _laɓe_, _knep,
   {{0x765602e7,0xe5a6707d,0x7e7b707e,0xd0160033}},	//   _qayy, дими, _joup, ালয়_,
   {{0x6b83707f,0x7e7b0154,0x645726ff,0x78a14638}},	//   lyng, _moup, _baxi, pilv,
   {{0xd942142f,0x765603e3,0x64570161,0x7e7b7080}},	//   _реши, _wayy, _caxi, _loup,
   {{0x645701d4,0xa3d800a5,0x76567081,0xfd560129}},	//   _daxi, ़ें_, _tayy, _babị,
   {{0x7e7b274b,0x00000000,0x00000000,0x00000000}},	//   _noup, --, --, --,
   {{0x64577082,0x61f67083,0x00e601b3,0x8afc007f}},	// [6e80] _faxi, rcyl, джан, _kręc,
   {{0xf42500c7,0xeb0d0251,0xc5f401c2,0x7e69039f}},	//   ম্বর_, _सबूत_, _daɓe_, _anep,
   {{0x649000aa,0x7e7b1bf0,0xdd8f015a,0x81b10033}},	//   _väid, _boup, یوم_, য়েল_,
   {{0x7e7b0e6c,0x0dca022a,0xe1f20452,0xdfcf0037}},	//   _coup, олей_, _جسد_, جيم_,
   {{0x649000aa,0x4103008f,0x66fa00bd,0x6457013c}},	//   _täid, _изяв, _iċke, _yaxi,
   {{0x44f40084,0x6fd605cd,0x6b830150,0x2013016d}},	//   _mä_, _भरपू, fyng, caxi_,
   {{0x6b8302ad,0x22420063,0x649000aa,0xc5f40044}},	//   gyng, _kbkk_, _käib, _zaɓe_,
   {{0xf1bf00e3,0x5a34008f,0x7e7b014b,0x38607084}},	//   _gcás_, хнит, _goup, _şir_,
   {{0x44f41531,0xb52000b6,0x00000000,0x00000000}},	//   _nä_, _बिषय_, --, --,
   {{0x7d021921,0x9c7c0335,0x7e7b0072,0x7e690094}},	//   mpos, _kičm, _zoup, _znep,
   {{0x7d020ee6,0x3ce70fef,0x7e7b7085,0x6457026d}},	//   lpos, _छूटे_, _youp, _raxi,
   {{0xc5f9007a,0x64570188,0x00000000,0x00000000}},	//   ंडेय_, _saxi, --, --,
   {{0x7d027086,0x44337087,0xb4e91fbb,0x00000000}},	//   npos, _pcx_, यदे_, --,
   {{0x44f47088,0x7d020a39,0xd7ef7089,0xf1d500b6}},	//   _dä_, ipos, _ју_, _दरबन,
   {{0x18330037,0x6457002b,0x7d020167,0x224201ff}},	//   _شروح, _vaxi, hpos, _bbkk_,
   {{0x27384b1f,0x64570188,0x320f0103,0x60f95309}},	//   mén_, _waxi, úgy_, зная_,
   {{0x7d02708a,0x7e7b48f0,0x22420063,0x2738708b}},	// [6e90] jpos, _roup, _dbkk_, lén_,
   {{0x6fa0000f,0xd0110f43,0x7e7b708c,0xd7f8002d}},	//   _गेहू, الا_, _soup, ncă_,
   {{0x7e7b708d,0x2738708e,0x2fc7052f,0x9f5001cd}},	//   _poup, nén_, æng_, ðaði_,
   {{0x05d300c3,0x44310072,0xdde20141,0x00000000}},	//   _सराब, lgz_, _šušt, --,
   {{0x7d02708f,0x849800cd,0x1d090326,0x628f0036}},	//   gpos, _رئیس_, чели_, _ilco,
   {{0x64900006,0x27380260,0x6b833dc0,0x7e7b0154}},	//   _täie, kén_, tyng, _woup,
   {{0x4fc452de,0x7e7b06a3,0x27380018,0xce95013d}},	//   _аста, _toup, jén_, _завъ,
   {{0x201101c8,0x27382c31,0x00000000,0x00000000}},	//   _hezi_, dén_, --, --,
   {{0x9f4a0065,0x201100e7,0x225900d7,0x00000000}},	//   _agbè_, _kezi_, _mask_, --,
   {{0x20110c56,0x81b10033,0xf092006e,0x9c7c0141}},	//   _jezi_, _ওরা_, ָנט_, _ličj,
   {{0x3946040c,0x20117090,0x273804c6,0x387c0036}},	//   _epos_, _mezi_, gén_, _dovr_,
   {{0x28cf000f,0xb4d8000f,0x20110060,0xd7f800ae}},	//   _सीरि, िष्_, _lezi_, acă_,
   {{0x3eaf0037,0x6acb0285,0x63bb013c,0xd9454688}},	//   ingt_, ातीर, şunl, _чели,
   {{0x273842cd,0x20112a1f,0x9f41037a,0x44f45995}},	//   bén_, _nezi_, nchó_, _vä_,
   {{0x2738167e,0x7d027091,0x21393177,0x44f4058f}},	//   cén_, zpos, _aqsh_, _wä_,
   {{0x7d027092,0x44f47093,0x98a400e8,0xd04a013c}},	//   ypos, _tä_, mumā_, ənəv,
   {{0x95560080,0x26c27094,0x76440193,0xe2970235}},	// [6ea0] _أخبا, moko_, _ibiy, хат_,
   {{0x1fb67095,0x26c27096,0x628f7097,0xb21b052f}},	//   нсер, loko_, _elco, _blæs,
   {{0x44441071,0x03a62064,0x7d1b7098,0x20110383}},	//   _ib_, _чино, _avus, _dezi_,
   {{0x81e200c7,0x444429cb,0x7d0202e6,0x26c27099}},	//   নুষ_, _hb_, tpos, noko_,
   {{0x2738045e,0xdca6322c,0x764400bf,0x444432e8}},	//   zén_, нади, _mbiy, _kb_,
   {{0xa80201d4,0x98a40029,0x26c2709a,0x644e709b}},	//   _çıxa, kumā_, hoko_, nebi,
   {{0x26c2709c,0x98a40029,0x7d02361a,0x44440133}},	//   koko_, jumā_, spos, _mb_,
   {{0x644e709d,0x6564265b,0x26c2709e,0xdee308f9}},	//   hebi, _orih, joko_, _боси,
   {{0x4444709f,0x26c270a0,0x644e70a1,0xd90d0260}},	//   _ob_, doko_, kebi, قین_,
   {{0x27380fea,0x764470a2,0x8b960f99,0x644e70a3}},	//   tén_, _abiy, _преч, jebi,
   {{0x569570a4,0xd7f800d3,0x9c7c0559,0x26c2010a}},	//   вант, rcă_, _ličk, foko_,
   {{0x444470a5,0x273870a6,0xd7f8002d,0x645c70a7}},	//   _ab_, rén_, scă_, edri,
   {{0x225970a8,0x39460270,0x444470a9,0x9c7c05db}},	//   _rask_, _upos_, _bb_, _ničk,
   {{0x644e70aa,0x764410df,0x9f4a0af0,0x645c0381}},	//   gebi, _ebiy, _egbé_, gdri,
   {{0xb86509e5,0xd3242917,0x98a400d9,0x32670138}},	//   _جانو, льти, cumā_, нтав,
   {{0x656416f4,0xd2581c76,0x201102f1,0x26c24379}},	//   _frih, нцу_, _sezi_, coko_,
   {{0x2b5200a5,0xdc3c00e7,0x644e70ab,0x225914e3}},	// [6eb0] łych_, _ašči, bebi, _vask_,
   {{0xd91b00f5,0x644e70ac,0x655600ca,0x444406e5}},	//   פובל, cebi, _סבתא_, _gb_,
   {{0x201170ad,0x4ab2007d,0xceeb09b4,0x442101f7}},	//   _vezi_, ुकाव, سران_, _idh_,
   {{0x9f5870ae,0x765d052f,0x531a00c1,0x444470af}},	//   _però_, ndsy, _קורצ, _zb_,
   {{0x320970b0,0x760c00c1,0xa3f502d5,0x44210031}},	//   mbay_, פּאַ, _आलाप_, _kdh_,
   {{0x7d1c0029,0x212970b1,0x6aa20065,0x26c270b2}},	//   _ārst, mrah_, _amof, zoko_,
   {{0x26c21ba4,0xdfd401b6,0x64455605,0x5fc50096}},	//   yoko_, _боры, _mbhi, _वडिल,
   {{0x644e70b3,0x3209041c,0x7d1b00e7,0xb4bd0d77}},	//   zebi, nbay_, _tvus, इकु_,
   {{0x6e946135,0x644e01e8,0x26c20062,0xb60402c6}},	//   _ситу, yebi, voko_, ndář,
   {{0x21290808,0x644e0a00,0x395f70b4,0x44210106}},	//   irah_, xebi, rvus_, _ndh_,
   {{0x320900a6,0x26c23d1f,0x644e0412,0x212959ba}},	//   kbay_, toko_, vebi, hrah_,
   {{0x656470b5,0x644570b6,0x4421151d,0x2ca770b7}},	//   _prih, _abhi, _adh_, lind_,
   {{0x26c21260,0x644e70b8,0x212914f7,0x3209008c}},	//   roko_, tebi, jrah_, dbay_,
   {{0x61fd70b9,0x44443bf4,0x2ca700d3,0x9c7c00e7}},	//   _afsl, _qb_, nind_, _ričk,
   {{0x645c30e2,0x26c24ecc,0x7aeb0124,0xe3b8028e}},	//   rdri, poko_, _kigt, çı_,
   {{0x44440197,0x7afc0068,0x2ca770ba,0x644e70bb}},	//   _wb_, _érte, hind_, sebi,
   {{0x2ca75c63,0x21290821,0xc5f403e3,0x3ea600c2}},	// [6ec0] kind_, grah_, _gaɓa_, viot_,
   {{0x444470bc,0x7aeb70bd,0x42c40081,0x6445009c}},	//   _ub_, _ligt, ্দেশ, _gbhi,
   {{0xe29a1f47,0xee3a3277,0x6d490072,0x21292fc5}},	//   _жан_, дне_, _apea, arah_,
   {{0x26c302e6,0x787e030b,0x21293510,0x0d8644f3}},	//   čkog_, _závě, brah_, клен,
   {{0x3ea670be,0xa2bf0469,0x6458003e,0x2ba71203}},	//   riot_, वकर्, _óvis, _केबा,
   {{0x9f58003e,0x0316009f,0x9c7c007e,0x53d60179}},	//   _ferð_, _तबाह_, _kiči, _धराश,
   {{0x7aeb70bf,0x9f580088,0x6d4901e9,0x8fa60915}},	//   _bigt, _gerð_, _epea, _раве,
   {{0x69cb0185,0xab83283b,0x67282a6c,0x9c7c0aa8}},	//   _byge, рушк, vrdj, _miči,
   {{0x7aeb70c0,0x2ca70f5a,0x9c7c191d,0x7c210154}},	//   _digt, bind_, _liči, _fdlr,
   {{0x2bbb0251,0x2ca770c1,0xc5f401c2,0x81b10033}},	//   _ऊँचा, cind_, _raɓa_, য়েক_,
   {{0x32091331,0x9c7c45ca,0xc5f40022,0x21290063}},	//   ybay_, _niči, _saɓa_, zrah_,
   {{0x442170c2,0x644500f9,0x47330018,0x752f0034}},	//   _sdh_, _sbhi, گریز, tucz,
   {{0xa2d3007a,0x385709b4,0xa2b800d2,0x68ea02a1}},	//   _भीष्, رشید_, ्कन्, _tifd,
   {{0x3af870c3,0x9c7c0138,0x98a3001f,0xe3b30103}},	//   _kép_, _biči, _киче, لرز_,
   {{0xa3dd02b0,0xd49870c4,0x6445037a,0x753d6053}},	//   तें_, тря_, _vbhi, stsz,
   {{0x212970c5,0x9c7c015c,0xd838110e,0x7aeb0188}},	//   trah_, _diči, diči_, _xigt,
   {{0x320970c6,0x6ef302a1,0xb5fb0072,0x3af870c7}},	// [6ed0] rbay_, _iħbi, rdád, _lép_,
   {{0x66df5873,0x44210096,0x94180092,0x320970c8}},	//   _tūks, _udh_, kirə_, sbay_,
   {{0x2ca770c9,0x21290498,0xdb1e0257,0x6d4900a1}},	//   vind_, srah_, _évèn, _spea,
   {{0x2ca70849,0x9f580088,0x21292253,0xb21b003e}},	//   wind_, _verð_, prah_, _glæp,
   {{0x7aeb70ca,0x2ca72f34,0x1d342f34,0x26c90a4b}},	//   _rigt, tind_, инця, _mkao_,
   {{0x6acb0c9c,0x7aeb70cb,0x69cb052f,0x649000aa}},	//   ात्र, _sigt, _ryge, _läin,
   {{0x2ca770cc,0x447c0130,0x69cb052f,0x7aeb00f9}},	//   rind_, ונגע, _syge, _pigt,
   {{0x2ca770cd,0x64900673,0x3af800de,0xddc90078}},	//   sind_, _näin, _dép_, _koeż,
   {{0x7aeb0021,0x2d99004d,0x2ca770ce,0x6d4900c2}},	//   _vigt, _åse_, pind_, _upea,
   {{0xd7090084,0x69cb0094,0x2ca70216,0x7aeb02ac}},	//   нное_, _vyge, qind_, _wigt,
   {{0x16aa0ac6,0x3af80103,0x7aeb0009,0x00000000}},	//   евни_, _gép_, _tigt, --,
   {{0xb80304f8,0x69cb70cf,0x00000000,0x00000000}},	//   _श्रम_, _tyge, --, --,
   {{0xa3e602d5,0x5e56006e,0x00000000,0x00000000}},	//   बेन_, נישע_, --, --,
   {{0x6aa910ec,0x2eed5d73,0x9c7c0095,0x92b00033}},	//   lief, _lief_, _piči, _ওঠে_,
   {{0x60c50167,0xd05c013c,0x3af8020b,0x798906b0}},	//   dohm, _girə, _xép_, lyew,
   {{0x628d11b9,0xb2950291,0xd83805db,0x00000000}},	//   gkao, ајућ, viči_, --,
   {{0x412770d0,0xe0da2156,0x7989068d,0x7d0400d9}},	// [6ee0] лото_, ева_, nyew, ģisk,
   {{0x459b028c,0x6aa970d1,0x66164ef7,0x071724eb}},	//   _נסיע, hief, _heyk, _दबाव_,
   {{0xe4570130,0x645e0009,0x3dcd01c2,0x2eed02ac}},	//   _גייט_, _iapi, _ayew_, _bief_,
   {{0x645e70d2,0xdb1e025a,0x443a05bd,0x42561b10}},	//   _hapi, _évén, _hcp_, _стот,
   {{0x63b60029,0xd8380146,0x2eed1570,0x98a400c6}},	//   šanā, siči_, _dief_, lumą_,
   {{0x6adc70d3,0x10a60752,0x645e00dd,0xd8386dad}},	//   मग्र, _сигн, _japi, piči_,
   {{0x645e70d4,0x201a00f9,0x2ba70f82,0xb5fb00d4}},	//   _mapi, mapi_, _केदा, ndác,
   {{0x201a2846,0x6f030428,0xdd160281,0x661602ac}},	//   lapi_, ínce, _مورخ, _neyk,
   {{0xcc361915,0xd83a00ae,0x443a0503,0xb4db00ee}},	//   _مراع, нэн_, _ocp_, ntàc,
   {{0x645e70d5,0x31570054,0x3af800fe,0x201a2c31}},	//   _napi, ניין_, _tép_, napi_,
   {{0xb86600cd,0xc6000033,0x6490007b,0x661670d6}},	//   ناگو, ্ণনা_, _päin, _beyk,
   {{0x41b40096,0x645e70d7,0x798906b0,0x201a49dd}},	//   ंपास, _aapi, byew, hapi_,
   {{0x201a042b,0x443a00fd,0x645e0b58,0xe1ff0034}},	//   kapi_, _bcp_, _bapi, _znów_,
   {{0x645e29b0,0x66d63e43,0x00000000,0x00000000}},	//   _capi, ráka, --, --,
   {{0x201a06ee,0x645e02c9,0xf53f017a,0x439407b3}},	//   dapi_, _dapi, stå_, барс,
   {{0x68ed00e3,0x92581b10,0x67000129,0x443a0231}},	//   _éadr, ласт_, _ịkwa, _ecp_,
   {{0x7c3a70d8,0x2eed042c,0x1da430a8,0x645e00eb}},	// [6ef0] _octr, _rief_, _खेलत, _fapi,
   {{0x645e70d9,0x201a70da,0x443a00dc,0x67010174}},	//   _gapi, gapi_, _gcp_, ịket,
   {{0x23fa00a1,0x20d40084,0x60c570db,0x14b809f9}},	//   _בהתא, päin_, rohm, _حديث_,
   {{0x645e6eb0,0xd8382d5a,0xed590d62,0x9c7c374d}},	//   _zapi, miču_, _psž_, _miču,
   {{0xa3a9116e,0xed5908f9,0x645e70dc,0x2b4c00ee}},	//   _खेत_, тол_, _yapi, _apdc_,
   {{0x201a1124,0x649000c2,0x99dd00b6,0x1da400a4}},	//   capi_, _näil, zeňs, _खेळत,
   {{0x6aa90b77,0x3f87007a,0x2eed0364,0x75280034}},	//   tief, änud_, _tief_, ądzi,
   {{0xca85028d,0xa9251456,0x00000000,0x00000000}},	//   ргий, адил, --, --,
   {{0x66160102,0x6aa970dd,0x2b4c00dc,0xc5f40022}},	//   _reyk, rief, _epdc_, _saɓo_,
   {{0xa3b570de,0x798903e3,0x6d5b0027,0x2d9d0027}},	//   जपा_, ryew, _isua, mzwe_,
   {{0xe7390831,0xf7454a4e,0x81ce0033,0x4a7500ae}},	//   њем_, шено, ষেপ_, _вылт,
   {{0x645e70df,0x6b7a0130,0xd5e62edd,0x9c7c0154}},	//   _sapi, _ברענ, ижни, _chčf,
   {{0x2d9d092f,0x15ba01b6,0xc8b431bb,0x80ba1e18}},	//   nzwe_, тыны_, _گلوک, ्वमे,
   {{0x2aba01d3,0xc5f403e3,0x37e51b60,0x69d9063d}},	//   mība_, _taɓo_, _колг, _izwe,
   {{0x63833c1a,0xc7a21bf9,0x2aba01d3,0x201a04e9}},	//   огра, _мишк, lība_, vapi_,
   {{0x645e0010,0x602800d9,0x98a40138,0x6b600103}},	//   _wapi, zīmē, rumą_, lágá,
   {{0x201a10f3,0x2aba00d9,0x66d61e80,0xe1f73947}},	// [6f00] tapi_, nība_, láko, ргу_,
   {{0x6e3b002b,0x60260f5f,0x649000aa,0xa494001c}},	//   _acub, рджа, _käim, _ایست,
   {{0x547b00a1,0x3246120a,0x41d50cce,0xb4c41e93}},	//   _סטטו, _кенг, _दरअस, ौती_,
   {{0x201a70e0,0xdfcf00e3,0xcd0611d9,0x1d0a1360}},	//   sapi_, ذين_, ачки, веди_,
   {{0x66d6488f,0x00000000,0x00000000,0x00000000}},	//   háko, --, --, --,
   {{0xc7b80106,0x2aba01d3,0xd0070156,0x6e3b063d}},	//   lađe_, dība_, _вере_, _ecub,
   {{0x201827db,0x66dd0018,0x92d80081,0x69d970e1}},	//   _ieri_, léke, াদী_, _azwe,
   {{0xe8df00ef,0x64900d80,0x201870e2,0xc7b80335}},	//   ước_, _säil, _heri_, nađe_,
   {{0x5ecc0033,0xed570b2f,0x14c605d6,0x00000000}},	//   িষদে, _кот_, लकाण, --,
   {{0x2018283d,0x7e6014a5,0x2ba704f1,0x7e622e7c}},	//   _jeri_, _hamp, _केवा, ldop,
   {{0xb8fd0d1b,0x501b0054,0x201870e3,0x69d90201}},	//   _थी_, כויו, _meri_, _ezwe,
   {{0x21200979,0x44380150,0x7bda50ba,0x38690044}},	//   ksih_, egr_, _iztu, _ɗari_,
   {{0x7e6010e3,0x2aba00d9,0xaae50dce,0x6d4270e4}},	//   _mamp, cība_, _اسلو, ntoa,
   {{0x442d02e2,0xd8380039,0x201870e5,0x6d42140e}},	//   ße_, tiču_, _neri_, itoa,
   {{0x93881191,0xa87b006e,0x61ec0092,0xd7ef1339}},	//   аста_, _באגר, ənlə, _фу_,
   {{0x7e6070e6,0x442d70e7,0x2018015e,0xa80303e0}},	//   _namp, şe_, _aeri_, _çırp,
   {{0x661d70e8,0x201857bd,0x51f8055b,0x9f4a0032}},	// [6f10] mask, _beri_, рную_, _agbà_,
   {{0xdb1a0257,0x6d4270e9,0x7e600270,0x29060051}},	//   _exté, dtoa, _aamp, _mtoa_,
   {{0x201870ea,0x6d5b005c,0x645570eb,0x7e6070ec}},	//   _deri_, _ssua, mezi, _bamp,
   {{0x44fd70ed,0x645570ee,0x2ef804e2,0x20180f4c}},	//   _kì_, lezi, _durf_, _eeri_,
   {{0x7e6070ef,0x44fd70f0,0x63bb03a3,0x201870f1}},	//   _damp, _jì_, ğunu, _feri_,
   {{0x44fd1610,0x645570f2,0x201870f3,0x661d3c21}},	//   _mì_, nezi, _geri_, hask,
   {{0x44fd70f4,0x1fe500c7,0x7e60030a,0x2001698f}},	//   _lì_, _প্রস, _famp, mchi_,
   {{0x6d5b01bb,0x7e60072f,0x13b800a1,0x291f6bb4}},	//   _tsua, _gamp, יהול_, tsua_,
   {{0x44fd0d79,0x1c0b1827,0x2018008e,0x6d5b411b}},	//   _nì_, _स्थल_, _yeri_, _usua,
   {{0x200170f5,0x645570f6,0x291f68a8,0x7e6070f7}},	//   nchi_, jezi, rsua_, _zamp,
   {{0x7e60646a,0x66dd01f9,0x2aba00e8,0x291f3e78}},	//   _yamp, zéke, sība_, ssua_,
   {{0x661d341b,0x7e6070f8,0x44fd1baa,0x66d670f9}},	//   gask, _xamp, _bì_, ráko,
   {{0x645570fa,0xddcb0034,0xaca3020b,0x443801ff}},	//   fezi, legł, _ngừo, tgr_,
   {{0x44fd70fb,0x645570fc,0x66dd0018,0xe73918d4}},	//   _dì_, gezi, véke, _бек_,
   {{0x66e6580c,0x68f90381,0xe29a4c89,0x64a370fd}},	//   _лока, _huwd, гав_, чара,
   {{0x66dd0068,0x201870fe,0x272308bb,0x75e10134}},	//   téke, _seri_, mın_, _ịzen,
   {{0x7e603a86,0x44fd00ef,0x272307d1,0x645570ff}},	// [6f20] _ramp, _gì_, lın_, bezi,
   {{0x212006ee,0x81bc00c7,0x7e607100,0x6455008f}},	//   rsih_, েইল_, _samp, cezi,
   {{0x27237101,0x20187102,0x2a7f5aa9,0x7e600d18}},	//   nın_, _veri_, kjub_, _pamp,
   {{0xc3330054,0x7e620113,0xb4db0428,0x8c140033}},	//   _צור_, udop, ntàn, _সাইন_,
   {{0xf7670434,0x7bda0067,0x20187103,0x27230740}},	//   _کا_, _sztu, _teri_, hın_,
   {{0x40960080,0x2001013d,0x27231001,0x6ab20d88}},	//   _السر, cchi_, kın_, ुक्र,
   {{0xa3e005d4,0x62867104,0x6d427105,0x66047106}},	//   _तरफ_, _koko, stoa, _ofik,
   {{0x272306d7,0x64557107,0x62867108,0x6d427109}},	//   dın_, zezi, _joko, ptoa,
   {{0x661d254d,0x6286004b,0x6455710a,0xdee300c2}},	//   vask, _moko, yezi, _хоти,
   {{0x628613e8,0x6604710b,0x44fd026e,0x661d117e}},	//   _loko, _afik, _rì_, wask,
   {{0x44fd0649,0x661d710c,0x7bda00d9,0x7524710d}},	//   _sì_, task, _uztu, _aviz,
   {{0x6455710e,0x628600f3,0x395d0090,0x2b5e03a8}},	//   wezi, _noko, _fsws_, _istc_,
   {{0x6455710f,0xf1bf4c36,0x66dd0103,0xa3e61f88}},	//   tezi, _adán_, tékb, बेस_,
   {{0x44fd00ef,0x66046538,0x661d7110,0x27230491}},	//   _vì_, _efik, sask, bın_,
   {{0x64557111,0x62867112,0x7afa7113,0xd2d70037}},	//   rezi, _boko, _jutt, مغرب,
   {{0x44fd026e,0x7afa3611,0x64550201,0x7c2d01c2}},	//   _tì_, _mutt, sezi, ɗaru,
   {{0x64557114,0x7afa7115,0xe1f00037,0x764d7116}},	// [6f30] pezi, _lutt, فسك_, _ibay,
   {{0x26cb7117,0x656d7118,0x6490007b,0x64550216}},	//   loco_, _irah, _näih, qezi,
   {{0x2001013d,0x7afa7119,0x62860018,0x9df9711a}},	//   rchi_, _nutt, _foko, анет_,
   {{0x2001711b,0x656d00dd,0x7c2800a1,0x316b00c4}},	//   schi_, _krah, _addr, _trcz_,
   {{0x27230702,0x823a0130,0x764d4545,0x7afa0084}},	//   zın_, _דערצ, _mbay, _autt,
   {{0x27230702,0xa3bd02e8,0x7afa711c,0x0f1b0018}},	//   yın_, _अशा_, _butt, _مغرب_,
   {{0xeb99711d,0xddc9025b,0x27230092,0x62862b43}},	//   рий_, _dneš, xın_, _yoko,
   {{0x7afa711e,0x656d08c5,0x2249005c,0x6490007a}},	//   _dutt, _orah, nfak_, _päik,
   {{0xe8f62787,0x6e290294,0xc9850037,0xdddb05db}},	//   олы_, _ideb, تشغي, _fouš,
   {{0x3eaf711f,0x7d040029,0x27230702,0x64900006}},	//   ligt_, ģist, tın_, _väik,
   {{0xa3a90d1b,0x656d7120,0x75247121,0x7afa00f3}},	//   _खेल_, _arah, _sviz, _gutt,
   {{0x2723436c,0x656d7122,0x395d023e,0x3eaf4d12}},	//   rın_, _brah, _tsws_, nigt_,
   {{0x62860038,0xdce0002d,0x272308bb,0xb4db05fe}},	//   _roko, _urmă, sın_, rtàn,
   {{0x62867123,0x656d7124,0x272303a3,0xb4db05fe}},	//   _soko, _drah, pın_, stàn,
   {{0x628606e4,0x6e290640,0xaca300de,0x290d7125}},	//   _poko, _odeb, _huỳn, lpea_,
   {{0xb5fb7126,0x6e297127,0xa3a9009d,0x6604413e}},	//   ndál, _ndeb, _खेळ_, _ufik,
   {{0x3eaf7128,0x61430f16,0xe29700d3,0xe800052c}},	// [6f40] digt_, мета, цат_, लुका_,
   {{0x6e297129,0x6286712a,0xc7b80995,0x2ed22581}},	//   _adeb, _woko, lađa_, तत्त,
   {{0x6286712b,0x316900e7,0x66dd712c,0x656d05db}},	//   _toko, avaz_, léka, _zrah,
   {{0x82360688,0x7afa712d,0xddc9007e,0x6286712e}},	//   _بردا, _rutt, _sneš, _uoko,
   {{0xa3e60eeb,0x7d0900b3,0x649000c2,0xdce90078}},	//   बेर_, _ctes, _päih, _greċ,
   {{0x6e29712f,0xc7b800cc,0xa5c40139,0x7afa49fb}},	//   _edeb, hađa_, _gbóń, _putt,
   {{0x7d097130,0x46ca00a8,0xddc90141,0x66dd03a9}},	//   _etes, रवाह, _vneš, héka,
   {{0x7d090052,0x2c0a0033,0x66dd03a9,0x00000000}},	//   _ftes, রণেই_, kéka, --,
   {{0x26cb0036,0x9c7c0383,0x38650027,0x00000000}},	//   voco_, _chčc, fdlr_, --,
   {{0x7afa7131,0xb4c4033a,0xa49b06a3,0x656d023b}},	//   _tutt, एको_, npòt, _rrah,
   {{0x7afa0084,0xdc3c1528,0xe758004d,0x656d03a9}},	//   _uutt, _ašći, щині_, _srah,
   {{0x656d7132,0xc7b8084f,0x56940938,0xc5f40d2a}},	//   _prah, gađa_, дают, _zaɓi_,
   {{0xfaf800d9,0x7ae27133,0x66dd0113,0x95383ac9}},	//   _trīs_, _ihot, géka, озят_,
   {{0x656d0094,0xfbd10018,0x14cb007b,0x7ae2039f}},	//   _vrah, _آتے_, рыми_, _hhot,
   {{0xc7b81197,0x7ae20194,0x2249026a,0x69d6004d}},	//   bađa_, _khot, tfak_, _øyeb,
   {{0x656d7134,0x764d7135,0x3eaf02c3,0xdce9003d}},	//   _trah, _ubay, xigt_, _preċ,
   {{0x7ae20a02,0x656d214f,0xb5fb7136,0xef2f020b}},	// [6f50] _mhot, _urah, ndám, _đựoc_,
   {{0x80781b9d,0xe4d9001c,0xb5fb0103,0x7ae27137}},	//   обус_, _دوخت_, zdál, _lhot,
   {{0x7d097138,0x3eaf7139,0xa7fc0342,0x00000000}},	//   _stes, tigt_, ydın, --,
   {{0x7ae20174,0xe0df02f1,0xc5f403e3,0x82f80281}},	//   _nhot, _apòt_, _saɓi_, _گریز_,
   {{0x3eaf713a,0x41e73006,0x69aa02d5,0x427a0796}},	//   rigt_, _фіна, _जेली, _הארג,
   {{0x3eaf713b,0x7ae2713c,0x60fa00ca,0x4c8401b3}},	//   sigt_, _ahot, _להשק, млів,
   {{0xfd6406c0,0x7ae203ea,0x2b57001c,0xb18602c3}},	//   _karị, _bhot, تیاد_, _tvåå,
   {{0x7ae2713d,0x6e291042,0x7d0900bd,0x00000000}},	//   _chot, _udeb, _ttes, --,
   {{0x7d090160,0xf2d400c1,0xaca300de,0xc5f401c2}},	//   _utes, ועק_, _quỳn, _taɓi_,
   {{0x48790084,0xfd640294,0x3ebf0090,0xe8f60805}},	//   ссия_, _larị, _hjut_, яль_,
   {{0x7ae2713e,0x6490007a,0x3ead0141,0xa8220d83}},	//   _fhot, _käiv, _kmet_, رکون,
   {{0x7ae2713f,0x98ad02dd,0x2bc417ff,0xa7fc07e7}},	//   _ghot, mreč_, _लुटा, ldıl,
   {{0xc7b8042d,0x6abb024a,0x9f580120,0x00000000}},	//   rađa_, mnuf, _ifrå_, --,
   {{0x66dd00cd,0x3ebf0106,0x7ae20146,0xdf940139}},	//   réka, _ljut_, _zhot, _bọ́s_,
   {{0x6702148e,0xccf200ca,0x3ead7140,0xe296001f}},	//   _रूपक_, תכם_, _omet_, праќ,
   {{0xe61f0220,0x80d40034,0x7afe0575,0x6abb7141}},	//   skôr_, _बीजे, ípti, nnuf,
   {{0x27e20034,0x661602ef,0x26d20027,0x26c00139}},	// [6f60] ękne_, čakč, _ikyo_, _ijio_,
   {{0xd12f04f4,0x3ead2d8d,0x3ebf7142,0x7ae93785}},	//   امل_, _amet_, _ajut_, hmet,
   {{0x7ae97143,0xd4c508ba,0x3ebf02a1,0xe3b2015a}},	//   kmet, _تغيي, _bjut_, _سرد_,
   {{0xde031f0d,0x7ae95242,0xdfcf0190,0xe0df0154}},	//   епци, jmet, ديم_, _spòt_,
   {{0x7ae97144,0x00000000,0x00000000,0x00000000}},	//   dmet, --, --, --,
   {{0x3ead015e,0x7ae90629,0xdca32cd8,0x7ae23b5c}},	//   _emet_, emet, начи, _shot,
   {{0x7ae24a72,0xe81f007f,0x7ae90d87,0x00000000}},	//   _phot, _मज़ा_, fmet, --,
   {{0x7ae97145,0x9c7c009c,0x62840350,0x00000000}},	//   gmet, _dhča, njio, --,
   {{0x81ce00c7,0x3ea77146,0x22420063,0xc8c70285}},	//   ষের_, ënte_, _mckk_, रकंट,
   {{0x26c302e6,0x2db700c1,0x27f8038c,0x7ae97147}},	//   čkom_, _זלמן_, ørn_, amet,
   {{0x7ae201e5,0x16350a67,0x7ae97148,0x38a0009c}},	//   _thot, меня, bmet, _lòrg_,
   {{0x7ae97149,0xba170037,0x7b970266,0x78ba02ef}},	//   cmet, _فيما_, _מכבד_, sntv,
   {{0x95cb0231,0xb4db00b3,0x5507065c,0x00000000}},	//   суна_, stàm, ячна, --,
   {{0x26d20283,0x3ae10220,0x81e20033,0x6fbe0096}},	//   _ekyo_, rópe_, দশা_, ्थां,
   {{0x67d33ad2,0x6e22024a,0x2a6600bc,0xf8a9001c}},	//   _пошу, kaob, _kaob_, _بدنه_,
   {{0xd7bb00ca,0x6284023b,0x3264004d,0x354700ae}},	//   _לצור, gjio, нтув, _ехов,
   {{0xdce902dd,0x5187714a,0x64480428,0x66dd0103}},	// [6f70] _sreč, чува, òdic, léko,
   {{0xdce9714b,0x66df0138,0x3ead26c4,0xa5d80037}},	//   _preč, _rūky, _smet_, _عبير_,
   {{0x64900d64,0x4423155c,0x7ae9714c,0x661f0052}},	//   _päiv, maj_, ymet, _keqk,
   {{0xdce90087,0x02a7294a,0xa3bc0096,0x00000000}},	//   _vreč, _хром, ेअर_, --,
   {{0x3946023e,0x629d028d,0x7ae900b3,0x00000000}},	//   _nqos_, _ilso, vmet, --,
   {{0x4423714d,0xdce9013f,0x66dd00b6,0x2c6d0103}},	//   naj_, _treč, kéko, ködő_,
   {{0x26c302e6,0x66dd0018,0xa7fc07e7,0x4423020a}},	//   čkoj_, jéko, rdıl, iaj_,
   {{0x44230d7d,0xb3aa0081,0xe7d00557,0x68e3023b}},	//   haj_, _খুঁজ, _हड़प, _shnd,
   {{0x4423714e,0x7ae9714f,0x6abb224d,0x6efa030b}},	//   kaj_, rmet, rnuf, _vůbe,
   {{0x442305c5,0xb0bf2171,0x290b00d9,0x20bf0bba}},	//   jaj_, ्विग, īca_, ्विध,
   {{0xb9047150,0x229c0102,0x629d1d91,0x3f4709a1}},	//   _भी_, _líka_, _olso, nõu_,
   {{0x7c235bae,0x7d1b0294,0x7a360233,0x39ce0294}},	//   lanr, _kwus, rütü, ịzị_,
   {{0xa3e01085,0x20bf04f8,0x95830084,0x44237151}},	//   _तरह_, ्वाध, вляе, faj_,
   {{0x64904207,0x629d0126,0x673a7152,0xd84e0023}},	//   _näit, _also, butj, _họng_,
   {{0x673a05db,0x00000000,0x00000000,0x00000000}},	//   cutj, --, --, --,
   {{0x3a3f1359,0x7c2308d3,0x79960034,0x26c00239}},	//   ngup_, hanr, _żywi, _ujio_,
   {{0x76447153,0x056300d3,0xd84e00fe,0x00000000}},	// [6f80] _iciy, _авын, _mọng_, --,
   {{0x442303ce,0x65640201,0x92be0081,0x917a0023}},	//   caj_, _isih, ইতে_, _cấp_,
   {{0x645c5ff3,0xb4da0034,0xdfcf0037,0x6e227154}},	//   meri, ़ती_, ليك_, taob,
   {{0x645c7155,0x7bdc01b9,0x00000000,0x00000000}},	//   leri, _ùrui, --, --,
   {{0xfee90080,0x6e220a02,0xfe79030b,0xdca60284}},	//   أعلى_, raob, _dnů_, мади,
   {{0x16bb00aa,0x7c2301af,0x649000bc,0x6e22007e}},	//   _उद्ब, ganr, _täiu, saob,
   {{0x645c7156,0x44443d36,0x7d1b0372,0xd84e020b}},	//   ieri, _mc_, _ewus, _bọng_,
   {{0x44237157,0xa7fc03a3,0x63a30018,0xafe300d6}},	//   zaj_, rdım, _ünne, _росл,
   {{0xa8020b88,0x7c23662b,0x44237158,0xdd8f12eb}},	//   _çıka, banr, yaj_, _پول_,
   {{0x645c0a75,0x66dd0068,0x6e207159,0x7644715a}},	//   jeri, téko, _hemb, _aciy,
   {{0x4423715b,0x6e204b82,0x7d00715c,0x2a66715d}},	//   vaj_, _kemb, _hums, _taob_,
   {{0x44441a2e,0x6e20072f,0x7d00694c,0x44230034}},	//   _ac_, _jemb, _kums, waj_,
   {{0x6e20715e,0x44233624,0x645c451e,0x64900084}},	//   _memb, taj_, feri, _näis,
   {{0x6e205aa9,0x3a24715f,0x7d000f17,0x673a0052}},	//   _lemb, lamp_, _mums, putj,
   {{0x44237160,0x44447161,0x65640060,0x00000000}},	//   raj_, _dc_, _esih, --,
   {{0x59e20b94,0x44447162,0x6e207163,0x3867007e}},	//   _परार, _ec_, _nemb, _zanr_,
   {{0x44230b27,0x7c237164,0x7d007165,0x765d7166}},	// [6f90] paj_, yanr, _nums, mesy,
   {{0x645c7167,0xfe7000cd,0x6f1c030a,0x44443ff0}},	//   ceri, یدن_, _bwrc, _gc_,
   {{0x64457168,0x3a241b06,0x9f040fb7,0xb4bd1860}},	//   _ichi, kamp_, نولو, ेकी_,
   {{0x6e200da3,0x765d0150,0x2ec91d69,0x7d002bf6}},	//   _cemb, nesy, िकेत, _bums,
   {{0x6490007a,0x7c230539,0x6e207169,0x442166e5}},	//   _täit, tanr, _demb, _keh_,
   {{0xf41d0081,0x442139e3,0x64900fc4,0x6e200270}},	//   _তাঁর_, _jeh_, _häir, _eemb,
   {{0x4421716a,0x765d716b,0x64450239,0x6e203a30}},	//   _meh_, kesy, _mchi, _femb,
   {{0x4421025e,0xc1e3143d,0x6e2026f7,0x7c23716c}},	//   _leh_, _खराब_, _gemb, sanr,
   {{0x6445716d,0x7e7b716e,0xd84e0019,0x645c716f}},	//   _ochi, _inup, _vọng_, yeri,
   {{0x64451ee3,0x44217170,0x645c7171,0x6e203581}},	//   _nchi, _neh_, xeri, _zemb,
   {{0x765d5067,0x645c0bb0,0x7e693642,0xe8000034}},	//   fesy, veri, _kaep, ोड़ा_,
   {{0x64457172,0xeb9607a6,0x645c7173,0xa5bb7174}},	//   _achi, _אדער_, weri, raón,
   {{0x753d0068,0x44217175,0x44446c29,0x2d497176}},	//   gusz, _beh_, _pc_, núe_,
   {{0x44447177,0xb4da0cce,0x64450036,0x26100469}},	//   _qc_, ़ते_, _cchi, _थ्री_,
   {{0x444400c9,0xe81502e8,0xfddc0455,0x4421009d}},	//   _vc_, _द्या_, _बर्फ, _deh_,
   {{0x64457178,0x44217179,0x28ab0179,0x4444717a}},	//   _echi, _eeh_, टोरि, _wc_,
   {{0x6e20717b,0x59d50006,0x00e65cf7,0x65644100}},	// [6fa0] _remb, _डुमर, ежан, _usih,
   {{0x6e20717c,0x7e7b00a6,0x69d93ed7,0x645c023b}},	//   _semb, _anup, _mywe, qeri,
   {{0x6e204263,0x7d00717d,0xecc30034,0x69d900eb}},	//   _pemb, _sums, वचनफ, _lywe,
   {{0x6490007a,0x291d00f9,0x1ea90037,0x21290063}},	//   _täis, _owwa_, واني_, bsah_,
   {{0x69d9717e,0x7c21022b,0x6fd008d4,0x3a24717f}},	//   _nywe, _belr, _तुरं, vamp_,
   {{0x765d00a5,0x7e7b199b,0x6e207180,0x7c21015e}},	//   zesy, _enup, _wemb, _celr,
   {{0x6e207181,0x7e690072,0x6d4b112f,0x753d007f}},	//   _temb, _faep, atga, zusz,
   {{0x2d4908a8,0x7d007182,0xb5fb4d05,0x69d9084e}},	//   búe_, _tums, ldáv, _bywe,
   {{0x3a243419,0x7c217183,0x69d900eb,0x7af900eb}},	//   ramp_, _felr, _cywe, _diwt,
   {{0x69d902ad,0x3ae17184,0xb5fb7185,0x291d0154}},	//   _dywe, rópa_, ndáv, _dwwa_,
   {{0x59e20251,0x44217186,0x21290146,0x765d02ac}},	//   _परवर, _reh_, zsah_, tesy,
   {{0x64457187,0x6f0308ec,0x44217188,0x4992001c}},	//   _schi, ínci, _seh_, _میبر,
   {{0x765d7189,0x66dd0103,0x1ae30120,0x69d9030a}},	//   resy, lékk, _соцм, _gywe,
   {{0x753d00a5,0xb4bd00bc,0x765d718a,0xb86601f3}},	//   rusz, ेके_, sesy, _ساتو,
   {{0x765d718b,0x420e00ac,0x00000000,0x00000000}},	//   pesy, _ọsọ_, --, --,
   {{0x2129005c,0x753d2214,0x5575430b,0x4421718c}},	//   tsah_, pusz, _агит, _weh_,
   {{0x4421718d,0x60f91736,0x25b70068,0xa158718e}},	// [6fb0] _teh_, дная_, _سندھ_, нату_,
   {{0x6445718f,0x2ec900aa,0x7e697190,0x2aba01d3}},	//   _uchi, िक्त, _saep, mību_,
   {{0x2aba01d3,0x9c7c0154,0x32090167,0x7aed0206}},	//   lību_, _chčm, pcay_, ňati,
   {{0x2d4908a8,0x6d4b7191,0xa2c2030b,0x21290063}},	//   túe_, ttga, रचण्, psah_,
   {{0x2aba00d9,0x8c452c11,0x660d00bd,0x8d65007b}},	//   nību_, веле, _mfak, твле,
   {{0x013600a1,0x6d4b7192,0x2d49002b,0x7e69024a}},	//   _ברשת_, rtga, rúe_, _waep,
   {{0x7bda7193,0xdca22776,0x2d4908a8,0x9f470084}},	//   _cytu, ращи, súe_, änä_,
   {{0x6d4b0365,0xb5fb0018,0x628f7194,0x6f09033d}},	//   ptga, ldáu, _joco, _čech,
   {{0xfc330260,0x69d60120,0x628f7195,0xdce9044c}},	//   _محض_, _øyel, _moco, _creă,
   {{0x5ba708b8,0xb4bd1000,0x660d3d12,0x2aba01d3}},	//   _през, ेको_, _afak, dību_,
   {{0x752d3343,0xddc201d3,0x7bda00f0,0x00000000}},	//   _avaz, mdoš, _gytu, --,
   {{0x9696336f,0xe1ff7196,0xddc200e8,0xc4c900ca}},	//   трош, _ngó_, ldoš, _וג_,
   {{0xd94537fa,0x05637197,0xb5fb0146,0x291d0174}},	//   _рели, авян, zdáv, _uwwa_,
   {{0x2a6d0150,0x394d7198,0xf770001c,0x752d0234}},	//   ldeb_, mtes_, _گاه_, _dvaz,
   {{0x394d29c4,0x628f7199,0x752d719a,0x39be0129}},	//   ltes_, _boco, _evaz, ịst_,
   {{0x628f719b,0x394d054e,0x2a6d0150,0xf65f02f1}},	//   _coco, otes_, ndeb_, ceæ_,
   {{0x394d00f3,0x412701c9,0x2aba0029,0x00000000}},	// [6fc0] ntes_, кото_, cību_, --,
   {{0x1306037e,0x00000000,0x00000000,0x00000000}},	//   _изом, --, --, --,
   {{0x649b0c6a,0x394d719c,0x26c30631,0x3f9c0146}},	//   _חסיד, htes_, čkov_, ávu_,
   {{0x394d719d,0x7bda52eb,0x65760052,0x38a00441}},	//   ktes_, _rytu, _kryh, _mòra_,
   {{0x7bda00a5,0x394d719e,0x76ab01c2,0xb4db00ee}},	//   _sytu, jtes_, nƙya, rtàv,
   {{0x61e657a1,0xdd930138,0xb5fb0037,0x2a7d01c0}},	//   _izkl, рашы, leác, _anwb_,
   {{0x2d800012,0x2aba01d3,0x69dd042c,0xfe46107a}},	//   ţie_, zību_, üsen, _инво,
   {{0x394d6619,0xdee6719f,0x628f05fe,0xdce202f7}},	//   ftes_, _роби, _xoco, kvoć,
   {{0x394d71a0,0xd83a147c,0x00000000,0x00000000}},	//   gtes_, мэн_, --, --,
   {{0x7bda00a5,0xa78600cd,0xc7b80335,0x9873345a}},	//   _tytu, نشجو, lađi_, альц,
   {{0x69c4013f,0x752d02c6,0xf093021e,0x394d71a1}},	//   _žied, _svaz, ינז_, ates_,
   {{0xc7b871a2,0x394d71a3,0x2aba00d9,0x3ea637bd}},	//   nađi_, btes_, tību_, nhot_,
   {{0x394d0990,0x98c625a4,0xd9433c12,0x00000000}},	//   ctes_, _искл, _вечи, --,
   {{0x09e308a4,0x628f0694,0x2aba01d3,0x6576030a}},	//   _точн, _soco, rību_, _dryh,
   {{0x628f71a4,0x2aba00d9,0x65760124,0x3ea60167}},	//   _poco, sību_, _eryh, khot_,
   {{0x660d71a5,0x00000000,0x00000000,0x00000000}},	//   _ufak, --, --, --,
   {{0x752d71a6,0xb5fb0072,0x3ea600d1,0x00000000}},	// [6fd0] _uvaz, seáb, dhot_, --,
   {{0x26c3025b,0x6aa200f0,0x673a1183,0x80bf02d5}},	//   čkou_, _llof, ortj, ्वें,
   {{0x6aa271a7,0x43950b9c,0x628f13a9,0xfaf801d3}},	//   _olof, _санс, _toco, _drīz_,
   {{0xdbdc003e,0x394d0358,0x00000000,0x00000000}},	//   _ráði, ytes_, --, --,
   {{0x518471a8,0x394d025a,0xfe701673,0x2a6d01fa}},	//   _кура, xtes_, تدل_, vdeb_,
   {{0x6aa20090,0xb5fb0018,0x9f05097d,0xed5900c4}},	//   _alof, ldás, _موسو, _vpž_,
   {{0xddc237e6,0x6aa2371a,0x00000000,0x00000000}},	//   rdoš, _blof, --, --,
   {{0x394d71a9,0x3ea671aa,0x3f73007e,0xb5fb01f9}},	//   ttes_, chot_, _iću_, ndás,
   {{0x6e9458aa,0x394d71ab,0xb4db05fe,0x673a0371}},	//   _титу, utes_, ntàs, ertj,
   {{0x6aa271ac,0xe9ff020b,0x00000000,0x00000000}},	//   _elof, _trắm_, --, --,
   {{0x394d71ad,0x5b150e06,0x6fb800c3,0xecdf023a}},	//   stes_, _смет, ्पयू, _पीएफ,
   {{0x394d71ae,0x44330607,0x5ba400ae,0x6aa200eb}},	//   ptes_, _adx_, _труз, _glof,
   {{0x673a1044,0x00000000,0x00000000,0x00000000}},	//   artj, --, --, --,
   {{0x65760185,0xf74547c4,0x3f730559,0x00000000}},	//   _vryh, _беко, _oću_, --,
   {{0x425642d1,0x61e60034,0x0fbe0033,0x00000000}},	//   лтат, _szkl, _অর্ধ, --,
   {{0xb3d20d88,0xc61e0081,0x864600c2,0x00000000}},	//   _दुःख, _থাকা_, _сниж, --,
   {{0x6d5b006c,0x60ea1720,0x00000000,0x00000000}},	// [6fe0] _npua, емам_, --, --,
   {{0xb46671af,0x61e60141,0xf1bf01f9,0x00000000}},	//   _скол, _vzkl, _adás_, --,
   {{0xb4c00454,0xee3a71b0,0xef1a013d,0x3ea612d2}},	//   ंची_, ене_, хме_, thot_,
   {{0x442a71b1,0xb4db0428,0xe7f60179,0xcd2a00c2}},	//   lab_, gràf, ुखता_, ежде_,
   {{0x61e601d3,0xf65300ca,0xc7b80095,0x3ea671b2}},	//   _uzkl, מצא_, rađi_, rhot_,
   {{0x3ea671b3,0x442a71b4,0x409519e8,0x6acc0caf}},	//   shot_, nab_, _крст, ाव्र,
   {{0xb5fb71b5,0x8fa671b6,0x6aa21570,0x20073e76}},	//   ndár, _саве, _plof, žnic_,
   {{0x442a71b7,0xbea3333f,0xb4db05fe,0xd91a164d}},	//   hab_, _ласк, ntàr, ньо_,
   {{0x6e932204,0x442a71b8,0x5e9300e3,0x38a001ec}},	//   _القا, kab_, _القط, _dòrn_,
   {{0x442a71b9,0x78740103,0x7e624e21,0x38a0009c}},	//   jab_, küvő, leop, _eòrn_,
   {{0x442a71ba,0xd7f7055b,0x443301af,0xda6f5f56}},	//   dab_, лую_, _rdx_, _ля_,
   {{0x7c2a71bb,0x7e6271bc,0x59af0006,0x00000000}},	//   lafr, neop, _जेकर, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442a71bd,0x7c2a038e,0x673a033b,0x44250037}},	//   gab_, nafr, prtj, úl_,
   {{0x7e6201ce,0x38a001b9,0x389b0142,0x335800d3}},	//   keop, _hòro_, _איגנ, ларэ_,
   {{0xadf6000f,0x78ba011d,0x29060239,0x45d60134}},	//   ेशान_, litv, _kuoa_, ọpụ_,
   {{0x442a5607,0xddc971be,0xbbe1030b,0x44330428}},	// [6ff0] bab_, _snež, _फर्क, _tdx_,
   {{0xdddb0871,0x78ba0087,0x442a448b,0x1ae117e5}},	//   _použ, nitv, cab_, _पठ्ठ,
   {{0x7ced0623,0x00d80504,0xb4db00ee,0x00000000}},	//   lúrg, ابقت_, tràf, --,
   {{0xdce900e9,0x9f4a0af0,0xb4db0428,0x6d5b0063}},	//   _kreć, _agbó_, ctàr, _ppua,
   {{0x80bf0f71,0x070b0cce,0xa0240a43,0x00000000}},	//   ্তব্, _संभव_, _পারব_, --,
   {{0x644771bf,0x78ba0087,0x7c2a01cd,0xddc902a1}},	//   ngji, jitv, gafr, _ineż,
   {{0x78ba02dd,0xd49800a1,0x66dd231d,0xdb210491}},	//   ditv, רכות_, léku, _ötür,
   {{0xc7b80335,0x6d4207ac,0x50e50034,0x3eb94350}},	//   nađu_, buoa, _कठुआ_, _öst_,
   {{0x442a71c0,0x6d5b2783,0xb5fb0437,0x3c475f34}},	//   yab_, _upua, zdár, _مضاف,
   {{0x6e2b0af0,0xc6250081,0x26c90065,0xb4cf00b6}},	//   lagb, _ভাষা_, _ajao_, षको_,
   {{0x442a71c1,0x2902003e,0xe7cf023a,0x270c00d2}},	//   vab_, íkar_, _सुखप, _pěna_,
   {{0xfd4c00ef,0x442a10dd,0x6e2b0bb6,0x6440013f}},	//   _nhiề, wab_, nagb, ėmim,
   {{0x442a71c2,0x78ba033b,0x5e56006e,0x69330d7f}},	//   tab_, bitv, סישע_, _اکبر,
   {{0xb4c00454,0x49b8006f,0xdbcf02c6,0x741602fc}},	//   ंचे_, _حامد_, _lžíc, شورا,
   {{0x6e2b71c3,0x3a2600dc,0x66e605cb,0x661d298b}},	//   kagb, _yeop_, _кока, bbsk,
   {{0x442a71c4,0xfd4c0019,0x9f580076,0xf5390206}},	//   sab_, _chiề, _ngrá_, šťa_,

   {{0x442a14b1,0x6e2b71c5,0x799b684d,0x66040193}},	// [7000] pab_, dagb, nyuw, _igik,
   {{0x3ea402e7,0x442a71c6,0x659b021e,0xf0a76621}},	//   _slmt_, qab_, _סייק, акул_,
   {{0x09e2022d,0xa7fc0702,0x9f4a0af0,0xa0676acb}},	//   _पर्य, ldır, _agbò_, раха_,
   {{0x2eed71c7,0x752471c8,0x614600d3,0x175600c1}},	//   _chef_, _kwiz, _кема, יסער_,
   {{0xa7fc06d7,0x7c2a01cd,0x7e620d76,0x00000000}},	//   ndır, tafr, reop, --,
   {{0x7524674b,0x6d4271c9,0x7e625903,0xd7a50096}},	//   _mwiz, ruoa, seop, खनाच,
   {{0xf76707c3,0x78ba0b27,0xfaa63bbc,0xe7870146}},	//   _با_, vitv, ишин, yšší,
   {{0xf1bf00e3,0x66040201,0xb5fb0076,0x64470052}},	//   _meán_, _ngik, deán, zgji,
   {{0x4c86014d,0x78ba71ca,0x75240383,0x4efb00ca}},	//   _клав, titv, _nwiz, _יהלו,
   {{0x660416da,0xb4c00dba,0x3cfe0381,0x00000000}},	//   _agik, ंचो_, _uitv_, --,
   {{0xdce900e9,0x78ba0b27,0x6f0071cb,0x75241b50}},	//   _sreć, ritv, _kimc, _awiz,
   {{0xdce908a9,0x7ced71cc,0x6f000188,0x75240193}},	//   _preć, túrg, _jimc, _bwiz,
   {{0x2a640087,0x78ba4811,0x661d305d,0x09e3125f}},	//   memb_, pitv, rbsk, _доцн,
   {{0x66c801e8,0x7c282281,0x394400d9,0xdce9005f}},	//   lıkl, _jedr, mums_, _vreć,
   {{0x6447074a,0x7c2871cd,0xfd4c00de,0x53343140}},	//   rgji, _medr, _phiề, жест,
   {{0xdce902e6,0x26c90051,0xf1bf4b71,0x66c8026a}},	//   _treć, _ujao_, _deán_, nıkl,
   {{0xb4db0428,0xe4e7036c,0x7c2800f0,0x394401d3}},	// [7010] tràd, _вінн, _oedr, nums_,
   {{0x26d931d6,0x80d1009d,0x656d71ce,0x8504001c}},	//   loso_, तकें, _isah, _گوین,
   {{0x6e2b71cf,0xfd4c0023,0x394401c2,0xddcb0103}},	//   tagb, _thiề, hums_, vegő,
   {{0x39440029,0x63ad00d9,0xf1d81ae6,0xdb030146}},	//   kums_, ģinā, _भुवन, jzná,
   {{0x7c28438b,0x39440b4b,0x6e2b500c,0xee380c10}},	//   _bedr, jums_, ragb, рні_,
   {{0x6f07033b,0x394401d3,0x229c003e,0x656d6a0b}},	//   _tujc, dums_, _ríki_, _msah,
   {{0x26d9026e,0x1cb806fa,0x6e2b71d0,0x6aa971d1}},	//   koso_, جانب_, pagb, thef,
   {{0x26d91e6c,0x6f0071d2,0xa7fc0233,0x38a971d3}},	//   joso_, _gimc, ydır, _múre_,
   {{0x394400d9,0x26d9222b,0x7c2871d4,0x2b5e0231}},	//   gums_, doso_, _fedr, _eptc_,
   {{0x7c280d50,0x6aa971d5,0x799b03e3,0x752405bd}},	//   _gedr, shef, ryuw, _rwiz,
   {{0x6e2971d6,0x656d71d7,0x7d0942be,0x26d90451}},	//   _keeb, _asah, _hues, foso_,
   {{0x7d01038c,0xba7400e3,0xa7fc0092,0x7d090167}},	//   _hils, _وانت, tdır, _kues,
   {{0x2d9d3f68,0x6e291030,0xf1bf0037,0x7d0171d8}},	//   nywe_, _meeb, _seán_, _kils,
   {{0x7d0914e2,0xb5fb71d9,0x6e2971da,0xa7fc04a8}},	//   _mues, rdáp, _leeb, rdır,
   {{0x26d971db,0x7d0171dc,0x03a300c2,0xb5fb0037}},	//   boso_, _mils, пиро, leál,
   {{0x7d090257,0x22490096,0x26d93f3d,0xa20671dd}},	//   _oues, ggak_, coso_, спад,
   {{0x7d090eb8,0x644108ec,0xb5fb0037,0xe80e00c3}},	// [7020] _nues, ólic, neál, _सलमा_,
   {{0x7d0171de,0x22490062,0x7d0601dc,0x200700c4}},	//   _nils, agak_, _éksi, žnin_,
   {{0x6e2971df,0x00000000,0x00000000,0x00000000}},	//   _beeb, --, --, --,
   {{0xdfcf1f0b,0x528600e3,0xcf250037,0x7d0171e0}},	//   رين_, _الحك, تركي, _ails,
   {{0x7d0911ce,0x7d011a4a,0xc2130796,0x6e2971e1}},	//   _cues, _bils, _מהר_, _deeb,
   {{0x394401d3,0xd47a006e,0xd5ed00fe,0x26d971e2}},	//   vums_, ראַל, _hoạ, zoso_,
   {{0x26d971e3,0x6f0001b5,0x7d0171e4,0x6e292454}},	//   yoso_, _timc, _dils, _feeb,
   {{0x394471e5,0x7d0971e6,0x39140d86,0xa3bb02d5}},	//   tums_, _fues, омир, _आइस_,
   {{0x7d010510,0x7d0971e7,0x26d9038f,0x66c80233}},	//   _fils, _gues, voso_, rıkl,
   {{0xdb0300fb,0x394471e8,0x47343f1d,0x8afc0034}},	//   szná, rums_, онос, _spęd,
   {{0x394471e9,0x656d010a,0x6e2971ea,0x7ced0131}},	//   sums_, _ssah, _yeeb, búrb,
   {{0x6e2971eb,0xb5fb470e,0xaae6450f,0xcf9300ca}},	//   _xeeb, beál, _اسطو, לטת_,
   {{0xe9ff00de,0xb5fb0076,0xceb30266,0x00000000}},	//   _trạm_, ceál, פיש_, --,
   {{0x7d01008c,0x7ced015e,0x00000000,0x00000000}},	//   _xils, múrc, --, --,
   {{0x443f0702,0x26d934fb,0x5695016d,0x321606c0}},	//   ğu_, poso_, _макт, _ọnụ_,
   {{0x656d71ec,0x764d037a,0x443f3266,0x00000000}},	//   _tsah, _ucay, şu_, --,
   {{0x656d117e,0x6e2971ed,0x22490634,0xb4db00b3}},	// [7030] _usah, _reeb, rgak_, gràc,
   {{0x51f81ad1,0xf70900fe,0x00000000,0x00000000}},	//   сную_, _mần_, --, --,
   {{0xf70900ef,0x7d0971ee,0xde1971ef,0xb65a0139}},	//   _lần_, _sues, لقات_, _ajẹ́,
   {{0x7d0914e2,0x51874e42,0x00000000,0x00000000}},	//   _pues, _луга, --, --,
   {{0x7d0971f0,0x7d010029,0x6e290006,0xb4db05fe}},	//   _ques, _pils, _veeb, cràc,
   {{0xcc8900bf,0x6e2948dd,0x7d090890,0xd6cf0081}},	//   شنبه_, _weeb, _vues, রতিয,
   {{0x6e29006c,0x00000000,0x00000000,0x00000000}},	//   _teeb, --, --, --,
   {{0xdce93df1,0x7d096cb2,0x27170023,0xb5fb0076}},	//   _iseč, _tues, _hăng_, teál,
   {{0xf70900ef,0x7d010b81,0x7d09007a,0x2d920120}},	//   _cần_, _tils, _uues, øyet_,
   {{0xb5fb119e,0xd90c00cd,0xf7090019,0xa3e9009d}},	//   reál, دیو_, _dần_, _बरं_,
   {{0xe9a800d0,0x27170023,0xb5fb0037,0x5ba714e8}},	//   لدین_, _măng_, seál, _ураз,
   {{0x271700de,0xaabd0af1,0x38a9033c,0x60100065}},	//   _lăng_, _ऋषिक, _búrc_, _kòmó,
   {{0xf7090028,0x2619009f,0xf8bf020d,0x66dd01f9}},	//   _gần_, पड़ी_, éés_, tékr,
   {{0x271700ef,0xdce971f1,0x229c003e,0x7d0603a9}},	//   _năng_, _oseč, _líkt_, _èkse,
   {{0x6fd90034,0x232a004d,0x98a400c6,0x2bdf0213}},	//   _बुलं, роби_, usmą_, _पुमा,
   {{0x200700d4,0xb4db00b3,0x00000000,0x00000000}},	//   žnil_, tràc, --, --,
   {{0x27170019,0x063700ca,0x00000000,0x00000000}},	// [7040] _băng_, _ונפט_, --, --,
   {{0x271700de,0x00000000,0x00000000,0x00000000}},	//   _căng_, --, --, --,
   {{0xb4d6099d,0xadc30065,0x00000000,0x00000000}},	//   िकी_, _ifẹn, --, --,
   {{0x7ce405fe,0x443a421d,0xa75a006e,0xb4db00ee}},	//   mòri, _hdp_, ידער, pràc,
   {{0x628671f2,0x8237001c,0x7ce4015e,0x00000000}},	//   _inko, _برپا, lòri, --,
   {{0xccb700d6,0x443a0095,0x27170023,0xdca3017b}},	//   огії_, _jdp_, _găng_, мачи,
   {{0x443a71f3,0xbea600ae,0xb6490139,0x9e6601f3}},	//   _mdp_, _давк, _emẹ̀, _وارن,
   {{0x5a340c0d,0x443a71f4,0x539b0266,0x00000000}},	//   чнит, _ldp_, ייצו, --,
   {{0x80bf00c7,0x6e22006d,0xc8662c22,0x443a71f5}},	//   ্তর্, mbob, отни, _odp_,
   {{0xa3bb0006,0x271700de,0xd7fa0231,0xf7090023}},	//   _आइल_, _xăng_, иун_, _vần_,
   {{0x38a00139,0x6d424e82,0x00000000,0x00000000}},	//   _jòri_, lroa, --, --,
   {{0x6d4271f6,0x443a71f7,0xadc30065,0xf70900de}},	//   oroa, _adp_, _afẹn, _tần_,
   {{0x443a71f8,0x6d4271f9,0x660900c4,0x2ee6084e}},	//   _bdp_, nroa, žeko, ilof_,
   {{0x628671fa,0xdc0800d9,0x7ce4015e,0x00000000}},	//   _anko, rēķi, fòri, --,
   {{0x6d4246ea,0x27170019,0x443a65c7,0x7ce400ee}},	//   hroa, _răng_, _ddp_, gòri,
   {{0x6d4271fb,0xc1050037,0x69d600f3,0x00000000}},	//   kroa, كوري, _øyes, --,
   {{0xb80e048a,0x20070995,0x35b4008f,0x443a71fc}},	// [7050] _सलाम_, žnim_, _обър, _fdp_,
   {{0x6d4271fd,0x8fe72b94,0x628671fe,0xfd4c0174}},	//   droa, оцед, _enko, shiọ,
   {{0x44312b40,0xdce22461,0xe9ff00de,0x23790103}},	//   maz_, jvođ, _trầm_, _امجد_,
   {{0xdce208a9,0x59ca1dae,0x6e2271ff,0x4f0801b6}},	//   dvođ, ापार, gbob, інін_,
   {{0x27170028,0x25fe0789,0x443a00dc,0x067c0142}},	//   _tăng_, रेपी_, _ydp_, ינאל,
   {{0x9f3501ce,0x44317200,0x251c0089,0x7c3a01b9}},	//   _негі, naz_, סווא, _cdtr,
   {{0x6e220044,0x7ced05e6,0x2d920170,0x6d4201ff}},	//   bbob, gúra, øyer_, aroa,
   {{0x44317201,0x7f84001c,0xdcfb0078,0x26cb00e1}},	//   haz_, _تلفن, _kruċ, ébol_,
   {{0x44317202,0x8d7703ed,0x00000000,0x00000000}},	//   kaz_, _بازا, --, --,
   {{0x50db02e8,0x38a90032,0x78a90831,0x29034478}},	//   भविष, _búra_, ског_, öja_,
   {{0x25ee007d,0xd90f0068,0xbb4800e3,0x66e67203}},	//   _घरही_, ریں_, _ولكن_, зона,
   {{0x443a5c15,0x99800220,0x6441003e,0x3eb50233}},	//   _sdp_, _žiť_, ólin, _çatı_,
   {{0x443a7204,0x44317205,0x66dd0018,0x777a023e}},	//   _pdp_, faz_, rékp, avtx,
   {{0x44317206,0xb4d6250d,0x7ce40472,0x3ae146b5}},	//   gaz_, िके_, tòri, rópu_,
   {{0x07a500d3,0x63837207,0xb4bc1101,0x6e3b039f}},	//   _хайн, нгра, _आगी_, _odub,
   {{0xa5bb0072,0x7d1b3585,0x44310113,0x280100d2}},	//   mbón, _otus, aaz_, ěrně_,
   {{0x26c27208,0xe2971e54,0x44317209,0x443a0085}},	// [7060] miko_, чат_, baz_, _tdp_,
   {{0xb0630181,0xf70900de,0x65640124,0x6e3b720a}},	//   jväč, _lầm_, _ipih, _adub,
   {{0x7d1b602d,0x9e661167,0x6e3b033c,0xa5bb00d4}},	//   _atus, звед, _bdub, nbón,
   {{0x26c2720b,0x6d42720c,0x69c4013f,0x645c5d95}},	//   niko_, troa, _žiem, lfri,
   {{0x6da30e06,0xfce640c9,0x2ee6720d,0x9a120174}},	//   ница, подо, rlof_, _mọtụ,
   {{0x26c2720e,0x6d4202a7,0x6e3b720f,0x645c0970}},	//   hiko_, rroa, _edub, nfri,
   {{0x26c22f3e,0x7d1b0084,0x629b0072,0xf70900fe}},	//   kiko_, _etus, _écoñ, _bầm_,
   {{0xf7090019,0x44317210,0x60de7211,0xb53a0065}},	//   _cầm_, zaz_, lopm, _arọ́,
   {{0x25fe143d,0xd90d03ed,0x26c27212,0x44310587}},	//   रेमी_, لین_, diko_, yaz_,
   {{0xb4d66100,0x7c3a01c5,0x3ea601d3,0xb19b006e}},	//   िको_, _udtr, lkot_, צייכ,
   {{0x656400f9,0x26c24cbb,0xf98f110a,0xb4d600b6}},	//   _apih, fiko_, نبی_, िकै_,
   {{0x76ab35af,0xb5fb00e3,0x26c20a00,0x38c20139}},	//   стов_, leái, giko_, _bérè_,
   {{0x645c7213,0x44317214,0x201806a3,0x3ea67215}},	//   ffri, taz_, _ofri_, ikot_,
   {{0xb5fb00e3,0x645c0018,0x6f1c015c,0x68420139}},	//   neái, gfri, _otrc, _dídà,
   {{0x44317216,0x200713e8,0x26c27217,0x00000000}},	//   raz_, žnik_, biko_, --,
   {{0x6fbd007a,0x66e407c8,0x44317218,0x645c7219}},	//   ्पसं, _поја, saz_, afri,
   {{0x44310b0b,0x25a20557,0x00000000,0x00000000}},	// [7070] paz_, cykl_, --, --,
   {{0x6e3b00e7,0xb21b02b6,0x00000000,0x00000000}},	//   _sdub, _knæk, --, --,
   {{0x7ae2721a,0xb5fb0037,0x7d1b721b,0x00000000}},	//   _okot, deái, _stus, --,
   {{0x3ea6721c,0x7ae23ffb,0x201801cd,0x00000000}},	//   gkot_, _nkot, _efri_, --,
   {{0xf70900fe,0xcbfe0033,0x2018030a,0x00000000}},	//   _rầm_, ুরোধ_, _ffri_, --,
   {{0x26c2721d,0x7ae22b0b,0x2cac00e7,0xf70900fe}},	//   ziko_, _akot, _cldd_, _sầm_,
   {{0xfc300037,0x61e6721e,0x2fc50212,0x26c20b58}},	//   احه_, _zykl, _älg_, yiko_,
   {{0x26c2721f,0x6e3b7220,0x00000000,0x00000000}},	//   xiko_, _udub, --, --,
   {{0x645c7221,0x7d1b6994,0x3ebf7222,0x67380090}},	//   yfri, _utus, _imut_, _avvj,
   {{0xb4bc1085,0xb5fb0080,0x6d4b0549,0x2ac35acf}},	//   _आगे_, ceái, muga, _bèbè_,
   {{0x6d4b03cb,0xf7090019,0x9a120134,0x3ead0660}},	//   luga, _tầm_, _pọtụ, _klet_,
   {{0x291f5e37,0x3ebf00bd,0x6b81033c,0x00000000}},	//   ppua_, _jmut_, _irlg, --,
   {{0x26c26ccf,0x6d597223,0x7afb7224,0x6d4b7225}},	//   riko_, ntwa, mmut, nuga,
   {{0x7ae97226,0x3ead05fe,0x7afb7227,0xdcfb00e7}},	//   llet, _llet_, lmut, _oruč,
   {{0x6d4b0102,0x26c27228,0x3ead0084,0x290f0088}},	//   huga, piko_, _olet_, _huga_,
   {{0x29077229,0x6d4b19f2,0x645c5cfe,0x7afb0143}},	//   _hina_, kuga, sfri, nmut,
   {{0x290f2129,0x2907722a,0xd24f0018,0x7ae9722b}},	// [7080] _juga_, _kina_, شنل_, ilet,
   {{0x2907068d,0x6d4b722c,0x25fe0b7f,0x2120005c}},	//   _jina_, duga, रेणी_, rpih_,
   {{0x2907722d,0xe29a0291,0x3ea6722e,0xb4ca31f4}},	//   _mina_, _дан_, tkot_, लची_,
   {{0x6d59127d,0x6d4b722f,0x3d0a0557,0x29020146}},	//   ftwa, fuga, ादले_, íkaz_,
   {{0xb5fb00e3,0x3ea67230,0x7ae97231,0x290701c8}},	//   teái, rkot_, dlet, _oina_,
   {{0x7ae21e81,0x3ebf00d1,0x7ae97232,0x5fd9058f}},	//   _skot, _emut_, elet, _बुकल,
   {{0x290f7233,0x7ae97234,0xb5fb00e3,0x3ead00dd}},	//   _auga_, flet, reái, _flet_,
   {{0x7ae97235,0x29072a74,0xb5fb00e3,0x290f7236}},	//   glet, _aina_, seái, _buga_,
   {{0x286a336f,0xb5fb7237,0x81e00081,0x2ee400e7}},	//   орно_, peái, ধের_, _ikmf_,
   {{0x26c01ba3,0x7ae92f8e,0x38a90139,0x5fd517ad}},	//   _amio_, alet, _dúro_, _दशमल,
   {{0x29077238,0x291d02e2,0xa7fc026a,0x290f00b3}},	//   _dina_, _etwa_, ldız, _euga_,
   {{0x29077239,0x7ae2723a,0x27e700eb,0x7d080c89}},	//   _eina_, _ukot, _dynn_, _hids,
   {{0x2907723b,0xe4e700d6,0xd4260033,0x290f723c}},	//   _fina_, дівн, _বাড়ি_, _guga_,
   {{0x67d40638,0x2907006d,0x79820139,0x00000000}},	//   _полу, _gina_, _irow, --,
   {{0x6d4b4700,0x290f0022,0x672100c4,0x7ced05f1}},	//   zuga, _zuga_, cplj, zúro,
   {{0x6d4b4259,0x7d0800b6,0x7ae0723d,0x3b1e020b}},	//   yuga, _lids, nomt, _mttq_,
   {{0x644838c4,0xdcfb015c,0x645a0428,0x50f50915}},	// [7090] ódic, _sruč, òtic, езат,
   {{0x3ead01c5,0x6d4b01e2,0x29070428,0x629601fa}},	//   _slet_, vuga, _xina_, ajyo,
   {{0x7ae9723e,0x7ae0723f,0x3ead0ac1,0x6d4b12e6}},	//   ylet, komt, _plet_, wuga,
   {{0x752d7240,0x6d590078,0x6443001f,0x7d087241}},	//   _kwaz, ttwa, _ônib, _aids,
   {{0xdce901ac,0x7ae90367,0x212b0150,0x660d0eac}},	//   _sređ, vlet, _uwch_, _mgak,
   {{0x6d4b7242,0xdce901ac,0x629d2cc6,0x66c8026a}},	//   ruga, _pređ, _hoso, lıkt,
   {{0x629d7243,0x7ae97244,0x6d4b7245,0xdcfb04a3}},	//   _koso, tlet, suga, _uruč,
   {{0x660d7246,0x79827247,0xdce90284,0x60c5005c}},	//   _ngak, _brow, _vređ, lihm,
   {{0x2bdf0557,0x7ae901ce,0x7afb7248,0x629d09e5}},	//   _पुरा, rlet, rmut, _moso,
   {{0x660d7249,0x7ae9724a,0x7d08724b,0x26c025f2}},	//   _agak, slet, _gids, _smio_,
   {{0xdce902e6,0x752d379b,0x07a5084c,0x7982010a}},	//   _uređ, _awaz, ханн, _erow,
   {{0x629d724c,0x6721005f,0x290f042d,0x798232dd}},	//   _noso, rplj, _tuga_, _frow,
   {{0xd7560068,0x798200a1,0x38a0009c,0x66c8026a}},	//   ولیت_, _grow, _còrs_, dıkt,
   {{0x6f0900d9,0xfd4e0134,0x9a120134,0x38b50139}},	//   _liec, _alkọ, _họpụ, _dùrù_,
   {{0x7c3e0396,0x629d0479,0x68e1724d,0x394d724e}},	//   ópri, _boso, mold, lues_,
   {{0x6f0917b5,0xe2970831,0x26c000e7,0x629d724f}},	//   _niec, нас_, _umio_, _coso,
   {{0x6143322c,0x21672611,0x3f830090,0xe5a600ae}},	// [70a0] лета, нити_, _arju_, _чипи,
   {{0x9c7c025b,0x68e17250,0x2a6d006c,0x23db0b86}},	//   _akčn, nold, heeb_, _मुकद,
   {{0x54570054,0xf4570089,0x6aa901df,0x7d087251}},	//   _אביב_, _אייר_, kkef, _rids,
   {{0x7d080021,0x68e11a08,0x629d0150,0x394d0052}},	//   _sids, hold, _goso, kues_,
   {{0x6f097252,0x394d0052,0x00000000,0x00000000}},	//   _diec, jues_, --, --,
   {{0x653b00c1,0x68e101df,0x394d1bc8,0x629d7253}},	//   לענד, jold, dues_, _zoso,
   {{0x6f090012,0x7d08052f,0x629d7254,0x2bc318ff}},	//   _fiec, _vids, _yoso, _वेदा,
   {{0x798200a5,0x6ee300aa,0xa3e300c3,0xb5fb037a}},	//   _prow, sõbr, _फँस_, nfác,
   {{0x7d0800f2,0x68e13aad,0xf992012b,0x394d0788}},	//   _tids, fold, ابع_, gues_,
   {{0x68e10018,0x2d847255,0x6ef102b6,0x752d05bd}},	//   gold, _irme_, nåbn, _rwaz,
   {{0xc5fb1006,0x752d7256,0x65760899,0x7ae00a4b}},	//   ृश्य_, _swaz, _asyh, pomt,
   {{0x2a6d01fa,0x798226b5,0x38a00441,0x29110076}},	//   ceeb_, _trow, _còrr_, únaí_,
   {{0x38cb48b2,0x68e17257,0x394d7258,0x00000000}},	//   _کانی_, bold, cues_, --,
   {{0x629d7259,0x752d06a3,0x9a120294,0x68e1007e}},	//   _soso, _vwaz, _zọpụ, cold,
   {{0x629d1420,0x60c509a1,0x00000000,0x00000000}},	//   _poso, vihm, --, --,
   {{0x629d4330,0x752d725a,0x2d84725b,0x660d05bd}},	//   _qoso, _twaz, _orme_, _ugak,
   {{0x629d04d8,0x752d725c,0x673a2e0e,0x6f09725d}},	// [70b0] _voso, _uwaz, lstj, _riec,
   {{0x6f0900a5,0x629d725e,0x00000000,0x00000000}},	//   _siec, _woso, --, --,
   {{0xdfd100e3,0x6f09725f,0x629d7260,0x673a183e}},	//   جيا_, _piec, _toso, nstj,
   {{0x6ee70037,0x2a6d023e,0x52a70037,0x00000000}},	//   رسال, xeeb_, _أصدق, --,
   {{0x6f097261,0x2a6d00bc,0x394d0216,0x443302c3}},	//   _viec, veeb_, xues_, _kex_,
   {{0x6f0900a5,0x394d7262,0x9a120174,0xada2007e}},	//   _wiec, vues_, _sọpụ, рашл,
   {{0x673a0126,0x68e12096,0x4433490b,0x9a120134}},	//   jstj, vold, _mex_, _pọpụ,
   {{0x44337263,0x394d1f70,0x673a017a,0x68e13e38}},	//   _lex_, tues_, dstj, wold,
   {{0x6aa90102,0xe9d90938,0x673a029a,0xe8f900c2}},	//   rkef, ьки_, estj, мли_,
   {{0x7e7b7264,0x394d7265,0x6c740a09,0x6aa901df}},	//   _haup, rues_, _مطمئ, skef,
   {{0x7e7b7266,0x68e17267,0x394d7268,0x8c3c020e}},	//   _kaup, rold, sues_, _doğd,
   {{0x68e17269,0x7cf600ae,0x4433029a,0x99850076}},	//   sold, râre, _aex_, _للصو,
   {{0x394d726a,0x7e7b009d,0x67240ca7,0x68e1726b}},	//   ques_, _maup, _čije, pold,
   {{0x7e7b726c,0x98a20284,0x6ef80072,0xd9423c76}},	//   _laup, _више, míbe, _теши,
   {{0x6ef8030b,0x42560c06,0xe29f01cd,0xa5071087}},	//   líbe, ктат, _boð_, тера_,
   {{0xc2431d54,0x1b130081,0x7e7b726d,0xb5fb05f1}},	//   инск, _সবাই_, _naup, teát,
   {{0x94260f99,0x6d5b006c,0xc05a00c2,0x6ef80072}},	// [70c0] _импе, _nqua, дрец_, níbe,
   {{0xb5fb7174,0xf537006e,0x443300fc,0x00000000}},	//   reát, _שניי_, _gex_, --,
   {{0x4438726e,0xb4c0007d,0x63a70067,0xe0d500d6}},	//   mar_, ूची_, cyjn, ують,
   {{0xa2c10285,0x7e7b037a,0xb21b3459,0x00000000}},	//   रोद्, _caup, _snæv, --,
   {{0xdce000d9,0x7e7b00fd,0x29190031,0xbea31009}},	//   _apmā, _daup, ísal_, јачк,
   {{0x55bb00a1,0x237f007f,0xb4db00ee,0x4433020b}},	//   ומנו, łuje_, quàt, _xex_,
   {{0xf70a0019,0xf1bf0072,0x4438726f,0x6d5b7270}},	//   _hầu_, _feás_, iar_, _equa,
   {{0x4438057c,0x3a742c13,0xbea32fad,0x7af903a8}},	//   har_, улир, _каск, _chwt,
   {{0xbea363df,0x63a70034,0xdc541ac9,0x2d8400ae}},	//   _татк, zyjn, _مراک, _urme_,
   {{0x44387271,0xdd8f0080,0x7e7b0087,0x673a0088}},	//   jar_, _بوك_, _zaup, tstj,
   {{0xd7f721f4,0xf70a00de,0x69d902a1,0x16352ba6}},	//   кую_, _lầu_, _exwe, леня,
   {{0x673a0088,0x7c3800c9,0x44337272,0x443800f0}},	//   rstj, lavr, _sex_, ear_,
   {{0x443831fb,0x673a0088,0x25fe2c5f,0x6ef80328}},	//   far_, sstj, रेली_, cíbe,
   {{0x64d2007d,0x7d1d05fe,0x673a25cc,0x3d15007f}},	//   _सदृश, _ésse, pstj, _फंसे_,
   {{0x25ad1770,0xd6db001f,0x00000000,0x00000000}},	//   šel_, _оти_, --, --,
   {{0xd838037d,0xf70a0019,0x63a70034,0x3f5c7273}},	//   lač_, _bầu_, ryjn, díu_,
   {{0xf70a0028,0x7e7b7274,0x60f902e3,0x63a70034}},	// [70d0] _cầu_, _raup, еная_, syjn,
   {{0x2edb58a0,0xf70a0019,0x7e7b7275,0xdce92a6c}},	//   यक्त, _dầu_, _saup, _iseć,
   {{0xf4120054,0x200702fd,0x6d5b7276,0x7bce1a5d}},	//   _לפי_, äni_, _squa, _žbun,
   {{0x4ea7013d,0xa295224a,0x92955566,0x9f5800ee}},	//   ърза, _самі, _самц, _agró_,
   {{0x3cdf04a9,0xd8381813,0x628f188c,0x8c45107a}},	//   गवले_, kač_, _inco, геле,
   {{0x387c01ff,0x7e7b0350,0x00000000,0x00000000}},	//   _navr_, _waup, --, --,
   {{0x7e7b4122,0x9f3400d6,0x69d90063,0x3f5c0072}},	//   _taup, _весі, _sxwe, cíu_,
   {{0xdce92c57,0xaca30af0,0x6ef8002b,0xead10033}},	//   _oseć, _ikọl, tíbe, াত্ম,
   {{0x44387277,0x1017000f,0x2bc300c3,0x2ab1033c}},	//   yar_, _तलाश_, _वेरा, _cába_,
   {{0x44387278,0x6ef804d8,0xd8380128,0x6f150090}},	//   xar_, ríbe, gač_, _kuzc,
   {{0x6ef808a8,0xa6ca078b,0xa3e30e19,0x38a9016d}},	//   síbe, елна_, _फुल_, _júri_,
   {{0x44382bc2,0xaca30023,0xba39006e,0xcb1200ca}},	//   war_, _ruộn, _װײַט, _הלא_,
   {{0x4a9a0089,0xd94555a6,0xe8ee01b3,0x2a7f01fa}},	//   _רינג, _сели, _гл_, mdub_,
   {{0x628f0465,0x2a7d01fa,0x443871d2,0x6e3901fa}},	//   _anco, _hawb_, uar_, hawb,
   {{0x2a7d023e,0x395f7279,0x6d4b0364,0xf70a0023}},	//   _kawb_, ltus_, hrga, _sầu_,
   {{0x44382612,0x670c0067,0x2a7f007a,0x387c14f3}},	//   sar_, _सूचक_, ndub_, _zavr_,
   {{0x4438727a,0x395f414f,0x2a7d023e,0xaca30af0}},	// [70e0] par_, ntus_, _mawb_, _akọl,
   {{0x628f2107,0x2a7d01fa,0x395f0084,0x4438727b}},	//   _enco, _lawb_, itus_, qar_,
   {{0x4444727c,0x03a61107,0x6d4b1575,0x395f00aa}},	//   _id_, _сино, erga, htus_,
   {{0x395f727d,0xd838005f,0x2a7d0197,0x4444128b}},	//   ktus_, zač_, _nawb_, _hd_,
   {{0xdca60058,0x395d023e,0x395f01fa,0xf65f0430}},	//   лади, _nqws_, jtus_, onær_,
   {{0xa3e80f53,0x75240a4b,0xfce3004d,0xbd87415a}},	//   _बडा_, _mtiz, бочо, انون_,
   {{0x2a7d0150,0x6e390124,0x76440134,0x4444727e}},	//   _bawb_, bawb, _odiy, _md_,
   {{0x7644068d,0xdee6386f,0x7c3814f3,0x2bc30096}},	//   _ndiy, _соби, savr, _वेळा,
   {{0x2a7d01bb,0xd83816aa,0x6f02027e,0x395f727f}},	//   _dawb_, tač_, mmoc, gtus_,
   {{0x2ee601a2,0x2bdf0409,0x444400ca,0x6f0200d4}},	//   loof_, _पुका, _nd_, lmoc,
   {{0x2a660020,0xd83800e9,0x2a7d006c,0x75247280}},	//   _бълг, rač_, _fawb_, _atiz,
   {{0x44447281,0xa3e80006,0xdce900cb,0x6f027282}},	//   _ad_, _बड़_, _pseć, nmoc,
   {{0x44447283,0xe8940f80,0x764400eb,0xe5c71785}},	//   _bd_, _валь, _ddiy, усно,
   {{0x6aa21db2,0x76440b88,0x44440413,0x7ced7284}},	//   _hoof, _ediy, _cd_, túri,
   {{0xb86500bf,0x3267344a,0x6aa27285,0x00000000}},	//   _خانو, лтав, _koof, --,
   {{0x44447286,0x6e2422e7,0xb6c90018,0x2a7d023e}},	//   _ed_, ñibl, _جاتے_, _xawb_,
   {{0xaca30174,0x290e7287,0xf19400ba,0x2ee6084e}},	// [70f0] _skọl, _kifa_, бить, doof_,
   {{0x26cb7288,0x3d18000f,0x656d2839,0x290e0022}},	//   lico_, _पढ़े_, _ipah, _jifa_,
   {{0x3f874346,0x64457289,0x6d40728a,0xe1ff0065}},	//   ínu_, _idhi, _avma, _gbón_,
   {{0x26cb1763,0x1e0f009d,0x44440128,0x6d4b0660}},	//   nico_, िशेष_, _zd_, trga,
   {{0x395f728b,0x2a7d023e,0x4444728c,0x6b880503}},	//   xtus_, _rawb_, _yd_, _ardg,
   {{0x21290484,0x6f02728d,0x26cb028d,0x656d728e}},	//   mpah_, amoc, hico_, _mpah,
   {{0xeb990274,0x2a7d0150,0x6aa20172,0x64450a4b}},	//   тий_, _pawb_, _boof, _mdhi,
   {{0xf53f070a,0x290e728f,0x395f7290,0x6aa203a4}},	//   kså_, _aifa_, ttus_, _coof,
   {{0x81e700c7,0x20240102,0x290e7291,0x6aa27292}},	//   যের_, _árið_, _bifa_, _doof,
   {{0x395f7293,0x229c030b,0xe7650feb,0x7cda01d3}},	//   rtus_, _díky_, авоп, _pārņ,
   {{0x395f7294,0x752401ac,0x2a7d022e,0x316001e9}},	//   stus_, _stiz, _tawb_, ztiz_,
   {{0x26cb1767,0x64457295,0x66e60c58,0x395f2a3f}},	//   gico_, _adhi, рома, ptus_,
   {{0x6ef81d9f,0xe9a80dce,0x44447296,0x7d0e173c}},	//   níba, _مدون_, _pd_, _ünsü,
   {{0x7ae41420,0x44210124,0x44447297,0x394d0052}},	//   čite, _cfh_, _qd_, mres_,
   {{0x44447298,0x394d7299,0xdc0801d3,0x64450113}},	//   _vd_, lres_, mēģi, _ddhi,
   {{0x394d0ba0,0x7644729a,0x644501dc,0x42260077}},	//   ores_, _udiy, _edhi, рдав,
   {{0x394d0933,0x3d1517ff,0x61ef729b,0x867b00ca}},	// [7100] nres_, _फूले_, _cycl, _ירקו,
   {{0x394d729c,0x4444729d,0xdb180103,0x3d0f0034}},	//   ires_, _ud_, szvé, ादों_,
   {{0xee3a729e,0x394d01bf,0xa3cd02d5,0x31605803}},	//   вне_, hres_, _शेप_, stiz_,
   {{0x0d861c4c,0x33db040a,0x7d060103,0x394d729f}},	//   илен, _יחיד, _éksz, kres_,
   {{0x6aa272a0,0x2ee672a1,0x394d72a2,0xa2c100a4}},	//   _roof, roof_, jres_, रोळ्,
   {{0x394d355d,0x78a372a3,0x2ab172a4,0x8c3c0511}},	//   dres_, _nonv, _bábo_, _boğa,
   {{0x394d00c7,0x9f5c02fd,0x7f4300d3,0x1e9600ae}},	//   eres_, ävä_, _мерж, _крар,
   {{0x26cb72a5,0x99665be9,0x394d72a6,0x8c3c0b88}},	//   xico_, атол, fres_, _doğa,
   {{0x26cb218a,0x9997008f,0x3fa40174,0x00000000}},	//   vico_, икът_, ̣sụ_, --,
   {{0x78a372a7,0x2ab10032,0x3f8a0094,0x61eb042c}},	//   _conv, _fábo_, _krbu_, ügli,
   {{0x3ea40505,0x394d72a8,0x656d72a9,0x78a372aa}},	//   _komt_, ares_, _spah, _donv,
   {{0x394d2f7c,0xf53f1484,0xdaaa0077,0x8f9b0eda}},	//   bres_, tså_, _швед_, דיטי,
   {{0x26cb72ab,0x394d0472,0x290e72ac,0x78a305aa}},	//   rico_, cres_, _tifa_, _fonv,
   {{0xf53f4ee8,0x14cb007b,0x98a400e8,0x00000000}},	//   rså_, тыми_, rsmē_, --,
   {{0x26cb3884,0xdce903e5,0xf2c70360,0xb17b169c}},	//   pico_, _speċ, асан, _nyår,
   {{0x68e872ad,0x963516d0,0x78a301cb,0x00000000}},	//   lodd, _униц, _zonv, --,
   {{0x26c903ce,0x6fd9000f,0x92010e50,0x656d72ae}},	// [7110] _imao_, _मशहू, लेंज_, _upah,
   {{0x92d700c7,0x68e80150,0x644572af,0xe4eb001c}},	//   িতে_, nodd, _udhi, _جعبه_,
   {{0x61ef0383,0xd01872b0,0x2d990154,0x00000000}},	//   _wycl, рфу_, _ŧse_, --,
   {{0x22952296,0x394d4201,0x68e800f0,0x6ef8002b}},	//   _الحس, yres_, hodd, tíba,
   {{0x2bdf0bf5,0x3ea40090,0x8c3c020e,0x27e2007f}},	//   _पुजा, _domt_, _soğa, ękny_,
   {{0x394d72b1,0xb4db05fe,0x6ef872b2,0xeac90023}},	//   vres_, cràt, ríba, hẹt_,
   {{0x7ced0037,0x3f8a015c,0x3f8500fd,0x68e872b3}},	//   dúrt, _grbu_, _élu_, dodd,
   {{0x394d72b4,0x2b490fa3,0x99840138,0x8d770a85}},	//   tres_, čac_, jamų_, _پارا,
   {{0x394d72b5,0xdc0801d3,0x78a30117,0x00000000}},	//   ures_, tēģi, _ponv, --,
   {{0x394d72b6,0xdcf9048f,0x26c971c3,0x24810364}},	//   rres_, _صفات_, _amao_, _nahm_,
   {{0xb69b5cac,0xd70a00c2,0x78a372b7,0x00000000}},	//   rmân, лное_, _vonv, --,
   {{0x394d72b8,0x66000220,0x7b1500b6,0x2ca500ca}},	//   pres_, ýmko, _všud, _hold_,
   {{0x81ac00c7,0x7ae972b9,0x68e8083e,0x2ca502b6}},	//   _কেন_, moet, bodd, _kold_,
   {{0x78ba5abe,0xdce91e4d,0x7ae972ba,0xf8ab007f}},	//   chtv, _opeč, loet, _छविय,
   {{0x24810124,0x38a9033c,0x2ca572bb,0x00000000}},	//   _dahm_, _dúrt_, _mold_, --,
   {{0x7ae972bc,0x7bce080e,0xdb120103,0xb4db015e}},	//   noet, _žbuk, ógép, fràs,
   {{0xe1fa1d7b,0x9a120134,0x66f80139,0x3f8a00c4}},	// [7120] уга_, _pọzụ, _e̟kó, _srbu_,
   {{0x2ca500f9,0x3ae10220,0x6d4416fc,0x7ae91f2a}},	//   _nold_, rópy_, šiak, hoet,
   {{0x443a022b,0x7ae90a00,0xd5e9015a,0x7ced0076}},	//   _iep_, koet, _معین_, húrs,
   {{0xe29a72bd,0x443a72be,0xee3a5de1,0x6fd902d5}},	//   _сам_, _hep_, унд_, _मशरू,
   {{0x443a72bf,0x7ae90764,0x20230e4b,0x00000000}},	//   _kep_, doet, érií_, --,
   {{0x443a4e4a,0x628472c0,0x2ca500ca,0x00000000}},	//   _jep_, ldio, _cold_, --,
   {{0x672408a9,0x3ea46822,0x7ae900f0,0x798b4251}},	//   _čijo, _tomt_, foet, _argw,
   {{0x443a2431,0xd00f00e3,0x7ae901e9,0x6abb024a}},	//   _lep_, _ألف_, goet, ghuf,
   {{0xd83a00c6,0x9c5a0100,0x98b8002d,0xe29b006e}},	//   лэн_, _مجاز_, илит_, רשפר,
   {{0x2ca572c1,0x98ad0031,0xad1b00ca,0x26c90357}},	//   _gold_, ateľ_, _עובר, _smao_,
   {{0x68e802ad,0x7ae972c2,0x15e1269c,0x24817088}},	//   rodd, boet, _गुजर_, _rahm_,
   {{0x6e22009d,0xfaa3413c,0x68e80150,0x6abb0610}},	//   ncob, _нахо, sodd, chuf,
   {{0x628402e0,0x7c3a72c3,0x6d425815,0x443a72c4}},	//   ddio, _ketr, nsoa, _bep_,
   {{0x443a72c5,0xdcfb02e6,0x66cf0139,0x66160103}},	//   _cep_, _vruć, _bòkè, _egyk,
   {{0x443a72c6,0x87260e5a,0x57260a09,0xe0070285}},	//   _dep_, _اعتم, _ارتق, _वृंद_,
   {{0x27240134,0x443a01ff,0x8c350139,0xbb3b006e}},	//   _ịnwa_, _eep_, _fo̟w, טעלי,
   {{0xa1590426,0x443a72c7,0x518718fa,0xdce96c25}},	// [7130] разу_, _fep_, щува, _speč,
   {{0x7ae90634,0x628400bc,0x100700e5,0x00000000}},	//   zoet, adio, бяем, --,
   {{0x613f0139,0x83670037,0x00000000,0x00000000}},	//   _bàlá, _ادخل, --, --,
   {{0x443a0027,0x2ca500ca,0x2bc30096,0x7ae901ff}},	//   _zep_, _sold_, _वेगा, xoet,
   {{0x7c3a72c8,0xee380c10,0x5d67013d,0xdca51543}},	//   _betr, сні_, стез, жали,
   {{0x61fd00d9,0x69c0049c,0x443a00fe,0x0cc70033}},	//   _izsl, dzme, _xep_, শক্ত,
   {{0x2ca5038c,0x7ae972c9,0x01db0a43,0x00000000}},	//   _vold_, toet, _দরিদ, --,
   {{0xa92500d5,0x6e220036,0x26d9020d,0x4ea73d77}},	//   одил, ccob, érol_, _урга,
   {{0x7ae972ca,0x2ca572cb,0x7c3a3572,0x6d9201cd}},	//   roet, _told_, _fetr, rðað,
   {{0x7ae403ce,0x7c3a6898,0x25ed0ed3,0x6e3b082b}},	//   čita, _getr, _घड़ी_, _heub,
   {{0x7ae972cc,0xe7390291,0x443a72cd,0x62840178}},	//   poet, јем_, _rep_, ydio,
   {{0x7c3a1b36,0x7d1b1c33,0x443a72ce,0x2d8d022b}},	//   _zetr, _kuus, _sep_, _kree_,
   {{0x443a72cf,0x6e3b72d0,0x7d1b03cf,0x6e2403be}},	//   _pep_, _meub, _juus, ñibi,
   {{0x7d1b6765,0x69dc026a,0x6e3b72d1,0x38bb0f5a}},	//   _muus, ğret, _leub, _bêre_,
   {{0x25fe04dd,0xc2270134,0xdce000c6,0x7d1b4638}},	//   रेजी_, _ụkọc, _esmė, _luus,
   {{0x6e3b374e,0x3a3f0124,0x628472d2,0xaca300fe}},	//   _neub, naup_, udio, _muốn,
   {{0x7d1b72d3,0x7d0172d4,0xa5bb002b,0xaca3020b}},	// [7140] _nuus, _ohls, lcón, _luốn,
   {{0x25e300aa,0x3a3f0234,0x6ab9030a,0x00000000}},	//   _टुटी_, haup_, _llwf, --,
   {{0x7c3a07ea,0x2d8d008f,0xe7ef0b3f,0xf42a00c2}},	//   _retr, _aree_, _घुमा_, _elää_,
   {{0xa3e302d5,0x6d4272d5,0x7d1b72d6,0x0ec40096}},	//   _फुट_, tsoa, _buus, लोंड,
   {{0x7c3a72d7,0x2d8d36fd,0x6e220510,0x638302c6}},	//   _petr, _cree_, rcob, píná,
   {{0x6d4272d8,0x645c6c68,0x6e2272d9,0x9b2623c3}},	//   rsoa, ngri, scob, офил,
   {{0x6d4200c9,0xa2c1074c,0x7c3a72da,0x2d8d0174}},	//   ssoa, रोक्, _vetr, _eree_,
   {{0x22401d49,0xf96a1ad1,0x8f9b0327,0x7d1b72db}},	//   naik_, арой_, _דילי, _fuus,
   {{0x7d1b7018,0x69c0042d,0x2564238c,0x26d90031}},	//   _guus, uzme, jöl_, érom_,
   {{0x6f1c72dc,0x6e3b01ff,0x00000000,0x00000000}},	//   _kurc, _zeub, --, --,
   {{0x224033ef,0x645c72dd,0x3b860231,0x00000000}},	//   kaik_, dgri, _флег, --,
   {{0x6f1c72de,0x7d1b0694,0xa96a45f4,0x00000000}},	//   _murc, _yuus, _вида_, --,
   {{0x291f0451,0x2ab80113,0x256472df,0x00000000}},	//   cqua_, _géba_, göl_, --,
   {{0x645c06dd,0x6f1c00fc,0x00000000,0x00000000}},	//   ggri, _ourc, --, --,
   {{0xaca30028,0x938872e0,0x02a70829,0xa85700ca}},	//   _xuốn, оста_, орам, _ויוה_,
   {{0x201872e1,0x3f87003e,0x645c0e22,0xb4db00b3}},	//   _agri_, ænum_, agri, rràq,
   {{0x6e3b200e,0xa2c12853,0x00000000,0x00000000}},	// [7150] _reub, रोग्, --, --,
   {{0x6f1c258d,0xddc900d3,0x7d1b4426,0x8b040022}},	//   _burc, _aceş, _ruus, ƙƙwa,
   {{0x2fc70028,0x22405261,0x7d1b0673,0x6f1c72e2}},	//   àng_, baik_, _suus, _curc,
   {{0x6f1c02d6,0xef18013f,0x3946137f,0x7d1b72e3}},	//   _durc, імі_, _ovos_, _puus,
   {{0x7d1b008c,0x00000000,0x00000000,0x00000000}},	//   _quus, --, --, --,
   {{0xc1720089,0xdd8e0411,0x6f1c72e4,0x66d60117}},	//   _רחם_, اوو_, _furc, mške,
   {{0x7ae402dd,0x39460956,0x2ab80113,0x7d1b2738}},	//   čitn, _avos_, _séba_, _wuus,
   {{0x63a801df,0x2d8d00ca,0x7d1b72e5,0xdddb020a}},	//   ødni, _tree_, _tuus, _cauţ,
   {{0x3a3f0085,0x645c00eb,0x00000000,0x00000000}},	//   raup_, ygri, --, --,
   {{0x6d5972e6,0xb6490065,0x291f014b,0x00000000}},	//   muwa, _ilẹ̀, rqua_, --,
   {{0xf7710241,0xc5e909c1,0x6d5972e7,0x291f72e8}},	//   راد_, _עד_, luwa, squa_,
   {{0x7e790270,0xe1ff00ee,0xa3c100b6,0x195901b3}},	//   newp, _ozó_, ्छन_, _гады_,
   {{0x6d5972e9,0x645c72ea,0xeab00c5e,0x00000000}},	//   nuwa, tgri, _جعل_, --,
   {{0xa50a016e,0x2eb83952,0xd11c1926,0x765d0f5a}},	//   сега_, _आत्त, _भूषण_, agsy,
   {{0x291d04f9,0x6d5972eb,0xe29a03fc,0x232a00d6}},	//   _huwa_, huwa, бав_, соби_,
   {{0x291d6c75,0xa2cc02e8,0xdbd70fc4,0x645c0150}},	//   _kuwa_, _सगळ्, määr, sgri,
   {{0x6f1c72ec,0x291d2d17,0x2018366c,0xa5bb124d}},	// [7160] _surc, _juwa_, _pgri_, ncól,
   {{0x6d5972ed,0x6f1c00a1,0x291d51c4,0x27210065}},	//   duwa, _purc, _muwa_, _kón_,
   {{0xb4e8007d,0x27210088,0xdbd731e8,0xaca30023}},	//   यकी_, _jón_, näär, _luồn,
   {{0x272172ee,0x127a00e3,0x6d590044,0x3a240036}},	//   _món_, _احدث_, fuwa, xcmp_,
   {{0x6d59006d,0x272172ef,0x568d006e,0x00000000}},	//   guwa, _lón_, יטאַ, --,
   {{0x628672f0,0xdbd74638,0x00000000,0x00000000}},	//   _hako, käär, --, --,
   {{0x628672f1,0x291d2d17,0x27210023,0xafe30036}},	//   _kako, _auwa_, _nón_, _зорл,
   {{0x628672f2,0x6d5972f3,0x1c1e0034,0x3afa023b}},	//   _jako, buwa, _पलवल_, rëpo_,
   {{0x62865164,0x5886004b,0xaca300de,0x291d72f4}},	//   _mako, пына, _cuồn, _cuwa_,
   {{0x628672f5,0xfca9487a,0x27210023,0x38c800d1}},	//   _lako, _والو_, _bón_, تابی_,
   {{0xaca40174,0x3d150336,0x291901cd,0xf09300ca}},	//   gbụr, _फूटे_, ísar_, גנת_,
   {{0x6286005f,0xa3cd06ed,0x291d01c2,0x45d5008d}},	//   _nako, _शेष_, _fuwa_, домс,
   {{0x27210072,0xf1bf0610,0x291d2649,0x8bee0033}},	//   _eón_, _afán_, _guwa_, টেশন_,
   {{0x27210037,0x798272f6,0xa9c501f3,0x657d0027}},	//   _fón_, _isow, _غزنو, rwsh,
   {{0x291d0a75,0x628666f5,0xe1ff0018,0x6d5972f7}},	//   _zuwa_, _bako, _szó_, zuwa,
   {{0x6d591114,0x291d0d2a,0xf8bc0285,0x78aa0f5a}},	//   yuwa, _yuwa_, _ऋतुप, _hofv,
   {{0x764d72f8,0xa3cd00c3,0x62d4001c,0x628672f9}},	// [7170] _iday, _शेर_, رآفر, _dako,
   {{0xdddb69ed,0x752d0875,0x55bc00ca,0x7982039f}},	//   _nauš, _itaz, _למחו, _msow,
   {{0x6d591114,0x628672fa,0x00000000,0x00000000}},	//   wuwa, _fako, --, --,
   {{0x6d5972fb,0x7c285272,0x628672fc,0x6ee70037}},	//   tuwa, _afdr, _gako, أسئل,
   {{0xdce20206,0x00000000,0x00000000,0x00000000}},	//   atoč, --, --, --,
   {{0x291d1114,0x6d5972fd,0x752d0051,0xeb990fbe}},	//   _ruwa_, ruwa, _mtaz, жик_,
   {{0x6d591114,0x62861a80,0x764d008a,0x79820172}},	//   suwa, _yako, _oday, _asow,
   {{0x764d2ac5,0xdbd70673,0xa2c102d5,0x752d0146}},	//   _nday, väär, रोच्, _otaz,
   {{0x272116c8,0x316972fe,0x752d02a4,0x09050927}},	//   _són_, ntaz_, _ntaz, мпин,
   {{0xd90f0068,0x764d72ff,0x5749534f,0x6d49020a}},	//   ھیں_, _aday, озом_, _ivea,
   {{0x66e6004c,0x752d7300,0x291d01c2,0x798248d3}},	//   дона, _ataz, _wuwa_, _esow,
   {{0x291d7301,0x9ac5010a,0x6441003e,0x2d99014b}},	//   _tuwa_, _beŋŋ, ðlin, _àses_,
   {{0xe8ee016a,0x62861750,0x2b40005f,0x764d0283}},	//   _ал_, _rako, ćice_, _dday,
   {{0x62867302,0xe7390e58,0xb4e80789,0xdce20220}},	//   _sako, _дек_, यके_, ytoč,
   {{0x628611cf,0x752d0c56,0x31690634,0x6e29063d}},	//   _pako, _etaz, etaz_, _ofeb,
   {{0xe297002d,0xdb240103,0x6e2d0328,0x7cf600ae}},	//   мас_, éséh, ñabl, râri,
   {{0x672408a9,0x61433da5,0x3f910491,0x3f8300aa}},	// [7180] _čiji, кета, _arzu_, _asju_,
   {{0x62867303,0x3f910335,0x6e297304,0x645a1de1}},	//   _wako, _brzu_, _afeb, ótid,
   {{0x62862188,0x6d4900d3,0x73067305,0x9e660070}},	//   _tako, _avea, _опоз, двед,
   {{0x917a0023,0x00000000,0x00000000,0x00000000}},	//   _cập_, --, --, --,
   {{0xdce27306,0xdddb16aa,0x00000000,0x00000000}},	//   stoč, _pauš, --, --,
   {{0x3e4e0019,0x16031c0a,0x6e29039f,0xdd9301b6}},	//   ột_, रेटर_, _efeb, ташы,
   {{0x6aab02b6,0xff2300ae,0x00000000,0x00000000}},	//   _bogf, _амсо, --, --,
   {{0x3e86013f,0xed5a4dff,0xc4bb16f8,0x00000000}},	//   _būtų_, _моб_, _उत्ख, --,
   {{0x6aab0150,0x9a120134,0xb5fb065b,0xbc660291}},	//   _dogf, _sọbụ, nfát, _овак,
   {{0xd90d037f,0xb4e87307,0x473427c9,0xb4bd00a5}},	//   مین_, यको_, ннос, _आते_,
   {{0xf98f00cd,0x905700a1,0x205700c1,0xc05700ca}},	//   هبی_, וסיף_, וייל_, וביץ_,
   {{0x569408d1,0x3ea67308,0x798201c2,0x249a044c}},	//   вают, njot_, _tsow, _anpm_,
   {{0x2d84000d,0x6ef800e3,0xe9da07e8,0x00000000}},	//   _jsme_, ríbh, _بذات_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x36d50236,0x2cac0150,0x38cb0470,0x7ae20090}},	//   _покр, _modd_, _بانی_, _kjot,
   {{0x260c0096,0x764d039f,0xb5fb0669,0xa2ca0285}},	//   ठेही_, _uday, rgáb, सोल्,
   {{0x34951cfb,0x752d7309,0xf70a0023,0x75d50037}},	// [7190] _запр, _utaz, _nầy_, _سيدا,
   {{0x4427008b,0x316964cf,0x7ae2730a,0x00000000}},	//   _ün_, rtaz_, _ljot, --,
   {{0xdfd100e3,0x316901e9,0x6d49084d,0x00000000}},	//   ديا_, staz_, _svea, --,
   {{0x867c006e,0xf70a0023,0x7ae20113,0x00000000}},	//   ַרוו, _bầy_, _njot, --,
   {{0x2cac730b,0xf70a00fe,0x00000000,0x00000000}},	//   _bodd_, _cầy_, --, --,
   {{0xf70a00fe,0x7ae200ce,0x00000000,0x00000000}},	//   _dầy_, _ajot, --, --,
   {{0x2cac32dd,0x917a0023,0x2d84730c,0x00000000}},	//   _dodd_, _tập_, _esme_, --,
   {{0x6e29063d,0x00000000,0x00000000,0x00000000}},	//   _ufeb, --, --, --,
   {{0xe9d9344a,0x2cac0150,0xf70a0023,0x7ae2295c}},	//   яки_, _fodd_, _gầy_, _djot,
   {{0xa3c11c05,0xa3e01fbb,0x48cd0033,0x3ebf003e}},	//   ्छा_, _दखल_, রক্র, _hlut_,
   {{0x657602e5,0xe80a00bc,0x66d600c6,0x6aab5bd8}},	//   _spyh, हेला_, eška, _togf,
   {{0xddc00154,0x00000000,0x00000000,0x00000000}},	//   _bemň, --, --, --,
   {{0x3ead730d,0x249a0085,0xef190078,0x00000000}},	//   _moet_, _pnpm_, _miż_, --,
   {{0x7afb32bf,0xef19009e,0x26c21175,0x00000000}},	//   llut, _liż_, shko_, --,
   {{0xd5b800d9,0x3ebf007b,0xa85600ca,0x00000000}},	//   ņā_, _olut_, _טיסה_, --,
   {{0xef190067,0x7afb730e,0x05660120,0x00000000}},	//   _niż_, nlut, _звин, --,
   {{0x205607ec,0x7afb007b,0x26c0024a,0x3afa006e}},	// [71a0] етер, ilut, _ilio_, פּלע,
   {{0x7afb730f,0x66040060,0x76461ba1,0xdcfb1197}},	//   hlut, _izik, laky, _oruđ,
   {{0x7afb7310,0x44380178,0xef19009e,0x3ebf0364}},	//   klut, mbr_, _biż_, _blut_,
   {{0x9f58023b,0x3ead00ee,0x7ae43fa3,0x92b60037}},	//   _hyrë_, _coet_, čitk, _أحدا,
   {{0x3ead0ab2,0xef190090,0x26c00239,0x86370142}},	//   _doet_, _diż_, _mlio_, גאנג_,
   {{0x224203e5,0xdca332d3,0x66040239,0xaca30023}},	//   _hekk_, лачи, _mzik, _muỗn,
   {{0x26c07311,0x7afb003e,0x764656ad,0x3dc67312}},	//   _olio_, flut, kaky, szow_,
   {{0x224204f9,0x7afb0fa0,0x29077313,0x68e30095}},	//   _jekk_, glut, _ahna_, _ajnd,
   {{0x63b500a5,0xed571352,0xc8660bb4,0x66047314}},	//   zyzn, _пот_, нтни, _nzik,
   {{0xd6fb2c5d,0x29187315,0x3ead029a,0x26c07316}},	//   ृष्ठ_, öra_, _zoet_, _alio_,
   {{0x26c0009c,0x7e620239,0x66040b32,0x46dc0096}},	//   _blio_, ogop, _azik, मचंह,
   {{0x7d1a7317,0x22420154,0x7afb7318,0x290701c8}},	//   _hits, _nekk_, clut, _ehna_,
   {{0xa2c417ff,0x7d1a7319,0x27460139,0x00000000}},	//   रसन्, _kits, _bíná_, --,
   {{0x26c0028d,0x7d1d00b3,0x6604731a,0xf9930142}},	//   _elio_, _èsse, _dzik, _תרס_,
   {{0xf76f00bf,0x387e731b,0x7d1a731c,0x6604731d}},	//   _هاي_, metr_, _mits, _ezik,
   {{0x7d1a731e,0x26c0009c,0xa5bb0076,0x442a01b9}},	//   _lits, _glio_, hcói, acb_,
   {{0x645a0d9f,0xddc9731f,0x224264f8,0x26d90146}},	// [71b0] ótic, _obeš, _dekk_, érou_,
   {{0x7d1a7320,0x902808a1,0x7b150095,0x3ead0313}},	//   _nits, ецца_, _ršum, _soet_,
   {{0x224200f3,0x64477321,0x3ead2423,0x09d40033}},	//   _fekk_, maji, _poet_, _হুমা,
   {{0x64477322,0x2242003e,0x9f580216,0x00000000}},	//   laji, _gekk_, _zyrë_, --,
   {{0x7d1a7323,0x3ead0305,0x09b50033,0x00000000}},	//   _bits, _voet_, _জেনা, --,
   {{0xd04501d4,0x64477324,0x7e620381,0x71d60eda}},	//   yihə, naji, agop, _יורד_,
   {{0x7d1a02ac,0x672d0146,0x3ead0b8e,0x7cf6044c}},	//   _dits, _čajo, _toet_, vârt,
   {{0x628d7325,0x7afb13ce,0x7d1a7326,0x00000000}},	//   ndao, ulut, _eits, --,
   {{0x7d1a7327,0x7afb0085,0x64477328,0x2b40005f}},	//   _fits, rlut, kaji, ćica_,
   {{0x7afb0bab,0x7d1a2de4,0x8c3c0491,0x64477329}},	//   slut, _gits, _boğu, jaji,
   {{0x81d70081,0x629d1b99,0x6f1b732a,0x7646732b}},	//   িথি_, _onso, _kiuc, taky,
   {{0x6d590ab2,0x8c3c08bb,0x2a660231,0x00000000}},	//   orwa, _doğu, _gcob_, --,
   {{0x95990a29,0x7646732c,0x41d002ed,0x6d4b0973}},	//   нтру_, raky, _सेंस, nsga,
   {{0x7646732d,0x629d732e,0x395f659a,0x6447732f}},	//   saky, _anso, muus_, gaji,
   {{0x044306b2,0x76467330,0x26d20172,0x64a32155}},	//   ресн, paky, _tmyo_, шара,
   {{0x3afa00dd,0xd5b20f36,0x628d02c9,0x26c00239}},	//   tëpi_, _نفع_, gdao, _ulio_,
   {{0x64477331,0x69c97332,0x6146251c,0x395f2568}},	// [71c0] baji, nzee, теза, nuus_,
   {{0x7ae400e9,0x629d0283,0x81ac00c7,0x67237333}},	//   čiti, _enso, _কেউ_, _kunj,
   {{0x75240126,0x7d1a7334,0x672302fa,0x44441224}},	//   _huiz, _rits, _junj, _ie_,
   {{0x6f097335,0x6aa90039,0x672d00e7,0x7d1a7336}},	//   _chec, jjef, _čajl, _sits,
   {{0x7d1a7337,0x6f1b32c3,0x6d4b7338,0x75247339}},	//   _pits, _diuc, gsga, _juiz,
   {{0x7524733a,0xdce9009e,0xc04501f9,0x69c900e8}},	//   _muiz, _preġ, _مخفو, dzee,
   {{0x4444733b,0x67230533,0x6d593138,0x8cb31efb}},	//   _me_, _nunj, arwa, _अवरो,
   {{0x4444733c,0x661b1912,0x7d1a733d,0xa5bb0076}},	//   _le_, žuki, _wits, scói,
   {{0xf2d309c1,0x44445282,0x66d6013f,0x7d1a733e}},	//   יעה_, _oe_, eško, _tits,
   {{0x7d1a1d19,0x1bed0006,0x7aed00e7,0x6abb0172}},	//   _uits, _चुकल_, čata, akuf,
   {{0x6447733f,0x6aa9037a,0x67230141,0x261509a1}},	//   vaji, bjef, _cunj, नेनी_,
   {{0x67230580,0x44447340,0x69c9023e,0x7524029a}},	//   _dunj, _ae_, bzee, _buiz,
   {{0x44441723,0x64477341,0x67232a69,0x59d9148e}},	//   _be_, taji, _eunj, _बेपर,
   {{0x44447342,0x75240126,0x9f580072,0x00000000}},	//   _ce_, _duiz, _eyré_, --,
   {{0x64477343,0xa3cd017f,0x569511c0,0x67237344}},	//   raji, _शेख_, _байт, _gunj,
   {{0x44447345,0x64477346,0xf2c404a1,0x6d590027}},	//   _ee_, saji, асун, yrwa,
   {{0x44447347,0x8cb3030b,0x26d90060,0x75247348}},	// [71d0] _fe_, _अवलो, miso_, _guiz,
   {{0x44447349,0x26d9734a,0x6f0900e7,0x2ab80032}},	//   _ge_, liso_, _shec, _débi_,
   {{0x15f4010d,0xa5c7003e,0xbeee0096,0x6d4001ee}},	//   _مسیح, _fróð, जवून_, _awma,
   {{0xf7730130,0x26d9067d,0x291c734b,0x62a50094}},	//   יקע_, niso_, _liva_, ároč,
   {{0x4444734c,0x6445734d,0x22490665,0xed59455b}},	//   _ye_, _kehi, maak_, хол_,
   {{0x4034734e,0x444400ef,0x395f00c2,0x6d4b0407}},	//   _верс, _xe_, vuus_, rsga,
   {{0x6f09734f,0xdce000d9,0x26d93944,0x4421022b}},	//   _thec, _apmē, kiso_, _mgh_,
   {{0xc2070da9,0xc3340054,0x64457350,0x61fd0146}},	//   _शराब_, בוק_, _lehi, _kysl,
   {{0x291c7351,0x26d95980,0x987e0092,0x99dd0146}},	//   _biva_, diso_, _açıq_, raňo,
   {{0x61fd7352,0x69c9029a,0xe0df02f1,0x6aa90120}},	//   _mysl, rzee, _dwòg_, sjef,
   {{0x44440054,0xca75022a,0x395f7353,0x75247097}},	//   _re_, _булы, suus_, _suiz,
   {{0xcfc500c7,0x44217354,0x66d62f54,0x291c0072}},	//   _এখান, _agh_, rško, _eiva_,
   {{0x44447355,0x752459d4,0x644517c6,0xe0df05aa}},	//   _pe_, _quiz, _behi, _gwòg_,
   {{0x44440910,0x67237356,0x291c294b,0x64457357}},	//   _qe_, _tunj, _giva_, _cehi,
   {{0x44447358,0xb5fb0068,0x394d7359,0x7ae402dd}},	//   _ve_, lgál, lses_, čitv,
   {{0x4444004f,0x26d9085f,0x394d735a,0x291c735b}},	//   _we_, ciso_, oses_, _ziva_,
   {{0x4444735c,0x394d04e4,0x6445735d,0xa7fc0233}},	// [71e0] _te_, nses_, _fehi, ngın,
   {{0x4444735e,0x644503f3,0x7e690f07,0xe1f74941}},	//   _ue_, _gehi, _acep, угу_,
   {{0x2249735f,0xb4c209c4,0x37d50033,0x00000000}},	//   baak_, ्फी_, _সুতর, --,
   {{0xf2a61407,0x394d7360,0xbd6a1055,0x71260103}},	//   _симп, kses_, ерке_, _مرسل,
   {{0x463b006e,0x3160225b,0xdcb100fe,0x00000000}},	//   גענע, quiz_, _bỏ_, --,
   {{0x26d9019f,0x38a900d4,0x0b8a1da9,0xb4db00b3}},	//   ziso_, _túry_, есии_, ssàv,
   {{0x394d1094,0x291c7361,0x09dc0442,0xd00760cf}},	//   eses_, _riva_, मप्य, _бере_,
   {{0x8c3c07aa,0xd12f0018,0x26d90188,0xe0df0383}},	//   _coğr, _ذمہ_, xiso_, _ewòd_,
   {{0x8c3c0702,0x26d9013d,0xe0df0154,0xc27b00ca}},	//   _doğr, viso_, _fwòd_, גרפי,
   {{0x22497362,0x26d9041c,0x00000000,0x00000000}},	//   zaak_, wiso_, --, --,
   {{0x6445265b,0x290200d9,0x26d900ee,0x394d00ca}},	//   _rehi, ēka_, tiso_, ases_,
   {{0x64452c09,0x2f97006e,0x656f042c,0x49ca0a0e}},	//   _sehi, אכטן_, ttch, _плен_,
   {{0x442100f9,0x25bf0018,0x26d97363,0x656f2db2}},	//   _pgh_, ául_, riso_, utch,
   {{0x656f7364,0x26d90201,0x61fd7365,0x00000000}},	//   rtch, siso_, _rysl, --,
   {{0xd6d11850,0x7792110a,0x26d906b0,0x644511bf}},	//   _وقت_, _ایجا, piso_, _vehi,
   {{0xa6ab0241,0x59d90455,0xb5a700e5,0x1dc418ff}},	//   _سابق_, _बेडर, _брой, वनात,
   {{0x224901a2,0x44210332,0x60f900c2,0xa15830fd}},	// [71f0] raak_, _tgh_, вная_, лату_,
   {{0x0467160b,0x44211821,0x61fd025b,0x2129005c}},	//   _стим, _ugh_, _vysl, rqah_,
   {{0x672d18c5,0x6fd5063c,0x8007711a,0x00000000}},	//   _čajk, _येशू, учае, --,
   {{0x66f7099d,0x394d0407,0x67050f8f,0xa7fc0233}},	//   ीतिक_, yses_, रतिक_, ygın,
   {{0xa2ba03a2,0x2129005c,0x6da52cd8,0x628f7366}},	//   _एकत्, qqah_, рила, _iaco,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628f7367,0xeab10076,0x00000000,0x00000000}},	//   _kaco, قعة_, --, --,
   {{0x394d1a8a,0x628f33ba,0x00000000,0x00000000}},	//   tses_, _jaco, --, --,
   {{0x394d7368,0x9a120134,0xdd940109,0x08c504d2}},	//   uses_, _fọmụ, _латы, ибин,
   {{0x394d0930,0x3a2d007e,0x3f9800f0,0x7c970452}},	//   rses_, scep_, _yrru_, _حشرا,
   {{0x394d17fc,0xb8ed02d5,0xeaae0018,0xf092021e}},	//   sses_, _रत_, سٹی_, קנט_,
   {{0x89d611a2,0xe1ff037a,0xd49100fe,0x6b9c2a6b}},	//   اویر_, _oyó_, ồn_, _árga,
   {{0xcb120054,0xf5064c82,0x7ae400e7,0xd945037e}},	//   _ולא_, измо, čitt, _тели,
   {{0xb4c22674,0x00000000,0x00000000,0x00000000}},	//   ्फे_, --, --, --,
   {{0xe1ff0032,0x32330294,0x98f40cc8,0x628f0133}},	//   _ayó_, _ụnụ_, _اثنا, _baco,
   {{0xd1320037,0x00000000,0x00000000,0x00000000}},	//   قمر_, --, --, --,
   {{0x628f5991,0x225d0034,0xaca40129,0x6906003e}},	// [7200] _daco, ówka_, waọr, iðen,
   {{0xe3ba68de,0x628f01b5,0xbebd0138,0xa5bb2bb5}},	//   _або_, _eaco, _liūd, rcót,
   {{0x628f7369,0xb4c24473,0x7e2602b3,0xe1ff0139}},	//   _faco, ंसी_, адеж, _eyó_,
   {{0x539b00a1,0x628f1dd1,0x277600c1,0x00000000}},	//   _סיכו, _gaco, יגען_, --,
   {{0x7aed08a9,0x6284736a,0xc8780233,0x00000000}},	//   čatl, meio, liğe_, --,
   {{0x614305cb,0x00000000,0x00000000,0x00000000}},	//   _фера, --, --, --,
   {{0x69dd0181,0x798b00eb,0x3f9801ff,0xa5bb736b}},	//   úsen, _asgw, _urru_, ncór,
   {{0x628f03be,0x8f3700ca,0x62840231,0x00000000}},	//   _xaco, _כאלו_, neio, --,
   {{0x63bc0ce3,0xdb1801f9,0x8d2a004d,0x00000000}},	//   hyrn, nyvé, _розв_, --,
   {{0x6f02736c,0x8c6609b4,0x20070034,0x9873345a}},	//   lloc, _خطرن, żnie_, ольц,
   {{0x627e0034,0xe81102d5,0x48a7065c,0x00000000}},	//   _złoż, डेला_, ртым_, --,
   {{0x98ab00d9,0x7bdb00ca,0xfaa31a0c,0x63bc736d}},	//   īcā_, _בקבו, _махо, dyrn,
   {{0x628f736e,0x9934006f,0xe894325f,0x80bc00a4}},	//   _raco, _افتت, _галь, _एवढे,
   {{0x628f2364,0x6f0250e3,0xb60800d8,0x00000000}},	//   _saco, hloc, _suší, --,
   {{0x628f736f,0x6aa27370,0xd9e80081,0x6f027371}},	//   _paco, _knof, _পরিম, kloc,
   {{0x6f0200d3,0x4733001c,0x02a41a9f,0xf1bf00fe}},	//   jloc, _بروز, орум, _ngác_,
   {{0x51871062,0x200539a2,0x672d00e7,0x00000000}},	// [7210] шува, _šli_, _čaji, --,
   {{0x92d700c7,0xd9e80081,0xa7fc026a,0x27240134}},	//   াকে_, _পরাম, ygıl, _ịnya_,
   {{0x33950080,0x628f5eae,0xb6080094,0x6f0213c5}},	//   _الجز, _taco, _tuší, floc,
   {{0x62840131,0x66c64cf5,0x00000000,0x00000000}},	//   ceio, _kóka, --, --,
   {{0x9a120294,0x6b9a7372,0x127a006e,0x00000000}},	//   _dọkụ, _artg, _גארע, --,
   {{0x8c42261f,0x6aa2044c,0x00000000,0x00000000}},	//   пеше, _anof, --, --,
   {{0xde67013d,0x627e007f,0x00000000,0x00000000}},	//   _възп, _włoż, --, --,
   {{0x6f025b13,0xa7fc026a,0x3a98007b,0x6aa203a8}},	//   cloc, rgıl, атью_, _cnof,
   {{0x7e7b7373,0xe8f92458,0xa2ba05d6,0x627e007f}},	//   _ibup, лли_, _एकस्, _ułoż,
   {{0x66d60087,0xd7020557,0x2d8d028d,0x6aa27374}},	//   mški, ोष्ठ_, _isee_, _enof,
   {{0x2cf50096,0x7ae4007e,0x30fa0354,0x62840350}},	//   ेतील_, čitr, ्ततः_, yeio,
   {{0x66c60088,0x5b1507c8,0x66e628dc,0x9abc0090}},	//   _bóka, _умет, сома, _luċj,
   {{0x7e7b0294,0x66080034,0x290e0090,0xdddb00e4}},	//   _mbup, ędko, _fhfa_, _lauž,
   {{0x66d6013f,0x3a3f0167,0x2d8d0350,0x63bc02c3}},	//   iški, lbup_, _msee_, tyrn,
   {{0xdce2005f,0x7e7b7375,0x78a37376,0x97350f98}},	//   stoć, _obup, _innv, _اعتص,
   {{0x4433023e,0x86465155,0x7e7b0134,0x2d8d0294}},	//   _efx_, _униж, _nbup, _osee_,
   {{0x95560602,0x463b006e,0x6f027377,0xe2971bc1}},	// [7220] _اخبا, _געפע, vloc, щат_,
   {{0x656606a8,0xb4db05fe,0xb4660291,0x62847378}},	//   mukh, ssàr, _укол, seio,
   {{0x644e7379,0xee3a1b4d,0x0eba004b,0x59d92337}},	//   mabi, гне_, луды_, _बेसर,
   {{0x644e737a,0x61e903f1,0xf4130054,0x91e6186f}},	//   labi, _žele, _מפת_, _гоме,
   {{0x1dd2000f,0x2240737b,0x63a3009c,0x00000000}},	//   _देखत, mbik_, _ànnr, --,
   {{0x644e737c,0x7e7b405f,0x6f02737d,0x8fa6737e}},	//   nabi, _ebup, sloc, _лаге,
   {{0x09b50081,0xdb09025b,0x6f0226c4,0x00000000}},	//   _জেলা, žnýc, ploc, --,
   {{0x65660060,0x644e2bd4,0x290e0172,0x00000000}},	//   kukh, habi, _shfa_, --,
   {{0x644e737f,0x41de030b,0xdddb7380,0x79896aa7}},	//   kabi, _नेमस, _zauž, gwew,
   {{0xd90d00d0,0xa2d80285,0x26c200c2,0xab2a5e39}},	//   نین_, नोत्, ekko_, _божа_,
   {{0x644e7381,0xda7a008f,0x00000000,0x00000000}},	//   dabi, _бял_, --, --,
   {{0xb5fb0037,0x8afe03e3,0x79890361,0x00000000}},	//   lgái, buƙa, bwew, --,
   {{0x3a2600b3,0xd7c7001c,0x7af301f9,0x779200d1}},	//   _igop_, لویه_, űjtö, زیکا,
   {{0x316004c3,0x26cb13de,0x97a62a61,0xb5fb7382}},	//   driz_, shco_, _грил, ngái,
   {{0xf8db00a1,0x241904d9,0x187700ca,0x44330227}},	//   _תחומ, ровы_, _העור_, _vfx_,
   {{0x65660201,0x7b1504e9,0x386e014b,0x00000000}},	//   bukh, _ušut, _hcfr_, --,
   {{0x2d99016d,0xa2da030b,0xcfd60033,0x31600218}},	// [7230] _àsex_, _नगर्, _তুলন, griz_,
   {{0x644e7383,0x660d7384,0x764f0034,0x9055004d}},	//   cabi, _izak, lacy, івец,
   {{0x7bde124d,0x224064c3,0xdea1001c,0x3946033c}},	//   úpul, bbik_, ویسی, _lwos_,
   {{0x764f7385,0x395f0138,0x57fb00ca,0x316000a7}},	//   nacy, yrus_, נלאו, briz_,
   {{0x31600451,0x9cf5004d,0x66d600c6,0x00000000}},	//   criz_, озді, uški, --,
   {{0x66d6013f,0x224b7386,0x60c7007e,0x212b009c}},	//   rški, _heck_, _uljm, _iuch_,
   {{0x764f00a5,0x3ea41ba6,0x3ec40103,0xa3df00bc}},	//   kacy, _fnmt_, ártó_, _देम_,
   {{0x644e7387,0xcfb20081,0x7b1502ef,0x212b00d8}},	//   zabi, _টেকন, _ašur, _kuch_,
   {{0x644e7388,0x7e640037,0x395f7389,0x59d90dc4}},	//   yabi, óipe, urus_, _बेशर,
   {{0xf7710678,0x212b0054,0x26c9738a,0x395f34ae}},	//   واج_, _much_, _alao_, rrus_,
   {{0x644e738b,0x16aa0318,0xb69b0161,0x660d738c}},	//   vabi, авни_, rlân, _azak,
   {{0x644e738d,0x764f738e,0x395f738f,0x09e80033}},	//   wabi, gacy, prus_, _পররা,
   {{0x644e7390,0x7afb7391,0xa50a2a6e,0x7ae97392}},	//   tabi, mout, иема_, mnet,
   {{0x7ae97393,0x660d007e,0x2eb60034,0x66d00139}},	//   lnet, _dzak, _अक्त, _bòkù,
   {{0x212b3477,0xa5bb2733,0x36e90018,0x660d4944}},	//   _auch_, scóp, _گروپ_, _ezak,
   {{0x7ae97394,0x31601f8b,0x212b01bf,0x644e7395}},	//   nnet, triz_, _buch_, sabi,
   {{0xe0da247a,0x644e7396,0x7ae97397,0x2b400995}},	// [7240] ава_, pabi, inet, ćici_,
   {{0x316002a7,0x66047398,0x212b0891,0x7afb7399}},	//   rriz_, _iyik, _duch_, hout,
   {{0x212b02e2,0x2905739a,0x7afb739b,0x3f9c2347}},	//   _euch_, illa_, kout, ívu_,
   {{0x28d91362,0xe29a4766,0x2eb9009d,0x7afb30ca}},	//   योति, _там_, _आवृत, jout,
   {{0x7ae9739c,0x7afb739d,0x0caa22f9,0x3f860031}},	//   dnet, dout, итки_, ňou_,
   {{0xd0e80260,0x7ae901e9,0x659b0266,0x764f739e}},	//   _اکرم_, enet, יינק, zacy,
   {{0xf7670e8c,0x7afb739f,0x1fb573a0,0xb5fb0076}},	//   _تا_, fout, _естр, rgái,
   {{0x290573a1,0x7afb73a2,0x629673a3,0x673800e7}},	//   ella_, gout, ndyo, _rtvj,
   {{0x764f0126,0x68fa00d3,0x660473a4,0x00000000}},	//   vacy, totd, _nyik, --,
   {{0x1d0a0465,0x26c908a9,0xb17b006e,0x764f73a5}},	//   _тези_, _slao_, סטיר, wacy,
   {{0x660d0068,0x7afb73a6,0x7ae973a7,0xa09b00c1}},	//   _szak, bout, bnet, בייט,
   {{0x99e80081,0x29050084,0xd6db73a8,0x66040079}},	//   _পরীক, alla_, рто_, _byik,
   {{0x764f62c6,0x6724048e,0xe9cf001c,0x2bde1101}},	//   racy, _diij, _لغو_, _केतू_,
   {{0x7ae073a9,0x02b80789,0x6724010a,0x212b0c6f}},	//   limt, _इकॉन, _eiij, _ruch_,
   {{0x57f304f5,0x212b73aa,0x53341e33,0x224b73ab}},	//   _општ, _such_, дест, _peck_,
   {{0x25a60087,0x79820174,0xb88200b6,0x629600f9}},	//   _šole_, _kpow, řídi, gdyo,
   {{0x69c073ac,0x660d73ad,0xd52d00fe,0xb42707e8}},	// [7250] nyme, _uzak, _dựn, _وعدو,
   {{0xcf9b15de,0x7ae073ae,0x7ae9030b,0x7afb73af}},	//   ије_, himt, znet, zout,
   {{0x764d0063,0x7ae91564,0x7ae073b0,0x224b73b1}},	//   _keay, ynet, kimt, _teck_,
   {{0x798200a5,0xe8a70e19,0x23fa00ca,0x752d286d}},	//   _opow, _कच्च, _להתא, _kuaz,
   {{0xa3df0b79,0x290573b2,0xdca51e9e,0xf53f017a}},	//   _देत_, ylla_, зали, npå_,
   {{0x91ba00a1,0x69c02b65,0xd7ca0096,0x78b80172}},	//   _המשי, dyme, ानाच, _novv,
   {{0x447c0130,0x79820139,0x7afb0127,0x7e640037}},	//   ינגע, _apow, tout, óipc,
   {{0xfbd000cd,0xe7fe0251,0x7ae073b3,0x4aa90036}},	//   خته_, _उड़ा_, gimt, скин_,
   {{0xaca30134,0x290573b4,0x7afb4226,0x69c05b95}},	//   _ahụl, tlla_, rout, gyme,
   {{0x7ae973b5,0x6d4903e3,0x88c90315,0x66040169}},	//   snet, _iwea, слов_, _ryik,
   {{0xb8e30521,0x07a5325f,0x7ae96f61,0x764d73b6}},	//   _एक_, чанн, pnet, _beay,
   {{0x752d010a,0x6a94004d,0x3f8305db,0xf1bf00fe}},	//   _buaz, _оріє, _mpju_, _ngáo_,
   {{0x6b5000e3,0xf53f0537,0x00000000,0x00000000}},	//   _tógá, gpå_, --, --,
   {{0x69d40dba,0x31690062,0x3f830090,0x2a6d00bc}},	//   _बेटी, duaz_, _opju_, lgeb_,
   {{0x68e173b7,0x6e2901c2,0x99dd0146,0x03a300c2}},	//   mild, _ogeb, raňu, ниро,
   {{0x6e2973b8,0x61e92266,0xc32300f6,0x2a6d00bc}},	//   _ngeb, _žela, емск, ngeb_,
   {{0xdb0a0103,0x752d0036,0xa2cd50a4,0x316901ff}},	// [7260] ínés, _guaz, _सतर्, guaz_,
   {{0x6e290172,0xb466163d,0x68e173b9,0x3ce00096}},	//   _ageb, _экол, nild, _औषधे_,
   {{0x752d01c8,0x00000000,0x00000000,0x00000000}},	//   _zuaz, --, --, --,
   {{0x68e173ba,0x2d9f02ac,0x25a00141,0xdce200c6}},	//   hild, _brue_, _kril_, ruoč,
   {{0x68e173bb,0x1d0a1121,0xe29b00ca,0x2d9f014b}},	//   kild, беди_, _השכר, _crue_,
   {{0x6e2973bc,0x69c01ea1,0x00000000,0x00000000}},	//   _egeb, vyme, --, --,
   {{0x6fb61dec,0x79820034,0x68e1071d,0xf65f02b6}},	//   _عمرا, _spow, dild, mhæv_,
   {{0x78b873bd,0x66c6003e,0x2d9f0ac9,0x8938180b}},	//   _sovv, _bókm, _frue_, опис_,
   {{0x7ae073be,0x2d9f73bf,0x3914007b,0xeaaf0037}},	//   rimt, _grue_, ммир, اعى_,
   {{0x7ae073c0,0xd90e00cd,0x68e173c1,0x47341a0c}},	//   simt, دیت_, gild, мнос,
   {{0x25a00063,0x69c00178,0xa09b006e,0x799b0172}},	//   _aril_, syme, זייט, avuw,
   {{0x25a00db1,0xe0df0154,0x69c0037a,0x00000000}},	//   _bril_, _awòl_, pyme, --,
   {{0x68e173c2,0xaaa9030b,0x18a61107,0x2b4000cb}},	//   bild, कारक, _надм, ćicu_,
   {{0xf53f017a,0x65600076,0x00000000,0x00000000}},	//   rpå_, ámha, --, --,
   {{0xa87b00a1,0x187b00a1,0xd25b1402,0xe0df0383}},	//   _האור, _הטוב, йца_, _dwòl_,
   {{0x31690634,0x752d0350,0x00000000,0x00000000}},	//   tuaz_, _tuaz, --, --,
   {{0x44f510f7,0xc2c400e3,0x00000000,0x00000000}},	// [7270] _опис, ريكي, --, --,
   {{0x66f201d3,0x6e29009c,0x31690634,0x00000000}},	//   māka, _sgeb, ruaz_, --,
   {{0x2fc700ef,0x66f200d9,0x6d494f2d,0x31690062}},	//   áng_, lāka, _swea, suaz_,
   {{0xd0920092,0x68e173c3,0xe81402d5,0xde580120}},	//   _müəs, zild, _डरना_, заці_,
   {{0xfe70003f,0x3d09009d,0x66f200d9,0x68e100a7}},	//   ادم_, ितले_, nāka, yild,
   {{0x2fc700ef,0x2bde0006,0x4e18001c,0x68e1013c}},	//   ơng_, _केहू_, ستند_, xild,
   {{0xddc23b7b,0xfc4602c6,0xaaa906e4,0xddc90141}},	//   rgoš, _říci_, कालक, _ubež,
   {{0x6d4973c4,0x68e1057a,0x2d9f00a1,0x6e2973c5}},	//   _twea, wild, _true_, _ugeb,
   {{0xac2773c6,0xa3df007a,0x2f1800c2,0x7c870c79}},	//   _ефек, _देस_, _хоть_, _нуже,
   {{0x5c741b9d,0xa3c2023a,0x57e9007b,0xddc90090}},	//   _плут, ्नम_, ждом_, _mbeż,
   {{0x68e108bb,0xc05200ca,0x6ab9008c,0x2c5f00e8}},	//   rild, כזי_, _towf, rādē_,
   {{0x68e173c7,0xabfa00ca,0xc4c900ca,0xddc900bd}},	//   sild, _והער, _דג_, _obeż,
   {{0x68e173c8,0x7bc373c9,0x66f201d3,0x7afc0103}},	//   pild, lynu, gāka, _írta,
   {{0xa3df018b,0xe8f836bf,0x2bd10287,0x00000000}},	//   _देह_, _елі_, तनपा, --,
   {{0x02c9007d,0x46f608c3,0x00000000,0x00000000}},	//   रसंभ, _очит, --, --,
   {{0x66f200d9,0x25763229,0x00000000,0x00000000}},	//   bāka, pæl_, --, --,
   {{0x7bc373ca,0xf1de3212,0x66f201d3,0x273300fe}},	// [7280] hynu, _नेशन, cāka, _hãn_,
   {{0xdcfb00e9,0xa3df0efd,0x25bf042c,0x00000000}},	//   _osuđ, _देव_, äule_, --,
   {{0x443a73cb,0x00000000,0x00000000,0x00000000}},	//   _ifp_, --, --, --,
   {{0x6700099d,0x273300de,0x6e2d0087,0x443a00c4}},	//   ैतिक_, _mãn_, žabn, _hfp_,
   {{0xb5fb0018,0x471b006e,0x20561896,0xdc390233}},	//   lgár, קונג, _отвр, _açıd,
   {{0xdca31312,0x23650141,0x40950b1b,0x44382d36}},	//   качи, šlje_, _прст, ncr_,
   {{0x201e02b4,0x9f880088,0x28b10179,0xd9b80be4}},	//   _àti_, _góða_, जानि, ेन्ट,
   {{0x4438102f,0x00000000,0x00000000,0x00000000}},	//   hcr_, --, --, --,
   {{0x645e6bea,0xadba0037,0x225d0034,0xdee30582}},	//   _odpi, _بهذا_, ówki_, _роти,
   {{0x443a73cc,0xb5fb0103,0x66f201d3,0x00000000}},	//   _nfp_, zgás, vāka, --,
   {{0xda6f73cd,0x1bf20a50,0xbfec0033,0xeb9a0012}},	//   _ия_, _अखिल_, _করুণ_, _фие_,
   {{0x25a602dd,0x66f200d9,0x443a667f,0x273300de}},	//   _šola_, tāka, _afp_, _dãn_,
   {{0x6d4201e9,0x00000000,0x00000000,0x00000000}},	//   npoa, --, --, --,
   {{0x66f200d9,0xf76f001c,0x61e9033b,0xf4840399}},	//   rāka, دای_, _želo, кусн,
   {{0xa3df03a2,0x25ad020a,0x00000000,0x00000000}},	//   _देश_, ţel_, --, --,
   {{0x2bb634d8,0x326473ce,0x00000000,0x00000000}},	//   _अपना, ктув, --, --,
   {{0xa3df0b89,0xb5fb0103,0x02df0336,0xa2a00285}},	// [7290] _देर_, rgás, _नगीन, _ऑफर्,
   {{0x4395017b,0x395901ab,0x00000000,0x00000000}},	//   _заос, ássi_, --, --,
   {{0x645573cf,0x66c601cd,0x00000000,0x00000000}},	//   mazi, _bókh, --, --,
   {{0x7c3a2b32,0xa25b00fd,0xe0df05aa,0xddc902a1}},	//   _aftr, _clôt, _kwòk_, _tbeż,
   {{0x2d5800d3,0x00000000,0x00000000,0x00000000}},	//   дичь_, --, --, --,
   {{0x645573d0,0xeb9973d1,0x8b950291,0xe0570260}},	//   nazi, зик_, ерич, _آیات_,
   {{0x780d5fbb,0x20110172,0xe1ff033c,0x00000000}},	//   _हरेक_, _uzzi_, _gcór_, --,
   {{0x645573d2,0x78aa0154,0xa3c23fac,0x628d73d3}},	//   hazi, _anfv, ्नत_, neao,
   {{0x645573d4,0x68ef0610,0x7bce0364,0xdce902a1}},	//   kazi, écdo, _übun, _eseġ,
   {{0xb4be0006,0xb8810146,0x6d59101e,0x9d1400d3}},	//   _आवे_, _číse, mswa, _адуч,
   {{0x645573d5,0x6d594900,0xa3df00aa,0xdcfb0995}},	//   dazi, lswa, _देल_, _usuđ,
   {{0x7ac473d6,0x273300fe,0xa5bb034f,0x2bd80403}},	//   _исче, _vãn_, lcóy, _भेटा,
   {{0x6d5973d7,0xe9ce28f1,0x6aab028d,0xe8ee73d8}},	//   nswa, _ск_, _ingf, _бл_,
   {{0xbebd01b3,0x2bb60179,0x2b9100e7,0x443a02a1}},	//   _siūl, _अपमा, _kšc_, _qfp_,
   {{0x443a0036,0x63833719,0x07a54c46,0x6e3b0172}},	//   _vfp_, лгра, _чайн, _ofub,
   {{0x6d5965ba,0xe8140789,0x443a73d9,0x3d160034}},	//   kswa, _डरता_, _wfp_, _पीने_,
   {{0x64a673da,0x645573db,0xe0461b77,0xe1ff0037}},	// [72a0] _запа, bazi, ензи, _scór_,
   {{0x64550465,0xc05900d6,0xdce2003d,0x6e3b06b0}},	//   cazi, дії_, rroċ, _afub,
   {{0x9e66355b,0xb4cc0cce,0x6d5901cb,0x66f200e8}},	//   евед, लसी_, eswa, nāko,
   {{0x481600c1,0x66c6003e,0xddc000b6,0xaff70076}},	//   ײַבן_, _bóki, _zemř, رفنا_,
   {{0xdd940450,0x6da308c3,0x6d5973dc,0x1d0a73dd}},	//   талы, лица, gswa, педи_,
   {{0x6e3b0172,0x00000000,0x00000000,0x00000000}},	//   _efub, --, --, --,
   {{0x7ac60084,0x6d4201ff,0xa3c233dc,0x212a01b9}},	//   еспе, spoa, ्नि_, _iibh_,
   {{0x645573de,0x31920154,0xc33300ca,0xdce20206}},	//   zazi, _kņz_, נוח_, mroč,
   {{0x645573df,0x4c8615db,0x6d590a4b,0xdce200d4}},	//   yazi, _плав, cswa, lroč,
   {{0xa3c234d8,0xeb9a07ed,0xd7fa73e0,0xdbd600c2}},	//   ्ना_, _низ_, зум_, _pääo,
   {{0xa3df0067,0x6455513e,0x2cac73e1,0x7b050072}},	//   _दें_, vazi, _indd_, góus,
   {{0x64555b7d,0x56940243,0x212a0076,0x00000000}},	//   wazi, гают, _libh_, --,
   {{0x645573e2,0x7ae273e3,0xb9100139,0x00000000}},	//   tazi, _imot, _mulẹ_, --,
   {{0x7ae20074,0xdce2025b,0xab6402e2,0x212a030a}},	//   _hmot, kroč, _grüß, _nibh_,
   {{0x645573e4,0xa7370037,0x7b050072,0x7ae20094}},	//   razi, _كثير_, cóus, _kmot,
   {{0xdce202dd,0x645573e5,0x290c73e6,0x212a01ec}},	//   droč, sazi, llda_, _aibh_,
   {{0x645573e7,0x69d6026a,0x7ae2083e,0x00000000}},	// [72b0] pazi, _üyed, _mmot, --,
   {{0x657d73e8,0xdce9009e,0x00000000,0x00000000}},	//   mtsh, _iseħ, --, --,
   {{0x6d4073e9,0x6d590372,0x61ea00a7,0x6d44020a}},	//   _atma, wswa, _əllə, ţial,
   {{0x6d5973ea,0xf41200a1,0x59b01d7d,0x212a009c}},	//   tswa, _כפי_, जमार, _eibh_,
   {{0x657d0060,0x656f045d,0x6d5973eb,0x224973ec}},	//   ntsh, nuch, uswa, mbak_,
   {{0xdce273ed,0x6d5973ee,0x22490381,0x2cac0169}},	//   broč, rswa, lbak_, _cndd_,
   {{0x6d5973ef,0x09c9009d,0x6d4073f0,0xdb1800c2}},	//   sswa, िन्य, _etma, kyvä,
   {{0x656f73f1,0xada60220,0xeab100e3,0x290c73f2}},	//   kuch, _slúž, شعب_, elda_,
   {{0x3ead73f3,0x656f0174,0x657d690a,0xe9a900d1}},	//   _inet_, juch, jtsh, بگان_,
   {{0xa3d10336,0x656f0074,0x3ebf0cad,0x25a60087}},	//   वना_, duch, _hout_, _šolo_,
   {{0x366a73f4,0x3ebf06a3,0x3a7505c7,0x00000000}},	//   мано_, _kout_, _алер, --,
   {{0x656f73f5,0xdb0100fd,0x7ae20141,0x28a601e4}},	//   fuch, _orlé, _gmot, _कोठि,
   {{0x3ead73f6,0x3ebf0381,0xe7780103,0x3a2f039f}},	//   _mnet_, _mout_, ولیں_, _iggp_,
   {{0x7d0373f7,0x7ae21548,0x31694fc6,0x224901ff}},	//   nons, _zmot, draz_, ebak_,
   {{0xe7b212eb,0x3ead73f8,0x212a1ab6,0x68e3039f}},	//   _نمود, _onet_, _ribh_, _imnd,
   {{0x656f73f9,0x212a117b,0x657d178f,0x7d0318d1}},	//   buch, _sibh_, btsh, hons,
   {{0x656f0081,0x26d20079,0x00000000,0x00000000}},	// [72c0] cuch, _ilyo_, --, --,
   {{0x7d0300d6,0x3ebf201c,0xe04333d4,0x3ead73fa}},	//   jons, _aout_, инуи, _anet_,
   {{0x7d0373fb,0x3ebf73fc,0x6d40009e,0xa3df1c3b}},	//   dons, _bout_, _stma, _देऊ_,
   {{0xcfa90080,0x316973fd,0x3ebf05ef,0xe35700ca}},	//   عالم_, braz_, _cout_, _בשטח_,
   {{0x29073b0d,0x7d0373fe,0x3ebf02f1,0x6f0201ee}},	//   _okna_, fons, _dout_, rooc,
   {{0x7d0373ff,0x7ae245ca,0x5043550d,0x26c00072}},	//   gons, _smot, _верб, _loio_,
   {{0x3ebf7400,0xa3e80336,0x656f7401,0x3ead0231}},	//   _fout_, _मेम_, zuch, _fnet_,
   {{0xf8ca06ae,0x49740396,0x3ebf7402,0xb9983f28}},	//   िस्प, глис, _gout_, евих_,
   {{0x0d770979,0x6d400160,0xc87801e8,0xa3df17e5}},	//   _لینک_, _utma, liği_, _देई_,
   {{0x52bf0176,0x1be310cf,0xa8a62863,0x3ebf01c0}},	//   _एक्स, _केवल_, трик, _zout_,
   {{0x656f7403,0xdb1800c2,0xc8780233,0xdce9009e}},	//   wuch, tyvä, niği_, _sseħ,
   {{0x656f7404,0x7ae27405,0x7c270103,0x657d1f60}},	//   tuch, _umot, _újra, ttsh,
   {{0x28a60096,0xb8960037,0x656f037a,0xd90f0103}},	//   _कोथि, _للشع, uuch, _ڈیٹ_,
   {{0x656f7406,0x657d7407,0xdb18007b,0x645a11e9}},	//   ruch, rtsh, syvä, ótip,
   {{0x68e87408,0x656f02dc,0x657d7409,0x03c42976}},	//   midd, such, stsh, астм,
   {{0x656f00ac,0xc87801e8,0x68e8740a,0x63a52a1e}},	//   puch, diği_, lidd, _vrhn,
   {{0x3ebf0383,0x22494ae2,0x7d03740b,0x52150b21}},	// [72d0] _rout_, rbak_, yons, удат,
   {{0x660d16e5,0x3ebf057a,0x3169740c,0x68e80517}},	//   _iyak, _sout_, rraz_, nidd,
   {{0x7d03740d,0x3ebf1428,0x672d0239,0x00000000}},	//   vons, _pout_, _kiaj, --,
   {{0x660d38d0,0x26c00072,0x68e8740e,0x7d03740f}},	//   _kyak, _xoio_, hidd, wons,
   {{0x629d7410,0x68e80517,0x26d20216,0x3ebf0154}},	//   _iaso, kidd, ëzoi_, _vout_,
   {{0x629d0018,0x3ebf06a3,0x660d0549,0x3ead068f}},	//   _haso, _wout_, _myak, _wnet_,
   {{0x3ebf7411,0x7d037412,0x629d7413,0x68e87414}},	//   _tout_, rons, _kaso, didd,
   {{0x629d7415,0x7d037416,0x672d7417,0x1a65001c}},	//   _jaso, sons, _niaj, ایشی_,
   {{0x7d03505d,0x660d3f68,0x629d1dc3,0xdd94022a}},	//   pons, _nyak, _maso, _каты,
   {{0x629d026d,0x68e85908,0x26c00072,0x26d90052}},	//   _laso, gidd, _soio_, ëron_,
   {{0x660d7418,0x28d914e5,0xab94004d,0x26c00042}},	//   _ayak, योगि, _вихі, _poio_,
   {{0x660d0549,0x28b1007a,0x4e170f77,0x02d200bc}},	//   _byak, जाहि, _तराई_, _सतेन,
   {{0x672d1bd6,0x7ae90220,0x68e87419,0x660d0193}},	//   _diaj, miet, bidd, _cyak,
   {{0x7ae9741a,0x660d741b,0x6abb033b,0xa3c2167f}},	//   liet, _dyak, ljuf, ्नल_,
   {{0x629d741c,0x2905741d,0x660d5784,0x69c90188}},	//   _baso, mola_, _eyak, lyee,
   {{0x2905741e,0x7ae9741f,0xe2977420,0x6abb4a2d}},	//   lola_, niet, лас_, njuf,
   {{0x660d67d1,0x21670acf,0x3f8a00ec,0x69c963b6}},	// [72e0] _gyak, лити_, _spbu_, nyee,
   {{0x7ae97421,0xc87801e8,0x69c90188,0x76561a4a}},	//   hiet, tiği_, iyee, _heyy,
   {{0x7ae97422,0x629d7423,0x2be3009d,0x6f1b036b}},	//   kiet, _faso, _केलं_, _bhuc,
   {{0x629d0c56,0x29057424,0xc878026a,0x7ae97425}},	//   _gaso, hola_, riği_, jiet,
   {{0x29057426,0x7ae97427,0x69c9023e,0x54a50504}},	//   kola_, diet, jyee, _صحیف,
   {{0x629d7428,0x62840451,0x2f150212,0x7536037a}},	//   _zaso, lfio, råga_, _muyz,
   {{0x629d7429,0x7ae92898,0x68e80407,0x69c90188}},	//   _yaso, fiet, vidd, eyee,
   {{0xa3bc05a7,0x7ae94ae5,0x5a34016e,0x62840d76}},	//   _आपन_, giet, шнит, nfio,
   {{0x6da36f40,0x62840150,0x2bb60296,0xfe4300d3}},	//   _лита, ifio, _अपवा, _ынто,
   {{0x672d0350,0x660d02a4,0x00000000,0x00000000}},	//   _siaj, _ryak, --, --,
   {{0x7ae9742a,0xbec200dd,0x68e8742b,0x69c9008a}},	//   biet, _çësh, ridd, ayee,
   {{0x68e8742c,0x7ae92a21,0x69c9742d,0x00000000}},	//   sidd, ciet, byee, --,
   {{0x672d3072,0x2905742e,0x62fc0033,0x7bca742f}},	//   _viaj, bola_, ্ষায়_, lyfu,
   {{0x29051258,0x660d0051,0x629d7430,0xa3c200a4}},	//   cola_, _vyak, _saso, ्नं_,
   {{0xa3df0d0b,0x629d2f95,0xb2ab3d7c,0x672d023e}},	//   _देख_, _paso, нтаж_, _tiaj,
   {{0x660d0154,0x00000000,0x00000000,0x00000000}},	//   _tyak, --, --, --,
   {{0xdcfb03ce,0x2018061d,0x660d0201,0xf1bf00fe}},	// [72f0] _upuć, _azri_, _uyak, _ngát_,
   {{0x629d60cc,0x7ae901e9,0x25a906a8,0x95840034}},	//   _waso, ziet, _iral_, żący,
   {{0x5f951807,0x629d7431,0x7a2b026a,0x8c9f02d5}},	//   риет, _taso, _kötü, _गोगो,
   {{0xa28300cd,0x29057432,0x69c9690e,0x25a9008b}},	//   _دیرو, zola_, yyee, _kral_,
   {{0x7ae97433,0xe80b000f,0x29050517,0x4e780f36}},	//   viet, _सुना_, yola_, احمد_,
   {{0x7ae900a5,0x69c901fa,0x4c8402b7,0x29057434}},	//   wiet, vyee, йлів, xola_,
   {{0x7ae97435,0x273a00dd,0x29053126,0x2fc70149}},	//   tiet, _nën_, vola_, ängd_,
   {{0x2bb6099d,0x64577436,0x69db02a7,0x29057437}},	//   _अपरा, _lexi, tzue, wola_,
   {{0x29057438,0xe8f91456,0xc8b50ab3,0xc5f40022}},	//   tola_, кли_, асны, _keɓe_,
   {{0x273a00dd,0x69db4281,0x69c90188,0xddc00233}},	//   _bën_, rzue, ryee, _hemş,
   {{0x7ae97439,0x25a900a6,0xf09200a1,0x3f81743a}},	//   piet, _aral_, חני_, nthu_,
   {{0x29051c7b,0x28d9074c,0x2d8d0134,0x25a91d63}},	//   sola_, योजि, _kpee_, _bral_,
   {{0x66f200d9,0x25a90036,0x6457743b,0xdb24003e}},	//   nāki, _cral_, _bexi, _ósát,
   {{0xccf20130,0x20f42918,0x290505ea,0x934611cc}},	//   ַכן_, _आदेश_, qola_, инге,
   {{0x42561f0d,0x395f743c,0x6457743d,0xd7630470}},	//   итат, lsus_, _dexi, _انبی,
   {{0x7a2b07d1,0x3a3f134a,0xd7fa00a1,0x443302a1}},	//   _götü, ncup_, _בהצל, _egx_,
   {{0xe2970476,0x00e62ca3,0x628400f0,0x23276e88}},	// [7300] шат_, ажан, rfio, роти_,
   {{0xe0d7131b,0xf1bf08a8,0xe3e70068,0x66c6003e}},	//   аву_, _agás_, اکین_, _tóks,
   {{0xdb01033c,0x6e460a85,0x395f743e,0x00000000}},	//   _arlí, لنام, hsus_, --,
   {{0x395f743f,0xe0df022b,0x7e7b0172,0xf2a60012}},	//   ksus_, _bwòs_, _ccup, _тимп,
   {{0x3a3f6776,0xe2973546,0x61e97440,0x4096001f}},	//   dcup_, _тая_, _želv, _крвт,
   {{0x3160020e,0x7b662a72,0x23ba04f8,0x00000000}},	//   msiz_, атие, _उपाद, --,
   {{0x3160071d,0x7e7b01cb,0x645c0062,0xee3a4214}},	//   lsiz_, _fcup, iari, _анб_,
   {{0x645c7441,0x8f9b13b6,0x22407442,0x2fc71683}},	//   hari, _בילי, ncik_, änge_,
   {{0xee0a0e21,0x31600587,0x66f200d9,0xe0df022b}},	//   _реал_, nsiz_, cāki, _gwòs_,
   {{0x645c7443,0x28a6269c,0xdbdc0146,0x98b8016d}},	//   jari, _कोशि, lším, улот_,
   {{0x645722e7,0x103700a1,0x22400332,0xb0370142}},	//   _rexi, יטים_, kcik_, יניג_,
   {{0x25a914b1,0x28a61c0a,0x3160008b,0xdbdc00d4}},	//   _pral_, _कोरि, ksiz_, nším,
   {{0xe5c4036a,0xceb3021e,0xc6f8083c,0x00000000}},	//   осро, קיש_, рнях_, --,
   {{0x645c7444,0x3160013c,0x55070077,0x00000000}},	//   gari, dsiz_, рчма, --,
   {{0xa3bc02e8,0x2ba90d43,0xd82f00d3,0xd6db21be}},	//   _आपण_, किया, _фэ_, _атп_,
   {{0x66e40396,0xdbdc0146,0x645c00aa,0x39460034}},	//   _моја, jším, aari, _ktos_,
   {{0x765d3d4f,0x948700d3,0xf4870450,0x00000000}},	// [7310] masy, _кынд, _кунн, --,
   {{0x44992082,0x765d7445,0x66f200e8,0xbebd00c6}},	//   _свою_, lasy, vāki, _liūt,
   {{0x4427026e,0x9295345e,0x32070034,0x2fc77446}},	//   _àn_, _ланц, łny_, âng_,
   {{0x765d232e,0x61e9005f,0x3f810150,0x25a60087}},	//   nasy, _želu, rthu_, _šoli_,
   {{0x8c455565,0x6da502ec,0x395f00a7,0x3946023e}},	//   беле, сила, xsus_, _ntos_,
   {{0x7c872f9f,0x66f201d3,0x2a6600b3,0x395f00bc}},	//   руде, rāki, _adob_, vsus_,
   {{0x765d7447,0x39467448,0x22597449,0x00000000}},	//   kasy, _atos_, _kesk_, --,
   {{0x645c744a,0x213901e5,0x395f007a,0xc33400a1}},	//   zari, _kush_, tsus_, חוק_,
   {{0x645c744b,0x3a3f68ee,0xf99100e3,0x765d744c}},	//   yari, rcup_, سبة_, dasy,
   {{0x645c744d,0x71d800a1,0x2259472a,0x3a3f01ce}},	//   xari, יוחד_, _lesk_, scup_,
   {{0x395f025a,0x645c535f,0x3946744e,0x69d60233}},	//   ssus_, vari, _etos_, _üyen,
   {{0x765d744f,0xc4c900ca,0x31600e26,0x2b810034}},	//   gasy, _אג_, ysiz_, móc_,
   {{0xa9690114,0x95831402,0x2139020a,0x00000000}},	//   _сила_, пляе, _nush_, --,
   {{0x2ed43ec9,0xdb083ece,0x316000ad,0x984b007b}},	//   _दत्त, _ardè, vsiz_, _ряда_,
   {{0x4adb007a,0x6b830027,0x765d7450,0xf78900fc}},	//   _बताव, ntng, basy, _deçà_,
   {{0x645c7451,0x31607452,0x3d09009d,0x2259015e}},	//   sari, tsiz_, ाकडे_, _cesk_,
   {{0x39460124,0x645c091a,0x644e028d,0xe80b09a1}},	// [7320] _xtos_, pari, pbbi, _सुता_,
   {{0x316007aa,0x645c7453,0x15ee0179,0x21390216}},	//   rsiz_, qari, _चेयर_, _dush_,
   {{0x4444004f,0xbbb60efd,0x3160071d,0xef8605da}},	//   _if_, _अपेक, ssiz_, слеп,
   {{0xe8e00028,0xad660076,0x3160047e,0x44447454}},	//   _thủy_, ماته, psiz_, _hf_,
   {{0x2cea0d64,0x63f70470,0x21390027,0xdbdc00d4}},	//   лько_, _نفیس_, _gush_, rším,
   {{0x765d0c56,0x3ea0000d,0x659b021e,0x66eb02c6}},	//   zasy, žit_, טינק, yřko,
   {{0x765d06a3,0xdbdc0146,0x39467455,0x44443ff0}},	//   yasy, pším, _stos_, _mf_,
   {{0x656f02ad,0x39460143,0x8c3c0233,0x00000000}},	//   yrch, _ptos_, _bağc, --,
   {{0x44447456,0x765d39a1,0x66f200d9,0x3d8b001c}},	//   _of_, vasy, nāku, _محلی_,
   {{0xdd8f12eb,0x656f0244,0x765d7457,0xe1ff0143}},	//   _سوم_, vrch, wasy, _odón_,
   {{0x765d7458,0xa3e81926,0x48a70109,0xa2db00b6}},	//   tasy, _मेल_, стым_, नसम्,
   {{0x44447459,0xdb080072,0x7d0a745a,0x4b370796}},	//   _af_, _ordé, lofs, _הראל_,
   {{0x765d6d40,0x39460bb6,0x629626a1,0xb6070265}},	//   rasy, _utos_, deyo, сянк,
   {{0x98a30084,0x765d745b,0x897b00a1,0x656f745c}},	//   _ниче, sasy, _ערוצ, rrch,
   {{0x765d27da,0xdceb020a,0x2259533d,0x612900c6}},	//   pasy, lugă, _pesk_, _užli,
   {{0x4444745d,0x2ba902d5,0x7d0a0364,0x656f00d4}},	//   _ef_, किता, hofs, prch,
   {{0x6aa20051,0x00000000,0x00000000,0x00000000}},	// [7330] _maof, --, --, --,
   {{0x92e90033,0x88bc02c6,0x4444745e,0x6aa2033c}},	//   মকে_, změn, _gf_, _laof,
   {{0x6296745f,0xdb080103,0x6235001f,0x00000000}},	//   beyo, _erdé, _мену, --,
   {{0x6aa20076,0xe0df02f1,0xe8b5058f,0x21391175}},	//   _naof, _ewòp_, _अच्च, _tush_,
   {{0xa69c0142,0x00000000,0x00000000,0x00000000}},	//   טשאפ, --, --, --,
   {{0xa3e80ed3,0x1b491eac,0x4f5b1487,0xdb090206}},	//   _मेँ_, азки_, _مجرد_, ľníc,
   {{0xdb090146,0xfd100604,0x00000000,0x00000000}},	//   žníc, رجه_, --, --,
   {{0xa3bc0251,0xcf92040a,0x6d4b004d,0x66f201d3}},	//   _आपस_, _קטן_, ppga, nākt,
   {{0x69d60b88,0x7e690134,0x6aa20503,0x00000000}},	//   _üyel, _idep, _daof, --,
   {{0xe6c5005f,0x6d490441,0x2d9f0167,0xdd0e071d}},	//   _češć, _itea, _isue_, mışl,
   {{0xa3e87150,0xb8d11d48,0x6d4400ae,0xdd0e04a8}},	//   _में_, _ऑफ_, ţiat, lışl,
   {{0x60c709b2,0xd62a231c,0x444470a9,0x6aa2033c}},	//   _lojm, ионе_, _sf_, _gaof,
   {{0xdd0e0511,0x89370b9f,0x62960227,0xd0fb0285}},	//   nışl, _اعصا, veyo, ्वाण_,
   {{0x394d7460,0xf771001c,0x6aa2007f,0x00000000}},	//   mpes_, _قاب_, _zaof, --,
   {{0x62960383,0x444424f9,0xd3720037,0x03a34be7}},	//   teyo, _vf_, ظهر_, миро,
   {{0x7d0a00cc,0x25b5058a,0x8c3c03a3,0x7e690129}},	//   zofs, ñaló_, _mağa, _ndep,
   {{0x02ca0bd9,0x62967461,0xe0df06a3,0x4444257e}},	// [7340] _रवीन, reyo, _pwòp_, _tf_,
   {{0x78a37462,0x26c202e6,0x0ef425af,0x394d7463}},	//   _janv, ljko_, ेक्स_, ipes_,
   {{0xee3a7464,0x66f20029,0x60c77465,0x6d497466}},	//   ане_, sāku, _dojm, _atea,
   {{0x78a37467,0x2fc70149,0x25a00154,0xe2973602}},	//   _lanv, änga_, _ksil_, _даю_,
   {{0x226500b6,0xdd0e11bc,0x7e694d16,0x26d90052}},	//   řský_, gışl, _ddep, ëroi_,
   {{0x6d4900e3,0x7e690129,0xdb6a0c79,0xafe6004d}},	//   _dtea, _edep, арил_, _догл,
   {{0xdfd20080,0x66f200e8,0xb4db015e,0x799b0172}},	//   _غير_, nāks, mpàt, ewuw,
   {{0x78a31d19,0x24980126,0x7d0a00e7,0x25a00072}},	//   _aanv, herm_, sofs, _osil_,
   {{0x78a37468,0xfe450103,0xdb240103,0x24980f5a}},	//   _banv, _رکنی, _ہوئی, kerm_,
   {{0x236502dd,0x320f0018,0xd90d00cd,0x2498004d}},	//   šlji_, ügyi_, هین_, jerm_,
   {{0x4a460b2c,0x2a66013d,0x25a07469,0xd7fa0131}},	//   _днев, _дълг, _asil_, руп_,
   {{0x3ea6746a,0xfd570032,0xd6d9007f,0x00000000}},	//   ndot_, _alaṣ, ół_, --,
   {{0x2d86057a,0xdb010037,0x3ea6746b,0xda1e2337}},	//   ntoe_, _urlá, idot_, _परित_,
   {{0x3ea600c2,0x98a700ae,0x8c3c0555,0x98ae022b}},	//   hdot_, _vină_, _yağa, _kifč_,
   {{0xd25b0236,0x92c7571b,0xf2c71693,0x00000000}},	//   ица_, ощад, осан, --,
   {{0x290c746c,0xdd0e03e0,0x236d746d,0xda1e0d75}},	//   loda_, yışl, čej_, _परात_,
   {{0x60c70d95,0x78a30092,0xdd0e00a7,0x39490052}},	// [7350] _pojm, _yanv, xışl, _çast_,
   {{0xd2500018,0x66f200e8,0x3ea668cd,0x00000000}},	//   ٹنے_, sākt, edot_, --,
   {{0x6d49746e,0xa6c80103,0xc49a00ca,0x00000000}},	//   _stea, _طویل_, _השתת, --,
   {{0x59ca074c,0x539a028c,0x394d211d,0x26c90131}},	//   िहार, _פירו, ypes_, _joao_,
   {{0xdd9b004d,0x290c0cce,0x64a10090,0x8c3c03e0}},	//   рше_, koda_, _eġiż, _sağa,
   {{0xdd0e0092,0x00000000,0x00000000,0x00000000}},	//   rışl, --, --, --,
   {{0x290c0060,0x545800a1,0x60080109,0x78a32ed2}},	//   doda_, חסון_, _днём_, _ranv,
   {{0x78a3746f,0x93fc00a1,0x6d490063,0x00000000}},	//   _sanv, ילוי, _ttea, --,
   {{0x394d0257,0x7bd8050d,0x78a30fee,0x7afe0072}},	//   upes_, _čauš, _panv, épta,
   {{0xdea30018,0xedb406cf,0xae2000c3,0x00000000}},	//   _ریڈی, _تحفظ, _बरतन_, --,
   {{0x9f450084,0x78a30430,0x26c903e3,0xaa95004d}},	//   _älä_, _vanv, _boao_, _нижч,
   {{0x394d743f,0x2ca57470,0x78a37471,0x66da00e5}},	//   ppes_, _hald_, _wanv, сьор_,
   {{0x290c0a75,0x249833e8,0xe0df05aa,0x2ca513c8}},	//   boda_, term_, _atòm_, _kald_,
   {{0x7afb7472,0x290c4c44,0x00000000,0x00000000}},	//   lnut, coda_, --, --,
   {{0xf65f0537,0x00000000,0x00000000,0x00000000}},	//   rkær_, --, --, --,
   {{0xb14608e5,0x7afb7010,0x27f80031,0x3636001c}},	//   знал, nnut, úrne_, _عربس,
   {{0x3ea4052f,0x867b00ca,0x25a0366c,0x24987473}},	// [7360] _ramt_, _הרפו, _usil_, perm_,
   {{0x3ea43813,0x7afb7474,0xa0a31102,0x741a0033}},	//   _samt_, hnut, науд, _দলীয়_,
   {{0x7afb1ff3,0x645e00d9,0x443a7475,0xadc30139}},	//   knut, _iepi, _igp_, _iyẹn,
   {{0x290c0fa3,0x59db00aa,0x645e026a,0x52765f34}},	//   zoda_, यनार, _hepi, _عاجز,
   {{0x7afb0074,0x3ea67476,0x1ea900e3,0x290c04d6}},	//   dnut, rdot_, تالي_, yoda_,
   {{0x2d860a9f,0xeaf6022d,0x645e2f95,0x2ca500ae}},	//   rtoe_, ुक्त_, _jepi, _cald_,
   {{0x290c00e9,0x2d860313,0xbc670037,0x443a13ea}},	//   voda_, stoe_, سمين_, _mgp_,
   {{0x645e28c3,0x290c7477,0x7afb02e6,0xbea35736}},	//   _lepi, woda_, gnut, _паск,
   {{0x61e47478,0x2ca501c5,0xfe20007a,0x6f030072}},	//   nzil, _fald_, _बरिस_, énce,
   {{0x81ae0f71,0x645e4290,0xf98f00ab,0x67247479}},	//   _কথা_, _nepi, ابي_, _ahij,
   {{0x7c3a0124,0x7afb1054,0xd7f7007b,0xda6f1441}},	//   _igtr, bnut, зуя_, _пя_,
   {{0xd6db28b9,0x290c747a,0x7e620051,0x8f9b0266}},	//   сто_, soda_, naop, זיטי,
   {{0x290c747b,0x690f02b6,0x00000000,0x00000000}},	//   poda_, røer, --, --,
   {{0x293700c1,0x645e747c,0x248d08c5,0x61e4747d}},	//   _זאגן_, _cepi, đemo_, dzil,
   {{0x645e747e,0x7e626f7b,0x00000000,0x00000000}},	//   _depi, kaop, --, --,
   {{0x381709c1,0x443a516e,0xba3d02c6,0x777a0062}},	//   _מקום_, _egp_, jdůl, mutx,
   {{0xa2ce02d5,0x3ced00a5,0x69c00124,0x628f0231}},	// [7370] _सवर्, _अगले_, nxme, _vbco,
   {{0x645e4900,0x7c3a00f9,0x443a6e92,0x2eff02a1}},	//   _gepi, _ngtr, _ggp_, _sjuf_,
   {{0xee4a0174,0xdb080143,0xc6090033,0x7afb747f}},	//   _ịdịn, _ardí, রেখা_, ynut,
   {{0xf4030081,0x7e62002b,0x2d0500c3,0x645e05aa}},	//   _এরপর_, gaop, शक्ल_, _zepi,
   {{0xdca57480,0x64d1009d,0x69c6007b,0x00000000}},	//   дали, _सकाळ, äkel, --,
   {{0x71d60266,0x777a01c8,0x00000000,0x00000000}},	//   _חושד_, kutx, --, --,
   {{0x7afb7202,0x78690103,0x2ca52225,0x6e20039f}},	//   tnut, _jövő, _vald_, _ezmb,
   {{0xe9d93d7c,0x61220257,0x2ca57481,0xfe6e001c}},	//   жки_, rôle, _wald_, _نگه_,
   {{0xc8c80789,0x6e3b0009,0x672401cb,0x2d58007b}},	//   ाउंट, _igub, _rhij, _нить_,
   {{0x672400dd,0x6f1902ad,0x00000000,0x00000000}},	//   _shij, llwc, --, --,
   {{0x645e7482,0x7afb0074,0x61e47483,0x443a0138}},	//   _repi, pnut, zzil, _rgp_,
   {{0x645e00cd,0x443a7484,0xeb900037,0x6616007b}},	//   _sepi, _sgp_, _حظك_, _pyyk,
   {{0x18692de0,0x6e3b063d,0x00000000,0x00000000}},	//   _дали_, _mgub, --, --,
   {{0x79890313,0x6aa90709,0x2a7f34fd,0x777a00ee}},	//   mtew, ldef, lgub_, butx,
   {{0xa3e8007d,0xdc4501b3,0x67247485,0x6e3b0361}},	//   _मेख_, jūči, _thij, _ogub,
   {{0x66047486,0x2a7f7487,0x6e3b2713,0x2bb60096}},	//   _txik, ngub_, _ngub, _अपघा,
   {{0x8c3c35f8,0x79897488,0x00000000,0x00000000}},	// [7380] _bağl, ntew, --, --,
   {{0x2f1c0072,0x798902ac,0x7e620350,0x00000000}},	//   tígo_, itew, waop, --,
   {{0x8c3c0491,0x130a163d,0x644102c6,0xdb0800d2}},	//   _dağl, _мной_, žlic, _srdí,
   {{0xf42a0084,0x61e400fc,0x79891cab,0x25b27489}},	//   _enää_, pzil, ktew, _kryl_,
   {{0xdd901e49,0x6aa9748a,0xfce62753,0xd8380117}},	//   اوت_, ddef, модо, leče_,
   {{0x6e3b748b,0x7e620231,0x00000000,0x00000000}},	//   _egub, saop, --, --,
   {{0xf7670814,0x7e6200f9,0xbb470190,0x8f75004d}},	//   _جا_, paop, ولون_, _путі,
   {{0xf96a00c2,0xff240e27,0x6aa90120,0x00000000}},	//   орой_, _سبزی, gdef, --,
   {{0x6d5b0174,0x8c3c008b,0x20180052,0x79890313}},	//   _gwua, _yağl, _hyri_, gtew,
   {{0x6e3b748c,0x41bb00c1,0x6d40009c,0x7c3a01ff}},	//   _zgub, קציע, _iuma, _ugtr,
   {{0x7e60748d,0xd838748e,0xe0df0154,0x00000000}},	//   _kemp, ječe_, _stòk_, --,
   {{0x6d402ee4,0x7e6014f7,0xb8d500bc,0x6aa900ee}},	//   _kuma, _jemp, _चो_, cdef,
   {{0x7e601268,0x6d40748f,0x94190092,0x00000000}},	//   _memp, _juma, əyən_, --,
   {{0x6d402ea9,0x7e601eec,0x777a1e86,0x46af0285}},	//   _muma, _lemp, putx, _जोरह,
   {{0x3d1605d4,0x6d407490,0xe53400c2,0xd7ef7491}},	//   _पीछे_, _luma, терь, _ру_,
   {{0x8c3c210e,0x7e607492,0x6d407493,0x00000000}},	//   _sağl, _nemp, _ouma, --,
   {{0x6d407494,0x26d901b3,0x628d00f0,0x00000000}},	// [7390] _numa, ūros_, rfao, --,
   {{0x657d6900,0xf0fb2853,0x7e6026de,0x60c5022e}},	//   mush, ्वेद_, _aemp, ujhm,
   {{0x657d7495,0x7e607496,0x2018030a,0xd8380141}},	//   lush, _bemp, _cyri_, beče_,
   {{0x6d407497,0x7e604aad,0xa3e809c3,0x00000000}},	//   _buma, _cemp, _मेट_, --,
   {{0x6d407498,0x506703fc,0x657d7499,0xbdf80604}},	//   _cuma, _отва, nush, ورها_,
   {{0x201804c8,0x6d40749a,0x7e60039f,0x290300c4}},	//   _fyri_, _duma, _eemp, čjak_,
   {{0xeb9109b4,0x657d628a,0xd6e00034,0x6d40749b}},	//   اظت_, hush, ółki_, _euma,
   {{0x657d0060,0x7e600496,0x32190084,0x63a8052f}},	//   kush, _gemp, _kysy_, ædni,
   {{0x6d405c5e,0x6aa9227a,0x7d04033c,0x657d749c}},	//   _guma, rdef, éisc, jush,
   {{0x7e60749d,0x657d749e,0x47c50084,0x8c3c008b}},	//   _zemp, dush, ебов, _yağm,
   {{0x6d40749f,0x798974a0,0x00000000,0x00000000}},	//   _zuma, stew, --, --,
   {{0x6d4074a1,0x657d74a2,0x224900e7,0x7e6074a3}},	//   _yuma, fush, jcak_, _xemp,
   {{0x6d40008a,0x657d74a4,0x58d5413c,0xd83874a5}},	//   _xuma, gush, _подт, veče_,
   {{0x26d90052,0x09f600ca,0x98a23283,0x00000000}},	//   ëror_, _אמנם_, _бише, --,
   {{0xd8383e76,0x232a09b9,0x141a0037,0x00000000}},	//   teče_, зови_, سيرة_, --,
   {{0x657d74a6,0x8c3c01e8,0x97d80037,0x00000000}},	//   bush, _rağm, _تظهر_, --,
   {{0x7e6074a7,0xd8382024,0x20180052,0xd33574a8}},	// [73a0] _remp, reče_, _syri_, тэры,
   {{0x7e6074a9,0x6d4010f3,0xd83803f1,0x53a6247a}},	//   _semp, _ruma, seče_, _заоб,
   {{0x6d4074aa,0x7e600d2c,0x00000000,0x00000000}},	//   _suma, _pemp, --, --,
   {{0x040b00ef,0x6d4074ab,0x8c150081,0x9daa00e5}},	//   _lượn, _puma, াধান_, зъка_,
   {{0x6d404628,0x13d50033,0x00000000,0x00000000}},	//   _quma, _হইয়, --, --,
   {{0x66df023b,0x5ba60379,0xf1bf00fe,0x6134013c}},	//   _mëka, ериз, _ngáy_, külə,
   {{0x91033574,0x6adb00a5,0xdb080037,0x6d40130e}},	//   _спре, बसूर, _ardá, _wuma,
   {{0x6d4074ac,0x657d02a4,0xa3c10096,0xada6273f}},	//   _tuma, yush, ंमत_, _пабл,
   {{0x6d403606,0xdee344c5,0x657d74ad,0xb9970b2f}},	//   _uuma, _соти, xush, евых_,
   {{0x60ce443b,0x657d74ae,0x49730138,0x00000000}},	//   _jobm, vush, ыльс, --,
   {{0x273a0138,0x60ce0124,0x5cf5004d,0x040b00fe}},	//   _būna_, _mobm, _ряту, _dượn,
   {{0x09e60303,0x657d74af,0x00000000,0x00000000}},	//   _поен, tush, --, --,
   {{0xe97300bf,0x1af700c1,0x99d30192,0x95d80927}},	//   _مهند, _אמאל_, _متوا, едят_,
   {{0x657d74b0,0x2edd0c38,0x80c402d5,0x040b00fe}},	//   rush, _मत्त, राफे, _gượn,
   {{0x25bf002d,0xad1b00a1,0x657d74b1,0x4394090f}},	//   ţul_, פולר, sush, ларс,
   {{0x41e73ad2,0x657d74b2,0x3219007b,0x31690062}},	//   ніза, push, _pysy_, tsaz_,
   {{0x22490479,0x60ce030a,0x764d74b3,0x8b0300d2}},	// [73b0] rcak_, _bobm, _ifay, ířil,
   {{0xd564013d,0x656d0169,0x100706e7,0x00000000}},	//   _стъп, _ivah, няем, --,
   {{0xc1040037,0x2ae70139,0x00000000,0x00000000}},	//   دولي, _lákọ_, --, --,
   {{0xb1842347,0x51870cd1,0x6122014b,0xd35600ca}},	//   šťas, _пуга, rôla, _שירי_,
   {{0x6da5294a,0xada532e3,0x00000000,0x00000000}},	//   тила, талл, --, --,
   {{0xd37802e6,0xeb9917a6,0x3ea974b4,0x656d0079}},	//   šće_, дик_, žat_, _mvah,
   {{0xa3c3007a,0xe81006e4,0x764d74b5,0x00000000}},	//   ्हि_, _ठुला_, _ofay, --,
   {{0x9f340120,0x656d02ac,0x60ce0141,0x00000000}},	//   _бесі, _ovah, _zobm, --,
   {{0xceb217f5,0xf40000ae,0x2f1502c3,0xf2d40142}},	//   _דין_, ăţii_, sågs_, טעק_,
   {{0xa3c31fbb,0x2ae70139,0xe8f60b2f,0xadf46f43}},	//   ्हा_, _dákọ_, клы_, _спуш,
   {{0xe80b0442,0x656d74b6,0x66e614e7,0x040b0023}},	//   _सुखा_, _avah, вона, _vượn,
   {{0x613400a7,0x9c7c00d4,0x00000000,0x00000000}},	//   rülə, _vlče, --, --,
   {{0x040b0028,0x00000000,0x00000000,0x00000000}},	//   _tượn, --, --, --,
   {{0xe9d868de,0x6aab2e0e,0x764d063d,0x3afa00e8}},	//   _які_, _hagf, _efay, rūpe_,
   {{0x398b038c,0x764d010a,0xe3631a17,0x638600e5}},	//   løs_, _ffay, икри, ъгва,
   {{0x06f600bf,0xe297421a,0x9f9d0231,0x00000000}},	//   _جستج, кас_, nçõe_, --,
   {{0x26190b94,0xd8380095,0xa526166f,0x00000000}},	// [73c0] _युपी_, meča_, _имид, --,
   {{0x9ffa0182,0x6aab238c,0x69c6007b,0xb5cb0a43}},	//   وراء_, _lagf, äkei, _লেকচ,
   {{0xdd1c0220,0xaa1e030b,0x80c4023a,0xb479006e}},	//   _nášh, _पर्छ_, राबे, _אָרי,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcfb00bd,0x5de600e5,0x00000000,0x00000000}},	//   _ssuġ, ъжда, --, --,
   {{0x62840036,0x2b5e061d,0x8d130120,0xe7f602c6}},	//   lgio, _pwtc_, адії, ुपमा_,
   {{0x8bc300e5,0x6aab0537,0x3a2005db,0x00000000}},	//   исъд, _bagf, _šip_, --,
   {{0x78aa02ef,0x2b55001c,0xd83874b7,0x00000000}},	//   _safv, ایند_, ječa_, --,
   {{0x6da30002,0xbd8a00bf,0x6aab74b8,0x6f0274b9}},	//   _кита, _زنان_, _dagf, mnoc,
   {{0x2ee610ec,0x6f0274ba,0xd7fa001f,0x27f8408f}},	//   lhof_, lnoc, дум_, úrno_,
   {{0x47353097,0x6aab4012,0x656d74bb,0x88bc00b6}},	//   лнос, _fagf, _svah, dmět,
   {{0x2cac436a,0x6f0201bf,0x2ee6091f,0x9c7c022b}},	//   _hadd_, nnoc, nhof_, _flčc,
   {{0xd90e0068,0xe8942e9e,0x6f021f72,0x6aa00a4b}},	//   _ویب_, _баль, inoc, memf,
   {{0x79800bbd,0x7ae201cd,0x00000000,0x00000000}},	//   mumw, _hlot, --, --,
   {{0x629f0092,0x241810e0,0xd83805db,0x2ee674bc}},	//   teqo, воры_, beča_, khof_,
   {{0x62840465,0x291e74bd,0xf83700ca,0x69d6026a}},	//   ggio, llta_, _בנות_, _üyes,
   {{0x6f02632d,0x53346f46,0x291e74be,0xc1050037}},	// [73d0] dnoc, ретт, olta_, هوري,
   {{0x273b013f,0x7ae274bf,0x62840036,0x25a974c0}},	//   _kūno_, _llot, agio, _isal_,
   {{0x291e00c2,0xa3d5001f,0x7ae274c1,0x79800350}},	//   ilta_, _сонч, _olot, humw,
   {{0x8f140426,0x79801ba4,0x612b00aa,0x00000000}},	//   афіч, kumw, külg, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2db030b,0x6aab74c2,0x6f020036,0x2cac03a8}},	//   नसक्, _sagf, anoc, _cadd_,
   {{0xeb9974c3,0x7ae274c4,0x7c847305,0x2cac01ee}},	//   хий_, _blot, руче, _dadd_,
   {{0xdd1c0181,0x6f021da6,0x7ae254ef,0x3f81008c}},	//   _vášh, cnoc, _clot, muhu_,
   {{0xa91d00b6,0x3f8174c5,0x61fb0433,0xd838033b}},	//   huže, luhu_, _žulj, veča_,
   {{0xdce90117,0xbc560206,0x398b00f2,0x2cac01ce}},	//   _kveč, čšíc, røs_, _gadd_,
   {{0x7ae274c6,0x25a90484,0x3ebf74c7,0x6aab74c8}},	//   _flot, _asal_, _knut_, _tagf,
   {{0x291e74c9,0xa91d00e9,0xa6830423,0xeab00037}},	//   alta_, duže, блюд, _وعن_,
   {{0x3f8174ca,0x2cac01c2,0xd8380783,0x79800027}},	//   huhu_, _yadd_, reča_, cumw,
   {{0xd838033b,0xdce92efd,0x3b1f00a7,0x612b74cb}},	//   seča_, _oveč, lluq_, nüld,
   {{0xe29a05c7,0x7d0374cc,0x78a174cd,0x1e20030b}},	//   нав_, inns, melv, _बर्ष_,
   {{0x425564e9,0x3f810188,0x2b450141,0x3b1f013c}},	//   итут, duhu_, _mulc_, nluq_,
   {{0x612b0018,0x2d8d023e,0xb2265566,0x6f0200d4}},	// [73e0] küld, _nqee_, умал, vnoc,
   {{0x3ebf1a3a,0x26d274ce,0xa91d033b,0x63b7037a}},	//   _anut_, _hoyo_, lužb, _frxn,
   {{0x645c74cf,0x26d274d0,0x2ee60a2c,0x2cac74d1}},	//   mbri, _koyo_, thof_, _radd_,
   {{0xa3c31e5e,0x645c74d2,0x26d20483,0x79800193}},	//   ्हर_, lbri, _joyo_, yumw,
   {{0x26d20010,0x3ead02e5,0x80c41492,0xf53f682e}},	//   _moyo_, _daet_, रादे, lvår_,
   {{0x50434911,0x3f8174d3,0x2ee60f7a,0x3320009e}},	//   _герб, buhu_, shof_, llix_,
   {{0x2d8f05fe,0x645c0037,0x7ae274d4,0xafe61143}},	//   atge_, ibri, _plot, _совл,
   {{0x7980696a,0x5fbb00a1,0x34d1030b,0xdee3455b}},	//   tumw, _אצלנ, _सक्द, _лоси,
   {{0xdce91271,0x7ae25e7c,0xa91d3df1,0x645c18f0}},	//   _zveč, _vlot, dužb, kbri,
   {{0x26c00085,0x78a12548,0x79800512,0x00000000}},	//   _anio_, gelv, rumw, --,
   {{0x645c4ee8,0x26d260e7,0x06ae0033,0x6ecb0e4c}},	//   dbri, _boyo_, গানি, _सचमु,
   {{0x7c2502e2,0x7ae274d5,0xc98600d3,0x25a902c6}},	//   ühre, _ulot, _буки, _psal_,
   {{0x612b74d6,0x78a174d7,0x26d201dc,0xd7c7001c}},	//   lüle, belv, _doyo_, نویه_,
   {{0xa3c3007d,0xa91d1419,0x26c074d8,0x7b2a01c2}},	//   ्हल_, tuže, _enio_, _uƙub,
   {{0x612b0233,0x24190b2f,0x00000000,0x00000000}},	//   nüle, товы_, --, --,
   {{0x3255105b,0xddc0030b,0x26d274d9,0x612b0b12}},	//   рвар, _nemů, _goyo_, züld,
   {{0x645c54ae,0xdce96d61,0x3946013f,0x50f522ff}},	// [73f0] bbri, _sveč, _juos_, азат,
   {{0xd37804eb,0x656f365f,0x0f0d397e,0x3946028d}},	//   šća_, msch, िक्स_, _muos_,
   {{0x656f0bb7,0x929574da,0x332000b3,0x351c00ca}},	//   lsch, _канц, blix_, _אוזנ,
   {{0x7d1a007a,0x3f8174db,0x656f028d,0x628a0103}},	//   _akts, ruhu_, osch, őfor,
   {{0x656f74dc,0x7c283d81,0x9e6400d6,0x68fa235a}},	//   nsch, _azdr, свід, kitd,
   {{0x88bc030b,0x656f74dd,0x61ed019f,0x2a6905db}},	//   změr, isch, mzal, _žab_,
   {{0xdce92c57,0x656f01bf,0x25fc009f,0xa2dc0cce}},	//   _uveč, hsch, _लेनी_, _नवम्,
   {{0x656f63c2,0x645c0559,0x61ed024a,0x9c7c00d8}},	//   ksch, zbri, ozal, _vlča,
   {{0x9c8774de,0x61ed74df,0x656f01c0,0x7e6b0270}},	//   _مشاه, nzal, jsch, magp,
   {{0x656f74e0,0xf77100e3,0x7e6b74e1,0x672d0169}},	//   dsch, ياج_, lagp, _ahaj,
   {{0xa91d1419,0x672d14d0,0x6d590124,0x656f74e2}},	//   tužb, _bhaj, lpwa, esch,
   {{0x672d74e3,0x645c74e4,0x7e6b1281,0x656f2b84}},	//   _chaj, wbri, nagp, fsch,
   {{0x6b8374e5,0x7ae974e6,0x656f365f,0x958300c2}},	//   lung, mhet, gsch, оляе,
   {{0x7ae974e7,0x7afb0138,0x69c9023e,0x61ed74e8}},	//   lhet, liut, mxee, dzal,
   {{0x6b8374e9,0x660d74ea,0x7f47022e,0x6f1b74eb}},	//   nung, _exak, _nujq, _okuc,
   {{0x7ae974ec,0x645c04ee,0x656f01bf,0x672d009e}},	//   nhet, sbri, bsch, _ghaj,

   {{0x6b8374ed,0xfd4e0134,0x5fab0034,0x656f022b}},	// [7400] hung, _dakọ, _टैबल, csch,
   {{0x6b8374ee,0x20564657,0x7f47023b,0x1fb61f5d}},	//   kung, ртар, _bujq, исер,
   {{0x444474ef,0x6b8301b3,0x7ae90060,0x7d042bb7}},	//   _ig_, jung, khet, éism,
   {{0x6b8374f0,0xfd4e0174,0x65640193,0x20050141}},	//   dung, _gakọ, _kwih, _žlic_,
   {{0x6f09029b,0x7ae974f1,0x69c9022e,0x61ed0034}},	//   _djec, dhet, jxee, czal,
   {{0x6b83089f,0x6f0974f2,0x6e2900e7,0x249a0063}},	//   fung, _ejec, _dzeb, _jbpm_,
   {{0x6b8374f3,0x444474f4,0x39460154,0x7afb008f}},	//   gung, _mg_, _suos_, fiut,
   {{0x7ae90d40,0x612b74f5,0x7c2802dd,0x764426f6}},	//   ghet, rüle, _vzdr, _ngiy,
   {{0x44445ec1,0xe1ff0fb6,0x612b56ef,0x0c7600d1}},	//   _og_, _león_, süle, _نداد,
   {{0x444474f6,0x6b8306e1,0x8c4313dc,0x612b026a}},	//   _ng_, bung, _дефе, püle,
   {{0x7d180146,0x6b830193,0x61ed74f7,0x7afb52eb}},	//   movs, cung, zzal, biut,
   {{0x444471e0,0x656f61bd,0x7ae974f8,0x7afb74f9}},	//   _ag_, tsch, chet, ciut,
   {{0x444474fa,0xd9540de1,0xca97040a,0x656f01bf}},	//   _bg_, _انتخ, _כדאי_, usch,
   {{0x656f74fb,0x444474fc,0xdb0d0084,0x39900428}},	//   rsch, _cg_, äköi, màs_,
   {{0x656f48eb,0x444474fd,0x672d0146,0x326703fc}},	//   ssch, _dg_, _thaj, итав,
   {{0x44441d1b,0xd2582311,0x083b0054,0x61ed0a00}},	//   _eg_, ицу_, _בעול, tzal,
   {{0x6b8329f7,0x90993eac,0xa91d74fe,0x6f0904e9}},	// [7410] zung, лват_, luža, _rjec,
   {{0x6b8374ff,0x7ae90018,0x6f090ea3,0x386c00e7}},	//   yung, zhet, _sjec, nadr_,
   {{0x2ba60569,0x7e6b00a6,0x64457500,0x5f951da9}},	//   _कैला, tagp, _ighi, сиет,
   {{0x44446559,0x7ae9023b,0x6b832149,0xdb010031}},	//   _zg_, xhet, vung, _oslá,
   {{0x44441268,0x6b836ccb,0x6f097501,0x7ae900f3}},	//   _yg_, wung, _vjec, vhet,
   {{0x7d1858c3,0x69c9023e,0x2fc70212,0x64450078}},	//   govs, vxee, ängs_, _jghi,
   {{0x7ae97502,0x7e6b0d3d,0x6b830364,0x6f090212}},	//   thet, pagp, uung, _tjec,
   {{0x9f05048f,0x6f1b0201,0xa91d0542,0x69c901e9}},	//   _اورو, _ukuc, duža, txee,
   {{0x60d51cbc,0x7ae97503,0x7afb7504,0xdce90146}},	//   _kozm, rhet, riut, _uveď,
   {{0x6b837505,0x644500ef,0x1c1b1c65,0x7d180094}},	//   pung, _nghi, _पुथल_, covs,
   {{0x7ae90201,0x69c609df,0x6d410bb6,0x7e6900ca}},	//   phet, äker, _iila, _keep,
   {{0x6d417506,0xe5a6008f,0x64457507,0x399011b2}},	//   _hila, бими, _aghi, bàs_,
   {{0x6d416213,0x39900428,0x249a0063,0x6445007e}},	//   _kila, càs_, _pbpm_, _bghi,
   {{0x3a3600a1,0xdff90034,0xe1ff1de1,0x98e50037}},	//   _פרסם_, ्पाद_, _peón_, _دكتو,
   {{0x6d4115ec,0xd3b50084,0x67552ba0,0x44447508}},	//   _mila, ость, _اختر, _vg_,
   {{0x44447509,0x6d41750a,0x6b9c41ba,0x61e9007f}},	//   _wg_, _lila, _ärge, _żela,
   {{0x4444750b,0xa3a809d0,0x6d410634,0xf1aa00cd}},	// [7420] _tg_, _खैर_, _oila, دازه_,
   {{0x4444750c,0x6d41750d,0x25a00113,0x60d5063b}},	//   _ug_, _nila, _ipil_, _cozm,
   {{0x7e690783,0x7d180357,0x25fc750e,0x8236015a}},	//   _beep, vovs, _लेती_, _گردا,
   {{0x6d41750f,0x2bbd1cff,0xddc0020a,0x00000000}},	//   _aila, ्मना, _nemţ, --,
   {{0x6d417510,0x7e697511,0x7ce60088,0x7d181ea1}},	//   _bila, _deep, _aðra, tovs,
   {{0x6d4101e5,0xdcb10023,0xb5fb02c6,0x3990015e}},	//   _cila, _cả_, lbác, vàs_,
   {{0x6d41584b,0x7d187512,0xcec300b6,0x00000000}},	//   _dila, rovs, áří_, --,
   {{0xa3b905cd,0x7d181a5d,0x6d417513,0x399005fe}},	//   चित_, sovs, _eila, tàs_,
   {{0x6d417514,0x7d18191d,0x7c9600a9,0x7d0d0076}},	//   _fila, povs, _грец, éasc,
   {{0x6d417515,0x39900472,0x19a7008f,0xd8f8004d}},	//   _gila, ràs_, стъп_, рної_,
   {{0xf98f0814,0x25a002c9,0x613000a2,0xc6200033}},	//   وبی_, _apil_, mäld, নেমা_,
   {{0xa91d04a3,0x6d417516,0xa25b0161,0x39900428}},	//   ruža, _zila, _anôn, pàs_,
   {{0x6f031f72,0x2fc700de,0x4421061d,0x6d410201}},	//   énci, ̣ng_, _syh_, _yila,
   {{0x442700ef,0x644816a2,0x6d411321,0x38c8015a}},	//   _ơn_, ždin, _xila, _خاصی_,
   {{0x2bbd084a,0x60d512fb,0xd82f00d3,0x56952b53}},	//   ्मया, _rozm, _хэ_, _дайт,
   {{0x925900c9,0x00000000,0x00000000,0x00000000}},	//   раат_, --, --, --,
   {{0x3ea67517,0x60d57518,0x7e6918ef,0x60f9013f}},	// [7430] deot_, _pozm, _reep, аная_,
   {{0x7e697519,0x00000000,0x00000000,0x00000000}},	//   _seep, --, --, --,
   {{0x4427751a,0x6d41751b,0x2fc700de,0x61e800a7}},	//   _án_, _rila, ãng_, _ədli,
   {{0x6d414c17,0x3f930062,0x52a70076,0x00000000}},	//   _sila, rtxu_, _اصدق, --,
   {{0x6f1900a5,0xa91d0106,0x80b80033,0x7e69751c}},	//   rowc, dužn, _আকর্, _veep,
   {{0x6d41751d,0x8c950565,0x00000000,0x00000000}},	//   _qila, ірлі, --, --,
   {{0x6d41751e,0xaac50557,0x7e69751f,0x04dc0266}},	//   _vila, वालक, _teep, רקול,
   {{0x6d417520,0xa2cc009d,0x78830103,0x93fc006e}},	//   _wila, हाय्, kívü, טלוי,
   {{0x6d417521,0xed591419,0x44240023,0x628f7522}},	//   _tila, _brže_, ́m_, _mcco,
   {{0xc79500ae,0x00000000,0x00000000,0x00000000}},	//   ормы, --, --, --,
   {{0xa6ca08c3,0x25a01050,0x628f008f,0xeaae0068}},	//   ална_, _spil_, _occo, رٹی_,
   {{0xa91d7523,0x2ca77524,0x61301945,0xc4c90327}},	//   drže, lend_, mäle, _בג_,
   {{0x94040092,0xb5fb00d4,0x00000000,0x00000000}},	//   əmə_, vbác, --, --,
   {{0x628f0e04,0xdb1a054e,0x2ca709ed,0x00000000}},	//   _acco, _artè, nend_, --,
   {{0x044322ee,0x443e00c2,0x2ca709ec,0x7d040037}},	//   дерн, ät_, iend_, éisi,
   {{0x2ca77525,0x0326036c,0x00000000,0x00000000}},	//   hend_, ідан, --, --,
   {{0x2ca73f76,0xb5fb0fd9,0x25a00449,0xdb0117a5}},	// [7440] kend_, rbác, _upil_, _islä,
   {{0x6ab60557,0xddc002dd,0x628f00e5,0x2ca700f3}},	//   _अफ्र, _nemš, _ecco, jend_,
   {{0x232a02ec,0x2ca73564,0x32461be7,0xe29a1f47}},	//   _вони_, dend_, _менг, _кан_,
   {{0x6da61a0c,0x00000000,0x00000000,0x00000000}},	//   жида, --, --, --,
   {{0xc27b0327,0x823600d1,0x2ca73ff0,0x3c5800d3}},	//   _דרכי, _گرگا, fend_, билэ_,
   {{0x2ca72071,0xcf5a007b,0x6ca300e5,0xda1d007a}},	//   gend_, _врач_, дръж, _पड़त_,
   {{0xaac504a9,0x61300222,0xa91d04a3,0xd0070cc0}},	//   वांक, räld, tužn, _дере_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc33309c1,0x2ca77526,0x7e626204,0x0c7a0781}},	//   ווה_, bend_, mbop, _نصاب_,
   {{0x20070034,0xd8381271,0x9c7c00d8,0x00000000}},	//   źnie_, leči_, _mlčk, --,
   {{0x6fba0ff9,0xed590147,0x00000000,0x00000000}},	//   ईटिं, _vrže_, --, --,
   {{0xd946232c,0xa91d63f0,0x644800d4,0xdb1a00d4}},	//   _деди, vrže, ždil, _orté,
   {{0xd6270037,0x6a9b00ca,0x00000000,0x00000000}},	//   تعدي, _כשאנ, --, --,
   {{0x99fb00a1,0xe3b37527,0x39590131,0xa91d02c6}},	//   _דפדפ, ورز_, ísse_, trže,
   {{0xdb1a7528,0x63be0218,0x628f037a,0x926b0161}},	//   _arté, _crpn, _pcco, ираа_,
   {{0x25b002fd,0xd8381cb4,0x2ca7279f,0x3f810146}},	//   ällä_, ječi_, zend_, vrhu_,
   {{0x628f00fe,0xf194007b,0xd52d00fe,0xd8380128}},	// [7450] _vcco, мить, _từn, deči_,
   {{0x160102d5,0xf43500ae,0xa91d14f3,0x3f8102c6}},	//   _लेयर_, _непэ, prže, trhu_,
   {{0x2ca77529,0xb4e70034,0xddc005db,0x00000000}},	//   vend_, पसी_, _remš, --,
   {{0x2ca70a9f,0x1dc617ff,0x00000000,0x00000000}},	//   wend_, लमंत, --, --,
   {{0x7cef0c08,0xa3b9045f,0x2ca7752a,0x00000000}},	//   _jørg, चिव_, tend_, --,
   {{0xf1bf44c2,0xdebc0022,0x361c0266,0x11da00ca}},	//   _irá_, _murƙ, בודד, _החשב,
   {{0x2ca70337,0x81ad0033,0x8c420396,0xf1bf0031}},	//   rend_, _কপি_, неше, _hrá_,
   {{0x2ca730b9,0x5ac9752b,0x20c90d77,0x69cc00a4}},	//   send_, слим_, रावध, _तपशी,
   {{0xceb23629,0xe8f95053,0xdd580829,0x7cef00f2}},	//   _אין_, йли_, _матч_, _nørg,
   {{0xa3cb000d,0xb4ea009d,0x2bbd142e,0xa91d00d4}},	//   लमा_, _मते_, ्मदा, ružo,
   {{0x66df023b,0x77900103,0xdb0800d8,0x6f0b020b}},	//   _lëku, نیوا, _hrdý, ongc,
   {{0xa3c100c3,0x7cef00f2,0x68ea112f,0x00000000}},	//   ूमन_, _børg, _elfd, --,
   {{0x63be752c,0x7aeb01d3,0x69dd00bc,0x06074f40}},	//   _srpn, _ilgt, äsed, зняк_,
   {{0xa87900c1,0x6aa9752d,0x2902752e,0xdebc03e3}},	//   _האַר, leef, ékat_, _durƙ,
   {{0xe73a1121,0xf1bf026e,0x7e7b0335,0x66e62753}},	//   _лек_, _ará_, _odup, _нока,
   {{0x9ad30129,0x934323e9,0xdb01042c,0x628d484b}},	//   _dịgh, енсе, _erlö, ggao,
   {{0x6d5b022e,0x612b0103,0xf1bf00da,0x00000000}},	// [7460] _ntua, rüln, _crá_, --,
   {{0x7e7b09f5,0xf61700a1,0xfbbd1e05,0x15fb00ca}},	//   _adup, _מחפש_, ्माम, _להפע,
   {{0x6d5b00c9,0xc2c60080,0x09a824eb,0x7c250364}},	//   _atua, _فيدي, _कन्य, ührl,
   {{0xf1bf0682,0x61460cc5,0x7cef1484,0xee3a0feb}},	//   _frá_, _нема, _lørd, бне_,
   {{0xf1bf0037,0xd8382102,0xb9290174,0x6d4f0231}},	//   _grá_, reči_, untụ_, _écal,
   {{0x6d5b0037,0xd838033b,0x612b071d,0x7cef00f2}},	//   _dtua, seči_, nüll, _nørd,
   {{0xab380879,0xb90c0065,0x8fa315ca,0x78a800f2}},	//   опку_, _eemọ_, _паре, vedv,
   {{0x6d5b023b,0x6aa90629,0x80c401e4,0x612b042c}},	//   _ftua, geef, राके, hüll,
   {{0xf65f00f2,0x25fc00bc,0xb6060218,0x612b60c9}},	//   kjær_, _लेली_, nošč, küll,
   {{0x6f02752f,0x7aeb00c6,0xdc3c0206,0x63bc14f3}},	//   lioc, _elgt, _háči, kvrn,
   {{0x7cef0856,0x3f7801d3,0xdceb02ef,0xc1c802d5}},	//   _sørg, nču_, _šićk, रमुग,
   {{0x6f0201ac,0xda7700ae,0x00000000,0x00000000}},	//   nioc, _еяш_, --, --,
   {{0x612b02e2,0x7cef00d6,0x255802c6,0x00000000}},	//   füll, _førd, vělý_, --,
   {{0x2ed9000c,0x6f020036,0x3a260027,0xb6060117}},	//   _भक्त, hioc, _iyop_, došč,
   {{0x291e042d,0x290c0ec9,0x225a00ac,0x28b700ca}},	//   mota_, mnda_, _ọfụm, _מפגש_,
   {{0xf1bf13a9,0x628d0a39,0xdc3c0094,0x53980120}},	//   _prá_, ugao, _náči, явся_,
   {{0x7cef0400,0x2b4600c4,0x30a702ff,0x26c9024a}},	// [7470] _høre, _mioc_, зрев, _inao_,
   {{0x291e7530,0x7cef01c5,0x3cf800a5,0x290c7531}},	//   nota_, _køre, ्चों_, nnda_,
   {{0x6d5b7532,0x6f020036,0x81440470,0x00000000}},	//   _stua, fioc, رنمن, --,
   {{0x291e7533,0x6f02008f,0xfbbd1757,0xf1bf7534}},	//   hota_, gioc, ्मसम, _trá_,
   {{0xed590559,0xd8380a39,0x291e0fd1,0x26c9024a}},	//   _brža_, meču_, kota_, _mnao_,
   {{0xa2d90789,0x6aa96e3a,0x69d6026a,0xdb087535}},	//   फॉर्, weef, _üyey, _ordó,
   {{0xeb997536,0x291e7537,0x3a260124,0x290c01c2}},	//   ций_, dota_, _ayop_, dnda_,
   {{0xa91d0954,0x290c7538,0x6f025c31,0x61300149}},	//   drža, enda_, cioc, mäla,
   {{0x6aa97539,0x386e03a8,0xdb080503,0x290c003e}},	//   reef, _befr_, _ardó, fnda_,
   {{0x26c91d29,0xd378005f,0x612b4550,0x7d04259a}},	//   _anao_, šći_, külm, éist,
   {{0x16aa0aeb,0xb90516e2,0x395f00ae,0x67030174}},	//   овни_, _नव_, spus_, _ọkam,
   {{0x7cef038c,0x98a200d9,0xd8384e00,0xb5fb3912}},	//   _døre, ēkā_, ječu_, rbán,
   {{0xb8e30f71,0xdce90284,0xba740fba,0x3b030032}},	//   _এক_, _cveć, _سانت, _eèpè_,
   {{0x58d423a3,0x7cef00f3,0x291e3fbf,0xb6060087}},	//   _почт, _føre, cota_, vošč,
   {{0x1543002d,0x7cef052f,0x386500d7,0x2eed039f}},	//   терм, _gøre, mblr_, _olef_,
   {{0x7d03753a,0x99e30244,0x39470088,0x04fe0033}},	//   hins, žňuj, _hins_, ংকের_,
   {{0x7d031114,0x453600c2,0xb0c92231,0x6724753b}},	// [7480] kins, _охот, रांग, _ikij,
   {{0x26c903ce,0x39470167,0xb6060087,0x394f753c}},	//   _znao_, _jins_, rošč, _mugs_,
   {{0x6f02175b,0x26c90124,0xdc3c0220,0x4f7a00c2}},	//   tioc, _ynao_, _páči, ющая_,
   {{0x3947753d,0x2eed00fd,0x291e0350,0xf1bf0af0}},	//   _lins_, _clef_, zota_, _iyán_,
   {{0x6f02753e,0x290c753f,0x7d03006d,0x395d006c}},	//   rioc, ynda_, fins, _ntws_,
   {{0xdb0a1484,0x7d037540,0x6f021100,0xa3e5009f}},	//   lvfø, gins, sioc, बैक_,
   {{0x291e0206,0x612b007a,0xe2080034,0x60dc009c}},	//   vota_, külj, _wróć_, _iorm,
   {{0x7cef01df,0x291e0090,0x67247541,0x8fa300d3}},	//   _røre, wota_, _nkij, _шасе,
   {{0x60dc7542,0x7cef4b39,0x7d04014b,0x291e151b}},	//   _korm, _søre, éiss, tota_,
   {{0xfbc60c79,0x67240051,0x290c0a4b,0x753c00e7}},	//   _обзо, _akij, unda_, jmrz,
   {{0x39470472,0xdce96361,0x56952edd,0x6d480188}},	//   _dins_, _sveć, нант, _iida,
   {{0x39470682,0x291e7543,0xfbd300a1,0x6d4841de}},	//   _eins_, sota_, _שתף_, _hida,
   {{0x39477544,0x6d487545,0xf1bf002b,0x60dc0313}},	//   _fins_, _kida, _ayán_, _oorm,
   {{0x6724083e,0x6d487546,0x98bc020a,0x612b14ce}},	//   _ekij, _jida, _divă_, tülm,
   {{0x6d487547,0xdceb04f9,0x98a30284,0xd4043c75}},	//   _mida, stgħ, _рије, вяти,
   {{0x612b7548,0x6d487549,0x7d03754a,0x69c27540}},	//   rülm, _lida, zins, _kroe,
   {{0x60dc754b,0xdce90039,0x7d03754c,0xde8f00de}},	// [7490] _borm, _uveć, yins, hịch_,
   {{0x6d48008a,0x27320037,0x78ba754d,0x78b800bd}},	//   _nida, mána_, ndtv, _javv,
   {{0xdb1a6117,0x60dc754e,0x80c40285,0x78b80172}},	//   _artí, _dorm, राजे, _mavv,
   {{0x7d03754f,0x6d487550,0x656d655f,0xff2500cd}},	//   wins, _aida, _kwah, ربای,
   {{0x6d4857fb,0xdca528ce,0xa2cc0f8f,0x61301531}},	//   _bida, еали, हार्, mäln,
   {{0x6d481379,0x394f7551,0x60dc7552,0x7c280185}},	//   _cida, _rugs_, _gorm, _bydr,
   {{0xa3c106ed,0x75cb009d,0x764d0188,0x7c2800f0}},	//   ूमि_, ामुळ, _ogay, _cydr,
   {{0x764d7553,0x69c2355d,0x6d487554,0xe9d90f94}},	//   _ngay, _broe, _eida, зки_,
   {{0x7d037555,0x69c202ad,0x80b60034,0x78b80172}},	//   pins, _croe, _उसमे, _bavv,
   {{0xe8f619a0,0xf1b200f5,0x6d487556,0x6724005f}},	//   ель_, נסי_, _gida, _skij,
   {{0x78b8013d,0x39477557,0xd706075f,0x656d60d9}},	//   _davv, _vins_, езни, _awah,
   {{0x39477558,0x9ad30134,0x394f24da,0x656d7559}},	//   _wins_, _dịch, _tugs_, _bwah,
   {{0x69c23fc3,0xa91d0031,0x612b01f9,0x3320014b}},	//   _groe, huži, rülj, voix_,
   {{0x39996245,0x7ae9755a,0x6abb755b,0x764d010a}},	//   mès_, lket, lduf, _egay,
   {{0x3999755c,0x03a30084,0x656d00d1,0x799b03e3}},	//   lès_, лиро, _ewah, ltuw,
   {{0x7ae9755d,0xa91d0039,0x60dc755e,0x672431ab}},	//   nket, duži, _sorm, _ukij,
   {{0x3999755f,0x60dc1ba1,0x6e297560,0xbbbd0557}},	// [74a0] nès_, _porm, _nyeb, ्मुक,
   {{0x29057561,0xb2231bf9,0x26f007d5,0x60dc1b41}},	//   nila_, умул, _चतुर_, _qorm,
   {{0x60dc3e0f,0x7ae93b0b,0xd12f00e3,0x6d487562}},	//   _vorm, kket, حمل_, _rida,
   {{0x6d487563,0x6e297564,0x29057565,0x7ae90095}},	//   _sida, _byeb, hila_, jket,
   {{0x60dc7566,0x29057567,0x6d482065,0x7f497568}},	//   _torm, kila_, _pida, _dieq,
   {{0xd37802e6,0xa91d7569,0x3999756a,0x7ae9756b}},	//   šću_, buži, dès_, eket,
   {{0x6d482452,0x3dd80081,0x78b80451,0x7f4902a1}},	//   _vida, _দেখল, _ravv, _fieq,
   {{0x69c210b5,0xd00f1a13,0x7c28025b,0x78b8756c}},	//   _proe, _الف_, _vydr, _savv,
   {{0x6d48756d,0x6e9300e3,0x3999756e,0xa92a004b}},	//   _tida, _حلقا, gès_, зіне_,
   {{0x69c20934,0x2905006d,0x2732030b,0x656d05bd}},	//   _vroe, gila_, vána_, _rwah,
   {{0x28d205d4,0xad1b22fe,0x656d756f,0x69c20abf}},	//   ताबि, _צובר, _swah, _wroe,
   {{0x69c27570,0x7ae97571,0x39997572,0x27320094}},	//   _troe, cket, bès_, tána_,
   {{0x29057573,0x3999025a,0x48e61165,0xceb300c1}},	//   bila_, cès_, _подв, ניש_,
   {{0x27322159,0x27390113,0x00000000,0x00000000}},	//   rána_, kéng_, --, --,
   {{0xd7ef7574,0x9f47025b,0xe3b00018,0xf2c77575}},	//   _су_, šné_, یرہ_, нсан,
   {{0x656d4ee2,0x00000000,0x00000000,0x00000000}},	//   _twah, --, --, --,
   {{0x02e10714,0x7f494126,0x612b7576,0x656d7577}},	// [74b0] _नवीन, _rieq, lüli, _uwah,
   {{0xa91d04a3,0x7ae902a7,0x25a90167,0x6d4f014b}},	//   tuži, zket, _ipal_, _écai,
   {{0x2d800181,0x613000c2,0xa91d07c0,0x5f95008f}},	//   šiel_, mäll, držl, тиет,
   {{0xa91d0660,0x6e2902f1,0x613000ce,0x7ae90062}},	//   ruži, _pyeb, läll, xket,
   {{0xa3b9048a,0x7c2d01c2,0xb276006e,0x00000000}},	//   चिक_, ƙark, _בערג_, --,
   {{0x29057578,0x399906a3,0x25a900b3,0x6130007b}},	//   xila_, vès_, _mpal_, näll,
   {{0x7ae97579,0x611400e5,0x4034757a,0x7f490078}},	//   tket, _сдру, _берс, _tieq,
   {{0x63ba052f,0x3999757b,0x799b03e3,0x635c0141}},	//   ætni, tès_, ttuw, _učne,
   {{0x7ae9757c,0x7cf401b5,0x6130173a,0x6abb1aa7}},	//   rket, _bàrd, käll, rduf,
   {{0x3eaf49bf,0x3999757d,0x61300853,0x7ae9757e}},	//   legt_, rès_, jäll, sket,
   {{0x2d8f00e9,0x25a9757f,0x8ae700d6,0x2d820572}},	//   luge_, _apal_, _підл, _åker_,
   {{0xb8e8269c,0x39992740,0x7cf4009c,0x00000000}},	//   _लो_, pès_, _eàrd, --,
   {{0x29057580,0xd7f80012,0x61300a6a,0xc8f5008f}},	//   pila_, ază_, fäll, _издъ,
   {{0x7c2461f0,0x2d9d0350,0x00000000,0x00000000}},	//   şire, itwe_, --, --,
   {{0xb4b25339,0x232a3dba,0x25a97581,0xddc90078}},	//   _ऐसी_, дови_, _epal_, _adeż,
   {{0xb6a600ae,0x2ed00354,0x00000000,0x00000000}},	//   _риил, _सचेत, --, --,
   {{0x9c7c0087,0xdddb00d3,0x43433f28,0x3f570231}},	// [74c0] _hoče, _reuş, ретв, _açu_,
   {{0x9c7c21ee,0xf0630156,0x00e400d1,0x00000000}},	//   _koče, икуп, دتری, --,
   {{0xdb011de1,0x9c7c05db,0x7cf40139,0x6130007b}},	//   _aplí, _joče, _jàre, sälo,
   {{0x2d8f7582,0x2d800029,0x69c4013f,0x273901dc}},	//   fuge_, šiem_, _šiem, réng_,
   {{0x9c7c0087,0x2d9609b9,0x7cef00f3,0x2d8f3759}},	//   _loče, трес, _søra, guge_,
   {{0x79897583,0x645c7584,0x27390031,0x61eb0c89}},	//   drew, ncri, méne_, øgle,
   {{0x69dd7585,0x9c7c033b,0x79890036,0x09df0033}},	//   äsen, _noče, erew, _বেলা,
   {{0x2732030b,0x501b00a1,0x2fc7052f,0x64df0971}},	//   dáno_, _חולו, ænge_, _नक्श,
   {{0x645c6035,0xbda54345,0xc8660bb4,0x00000000}},	//   kcri, _محلو, ктни, --,
   {{0x48aa00ae,0x00000000,0x00000000,0x00000000}},	//   фтим_, --, --, --,
   {{0x61300084,0x7cf400b3,0x8c463ac9,0x00000000}},	//   väll, _vàrd, _реже, --,
   {{0x9c7c02e6,0xcf9300ca,0x4bfb0796,0x645c0381}},	//   _doče, סטר_, _קלאס, ecri,
   {{0x6130070a,0x5963008f,0x59b618ff,0x99d30286}},	//   täll, _къща, _अनिर, _نتوا,
   {{0x3eaf01cb,0x271600e8,0x00000000,0x00000000}},	//   zegt_, rāna_, --, --,
   {{0x2bc50f53,0x8ca400c3,0x06ae0033,0xada30e43}},	//   विया, च्यो, গাজি, _zaúč,
   {{0x61300084,0x32641062,0x59b60d75,0x3f57003d}},	//   säll, итув, _अनार, _dħul_,
   {{0x645c037a,0x245900d3,0x25a90117,0x00000000}},	// [74d0] bcri, _папь_, _upal_, --,
   {{0x3eaf0364,0x25fc00c3,0x2d8f02a4,0x00000000}},	//   wegt_, _लेटी_, vuge_, --,
   {{0x7cef0021,0x7c2d0044,0x3eaf0ac1,0x00000000}},	//   _børn, ƙari, tegt_, --,
   {{0x97570796,0xf2c700ae,0x00000000,0x00000000}},	//   דיאו_, _рсон, --, --,
   {{0x2732030b,0x3eaf042c,0x6448007e,0x7dea00e8}},	//   záno_, regt_, ždit, _nēsā,
   {{0x2d8f7586,0x116a0281,0x3e7100fe,0x7c870131}},	//   ruge_, _سلفی_, ạt_, туде,
   {{0xeab100e3,0xc878008b,0x7cf42269,0x2d8f7587}},	//   معة_, dağ_, _bàrb, suge_,
   {{0x2732030b,0xb9170134,0x9c7c00d8,0x61304638}},	//   váno_, bagọ_, _roče, jälj,
   {{0x9c7c0141,0x00000000,0x00000000,0x00000000}},	//   _soče, --, --, --,
   {{0x9c7c0d95,0xb4b20067,0xdb1a0146,0x798901d0}},	//   _poče, _ऐसे_, _vrtá, rrew,
   {{0xd70a01b3,0xdea903e3,0x81d90033,0x27390206}},	//   енне_, _sheƙ, ়নি_, zéne_,
   {{0x7c2502e2,0x7cf40428,0x7e790124,0x273200d4}},	//   ühru, _vàre, nawp, ráno_,
   {{0xc87801d4,0xe9ce05b6,0x98a5185c,0xf985008f}},	//   bağ_, _ук_, _биле, _сгло,
   {{0xa91d0335,0x9c7c1e4d,0xdc4300b6,0x97c50781}},	//   tužu, _toče, _léči, _مقتو,
   {{0x9c7c00cb,0xc2610129,0x833a015f,0x04570037}},	//   _uoče, _ụdịr, ечат_, الفة_,
   {{0x645c1b14,0xa91d0128,0x27160325,0x00000000}},	//   scri, ružu, māno_, --,
   {{0x10a60b37,0xf8b7009d,0x00000000,0x00000000}},	// [74e0] лиан, _असाय, --, --,
   {{0x45fb00ca,0xa91d04ad,0x67267588,0x2d800031}},	//   _נהיג, držk, lokj, šiek_,
   {{0x749b0054,0x205510e8,0x00000000,0x00000000}},	//   _אייפ, ртур, --, --,
   {{0x3f861515,0x00000000,0x00000000,0x00000000}},	//   čou_, --, --, --,
   {{0xf76700fb,0xc27b028c,0xd1751ad1,0xfce62917}},	//   _گا_, _ארכי, _высы, лодо,
   {{0x412a00d6,0x65640051,0x7bde007b,0xb4b2074c}},	//   _чого_, _mtih, äpuo, _ऐसो_,
   {{0xf767003f,0xae04074c,0x7cef12dc,0x00000000}},	//   _دا_, _शेरन_, _tørn, --,
   {{0x7cef13ea,0x646600a7,0x62967589,0x3af1071c}},	//   _føro, əriş, ngyo, _pápa_,
   {{0x6130007a,0x656402a4,0x7cf400b3,0x00000000}},	//   välj, _ntih, _càrc, --,
   {{0x7f421a4a,0xdd8f0a09,0xc19b00ca,0xed57758a}},	//   lmoq, _روم_, עשיי, _соф_,
   {{0x59b60557,0xd6d50ae3,0x98c3163d,0x65640169}},	//   _अनवर, ажны, ссыл, _atih,
   {{0x28d21c83,0x7bc8758b,0x386000c4,0x00000000}},	//   ताहि, _irdu, _điru_, --,
   {{0x7a7b0266,0xe7b000b6,0x09e6004d,0x656400d8}},	//   _טראס, _जनकप, _щодн, _ctih,
   {{0x61300149,0x64430146,0xd83a00d3,0x00000000}},	//   sälj, _únik, _пэй_, --,
   {{0x6564758c,0x7ae221a8,0x00000000,0x00000000}},	//   _etih, _koot, --, --,
   {{0x81ae0081,0x7bc8758d,0xb5fb00d4,0x7ae200bc}},	//   কিন_, _mrdu, dbáv, _joot,
   {{0x9f47033a,0x7ae20d80,0x612b758e,0x53340e3a}},	// [74f0] ání_, _moot, kült, сетт,
   {{0x7bc8758f,0x98a76a54,0x7ae27590,0x7cef0120}},	//   _ordu, čiću_, _loot, _røro,
   {{0x9f47030b,0x53350d9b,0x7cef0120,0xd25105bc}},	//   šní_, _вент, _søro, _وند_,
   {{0xdb010094,0xf1ca0031,0xdb180537,0xa1953d1a}},	//   _oplá, _stáť_, lvvæ, _камч,
   {{0x7bc80a00,0x127a00c1,0x7bc3023e,0x7cef21ad}},	//   _ardu, _בארע, wvnu, _førl,
   {{0x7bc8009c,0x81bc0033,0x612b374f,0x394e009e}},	//   _brdu, _অথচ_, gült, _nifs_,
   {{0x2bc5099d,0x7ae27591,0x7e7900f9,0x4c920284}},	//   विधा, _boot, pawp, цијс,
   {{0xa91d007e,0x7cf4009c,0xdb010503,0x80c900a4}},	//   mrži, _pàrc, _bplá, _होते,
   {{0x7ae201ff,0x88d501b3,0x00000000,0x00000000}},	//   _doot, аўні, --, --,
   {{0x3ebf7592,0xfd130dce,0xa8551009,0x00000000}},	//   _haut_, _اجر_, штиј, --,
   {{0x3ebf0029,0x7ae27593,0x6d4301c2,0x07a50f80}},	//   _kaut_, _foot, mmna, шанн,
   {{0xdb0100ee,0x394e03a8,0x00000000,0x00000000}},	//   _eslò, _eifs_, --, --,
   {{0x3ebf063f,0xdce2025b,0xed590106,0x996713b2}},	//   _maut_, zpoč, _brži_, _стел,
   {{0x394e7594,0xddc200e7,0x00000000,0x00000000}},	//   _gifs_, nboš, --, --,
   {{0x04467595,0x7cef004d,0x29073743,0x68e37596}},	//   ревн, _rørl, _imna_, _iond,
   {{0x68e37597,0x160110ed,0xa91d02c8,0x2d9f0161}},	//   _hond, _लेकर_, drži, _oque_,
   {{0x68e37598,0x26d200a6,0x8be90081,0x7cf40049}},	// [7500] _kond, _inyo_, _কেমন_, _làra,
   {{0x26d2023e,0x273953bc,0x68e30120,0xddc205db}},	//   _hnyo_, ména_, _jond, jboš,
   {{0x68e37599,0x3ebf759a,0x26c001ff,0x7cf401ec}},	//   _mond, _baut_, _kaio_, _nàra,
   {{0x3ebf00d3,0x26c001e9,0xbea6013f,0x6f0b759b}},	//   _caut_, _jaio_, радк, gigc,
   {{0x26c00ba0,0x823600bf,0x7f42759c,0x3af10065}},	//   _maio_, _خردا, rmoq, _aápo_,
   {{0x6b81015d,0x68e30a00,0xa06700d3,0x00000000}},	//   _bvlg, _nond, _вара_, --,
   {{0x3ebf04ea,0xdb01025b,0x7ae21cab,0x7d0a0088}},	//   _faut_, _splá, _poot, rifs,
   {{0xbab831f6,0x9c7c472a,0x68e3759d,0x26d20a15}},	//   угих_, _doča, _aond, _nnyo_,
   {{0x68e314b1,0xdcfb02e6,0x7ae2759e,0xdb0102b6}},	//   _bond, _zvuč, _voot, _oplæ,
   {{0x26d20bb6,0x7ae242ce,0x9c7c1d95,0x29070063}},	//   _anyo_, _woot, _foča, _cmna_,
   {{0x68e3759f,0x7ae20006,0x26c00042,0x29070167}},	//   _dond, _toot, _baio_, _dmna_,
   {{0x6d4f0257,0x26c05b93,0xed590995,0x7c3a75a0}},	//   _écar, _caio_, _srži_, _iztr,
   {{0x6f0316c8,0xed590580,0x443a01c8,0x26c502c6}},	//   ènci, _prži_, _azp_, ělo_,
   {{0x68e30068,0x2bbd0be4,0x26d22bfe,0x290700ec}},	//   _gond, ्मचा, _enyo_, _gmna_,
   {{0x26c00072,0x38cb0470,0x09b61f88,0x00000000}},	//   _faio_, _جانی_, _अनुय, --,
   {{0x290c75a1,0x68e30505,0x248d0367,0x8c1b0327}},	//   lida_, _zond, şem_, דולי,
   {{0xdddb02e6,0x3ebf02e7,0x6d430c19,0x6b550138}},	// [7510] _oduš, _raut_, ymna, _išge,
   {{0x290c75a2,0x26c00a00,0xe04b001c,0x3ebf20ed}},	//   nida_, _zaio_, نشاه_, _saut_,
   {{0x3ebf2190,0x83191454,0x902801b3,0xf773006e}},	//   _paut_, _مقدر_, ацца_, ַקס_,
   {{0x290c75a3,0x02a775a4,0x9c7c033b,0x27f80206}},	//   hida_, _тром, _roča, úrny_,
   {{0x51840219,0x3ebf0257,0x28b7009f,0x443a01c0}},	//   _мура, _vaut_, _असलि, _zzp_,
   {{0x9c7c2778,0x61ed019f,0xa91d0a9e,0x290c75a5}},	//   _poča, myal, prži, jida_,
   {{0x290c1f84,0x68e375a6,0x3b09136c,0x6d4301cb}},	//   dida_, _rond, леко_, rmna,
   {{0x68e375a7,0xfbd0012b,0x61302a3c,0xce940036}},	//   _sond, بته_, väli, _масъ,
   {{0x6f0975a8,0x61ed75a9,0x290c75aa,0x26c00558}},	//   _imec, nyal, fida_, _raio_,
   {{0x290c75ab,0x672d34f0,0x7cef038c,0x9c7c0a9e}},	//   gida_, _akaj, _mørk, _toča,
   {{0xfbd000e3,0x26c075ac,0x9c7c0106,0x68e375ad}},	//   _يتم_, _paio_, _kočn, _vond,
   {{0x81ae0081,0x61ed0283,0x68e375ae,0x2d8f063d}},	//   কিত_, kyal, _wond, orge_,
   {{0x290c2027,0x9c7c02dd,0x6f090294,0xe9ce00d3}},	//   bida_, _močn, _mmec, _эк_,
   {{0x290c1f84,0x69cb02e2,0xed5910e1,0x68fa279f}},	//   cida_, _irge, _muž_, chtd,
   {{0xf7461a6d,0x764b01f9,0x00000000,0x00000000}},	//   _леко, _úgyn, --, --,
   {{0x6ab5007d,0x9c7c4fd4,0x6e3b0094,0x61e219da}},	//   _अघोर, _nočn, _ozub, äolo,
   {{0x6e3b0129,0xd5b10023,0x61ed0103,0xed590206}},	// [7520] _nzub, ắc_, gyal, _nuž_,
   {{0x205675af,0xdb1a05fe,0xd83e033b,0x6f090239}},	//   стар, _estè, ščem_, _amec,
   {{0x9c7c16aa,0x7afb0060,0xe4570341,0x287a006e}},	//   _bočn, khut, _לייט_, רנעמ,
   {{0x290c023f,0x6e9300e3,0x6286052f,0x61ed149c}},	//   zida_, كلما, _udko, byal,
   {{0x290c01ee,0x7cf40441,0x569b0266,0x61ed0027}},	//   yida_, _dàrn, רינצ, cyal,
   {{0x290c75b0,0x6f090129,0xed590335,0x963b0266}},	//   xida_, _emec, _duž_, נגסט,
   {{0x69cb75b1,0x290c75b2,0x9f47025b,0x6e3b0134}},	//   _arge, vida_, šná_, _ezub,
   {{0xbea31c16,0xbf1606fa,0x290c75b3,0x27320830}},	//   _наск, _اورب, wida_, báni_,
   {{0x290c75b4,0xed5909ac,0x00000000,0x00000000}},	//   tida_, _bržu_, --, --,
   {{0x3ce505e8,0x610f0138,0x6d4f1789,0x672d2727}},	//   _golv_, _gėlė, _écap, _skaj,
   {{0x69cb41b8,0x290c75b5,0xda6f01b3,0x7afb0372}},	//   _erge, rida_, _ня_, bhut,
   {{0x7afb4325,0x290c75b6,0xd6db090f,0xdc3b00c1}},	//   chut, sida_, уто_, _געבר,
   {{0xeb1405d4,0xfa360241,0x69cb00c4,0x80db0851}},	//   तचीत_, _اراد, _grge, नामे,
   {{0x290c041c,0x9c7c0146,0x555822d5,0xa99b00ca}},	//   qida_, _močo, саря_, _עבור,
   {{0x672d0095,0xdb1a4229,0x7cf40139,0x00000000}},	//   _tkaj, _asté, _làro, --,
   {{0x61ed75b7,0x672d0875,0xc9090033,0x657600eb}},	//   tyal, _ukaj, রকৃত_, _fwyh,
   {{0x9c7c134c,0x00000000,0x00000000,0x00000000}},	// [7530] _ročn, --, --, --,
   {{0x61ed19b7,0x6f0975b8,0xed5900cb,0x273202c6}},	//   ryal, _smec, _ruž_, váni_,
   {{0x61ed75b9,0xdfd100e3,0x3e5e0294,0x3ce50f3c}},	//   syal, بيا_, _ịta_, _rolv_,
   {{0x7cef01df,0xed59042d,0x61ed026a,0x635c09ac}},	//   _tørk, _puž_, pyal, _očnj,
   {{0x7cef01df,0x9c7c00c4,0x2d76007f,0x7c24173c}},	//   _høri, _vočn, głe_, şirl,
   {{0x27321e80,0x4aa61f88,0x3f8305db,0x00000000}},	//   ráni_, क्सव, _tvju_, --,
   {{0x9c7c75ba,0x09d102e8,0x7afb0060,0x7cfd015e}},	//   _točn, तम्य, thut, _lèrg,
   {{0x442100de,0x7e62028d,0x6f090a4b,0xfe540103}},	//   _mxh_, ccop, _umec, _ٹیوب_,
   {{0xe8f93c1a,0x7afb06e1,0xfd560134,0x3ce575bb}},	//   или_, rhut, _mgbị, _tolv_,
   {{0xa3cc0bd9,0x7afb75bc,0x7e7b1030,0xa3ba007a}},	//   लिम_, shut, _heup, _आईल_,
   {{0xf09209c1,0x6d4175bd,0x7e7b08d3,0x60c500e3}},	//   וני_, _ihla, _keup, idhm,
   {{0x6d5b75be,0x80d002d5,0x6f1900f0,0x9c7c033b}},	//   _kuua, _डोने, nnwc, _ločl,
   {{0x69cb6b03,0x7c2d020e,0x7e7b024a,0x3ead0216}},	//   _urge, şard, _meup, _mbet_,
   {{0xfd640134,0x2a7f01bf,0x6d5b75bf,0x18692917}},	//   _afrị, laub_, _muua, _таки_,
   {{0x69c975c0,0x6d410201,0x28c2009f,0x6d5b09a1}},	//   lvee, _mhla, _वोटि, _luua,
   {{0xf26a23a3,0xa3cc0789,0x613001bf,0x64570372}},	//   риал_, लिब_, hält, _egxi,
   {{0x6d4102a9,0xb5fb2cfa,0x69c940a4,0x3d1a08d4}},	// [7540] _ohla, lcán, nvee, _बदले_,
   {{0xe0d7438d,0x3ead0112,0x2a7f022e,0x6d41019f}},	//   ову_, _abet_, haub_, _nhla,
   {{0x14d70130,0x09b6218b,0xa2e6085f,0x7cfd05aa}},	//   _וויל_, _अन्य, _донд, _mèrd,
   {{0x6d4175c1,0x7cf401b9,0x0dca166f,0x60c5036b}},	//   _ahla, _eàrl, илей_, adhm,
   {{0x61301683,0x6d41152f,0x0cd454b5,0x7e7b030a}},	//   fält, _bhla, золю, _deup,
   {{0x6d4175c2,0x7e621173,0x7af90154,0xc5f300ca}},	//   _chla, scop, _alwt, ודד_,
   {{0x46ca00b6,0x8fa300ae,0x96ca023a,0x273200d4}},	//   ियाह, _оаре, ियाउ, lánu_,
   {{0x6d410201,0x7e7b0acb,0x7af903a8,0x2d76007f}},	//   _ehla, _geup, _clwt, płe_,
   {{0xaaa658a0,0x6d412e6a,0xf1bf0103,0x3dcd00d7}},	//   क्षक, _fhla, _száz_, _grew_,
   {{0x6d41006b,0xa3ba09d0,0x2d801dfc,0x80d000a5}},	//   _ghla, _आईं_, šies_, _डोमे,
   {{0xfaa6328a,0x00000000,0x00000000,0x00000000}},	//   _мажо, --, --, --,
   {{0x7cfd2307,0xf76f001c,0x9c7c0141,0x273200d4}},	//   _pèrg, کای_, _močm, kánu_,
   {{0xe3b803e0,0x6b550138,0x00000000,0x00000000}},	//   çın_, _išga, --, --,
   {{0x4aa61ab1,0x7c2d2af9,0x00000000,0x00000000}},	//   क्रव, şare, --, --,
   {{0xd7e616dd,0x613009b5,0xf1bf0103,0x44210113}},	//   _філо, häls, _nyár_, _qxh_,
   {{0x6eca030b,0x28a8007f,0x9c7c0117,0xd7f8044c}},	//   _सोलु, कभवि, _sočl, ncăm_,
   {{0x67ff0018,0x27320094,0x7cf401b5,0x9c7c05db}},	// [7550] _tájé, gánu_, _pàrl, _počl,
   {{0x4ad1007d,0xd1310f36,0x7f5c75c3,0x6d5b00c2}},	//   _दोनव, رما_, _burq, _ruua,
   {{0x74150a09,0x7e7b0257,0x442700de,0x53354444}},	//   _روحا, _peup, _ân_, _неот,
   {{0xf8b7099d,0x6d4175c4,0x7cfd06aa,0x61301489}},	//   _अस्प, _shla, _mère, wält,
   {{0x6d4175c5,0xf1bf016d,0x3ead75c6,0xbdf80037}},	//   _phla, _usá_, _vbet_, يرها_,
   {{0x9c7c1197,0x3ac70023,0x7cf4015e,0x6cc204d9}},	//   _uočl, _ốp_, _fàrm, ейша,
   {{0x2a7f75c7,0x6d4f0036,0x0ec62171,0x4154001f}},	//   taub_, _ècam, _रोकड, _цврс,
   {{0xa3cc0bd9,0x613002fd,0x3dcd00dc,0x81ae0033}},	//   लित_, sält, _trew_, কির_,
   {{0xdd9106fa,0xc33400a1,0xf99100e3,0x7cfd05fe}},	//   _سوا_, ווק_, ربة_, _pèrd,
   {{0xe8f9185c,0x69c92484,0x480500d6,0x3d940f00}},	//   сло_, rvee, зпов, _цифр,
   {{0xccf2004f,0x395f75c8,0xf09207a6,0x7cfd0113}},	//   _רכב_, squs_, ענט_, _cère,
   {{0xa25b00fd,0xd5b100fe,0x9c7c05db,0xdb030206}},	//   _saôn, ắn_, _nočj, ktné,
   {{0xcb1200a1,0x7bc10231,0x9c8314f3,0x00000000}},	//   _אלא_, _hslu, ščup, --,
   {{0x7bc10124,0x7cfd00b3,0x00000000,0x00000000}},	//   _kslu, _fère, --, --,
   {{0xa5071407,0xfdb809c4,0x9f590113,0x7cfd014b}},	//   чера_, _इन्फ, _èyèl_, _gère,
   {{0xaabd0455,0x877a006e,0xa3bd0285,0x00000000}},	//   ्यिक, _פאפי, _इनर_, --,
   {{0xe71700ca,0x7f5c037a,0xa7fc020e,0xc6930142}},	// [7560] _מחקר_, _surq, ncın, _נאז_,
   {{0x7bc10995,0x9c7c0234,0x00000000,0x00000000}},	//   _oslu, _počm, --, --,
   {{0x4abd22a3,0xaabd41f2,0x547700a1,0x7f5c75c9}},	//   ्याव, ्याक, _מגיע_, _qurq,
   {{0x273208a8,0x794d0034,0x6da63974,0x81bb0a43}},	//   máns_, _dźwi, зида, _অপর_,
   {{0x237f02e6,0x273275ca,0x7bc160b1,0x46dd0096}},	//   ćuje_, láns_, _aslu, यातह,
   {{0x7f5c75cb,0x4c9417b9,0xd1320037,0x61300212}},	//   _turq, фикс, _أمس_, räls,
   {{0x60231756,0xa9f4030b,0x9c7c007e,0x9f4900d4}},	//   _здра, इन्छ_, _hočk, žkám_,
   {{0xada61cf2,0x9c7c00b6,0xfbcf2827,0xdb0805aa}},	//   _набл, _kočk, اتو_, _asdò,
   {{0x3f9a01d9,0x7cef00f2,0x7cfd03a9,0xd7f8020a}},	//   lupu_, _rørv, _sère, rcăm_,
   {{0x7cef004d,0xfcaa001c,0x7cfd020d,0x7cf400b3}},	//   _sørv, _دارو_, _père, _màrk,
   {{0xe69500ae,0xb904023a,0x00000000,0x00000000}},	//   мины, _पच_, --, --,
   {{0x273208a8,0x7bdb00ca,0xdb0300d4,0x00000000}},	//   dáns_, _לקבו, ytné, --,
   {{0x6d4a75cc,0x60db03e3,0x273201f9,0x69dd0f06}},	//   omfa, _ɗumb, vánt_, äset,
   {{0x69c275cd,0x48e31011,0x656f0063,0x7cfd05aa}},	//   _isoe, _почв, rpch, _tère,
   {{0x7cef0ac9,0xd90e0d83,0x7cfd00ee,0x29150031}},	//   _tørv, _لیک_, _hèrc, ýbať_,
   {{0x78ba0068,0xf4080037,0x7cef01df,0x68ea02ac}},	//   letv, سيقى_, _hørt, _hofd,
   {{0x442d00a5,0x672f00a5,0x7cef052f,0x27320103}},	// [7570] łe_, mocj, _kørt, ránt_,
   {{0x51f81119,0x81ae0081,0x9c7c0146,0x656d46b6}},	//   чную_, কিং_, _dočk, _itah,
   {{0xdb030244,0x3f872159,0x2732002b,0x656d0090}},	//   stné, énu_, cáns_, _htah,
   {{0xff04004d,0x69c201c8,0x6443015e,0x00000000}},	//   нячн, _osoe, _úniq, --,
   {{0xddab2ca4,0x00000000,0x00000000,0x00000000}},	//   стел_, --, --, --,
   {{0x11da00a1,0x3af80139,0x98a501d3,0x7cfd00ee}},	//   _וחשב, _bépo_, kolā_, _sèrb,
   {{0x236600e7,0x00000000,0x00000000,0x00000000}},	//   _čojk_, --, --, --,
   {{0x80db007d,0x60c775ce,0x629f0060,0x752e09ac}},	//   नावे, _hajm, ngqo, zobz,
   {{0x656d674b,0x7cfd00b3,0x635c022b,0x764b0103}},	//   _ntah, _cèrc, _fčnw, _úgyh,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc100e9,0x656d46b6,0xdb01052f,0xb5fb0037}},	//   _uslu, _atah, _oplø, scál,
   {{0x60c701e5,0xa3cc03a2,0x635c0087,0x6b9c01df}},	//   _lajm, लिस_, _učni, _årga,
   {{0x7cef038c,0x443c0138,0x2bc5052c,0x06070f80}},	//   _ført, _šv_, विका, дняк_,
   {{0x60c70206,0x273226ca,0x9c7c0660,0x613002c3}},	//   _najm, táns_, _ročk, jälp,
   {{0x656d039f,0xa7fc026a,0x7cef01df,0x260e0442}},	//   _etah, ncıl, _hørs, _ढेरी_,
   {{0x273275cf,0x9c7c2347,0x7cef02b6,0x656d0090}},	//   ráns_, _počk, _kørs, _ftah,
   {{0x60c7580e,0x27320042,0x045a0076,0x00000000}},	// [7580] _bajm, sáns_, _وجدت_, --,
   {{0x3f9a75d0,0x7c2475d1,0x61eb0212,0x27320072}},	//   tupu_, şiri, ägla, páns_,
   {{0xa2a6030b,0x60c775d2,0xd12f0037,0xdee60161}},	//   _छाप्, _dajm, جمل_, можи,
   {{0x9c7c011d,0xee3a75d3,0x7aeb0313,0x78ba0103}},	//   _točk, оне_, _nogt, zetv,
   {{0x628475d4,0x656d0063,0x3f9a2ae7,0x78ba75d5}},	//   maio, _xtah, supu_, yetv,
   {{0x3f9a75d6,0x6d4a75d7,0x6284070b,0x628b0206}},	//   pupu_, umfa, laio, ógov,
   {{0x78ba75d8,0xa2a500d2,0x9c7c007e,0x7aeb75d9}},	//   vetv, ङ्क्, _joči, _bogt,
   {{0x7cef038c,0x60c700a5,0x69c20634,0x7cf4015e}},	//   _børs, _zajm, _psoe, _màri,
   {{0x7aeb0185,0x9c7c0087,0xa2a6030b,0x22420063}},	//   _dogt, _loči, _छान्, _jzkk_,
   {{0x7c2d008b,0x940400a7,0x200400a7,0xd83e0031}},	//   şara, şmə_, _əmin_, áčom_,
   {{0x656d75da,0x78ba0ea3,0x9c7c0087,0xb5fb0072}},	//   _stah, retv, _noči, rcám,
   {{0x7cef1a08,0x6f0275db,0x3cfe0076,0x69c2084e}},	//   _førs, nhoc, _hltv_, _tsoe,
   {{0xdb1a00c9,0x779200cd,0x628475dc,0x7cfd00b3}},	//   _estã, ریکا, daio, _hèra,
   {{0x672f10a4,0x9c7c0559,0x9f476130,0x7cfd0139}},	//   socj, _boči, ánú_, _kèra,
   {{0x7aeb01fa,0x289b0266,0x672f04e9,0x7cf4015e}},	//   _yogt, _ויוא, pocj, _càri,
   {{0x60c71419,0x62840956,0x9f470031,0x7aeb008c}},	//   _sajm, gaio, šnú_, _xogt,
   {{0x656d75dd,0x291e75de,0xa2a500b6,0x3f8e00e7}},	// [7590] _utah, onta_, ङ्ग्, šful_,
   {{0x272403a3,0xa3cc086d,0x291e50ec,0x25d600ca}},	//   mına_, लिश_, nnta_, _נותן_,
   {{0x291e75df,0x6b4575e0,0x272407aa,0x6f0200e3}},	//   inta_, lóge, lına_, fhoc,
   {{0x7cef052f,0x2b4600fe,0x2bc208c0,0xa7fc0233}},	//   _nørr, _nhoc_, _वैधा, vcıl,
   {{0x272407d1,0x60c7031a,0x291e01c2,0x26c9010a}},	//   nına_, _tajm, knta_, _maao_,
   {{0xdb1a0072,0x7cef00f3,0xdca20231,0x90870103}},	//   _ortó, _rørs, гаши, _زمرے_,
   {{0xeb993e86,0x4ada007d,0xcfa400ae,0x2b4601b9}},	//   чий_, भांव, _ишти, _bhoc_,
   {{0x6f0275e1,0x2b462620,0x845800a1,0x2ca902c6}},	//   choc, _choc_, ובוס_, řad_,
   {{0xb5290065,0x2724026a,0x28db0034,0x7aeb75e2}},	//   _atọ̀, jına_, बालि, _vogt,
   {{0x2eed0a9f,0xdb1a0472,0x27240511,0x62840634}},	//   _hoef_, _està, dına_, zaio,
   {{0xe73a2f11,0x2d9d75e3,0x26c9010a,0x7cfd03a9}},	//   зен_, luwe_, _baao_, _gèra,
   {{0x291e75e4,0x27240491,0x60db0022,0x3af80103}},	//   anta_, fına_, _ɗuma, _lépj_,
   {{0x9c7c75e5,0xdb0302c6,0x27240b12,0x2d9d05bd}},	//   _soči, ntní, gına_, nuwe_,
   {{0xb0ce00a5,0x25bf0131,0x2eed02ac,0xdb030076}},	//   _होंग, çula_, _loef_, itní,
   {{0xb602000d,0x628475e6,0x38ca01f3,0x2d9d75e7}},	//   _žádn, taio, _راوی_, huwe_,
   {{0x27240491,0x27f8038c,0x2d9d75e8,0xdb0302c6}},	//   bına_, ørne_, kuwe_, ktní,
   {{0x79894bf3,0x409601a0,0x46dd0179,0x628475e9}},	// [75a0] nsew, ерет, यारह, raio,
   {{0xa0a300d3,0x628475ea,0x9c7c75eb,0x628f02ac}},	//   лауд, saio, _toči, _edco,
   {{0x6f0275ec,0x628475ed,0x9c7c08c5,0x2d9d01cb}},	//   thoc, paio, _uoči, euwe_,
   {{0xdb1a385c,0xeda621be,0x3f4700bc,0xa85600ca}},	//   _ostá, ешко, jõud_, גיעה_,
   {{0x291e0694,0x9c7c1fce,0x2d9d0193,0x644101d3}},	//   ynta_, _močv, guwe_, ļlie,
   {{0x6f02745c,0x2eff0078,0x361b006e,0x7cfd03a9}},	//   shoc, _eluf_, הונד, _pèra,
   {{0x6f020113,0x44440141,0x67242caa,0x2724008b}},	//   phoc, _jz_, _ojij, zına_,
   {{0xe6ca0782,0x6e9606f6,0x444402db,0x27240511}},	//   ियोज, _سلطا, _mz_, yına_,
   {{0x256600f0,0x645a02ef,0x764475ee,0x69cd007f}},	//   _nôl_, žtih, _nziy, तिषी,
   {{0xf2df00ef,0x39581c6d,0x672475ef,0x291e52b6}},	//   _nhân_, örs_, _ajij, unta_,
   {{0xdb1a38c0,0x7cef038c,0x764444d9,0x80ca0081}},	//   _está, _tørr, _aziy, রাপ্,
   {{0x272407d1,0xaaa7072d,0xdbc7007a,0x6b456a26}},	//   tına_, _गायक, _pöör, tóge,
   {{0x444475f0,0x7c3a0150,0x443a13e0,0x7a4900fd}},	//   _az_, _hytr, _ayp_, rêté,
   {{0x27240390,0xf2df0028,0x67240134,0x2bc50980}},	//   rına_, _chân_, _ejij, विचा,
   {{0x444475f1,0x6d5a75f2,0x272406d7,0x76442828}},	//   _cz_, _mita, sına_, _eziy,
   {{0x7c3a008f,0x083b00a1,0xdbc700aa,0x5334203c}},	//   _mytr, _מעול, _töör, гест,
   {{0x444412c3,0x80ca00c7,0x32550f16,0xf1940686}},	// [75b0] _ez_, রান্, твар, лить,
   {{0x6d5a2144,0x55ac006e,0x673d502a,0x7cf40065}},	//   _nita, _צייַ, llsj, _kàru,
   {{0x2eed1cab,0x7c3a2c28,0x0f3500d1,0x8af7013c}},	//   _poef_, _nytr, نکرد, _şəmk,
   {{0x6d5a415d,0x3ee4013d,0x2d9d75f3,0xfe71001c}},	//   _aita, лючв, tuwe_, شگر_,
   {{0x6d5a72fc,0xa2a60c8c,0xdca50070,0xd24400ae}},	//   _bita, _छात्, вали, _бэри,
   {{0x6d5a75f4,0x2d9d75f5,0x27390094,0x2eed1cab}},	//   _cita, ruwe_, ménu_, _woef_,
   {{0x6d5a0655,0xdb030618,0x6d4801ec,0x7c3a007f}},	//   _dita, stní, _dhda, _cytr,
   {{0xe9d90f94,0x8e8400e3,0x798975f6,0x6d5a75f7}},	//   дки_, _ملفه, tsew, _eita,
   {{0x6d5a1114,0x79890154,0x2b4d044c,0xb69b0231}},	//   _fita, usew, rmec_, thân,
   {{0x6d5a75f8,0x79890238,0x2bc21462,0x256600f0}},	//   _gita, rsew, _वैवा, _rôl_,
   {{0x79890090,0x7d010795,0x7cf400b3,0x00000000}},	//   ssew, _ills, _pàrv, --,
   {{0x6d5a75f9,0x68060113,0x6e3b0167,0x44441399}},	//   _zita, _séjé, _kyub, _rz_,
   {{0xf2df0028,0x7ae975fa,0x444475fb,0x644509a4}},	//   _phân_, mjet, _sz_, _azhi,
   {{0x7ae975fc,0x444475fd,0x81e70081,0xdddb0542}},	//   ljet, _pz_, বনা_, _oduž,
   {{0x28a63b30,0x29050013,0x25f20096,0x443a5fd5}},	//   _खाति, mhla_, ुनही_, _qyp_,
   {{0x7afb047a,0x61e441da,0xc3230ef7,0x61f6007b}},	//   nkut, txil, амск, tyyl,
   {{0xf2df0028,0x7d010037,0x3320225b,0x6e3b2960}},	// [75c0] _thân_, _olls, rnix_, _nyub,
   {{0x443a75fe,0x444475ff,0x29050201,0x7ae97600}},	//   _typ_, _tz_, nhla_, hjet,
   {{0x444457dc,0x7afb7601,0x7fd500d6,0x7cf47602}},	//   _uz_, kkut, ліці, _màrt,
   {{0x6d5a7603,0x7d017604,0x7f497605,0x7ae91233}},	//   _sita, _alls, _cheq, jjet,
   {{0x6d5a03ce,0x7ae96a6a,0x29055c3d,0xbea31d7b}},	//   _pita, djet, khla_, рачк,
   {{0xe0464c88,0x656400c2,0x1d3304a1,0xb5fb0103}},	//   _анги, _muih, анія, tbáz,
   {{0x9fc70636,0xb5fb0037,0x09bc0403,0x2bc2277c}},	//   _игра_, rcái, ्ट्य, _वैशा,
   {{0x6d5a7606,0xb5fb00e3,0x4cc80081,0x7afb7607}},	//   _wita, scái, লাধু, gkut,
   {{0x6d5a3698,0x7c3a0034,0xee37004b,0x973d0095}},	//   _tita, _wytr, _ант_, nuće,
   {{0x6d5a002d,0x9c7c25b5,0x7afb7608,0x00000000}},	//   _uita, _poču, akut, --,
   {{0xa09b0130,0x27397609,0x7ae9760a,0x909b00ca}},	//   וייט, ként_, bjet, וסיק,
   {{0x973d00cb,0x7d180f63,0x29050206,0x00000000}},	//   kuće, livs, ahla_, --,
   {{0x973d0039,0x65640113,0xceb3006e,0x199429b6}},	//   juće, _cuih, סיש_, _саля,
   {{0x973d08a9,0x2905035d,0x77630072,0x6564009c}},	//   duće, chla_, _funx, _duih,
   {{0xd7ef760b,0x93880326,0x55580012,0x386e0072}},	//   _ту_, кста_, таря_, _iffr_,
   {{0x7d180128,0x273900d4,0x00000000,0x00000000}},	//   hivs, ténu_, --, --,
   {{0xdb1a0222,0x973d084f,0x45d51fdb,0x7d180d2d}},	// [75d0] _istä, guće, _сопс, kivs,
   {{0xc7ad0068,0x7f49023b,0x27391054,0x7cf40e8b}},	//   _بڑی_, _sheq, rénu_, _xàrt,
   {{0x7535003d,0x6e3b3653,0x50644a6f,0x1e700174}},	//   mozz, _syub, ртуа, _ịtọl,
   {{0x7535760c,0x395c1842,0xf2df00fe,0x9c820234}},	//   lozz, _livs_, _khâm_, ščla,
   {{0x3da728b9,0x7ae9760d,0xa184055b,0x41e401b3}},	//   треб, vjet, _высл, _кіра,
   {{0x75350a53,0x6b550138,0x7ae9760e,0x40350a3a}},	//   nozz, _išgi, wjet, _бегс,
   {{0xa3cc02b0,0x7ae9760f,0x4fc400c2,0x7afb03a7}},	//   लिए_, tjet, _кста, tkut,
   {{0x05c302d5,0x7cfd0113,0x49c92a59,0xaada00b6}},	//   षबाब, _tèro, елин_, भागक,
   {{0x7ae97610,0x9c7c0244,0x7afb7611,0x7cf47612}},	//   rjet, _počt, rkut, _càrs,
   {{0x7ae94f4f,0x77631b27,0x6f1900f0,0x7cf400b3}},	//   sjet, _punx, liwc, _dàrs,
   {{0x7ae97613,0x656400c2,0x7cfd03a9,0x29057614}},	//   pjet, _suih, _jèrm, rhla_,
   {{0x6f1900f0,0x7cf4009c,0x2905007e,0x7aa4004d}},	//   niwc, _fàrs, shla_, _виїз,
   {{0x59b71006,0xf2df00de,0x80ca0033,0x7cf400b3}},	//   _अहिर, _châm_, রাত্, _tàrt,
   {{0xc99200e3,0xdb1a00c2,0x75357615,0xddc217a0}},	//   _الوظ, _estä, gozz, ncoš,
   {{0x65640449,0x00000000,0x00000000,0x00000000}},	//   _wuih, --, --, --,
   {{0x316900a7,0xf2a300ae,0xdd850103,0x00000000}},	//   fqaz_, йисп, _وڈ_, --,
   {{0x91e301c9,0x75357616,0x26c27617,0x98ac01d3}},	// [75e0] боте, bozz, meko_, lodā_,
   {{0x26c27618,0x2739538a,0x51560686,0x7535028d}},	//   leko_, béns_, утбу, cozz,
   {{0xdb1a0084,0x9f47025b,0x28a617ff,0x6f1900f0}},	//   _ystä, šný_, _खासि, fiwc,
   {{0x26c202a7,0x973d00cc,0x6e46001c,0x00000000}},	//   neko_, puće, هنام, --,
   {{0xa3cc0557,0xb5fb0231,0x00000000,0x00000000}},	//   लिक_, scáv, --, --,
   {{0x26c20634,0x93620134,0x6b8100eb,0xac182290}},	//   heko_, _ọnyị, _bwlg, колу_,
   {{0x62860da3,0x26c27619,0x7d180973,0x6fc802d5}},	//   _keko, keko_, rivs, _रनिं,
   {{0x7cf40472,0x26c20ea3,0x6f190150,0x6286739b}},	//   _càrr, jeko_, ciwc, _jeko,
   {{0x60ce022e,0x26c202a7,0x58860077,0xbef700a1}},	//   _kabm, deko_, лына, _עצמו_,
   {{0x57b42aed,0x6286761a,0xd90d110a,0xd8f8004d}},	//   абот, _leko, وین_, тної_,
   {{0xdb03025b,0xeb970ac6,0x394200d9,0x59d2030b}},	//   stná, _бих_, ēks_, तिहर,
   {{0x628604a3,0x26c2092f,0x6d4f0036,0x7cf401ec}},	//   _neko, geko_, _ècar, _gàrr,
   {{0xf2df0019,0xadf900c3,0x00000000,0x00000000}},	//   _giây_, ्नयन_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7535761b,0x6286761c,0x26c20a00,0x99470037}},	//   rozz, _beko, beko_, _حلول_,
   {{0x41e70f1e,0x628603a9,0x427500e5,0xf2df00de}},	//   ліза, _ceko, ргас, _thâm_,
   {{0x161c110f,0xb11501b6,0x9259001f,0x349525e7}},	// [75f0] _पेपर_, амаш, таат_, _капр,
   {{0x100721b9,0xa3cc00c3,0xdddb00d4,0x7cfd0154}},	//   ляем, लिख_, _neuš, _pèrm,
   {{0x9976007f,0x155a00d7,0x00000000,0x00000000}},	//   nęły_, _שכתב, --, --,
   {{0x62860d50,0x2fca0063,0x7c2d04a8,0x7982010a}},	//   _geko, _dsbg_, şark, _owow,
   {{0x9ad40134,0x6f190150,0x78b8010a,0x00000000}},	//   _pịny, riwc, _obvv, --,
   {{0x26c203f3,0xe3b009b4,0xeb992a72,0x7cfd761d}},	//   zeko_, _بری_, вик_, _tèrm,
   {{0x26c20453,0x1d0600e5,0x7cf4009c,0x62860517}},	//   yeko_, рещи_, _pàrr, _yeko,
   {{0x26c201e9,0x79820172,0x241800ca,0x1a6800d1}},	//   xeko_, _bwow, טחון_, هیمی_,
   {{0x31af564a,0x090515c2,0x6ca71f9c,0x799b03e3}},	//   nüz_, ипин, _مصال, uruw,
   {{0xbc6800e3,0x29030018,0x6b450165,0x26c2761e}},	//   _ممكن_, ója_, cógn, weko_,
   {{0x26c2761f,0x28a6000f,0x7b1700d3,0x7cf40428}},	//   teko_, _खारि, lţum, _tàrr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd8f500bf,0x26c27620,0x38ca00cd,0x6b450220}},	//   _پزشک, reko_, رایی_, lógo,
   {{0x628606e1,0x26c27621,0x88bc00b6,0x69d902a1}},	//   _seko, seko_, lněn, _irwe,
   {{0x07a53edd,0x26c201e9,0x833a004d,0x62867622}},	//   _тайн, peko_, вчат_, _peko,
   {{0xaabd20cd,0x05661497,0xb226083c,0x236b02c6}},	//   ्यटक, _квин, амбл, _žijí_,
   {{0x62867623,0x21a608e5,0xf267002d,0xdc340206}},	// [7600] _veko, ризм, риул_, _rúčk,
   {{0xe0461d18,0xb05a0037,0xdb0300bc,0x5fd62636}},	//   анзи, نشاط_, ltnä, ицеф,
   {{0x62867624,0x0fd91ad1,0xc05900d6,0x34b703c2}},	//   _teko, льцы_, гії_, _דפים_,
   {{0xf98700bf,0x205522ee,0x69d97625,0x88bc00b6}},	//   _وب_, стур, _orwe, jněn,
   {{0x60ce023e,0x88bc00b6,0x63be0063,0xae160006}},	//   _tabm, dněn, _hppn, _देशन_,
   {{0x80ca00c7,0x260700a3,0x3ea6019c,0x7cf40428}},	//   রাহ্, हनती_, sgot_, _pàrq,
   {{0xb5fb0396,0x69d90150,0x69cb7626,0x7ac600c6}},	//   ncár, _arwe, _asge, аспе,
   {{0xbea3393e,0x00000000,0x00000000,0x00000000}},	//   _маск, --, --, --,
   {{0x38c800cd,0x6c960076,0x00000000,0x00000000}},	//   هادی_, _نشاط, --, --,
   {{0xa3e6033a,0xd90e1e49,0x273210a8,0x7f427627}},	//   पमा_, بیت_, mány_, lloq,
   {{0x69d902e2,0x47350dde,0x30d900c1,0xda6f002d}},	//   _erwe, йнос, אַרע, _мя_,
   {{0x88bc00b6,0x7bda0090,0xd8380095,0x00000000}},	//   cněn, _irtu, ngči_, --,
   {{0x973d00e9,0xceb300a1,0x7ae27628,0x80a70403}},	//   guća, חיר_, _inot, _चाले,
   {{0xb0d50096,0xd90e001c,0x31af071d,0xd4981e9e}},	//   _डोंग, _آید_, vüz_, ирс_,
   {{0x27320018,0xd7fa0831,0x261702d5,0xd7940308}},	//   hány_, _јул_, _पेरी_, _البخ,
   {{0xe70509e5,0x63be0063,0xdb1a15c1,0xa3cc00a8}},	//   _دستی, _dppn, _astú, लिज_,
   {{0x335800d3,0xb5fb002b,0x20670284,0x00000000}},	// [7610] ратэ_, acár, ађев, --,
   {{0x7bda7629,0x88bc02c6,0x2732762a,0x31af0847}},	//   _ortu, zněn, dány_, rüz_,
   {{0x83f9319f,0xa26700e5,0x31af020e,0x7ae212ed}},	//   _сенс_, _въгл, süz_, _onot,
   {{0xf8c90065,0xdb1a0d5a,0xa85700a1,0x2cac01ec}},	//   _abẹ́_, _estú, ביבה_, _acdd_,
   {{0xd08700c2,0x88bc00b6,0x6b6a0034,0x27324e96}},	//   _выби, vněn, _węgl, gány_,
   {{0x7ae200a1,0xfbd100e3,0x2bd34422,0xf1bf0032}},	//   _anot, كتب_, थिला, _ipá_,
   {{0x7f4200fd,0x88bc00b6,0x7f940077,0x4ea70161}},	//   bloq, tněn, _марх, _врза,
   {{0x7bda762b,0xcac90084,0xdb03023b,0xd5b90c22}},	//   _drtu, угие_, munë, ेबाज,
   {{0x88bc00b6,0x80ca0081,0x7cfd0113,0x3ead762c}},	//   rněn, রার্, _lèri, _icet_,
   {{0x09050dc9,0x60c502e2,0x7ae2762d,0x628d0124}},	//   спон, nehm, _enot, haao,
   {{0x88bc00b6,0xdab901b3,0xd90d001c,0x00000000}},	//   mněl, _былі_, ویچ_, --,
   {{0x6d430222,0x0a1800bf,0x7ae201b5,0x79800174}},	//   llna, افیک_, _gnot, _ịwec,
   {{0xe8ee1525,0x69d90193,0x7cfd0428,0xdb031489}},	//   _ел_, _urwe, _aèri, rtnä,
   {{0x4aa70378,0x7ae2762e,0x973d0a39,0xe4da001c}},	//   _गाँव, _znot, ruća, دوست_,
   {{0xe29a3a6f,0xf1bf0d79,0x68fc3737,0x69c96237}},	//   лав_, _apá_, örde, lwee,
   {{0x6aa9762f,0xadf907d5,0x27f809a1,0x7cfd00ee}},	//   ngef, ्नान_, ärne_, _dèri,
   {{0x9c82013f,0x69c97630,0xb5fb05e6,0x64a612d1}},	// [7620] ščia, nwee, scár, _лапа,
   {{0x26d26f27,0x343a0241,0x27327631,0x6aa901bf}},	//   _hayo_, _مسجد_, vány_, hgef,
   {{0x26d203cb,0x63be07b0,0xdb1a0220,0x4aa70101}},	//   _kayo_, _uppn, _vstú, _गांव,
   {{0x69c97632,0x26d26025,0xbea601ef,0x27326945}},	//   kwee, _jayo_, садк, tány_,
   {{0x26d27633,0xdd8f0fb7,0x644a015c,0x7f420231}},	//   _mayo_, فون_, šlić, rloq,
   {{0xd132177a,0x26d234ba,0x06e4009f,0x69c9226b}},	//   _رمز_, _layo_, गाँव_, dwee,
   {{0x973d03ce,0x8fa328b9,0xb60602dd,0x6aa91c7e}},	//   dućn, _наре, lišč, fgef,
   {{0x26d27634,0x68e37635,0x497405d8,0x7bda0146}},	//   _nayo_, _annd, олис, _vrtu,
   {{0xdce2005f,0xb606033b,0x3eb300a7,0x6f022c85}},	//   spođ, nišč, əxt_, mkoc,
   {{0xa2da0789,0x973d02e6,0xdd8f00e3,0xd8e608e5}},	//   _पोस्, gućn, _أول_, сцип,
   {{0x06e40f35,0x26d27636,0x7d0800f2,0x7bda0062}},	//   गांव_, _bayo_, _ilds, _urtu,
   {{0x26d27637,0x7ae2063d,0x68e3010a,0x6f027638}},	//   _cayo_, _unot, _ennd, nkoc,
   {{0xe8941476,0x7cfd0472,0x7afd7639,0xb6060087}},	//   _даль, _sèri, öste, jišč,
   {{0xb6060b27,0xf76f00bf,0x7cfd763a,0xbebd00c6}},	//   dišč, بای_, _pèri, _pjūk,
   {{0x249f03a3,0xf1bf763b,0x26d2763c,0x00000000}},	//   ğum_, _spá_, _fayo_, --,
   {{0x26d2763d,0x6ec40ccb,0x249f020e,0x6b7100e8}},	//   _gayo_, _रसगु, şum_, _jāga,
   {{0x291e0084,0x50f50cb0,0x6f020031,0xa3ce02c6}},	// [7630] oita_, озат, dkoc, _míří_,
   {{0x291e117e,0x26d24dae,0x8319001c,0x764d763e}},	//   nita_, _zayo_, _چقدر_, _izay,
   {{0x26d24dae,0x672d00e7,0x6f020364,0x291e024a}},	//   _yayo_, _kjaj, fkoc, iita_,
   {{0x291e763f,0x2a66023e,0x7d1a4192,0x141a00ca}},	//   hita_, _ngob_, _amts, _כותב,
   {{0x291e7640,0x290c008a,0x14de0096,0x7cfd0154}},	//   kita_, khda_, _फोडण, _mèrv,
   {{0x672d1cae,0x21ba00c1,0xdb037641,0xed590161}},	//   _ljaj, _דזשא, punë, шол_,
   {{0x973d01ac,0x81bb0081,0xf53f0b97,0x2d490042}},	//   jućo, _আছি_, mråd_, búen_,
   {{0x69c90054,0x7d0857eb,0x6f0200e7,0x973d00cc}},	//   twee, _elds, ckoc, dućo,
   {{0x291e7642,0x6aa90ba1,0x26d200e1,0xae16009d}},	//   fita_, rgef, _rayo_, _देऊन_,
   {{0x69c91f49,0x26d27643,0x6aa901bf,0x88bc00b6}},	//   rwee, _sayo_, sgef, lněj,
   {{0xb17b070a,0x69c93eba,0x26d200a6,0x973d042d}},	//   _fråg, swee, _payo_, gućo,
   {{0xe73a0636,0x05060081,0xf2df0023,0x7cfd00ee}},	//   рем_, _ঈদের_, _khâu_, _cèrv,
   {{0x291e7644,0x95831402,0xa2da04d7,0x6f09263e}},	//   bita_, мляе, _पोष्, _mlec,
   {{0x290c01f7,0x973d0106,0x26d27645,0xb606033b}},	//   chda_, vrće, _wayo_, višč,
   {{0x26d20256,0xc7460604,0x6f1b06b0,0x764d7646}},	//   _tayo_, _وضعي, _omuc, _ezay,
   {{0xa22a02b3,0xb6060087,0x7bc10072,0x98ac0138}},	//   ажба_, tišč, _mplu, rodą_,
   {{0xdce000d3,0x256f0511,0x88bc00b6,0x6f0223a0}},	// [7640] _jumă, _gül_, dněj, vkoc,
   {{0xa2da000c,0xf53f0501,0xb60602dd,0x6f091497}},	//   _पोर्, står_, rišč, _alec,
   {{0x7bc1006c,0x2d4903be,0x753c7647,0x6f097648}},	//   _nplu, túen_, morz, _blec,
   {{0x91e67649,0x44443194,0x63a10181,0x290c56d8}},	//   _доме, _iy_, álne, zhda_,
   {{0x44441f30,0x6f020ab2,0x7bc102e5,0xf2df0028}},	//   _hy_, rkoc, _aplu, _châu_,
   {{0x4444764a,0x6f091647,0x291e0a00,0x6f02764b}},	//   _ky_, _elec, xita_, skoc,
   {{0x44441f30,0x6f09764c,0x88bc02c6,0x46aa764d}},	//   _jy_, _flec, bněj, _कांह,
   {{0x44441cc0,0xaec34faa,0x39450472,0x7644764e}},	//   _my_, _обсл, ells_, _oyiy,
   {{0x291e764f,0x753c0067,0x764403a9,0x44447650}},	//   tita_, korz, _nyiy, _ly_,
   {{0x672d00e9,0xeb9a0465,0x44447651,0x644100aa}},	//   _sjaj, _виж_, _oy_, ülik,
   {{0x44440501,0x291e7652,0xdce908a9,0xe1ff00de}},	//   _ny_, rita_, _steć, _ngón_,
   {{0x290c7653,0xa2da201e,0x764405bd,0x249a020a}},	//   shda_, _पोल्, _byiy, _adpm_,
   {{0x44447654,0x291e7655,0x753c7656,0xdb030031}},	//   _ay_, pita_, forz, ytnú,
   {{0x44447657,0x81c20033,0x657d7658,0xe4e4004d}},	//   _by_, ্মা_, rpsh, місн,
   {{0x4444092f,0x987b0341,0x76442673,0x291c05bd}},	//   _cy_, _דרוק, _eyiy, _imva_,
   {{0x44447659,0x63a70335,0xf2df00fe,0x68f80120}},	//   _dy_, rujn, _nhât_, _hovd,
   {{0x4444765a,0x88bc030b,0xf53f682e,0x764d765b}},	// [7650] _ey_, vněj, tråd_, _uzay,
   {{0xd49b0562,0x444402ad,0x6f090ab2,0x61ed0188}},	//   _три_, _fy_, _slec, rxal,
   {{0x6f094a4c,0x44440283,0x656d765c,0xf53f0b97}},	//   _plec, _gy_, _huah, rråd_,
   {{0xdb030979,0x656d0239,0xf53f0f3c,0xb69b020d}},	//   puné, _kuah, sråd_, chât,
   {{0x237f005f,0x7bc1765d,0x88bc00b6,0x6f095abd}},	//   ćuju_, _splu, rněj, _vlec,
   {{0x88bc00b6,0x00000000,0x00000000,0x00000000}},	//   sněj, --, --, --,
   {{0x6b450206,0x656d0332,0x69c2191d,0xcfb4008f}},	//   lógi, _luah, _apoe, _обръ,
   {{0xb17b1bfa,0x6f1b023f,0x753c765e,0x212100e7}},	//   _tråd, _umuc, zorz, lihh_,
   {{0x3b0d0052,0x7cfd00b3,0x68f8765f,0x7764008c}},	//   rheq_, _sèru, _bovd, _riix,
   {{0x656566ea,0x635c0383,0x76440079,0x23cb18ff}},	//   _nihh, _dčny, _ryiy, ाबाद,
   {{0x6d414b82,0x753c7660,0x6445023e,0x60d566b1}},	//   _ikla, vorz, _nyhi, _mazm,
   {{0x44447661,0x656d39a0,0x753c00a5,0x291c019f}},	//   _ry_, _buah, worz, _emva_,
   {{0x44447662,0x753c7663,0x7b0e0139,0x7cfd00ee}},	//   _sy_, torz, _dùud, _fèrt,
   {{0xb97a0327,0x24917664,0x76440027,0x60d57665}},	//   _הנסי, gazm_, _vyiy, _nazm,
   {{0x987a006e,0x7af92b7c,0x6386013f,0x60ca013c}},	//   _פאקט, _kowt, ягва, _ölmə,
   {{0xe3632b49,0x7e697666,0x6b9c02b6,0xfbd20266}},	//   екси, _ngep, _ærge, עתן_,
   {{0x753c7667,0x5bb80775,0x44447668,0x656d7669}},	// [7660] porz, _आह्व, _wy_, _guah,
   {{0x4444766a,0x20564070,0x3ebf02c9,0x7e69766b}},	//   _ty_, птер, _abut_, _agep,
   {{0x4444766c,0x09b70033,0x212600cc,0xb4fb00ca}},	//   _uy_, জিটা, đoh_, _הפיי,
   {{0x6d4100a6,0x48dd0caf,0xb17b0537,0x00000000}},	//   _akla, _कोसो_, _dråb, --,
   {{0x628411ce,0x26c00051,0xae1603b3,0x00000000}},	//   mbio, _mbio_, _देखन_, --,
   {{0x60d5766d,0xe80e00b6,0x29050d62,0x673d0357}},	//   _gazm, ानमा_, jkla_, zosj,
   {{0x69c20305,0x7af93aab,0x64450063,0x68f840d6}},	//   _spoe, _bowt, _xyhi, _rovd,
   {{0x6d41766e,0x79a61c00,0x7cfd0113,0x62840062}},	//   _ekla, прое, _bèrs, nbio,
   {{0x6da30743,0x60d508bb,0xada3766f,0x673d7670}},	//   _пита, _yazm, _патл, vosj,
   {{0x26c00af0,0x29050270,0x290a7671,0x80ca0033}},	//   _abio_, gkla_, óba_, রাক্,
   {{0x673d7672,0x7af90090,0x7cfd7673,0x656501b9}},	//   tosj, _fowt, _vèrt, _rihh,
   {{0xb9037674,0xe7ed00aa,0x6d4102c6,0xb3470131}},	//   _पो_, _छपरा_, _zkla, _maçô,
   {{0xb0ac02e8,0x673d6abe,0xcb130796,0xc54a0174}},	//   _चांग, rosj, _אלף_, _áhị̄,
   {{0x2ec90cf6,0x29050149,0x38c80018,0x291c0193}},	//   _रस्त, ckla_, _ذاتی_, _umva_,
   {{0x58bb00a1,0x88bb00ca,0x38cb0504,0x673d04e9}},	//   _המוצ, _המוז, _دانی_, posj,
   {{0x656d7675,0x00000000,0x00000000,0x00000000}},	//   _tuah, --, --, --,
   {{0xb6060146,0xd234008f,0x26cb7676,0x00000000}},	// [7670] _práš, ентъ, meco_, --,
   {{0x26cb7677,0x26c014f3,0x6445063d,0x00000000}},	//   leco_, _zbio_, _tyhi, --,
   {{0x200731a2,0x62840451,0x7bdc0103,0xd01107e8}},	//   áni_, bbio, _áruh, خلا_,
   {{0x6d416c8d,0x26cb0131,0x21210167,0x200f007f}},	//   _skla, neco_, sihh_, ągi_,
   {{0x2007011d,0x9f5c030b,0x3f987678,0x6d4100e7}},	//   šni_, ává_, _evru_, _pkla,
   {{0xee3802ec,0x26cb0231,0x628f030a,0x00000000}},	//   чні_, heco_, _heco, --,
   {{0x628f1bd6,0x6d410146,0x26cb03a9,0x7af90034}},	//   _keco, _vkla, keco_, _powt,
   {{0x64410067,0x2ef501b6,0xa3c500aa,0x7cfd7679}},	//   żliw, _ўзар, _एहन_, _pèrs,
   {{0x29050094,0xdb1a033c,0x6d410231,0xf1e008c0}},	//   tkla_, _astó, _tkla, नियन,
   {{0x27390068,0x48050a8d,0xdb03767a,0x628f1022}},	//   mény_, дпов, muní, _leco,
   {{0x628f767b,0xa6ca192f,0x26cb034f,0x629d574a}},	//   _oeco, олна_, feco_, _odso,
   {{0x628f767c,0xeab00037,0x29050094,0x7cfd0113}},	//   _neco, _معه_, skla_, _tèrs,
   {{0xe8f50037,0x62840b85,0x00000000,0x00000000}},	//   _يستخ, vbio, --, --,
   {{0xd8251fdb,0x628f00b3,0x629d0133,0x00000000}},	//   _одли, _aeco, _adso, --,
   {{0x04433b2f,0x628f00a1,0x98ac00b6,0x26cb767d}},	//   верн, _beco, hodě_, beco_,
   {{0x26c003ce,0x628f767e,0x26cb01ff,0x63a101f9}},	//   _ubio_, _ceco, ceco_, álna,
   {{0x628f40d3,0x6284767f,0x9c140174,0xa09a0037}},	// [7680] _deco, rbio, _tọgz, قضاء_,
   {{0x8cbf0f78,0x629d7680,0x9c7c022b,0xc0a90037}},	//   ल्मो, _edso, _enčj, كامل_,
   {{0x628f028d,0x6b4543b3,0x2d8000e8,0x00000000}},	//   _feco, lógu, ģiem_, --,
   {{0xe80e0336,0x628f0126,0x00000000,0x00000000}},	//   ानता_, _geco, --, --,
   {{0x27390103,0x00000000,0x00000000,0x00000000}},	//   gény_, --, --, --,
   {{0x7afd1ee2,0x00000000,0x00000000,0x00000000}},	//   östn, --, --, --,
   {{0x69dd01c5,0x00000000,0x00000000,0x00000000}},	//   æsen, --, --, --,
   {{0x26cb00b3,0x00000000,0x00000000,0x00000000}},	//   xeco_, --, --, --,
   {{0x26cb7681,0xbebd0138,0x00000000,0x00000000}},	//   veco_, _smūg, --, --,
   {{0xcce600e3,0x57f402a0,0x2ca7007e,0x00000000}},	//   _تسري, епот, _окуп_, --,
   {{0x7c6500e3,0x26cb0d5a,0xdb0a0212,0x69d300bc}},	//   _كامل, teco_, ttfä, _बैठी,
   {{0x6d4a7682,0xdb1a7683,0x798b03a8,0x00000000}},	//   llfa, _estò, _fwgw, --,
   {{0x628f72a7,0x26cb038f,0x2768015a,0xdb030031}},	//   _reco, reco_, _کشتی_, ntný,
   {{0x628f0e04,0xdb0a11d0,0x00000000,0x00000000}},	//   _seco, stfä, --, --,
   {{0x628f0451,0xd6db249c,0x3eaf0ee1,0x27390146}},	//   _peco, _дтп_, yggt_, zény_,
   {{0x973d0480,0x35b5064c,0xe6670859,0x80c10be4}},	//   kući, _збир, _отпо, र्ने,
   {{0x973d1419,0x443f00a5,0x628f7684,0x00000000}},	// [7690] jući, łu_, _veco, --,
   {{0x973d0335,0x7b1700d3,0x27390103,0xc5f20327}},	//   dući, nţur, vény_, _עדי_,
   {{0x44271424,0xb4cb009d,0x35f80281,0xa29504a1}},	//   _än_, ळजी_, _فرید_, _пані,
   {{0x629d02b6,0xe0cf0033,0x79860174,0x27396db0}},	//   _udso, রাইভ, ̣kwa, tény_,
   {{0x973d02e6,0x427a0341,0x317900c1,0x290e0117}},	//   gući, _מארג, _מאָד, _olfa_,
   {{0x78710018,0xabd51fdb,0x00000000,0x00000000}},	//   _művé, ециј, --, --,
   {{0x8c420609,0xac09423e,0x00000000,0x00000000}},	//   леше, янка_, --, --,
   {{0x0dcb00d3,0x6d4a0365,0x00000000,0x00000000}},	//   _музи_, alfa, --, --,
   {{0x1d35008f,0xc8b5022a,0x00000000,0x00000000}},	//   _зная, нсны, --, --,
   {{0x2d8d0134,0x3f6803e0,0xb4ce00b7,0x6c840076}},	//   _iwee_, _uğur_, _रसे_, _للكم,
   {{0xb8d709d0,0x2d8d01dc,0x80ca0033,0x00000000}},	//   _छा_, _hwee_, রাচ্, --,
   {{0x2d8d0134,0x290e49ac,0x00000000,0x00000000}},	//   _kwee_, _elfa_, --, --,
   {{0x7e7b0051,0x7aeb0113,0xaa0701c3,0x98a500d3}},	//   _mfup, _ingt, _تظاه, _зиле,
   {{0x2574070a,0x80c133dc,0x2d8d0350,0xe81a0ff9}},	//   _väl_, र्मे, _mwee_, _फेका_,
   {{0xa3e744aa,0xdddb0774,0xd37233c6,0x98a500e8}},	//   ндра_, _neuž, اهر_, solē_,
   {{0xdb030094,0x00000000,0x00000000,0x00000000}},	//   ytný, --, --, --,
   {{0xcb1200c1,0x2d8d00ac,0xae1f0285,0x05770076}},	// [76a0] אלן_, _nwee_, _मेलन_, _كمية_,
   {{0x46c1000d,0x4f9600d3,0x973d0218,0x00000000}},	//   ष्ठह, ерду, vući, --,
   {{0x66064012,0x2d8d010a,0x24b7006e,0xa4b700ca}},	//   lykk, _awee_, _אהין_, _אליה_,
   {{0x216a249c,0x3f860031,0xc7b2021e,0x63bb044c}},	//   _ними_, ďou_, רבא_, ăunt,
   {{0x63ae5141,0x00000000,0x00000000,0x00000000}},	//   lubn, --, --, --,
   {{0x62967685,0x61460095,0x7aeb7686,0xb17b0212}},	//   layo, _чега, _angt, _krån,
   {{0x1fb507c8,0xdb0315f2,0x973d00c4,0x00000000}},	//   _истр, stný, sući, --,
   {{0xa0671e54,0x6e930080,0x6296068d,0xdd920d59}},	//   _часа_, _ملفا, nayo, _مور_,
   {{0x88bc00b6,0xb53a0d79,0x95ef278e,0x80d30033}},	//   knět, _atọ́, _चपेट_, সার্,
   {{0x92cc0081,0x62967687,0x7b150143,0x660647b2}},	//   লায়_, hayo, _náuf, dykk,
   {{0xf53f0222,0x62967688,0x60c1026a,0x082a00c2}},	//   från_, kayo, _ölme, яции_,
   {{0x1dd4023a,0x00000000,0x00000000,0x00000000}},	//   _धनात, --, --, --,
   {{0x629611b9,0x8afb00ca,0x9c7c7689,0x00000000}},	//   dayo, _מהאי, _anči, --,
   {{0x63a1768a,0xdb030146,0x290e03a9,0x25a401f9}},	//   álno, muná, _ulfa_, ámla_,
   {{0x63ae1197,0xa29501b3,0xf72b00ae,0x00000000}},	//   gubn, каві, _нций_, --,
   {{0x6296768b,0xdb180220,0xa6db04c8,0x635c01b9}},	//   gayo, ftvé, boða, _sōnr,
   {{0x4ac210e9,0x30a73a69,0xa0a700ae,0xaac21d96}},	// [76b0] व्यव, ерев, ешел, व्यक,
   {{0x629600f9,0xb17b0212,0x6b45768c,0x7bc8000b}},	//   aayo, _från, nógr, _opdu,
   {{0x6296768d,0xa3c5007a,0xe7e300aa,0x2d8d00dc}},	//   bayo, _एहि_, गिया_, _swee_,
   {{0xfe700604,0x316a01ff,0x6296768e,0x63a80e4b}},	//   مده_, _eibz_, cayo, ádne,
   {{0x4ea40836,0x00000000,0x00000000,0x00000000}},	//   урха, --, --, --,
   {{0x3135117c,0xe1ff00fe,0x7b0e009c,0x7f850076}},	//   _регр, _ngói_, _rùua, _للسن,
   {{0xf53f1e8f,0x00000000,0x00000000,0x00000000}},	//   yrån_, --, --, --,
   {{0x2d8d1d19,0x2bc2009d,0x7e7b0239,0x1ae50236}},	//   _twee_, _शहरा, _ufup, тоим,
   {{0x0edd00a5,0x7e64042d,0x2eed5d30,0x80c1231e}},	//   _नोएड, žipr, _inef_, र्थे,
   {{0x6296768f,0x74ad18ff,0x00000000,0x00000000}},	//   zayo, _जागृ, --, --,
   {{0xe73a2440,0x6296554f,0x3cfa006e,0x2eed009c}},	//   ден_, yayo, _קלענ, _knef_,
   {{0xfbd2040a,0x660647b2,0x80c111c7,0x6b6a007f}},	//   _כתב_, tykk, र्ते, _węgr,
   {{0x6726354c,0x62967690,0x4ada00c3,0xaa880076}},	//   rikj, vayo, _मोटव, _أنهم_,
   {{0x290b00d9,0x62967691,0x660608ca,0x93f600a7}},	//   īcas_, wayo, rykk, _çəkə,
   {{0x62967692,0x66060d45,0x67261db6,0xa8480076}},	//   tayo, sykk, pikj, _كلهم_,
   {{0x2d80002d,0x6d437693,0x63ae0094,0x24850555}},	//   ţiei_, hona, rubn, ılma_,
   {{0x6d437694,0x973d08c5,0x62967695,0x491800b6}},	// [76c0] kona, guću, rayo, योको_,
   {{0x6d437696,0x62967697,0x224b01af,0x2eed0167}},	//   jona, sayo, _dyck_, _anef_,
   {{0xf9f90081,0x629602c9,0x3f9c0257,0x224b0072}},	//   েছিল_, payo, évu_, _eyck_,
   {{0x8fa30ad8,0x443a002b,0x799b7698,0x629601ee}},	//   раце, _ixp_, ksuw, qayo,
   {{0x9db7114c,0x6d437699,0x2b4d142e,0x00000000}},	//   ندوز_, fona, dlec_, --,
   {{0x80c1099d,0x6d43769a,0x6b550138,0xdfd20103}},	//   र्दे, gona, _išgy, _پير_,
   {{0x61e600e7,0x60dc152f,0x3cfe00ee,0x00000000}},	//   _hrkl, _iarm, _votv_, --,
   {{0x61e614f3,0x2b4d00c4,0xe6dc06e4,0x00000000}},	//   _krkl, glec_, ययोज, --,
   {{0x6d432e02,0x6f000091,0x6b453916,0x799b12f5}},	//   bona, _iomc, tógr, gsuw,
   {{0x6d43769b,0x61e6015c,0x998d0034,0xdb0300d4}},	//   cona, _mrkl, dzeń_, runá,
   {{0x6f00769c,0x3cdb10e9,0x6b45769d,0x2b4d00c4}},	//   _komc, _गोटे_, rógr, blec_,
   {{0x75270ab2,0x60dc769e,0x7c3a009e,0x6f000063}},	//   wijz, _larm, _ixtr, _jomc,
   {{0x6f0300c9,0x6f000039,0x7527029a,0x6b450143}},	//   ênci, _momc, tijz, pógr,
   {{0x0624036a,0x6f00769f,0x672407f5,0x7bdc01f9}},	//   рфюм, _lomc, _emij, _árus,
   {{0x75270126,0x61e60138,0x00000000,0x00000000}},	//   rijz, _arkl, --, --,
   {{0x6d480113,0x61e60128,0x237e0103,0x60dc71da}},	//   _lkda, _brkl, ítja_, _aarm,
   {{0x998d00a5,0xc0930032,0x2fca010a,0x2fd80027}},	// [76d0] czeń_, _aláṣ, _apbg_, _asrg_,
   {{0x672403ce,0x764d006d,0x6d430062,0x23600188}},	//   _zmij, _iyay, xona, amij_,
   {{0x60dc76a0,0x61e676a1,0x6d430018,0x2eff3b4e}},	//   _darm, _erkl, vona, _pouf_,
   {{0x6d4876a2,0x6d4376a3,0x798276a4,0xe7e315e4}},	//   _akda, wona, _otow, गिता_,
   {{0x6d4376a5,0xddc524d3,0xdca53f1d,0x6d5a009c}},	//   tona, убли, гали, _bhta,
   {{0x3f4700aa,0x621a0327,0x6d5a0503,0x00000000}},	//   tõus_, _טורק, _chta, --,
   {{0x5f9476a6,0x798276a7,0x6f000063,0x764d0361}},	//   _вист, _atow, _fomc, _lyay,
   {{0xe9d95053,0x799b0d2a,0x6d4376a8,0x2ca900a7}},	//   еки_, tsuw, sona, şad_,
   {{0x6d4376a9,0x764d76aa,0x60dc76ab,0x3947061d}},	//   pona, _nyay, _yarm, _pkns_,
   {{0x67240292,0x3209008a,0x6d43008a,0x2911374a}},	//   _smij, iyay_, qona, óza_,
   {{0xd82516bd,0x764d76ac,0x799b03e3,0x95fe007f}},	//   удни, _ayay, ssuw, ॉन्ट_,
   {{0xa3e704a9,0x9c140134,0x290c00f9,0x24983155}},	//   पिन_, _kọnz, akda_, warm_,
   {{0x64400092,0x249802a1,0x764d02a4,0x61e9007e}},	//   əmiy, tarm_, _cyay, _šeln,
   {{0x69d976ad,0x7afb3c8c,0x998d0034,0x588732aa}},	//   _iswe, ljut, rzeń_, _рыда,
   {{0x3209008a,0x39450877,0x24982b13,0x61e602ef}},	//   eyay_, mols_, rarm_, _srkl,
   {{0x7afb042b,0x67240880,0x80c11f88,0x7d010381}},	//   njut, _umij, र्से, _lols,
   {{0x60dc76ae,0x764d0361,0xdb0a00f2,0x00000000}},	// [76e0] _parm, _gyay, rtfø, --,
   {{0x7f49039f,0x3945640b,0x61e600c4,0x69d90154}},	//   _akeq, nols_, _vrkl, _mswe,
   {{0x60dc21a2,0xdee62cb3,0xbeaa00cd,0x94bb00a1}},	//   _varm, ложи, فهان_, _אמית,
   {{0x69cb1d19,0x6d5a01e5,0xee3a08a1,0x7f5b037a}},	//   _opge, _shta, нне_, _chuq,
   {{0x7d010b0b,0x7afb1100,0x69d90169,0x1c1c00aa}},	//   _bols, djut, _nswe, _भेजल_,
   {{0x7d0176af,0x394500ee,0x272b022b,0x7f5b039f}},	//   _cols, jols_, _kònè_, _ehuq,
   {{0x69d976b0,0x61e476b1,0x6e3b039f,0x798276b2}},	//   _aswe, lvil, _exub, _stow,
   {{0x290302c3,0x25a0022b,0x61e409a1,0x7afb4350}},	//   öjan_, _ovil_, ovil, gjut,
   {{0x7d010125,0xee37008f,0x39142dc8,0x80c118ff}},	//   _fols, _бнт_, имир, र्वे,
   {{0x41bb00c1,0x91bb006e,0x7d010090,0xd90e0018}},	//   עציע, עמיי, _gols, ثیت_,
   {{0x47350cf5,0x61e428b4,0x69d90372,0x290c013c}},	//   инос, hvil, _eswe, rkda_,
   {{0x7bda76b3,0xd6db0426,0x61e476b4,0x2d490143}},	//   _istu, хто_, kvil, búes_,
   {{0x776d0933,0x2bd00034,0x160c0179,0xdce805aa}},	//   _viax, थौरा, हनगर_, _lidč,
   {{0x61e476b5,0x69c00138,0xdb1a016d,0x272b022b}},	//   dvil, mtme, _estô, _bònè_,
   {{0x61e476b6,0xa87b00a1,0x69c076b7,0xd4980b91}},	//   evil, _ארוח, ltme, ыря_,
   {{0x2bac11d7,0x2d840580,0x69c076b8,0x764d039f}},	//   _घटना, _otme_, otme, _tyay,
   {{0x69c076b9,0xa5f90012,0xdb03016d,0x765a007f}},	// [76f0] ntme, _репу_, sunç, ętyc,
   {{0x69c076ba,0x7bda007a,0x3209026d,0x92682dc8}},	//   itme, _ostu, ryay_, урса_,
   {{0x7d0104e2,0x69c000aa,0xff074911,0xb17b1f60}},	//   _rols, htme, лядн, _kråk,
   {{0x7d0176bb,0x2d9d023f,0x61e45dab,0x69c00a04}},	//   _sols, tswe_, bvil, ktme,
   {{0x7d01045f,0x6cf00592,0x26c90239,0x51843e7b}},	//   _pols, चांग_, _mbao_, _гуса,
   {{0xfce54fe3,0xdce80154,0xa2bd09c4,0x7b21020d}},	//   роко, _fidč, शभक्, nœuv,
   {{0xaa0d000d,0x7d0176bc,0x39450428,0x2d84026a}},	//   िन्छ_, _vols, vols_, _etme_,
   {{0x7d0176bd,0x3d100139,0x69c03318,0x628d020b}},	//   _wols, _fàwo_, ftme, nbao,
   {{0x7afb0006,0xa2dd0251,0x394576be,0xdb1800b6}},	//   rjut, _पसन्, tols_, ctví,
   {{0x7afb31e8,0x26c9010a,0x7d010063,0x63770129}},	//   sjut, _abao_, _uols, ụnye,
   {{0x6aa70081,0x69c000a1,0x7b15002b,0xb17b05e8}},	//   ক্ষো, atme, _cáuc, _bråk,
   {{0xf7461f02,0x394576bf,0x96661676,0x69d903a9}},	//   ремо, sols_, икне, _tswe,
   {{0xe7374487,0x69d97634,0xda1d00a3,0x394576c0}},	//   рея_, _uswe, _बेचत_, pols_,
   {{0x2bdc17ff,0x2ed200af,0x2bda0442,0x7c380052}},	//   _मनमा, _सस्त, भिचा, _çarç,
   {{0xe29a0c58,0xdb0300bc,0x00000000,0x00000000}},	//   кав_, punä, --, --,
   {{0x25a0004d,0x628d0270,0x27ea0537,0x79890a4b}},	//   _tvil_, gbao, æbne_, opew,
   {{0x64a622d1,0xf8d90096,0x61e4014b,0x2bdc02d5}},	// [7700] _капа, _बघाय, uvil, _मनभा,
   {{0x0ce00081,0xa0a61440,0x9c7c6014,0x10a613c7}},	//   _বক্ত, ражд, _kače, рижн,
   {{0x9c7c0995,0x98be00e8,0x00000000,0x00000000}},	//   _jače, notā_, --, --,
   {{0x539b0054,0x527537f2,0x61e476c1,0x25ad0220}},	//   _ביטו, _гуру, pvil, šele_,
   {{0xd838103b,0x80c10789,0x245c0139,0x9c7c0117}},	//   mače_, _रॉके, _fámí_, _lače,
   {{0xd8380559,0x61eb0537,0x16d300b6,0x5ba60e1d}},	//   lače_, ægle, _तस्ब, ариз,
   {{0xed570291,0x8fa30d57,0x00000000,0x00000000}},	//   јој_, _маре, --, --,
   {{0xa3e704dd,0x2ba7000f,0x7bda0618,0xd838424b}},	//   पित_, _गिरा, _vstu, nače_,
   {{0x3f6803e0,0xb997013f,0x5d862259,0x00000000}},	//   _oğuz_, авых_, _ضلال, --,
   {{0xdde900bf,0x69c000a1,0xc866090f,0x9c7c0335}},	//   _حرفه_, rtme, итни, _bače,
   {{0x7bda2562,0x69c076c2,0x8c461d62,0xeb9a00d3}},	//   _ustu, stme, _теже, _рие_,
   {{0x6b820174,0xf53f2ba4,0xdce900bd,0x61e916ac}},	//   _ọgwa, pråk_, _iweġ, _šelm,
   {{0xd838739c,0x661d00b6,0x55070448,0x9c7c0095}},	//   dače_, uzsk, ачва, _tačd,
   {{0xf806004d,0x7afd02c3,0x00000000,0x00000000}},	//   _вчин, östv, --, --,
   {{0xb17b2708,0x68fc00aa,0x7b070062,0xdce900bd}},	//   _tråk, ördu, _iñur, _jweġ,
   {{0xd83802dd,0x7cfd0154,0x26c90a4b,0x427501b6}},	//   gače_, _dèry, _ubao_, сгас,
   {{0x9c7c0b27,0xcad700ca,0xe80e00b6,0x00000000}},	// [7710] _zače, סומת_, ानका_, --,
   {{0x7778023e,0x2ba7206b,0xe4a776c3,0x00000000}},	//   _kuvx, _गिला, _трио, --,
   {{0x200700d3,0xd838077e,0x39490072,0x7cfd05aa}},	//   âni_, bače_, _íase_, _gèry,
   {{0x623500ae,0x00000000,0x00000000,0x00000000}},	//   _гему, --, --, --,
   {{0xe4ec2337,0x3d190032,0x63b505d6,0x00000000}},	//   _छोडि_, _lèwe_, luzn, --,
   {{0x973d00e7,0xeb99007e,0xb0c6023a,0x8b9505cb}},	//   mrću, гик_, र्दग, брич,
   {{0xab293e86,0x6ee10134,0xdfd800e5,0x00000000}},	//   лока_, _ịbuw, _кът_, --,
   {{0x2bb80034,0xd43800ca,0x00000000,0x00000000}},	//   _इमरा, יטוי_, --, --,
   {{0x3ce2007d,0x9c7c1100,0xd5ed00de,0xdd913a89}},	//   _टोके_, _sače, _ngà, _روا_,
   {{0x29030088,0xa3c9086d,0xa2c90f42,0xe8f90e20}},	//   ðja_, ोबा_, _हॉस्, уло_,
   {{0x66e6037e,0xb8cf0285,0x00000000,0x00000000}},	//   бона, _ओय_, --, --,
   {{0x273202dd,0x3d190139,0xfb84001c,0x63b50b18}},	//   kšne_, _dèwe_, _بگوی, duzn,
   {{0x99850080,0xd838068e,0xda780465,0x7afd0d2f}},	//   _التو, vače_, _тях_, östu,
   {{0x9c7c007e,0x63a81405,0x00000000,0x00000000}},	//   _tače, ádno, --, --,
   {{0xd838025b,0x7bc301cb,0x80ca02d5,0xa5071bc1}},	//   tače_, ntnu, स्फे, щера_,
   {{0xf74376c4,0x317901f9,0x00000000,0x00000000}},	//   _нещо, _busz_, --, --,
   {{0xd83803f1,0x7bc300bc,0x171b00ca,0x317100fc}},	// [7720] rače_, htnu, _תופע, _bizz_,
   {{0x644800aa,0xd8380128,0x7bc345d9,0x7cfd0154}},	//   üdis, sače_, ktnu, _tèry,
   {{0xd83802f7,0x447700ca,0xe7ea14e5,0xee86013f}},	//   pače_, _לעיל_, टिया_, было,
   {{0xdfcf1823,0xf48700cd,0xbda60037,0x00000000}},	//   عين_, _پایی, محتو, --,
   {{0x1d0a1a6d,0xdb0a76c5,0x00000000,0x00000000}},	//   леди_, rtfü, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdee60a8e,0x28bd19af,0x00000000,0x00000000}},	//   _лови, ्भनि, --, --,
   {{0xef9100cd,0xa03700ca,0x2b40033b,0x00000000}},	//   _آیند, _האלה_, čico_, --,
   {{0xdca60d86,0x249a0314,0xee3a2914,0x00000000}},	//   _гази, _oepm_, _сна_, --,
   {{0xdce9003d,0x00000000,0x00000000,0x00000000}},	//   _tweġ, --, --, --,
   {{0x6d4a76c6,0xd6d50ae3,0x7bc301cb,0x80ca00a4}},	//   mofa, ожны, ctnu, स्ये,
   {{0xab662195,0x6d4a76c7,0xa3e700c3,0x205700a1}},	//   _увел, lofa, पिस_, מייל_,
   {{0xceb300ca,0xa3de0179,0x636f0139,0x00000000}},	//   היר_, _दैब_, _lònì, --,
   {{0x7ae276c8,0x63b5015c,0x973d015c,0x00000000}},	//   _haot, tuzn, vrću, --,
   {{0x7ae2007a,0x93880084,0x2418163d,0x02a75e6e}},	//   _kaot, йста_, боры_, йрам,
   {{0x7ae200aa,0xe29f01cd,0xddc9007f,0xadfa2b6e}},	//   _jaot, _boða_, _cześ, ्हान_,
   {{0x7ae21d6a,0x9099672f,0x317105db,0x00000000}},	// [7730] _maot, иват_, _pizz_, --,
   {{0x672f00a5,0x29c20088,0x7bc3025b,0x7ae200bc}},	//   licj, iða_, ytnu, _laot,
   {{0x660f0222,0x680a00a7,0x06dc0033,0x00000000}},	//   lyck, qədd, ধারি, --,
   {{0xb65a0af0,0x636f0139,0x3f8701d3,0x672f007f}},	//   _abẹ́, _dònì, īnu_, nicj,
   {{0xa6e30033,0x660f02c3,0x00000000,0x00000000}},	//   যাপট, nyck, --, --,
   {{0x212a02e2,0x6d4a76c9,0x629f0167,0x9ce70103}},	//   _gmbh_, gofa, laqo, صوبے_,
   {{0x7ae276ca,0xff530e25,0xfd590139,0x00000000}},	//   _baot, _فخر_, _kubẹ, --,
   {{0x3eb90856,0xc9a9008f,0x7ae276cb,0x2f185be9}},	//   _øst_, авие_, _caot, _лось_,
   {{0x7ae202c9,0x29c201cd,0x3d940974,0x88d501b3}},	//   _daot, gða_, _нитр, оўні,
   {{0x660f00b6,0x77c902f3,0x6d4a76cc,0x00000000}},	//   dyck, алог_, cofa, --,
   {{0x672f043f,0x7ae20441,0xdb180437,0x06e30033}},	//   ficj, _faot, stvá, যানি,
   {{0x7ae20527,0xfbd00281,0x00000000,0x00000000}},	//   _gaot, _ستم_, --, --,
   {{0x98a532d3,0xd54a0037,0x629f76cd,0xdb180537}},	//   _диле, لجسم_, daqo, ftvæ,
   {{0x9c7c4390,0xdd7a00c1,0x98a501d3,0xddc90034}},	//   _kača, יטשל, bilā_, _sześ,
   {{0x9c7c04a3,0x68e376ce,0x52870294,0x629f0216}},	//   _jača, _iand, _ụlọi, faqo,
   {{0x29070a00,0x6abb76cf,0x6d4a76d0,0x4ad9009f}},	//   _hona_, nguf, zofa, ढ़िव,
   {{0x68e376d1,0x290776d2,0x6d4a76d3,0xd8380087}},	// [7740] _kand, _kona_, yofa, mača_,
   {{0x68e376d4,0x290776d5,0xd83830a0,0x3ebf3511}},	//   _jand, _jona_, lača_, _acut_,
   {{0x68e376d6,0x2907486e,0x60c306a3,0x9c7c0094}},	//   _mand, _mona_, ònma, _nača,
   {{0xa3c9578d,0x29074296,0x645e76d7,0x69db01c2}},	//   ोबर_, _lona_, _izpi, kwue,
   {{0x6d4a76d8,0x212a005c,0x290776d9,0x00000000}},	//   tofa, _tmbh_, _oona_, --,
   {{0x68e376da,0x628476db,0x7ae20a1b,0xd7a90096}},	//   _nand, lcio, _saot, _किंच,
   {{0x26c00fb6,0x7ae2078e,0xa4fb0142,0x00000000}},	//   _ocio_, _paot, ילסט, --,
   {{0x68e30db8,0x9c7c6ed0,0x290701f7,0x39a6004d}},	//   _aand, _dača, _aona_, ошов,
   {{0x290776dc,0xd838042d,0x80ca009d,0x628476dd}},	//   _bona_, dača_, स्थे, icio,
   {{0x68e376de,0x29c20102,0x291876df,0x26c00072}},	//   _cand, rða_, óra_, _acio_,
   {{0x68e376e0,0x290776e1,0x7ae2007a,0xc07b00c1}},	//   _dand, _dona_, _taot, יטיש,
   {{0x660f76e2,0xd8380559,0x80ca1e05,0x68e30381}},	//   tyck, gača_, स्ते, _eand,
   {{0x9c7c134c,0x68e376e3,0xfa3600d0,0x645e0a00}},	//   _zača, _fand, _براد, _azpi,
   {{0x32d50028,0x628676e4,0x29070044,0x25fc009f}},	//   _ấy_, _afko, _gona_, _ऊपरी_,
   {{0x7d0801c5,0x9c830146,0xd838037d,0x6474402c}},	//   _mods, _účes, bača_, дгру,
   {{0x68e376e5,0x6aa00a3d,0x3980022b,0xd83814f3}},	//   _zand, namf, _kòs_, cača_,
   {{0x68e376e6,0x29076eb6,0x00000000,0x00000000}},	// [7750] _yand, _yona_, --, --,
   {{0x68e376e7,0x628476e8,0x26d976e9,0x98ac013f}},	//   _xand, acio, leso_, rodė_,
   {{0x3cfe2235,0x974300cb,0x6aa016ed,0x00000000}},	//   लाने_, šćuj, kamf, --,
   {{0x628476ea,0x7d1a1484,0x9c7c76eb,0xb17b1f60}},	//   ccio, _alts, _rača, _bråt,
   {{0xfe700979,0x672d76ec,0x291e03ec,0x23690167}},	//   نده_, _mmaj, khta_, mmaj_,
   {{0xd8380039,0x7d08008a,0x9ccb0077,0x80c1030b}},	//   zača_, _cods, рыда_, र्खे,
   {{0xeb9962f9,0x7ed70f43,0x629d76ed,0xce95008f}},	//   щий_, _وزرا, _keso, _навъ,
   {{0x273202dd,0x629d028d,0x39800383,0xdb1802c3}},	//   kšna_, _jeso, _bòs_, jtvä,
   {{0x629d76ee,0xd83808a9,0x29070f20,0xb17b0e3e}},	//   _meso, vača_, _pona_, _gråt,
   {{0x2ba50029,0x68e376ef,0x7d081b06,0x672d4dce}},	//   pēc_, _qand, _gods, _amaj,
   {{0x6f1b10cf,0xd83876f0,0x290776f1,0x26d976f2}},	//   _kluc, tača_, _vona_, feso_,
   {{0x68e30a75,0x3ce50501,0xe64612e7,0xe73a3f1a}},	//   _wand, _halv_, земп, сем_,
   {{0xe9ce76f3,0xd83802e6,0x290776f4,0x645e00a5}},	//   _як_, rača_, _tona_, _szpi,
   {{0x291e4205,0x81c10081,0x6f1b76f5,0x68e30051}},	//   chta_, ংবা_, _lluc, _uand,
   {{0x629d76f6,0xd83808a9,0x26d900f9,0x61200103}},	//   _beso, pača_, beso_, _hölg,
   {{0x26d911c4,0x98a5002d,0x629d6496,0x26c000cc}},	//   ceso_, bilă_, _ceso, _ucio_,
   {{0x28c20d0b,0x98a5020a,0x629d76f7,0x00000000}},	// [7760] _शामि, cilă_, _deso, --,
   {{0x672d2e48,0x628476f8,0x78a176f9,0x987800c4}},	//   _zmaj, scio, nalv, ršći_,
   {{0x629d015e,0x6f1b0036,0x6f0945cd,0xa5bb0669}},	//   _feso, _bluc, _boec, nzón,
   {{0x444403e5,0x629d0665,0x78a176fa,0x3f871f32}},	//   _ix_, _geso, halv, ínua_,
   {{0x6f020365,0x7d0876fb,0x5ea30781,0x78a1098a}},	//   rjoc, _pods, رمول, kalv,
   {{0xa06a0a7c,0x60220103,0x78a1037a,0x3dc676fc}},	//   _гага_, _címé, jalv, rtow_,
   {{0xe7b60081,0x7d082388,0x3dc676fd,0x6e220103}},	//   _জন্য, _vods, stow_, szob,
   {{0xdee376fe,0x612008bb,0xa03b00c1,0xeb970291}},	//   _поси, _bölg, _העלפ, чић_,
   {{0x291e0052,0xdb0a02c3,0x444476ff,0x6aa07700}},	//   thta_, ktfö, _lx_, ramf,
   {{0x9c7c41f9,0x672d7701,0x78a122bb,0x6aa0254e}},	//   _začn, _smaj, galv, samf,
   {{0x26d97702,0xf8b800fe,0x394c3e30,0xab2a0360}},	//   teso_, ghĩa_, rods_, _ложа_,
   {{0x291e7703,0x6d587704,0x56941aad,0x103700ca}},	//   shta_, llva, нают, לטים_,
   {{0x629d7705,0x6d587706,0x61207707,0x78a17708}},	//   _reso, olva, _köld, balv,
   {{0x26d91a45,0x629d7709,0x78a1039f,0xdb180212}},	//   seso_, _seso, calv, stvä,
   {{0x629d770a,0x26d96636,0x291c770b,0xccf800b6}},	//   _peso, peso_, _ilva_, _mně_,
   {{0x083b03c2,0xd7bb00ca,0x77640090,0x4444770c}},	//   _לעול, _הצהר, _ghix, _dx_,
   {{0x9f47770d,0x629d033b,0xf1dd007f,0x25ab770e}},	// [7770] íní_, _veso, _नैशन, _ادبي_,
   {{0x629d770f,0x2369007e,0xe3b00018,0x44443ff0}},	//   _weso, smaj_, ضرہ_, _fx_,
   {{0xa3e12337,0x6f097710,0x25a94a75,0x09d900b6}},	//   _धनि_, _poec, _hval_, _भन्य,
   {{0xde190037,0x25a90973,0x657f019f,0x65777711}},	//   يقات_, _kval_, _kuqh, _hixh,
   {{0x6f1b0126,0xfce57712,0xd24400d3,0xb27411ba}},	//   _vluc, доло, _зэри, _плюш,
   {{0xd838033b,0x657700bd,0x00000000,0x00000000}},	//   jačo_, _jixh, --, --,
   {{0x44447713,0x9c7c175b,0x78a17714,0x657f0372}},	//   _xx_, _tačn, valv, _luqh,
   {{0x7b150181,0x6d58002b,0x68f801ff,0xbdd5007b}},	//   _záuj, alva, _anvd, _ообщ,
   {{0xe29f38d5,0x78a17269,0x61200018,0x61ed1f5b}},	//   _með_, talv, _föld, nval,
   {{0xdb0300e3,0x36e6009f,0xaca30134,0x9c130134}},	//   isné, _जोड़ी_, _maịl, _pọdk,
   {{0xf7462825,0x2ba70789,0xa9c400cd,0x78a14192}},	//   дено, _गिटा, وزیو, ralv,
   {{0x61200018,0x272200de,0x291c5ccb,0x09f90037}},	//   _zöld, _móng_, _elva_, _وفاة_,
   {{0x44447715,0x78a132e3,0x7ae905aa,0xdb0a5748}},	//   _sx_, palv, mdet, ttfö,
   {{0x7ae97716,0x61ed6a2b,0xf8ce00de,0x69c97717}},	//   ldet, dval, _hứng_, mtee,
   {{0x27220028,0x589400e3,0x69c92921,0xdb0a3125}},	//   _nóng_, _أجهز, ltee, rtfö,
   {{0x7ae97718,0x7e7b7719,0x680a0092,0x69c92568}},	//   ndet, _ngup, qəda, otee,
   {{0x69c92a92,0x26d2092f,0x7ae9771a,0x61ed771b}},	// [7780] ntee, _ibyo_, idet, gval,
   {{0x27220028,0x3ead01e8,0x7ae90084,0xc05a3407}},	//   _bóng_, _adet_, hdet, орец_,
   {{0x28cf37b3,0x69c902fd,0x04461612,0x33660e2c}},	//   त्यि, htee, _ценн, _овог,
   {{0x7ae94fd4,0x69c9771c,0xa25b0257,0xaca300ac}},	//   jdet, ktee, _icôn, _faịl,
   {{0x7ae9771d,0x63bc771e,0xbea31469,0x8d6a125f}},	//   ddet, lurn, тачк, ојка_,
   {{0x09bc00c7,0x273202dd,0x7ae9771f,0x28cf0285}},	//   _অনলা, kšno_, edet, त्मि,
   {{0x63bc01cd,0x6120003e,0x26d2010a,0x69c97720}},	//   nurn, _völd, _obyo_, etee,
   {{0xf8ce0019,0x69c97721,0x7ae97722,0x9c7c0094}},	//   _cứng_, ftee, gdet, _začl,
   {{0x63bc7723,0x69c90188,0x00000000,0x00000000}},	//   hurn, gtee, --, --,
   {{0x63bc7724,0x26d2294f,0x2bb0009f,0x7ae97725}},	//   kurn, _abyo_, ींदा, adet,
   {{0x8c3c0b88,0x9c830363,0x69c91e0b,0x7ae903a9}},	//   _beğe, _účas, atee, bdet,
   {{0x63bc7726,0x69c9008a,0x7ae900ee,0x65777727}},	//   durn, btee, cdet, _sixh,
   {{0x8c3c0b88,0x69c90ab2,0x673d169c,0x6a160c5e}},	//   _değe, ctee, rnsj, _تبار,
   {{0x61ed7728,0x26d20283,0x63bc7729,0x63b5007f}},	//   vval, _ebyo_, furn, trzn,
   {{0x63bc02e6,0xc60700c7,0x5bdc04f8,0xd82f00d3}},	//   gurn, _লেখা_, _मनोव, _рэ_,
   {{0x61ed533f,0xe2f801b6,0xf8ce00de,0xaca30174}},	//   tval, месі_, _xứng_, _paịl,
   {{0x6234772a,0x80c800c7,0x27220019,0xd56708d8}},	// [7790] вету, রজন্, _sóng_, _отоп,
   {{0x7ae90018,0x644501bb,0x3f873906,0x7bca40d6}},	//   zdet, _txhi, ínuo_, ktfu,
   {{0x61ed772b,0x7535772c,0x69c90a00,0xf6500018}},	//   sval, mizz, ztee, _مئی_,
   {{0x75356755,0xd25000fb,0x26dc00c1,0x69c900c2}},	//   lizz, انے_, ַקומ, ytee,
   {{0xa3e73ec9,0x1db10b2b,0x00000000,0x00000000}},	//   पिक_, ुंधत, --, --,
   {{0x75353e51,0x7bca040f,0x00000000,0x00000000}},	//   nizz, ftfu, --, --,
   {{0x4fc4772d,0x7bca0537,0x9c7c0141,0x00000000}},	//   _иста, gtfu, _kačj, --,
   {{0x69c902fd,0x75350451,0x7e7b0079,0x4aa91c16}},	//   ttee, hizz, _ugup, чкин_,
   {{0x7ae917c7,0x75355140,0x22590c89,0x9c7c228d}},	//   rdet, kizz, _jysk_, _mačj,
   {{0x7ae9772e,0x69c9772f,0xf8b10504,0x7535010a}},	//   sdet, rtee, اکش_, jizz,
   {{0x753503e5,0x69c97730,0xa5bb01f9,0x00000000}},	//   dizz, stee, szól, --,
   {{0x69c96cfd,0x61200103,0x501a00ca,0x00000000}},	//   ptee, _kölc, פורו, --,
   {{0x4a9a00c1,0x6b817731,0x75350036,0xe6171cf2}},	//   _זינג, _hulg, fizz, едя_,
   {{0x6b8100bc,0x80cf0033,0x59d8007f,0x75350816}},	//   _kulg, _হোস্, _बैटर, gizz,
   {{0x6b816fb1,0x680a0092,0xf8b20327,0x588410e0}},	//   _julg, nədl, _עשה_, _рыча,
   {{0xf7d600a1,0x0cdc0213,0x6b8127e0,0x26d20027}},	//   _נופש_, _यस्म, _mulg, _ubyo_,
   {{0x75357732,0x62967733,0x2aba026a,0x9c7c037d}},	// [77a0] bizz, rbyo, lübü_, _sačm,
   {{0x753500e5,0x63bc7734,0x2259007f,0x00000000}},	//   cizz, purn, _dysk_, --,
   {{0xf1ac0455,0x28c20557,0x749b00ca,0x06e30081}},	//   _चिकन, _शासि, _מייפ, যারি,
   {{0x28cf5516,0x26c270df,0x73e300a9,0x06b20081}},	//   त्ति, ngko_, _союз, ট্রি,
   {{0xed5a0291,0x127b006e,0xf2d30142,0x00000000}},	//   под_, _מאכע, _גער_, --,
   {{0x61e602e6,0x09d80081,0x6b817735,0x7bca07ee}},	//   _iskl, তিমা, _bulg, ttfu,
   {{0x99bc00c7,0x6143013f,0xdce1009c,0x27220206}},	//   _অনেক, _сера, _ghlč, _zóne_,
   {{0x200d008e,0x9c7c1c5f,0x28c22235,0x8c350139}},	//   çmiş_, _kačk, _शाहि, _ke̟j,
   {{0xf98f1ac9,0x2bac0096,0xa3e7110d,0x00000000}},	//   یبی_, _घटका, _मैन_, --,
   {{0x9c7c0f72,0x6fc4009d,0x6b817736,0xf1b3028c}},	//   _mačk, ांपू, _fulg, נסת_,
   {{0x75350078,0x313700ca,0x7b6400ae,0x645a09a1}},	//   vizz, תנים_, _иӂие, ütil,
   {{0x3cfe1e5e,0x09d80081,0x8c1b00a1,0x29030212}},	//   लावे_, তিবা, _מובי, öjar_,
   {{0x753554ae,0xd6e30081,0xfba400a8,0x9c7c05db}},	//   tizz, যালয, _गौतम, _račj,
   {{0x2b40005f,0x225902c3,0xd90e0103,0xe4e40120}},	//   čicu_, _rysk_, _چیک_, лісн,
   {{0x7535772c,0x6b8108a8,0xd90e09b4,0xf36705e1}},	//   rizz, _xulg, _نیک_, етан,
   {{0x9c7c71f1,0x75357737,0x7982024a,0x60c802c3}},	//   _bačk, sizz, _kuow, _ödmj,
   {{0x290e0044,0x680a0092,0x3ea602c9,0x80c2007f}},	// [77b0] _kofa_, zədl, daot_, _लाशे,
   {{0x98be00b6,0x68ea00bd,0x6aa20503,0x00000000}},	//   votě_, _jafd, _leof, --,
   {{0x7b1c025a,0x61e67738,0x43951107,0xc4350421}},	//   _réun, _eskl, _шанс, _شکست,
   {{0xdb010074,0x22592ca7,0x990c00b6,0x290e7739}},	//   _ovlá, _tysk_, ाउँछ_, _lofa_,
   {{0x646300e9,0x6b8100aa,0xa2f4065c,0x00000000}},	//   štić, _sulg, _спяч, --,
   {{0x271e046e,0x6b81773a,0x7c870084,0x290e010a}},	//   _पत्र_, _pulg, худе, _nofa_,
   {{0xfaf10037,0xbebd17b1,0x5e950037,0xa3e700a3}},	//   لثة_, _plūd, _للأط, _मैम_,
   {{0x6b816ab9,0xb4cd099d,0xe29f003e,0x00000000}},	//   _vulg, रभु_, _boði_, --,
   {{0xe969036f,0x6b81007f,0x28b900d3,0x00000000}},	//   маил_, _wulg, мунэ_, --,
   {{0x79824341,0x3f83773b,0x6b8109a1,0x00000000}},	//   _duow, _kuju_, _tulg, --,
   {{0x3f8365d0,0x978300cd,0x2ca7019e,0x28c21117}},	//   _juju_, دیبه, mand_, _शारि,
   {{0x2d9f0294,0x3f8314f3,0x25de50da,0x00000000}},	//   _kwue_, _muju_, गबली_, --,
   {{0x290e773c,0x7aeb0537,0xb4cd0296,0x00000000}},	//   _fofa_, _iagt, रभू_, --,
   {{0x2ca7773d,0x7aeb773e,0x9c7c773f,0x00000000}},	//   nand_, _hagt, _račk, --,
   {{0xdb010363,0x64a30ff5,0x3f83001c,0x6ed204f8}},	//   _zvlá, раса, _nuju_, ण्डु,
   {{0x78a31484,0x2b0406ed,0x2ca77740,0x7aeb7741}},	//   _henv, वायु_, hand_, _jagt,
   {{0x7aeb7742,0x21a60c33,0x02e20251,0x5bae0557}},	// [77c0] _magt, тизм, _पसीन, _टि्व,
   {{0x2ca77743,0x312300c6,0x7aeb7744,0x3f8300c4}},	//   jand_, адуг, _lagt, _buju_,
   {{0xb466131b,0x3f8300cc,0x2ca77745,0x98ac044c}},	//   _школ, _cuju_, dand_, lidă_,
   {{0x7aeb4e06,0x9c7c1027,0xee3a33a2,0x69d91044}},	//   _nagt, _tačk, мне_, _opwe,
   {{0x5436037f,0x3ea600f9,0x201c02ef,0x2ca77746}},	//   _سرگر, raot_, švi_, fand_,
   {{0x2ca77747,0x61467748,0x61e40239,0x9c7c7749}},	//   gand_, _рега, mwil, _kači,
   {{0x9c7c08c5,0x8fa636bf,0x8fa36a72,0x69d9022b}},	//   _jači, _шаве, _васе, _apwe,
   {{0xdd92006f,0x9f4a05fe,0x9c7c774a,0x7aeb0188}},	//   _نور_, _urbà_, _mači, _cagt,
   {{0x78a3774b,0xd8381271,0x996652c3,0x61e441e9}},	//   _benv, mači_, ктол, nwil,
   {{0xd1050bd9,0xd8380995,0x2ca700d3,0xd83a01b6}},	//   रायण_, lači_, cand_, дэм_,
   {{0x61e4774c,0xdd3100a7,0x78a364fc,0x25a001ee}},	//   hwil, ləşm, _denv, _awil_,
   {{0xb8f90e72,0x78a304ee,0xd83821b8,0x659500d3}},	//   _डॉ_, _eenv, nači_, ламу,
   {{0x61e40126,0x290e774d,0xfb1b00ca,0x7ae0774e}},	//   jwil, _tofa_, _קודמ, memt,
   {{0x78a302b9,0x2d840051,0x69c002a4,0x7ae0774f}},	//   _genv, _mume_, mume, lemt,
   {{0x69c07750,0x2d847751,0xd8380141,0xf2c7031e}},	//   lume, _lume_, kači_, ксан,
   {{0x3ea401c5,0x2ca77752,0xae020179,0x78a303a9}},	//   _nemt_, zand_, लमान_, _zenv,
   {{0x9c7c0291,0x2d84002d,0x60f93dbc,0x26c97753}},	// [77d0] _dači, _nume_, нная_, _icao_,
   {{0x7bda00e9,0xdce8030b,0x31c407ed,0xd49900d6}},	//   _optu, _vidě, јств, _якої_,
   {{0x69c07754,0x2ca77755,0x2d8401ff,0x00000000}},	//   hume, vand_, _aume_, --,
   {{0x9c130174,0x63ba0220,0x3cfe36c7,0x2ca731ae}},	//   _bọnk, átne, _antv_, wand_,
   {{0x2d842435,0x7bda00d9,0x3cfe00e7,0x3d1903a9}},	//   _cume_, _aptu, _bntv_, _hèwi_,
   {{0x9c7c7756,0x8c4537f2,0x7aeb7757,0x69c07758}},	//   _zači, леле, _sagt, dume,
   {{0x7aeb7759,0x31340084,0x2d8403be,0x78a30257}},	//   _pagt, _терр, _eume_, _renv,
   {{0x7b1508ec,0x2d840921,0x2ca7775a,0x69c06b34}},	//   _náut, _fume_, sand_, fume,
   {{0x2ca7775b,0x7aeb02b6,0x80ca0569,0x960200c3}},	//   pand_, _vagt, स्के, _लपेट_,
   {{0x7aeb775c,0x80e10081,0x26c90131,0xddc902a1}},	//   _wagt, নাক্, _acao_, _mgeż,
   {{0xd05c01d4,0xec15012b,0x7aeb775d,0xc1d0030b}},	//   _barə, _حواد, _tagt, _सङ्ग,
   {{0xc9f51e53,0x69c0692e,0x61e4775e,0x2ca500ca}},	//   _مستع, bume, ywil, _held_,
   {{0x6d43775f,0x69c00788,0x69d90a4b,0x2d847760}},	//   onna, cume, _upwe, _xume_,
   {{0x27220472,0x9c7c0ca7,0xd83801ac,0x26cf0149}},	//   _dóna_, _sači, zači_, _ögon_,
   {{0x2ca510c5,0x68e17761,0x39893e07,0x9c7c013f}},	//   _meld_, meld, _hús_, _pači,
   {{0x28cf0f82,0x61e40d21,0x27320087,0x491b030b}},	//   त्रि, twil, kšni_, यसको_,
   {{0xd83800e9,0x67247762,0xb1460752,0x626600c9}},	// [77e0] vači_, _ilij, гнал, уваа,
   {{0x68e17763,0x61e45537,0xdcfb0106,0xf8b5009f}},	//   neld, rwil, _otuđ, ूलिय,
   {{0x9c7c01b3,0x67247764,0x69c07765,0x2722045e}},	//   _tači, _klij, zume, _zóna_,
   {{0x68e17766,0x6d437767,0x69c04208,0x91862519}},	//   held, enna, yume, _مجسم,
   {{0x67240ea3,0xd83800e9,0xdd8f00e3,0x68e17768}},	//   _mlij, rači_, كون_, keld,
   {{0x69c07769,0xd8380995,0x9c7c0d62,0x68e14fc7}},	//   vume, sači_, _mačv, jeld,
   {{0xa067776a,0xd838015c,0x7ae0776b,0x6724776c}},	//   _бара_, pači_, temt, _olij,
   {{0x6d430e5c,0x5b140c28,0x2d84776d,0x657e019f}},	//   anna, рмит, _tume_, _liph,
   {{0x2ca50364,0x7ae0776e,0xdb0a776f,0xdbde0072}},	//   _feld_, remt, nsfé, _víña,
   {{0x2ca50d50,0x69c07770,0x67247771,0x68e17766}},	//   _geld_, rume, _alij, geld,
   {{0x67240505,0x6d5a03e5,0x6ac609e5,0x31570089}},	//   _blij, _ikta, _مقام, ריין_,
   {{0x78a87772,0x2360023e,0x9c7c1912,0x69c07773}},	//   sadv, jlij_, _bačv, pume,
   {{0x672400c4,0x395e029a,0x39890139,0x00000000}},	//   _dlij, plts_, _gús_, --,
   {{0x7e7d0181,0x67247774,0xd9434aa9,0x00000000}},	//   _úspe, _elij, _лечи, --,
   {{0x56950fbe,0x67240052,0xf77000d1,0x693300ae}},	//   _кайт, _flij, تای_, _ыншу,
   {{0x57fb0054,0x290c02e6,0xf2077775,0x672401c0}},	//   _טלוו, ljda_, лязо, _glij,
   {{0x6d5a7776,0x6d4300f0,0x6d48031a,0x680a00a7}},	// [77f0] _okta, ynna, _ojda, dədi,
   {{0x291e7777,0xb2741b77,0x657e0124,0x60c5023e}},	//   nkta_, слуш, _giph, ughm,
   {{0x72d5222a,0xa2d0084a,0x60c50063,0x2ca5084e}},	//   _конф, _डॉक्, rghm, _reld_,
   {{0x539a0054,0x6d5a04f9,0x61207778,0x06e30081}},	//   _שירו, _akta, _höll, যাকি,
   {{0xdbde0682,0xd8381912,0x61207779,0x776d009c}},	//   _síða, maču_, _köll, _mhax,
   {{0x5bb57095,0x2732080e,0x8b050034,0xd8380234}},	//   асиф, ršni_, _mięś, laču_,
   {{0x2ca50305,0x68e1777a,0x6120502f,0x39890072}},	//   _veld_, veld, _möll, _sús_,
   {{0xe9d93d7c,0x2ca502ad,0x68e1777b,0x7c2b1386}},	//   вки_, _weld_, weld, _đorđ,
   {{0x13de00c7,0xaa455544,0x68e12481,0x7f5b063d}},	//   ডিয়, репл, teld, _ikuq,
   {{0xe8f62e9e,0x9c7c14f3,0x6724777c,0x7d7900d0}},	//   аль_, _račv, _slij, _شمار_,
   {{0x6c840080,0x68e132a7,0xd706321c,0x67240268}},	//   _المم, reld, азни, _plij,
   {{0x7bc3777d,0x398900e3,0x657e0201,0xe73a039b}},	//   munu, _tús_, _siph, тем_,
   {{0x7b740e8c,0x7bc370f3,0x776d008a,0xa9a546ff}},	//   _اطلا, lunu, _dhax, _тилд,
   {{0x4a443006,0xdb0a0364,0x291e0212,0x64a3147c}},	//   _унів, zufü, ckta_, жара,
   {{0x7f5b0201,0x23364214,0xa9560327,0x00000000}},	//   _okuq, ахар, _דיסק_, --,
   {{0x95860e58,0xf77200fb,0x96ba021c,0x6724777e}},	//   _клие, _بات_, _руку_, _ulij,

   {{0x7bc3777f,0x09b500c1,0x645e0034,0x657e00fc}},	// [7800] hunu, יפּט_, _wypi, _tiph,
   {{0x9c7c191d,0x201a023b,0x645e4bf9,0x61207780}},	//   _začu, typi_, _typi, _göll,
   {{0x4ea64d95,0x7bc3601a,0x680a0092,0x98bd0179}},	//   арла, junu, tədi, _एएनए,
   {{0x7bc37781,0xe8060386,0xa6e20088,0x14d20096}},	//   dunu, षमता_, áðhe, द्रण,
   {{0xcd06282a,0x680a00a7,0x4c942321,0x6120007b}},	//   ички, rədi, билс, _yöll,
   {{0x21a30f32,0x7e6903d6,0x7bc30da8,0x7f5b0201}},	//   _фирм, _dzep, funu, _ekuq,
   {{0x7bc37782,0x237f025b,0x50432549,0x7e690372}},	//   gunu, ňuje_, _дерб, _ezep,
   {{0x3f9a00c2,0x00000000,0x00000000,0x00000000}},	//   mppu_, --, --, --,
   {{0x9c7c02fb,0x7bc30172,0xacea0161,0x00000000}},	//   _raču, aunu, _имаа_, --,
   {{0x9c7c00e9,0x776d008c,0xd8380995,0xb4e500a4}},	//   _saču, _shax, začu_, _नसे_,
   {{0x291e7783,0x6d584433,0xb8ce03b3,0xe838004d}},	//   rkta_, mova, _ओज_, упні_,
   {{0xdc3b00ca,0x7e60007b,0x3cfe074c,0x00000000}},	//   _בעבר, _kymp, लाके_, --,
   {{0xd8380039,0x6b885202,0x9f650018,0xfd570139}},	//   vaču_, _hudg, ítés_, _abaṣ,
   {{0x80c27674,0x612001d4,0x7c2b0491,0x80aa02d5}},	//   _लागे, _bölm, _ömrü, टरफे,
   {{0x80aa53b8,0x93884f07,0x92a71d2e,0x61202305}},	//   टरने, иста_, ијал, _völl,
   {{0x6d587784,0x6b88646b,0xa87b1777,0x00000000}},	//   hova, _mudg, _באור, --,
   {{0x6d5828f9,0xd8380106,0x673d7785,0x26db023e}},	// [7810] kova, raču_, misj, _ibqo_,
   {{0x6d580579,0x2b490335,0x7bc3008b,0x6b880629}},	//   jova, čaci_, yunu, _oudg,
   {{0x7e690018,0x6b880180,0x7bc3013c,0x00000000}},	//   _szep, _nudg, xunu, --,
   {{0x926b00c6,0xef190078,0x673d7786,0x7bc37787}},	//   _арга_, _biża_, nisj, vunu,
   {{0x6d587788,0x7e600113,0x7f490216,0x8c3c0233}},	//   fova, _cymp, _vjeq, _değm,
   {{0x7bc348df,0xfce5014d,0x7e60030a,0x00000000}},	//   tunu, соко, _dymp, --,
   {{0x256402c3,0x00000000,0x00000000,0x00000000}},	//   följ_, --, --, --,
   {{0x7bc37789,0x7f5b0060,0x0ae91cb1,0xd1051c83}},	//   runu, _ukuq, удий_, रावण_,
   {{0x6d58134c,0x7bc3778a,0x3d941824,0x661d052f}},	//   bova, sunu, _митр, jysk,
   {{0x7bc3778b,0x6d5818ed,0x661d778c,0x00000000}},	//   punu, cova, dysk, --,
   {{0xbb850080,0x673d00e7,0x753c01d3,0xe1ff0103}},	//   _الصي, fisj, virz, _szól_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcb1200a1,0xaa08048f,0xb0c702d5,0xe73702e3}},	//   _מלא_, _نزول_, _लांग, сея_,
   {{0x395c02ef,0xf99200a1,0x799b00f9,0xa5c7003e}},	//   _gkvs_, _צרו_, mpuw, _stóð,
   {{0x6120070a,0xc7950604,0x232a11d9,0xfd670065}},	//   _följ, _اشتب, гови_, _burẹ,
   {{0xe7ec14e5,0x6d5d003e,0xa6db04c8,0x935a13a8}},	//   _जनता_, _ísaf, viðg, ургу_,
   {{0x95c90396,0xe0da008f,0x6d586e92,0x8c350139}},	// [7820] _куќа_, лва_, yova, _ke̟s,
   {{0xd00a0476,0x6d586977,0x2bf90285,0xa0a61bc1}},	//   лезе_, xova, ्मां_, сажд,
   {{0xa2e60a51,0x7e600b87,0x63a9007e,0x8e3a1aaa}},	//   _лонд, _symp, ćenc, گسار_,
   {{0x8cda0374,0xdcfa022b,0xdb0302c3,0x00000000}},	//   प्नो, _vitč, nsnä, --,
   {{0x9c7c02dd,0x61210134,0xee3a0012,0x256402c3}},	//   _načr, _ịlek, ынд_, jölk_,
   {{0x40ab0421,0xef19009e,0x00000000,0x00000000}},	//   _مخفی_, _viża_, --, --,
   {{0x661d00a5,0x98880103,0x2bb70037,0x55770142}},	//   zysk, یحدہ_, ماية_, זעסן_,
   {{0x6d58778d,0x00000000,0x00000000,0x00000000}},	//   sova, --, --, --,
   {{0x6d583472,0x5e4a3967,0x673d004d,0x799b0124}},	//   pova, _спам_, visj, gpuw,
   {{0x3f8a0da3,0x8c46004c,0x661d5ae0,0x00000000}},	//   _kubu_, _лезе, vysk, --,
   {{0xa3e70d1b,0x415b006e,0x673d778e,0x00000000}},	//   _मैं_, רדיג, tisj, --,
   {{0x95cb03fc,0x3f8a02c9,0x661d00c2,0x2bdd00aa}},	//   луга_, _mubu_, tysk, _महता,
   {{0x673d778f,0x3f8a285a,0xdb0a0072,0x2bc600a4}},	//   risj, _lubu_, nsfí, रंवा,
   {{0x92c50081,0x673d00d6,0x3f9801d3,0x661d0034}},	//   _এসে_, sisj, _otru_, rysk,
   {{0x3f8a05bd,0xa3e400c3,0x9c7c0128,0x3cf0007f}},	//   _nubu_, पौल_, _začr, _इसने_,
   {{0x1fce0081,0x69c07790,0xc2991e20,0x6b820239}},	//   রবাস, orme, рках_, _jiog,
   {{0x3f8a07ac,0xb11500b4,0x60870037,0x6b8203a9}},	// [7830] _aubu_, омаш, مشاك, _miog,
   {{0x69c00a02,0x3f8a024a,0xdb180329,0x00000000}},	//   irme, _bubu_, luvä, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8a1114,0x01c90068,0x9df91d68,0xe2f90120}},	//   _dubu_, _پوسٹ_, инет_, _темі_,
   {{0xa2270286,0xf1ab0076,0x00000000,0x00000000}},	//   _طرحه, _حاجه_, --, --,
   {{0xa1947791,0x61ef00ee,0x28d82fbd,0xe3b0015a}},	//   _харч, _iscl, _बॉलि, _تری_,
   {{0xeb995827,0x251c0130,0x69c00eb3,0xcfa400ae}},	//   ший_, רווא, erme, _ншти,
   {{0x2ee601cb,0x00000000,0x00000000,0x00000000}},	//   ceof_, --, --, --,
   {{0x6b827792,0x61fb031a,0x3f8a00d8,0x3eaf0537}},	//   _diog, _šulj, _zubu_, magt_,
   {{0x3eaf2c03,0x3f8a0169,0x78a90284,0x92c50a43}},	//   lagt_, _yubu_, шког_, _এসো_,
   {{0x186908c3,0xfbdd0336,0xd70a01b3,0x574a444f}},	//   рани_, _महिम, анне_, изом_,
   {{0x81e00081,0x6b827793,0x61ef0076,0xdddb00c4}},	//   থিত_, _giog, _oscl, _zguš,
   {{0x6a675f34,0x3cfe0096,0xdb0302c3,0x44310381}},	//   _اطال, लाचे_, rsnä, ezz_,
   {{0xfbdd1fb4,0x6b8200e7,0x2bc622a3,0xdb01004d}},	//   _महाम, _ziog, रूवा, _avlø,
   {{0x48ee02e8,0xa87900c1,0x61ef09c2,0x833a015f}},	//   _असतो_, _דאַר, _ascl, ачат_,
   {{0xe29a001f,0x798302e2,0x3f8a1912,0xa3bb00c3}},	//   раа_, _hinw, _rubu_, _घिर_,
   {{0x6aab0068,0x798371d7,0xa5bb0103,0x3f9800c4}},	// [7840] _megf, _kinw, szór, _stru_,
   {{0x6aab0018,0x79830da7,0x798b1e59,0x00000000}},	//   _legf, _jinw, _mugw, --,
   {{0x4fea1a77,0x61ef608c,0xdd990154,0x798b084e}},	//   рмен_, _escl, _atň_, _lugw,
   {{0x9e661bec,0x57cc00c1,0x00000000,0x00000000}},	//   овед, רמאַ, --, --,
   {{0x6b820441,0x2ee600d7,0x00000000,0x00000000}},	//   _riog, reof_, --, --,
   {{0x412a3379,0x3f8a02a1,0xd6570327,0xdb0103a8}},	//   _того_, _tubu_, חינת_, _bwlï,
   {{0xdcfa00d9,0x6b8200e5,0xdfd205d1,0xbb2a002d}},	//   _citā, _piog, _تيز_, ицие_,
   {{0x81bd0081,0x798b0361,0x6b8200ac,0xf53f0a1f}},	//   _আহত_, _bugw, _ọgba, nsår_,
   {{0xc8780233,0x6ab900eb,0x6aab030a,0x00000000}},	//   meği_, _ddwf, _degf, --,
   {{0xdce800d9,0xdddb0542,0x7983008c,0x38343bbc}},	//   _vidē, _uguš, _cinw, знор,
   {{0xf09300a1,0xab2a0b73,0x6b82010b,0x3f840517}},	//   ונת_, _кожа_, _tiog, _kimu_,
   {{0x798301bf,0x3f8401c2,0xc878026a,0x569400a9}},	//   _einw, _jimu_, neği_, мают,
   {{0xceb300a1,0x2cac0018,0x6d4a7794,0x798b06b0}},	//   ויר_, _kedd_, onfa, _gugw,
   {{0x798300f9,0x3f84083e,0x6d4a7795,0x2cac00bd}},	//   _ginw, _limu_, nnfa, _jedd_,
   {{0x68e87796,0x44257797,0x389b00ca,0x6d4a7798}},	//   medd, ál_, _דיונ, infa,
   {{0x68e87799,0x61fd0542,0x2cac004d,0x4431033c}},	//   ledd, _prsl, _ledd_, rzz_,
   {{0x8c3c074e,0x2cac02e0,0x9487002d,0x798303e3}},	// [7850] _deği, _oedd_, _мынд, _yinw,
   {{0x68e8779a,0xecc90557,0x2cac00f0,0xf53f02c3}},	//   nedd, _राइफ, _nedd_, rsås_,
   {{0x3f84779b,0xbe980294,0x3eaf779c,0x00000000}},	//   _bimu_, _ịhụr, tagt_, --,
   {{0x68e80150,0x25a90d2a,0x5ede0033,0x00000000}},	//   hedd, _kwal_, _নোবে, --,
   {{0x7de70080,0xc33200c1,0x68e80bf2,0x80d853b8}},	//   تسام, _טוט_, kedd, न्हे,
   {{0x3eaf779d,0x61ed2d30,0x68e8004d,0x6b9a010a}},	//   sagt_, mwal, jedd, _bttg,
   {{0x61ed779e,0x2bc6030b,0x68e8030a,0xc8780233}},	//   lwal, रूला, dedd, beği_,
   {{0x7e7d025b,0xc87801e8,0x3f8406b0,0x00000000}},	//   _úspo, ceği_, _gimu_, --,
   {{0x61ed779f,0x7b1c00fd,0x68e800f0,0x6aab041b}},	//   nwal, _réut, fedd, _vegf,
   {{0x68e80517,0x3ead77a0,0x81e50033,0x6aab042c}},	//   gedd, _heet_, পটপ_, _wegf,
   {{0x25a91bd6,0x61ed77a1,0x2d850294,0x09e10081}},	//   _awal_, hwal, _iile_, বিধা,
   {{0x61ed77a2,0xd5b800d9,0x7b1c0072,0xf7722ba0}},	//   kwal, ņām_, _déus, عاد_,
   {{0x68e877a3,0x2d856134,0x7ae9007a,0x3ead77a4}},	//   bedd, _kile_, meet, _meet_,
   {{0x61ed77a5,0x7ae977a6,0x3ead0b14,0x25a9009e}},	//   dwal, leet, _leet_, _dwal_,
   {{0x69c9373c,0xe1ff026e,0x2e4e0174,0xd46a00ae}},	//   luee, _aró_, lọtọ_, сиве_,
   {{0x2d8577a7,0x2b910023,0x969500d3,0x61ed026d}},	//   _lile_, _mác_, _орьш, fwal,
   {{0x26d2092f,0x7bc3033d,0x25a903e3,0x2d8577a8}},	// [7860] _icyo_, hrnu, _gwal_, _oile_,
   {{0x3f840010,0x7ae977a9,0x00000000,0x00000000}},	//   _simu_, heet, --, --,
   {{0x7ae977aa,0x2cac004d,0x6ee10134,0x22950174}},	//   keet, _redd_, _ịbaw, _ụke_,
   {{0x2d8577ab,0x68e877ac,0x2cac77ad,0x69c94880}},	//   _aile_, zedd, _sedd_, kuee,
   {{0x3ead01af,0x7ae977ae,0x68e8083e,0x61ed019f}},	//   _deet_, deet, yedd, cwal,
   {{0x2b910028,0x6d4a22a4,0x2d8577af,0x69c974bc}},	//   _bác_, unfa, _cile_, duee,
   {{0x2b91011b,0x3f84068d,0x81ce0081,0x9c7c2449}},	//   _các_, _timu_, _শনি_, _obče,
   {{0x2d8577b0,0x290777b1,0xb99802ec,0x68e857cf}},	//   _eile_, _anna_, ових_, wedd,
   {{0x2d85051f,0x68e877b2,0x2cac01f9,0xdcfa078e}},	//   _file_, tedd, _tedd_, _cită,
   {{0xfe45110a,0x29180088,0x26d20027,0x63b5007f}},	//   _تکمی, ðra_, _acyo_, yszn,
   {{0x7d080021,0x7ae977b3,0x61ed00a5,0xbc6a0241}},	//   _inds, beet, zwal, _امان_,
   {{0x2d8577b4,0x68e877b5,0x29070451,0x25a902f1}},	//   _zile_, sedd, _enna_, _pwal_,
   {{0x7d1a77b6,0x68e8010a,0xd05c0044,0x69c901cb}},	//   _kots, pedd, _karɓ, cuee,
   {{0x58d300c9,0x2d85015e,0x25a905aa,0xdb0100eb}},	//   _зошт, _xile_, _vwal_, _gwlâ,
   {{0x7d1a77b7,0x2b910028,0x63a91419,0x61ed6778}},	//   _mots, _xác_, ćeno, wwal,
   {{0x61ed77b8,0x7d1a77b9,0xe1ff20df,0xe3b01f9c}},	//   twal, _lots, _pró_, طرف_,
   {{0x290777ba,0x8ccd12e5,0x7d081842,0x3ead4d0b}},	// [7870] _ynna_, _सालो, _onds, _reet_,
   {{0x7bca661c,0x61ed77bb,0x7d1a77bc,0x672d033b}},	//   kufu, rwal, _nots, _hlaj,
   {{0x61ed77bd,0x672d77be,0x28d40179,0xd4981402}},	//   swal, _klaj, _दानि, _эры_,
   {{0x2d85026e,0x7bc30039,0x2b910019,0x7d0877bf}},	//   _sile_, vrnu, _rác_, _ands,
   {{0x2a660d7d,0x6e220068,0x7d1a4385,0x61ed77c0}},	//   _nyob_, gyob, _bots, qwal,
   {{0x3ead1d19,0x7ae977c1,0x7bca77c2,0x2b91424d}},	//   _weet_, weet, fufu, _pác_,
   {{0x2d85068d,0x7ae977c3,0xdd9100fb,0xdbf70378}},	//   _vile_, teet, روں_, ंटेड_,
   {{0x69c97119,0x394c00a1,0xfd4e0134,0x7d08042c}},	//   tuee, ends_, _kekọ, _ends,
   {{0x1dd10354,0x7d1a169c,0xfd4e0294,0x7bc30106}},	//   _समित, _fots, _jekọ, srnu,
   {{0x2b9100ef,0x672d77c4,0x2d8510f0,0x7ae90f4c}},	//   _tác_, _alaj, _uile_, seet,
   {{0x61200102,0x6f1b06a3,0x672d77c5,0xfd4e0134}},	//   _tölv, _kouc, _blaj, _lekọ,
   {{0x98ad0dea,0x236901fa,0x399203a8,0x394c00fc}},	//   ının_, jlaj_, _fâs_, ands_,
   {{0x6f1b4afe,0x61200018,0x2b5f00b6,0xdcfa020a}},	//   _mouc, _költ, mouc_, _uită,
   {{0x68450870,0x6f1b77c6,0x290700d6,0x672d6961}},	//   _онла, _louc, _unna_, _elaj,
   {{0x3cf000a5,0x236977c7,0x00000000,0x00000000}},	//   _इससे_, flaj_, --, --,
   {{0x6d434e06,0x236977c8,0x82f5008f,0xb8b20139}},	//   hina, glaj_, нчуц, _fẹsè,
   {{0x2a66023e,0x2e4e00ac,0x27e000c4,0xd18601b6}},	// [7880] _xyob_, họrọ_, _ćini_, длай,
   {{0x69c602dd,0xfd4e0134,0x672d1197,0x6e220239}},	//   škeg, _dekọ, _zlaj, vyob,
   {{0x6f1b6672,0x236977c9,0x7f420033,0xdb0a00dd}},	//   _bouc, blaj_, tioq, ënës,
   {{0x7d1a007a,0x3f9c01d3,0x6d430138,0x2e4e0134}},	//   _sots, īvu_, eina, dọrọ_,
   {{0x7d1a77ca,0xdd8f0c5e,0x9f650018,0x80ad0081}},	//   _pots, لون_, ítás_, _চার্,
   {{0x6d434d59,0x7bca77cb,0xb0dd66d3,0x6f0977cc}},	//   gina, tufu, न्दग, _enec,
   {{0xfbcf00ab,0x7d1a007e,0x395e77cd,0x00000000}},	//   لتي_, _vots, vots_, --,
   {{0x1b7700e3,0x7bca77ce,0x776402a1,0x00000000}},	//   وصية_, rufu, _nkix, --,
   {{0x6d4377cf,0x3ea677d0,0x7bd877d1,0x7d1a77d2}},	//   bina, mbot_, stvu, _tots,
   {{0x3ea600f0,0x61200088,0x7d08052f,0x2e4e0134}},	//   lbot_, _tölu, _unds, bọrọ_,
   {{0xcb6a21a1,0x672d77d3,0x395e01d3,0x998202c6}},	//   _даже_, _plaj, rots_, šků_,
   {{0x613277d4,0x3a2635c1,0x61e677d5,0x8cda0287}},	//   _fælg, _омег, _opkl, प्रो,
   {{0x7ae26299,0x613202b6,0x672d1405,0x666400e5}},	//   _ibot, _kæld, _vlaj, върз,
   {{0xb3470396,0xfd4e321e,0xe4e40120,0x00000000}},	//   _opçõ, _rekọ, кісн, --,
   {{0x61e6013f,0xfd4e0134,0x3ea607ac,0x672d77d6}},	//   _apkl, _sekọ, kbot_, _tlaj,
   {{0x68f80021,0x9f4c0649,0x44230034,0x672d77d7}},	//   _havd, _èdè_, ryj_, _ulaj,
   {{0x7ae200bf,0x291c11cf,0x6d4377d8,0x2509001c}},	// [7890] _mbot, _kova_, yina, _فردی_,
   {{0x6d434ce0,0xeb1b02e8,0x3dc64836,0x6f1b77d9}},	//   xina, _फक्त_, drow_, _souc,
   {{0xa3d600af,0x6f1b1379,0xa3e700a5,0x7ae277da}},	//   _समय_, _pouc, _मैच_, _obot,
   {{0x6d4377db,0x68f8023b,0x41c702d5,0x291c10c0}},	//   wina, _lavd, _लिपस, _lova_,
   {{0x6d4377dc,0xfce52dd8,0x6f1b77dd,0x9f4a00b3}},	//   tina, еоло, _vouc, _arbó_,
   {{0x0d8402ec,0x68f80087,0x7ae277de,0x3ea61ba1}},	//   влін, _navd, _abot, abot_,
   {{0x61320021,0x3ea677df,0x6f1b77e0,0x6d4377e1}},	//   _sælg, bbot_, _touc, rina,
   {{0x3dc62ad7,0x200301c2,0x6f09406e,0x61200e2e}},	//   brow_, _irji_, _unec, _föls,
   {{0x6d4377e2,0x61200018,0x27340019,0x291c77e3}},	//   pina, _tölt, _hãng_, _bova_,
   {{0x63a9150a,0x613201c5,0x291c77e4,0x63ba0087}},	//   ćenj, _vælg, _cova_, štni,
   {{0x291c77e5,0x3f9177e6,0x6d4102a1,0x25a200dc}},	//   _dova_, _juzu_, _imla, wpkl_,
   {{0x65650167,0x06b00081,0xef190090,0xe73203ef}},	//   _akhh, _কাহি, _biżi_, اصد_,
   {{0xa6db0088,0x273400de,0x2812001c,0x613200f2}},	//   miðl, _lãng_, نویس, _hæle,
   {{0x7afb0a00,0x613202b6,0x69db0052,0xba74487a}},	//   ldut, _kæle, mtue, _شانت,
   {{0x64570072,0x187500c1,0x394500b3,0x229500ac}},	//   _cxxi, _אײַך_, mils_, _ụka_,
   {{0x23b103a2,0x3ebf0449,0x14170037,0x291c007e}},	//   _जबरद, _ndut_, ريقة_, _zova_,
   {{0x646200a5,0x7e6977e7,0x20035019,0x26c0009c}},	// [78a0] _świę, _nyep, _arji_, _idio_,
   {{0x25a002f1,0x20563d02,0x3ea61423,0x39451afb}},	//   _itil_, нтер, wbot_, nils_,
   {{0x9c7c134c,0xb4ac07e2,0xe29a0528,0x27e70085}},	//   _obča, खरी_, _нан_, _jpnn_,
   {{0x3f9102a7,0x200c03e5,0x660477e8,0x272277e9}},	//   _duzu_, _ġdid_, _krik, _ións_,
   {{0x3ea677ea,0x0cd42776,0x69db00dd,0x20030090}},	//   rbot_, волю, jtue, _erji_,
   {{0x3dc600ca,0x7afb0072,0x660400cd,0x3ebf00ce}},	//   rrow_, edut, _mrik, _edut_,
   {{0x26c077eb,0x3f916a54,0x3ea6009c,0xd47a006e}},	//   _odio_, _guzu_, pbot_, האַל,
   {{0x26c0068d,0x68f800e8,0x291c1e8f,0x660477ec}},	//   _ndio_, _savd, _sova_, _orik,
   {{0x394577ed,0x25a0010a,0x68f80216,0xe9462312}},	//   fils_, _ntil_, _pavd, ехно,
   {{0x26c077ee,0xadb70037,0x8afd00d2,0x00000000}},	//   _adio_, _أهلا_, voře, --,
   {{0x59c210e9,0x660477ef,0x313700ca,0x25a013d0}},	//   _शिवर, _arik, גנים_, _atil_,
   {{0x38c60032,0xd6db007b,0x7af9020b,0x7ae2039f}},	//   _bírà_, что_, _gawt, _ubot,
   {{0xae03034c,0xa3d302e8,0x39450472,0x69db0c31}},	//   लियन_, हून_, bils_, ctue,
   {{0x66041484,0x291c00e5,0x394577f0,0xd7f000e3}},	//   _drik, _uova_, cils_, _نكت_,
   {{0x660477f1,0x06b00033,0xd82f016a,0x248502c3}},	//   _erik, _কারি, _сэ_, älm_,
   {{0x660477f2,0x2b090034,0xd05c01c2,0x52cb00b6}},	//   _frik, वाएँ_, _harɗ, िलेस,
   {{0x660477f3,0x3f910995,0x60f90b2f,0x6459007f}},	// [78b0] _grik, _suzu_, мная_, _świd,
   {{0x3329008c,0x00000000,0x00000000,0x00000000}},	//   skax_, --, --, --,
   {{0xf8b30341,0x853c00a1,0xf6500068,0x660400e7}},	//   רשע_, _מגזי, _نئی_, _zrik,
   {{0x6d4102ef,0x273400fe,0xdcb100fe,0x7c3d013c}},	//   _smla, _vãng_, _sẻ_, _əsrd,
   {{0x7ed40d59,0x69db014b,0x3f910172,0x00000000}},	//   ازما, xtue, _wuzu_, --,
   {{0x5184007e,0x8c450219,0xfce54e5c,0x7af9041c}},	//   _буса, келе, токо, _sawt,
   {{0x394577f4,0xdcb100fe,0x00000000,0x00000000}},	//   vils_, _vẻ_, --, --,
   {{0x64410034,0x3ebf0113,0x69db77f5,0x7afb007b}},	//   źliw, _udut_, ttue, udut,
   {{0x394577f6,0x7afb5664,0xdd951ad1,0x2add22a0}},	//   tils_, rdut, _разы, क्षु_,
   {{0x6d4177f7,0x95ee030b,0x7afb0036,0xfe6e001c}},	//   _umla, _छनौट_, sdut, _بگم_,
   {{0x69db77f8,0xf092040a,0x394577f9,0x660434ac}},	//   stue, יני_, rils_, _srik,
   {{0x69db77fa,0xd6b00033,0xf746044b,0x394577fb}},	//   ptue, কল্প, темо, sils_,
   {{0x69350f30,0x49bb1574,0x394577fc,0xbb3a00c1}},	//   _инду, _راشد_, pils_, _קעני,
   {{0xb4ac0455,0x629d77fd,0x628f77fe,0x25a00167}},	//   खरे_, _afso, _agco, _vtil_,
   {{0x628f34bb,0x6b8b77ff,0x442c0037,0x0ed102d5}},	//   _bgco, _kigg, ád_, _हांड,
   {{0x6b8b0078,0x26c00dd9,0x628f0022,0x6aa9384c}},	//   _jigg, _udio_, _cgco, nbef,
   {{0x25a01e51,0x6b8b06b0,0x877b006e,0x66047800}},	// [78c0] _util_, _migg, _קאפי, _urik,
   {{0x6b8b1842,0x64590067,0xb5b70089,0x10a60d66}},	//   _ligg, _świe, _שליח_, тижн,
   {{0x69c90505,0x2d1e00c3,0xdfd20076,0x6fb30076}},	//   hree, _बकौल_, شيش_, لملا,
   {{0x69c97801,0x25ad00d3,0x5276002d,0x6da60e1d}},	//   kree, ţele_, _аугу, вида,
   {{0xf2d31541,0x52750290,0xdce10154,0xe1ff007f}},	//   _דער_, _буру, _eklč, _wzór_,
   {{0x69c9002d,0xa0a3125f,0x00000000,0x00000000}},	//   dree, _вард, --, --,
   {{0x61430e08,0x6b8b7802,0x69c97803,0x656e10e4}},	//   _тера, _bigg, eree, ilbh,
   {{0x96a20789,0x9a860db2,0x7bc5034f,0x00000000}},	//   _क्लॉ, купл, áhua, --,
   {{0x7de503ef,0x63a902e6,0x69c97804,0x6b8b256f}},	//   _مسلم, ćeni, gree, _digg,
   {{0xdb0a00d4,0x39140c58,0x0c7a05bc,0xc27b0eda}},	//   nsfú, умор, _قصاب_, ורפי,
   {{0x6b8b2977,0x69c90188,0x00000000,0x00000000}},	//   _figg, aree, --, --,
   {{0xfaa619ff,0x69c919fb,0x2d8c00ca,0x16bf0034}},	//   _радо, bree, _hide_, ्लेब,
   {{0x2d8c5570,0x69dc020a,0x6a1601c3,0x798a02a1}},	//   _kide_, ăres, _جبار, _tifw,
   {{0x2d8c7805,0x6b8b7806,0x02cb030b,0xd9430036}},	//   _jide_, _zigg, िल्न, _кечи,
   {{0x2d8c4196,0xb8200033,0x290e0231,0x9f5f0052}},	//   _mide_, _ফেরত_, _infa_, ërën_,
   {{0x2d8c7807,0x656e0091,0x81e70081,0x0ed10d77}},	//   _lide_, albh, ভিস_, _हाइड,
   {{0x883700e8,0x00000000,0x00000000,0x00000000}},	// [78d0] ģēša, --, --, --,
   {{0x44f5205c,0x00000000,0x00000000,0x00000000}},	//   _спос, --, --, --,
   {{0x518407c6,0x628f0451,0x69c90063,0x00000000}},	//   рута, _tgco, zree, --,
   {{0x2d8c04ea,0x66027808,0xd9f2136b,0x69c93bd7}},	//   _aide_, _šoki, _अनंत_, yree,
   {{0x2d8c169d,0x6b8b7809,0xdcb10023,0x00000000}},	//   _bide_, _rigg, _hỏi_, --,
   {{0x6b8b780a,0x69c91507,0xbebd17b1,0x00000000}},	//   _sigg, vree, _plūs, --,
   {{0x2d8c0af0,0x6b8b780b,0x69c9041c,0x6d5d01cd}},	//   _dide_, _pigg, wree, _ísam,
   {{0x69c93bfa,0x2b980257,0xa5bb0103,0x2d8c0120}},	//   tree, _déc_, gyók, _eide_,
   {{0xc33400a1,0x6b8b108c,0x69c9780c,0x6aa9780d}},	//   יוק_, _vigg, uree, rbef,
   {{0x69c9780e,0x2d8c780f,0x3f8d00de,0xb9100294}},	//   rree, _gide_, _hieu_, melụ_,
   {{0x6b8b7810,0x80d82125,0x3f8d0023,0x7ad503ef}},	//   _tigg, न्टे, _kieu_, _مقاص,
   {{0x69c97811,0x28a30096,0xe5a61a57,0x290e7812}},	//   pree, _ख्रि, лими, _enfa_,
   {{0xb9100174,0x26de0034,0x3f8d7813,0x00000000}},	//   nelụ_, ęto_, _mieu_, --,
   {{0x3f8d7814,0x98a22e0f,0x00000000,0x00000000}},	//   _lieu_, _лише, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8d057a,0x00000000,0x00000000,0x00000000}},	//   _nieu_, --, --, --,
   {{0x9f5e04ea,0x00e620e6,0x00000000,0x00000000}},	// [78e0] _été_, лжан, --, --,
   {{0x98be00d3,0xd5b801d3,0x00000000,0x00000000}},	//   mită_, ņās_, --, --,
   {{0x98be00ae,0x25b20150,0x2d8c4a62,0x3f8d00fe}},	//   lită_, _hwyl_, _ride_, _bieu_,
   {{0x5fc90455,0x2d8c00a1,0x3fb90018,0x25b2084e}},	//   ांजल, _side_, ئپنگ_, _kwyl_,
   {{0x3f8d7815,0x2d8c0fb6,0x98be00ae,0xfe4600ae}},	//   _dieu_, _pide_, nită_, ындо,
   {{0x61460832,0x00000000,0x00000000,0x00000000}},	//   _сега, --, --, --,
   {{0x0b8a5cb1,0xbccf0206,0x8fa31722,0x00000000}},	//   нсии_, íťaž, _гасе, --,
   {{0x3cf00067,0x70530e25,0x2d8c3819,0x00000000}},	//   _इसके_, _انفا, _wide_, --,
   {{0x5f1102e8,0xdca61693,0x442a0146,0x4ad50b94}},	//   णार्_, _бази, hyb_, _धारव,
   {{0xc23700ca,0xa6db003e,0x98be020a,0x2d8c0141}},	//   טרפו_, miði, dită_, _uide_,
   {{0x7c930080,0x5c567816,0xa6db003e,0x6d4a0415}},	//   _المص, _стаф, liði, mifa,
   {{0x6d4a0a4b,0x9a6a0037,0x98be044c,0x00000000}},	//   lifa, _كمال_, fită_, --,
   {{0xdb0a038c,0x659507c6,0x3cfe3f16,0x291830c1}},	//   dsfø, рагу, _katv_, öras_,
   {{0x6d4a7817,0xb4c10be4,0x260a009f,0xdb017818}},	//   nifa, ुले_, ामजी_, _atlè,
   {{0x3cec030b,0x80d8030b,0x78ba0a84,0xa0240033}},	//   _आउने_, न्छे, matv, _যেসব_,
   {{0x6d4a0010,0xe2f801ce,0xa2a00ccb,0x98be00ae}},	//   hifa, лесі_, गुल्, bită_,
   {{0x6d4a4671,0x98be00ae,0x30a715ca,0x7c2a00f0}},	// [78f0] kifa, cită_, грев, hyfr,
   {{0x6d4a0051,0xf1c80037,0x3f8d0023,0x78ba00c6}},	//   jifa, اولى_, _sieu_, natv,
   {{0x20077819,0x6d4a781a,0x7a4800e8,0x00000000}},	//   íni_, difa, lītī, --,
   {{0x672f00a5,0x78ba781b,0x63a50350,0x6d4a05c2}},	//   nkcj, hatv, _ithn, eifa,
   {{0x6d4a005c,0x386e0150,0x9f5c00b6,0x78ba13ea}},	//   fifa, _lyfr_, ívá_, katv,
   {{0x85300d2a,0x6d4a781c,0x78ba0117,0xb9100134}},	//   _kuɗa, gifa, jatv, relụ_,
   {{0x3f8d00de,0x98be00ae,0x78ba781d,0x00000000}},	//   _tieu_, zită_, datv, --,
   {{0x3cfe0a4b,0x6d4a02ac,0xcc080981,0x00000000}},	//   _eatv_, aifa, ازون_, --,
   {{0x6d4a2cd0,0xdce100bd,0x00000000,0x00000000}},	//   bifa, _nilħ, --, --,
   {{0x39451bec,0x98be00ae,0xbb4400c2,0x78ba610d}},	//   рног, vită_, äärä, gatv,
   {{0xe73a07f3,0x2eff01bf,0x3cf202d5,0x63a2007e}},	//   вен_, _kauf_, ंजरे_, _čono,
   {{0xc9f50018,0xdce10090,0x98be00ae,0x00000000}},	//   _نستع, _bilħ, tită_, --,
   {{0x63a50037,0x16b606eb,0x78ba02ac,0x6abb02db}},	//   _athn, _अजीब, batv, mauf,
   {{0x64590067,0x98be00d3,0x6abb01bf,0x853003e3}},	//   _świa, rită_, lauf, _buɗa,
   {{0x888300cd,0xdb01781e,0xd46a2ba7,0x85300022}},	//   _دیدن, _atlé, тиве_, _cuɗa,
   {{0x97c400cd,0x6d4a781f,0x6abb0364,0x66022347}},	//   _اتوم, zifa, nauf, _šoku,
   {{0x63a57820,0xe0da0cd7,0xe2970d4f,0xb1464587}},	// [7900] _ethn, ква_, рау_, анал,
   {{0x399b0396,0x6abb7821,0xf0a7002d,0x28dd09b0}},	//   _mês_, hauf, икул_, _माफि,
   {{0xa2e606ff,0x28dd000d,0x6abb01bf,0xd00f0037}},	//   _конд, _मानि, kauf, ولك_,
   {{0xdee63277,0x7c2e02e2,0x539b040a,0xeda67822}},	//   роди, _übri, _שיכו, ашко,
   {{0x6d4a7823,0x3ea90143,0x3cf20d75,0x00000000}},	//   tifa, ñata_, ंजले_, --,
   {{0x80dd7824,0x2b4601b9,0xa6db01cd,0x00000000}},	//   _पाये, _smoc_, riði, --,
   {{0x6d4a7825,0xb6060117,0xaca30065,0x78ba7826}},	//   rifa, ljšč, _gbọl, vatv,
   {{0x6d4a0060,0x5b14002d,0xa3b8030b,0x3ce90995}},	//   sifa, смит, घीय_, đava_,
   {{0x3f980010,0xb6062281,0x80dd00c3,0x6f00009c}},	//   _huru_, njšč, _पामे, _iamc,
   {{0x3f987827,0x399b0231,0x7aa600a4,0x6f007828}},	//   _kuru_, _dês_, _ट्रॅ, _hamc,
   {{0x3f987829,0x6d48782a,0x6f006e92,0xb8fe0285}},	//   _juru_, _imda, _kamc, _णा_,
   {{0x09e61605,0x6f02782b,0x853003e3,0x3f98782c}},	//   _водн, ndoc, _ruɗa, _muru_,
   {{0x6f000880,0x2bc40294,0x29110037,0x3f9801dc}},	//   _mamc, _ịche_, ánaí_, _luru_,
   {{0x69c0782d,0x58d3007e,0x3d19074c,0x7a79006e}},	//   msme, _дошт, पाये_, _גרױס,
   {{0x3f98782e,0x397b006e,0x897b00ca,0x660200c6}},	//   _nuru_, _שטונ, _שרוצ, _šokt,
   {{0x394c5af9,0xa3be02d5,0xdce1009e,0x00000000}},	//   lids_, ुंज_, _tilħ, --,
   {{0x645e782f,0x6d484e43,0x69c07830,0x6f027831}},	// [7910] _expi, _omda, nsme, ddoc,
   {{0x3f987832,0x2eff0257,0x394c7833,0xa0a73e7b}},	//   _buru_, _sauf_, nids_, ршал,
   {{0x3f9802f7,0x6f00063d,0x6f020350,0x63a90357}},	//   _curu_, _bamc, fdoc, ćens,
   {{0x6f007834,0x6d487835,0x69c000d9,0x26d900cd}},	//   _camc, _amda, ksme, ngso_,
   {{0xdef82787,0x69c01ce4,0x6f007836,0xa3d34660}},	//   рых_, jsme, _damc, हूर_,
   {{0xa3be05d4,0xee380426,0x69c00407,0x78b8010a}},	//   ुंच_, шні_, dsme, _nevv,
   {{0xadc30028,0x6abb0364,0x6f027837,0x6f000154}},	//   _trắn, tauf, bdoc, _famc,
   {{0x6d487838,0x545800ca,0x6f0001ee,0x59c209a0}},	//   _emda, יסון_, _gamc, _शिखर,
   {{0x6abb01bf,0x69c02085,0x3f9800ac,0xe2a601cd}},	//   rauf, gsme, _zuru_, óðin_,
   {{0x9be702ec,0x394c0371,0x27fc0063,0x6f000095}},	//   _відк, gids_, _bsvn_, _zamc,
   {{0xc6890796,0x29110511,0x69c018f0,0xe71100c6}},	//   _נא_, ıza_, asme, _dėžė,
   {{0x7d01032e,0xaa950037,0xe73a0ab3,0x69c00ac1}},	//   _hals, _الإث, уем_, bsme,
   {{0xa3da02e8,0x2b4d007f,0x00000000,0x00000000}},	//   डून_, miec_, --, --,
   {{0xdce30ec8,0x394c43a2,0x64a31603,0x2b4d00e8}},	//   konč, cids_, зара, liec_,
   {{0x61fd005c,0x7d017839,0x1dd108d4,0x799900eb}},	//   _assl, _mals, _समझत, _huww,
   {{0x2b4d3239,0x3f9800ac,0xdce30477,0x799903e3}},	//   niec_, _ruru_, donč, _kuww,
   {{0x200a00e9,0x613201c5,0x3f98783a,0x6f005b40}},	// [7920] _srbi_, _fæll, _suru_, _ramc,
   {{0x3f980294,0xb69b2364,0x1dd10096,0x799902ac}},	//   _puru_, ndân, _समजत, _muww,
   {{0xa4fb0266,0x6f0009ac,0x61fd02db,0x2af909a1}},	//   _גליט, _pamc, _essl, ्याँ_,
   {{0x1e860012,0xee3a0291,0x7d01783b,0x69c0783c}},	//   блем, лне_, _aals, ysme,
   {{0x7d01783d,0x81e70081,0x3f980134,0xb7ef0033}},	//   _bals, ভিউ_, _wuru_, য়মিত_,
   {{0x3f98783e,0x69c00160,0x3f960396,0x6f0201cb}},	//   _turu_, vsme, _граѓ, sdoc,
   {{0x7d01783f,0x4adc0966,0xa137006e,0x3c0700fe}},	//   _dals, _यादव, _פאלק_, _cđv_,
   {{0x69c04834,0x5a343407,0x61e47840,0x69c60117}},	//   tsme, жнит, otil, škem,
   {{0xa92a0077,0x69c07841,0x394c032e,0xcb670291}},	//   гіне_, usme, tids_, љање_,
   {{0x69c07842,0xa3d3007a,0xce370796,0x3f867843}},	//   rsme, हूँ_, _האמת_, lmou_,
   {{0x9c7c19be,0xab9600e3,0x394c0212,0x69c07844}},	//   _obči, _الصغ, rids_, ssme,
   {{0x61e47845,0x3f8606a3,0x973d0ac3,0x69c07846}},	//   ktil, nmou_, opći, psme,
   {{0x8b650080,0xe6670423,0xe918224a,0x3f8613a9}},	//   _بالم, стно, _волі_, imou_,
   {{0x61e411d3,0x290201d3,0x6d587847,0xa6db04c8}},	//   dtil, ēkas_, nnva, viðu,
   {{0xa3d30da9,0x6b9a05fe,0x0ed8121d,0xf2c7004b}},	//   हूं_, _jutg, _डांड, йсан,
   {{0xe6160087,0xdb030212,0x387c00c4,0x337502b7}},	//   žišč, ssnö, _izvr_, ігар,
   {{0x388e025c,0x25ac0146,0x61e413ea,0x613202b6}},	// [7930] lər_, čilý_, gtil, _tæll,
   {{0x660d7848,0x3d02007f,0x25a901f9,0xdce30433}},	//   _irak, लयों_, _ital_, tonč,
   {{0xd0110241,0x61e4177f,0x273b023b,0xa295224a}},	//   بلا_, atil, _tënd_, _мані,
   {{0x660d7849,0x61e4784a,0xa6db003e,0xa92300c6}},	//   _krak, btil, miðs, ęžim,
   {{0x5fc5007d,0x388e01d4,0x7d014b2c,0x2b4d784b}},	//   _लटकल, hər_, _pals, viec_,
   {{0xc3010f71,0x2b4d00a5,0x78ad0335,0x6d58354e}},	//   _একটি_, wiec_, _đavo, gnva,
   {{0x7d01784c,0xeab100e3,0xcda900cd,0x26c90b18}},	//   _vals, وعة_, _چهره_, _odao_,
   {{0x388e01d4,0x6d5813e4,0x49c95a78,0x25a9784d}},	//   dər_, anva, алин_, _otal_,
   {{0x7d01784e,0x7999005c,0x7e7b0034,0x28d42c5f}},	//   _tals, _quww, _uzup, _दाखि,
   {{0x388e01d4,0x47c53164,0x57e900be,0xbd6b0284}},	//   fər_, обов, адом_, _србе_,
   {{0x660d784f,0x388e01d4,0x25a97850,0x2b4d0034}},	//   _arak, gər_, _atal_, piec_,
   {{0x61e47851,0x7bc3057e,0x7c3d00a7,0x224001f9}},	//   ytil, msnu, _əsrl, yzik_,
   {{0x683f0032,0xe57a7852,0x7ae9530e,0xba2b450f}},	//   _bádé, изм_, mfet, _حسام_,
   {{0x388e01d4,0x7ae93e44,0x6b5e01d3,0x25760537}},	//   bər_, lfet, mīga, mælk_,
   {{0x660d7853,0xe7b500e3,0x7bc36b55,0x6b5e01d3}},	//   _erak, _بمعد, nsnu, līga,
   {{0x660d5b87,0xe2970e3a,0x61e47854,0x4911000d}},	//   _frak, жат_, ttil, ताको_,
   {{0x6b5e01d3,0x91e30b21,0x660d7855,0x6d580653}},	// [7940] nīga, моте, _grak, ynva,
   {{0x2905067d,0x61e47856,0xb17b0149,0x7bc37857}},	//   ndla_, rtil, _spår, ksnu,
   {{0x660d7858,0xb4d6000f,0x22400103,0x071e5620}},	//   _zrak, हली_, szik_, _बचाव_,
   {{0x6b9a7859,0x64480220,0xdce0013c,0x00000000}},	//   _rutg, údiu, _rumı, --,
   {{0x388e0092,0xee8300ae,0xada30094,0xad660076}},	//   zər_, мышо, _neúč, ياته,
   {{0x613202b6,0x388e00a7,0x5ba61141,0x3f860072}},	//   _mælk, yər_, ориз, smou_,
   {{0x7ae94126,0x6d586676,0x7bc32bf6,0xf1c5004b}},	//   ffet, rnva, gsnu, rašų_,
   {{0x29050923,0xdb01016d,0xdddb026a,0x2fc7020a}},	//   edla_, _atlâ, _uyuş, ânge_,
   {{0xb9970761,0x00000000,0x00000000,0x00000000}},	//   овых_, --, --, --,
   {{0x6b9a009c,0x388e00a7,0x6120007b,0x660d5b92}},	//   _tutg, tər_, _pöly, _rrak,
   {{0x80d000c7,0x25a90e43,0x20050088,0xeb9a00c9}},	//   স্থ্, _stal_, _álit_, _тие_,
   {{0x7bd80435,0x388e00a7,0x00000000,0x00000000}},	//   muvu, rər_, --, --,
   {{0x95d80084,0x7bd81d84,0xa5075544,0x6b5e01d3}},	//   одят_, luvu, оявл, cīga,
   {{0x660d785a,0xdea201c2,0xfa7700ca,0x80d00033}},	//   _vrak, rkoƙ, _ועדת_, স্ত্,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc299061b,0x00000000,0x00000000,0x00000000}},	//   сках_, --, --, --,
   {{0x660d785b,0xa2dc2853,0x2be60033,0x6b8254a0}},	// [7950] _urak, _फार्, কিয়ে_, _mhog,
   {{0x7bd84970,0xc17800d6,0x00000000,0x00000000}},	//   kuvu, оїх_, --, --,
   {{0x28dd1efb,0x5f951807,0xbf730032,0xdb1802b6}},	//   _मासि, чиет, _apàṣ, msvæ,
   {{0x80dd00aa,0xdb1877d4,0x00000000,0x00000000}},	//   _पावे, lsvæ, --, --,
   {{0xdca51ac7,0xe1ff034f,0x4431785c,0x00000000}},	//   пали, _usó_, lyz_, --,
   {{0x6b820018,0x61f90555,0xceb902c6,0xdb1812dc}},	//   _ahog, ğalı, _moři_, nsvæ,
   {{0x9c7c02dd,0x6b820527,0x7bd8785d,0x2d870141}},	//   _obču, _bhog, guvu, rmne_,
   {{0x28dd0454,0x6b820091,0x3cf70179,0xba250231}},	//   _माहि, _chog, _एसके_, здик,
   {{0x7ae9785e,0x7c380477,0xdcfa01d3,0xdb183459}},	//   rfet, _čarš, _citē, ksvæ,
   {{0xa2cb0be4,0x7ae932a6,0x6b5e01d3,0xaaab0287}},	//   तृत्, sfet, rīga, _ट्रक,
   {{0x3ea0096d,0x6b820091,0x18694a4a,0x2c740037}},	//   žite_, _fhog, сани_, rúdú_,
   {{0x3d1904a9,0x290303f1,0x25760088,0x6b82581c}},	//   पावे_, žja_, mæli_, _ghog,
   {{0x613301e8,0x6b8949db,0xdb1801cd,0xa6e301cd}},	//   _kılı, mmeg, fsvæ, óðas,
   {{0xb4d6785f,0x6b897860,0xdb187861,0xdce302c6}},	//   हले_, lmeg, gsvæ, vlně,
   {{0x2936006e,0xf990450f,0x00000000,0x00000000}},	//   _מאסן_, _شبه_, --, --,
   {{0xe29a0231,0xf1c70cce,0x00000000,0x00000000}},	//   саа_, _लिखन, --, --,
   {{0x26c27862,0xa8230068,0x63bb02ef,0x00000000}},	// [7960] mako_, _رکھن, ćuna, --,
   {{0x26c27863,0x6b89042c,0x7bd80027,0xa06a0077}},	//   lako_, hmeg, yuvu, база_,
   {{0x80dd00b6,0x273b0216,0x4fea120a,0x26c20634}},	//   _पारे, _hëna_, смен_, oako_,
   {{0x26c27864,0x6b890126,0xdce3030b,0x6132003e}},	//   nako_, jmeg, plně, _mæli,
   {{0xddcb01e8,0x527500ae,0xdce8003d,0x26c20634}},	//   ğişi, _журу, _jidħ, iako_,
   {{0x6b827865,0x7bd87866,0x26c27867,0xdb010428}},	//   _shog, tuvu, hako_, _atlà,
   {{0x06c700c7,0x00000000,0x00000000,0x00000000}},	//   ষ্টি, --, --, --,
   {{0xd90d00cd,0x26c27868,0xd00f0103,0x27220094}},	//   یین_, jako_, _حلف_, _tóny_,
   {{0xa3d605d4,0x26c27869,0xadc30019,0x273b023b}},	//   _समझ_, dako_, _trạn, _nëna_,
   {{0xd7fa11d9,0x273400fe,0x69cf124d,0x885800ae}},	//   бум_, _hãnh_, ácea, жиос_,
   {{0x6b826b75,0x26c2786a,0x28dd055c,0xfbd233e7}},	//   _thog, fako_, _मारि, _ستا_,
   {{0x6c7b00c1,0x26c2786b,0xa3d60096,0xdb0901c3}},	//   _פראד, gako_, _समज_, _وزنه_,
   {{0x613301e8,0x27340023,0x00000000,0x00000000}},	//   _yılı, _mãnh_, --, --,
   {{0x27340019,0x26c2786c,0x8afd02c6,0xf2d40033}},	//   _lãnh_, aako_, voři, হ্মণ,
   {{0x0fd70081,0xdb180088,0x18970037,0x387a0103}},	//   _সন্ধ, rsvæ, _عضوة_, _ápr_,
   {{0xb7db00ca,0x44312647,0x26c20062,0x00000000}},	//   _הקהי, ryz_, cako_, --,
   {{0x69bf0789,0xd0470092,0xdb1802c3,0x00000000}},	// [7970] लीपी, əməs, msvä, --,
   {{0x55bc0327,0xa25b0206,0xdb1802c3,0x68fa702b}},	//   _המזו, _odôv, lsvä, netd,
   {{0x67210bd9,0x2fc700d1,0x389b00c1,0xe3a5015a}},	//   यापक_, éng_, ציאנ, _تشخی,
   {{0xdb180149,0x00000000,0x00000000,0x00000000}},	//   nsvä, --, --, --,
   {{0x28dd0336,0x2fc70023,0x1eea00d1,0x7bc84f39}},	//   _मालि, ũng_, تونی_, _avdu,
   {{0x25de009d,0x26c2786d,0x7ae21d32,0x613300a7}},	//   कंती_, zako_, _acot, _qılı,
   {{0xdb014c20,0xbbe80080,0x26c20517,0xdb180212}},	//   _atlá, كريم_, yako_, ksvä,
   {{0xeeb9008f,0x6b89024a,0x26c20634,0x00000000}},	//   _флаш_, umeg, xako_, --,
   {{0x26c20f4c,0x6b89786e,0xdb180212,0x00000000}},	//   vako_, rmeg, dsvä, --,
   {{0x26c25c7f,0x9f410037,0x3ebf042c,0x613201cd}},	//   wako_, ithí_, _heut_, _pæli,
   {{0x26c2786f,0xfbd003ed,0x00000000,0x00000000}},	//   tako_, _متن_, --, --,
   {{0x201108a9,0x2d9f00bc,0xdb1802c3,0x7ae200da}},	//   _mrzi_, _kuue_, gsvä, _gcot,
   {{0x26c27870,0x68fa1a4a,0x7afb0350,0x7bd200e8}},	//   rako_, betd, meut, ījuš,
   {{0x26c27871,0x3ebf007e,0x85300d2a,0x7afb7872}},	//   sako_, _leut_, _kuɗi, leut,
   {{0x26c27873,0x212a0049,0xfc3f00b6,0x64a300c5}},	//   pako_, _robh_, _říj_, таса,
   {{0x29077874,0x7afb7875,0xc7d600a1,0xae1d167f}},	//   _hana_, neut, _חוקי_, पमान_,
   {{0x29077876,0x20117877,0x2d8500ec,0x273400fe}},	// [7980] _kana_, _arzi_, _ohle_, _rãnh_,
   {{0x66047878,0x29077879,0x7afb0084,0x2011005f}},	//   _isik, _jana_, heut, _brzi_,
   {{0x2907787a,0x351b193b,0x251b0130,0xe29a2b79}},	//   _mana_, _ווינ, _וויא, _ман_,
   {{0x2907787b,0x201108a9,0x25a00498,0xdb0a0212}},	//   _lana_, _drzi_, _kuil_, lsfö,
   {{0x26c00396,0x7afb787c,0x25a0025a,0x290700d3}},	//   _meio_, deut, _juil_, _oana_,
   {{0x2907787d,0x66040051,0xdb0a0149,0x7ae24f4e}},	//   _nana_, _msik, nsfö, _scot,
   {{0x69cf00b6,0x68fa393c,0x25a0022b,0x670e09a1}},	//   ácen, vetd, _luil_, ियाक_,
   {{0x2907787e,0x69bf0034,0x63ba0031,0x3ebf02ac}},	//   _aana_, लीभी, átny, _geut_,
   {{0x2907787f,0x64580138,0x7c3d00a7,0xdb0a0212}},	//   _bana_, _žvil, _əsri, ksfö,
   {{0x0d8300d3,0x2d8501ec,0xdb18298b,0x81b30033}},	//   _алун, _ghle_, dsvå, _টিম_,
   {{0x290703ce,0x66047880,0x7d1a7881,0xdb0a0149}},	//   _dana_, _asik, _ints, dsfö,
   {{0x81c400c7,0xf09300ca,0x25a00441,0x274b004d}},	//   _এমন_, כנת_, _buil_, ічно_,
   {{0x25a07882,0xceb300a1,0xdb180212,0x29077883}},	//   _cuil_, כיר_, rsvä, _fana_,
   {{0x25a001f7,0xf10d1115,0xdb0a0212,0xdb180212}},	//   _duil_, _सफेद_, gsfö, ssvä,
   {{0x66047884,0x7d080f04,0x26c07885,0x7af50103}},	//   _esik, _mads, _feio_, őzte,
   {{0x290730db,0x25a00527,0x26c001ff,0x2b17007f}},	//   _zana_, _fuil_, _geio_, थाएँ_,
   {{0x29077886,0x7d1a0db8,0x05bb01f9,0x61d9007b}},	// [7990] _yana_, _onts, _بدعت_, ямая_,
   {{0x7d0804ad,0x29077887,0x2011015c,0xda080023}},	//   _nads, _xana_, _przi_, _mỏ_,
   {{0x3ebf04ea,0x395e7888,0x25a001cb,0x00000000}},	//   _peut_, ints_, _zuil_, --,
   {{0xf1a71362,0x7d1a7889,0x69cf0980,0x853001c2}},	//   _कंपन, _ants, _दिली, _ruɗi,
   {{0x3ebf025a,0x31a403a3,0x629d019c,0x2b4f020a}},	//   _veut_, _göz_, _igso, _rmgc_,
   {{0xdd910018,0xe6dc02c6,0xa2160142,0x00000000}},	//   ھوں_, _मञ्ज, _אַלס_, --,
   {{0x29071114,0x60c5048e,0x7afb0084,0xfaa515c2}},	//   _rana_, mahm, teut, найо,
   {{0x2907788a,0x7d1a788b,0x395e788c,0xda080028}},	//   _sana_, _ents, ents_, _bỏ_,
   {{0x2907788d,0xda0800de,0xc9550ab3,0x7afb788e}},	//   _pana_, _cỏ_, етны, reut,
   {{0x60c502e2,0x7d0800d9,0x25a01044,0x26c00131}},	//   nahm, _gads, _ruil_, _seio_,
   {{0x6d4310f0,0x2907788f,0x66e65be9,0x799805aa}},	//   mhna, _vana_, нона, _divw,
   {{0x29077890,0x395e36e7,0x672d00ae,0xf09200ca}},	//   _wana_, ants_, _coaj, טני_,
   {{0x29071114,0xf65216c4,0x26c0001f,0xdb0a0149}},	//   _tana_, ائج_, _veio_, tsfö,
   {{0x60c50808,0x25a004e2,0xdb18298b,0x29070350}},	//   jahm, _vuil_, rsvå, _uana_,
   {{0x31a407d1,0x60c53094,0xd8d60266,0xe73a0293}},	//   _söz_, dahm, _טוסט_, _нек_,
   {{0x6604630c,0x232719e8,0x41aa0459,0xdb0a0212}},	//   _tsik, носи_, зван_, ssfö,
   {{0x66047891,0x64a67892,0xe3631e61,0xa59627c9}},	// [79a0] _usik, _папа, укти, _прощ,
   {{0x8cdb0789,0x7cf3564a,0x69c900c2,0x02031402}},	//   _नागो, nırı, isee, ызун,
   {{0x6d437893,0x7d087894,0x6f095842,0xa3d700b7}},	//   dhna, _rads, _baec, _सिय_,
   {{0x69c902fd,0x81cf0033,0x888c006e,0x7d087895}},	//   ksee, _শহর_, קראַ, _sads,
   {{0x6f090113,0x257602b6,0x7cf3026a,0x613202b6}},	//   _daec, bælt_, kırı, _bælt,
   {{0xafe633ed,0xdd8f006f,0x6d430a1b,0xa3d40034}},	//   _погл, مون_, ghna, _हटा_,
   {{0x01630508,0x69c90084,0x69cb07ee,0x7ac62a61}},	//   _скро, esee, _avge, нспе,
   {{0xff26008f,0x9f4a007b,0x613204c8,0x00000000}},	//   _ямбо, ömän_, _vælu, --,
   {{0x853003e3,0x6b9903a8,0x69c902ac,0x00000000}},	//   _huɗu, _diwg, gsee, --,
   {{0x6d437896,0xda0800de,0x395e00ca,0x26144f3a}},	//   chna, _vỏ_, unts_, दिनी_,
   {{0xdd8f006f,0x6bd60dd0,0x236000a5,0x69c9007b}},	//   _اول_, _ستار, knij_, asee,
   {{0xda0800de,0x2a66006c,0x69c92454,0x4a460d9b}},	//   _tỏ_, _txob_, bsee, _пнев,
   {{0xe1ff0072,0x684600fc,0x56940208,0x00000000}},	//   _axón_, _bédé, лают, --,
   {{0x68463d66,0x69c600c6,0x00000000,0x00000000}},	//   _cédé, škes, --, --,
   {{0x9982013f,0xe6df0129,0x853001c2,0x684601dc}},	//   škų_, _agụụ_, _nuɗu, _dédé,
   {{0x23607897,0x7c250364,0x6b9c002b,0xa87b0327}},	//   gnij_, ähri, _érgu, _מאור,
   {{0x68460257,0x290c0188,0x291c0383,0x00000000}},	// [79b0] _fédé, odda_, _knva_, --,
   {{0x6f1b01b9,0x290c7898,0x68460065,0x69d80096}},	//   _snuc, ndda_, _gédé, _मिनी,
   {{0xb4dd1376,0xf3cb0076,0x00000000,0x00000000}},	//   डली_, _عبده_, --, --,
   {{0xe522030b,0x69c9008c,0x7cf304a8,0x7bca32e1}},	//   माथि_, ysee, zırı, dsfu,
   {{0x1d09193d,0xdd9b0084,0x2284013d,0x6d430037}},	//   дели_, чше_, _бург, thna,
   {{0x61ed2085,0x063800c1,0x5ff5282a,0xf1bf0139}},	//   mtal, ענגט_, _изгу, _iwá_,
   {{0xdfd80465,0x61ed7899,0x6f090da7,0x613202b6}},	//   _път_, ltal, _taec, _vælt,
   {{0x69c90f06,0x6f1b00cc,0x5f940291,0x291c010a}},	//   tsee, _unuc, _бист, _anva_,
   {{0x7cf308bb,0x9c820031,0xa25b0031,0x2249789a}},	//   tırı, ľčan, _zdôr, nzak_,
   {{0x69c9789b,0x61ed789c,0x2ba904f1,0xe7a93519}},	//   rsee, ital, _चंपा, мвол_,
   {{0x6d41789d,0xf7461b10,0x61ed789e,0x7cf30555}},	//   _illa, вено, htal, rırı,
   {{0x61ed19a8,0x7e7b0085,0x291c0361,0x48e500c3}},	//   ktal, _kyup, _enva_, ज्जो_,
   {{0xcb360054,0x69c6030b,0x61ed789f,0xdb010052}},	//   _שאני_, šker, jtal, _lulë,
   {{0xa3bf0034,0x98a200a9,0x18a201b6,0x00000000}},	//   ुओं_, _кише, _кашм, --,
   {{0x61ed78a0,0x03a643c7,0x00000000,0x00000000}},	//   etal, тибо, --, --,
   {{0x61ed78a1,0xdb010149,0xe36311a0,0x22490381}},	//   ftal, _utlä, акси, fzak_,
   {{0x61ed78a2,0x6d4178a3,0x23603ee5,0x2249029a}},	// [79c0] gtal, _olla, rnij_, gzak_,
   {{0xe0d70291,0x236d0095,0xf53f02c3,0x00000000}},	//   кву_, čeja_, spår_, --,
   {{0x838a02ec,0x40964487,0x3dcd05aa,0xb4be034c}},	//   _обов_, трат, _avew_, आरी_,
   {{0xa3d7030b,0xc29412eb,0x443849dc,0x3ead033c}},	//   _सित_, _میزب, myr_, _cfet_,
   {{0x290c78a4,0xdee304b3,0x26d200f9,0x4f6502a3}},	//   ydda_, рочи, _mdyo_, دالف,
   {{0x628678a5,0x00864ead,0x3ead0154,0x6fb60037}},	//   _izko, _алго, _efet_, _لمسا,
   {{0x6d410113,0xd47a006e,0x7e7b0113,0xd00700ae}},	//   _dlla, ואַל, _eyup, _иере_,
   {{0x6d412e6c,0xc6bd0033,0x7bca0973,0x26d218fe}},	//   _ella, _আঞ্চ, rsfu, _ndyo_,
   {{0xada61456,0x44380150,0x7bca00ca,0x6da6328d}},	//   _разл, hyr_, ssfu, _риза,
   {{0x2cac01c2,0x443878a6,0x5fc600c3,0xdb010139}},	//   _ufdd_, kyr_, _लबाल, _lulè,
   {{0x6d5878a7,0x91ae0081,0x61ed0103,0x31370327}},	//   miva, টওয়্, ztal, דריך_,
   {{0x290a1cbc,0x443878a8,0x61ed78a9,0xbb44007b}},	//   žba_, dyr_, ytal, äädä,
   {{0x26d20517,0x9f47020d,0xe7e410e9,0x61ed78aa}},	//   _ddyo_, îné_, _कमवा_, xtal,
   {{0xb4dd2183,0x61ed3135,0x8e200ed7,0x44382405}},	//   डले_, vtal, лiк_, fyr_,
   {{0xd82f00ae,0x628601e9,0x68380032,0x1c0210e9}},	//   _тэ_, _azko, _dúdú, लबिल_,
   {{0x61ed78ab,0x224902a7,0x6d5878ac,0x15e30789}},	//   ttal, tzak_, hiva, कंदर_,
   {{0x43944c88,0xdb011f60,0x66160052,0x20c7007b}},	// [79d0] ратс, _utlå, _gryk, всег,
   {{0x61ed78ad,0x6d5803ce,0x4438038c,0x68380065}},	//   rtal, jiva, byr_, _gúdú,
   {{0x667400bf,0x628601e9,0xaeb00134,0xa2830103}},	//   _مدیر, _ezko, _ịnọs, _چیزو,
   {{0x61ed78ae,0x673d00d6,0x6d41023b,0x00000000}},	//   ptal, nksj, _slla, --,
   {{0x22da0327,0xdd2c0138,0x6d410052,0x926b0b1b}},	//   _אחרא, _dėžu, _plla, _црна_,
   {{0x6d5878af,0x00000000,0x00000000,0x00000000}},	//   giva, --, --, --,
   {{0x764b0018,0x6d41023b,0xbbf50037,0x9f58022b}},	//   _ügyf, _vlla, استث, _oprè_,
   {{0x7e690062,0x673d0381,0x00000000,0x00000000}},	//   _txep, jksj, --, --,
   {{0x6d5878b0,0x2bae007f,0x98a52cc3,0x00000000}},	//   biva, _ręce_, липе, --,
   {{0x6d5803ce,0x6d4178b1,0x9f5806a3,0xc27c00ca}},	//   civa, _ulla, _aprè_, ורחי,
   {{0x25b278b2,0x6ec707d5,0x00000000,0x00000000}},	//   _styl_, ारपु, --, --,
   {{0xe7e40251,0x6d460138,0x2ab800d3,0x7c25042c}},	//   _कमरा_, _įkai, _алць_, ähru,
   {{0xcb120054,0x443802e0,0x7f3a00c1,0x6abb0239}},	//   _ללא_, wyr_, גערו, mbuf,
   {{0x443878b3,0xe5a300ae,0x394401b3,0xa25b0231}},	//   tyr_, сири, _кніг, _peôn,
   {{0x62860067,0x04432a6a,0x443e78b4,0x63a50113}},	//   _szko, берн, át_, _cuhn,
   {{0x6d5803ce,0x66161484,0x31780a7f,0xd25207e8}},	//   ziva, _tryk, _skrz_, منز_,
   {{0xdb1801df,0xdb0100b3,0x443807ee,0x267a002d}},	// [79e0] rsvø, _culé, syr_, _яскэ_,
   {{0x6d5878b5,0x88d50033,0x11d70037,0x44380231}},	//   xiva, ত্রক, اولة_, pyr_,
   {{0x6d5878b6,0xcae30034,0xdfcf0037,0x00000000}},	//   viva, _गांड_, كيل_, --,
   {{0x52760450,0x69db78b7,0x59d40285,0xada60565}},	//   _бугу, krue, _दिलर, гадл,
   {{0xee3a04d9,0x628600e8,0x539b00ca,0xed5a5b6c}},	//   энд_, _uzko, _ריכו, нод_,
   {{0xa0a33549,0x6b8b010a,0xe7e402f0,0x00000000}},	//   _гард, _ahgg, _कमला_, --,
   {{0x6d5878b8,0x00000000,0x00000000,0x00000000}},	//   riva, --, --, --,
   {{0x66060449,0x201878b9,0x00000000,0x00000000}},	//   kwkk, _irri_, --, --,
   {{0x0d860805,0x9e6678ba,0x6d582a3c,0x69db023b}},	//   _блан, _свад, piva, grue,
   {{0x4dfb006e,0x6abb010a,0x090602e1,0x00000000}},	//   _אפמא, abuf, учим, --,
   {{0x9f582f8a,0x645a3070,0x657578bb,0x00000000}},	//   _apré_, útil, vozh, --,
   {{0xfaa622f9,0x2ee60313,0x63a578bc,0x69db01ce}},	//   _садо, ngof_, _ruhn, brue,
   {{0x66e60490,0x69db24f9,0x28dd0285,0x2d9e5244}},	//   _कारक_, crue, _माचि, _kite_,
   {{0xe89421f4,0x201878bd,0x23790063,0x6f020076}},	//   _каль, _orri_, _sksj_, heoc,
   {{0xa3e40285,0x7a480029,0x27f7025b,0x2d9e78be}},	//   _नमः_, sūtī, čená_, _mite_,
   {{0x2d9e78bf,0x290e0682,0xa2b53c0f,0x236d0087}},	//   _lite_, _hafa_, рбач, čejo_,
   {{0x290e1114,0xc2993b4f,0x1dc63245,0x26cb028d}},	// [79f0] _kafa_, тках_, रीमत, maco_,
   {{0xf1da0caf,0x26cb0143,0x290e78c0,0xa3ce0285}},	//   यंजन, laco_, _jafa_, _रिच_,
   {{0xe52200b7,0x6b5e00e8,0x00000000,0x00000000}},	//   मारि_, līgu, --, --,
   {{0x7ff40080,0x273b023b,0x2d9e0441,0x290e78c1}},	//   إسلا, _bëni_, _aite_, _lafa_,
   {{0x6cc516c0,0x398b038c,0x201878c2,0x2d9e78c3}},	//   айла, løse_, _erri_, _bite_,
   {{0xabd52d16,0x200a0113,0x32db0065,0x11da00ca}},	//   ациј, _fsbi_, _fàyà_, _בחשב,
   {{0x2d9e78c4,0x2d990113,0x00000000,0x00000000}},	//   _dite_, _èsem_, --, --,
   {{0xb33b0b88,0x2d9e78c5,0x00000000,0x00000000}},	//   _hiçb, _eite_, --, --,
   {{0x290e78c6,0x2d9e78c7,0x26cb078e,0x00000000}},	//   _bafa_, _fite_, daco_, --,
   {{0x69db78c8,0x2d9e78c9,0x290e022b,0x589500d3}},	//   rrue, _gite_, _cafa_, ишну,
   {{0x8c671ac7,0x290e0d2a,0x1869282a,0xe7660c79}},	//   _стад, _dafa_, тани_, ивоп,
   {{0x7d0378ca,0x61fd40df,0x3a7578cb,0x2d9e78cc}},	//   lens, _opsl, _клер, _zite_,
   {{0x290e0f20,0x7d030a9f,0x80d00081,0xb5221e93}},	//   _fafa_, oens, স্ট্, मालय_,
   {{0x7d0378cd,0x60c700b6,0x290e78ce,0x00000000}},	//   nens, _nejm, _gafa_, --,
   {{0x321902e7,0xa87900c1,0x987900c1,0x69c2029a}},	//   _arsy_, _באַר, _באַט, _zwoe,
   {{0xa3d708d4,0x60d50063,0x26cb0131,0x200a0085}},	//   _सिर_, _adzm, caco_, _rsbi_,
   {{0xdcfa030b,0x60c7023b,0xe29a016d,0xb77b00ca}},	// [7a00] _chtě, _bejm, таа_, _שאפש,
   {{0xa63b00ca,0x20180090,0x00000000,0x00000000}},	//   _סגיר, _prri_, --, --,
   {{0x7d0378cf,0x2d9e78d0,0x35dc009f,0x60c778d1}},	//   dens, _rite_, _बिड़, _dejm,
   {{0x91e6247a,0x2d9e67cd,0xee3a02e1,0xd5a500c3}},	//   _коме, _site_, кне_, _गूँज,
   {{0x7d03411b,0x3f8d78d2,0xcbb20033,0x00000000}},	//   fens, _dheu_, _ঘটেছ, --,
   {{0x7d030dbc,0x764b0103,0x2ae3030b,0x60c70095}},	//   gens, _ügye, _गाउँ_, _gejm,
   {{0x2d9e78d3,0x9b587816,0xcc240081,0xe4ee1d72}},	//   _vite_, ликт_, বন্ধ_, _जानि_,
   {{0xcfb70054,0x290e78d4,0x60c7030b,0x2d9e4ed7}},	//   _כללי_, _safa_, _zejm, _wite_,
   {{0x7d0378d5,0x2d9e78d6,0xd5a50251,0x61e478d7}},	//   bens, _tite_, _गूंज, nuil,
   {{0x7d031d22,0x2d9e00d3,0xa3d70ec3,0x290e0216}},	//   cens, _uite_, _सिल_, _qafa_,
   {{0xb8ce0b7f,0x61e478d8,0xc1740022,0xe7871143}},	//   _कल_, huil, guɗi_, иумо,
   {{0x290e413e,0x644e0e94,0x61e478d9,0x00000000}},	//   _wafa_, dzbi, kuil, --,
   {{0x26cb78da,0x0a16015a,0x2f97006e,0x00000000}},	//   raco_, _خوشح, יכטן_, --,
   {{0x97a60e45,0x26cb016d,0x6b5e00e8,0x3857001c}},	//   _крил, saco_, rīgu, اشید_,
   {{0xf2c710f7,0x93970037,0x26cb0231,0xf79500ae}},	//   исан, لجرا, paco_, _лакэ,
   {{0x442d02e6,0x7d0378db,0x60c778dc,0x389b00ca}},	//   će_, zens, _sejm, _ביונ,
   {{0x443f0029,0x61e472ec,0x30a71a0c,0xa0a700d3}},	// [7a10] ņu_, guil, арев, ашел,
   {{0x2b460990,0x660d78dd,0x7d0378de,0x867c00ca}},	//   _lloc_, _isak, xens, _ברחו,
   {{0x7d0378df,0xe819009f,0xc6780100,0x764b01f9}},	//   vens, धिया_, _محیط_, _ügyb,
   {{0x7d0303de,0xdb01004d,0xef190090,0x321900d8}},	//   wens, _utlø, _okże_, _trsy_,
   {{0x25a92664,0x60c778e0,0x61e43dc2,0x88de0081}},	//   _jual_, _tejm, cuil, ব্যক,
   {{0x6d4a78e1,0x25a90710,0x3209014b,0x660d78e2}},	//   ghfa, _mual_, mway_, _msak,
   {{0x2b4678e3,0x320978e4,0x3f8d78e5,0x81e90033}},	//   _bloc_, lway_, _theu_, _মনি_,
   {{0x660d78e6,0x1ee70421,0x99840138,0x3869007e}},	//   _osak, _خوری_, kymų_, _ćar_,
   {{0x7d03436f,0x660d0735,0x00000000,0x00000000}},	//   pens, _nsak, --, --,
   {{0x5d8500e3,0x39452d7b,0x6d4a78e7,0x7d540ab3}},	//   _الطل, сног, chfa, _двух,
   {{0xe73a313c,0x660d0372,0x2b465a40,0x61e40239}},	//   ген_, _asak, _floc_, zuil,
   {{0x32092375,0x59c4030b,0x25a90804,0x26c90072}},	//   kway_, लीहर, _bual_, _ceao_,
   {{0x25a914e2,0x9b740080,0x3a290092,0xab7400e3}},	//   _cual_, _بالص, _çap_, _بالإ,
   {{0x61e40084,0x9f58028d,0x32090133,0x98a500e5}},	//   vuil, _aprì_, dway_, _уике,
   {{0x2905063d,0x320922d4,0x394200d9,0xe1ff0032}},	//   mela_, eway_, īkst_, _apó_,
   {{0x29050e7a,0x3ea00106,0x61e4007b,0x394201d3}},	//   lela_, žiti_, tuil, ūkst_,
   {{0x320978e8,0x67240095,0xa3e40e4c,0x25a978e9}},	// [7a20] gway_, _inij, _नमक_, _gual_,
   {{0x290578ea,0xe2970ad8,0x61e478eb,0x40965e04}},	//   nela_, сау_, ruil, брет,
   {{0x61e42d12,0x320960ba,0x67247588,0x63610174}},	//   suil, away_, _knij, ịnaa,
   {{0x29050201,0x80c6030b,0x487a006e,0x657e00fe}},	//   hela_, िरहे, אטעס, _hkph,
   {{0x61e478ec,0x2905067d,0x6d4a1066,0x7ae978ed}},	//   quil, kela_, thfa, dget,
   {{0x29050480,0x8bc610bb,0x2b4601ec,0x00000000}},	//   jela_, бсид, _sloc_, --,
   {{0x7ae90364,0x602678ee,0x2b4623a5,0xf2df03a8}},	//   fget, _удва, _ploc_, _mlân_,
   {{0x1de000b7,0x7ae90d63,0x6d4a78ef,0x4fd72252}},	//   _निपत, gget, shfa, _לולב_,
   {{0x290578f0,0xdb010072,0x00000000,0x00000000}},	//   fela_, _gulí, --, --,
   {{0x290578f1,0x79581031,0x672478f2,0xc9260033}},	//   gela_, риор_, _anij, যস্ত_,
   {{0x6c860080,0x6d5a0092,0x25a90092,0x3cf10094}},	//   _الام, _imta, _sual_, žový_,
   {{0x09e61147,0xa09b006e,0x99840138,0x320978f3}},	//   _годн, טייט, tymų_, yway_,
   {{0x25a978f4,0x290578f5,0xa3cb00a5,0x25a1075b}},	//   _qual_, bela_, रीन_, _pihl_,
   {{0x29051389,0x660d0b27,0x80de00c7,0x00000000}},	//   cela_, _vsak, ন্ত্, --,
   {{0x395e6434,0x182901f9,0x00000000,0x00000000}},	//   mits_, _نقوی_, --, --,
   {{0x660d0a75,0x672404e9,0x25a90167,0x322b04a1}},	//   _tsak, _gnij, _tual_, лізм_,
   {{0x6d4800fb,0x660d78f6,0x6d5a0c2e,0xe6b502d5}},	// [7a30] _olda, _usak, _omta, ंडीज,
   {{0x21030336,0x32096cb2,0xe00402d5,0xf2df0178}},	//   रजेश_, rway_, रबंद_, _glân_,
   {{0xe4ee2373,0x3209005c,0x3f15036a,0xb4d50096}},	//   _जाति_, sway_, ждес, हणी_,
   {{0x6d4803f3,0x290578f7,0xc7b300c1,0x3cfb030b}},	//   _alda, zela_, לבע_, ल्ने_,
   {{0x290578f8,0x395e78f9,0x795f0065,0x00000000}},	//   yela_, kits_, _jáwè, --,
   {{0xfe702b38,0x527a00ca,0x290578fa,0x25de0285}},	//   ردن_, _כנרא, xela_, कूटी_,
   {{0x290578fb,0x395e78fc,0x7ae93155,0x2369020a}},	//   vela_, dits_, tget, onaj_,
   {{0x80de00c7,0xe9d93967,0x6d4878fd,0x290578fe}},	//   ন্দ্, аки_, _elda, wela_,
   {{0xc9a624d3,0x7f4902a1,0x395e00ca,0x6d48010a}},	//   овые_, _ileq, fits_, _flda,
   {{0x672478ff,0x395e7900,0x7ae9240e,0xe8f601ef}},	//   _snij, gits_, sget, оль_,
   {{0xa3cb110f,0x29057901,0x1cb80678,0xc6890266}},	//   रीम_, rela_, _طالب_, _סא_,
   {{0x29057902,0xbf8700de,0x59f900d3,0x7f4900bd}},	//   sela_, _điền_, _ведя_, _jleq,
   {{0xaa58193d,0x395e0fe4,0x00000000,0x00000000}},	//   _лицу_, bits_, --, --,
   {{0x395e7903,0x7e9a0089,0x03a600b4,0x6d437904}},	//   cits_, יסרו, живо, nkna,
   {{0x64a3596a,0x31790134,0x6d437905,0x00000000}},	//   дара, ụọla_, ikna, --,
   {{0x23697906,0x96ba0396,0x2b5f044c,0x00000000}},	//   gnaj_, _туку_, niuc_, --,
   {{0xa3cb007f,0x6d435255,0x00000000,0x00000000}},	// [7a40] रीब_, kkna, --, --,
   {{0x6d4356a2,0x601a0f32,0x00000000,0x00000000}},	//   jkna, ицер_, --, --,
   {{0x600a2c4c,0x00000000,0x00000000,0x00000000}},	//   рнем_, --, --, --,
   {{0x1e8600c9,0x4eba0081,0xdfcf0568,0x63b31054}},	//   олем, ুল্ল, ئين_, žené,
   {{0xdd8f001c,0x00000000,0x00000000,0x00000000}},	//   چون_, --, --, --,
   {{0xdd8f006f,0x7a400065,0x00000000,0x00000000}},	//   نون_, _látú, --, --,
   {{0x22400018,0x395e7907,0xfbcf0190,0x7f492df7}},	//   lyik_, vits_, نتي_, _fleq,
   {{0x3ce0026a,0x657c0124,0x5a34075f,0x98a500c6}},	//   şiv_, horh, знит, oklė_,
   {{0x395e7908,0x6f1d255c,0x22407909,0x61f60034}},	//   tits_, _ósca, nyik_, ntyl,
   {{0x3f86790a,0x6d5a790b,0xdb01015e,0xdb080143}},	//   llou_, _umta, _eulà, _mudé,
   {{0x2138080e,0x395e790c,0x00000000,0x00000000}},	//   _morh_, rits_, --, --,
   {{0x2b5f00ae,0x395e0fe4,0x16b50285,0xa2bc05d6}},	//   ciuc_, sits_, ंडेब, षुम्,
   {{0xfd57026e,0x657c038c,0x61f6790d,0x236919ad}},	//   _adaṣ, forh, jtyl, vnaj_,
   {{0x236900a5,0xb4d5009d,0x22402375,0xdb080154}},	//   wnaj_, हणे_, dyik_, _sudè,
   {{0x3f86790e,0x00000000,0x00000000,0x00000000}},	//   klou_, --, --, --,
   {{0x27f30206,0x00000000,0x00000000,0x00000000}},	//   žaní_, --, --, --,
   {{0x23690146,0x657c00d7,0x22400103,0x32551361}},	// [7a50] rnaj_, borh, gyik_, чвар,
   {{0x34951e54,0xdb08037a,0x00000000,0x00000000}},	//   _напр, _dudé, --, --,
   {{0x2fc7001c,0x2138080e,0x7f490052,0x98b8007f}},	//   èng_, _dorh_, _pleq, órę_,
   {{0xbf58004d,0xa3cb00a4,0x00000000,0x00000000}},	//   орії_, रीण_, --, --,
   {{0x7bc802ad,0xdd140181,0x2252007f,0x00000000}},	//   _awdu, _dĺžk, czyk_, --,
   {{0xf1c4007f,0x00000000,0x00000000,0x00000000}},	//   _लौटन, --, --, --,
   {{0x6d431c82,0x26c200a5,0x3f8647ce,0xbc1900c6}},	//   rkna, ybko_, blou_, сілі_,
   {{0x3f8605fe,0x05dc049d,0x6d430324,0xdb080113}},	//   clou_, _बिलब, skna, _yudé,
   {{0xa3cb0efd,0x5d552cde,0x2b5f020a,0x00000000}},	//   रीत_, _екат, riuc_, --,
   {{0xa3ab00aa,0x00000000,0x00000000,0x00000000}},	//   खदा_, --, --, --,
   {{0x657c790f,0xb33b014b,0x26c20634,0x00000000}},	//   vorh, _niço, tbko_, --,
   {{0xe4ee09a1,0xdb01033c,0x00000000,0x00000000}},	//   _जाहि_, _fulá, --, --,
   {{0x657c7910,0xf1a70251,0x7afb7911,0xdb010094}},	//   torh, _कंगन, mfut, _gulá,
   {{0xa3d70e4c,0x00000000,0x00000000,0x00000000}},	//   _सिख_, --, --, --,
   {{0xf746105e,0x18660b2c,0xe73a3898,0xdb0200b3}},	//   _неко, _наши_, _гей_, _bioè,
   {{0x21f400aa,0x7afb7912,0x52aa00e5,0xdb080231}},	//   täh_, nfut, свам_, _pudé,
   {{0xe2977913,0x7afb0350,0x00000000,0x00000000}},	// [7a60] зат_, ifut, --, --,
   {{0xf8bd121d,0x66047914,0x40962fd2,0x00000000}},	//   ोरिय, _ipik, прет, --,
   {{0x225200a5,0x316602ef,0x2d870031,0x26140442}},	//   szyk_, đoz_, dlne_, दिकी_,
   {{0x2d877915,0x00000000,0x00000000,0x00000000}},	//   elne_, --, --, --,
   {{0x539b00f5,0xbb44007b,0x3eab00d8,0x00000000}},	//   _ליטו, äämä, _šitá_, --,
   {{0xf98700fb,0x66042e74,0x261d0096,0x3f867916}},	//   _سب_, _mpik, मिती_, slou_,
   {{0x69dd0038,0x200c00e5,0x60260fe9,0xa2b30eeb}},	//   ásen, _èdi_, _эдва, _अलम्,
   {{0x2d877917,0xf914007f,0x00000000,0x00000000}},	//   alne_, _थोड़ा_, --, --,
   {{0x644301e8,0xdcf87918,0xa9230206,0x05ac007f}},	//   _üniv, lovč, _šľap, _टूलब,
   {{0x63a60572,0x753a01bf,0x62867919,0x61e4791a}},	//   _likn, ötzl, _myko, iril,
   {{0x660420fa,0xdcf876f0,0x62866325,0x61e4791b}},	//   _apik, novč, _lyko, hril,
   {{0x98a700b6,0xa5f900c2,0x63a66da8,0x7d0a4f39}},	//   _koně_, оему_, _nikn, lefs,
   {{0x5fce1757,0x628605e8,0xdcf800e7,0x6b8204e9}},	//   _हौसल, _nyko, hovč, _ikog,
   {{0x61e4791c,0xdcf8080e,0x25a5003e,0xdbda0139}},	//   dril, kovč, öll_, _làíg,
   {{0x6604791d,0xd4040a01,0x61e46757,0x97ad026a}},	//   _epik, няти, eril, üştü,
   {{0x6286057a,0x53341219,0x7d0a0313,0xdb0200fc}},	//   _byko, нест, hefs, _bioé,
   {{0xd7f800d3,0x63a61d06,0xdb020113,0xb1842347}},	// [7a70] ltă_, _dikn, _cioé, _šťav,
   {{0x69c4003d,0x69c000ca,0x66ed0336,0x6b4e0065}},	//   _ħiel, ipme, _झाँक_, _jùgb,
   {{0xd7f80012,0x61e4791e,0x60ce037a,0x661d17d2}},	//   ntă_, aril, _debm, lvsk,
   {{0xd7f800ae,0x6b820027,0x2bb500e8,0xa2bc13cc}},	//   ită_, _nkog, _nāca_, षुद्,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc21200a1,0x61e20087,0x6b820065,0x236d0095}},	//   _שהם_, šolc, _akog, čeju_,
   {{0x3b95001f,0x00000000,0x00000000,0x00000000}},	//   мјит, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6609026a,0x2d870031,0x14bf2581,0x44210234}},	//   çekl, plne_, ्राण, _lrh_,
   {{0x6b82791f,0xd7f8044c,0x00000000,0x00000000}},	//   _ekog, ftă_, --, --,
   {{0x6b4e0032,0x661d0052,0x6604756f,0x7afb7920}},	//   _dùgb, evsk, _spik, pfut,
   {{0xd90f00fb,0x501a00a1,0xa5b200a5,0x34c6152c}},	//   ئیں_, קורו, _इंदौ, वर्द,
   {{0xe8ee3028,0x6b8923ff,0xd7f800d3,0x644109af}},	//   _ил_, mleg, ată_, ølin,
   {{0x6b897921,0x61e47922,0x44210154,0x6b9b7923}},	//   lleg, vril, _brh_, lmug,
   {{0xe5a3168c,0xd7f800d3,0x35a301b6,0x6286084e}},	//   тири, ctă_, тарг, _syko,
   {{0x6b890c09,0x3787013d,0x61e45637,0xa5d7049d}},	//   nleg, _общо_, tril, _बिचौ,
   {{0x6f1902ad,0x61e47924,0x63a67925,0x66047926}},	// [7a80] ddwc, uril, _vikn, _upik,
   {{0x6286135f,0xa3cb152c,0x92ce0033,0x91e30ef1}},	//   _vyko, रीह_, রলে_, тофе,
   {{0x62860067,0xa00a04f4,0x6b897927,0xdfcf00e3}},	//   _wyko, تقال_, kleg, ليل_,
   {{0x61e402e6,0xdcf80095,0xdb020072,0xc4fa0018}},	//   pril, rovč, _tioé, _اٹھا_,
   {{0x6b8900f3,0x60ce023e,0xf2d3006e,0xdcfa0078}},	//   dleg, _tebm, _בער_, _jitħ,
   {{0x6b820572,0x23d2007f,0xdcfa00bd,0xdcf80357}},	//   _skog, _तबाद, _mitħ, povč,
   {{0x6b8931b5,0x69cb0188,0x64430233,0x212a01b9}},	//   fleg, _awge, _ünit, _inbh_,
   {{0x6b8923ff,0x6b9b0124,0x7d0a7604,0xda140284}},	//   gleg, gmug, sefs, едињ,
   {{0x3cfb61b6,0x201e0ebd,0xdcfa02a1,0xf1bf00da}},	//   ल्हे_, _štih_, _nitħ, _grád_,
   {{0xd8f800d6,0x799a023e,0x6b9b06b0,0x69c0004b}},	//   чної_, umtw, amug, rpme,
   {{0x6b897928,0x79887929,0x93c500fe,0x2d4b00f2}},	//   bleg, rldw, _chắ, _køen_,
   {{0xd7f8002d,0xb7d80068,0x6b8900a5,0x3a29015c}},	//   rtă_, _ہوتا_, cleg, _šape_,
   {{0xd7f8002d,0xdb08767a,0x56940243,0x3cfb0980}},	//   stă_, _judí, кают, ल्वे_,
   {{0xd7f800d3,0x6b80792a,0x661d792b,0xf80600ae}},	//   ptă_, lomg, rvsk, _жчин,
   {{0xe7e50d1b,0xdb1a020d,0x99990031,0x00000000}},	//   _किया_, _atté, ásť_, --,
   {{0x4421792c,0x290c792d,0x14bf1dae,0x6b80792e}},	//   _vrh_, leda_, ्रहण, nomg,
   {{0x60c90095,0x851a074c,0xdb0800d8,0x00000000}},	// [7a90] _đemb, _फोकट_, _nudí, --,
   {{0x290c792f,0x4421025b,0xddc200a5,0xdb010364}},	//   neda_, _trh_, szoś, _zulä,
   {{0xd3710286,0xdb087930,0x442114cf,0xa3cb136b}},	//   _مهد_, _audí, _urh_, रीश_,
   {{0x290c013d,0xdb080146,0xc49a0327,0x6b890537}},	//   heda_, _budí, _משתת, xleg,
   {{0x162204f8,0x7bda0113,0x290c7931,0x6b897932}},	//   मियर_, _avtu, keda_, vleg,
   {{0x290c0ea3,0x61ed7933,0x1de00285,0x02ef00a3}},	//   jeda_, mual, _निरत, _छाँह_,
   {{0x6b8944ff,0x290c013f,0x61ed7934,0x1b180033}},	//   tleg, deda_, lual, থানে_,
   {{0x394e0090,0x49c9020a,0x70940f57,0x00000000}},	//   _alfs_, плин_, _расф, --,
   {{0x6b8922b7,0x7d012ba1,0x61ed0a5f,0xda1606e4}},	//   rleg, _tbls, nual, तिगत_,
   {{0x6b897935,0x290c00aa,0xd102206b,0x6b9b7936}},	//   sleg, geda_, र्पण_, smug,
   {{0x6b897937,0x61ed7938,0xef19003d,0x1da8009f}},	//   pleg, hual, _każ_, _छूटत,
   {{0x44262ba9,0xa8220d5b,0xb33b00dd,0x61ed0a00}},	//   _čo_, اکون, _diçk, kual,
   {{0x290c7939,0xdb080042,0xef19009e,0xbebd00c6}},	//   beda_, _xudí, _maż_, _anūk,
   {{0x290c0328,0x61ed0fc9,0x93c500fe,0x00000000}},	//   ceda_, dual, _thắ, --,
   {{0xf1bf054f,0xa3cb009d,0x232a00f6,0xdcf800e8}},	//   _atá_, रील_, пови_, novā,
   {{0x3ead5fd5,0x23e10285,0xdcfa0078,0x00000000}},	//   _nget_, _फिरद, _titħ, --,
   {{0xa3dc1a09,0xb0cb02d5,0x91e310a6,0x00000000}},	// [7aa0] _ठिक_, िरंग, лоте, --,
   {{0xdce3013f,0x2d4b0c89,0xdbda0065,0x7bc30113}},	//   monė, _søen_, _làág, kpnu,
   {{0x3ead0167,0xdd9905aa,0xdce300c6,0xb4dc0096}},	//   _bget_, _epňk_, lonė, डणी_,
   {{0x60c308bb,0xa3e50251,0x2d85793a,0x7981793b}},	//   ınma, _नित_, _akle_, holw,
   {{0x79812471,0x61ed06ee,0xef1900bd,0x290c03e3}},	//   kolw, cual, _daż_, yeda_,
   {{0x3ead0d3e,0x3cfb2301,0x26d20201,0x7bd821ad}},	//   _eget_, ल्ले_, _leyo_, tsvu,
   {{0x290c793c,0xdee64c89,0xd0071f75,0x9c7c0094}},	//   veda_, _пови, _пере_, _odče,
   {{0x2d8501e8,0x7bd8793d,0x8fa3793e,0x290c793f}},	//   _ekle_, rsvu, _басе, weda_,
   {{0x290c005f,0x49742657,0xdce300c6,0x00000000}},	//   teda_, клис, jonė, --,
   {{0x0e6300ae,0xccf802c6,0x00000000,0x00000000}},	//   _скун, _změn_, --, --,
   {{0x61ed7940,0x315700c1,0x310200d2,0x00000000}},	//   zual, גיין_, र्यः_, --,
   {{0x7d1a7941,0x261d167f,0x00000000,0x00000000}},	//   _hats, मिली_, --, --,
   {{0x7d1a7942,0xd9467943,0x290c0096,0xb60428f1}},	//   _kats, _педи, peda_, лярк,
   {{0xd90e00cd,0x796603a9,0xa3b505cd,0x26d201ee}},	//   _اید_, _déwè, _छंद_, _eeyo_,
   {{0x7d1a0a75,0xc88501bf,0x15ed0034,0xa3cb1024}},	//   _mats, ößte_, _जमकर_, रीं_,
   {{0xb33b0092,0x26d27944,0xe3b025a1,0x00000000}},	//   _kiçi, _geyo_, صرف_, --,
   {{0xb5a71211,0x672d7945,0x6d4a00f3,0x6b550503}},	// [7ab0] _прой, _inaj, kkfa, _fágf,
   {{0x7d1a7946,0x61ed7947,0xdb0102c3,0xef1902a1}},	//   _nats, rual, _utlö, _saż_,
   {{0x61ed1059,0xdcb10023,0x64bf0285,0x26d2010a}},	//   sual, _bản_, ्रीश, _yeyo_,
   {{0x2d8500d4,0x00000000,0x00000000,0x00000000}},	//   _skle_, --, --, --,
   {{0x7d1a7948,0x5f7452c6,0x672d7949,0xa3b5152c}},	//   _bats, دالر, _mnaj, _छूत_,
   {{0x7d1a1848,0xdb0800b3,0xc694021e,0x01c80103}},	//   _cats, _audà, נאס_, _سوفٹ_,
   {{0x7d1a23f0,0x2ef51fdb,0xef19003d,0x4cca0081}},	//   _dats, _извр, _taż_, _রাখু,
   {{0xb33b794a,0x3eb90587,0x7981794b,0x6d4a794c}},	//   _biçi, _üst_, wolw, akfa,
   {{0xfe730068,0x7d1a4a28,0xfe430421,0x295500e5}},	//   _صدر_, _fats, _حکای, вънр,
   {{0x98a516d0,0x6d4a0c05,0x7cd909e5,0x672d794d}},	//   кипе, ckfa, _آواز_, _anaj,
   {{0x6f1b794e,0xcb1500ae,0x1ae30033,0x00000000}},	//   _kauc, _афлы, ক্ষে_, --,
   {{0x66161842,0x7981794f,0x6f1b7950,0x7d1a728e}},	//   _psyk, solw, _jauc, _zats,
   {{0xa3d40e50,0x7d1a7951,0xc4bf0034,0xd04500a7}},	//   सीन_, _yats, ्रूख, rahə,
   {{0x7dd800e3,0x6f1b7952,0x672d7953,0xd04700a7}},	//   _húsá, _lauc, _enaj, şməs,
   {{0x6b6701dc,0x94797954,0x69db2261,0xdb080206}},	//   _gègè, есту_, lsue, _hudá,
   {{0x6f1b1da7,0xa25600d1,0x3a2005db,0x00000000}},	//   _nauc, نپزش, _šipi_, --,
   {{0x03a33528,0x69db7955,0xe8190f8f,0xe1fa00ba}},	// [7ac0] рито, nsue, धिका_, ьга_,
   {{0x672d3624,0x25d707a6,0xd5b7000f,0xe297002d}},	//   _znaj, _שוין_, _इंतज, тау_,
   {{0x6f1b7956,0x7d1a1cea,0xc059004d,0xf1bf0031}},	//   _bauc, _rats, нії_, _prác_,
   {{0x7d1a09ce,0xdee61bb8,0x69db0f6f,0x6f1b7957}},	//   _sats, тоди, ksue, _cauc,
   {{0x7d1a7958,0xed5a334a,0xdb0e014b,0xbdf713c3}},	//   _pats, мод_, _àdéc, نروا_,
   {{0xde930284,0xdb080e8b,0x7d1a11bc,0x00000000}},	//   јашњ, _sudà, _qats, --,
   {{0x3f6a30cc,0x6f1b7959,0x7d1a00c2,0x6d4a01cd}},	//   _живо_, _fauc, _vats, rkfa,
   {{0x7d1a795a,0x6f1b025a,0x5b146def,0x3a2914f3}},	//   _wats, _gauc, умит, _šapa_,
   {{0x7d1a795b,0x9cf6002d,0x00000000,0x00000000}},	//   _tats, _ачеш, --, --,
   {{0x35dc0034,0x7d1a01fa,0x764b01f9,0x00000000}},	//   _बिज़, _uats, _ügyi, --,
   {{0x96f900ae,0x7f400372,0x00000000,0x00000000}},	//   нент_, _komq, --, --,
   {{0x69db00e1,0x00000000,0x00000000,0x00000000}},	//   bsue, --, --, --,
   {{0x7ae23ad5,0x69db009c,0x00000000,0x00000000}},	//   _idot, csue, --, --,
   {{0x64bf09c4,0x7764039f,0x7f40795c,0x00000000}},	//   ्रेश, _emix, _lomq, --,
   {{0x1af50033,0x22b80129,0x44250076,0x893700ca}},	//   _আসতে_, _ọka_, íl_, _ברגע_,
   {{0x291c07d1,0x97a41119,0x672d0010,0x3a26052f}},	//   _hava_, _крыл, _unaj, _krop_,
   {{0x291c166d,0x2018795d,0x6f1b01bf,0xceb902c6}},	// [7ad0] _kava_, _asri_, _rauc, _jaře_,
   {{0x6f1b795e,0x291e0018,0xe3b00018,0x291c00ca}},	//   _sauc, ndta_, صرہ_, _java_,
   {{0x7ae20084,0x6f02053e,0x60d74c47,0x30a746aa}},	//   _odot, ffoc, raxm, трав,
   {{0x291c795f,0x7ae27960,0x26d9019f,0xe7e533c5}},	//   _lava_, _ndot, naso_, _किसा_,
   {{0xdef81736,0xfce5249c,0x201e00cc,0x6f1b7961}},	//   тых_, голо, _štit_, _vauc,
   {{0x7ae27962,0xe3b00260,0x0d84224a,0x291c24fa}},	//   _adot, _دری_, алін, _nava_,
   {{0x26d96056,0xdb083e6a,0x6f1b01bf,0x7ae20090}},	//   kaso_, _sudá, _tauc, _bdot,
   {{0xe4e30775,0x69db0a00,0x2369007f,0x291c00bc}},	//   कृति_, tsue, niaj_, _aava_,
   {{0x22492129,0x291c3304,0x399900fd,0xdea10018}},	//   nyak_, _bava_, hèse_, _ایشی,
   {{0x291c7963,0x7ae20a00,0x8cca2125,0x2369006c}},	//   _cava_, _edot, _स्पो, hiaj_,
   {{0x69db7964,0x3a260126,0x291c7965,0x6d417966}},	//   ssue, _erop_, _dava_, _iola,
   {{0x26d9083e,0xf09200a1,0xdb080103,0xdcf8044c}},	//   gaso_, מני_, _tudá, povă,
   {{0x09e50084,0x291c0036,0x55f602e3,0xdb0b0052}},	//   _солн, _fava_, ычну, _ligë,
   {{0x6d417967,0x60d52449,0x291c0361,0x394c0036}},	//   _jola, _nezm, _gava_, ckds_,
   {{0x5faf0b76,0xf9920089,0x26d97968,0xc984002d}},	//   _जंगल, _הרג_, baso_, _туци,
   {{0x26d904d8,0x7c2e7969,0x6d41101e,0xe3550fe9}},	//   caso_, _ábre, _lola, атуэ,
   {{0x60d550a7,0xa3d40455,0x2018796a,0xb226013f}},	// [7ae0] _bezm, _सौर_, _ssri_, ымал,
   {{0x6d41796b,0x2ecc0569,0x2056101b,0x291c0072}},	//   _nola, ार्त, лтер, _xava_,
   {{0x40961c99,0x60d5002d,0xd46a4438,0x0446307f}},	//   урат, _dezm, _чине_, _сенн,
   {{0xf1bf0328,0x6d41796c,0x22490113,0x6b55026e}},	//   _irán_, _aola, byak_, _lágb,
   {{0x6d41796d,0xdee30cba,0x9e7600d1,0x00000000}},	//   _bola, сочи, دهشت, --,
   {{0xa3cb05cd,0x3f8f00aa,0xa3b8148e,0x6f020131}},	//   रीक_, algu_, _चढा_, sfoc,
   {{0xab5c0029,0x69c203ee,0xfbaa004c,0x7f40022e}},	//   _atļa, _stoe, нтий_, _tomq,
   {{0x6d41054f,0x3320796e,0x3a26796f,0x291c7970}},	//   _eola, ndix_, _prop_, _sava_,
   {{0x6d417971,0xdd8f0504,0x26d9028d,0x6b550af0}},	//   _fola, _کول_, vaso_, _bágb,
   {{0x6d411eef,0xdb0b0428,0x26d97972,0xa967001f}},	//   _gola, _ligè, waso_, лиња_,
   {{0x31370054,0x291c022b,0xb8dc218b,0x2369022e}},	//   אריך_, _vava_, _अल_, yiaj_,
   {{0x3a2604ea,0x6d417973,0xa3b80251,0x236901fa}},	//   _trop_, _zola, _चढ़_, xiaj_,
   {{0x26d97974,0x291c7975,0xe94400cd,0x3cfb0179}},	//   raso_, _tava_, _پرشی, ल्के_,
   {{0x040e00c7,0x6d587976,0xf65f02b6,0x26d97977}},	//   হিনী_, nhva, lbæk_, saso_,
   {{0x26d9044d,0x88bb00c1,0x00000000,0x00000000}},	//   paso_, _אזוי, --, --,
   {{0x98bc0154,0xe3150284,0x00000000,0x00000000}},	//   _movč_, јмањ, --, --,
   {{0x23697978,0xdb0b38df,0x623400d3,0x00000000}},	// [7af0] riaj_, _digè, бету, --,
   {{0x7c287979,0x660d608a,0x236900a5,0xdce300c4}},	//   _ordr, _ipak, siaj_, tinč,
   {{0xa3cb0e72,0xd01109b4,0x60d50146,0x3015797a}},	//   रीख_, تلا_, _vezm, рдер,
   {{0x398b038c,0x660d0294,0xdce3596a,0x00000000}},	//   løst_, _kpak, rinč, --,
   {{0x6d410d54,0xa91c0220,0x7c28797b,0x8ca70d75}},	//   _pola, voľn, _ardr, टेनो,
   {{0x660d797c,0x6d410188,0x61ed797d,0xdce3033b}},	//   _mpak, _qola, mral, pinč,
   {{0xeab100e3,0x8cc10fdd,0x00000000,0x00000000}},	//   يعة_, रुषो, --, --,
   {{0x0b450231,0x05b50789,0x660d12fb,0x7e7b0634}},	//   рнин, ंदाब, _opak, _txup,
   {{0x5f4409f4,0x660d0270,0x63af0188,0x61ed173c}},	//   _انقل, _npak, _micn, nral,
   {{0x63af175b,0x6d580146,0x6e2905bd,0x48052223}},	//   _licn, chva, _ireb, апов,
   {{0x660d6648,0x2d87797e,0x20010979,0x61ed0220}},	//   _apak, mone_, nthi_, hral,
   {{0x63af01b9,0x6e29680b,0x00000000,0x00000000}},	//   _nicn, _kreb, --, --,
   {{0x7f3a0130,0x0ab40a09,0xbb8400e3,0x04b600d6}},	//   דערו, _احمد, _الني, исвя,
   {{0x2d87797f,0x69c97980,0x660d005c,0x18a51c1b}},	//   none_, mpee, _dpak, _калм,
   {{0x6f097981,0x64a671dd,0x61ed7982,0xdb0b0076}},	//   _obec, рава, eral, _aigé,
   {{0x2d876745,0x6e297983,0x58940037,0x0cd1030b}},	//   hone_, _oreb, _اجهز, हरुम,
   {{0x2d877984,0x52aa0f6a,0xa5bb0042,0xdb0b015e}},	// [7b00] kone_, твам_, nvól, _vigè,
   {{0x2d877985,0xf1bf0023,0xe3ba007b,0xc0e632f8}},	//   jone_, _trán_, _ибо_, рожк,
   {{0x2d877986,0x46ba1244,0xd102397e,0x6e297987}},	//   done_, _इलाह, र्षण_, _areb,
   {{0x61ed7988,0x6e292793,0x256c0065,0xf1bf02c6}},	//   bral, _breb, _fólè_, _král_,
   {{0x2d877989,0x6e290e36,0x63a4798a,0x0cd1030b}},	//   fone_, _creb, mmin, हरूम,
   {{0x2d87798b,0xb5fb0018,0xcbe67913,0x92ce0033}},	//   gone_, szág, ации, _রায়_,
   {{0x6ca3008f,0x8fa634ed,0xe456006e,0x317b0142}},	//   оръж, _ваве, ייַט_, _סאלד,
   {{0x6d5814f3,0xa3cb1179,0xf1bf0437,0x00000000}},	//   shva, रीट_, _orál_, --,
   {{0x63a4798c,0x2d875e0a,0x9982030b,0x6e2901c8}},	//   imin, bone_, íků_, _greb,
   {{0x63a4798d,0x2d87798e,0x3eab00d4,0x00000000}},	//   hmin, cone_, _úcta_, --,
   {{0x63a4798f,0xeb360d5b,0x00000000,0x00000000}},	//   kmin, _پراخ, --, --,
   {{0x8cca10e9,0xdce30029,0x61ed7990,0x7bca0364}},	//   _स्तो, minā, yral, mpfu,
   {{0xdce300d9,0x7bca00ca,0x63a40fda,0x00000000}},	//   linā, lpfu, dmin, --,
   {{0x61ed7991,0xb866001c,0x229c00c6,0x14c7001c}},	//   vral, _پاتو, iškį_, شهری_,
   {{0x6b553912,0xf36701a0,0xd7fa00d3,0xdce300e8}},	//   _hága, атан, _рул_, ninā,
   {{0x63a47992,0x2d877993,0xe7380831,0x63b70149}},	//   gmin, zone_, _већ_, _vuxn,
   {{0xa3cb0789,0x660d7994,0x2d872dcf,0xdcef02c6}},	// [7b10] रीज_, _upak, yone_, _řeče,
   {{0x61ed7995,0x63a47996,0xdb0b034f,0x6e290216}},	//   rral, amin, _vigé, _rreb,
   {{0x61ed7997,0x63a47998,0x2d87028d,0x6f010103}},	//   sral, bmin, vone_, jábó,
   {{0x6e29230b,0xdce30029,0x2d877999,0x2001799a}},	//   _preb, dinā, wone_, rthi_,
   {{0x539a00f5,0xfe70177a,0x1af50081,0x200100cd}},	//   _תירו, وده_, _আসলে_, sthi_,
   {{0x6e292461,0x6b73020a,0x00000000,0x00000000}},	//   _vreb, măgi, --, --,
   {{0x2d870d63,0xa3cb0096,0xb5fb0072,0x80dc00c3}},	//   rone_, रीच_, nzáb, _फ़ते,
   {{0x6e29799b,0x2d87799c,0x9f053a89,0x2b150120}},	//   _treb, sone_, _دورو, ськр,
   {{0x2d87799d,0xaa4900c2,0x6e2902a4,0x3e180fe9}},	//   pone_, уппа_, _ureb, _котэ_,
   {{0x69c90084,0xdce300d9,0x63a4799e,0x6b4e01ec}},	//   rpee, binā, zmin, _lùgh,
   {{0x1b1f00c7,0x69c90305,0xdce30029,0x7c9500e3}},	//   ভাবে_, spee, cinā, _الاص,
   {{0x63a400a7,0x69c9799f,0x6b5579a0,0x00000000}},	//   xmin, ppee, _fága, --,
   {{0x4e79006e,0x6b550139,0x63a40902,0x00000000}},	//   ראָצ, _gága, vmin, --,
   {{0x04461510,0x6b890381,0x63a41868,0x1de00096}},	//   бегн, loeg, wmin, _निघत,
   {{0x63a4007a,0x8579008f,0xb4b80bd9,0x684500d3}},	//   tmin, рсят_, _छली_, _ынка,
   {{0x675600bf,0xaca30294,0x6b891044,0x63a479a1}},	//   _دختر, _adịl, noeg, umin,
   {{0xdce30029,0x78c60018,0x6b4e01f7,0x6d8d221e}},	// [7b20] zinā, _érvé, _dùgh, núas,
   {{0x05b502d5,0x1aff0033,0x00000000,0x00000000}},	//   ंदरब, ্যিই_, --, --,
   {{0xd8da00c1,0x4fea79a2,0x656e0201,0x251b0142}},	//   רקער, умен_, mibh, _גויא,
   {{0x656e79a3,0x27fa004d,0xdce301d3,0x644e0138}},	//   libh, _åpne_, vinā, mybi,
   {{0xa3d40557,0x644e79a4,0x3f9f041c,0x00000000}},	//   सीर_, lybi, _dhuu_, --,
   {{0xdce300d9,0xb17b02c3,0x00000000,0x00000000}},	//   tinā, _tvåa, --, --,
   {{0x61f60367,0x644e79a5,0x31570142,0x00000000}},	//   luyl, nybi, _פילן_, --,
   {{0xf06379a6,0xdce300d9,0x6b550072,0x7988549f}},	//   _эксп, rinā, _pága, wodw,
   {{0xdce30029,0x2d8c0063,0x61f60233,0xdd922ba0}},	//   sinā, _tkde_, nuyl, _فور_,
   {{0x26c200a5,0x644e0138,0x290a0220,0xd83a00ae}},	//   ecko_, kybi, ýba_, гэм_,
   {{0x61f601af,0x2381013f,0x656e79a7,0x1e181358}},	//   huyl, lėje_, dibh, _धनुष_,
   {{0x290200b6,0x61f6019c,0x644e00c6,0x79880eca}},	//   řka_, kuyl, dybi, sodw,
   {{0x238101b3,0x60de02ae,0x00000000,0x00000000}},	//   nėje_, kapm, --, --,
   {{0x67d42f00,0x6d5d0138,0xdce3020a,0x6b4e01b9}},	//   _доку, _įsak, mină, _sùgh,
   {{0x60de79a8,0x64b9009f,0x2458002d,0xa3d40c22}},	//   dapm, _आलीश, барь_, सील_,
   {{0x443f02e6,0xa91c0181,0x5b7b006e,0x92b70076}},	//   ću_, koľk, ָרמא, صحرا,
   {{0xe8200abe,0xdb080181,0x26db00ee,0xf1bf020b}},	// [7b30] यिका_, _budú, _ieqo_, _trám_,
   {{0x60de0167,0x3f9f0231,0xba9b00ca,0xa25b030a}},	//   gapm, _shuu_, רסמי, _ffôn,
   {{0x44275c75,0xdcb10023,0x691e009e,0x5fa40096}},	//   _én_, _tải_, _għeż, _ओळखल,
   {{0xdddb0871,0x3cfe0036,0x623500d3,0x2b460188}},	//   _využ, _actv_, _дему, _nooc_,
   {{0x6b890272,0xf1271068,0x9e0700ae,0x9f580103}},	//   voeg, _льво, счел, _apró_,
   {{0x629d01d3,0x00000000,0x00000000,0x00000000}},	//   _izso, --, --, --,
   {{0xa2ce0096,0x6b892d6d,0x8c42008f,0xdca26ab4}},	//   तरच्, toeg, деще, маши,
   {{0x238100c6,0x6d8d03be,0x8458021e,0x7a3e00c6}},	//   bėje_, túas, מבוס_, kštą,
   {{0x656e067d,0xfaf901d3,0x6b8901cb,0x49900103}},	//   yibh, rgū_, roeg, کیور,
   {{0x764f00a5,0xb4b800a3,0x6b8979a9,0x00000000}},	//   dycy, _छले_, soeg, --,
   {{0xe73a0832,0x07a60c10,0x38600022,0x6b8900bc}},	//   аен_, жанн, _ƙira_, poeg,
   {{0x16aa1121,0x644e0138,0x00000000,0x00000000}},	//   ивни_, vybi, --, --,
   {{0x656e02a1,0x65a00364,0x2bb501d3,0xf1b500aa}},	//   tibh, höhe, _vācu_, _अंगन,
   {{0x644e52ce,0xdcf802c6,0x7afb79aa,0x9f410052}},	//   tybi, dově, lgut, fshë_,
   {{0xa34a008f,0x656e79ab,0xa3d40285,0xf74628b9}},	//   азва_, ribh, सीं_, _меко,
   {{0x7afb79ac,0x42ca0219,0xe81e0251,0x39470f20}},	//   ngut, рган_, _बनता_, _hons_,
   {{0xb14620f9,0xe0da22d1,0xc8780092,0xcb120796}},	// [7b40] онал, ива_, mağa_, ולן_,
   {{0x40963fcf,0xaca30174,0x67240051,0x21a30396}},	//   орет, _adọl, _haij, диум,
   {{0x672479ad,0xb17b0212,0x3cfe037a,0x64a64a6f}},	//   _kaij, _tvån, _rctv_, _фана,
   {{0x3cfe79ae,0x25b700cd,0x23810138,0x11d6224a}},	//   _sctv_, _دهید_, tėje_, _мігр,
   {{0x672400d9,0xeda60291,0x3cfe0513,0x6fe000da}},	//   _maij, ошко, _pctv_, _bácá,
   {{0x61e407aa,0x6b550042,0x2b4679af,0x8bc64ead}},	//   msil, _bágo, _sooc_, осид,
   {{0x6b5c0257,0x23810138,0x60dc02a1,0xe819750e}},	//   _lége, sėje_, _ierm, _फैला_,
   {{0x8cca04f8,0x61e479b0,0x672479b1,0x7afb4e11}},	//   _स्रो, osil, _naij, ggut,
   {{0x394779b2,0x60dc3fb7,0x6458003d,0x61e479b3}},	//   _bons_, _kerm, _żvil, nsil,
   {{0x60dc0706,0x6b550072,0x61e479b4,0x39470632}},	//   _jerm, _fágo, isil, _cons_,
   {{0x6d5a0084,0x61e42326,0x394779b5,0x6604063d}},	//   _ilta, hsil, _dons_, _aqik,
   {{0xd6db0cb8,0x6724023e,0x61e479b6,0xf1f000c3}},	//   што_, _caij, ksil, _चिढ़_,
   {{0x6d4879b7,0x39470472,0x672402ef,0x6b5c0103}},	//   _koda, _fons_, _daij, _cége,
   {{0x60dc79b8,0xd5b801b3,0x28f7002d,0x39470f5a}},	//   _nerm, ўся_, _дешь_, _gons_,
   {{0x29c00028,0x61e61f60,0x2d4b0430,0x212305db}},	//   _hòa_, _avkl, _køer_, _rajh_,
   {{0x7ae079b9,0x5334188d,0x6d480441,0x2616009d}},	//   namt, мест, _loda, _पैकी_,
   {{0x60dc2394,0x776d22e7,0x61e42839,0x6d484e1a}},	// [7b50] _berm, _imax, gsil, _ooda,
   {{0x6d4879ba,0x60dc063f,0x7ae079bb,0x8cca0be4}},	//   _noda, _cerm, hamt, _स्लो,
   {{0x60dc79bc,0x3f1517ab,0xd7f800ae,0x7ae02eff}},	//   _derm, здес, nuă_, kamt,
   {{0x441a0054,0xdcf8000d,0x442101e5,0x6b5c33c3}},	//   _פורס, pově, _ish_, _légb,
   {{0x60dc79bd,0x6d4879be,0x7ae001c2,0x433a0796}},	//   _ferm, _boda, damt, _הערב,
   {{0x6d4879bf,0x8d650f94,0x60dc79c0,0xdb0b2c68}},	//   _coda, явле, _germ, _vigí,
   {{0x6d480f90,0x7aef0072,0x00000000,0x00000000}},	//   _doda, ócto, --, --,
   {{0x442179c1,0xe9d91c00,0x7ae02ad2,0xb5fb0103}},	//   _msh_, бки_, gamt, zzáa,
   {{0x7afb1305,0x6d487378,0x442101cd,0x00000000}},	//   rgut, _foda, _lsh_, --,
   {{0x395e0054,0x7afb02c9,0x60dc03be,0x6b5c0103}},	//   ghts_, sgut, _xerm, _rége,
   {{0x7d7a00c1,0x67241a3a,0x6b5c0065,0xe72a00ae}},	//   _פרעג, _paij, _dégb, бонд_,
   {{0x6d480ab2,0xed59084f,0x6f1900f0,0xadff009f}},	//   _zoda, _duže_, newc, _ईमान_,
   {{0xe8ee40ae,0x394779c2,0x8ca706e4,0x672400ce}},	//   _пл_, _tons_, टेरो, _vaij,
   {{0x69d900bd,0x395e79c3,0x6b5c0018,0x88bc00b6}},	//   _iwwe, chts_, _vége, nděl,
   {{0x68e179c4,0x7e620036,0x6b55003e,0x4421030a}},	//   mald, zzop, _lágm, _csh_,
   {{0x68e138ff,0x97ae00a7,0x3f780095,0x7d18007e}},	//   lald, üşdü, rčuk_, zevs,
   {{0xd29a004d,0x80d80469,0x44211175,0x68e101ff}},	// [7b60] стві_, यरले, _esh_, oald,
   {{0x68e179c5,0x64a64241,0x7ae00022,0x7f5b039f}},	//   nald, _напа, zamt, _aluq,
   {{0x60dc17bb,0x249f01c2,0x14d7006e,0x442179c6}},	//   _verm, ƙuma_, _מויל_, _gsh_,
   {{0x6d4879c7,0x61e479c8,0x68e179c9,0x60c57532}},	//   _soda, psil, hald, achm,
   {{0xa3b5000f,0x68e158b0,0xf3f100de,0x162200b6}},	//   _छूट_, kald, ợc_, मिटर_,
   {{0x63be79ca,0x68e179cb,0x61e2033b,0xe6d902d5}},	//   _kupn, jald, šols, _भज्ज,
   {{0x7ae02d9a,0x7d1879cc,0x6d5a00b6,0x68e179cd}},	//   tamt, revs, _vlta, dald,
   {{0x5a34016e,0xad6600cd,0x7d1800e7,0x207b006e}},	//   днит, _کاره, sevs, _האלא,
   {{0x6d483d46,0x7ae0006d,0x68e121d0,0x23810138}},	//   _toda, ramt, fald, nėja_,
   {{0x7ae079ce,0x68e179cf,0x6d5a79d0,0x237f00b6}},	//   samt, gald, _ulta, čuji_,
   {{0x69d904f9,0x7ae0084f,0xa91c0181,0x776d03a9}},	//   _ewwe, pamt, koľv, _pmax,
   {{0x29c00019,0x238100c6,0x68e100bc,0x44213177}},	//   _tòa_, kėja_, aald, _rsh_,
   {{0x68e102a7,0xf1bf0028,0xe81e0096,0x9f53014b}},	//   bald, _trái_, _बनवा_, édés_,
   {{0x68e104d3,0x5e570130,0x4a5300d6,0xed590542}},	//   cald, ליכע_, _якіс, _tuže_,
   {{0xdb1a04d8,0x439500d6,0xbf1c0096,0x2d5b0134}},	//   _auté, давс, _नसून_, ụego_,
   {{0xa87b040a,0x88bc00b6,0x213803a8,0xdb1a014b}},	//   _לאור, zděl, _anrh_, _buté,
   {{0x248d0067,0x7afd0428,0x75250063,0x238100c6}},	// [7b70] łem_, òsti, _tahz, gėja_,
   {{0x92cd0081,0x30a72ab6,0x00000000,0x00000000}},	//   রণে_, прев, --, --,
   {{0xb4d906e4,0x60c55dd2,0x44213177,0x490e02c6}},	//   ारी_, rchm, _ush_, त्यो_,
   {{0x60c502e2,0x68e101e9,0x6e991e46,0xdb1a014b}},	//   schm, zald, овер_, _futé,
   {{0xe2ab00cd,0x7bda003d,0x63be0433,0xb5fb01f9}},	//   _دادن_, _awtu, _zupn, zzán,
   {{0x628001b3,0x213847a6,0x51871907,0xa3d40ded}},	//   _žmog, _gnrh_, _хума, सीक_,
   {{0xea0000ef,0x68e10358,0x320929e4,0x2b5f00fe}},	//   _đại_, vald, ltay_, thuc_,
   {{0xb4d942c3,0x5f9400ae,0x7f5b039f,0x00000000}},	//   ारु_, _зист, _uluq, --,
   {{0x320979d1,0x68e102a7,0x3f8f0995,0x4ea70a28}},	//   ntay_, tald, mogu_, _хрва,
   {{0x57e96eb1,0xdb0b0143,0x00000000,0x00000000}},	//   одом_, _digá, --, --,
   {{0x68e179d2,0x2b5f00fe,0x8cc879d3,0x00000000}},	//   rald, phuc_, _رونق_, --,
   {{0x68e179d4,0xe73a1e6d,0x3a2900c4,0x320901ee}},	//   sald, цем_, _šapu_, ktay_,
   {{0x68e179d5,0xb4d9007a,0x80e30033,0x80dd00c3}},	//   pald, ारू_, _পান্, यराइ,
   {{0x64a601b3,0x63be79d6,0x320901ee,0x68e1013c}},	//   дага, _pupn, dtay_, qald,
   {{0x3f8f0006,0xaad106e4,0x9c7c05db,0x00000000}},	//   kogu_, _सभाक, _večg, --,
   {{0xf77209e5,0x32090188,0x03a379d7,0x22400634}},	//   _جات_, ftay_, висо, txik_,
   {{0x2fcd02e6,0xe29707f3,0xb5fb0fb6,0x3209008a}},	// [7b80] _čega_, дат_, nzál, gtay_,
   {{0x6b5c79d8,0x23810138,0x236079d9,0x00000000}},	//   _méga, rėja_, shij_, --,
   {{0x6b5c025a,0x9c7c02ef,0x32090188,0x653b00ca}},	//   _léga, _keče, atay_, _ועיד,
   {{0x32090694,0x2bc40251,0x3d0009c3,0x3f8f01d3}},	//   btay_, _लंबा, _राहे_, gogu_,
   {{0x9c7c79da,0x6b5c79db,0xdee30221,0x00000000}},	//   _meče, _néga, точи, --,
   {{0xe81e1349,0x9c7c0284,0xdfd200e3,0xf1bf035d}},	//   _बनला_, _leče, _ليس_, _práv_,
   {{0xab9402ec,0x3f8f14f3,0x5577006e,0x2b5d030a}},	//   никі, bogu_, ועסן_, _blwc_,
   {{0x9c7c79dc,0xdb0200fe,0x917900fe,0x6b5c79dd}},	//   _neče, _khoé, _tận_, _béga,
   {{0x8bb300e3,0x00000000,0x00000000,0x00000000}},	//   خصوص, --, --, --,
   {{0x6b5c00fd,0x4cd80081,0x99860234,0xdb0b0231}},	//   _déga, _ঠাকু, _broš_, _vigá,
   {{0x9cd700a1,0xd0f700a1,0x9c7c0307,0xf1bf00b6}},	//   _חובה_, ומית_, _beče, _hrát_,
   {{0x32093606,0xf1bf0244,0xa91c0031,0x9c7c0117}},	//   ytay_, _krát_, voľu, _večd,
   {{0x99660613,0x09c80033,0x6b5c0113,0x9c7c0660}},	//   _откл, _শিকা, _géga, _deče,
   {{0xb4d9167f,0x88bc030b,0x6d580b6a,0xed590117}},	//   ारे_, zděj, nkva, _kuža_,
   {{0x63a600e7,0xa3d900aa,0x38690d2a,0x00000000}},	//   _bhkn, ठीं_, _ƙare_, --,
   {{0xf1c30789,0x799a0150,0x644305fe,0xed59419a}},	//   _वंदन, lltw, _ànim, _muža_,
   {{0xf1bf0028,0x06ad0081,0x43945c8f,0x636300bc}},	// [7b90] _quá_, _ক্রি, татс, _lõng,
   {{0x51f81736,0x32090694,0x1af50081,0x9c7c79de}},	//   ьную_, rtay_, _আসছে_, _zeče,
   {{0x3209008a,0x6d580073,0x3f8f79df,0x2ef50d9b}},	//   stay_, dkva, togu_, езер,
   {{0x0fd500a5,0x6b826e46,0x23810138,0x171c006e}},	//   डीगढ, _njog, mėjo_, ַווע,
   {{0x63ad79e0,0x2381013f,0x3f8f0a84,0xa2f600ca}},	//   mman, lėjo_, rogu_, _אמרה_,
   {{0x11da0054,0xdca5249b,0x237f005f,0x6b8279e1}},	//   _מחשב, нали, čuju_, _ajog,
   {{0xaf07013d,0x68370174,0x23810138,0x63ad79e2}},	//   _очак, _ọda, nėjo_, oman,
   {{0x63ad79e3,0xe9d9185c,0xed5900cc,0xba2505cf}},	//   nman, пки_, _duža_, едик,
   {{0x63ad0a84,0x8cca2c5d,0x44330072,0x443e0023}},	//   iman, _स्को, _lrx_, ̣t_,
   {{0xb5fb2299,0xb4d979e4,0x6b55781e,0x2381013f}},	//   rzál, ारो_, _mági, kėjo_,
   {{0x63ad79e5,0x06ad00c7,0xb5fb0018,0x661679e6}},	//   kman, _ক্লি, szál, _spyk,
   {{0x238101b3,0x61f60dd8,0x6b5c0113,0x00000000}},	//   dėjo_, yryl, _téga, --,
   {{0x7bc179e7,0x65750167,0x636300aa,0x4433058f}},	//   _hulu, fizh, _mõnd, _arx_,
   {{0x6b9b79e8,0x7bc179e9,0x1869008f,0x645500d4}},	//   llug, _kulu, _нали_, fyzi,
   {{0x7bc10498,0xe94600cd,0xa87900c1,0x9c7c141f}},	//   _julu, _سروی, _מאַר, _teče,
   {{0x7bc10554,0x63ad79ea,0xdc030220,0xc3230b1b}},	//   _mulu, gman, jčít, лмск,
   {{0x7bc10706,0xe1fa79eb,0xf7720421,0x00da0037}},	// [7ba0] _lulu, яга_, _لاک_, كبات_,
   {{0x63ad79ec,0x7bc10084,0x23810138,0x399903a9}},	//   aman, _oulu, bėjo_, fèsi_,
   {{0xdfcf0b3d,0x5ed100c7,0x7bc179ed,0x63ad04cc}},	//   ميل_, _হয়ে, _nulu, bman,
   {{0xeaa7054f,0x5de6013d,0xed5976f0,0x63ad79ee}},	//   _مع_, ежда, _ruža_, cman,
   {{0xee3a01b6,0xfe720981,0x7bc10ac1,0x00000000}},	//   янд_, ددا_, _aulu, --,
   {{0x7bc179ef,0x6b82022b,0xb606033b,0xed5900c4}},	//   _bulu, _sjog, mešč, _puža_,
   {{0xa0a320e6,0x7bc1008a,0x6b9b79f0,0x6d5879f1}},	//   _бард, _culu, flug, rkva,
   {{0xa3e20e52,0x7bc179f2,0x67c8000d,0x6d5879f3}},	//   नीय_, _dulu, _něja, skva,
   {{0xc33300ca,0x80e30033,0x7bc1078e,0x00000000}},	//   רוח_, _পাত্, _eulu, --,
   {{0x63ad79f4,0x65a001bf,0x7bc10172,0x9c7c0141}},	//   zman, wöhn, _fulu, _večb,
   {{0x63ad79f5,0xf71000fe,0x6b9b79f6,0x6e2206b0}},	//   yman, _vầng_, blug, lwob,
   {{0xb5fb0018,0xb4d9009d,0x6f0279f7,0x6363007a}},	//   szám, ार्_, ngoc, _kõne,
   {{0x28d10336,0xf7100019,0x9f4700cd,0xf8d142d4}},	//   _द्वि, _tầng_, éné_, _द्वय,
   {{0xb5240963,0x201879f8,0x6363007a,0xd5b80084}},	//   льск, _opri_, _mõne, есс_,
   {{0x63ad0990,0x394e0212,0x7f981f4a,0x25ed00c3}},	//   tman, _iofs_, líqu, _अटकी_,
   {{0x6b5579f9,0x2381013f,0x6e220027,0x00000000}},	//   _pági, rėjo_, kwob, --,
   {{0x201800e5,0x60db00cb,0xb5fb0103,0x9f5a020d}},	// [7bb0] _apri_, _đumb, zzáj, cupé_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63ad79fa,0x6b5c00fd,0x26cb028d,0x4ae00d61}},	//   pman, _négo, occo_, नराव,
   {{0x291e0129,0x7ff452c6,0xb5fb0094,0x212a009c}},	//   heta_, اسلا, vzáj, _eabh_,
   {{0x291e79fb,0x7bc179fc,0x5e5800d6,0xdb1a0131}},	//   keta_, _sulu, ниця_, _cutí,
   {{0x291e0fa3,0x212a0a02,0x394e003d,0x4df502d5}},	//   jeta_, _gabh_, _nofs_, ुंबई_,
   {{0xf1bf6c61,0x7ae279fd,0x3a260139,0x9c7c00e7}},	//   _trás_, _beot, _asop_, _rečc,
   {{0x7f980328,0x7ae2009c,0x6b5c020d,0x6e2202a4}},	//   fíqu, _ceot, _dégo, bwob,
   {{0xdcbb02fd,0x291e79fe,0x6b9b79ff,0x44230197}},	//   _еще_, feta_, rlug, hwj_,
   {{0x7bc17a00,0xdb1a016d,0x69c20ac9,0x00000000}},	//   _tulu, _cutâ, _duoe, --,
   {{0x6b9b7a01,0x8cca097c,0xf772006f,0xed590095}},	//   plug, _स्टो, لاح_, _hužo_,
   {{0x2ac70065,0x32190f5a,0x44310381,0x6d5300e8}},	//   _díbó_, _opsy_, dvz_, šdaļ,
   {{0x291e7a02,0xd7f800d3,0x25ba3ddb,0x00000000}},	//   beta_, ară_, _pipl_, --,
   {{0x5e560130,0x291e7a03,0xb60602dd,0x26cb0036}},	//   דישע_, ceta_, vešč, acco_,
   {{0xf9905d50,0x9c7c09ac,0x3ebf0085,0x68e30239}},	//   _ابن_, _keča, _ogut_, _iend,
   {{0x68e370e8,0x6b5c00fd,0x7ae2002b,0x27f80031}},	//   _hend, _négl, _xeot, árne_,
   {{0x68e37a04,0x98bc00b6,0xe64600ae,0x20182e13}},	// [7bc0] _kend, _nově_, _репп, _spri_,
   {{0x20560208,0x68e32762,0x3ebf00ee,0xe577002d}},	//   ктер, _jend, _agut_, _азь_,
   {{0xd12f1be8,0xdb1a0072,0x386001c2,0x76a80139}},	//   تمل_, _sutí, _ƙiri_, _fèyí,
   {{0x291e7a05,0x9c7c025b,0x200705fe,0xed590b14}},	//   zeta_, _neča, ània_, _bužo_,
   {{0x291e0fa0,0x332005fe,0x6b5c014b,0x2907020a}},	//   yeta_, meix_, _ségo, _ocna_,
   {{0x68e37a06,0xcbcd0081,0x7ae2007a,0x33200428}},	//   _nend, _রয়েছ, _seot, leix_,
   {{0x291e00e9,0x1fb601b6,0x5f0608c3,0x9c7c00c4}},	//   veta_, _асар, _изва, _beča,
   {{0x291e06c0,0x33200472,0x68e37a07,0x00000000}},	//   weta_, neix_, _aend, --,
   {{0x291e08a9,0x9c7c0291,0x1d260cd7,0xa3e202d5}},	//   teta_, _deča, _имам, नीत_,
   {{0x68e32d96,0x29076776,0xd7f8002d,0xdbd9001f}},	//   _cend, _ccna_, tră_, _açõe,
   {{0x68e37a08,0x2bbb000f,0x3a26022b,0xdd8f0e25}},	//   _dend, _ऊंचा, _wsop_, _بول_,
   {{0x68e30a9f,0xa5f9007b,0x61ff0abd,0x00000000}},	//   _eend, нему_, yuql, --,
   {{0x33200472,0xf1bf0139,0x3a260063,0xe9440504}},	//   deix_, _asán_, _usop_, _مرثی,
   {{0x68e37a09,0xa2d57a0a,0xceb30796,0x6b557a0b}},	//   _gend, युन्, ייר_, _dágu,
   {{0x68e80694,0x478b0291,0x2ee402ac,0x26cb0027}},	//   madd, _осим_, _oemf_, pcco_,
   {{0x33200472,0x68e87a0c,0x68e37a0d,0x490e0640}},	//   geix_, ladd, _zend, त्रो_,
   {{0x6b5c025a,0x68e328e4,0x442301fa,0xdb19001c}},	// [7bd0] _régl, _yend, swj_, _diwè,
   {{0x68e8787e,0x672d008c,0x68e32dc1,0x660d039f}},	//   nadd, _haaj, _xend, _iqak,
   {{0xe8d700ca,0x3320015e,0x00000000,0x00000000}},	//   דובר_, beix_, --, --,
   {{0x68e87a0e,0x672d2a86,0x00000000,0x00000000}},	//   hadd, _jaaj, --, --,
   {{0x61ff01d4,0x68e87a0f,0x672d7a10,0x63bd00f9}},	//   quql, kadd, _maaj, _iisn,
   {{0xac090870,0x672d0084,0x68e87a11,0x9c7c0a39}},	//   енка_, _laaj, jadd, _seča,
   {{0xeb991a18,0x68e34287,0x4c150080,0x68e87a12}},	//   ник_, _rend, ابتس, dadd,
   {{0x8b2528f1,0x20016185,0x3ebf061d,0xdb1a00b3}},	//   удие, muhi_, _ugut_, _cutà,
   {{0x68e32058,0x63bd7a13,0x61ed7a14,0x68e87a15}},	//   _pend, _misn, nsal, fadd,
   {{0x68e301e5,0x68e80517,0x63bd0a9e,0x6e29019f}},	//   _qend, gadd, _lisn, _iseb,
   {{0x68e30bb0,0x200106ee,0x9c7c62ff,0x61ed0092}},	//   _vend, nuhi_, _teča, hsal,
   {{0x68e37a16,0x21217a17,0xfc4602c6,0x3ce50596}},	//   _wend, hehh_, žích_, _helv_,
   {{0x68e87a18,0xfa3412eb,0x7ae90062,0x6e2902a1}},	//   badd, _پرند, maet, _jseb,
   {{0x7ae902ad,0x68e8008a,0x68e37a19,0x61ed7a1a}},	//   laet, cadd, _uend, dsal,
   {{0x33200990,0x63bd159d,0x49b85e51,0x6b550037}},	//   teix_, _bisn, _شاهد_, _fágt,
   {{0x6e292782,0x7ae902e0,0x629d00ec,0x23271c3e}},	//   _oseb, naet, _byso, лоси_,
   {{0x61ed20c1,0x33200472,0xd38714fa,0xe7850b1b}},	// [7be0] gsal, reix_, уйте_, _њујо,
   {{0x29c900de,0x6f091741,0xdb1901dc,0x7ae900f0}},	//   _múa_, _acec, _diwé, haet,
   {{0x5ecd0081,0x61ed7a1b,0x29c97a1c,0x672d023e}},	//   ারনে, asal, _lúa_, _yaaj,
   {{0x672d008a,0x6db90220,0x2fd7015a,0x42d5036c}},	//   _xaaj, _dňam, اوند_, _віру,
   {{0x7ae902e0,0x80e300c7,0x68e80c1a,0x29c9002b}},	//   daet, _পার্, yadd, _núa_,
   {{0x2001476c,0x16c107e2,0x3a3a7a1d,0x68e8008c}},	//   buhi_, _एल्ब, _čpp_, xadd,
   {{0x50b508d1,0x6e297a1e,0x7ae900f0,0xcd270b1b}},	//   _всту, _eseb, faet, ужје_,
   {{0x29c97a1f,0x7ae902ad,0x3d0905a7,0x68e80517}},	//   _búa_, gaet, _साथे_, wadd,
   {{0xee3a7a20,0x68e87a21,0x7f750114,0x672d5142}},	//   _яна_, tadd, _турц, _raaj,
   {{0x7764002b,0x672d7a22,0xd6e10033,0xd7fa0290}},	//   _alix, _saaj, _ভাইয, нум_,
   {{0x68e87a23,0x77647a24,0x8d5b00ca,0x88bc02c6}},	//   radd, _blix, _רכבי, jdět,
   {{0x70e10ed3,0x68e83329,0x48a702e3,0x77645d30}},	//   _फ़्ल, sadd, ытым_, _clix,
   {{0x628008a1,0x9b9300e3,0x63bd32af,0x6b5c01f9}},	//   _žmon, _النت, _risn, _légk,
   {{0x776408a8,0x672d32bd,0x68e87a25,0x8cc702d5}},	//   _elix, _waaj, qadd, ाशयो,
   {{0x77647a26,0x63bd7a27,0x80e30033,0x61ed0afd}},	//   _flix, _pisn, _পাল্, wsal,
   {{0x61ed7a28,0x25660257,0x260200aa,0x87090103}},	//   tsal, _rôle_, वंशी_, _شعبہ_,
   {{0x63bd1842,0x61ed0e22,0x00000000,0x00000000}},	// [7bf0] _visn, usal, --, --,
   {{0x629d0871,0xeb214f3a,0x61ed7a29,0x200146c3}},	//   _vyso, _मस्त_, rsal, tuhi_,
   {{0x629d0067,0x63bd7a2a,0xa0a701a0,0x7ae900f0}},	//   _wyso, _tisn, ушал, yaet,
   {{0x3ce51a08,0x61ed7a2b,0x6b557a2c,0x09da0033}},	//   _selv_, psal, _lágr, _দিনা,
   {{0x1d094a4e,0x20010498,0x2d760034,0x3d004422}},	//   вели_, suhi_, ałem_, _राखे_,
   {{0x6e290b27,0x29c90933,0xf1a90490,0x9c7c7a2d}},	//   _vseb, _rúa_, _कठिन, _večn,
   {{0x29c94b1f,0xe05700d0,0x7ae90150,0xa3d90096}},	//   _súa_, _حیات_, taet, ठीच_,
   {{0x23694de8,0x9c7c2a6c,0x7ae90150,0x29c90143}},	//   nhaj_, _tečn, uaet, _púa_,
   {{0x7ae90150,0x6e290201,0x69253a62,0x29c900fe}},	//   raet, _useb, ампа, _qúa_,
   {{0x7ae925a8,0xc8b500c2,0xa2d51178,0x29050a39}},	//   saet, исны, युत्, ugla_,
   {{0x29057a2e,0x670a04f1,0x98a5120a,0xe3bf0062}},	//   rgla_, _वादक_, рине, _oiñ_,
   {{0x29c922e7,0xe816007a,0x27f8321f,0xe3bf034f}},	//   _túa_, _तहरा_, árna_, _niñ_,
   {{0xd9457a2f,0xfd4e0032,0xb5fb0103,0x2d76007f}},	//   _вели, _afiṣ, zzáv, złem_,
   {{0x3ea20120,0xe3bf01ff,0x2d76007f,0x00000000}},	//   _økte_, _aiñ_, yłem_, --,
   {{0x6363007a,0x9c7c1e4d,0x00000000,0x00000000}},	//   _sõna, _nečl, --, --,
   {{0xdb020019,0xe3630a7c,0x00000000,0x00000000}},	//   _khoá, окси, --, --,

   {{0x6d417a30,0x6b5c033c,0x00000000,0x00000000}},	// [7c00] _onla, _dégh, --, --,
   {{0xb17b070a,0xe0d72611,0x6e46001c,0xe3bf0062}},	//   _svår, иву_, ینام, _eiñ_,
   {{0x03a61c16,0xb4fb0054,0xaec61f82,0xd0260077}},	//   _вино, _בפיי, абел, рмей,
   {{0x6d416227,0xa2d500b6,0x9c7c138c,0x23697a31}},	//   _anla, युद्, _sečo, chaj_,
   {{0x645c7a32,0x443a1359,0xdce1026a,0xa5bb007f}},	//   lyri, _hrp_, _aklı, dwój,
   {{0x443a7a33,0x657c00f9,0x91e360dc,0x7c3e2e2f}},	//   _krp_, nirh, _форе, åpro,
   {{0x7b6648bd,0x69cf02c6,0x3212007b,0x50aa0167}},	//   итие, ícen, ltyy_, _करिष,
   {{0x6d416f6e,0x00000000,0x00000000,0x00000000}},	//   _enla, --, --, --,
   {{0x3f860146,0xdb020023,0xb5fb15bf,0x321200c2}},	//   mnou_, _choá, nzát, ntyy_,
   {{0x6b5c0018,0x3f860579,0x26d20154,0x2918003e}},	//   _mégi, lnou_, _afyo_, ýra_,
   {{0x6b5c20cc,0x013700a1,0x3f86137f,0x657c7a34}},	//   _légi, ברית_, onou_, dirh,
   {{0x3f867a35,0x23690052,0xdcf800c6,0x9c7c7a36}},	//   nnou_, xhaj_, tovė, _ječm,
   {{0x7bc87a37,0xaac50037,0x645a01ce,0x3f8619f0}},	//   _hudu, _اتمن, øtin, inou_,
   {{0x443a7a38,0x645c3374,0xdcf80138,0x3f8602c6}},	//   _brp_, fyri, rovė, hnou_,
   {{0x7bc87a39,0xdcfa00d9,0xe5160abe,0xa3e2014e}},	//   _judu, _aktī, द्धि_, नील_,
   {{0x7bc87a3a,0x443a061d,0x88bb00ca,0x3f860e51}},	//   _mudu, _drp_, _במוז, jnou_,
   {{0x3f860368,0x657c0270,0xd25001f9,0x00000000}},	// [7c10] dnou_, birh, ونِ_, --,
   {{0xdb090037,0x443a004d,0x9c7c02c6,0x23697a3b}},	//   imeá, _frp_, _pečl, shaj_,
   {{0x2fc70028,0x4427098c,0x7bc800cd,0x2d760034}},	//   êng_, _èn_, _nudu, ałek_,
   {{0x3f860956,0x7d1a225b,0x27f16db0,0x9c7c0117}},	//   gnou_, _abts, ázni_, _večl,
   {{0xd3360341,0x7bc87a3c,0x98a701d3,0x765d0565}},	//   _פרשה_, _audu, _manā_, nysy,
   {{0x7bc80106,0x200e05fe,0x645a01bf,0xed59080e}},	//   _budu, àfic_, ätig, _kuži_,
   {{0x7bc8008a,0xf1b200a1,0x3f860146,0x251c0142}},	//   _cudu, _מסך_, bnou_, דווא,
   {{0x5f9417de,0x7bc8117e,0xed59025b,0x88e30081}},	//   _дист, _dudu, _muži_, _মাইক,
   {{0x7c3a7a3d,0x5ecd0033,0x6f1b7a3e,0x3a3900d4}},	//   _ertr, ারদে, _ibuc, ísp_,
   {{0x6d413baa,0x6e3b2caa,0x7bc8008a,0x97d90d72}},	//   _unla, _irub, _fudu, льму_,
   {{0x7bc85ce4,0x6e3b025b,0x315800c1,0x213103a9}},	//   _gudu, _hrub, ייזן_, _mazh_,
   {{0x321202fd,0xdb020019,0x645c7a3f,0x00000000}},	//   ytyy_, _thoá, vyri, --,
   {{0x98a50b88,0x657c7a40,0x443a7a41,0x6441038c}},	//   rklı_, tirh, _srp_, ålin,
   {{0xceb20054,0x645c7a42,0x6b5c7a43,0x69db0890}},	//   פים_, tyri, _régi, mpue,
   {{0x2d871519,0xa3e20006,0x7bc80188,0x26e70033}},	//   inne_, नीं_, _xudu, _কারো_,
   {{0xed590335,0x321200c2,0x6e3b0062,0x00000000}},	//   _duži_, ttyy_, _orub, --,
   {{0x3f86025b,0xa1c319cb,0x52aa63df,0x9c7c05db}},	// [7c20] vnou_, збуд, увам_, _rečm,
   {{0x9c7c0284,0x66067a44,0x6f1b7a45,0x6b5c0103}},	//   _dečj, mukk, _abuc, _végi,
   {{0x66063ba3,0x3f867784,0x321200c2,0x443a0451}},	//   lukk, tnou_, styy_, _urp_,
   {{0x7bc87a46,0x2d877a47,0x6e3b4ba8,0x461300d1}},	//   _rudu, enne_, _brub, _بویر,
   {{0xf2d307a6,0x63a41842,0xb14800bf,0x7bc839fb}},	//   _מער_, mlin, _پیام_, _sudu,
   {{0xf98752c6,0x3f867a48,0x63b6003e,0x6f1b0372}},	//   _رب_, snou_, lmyn, _ebuc,
   {{0x3d09110f,0x6e3b321e,0x63a42768,0x38c809e5}},	//   _सारे_, _erub, olin, یادی_,
   {{0x66060333,0xbf1600cd,0x672600dd,0x2d877a49}},	//   kukk, _دورب, jekj, anne_,
   {{0x6e3b7a4a,0x660650ef,0x7bc87a4b,0x442a023e}},	//   _grub, jukk, _wudu, hwb_,
   {{0xb5fb00fb,0x63a47a4c,0x7bc87a4d,0xdb097a4e}},	//   zzás, hlin, _tudu, rmeá,
   {{0x63a43fe4,0x319b00c1,0x63b60088,0xc19b006e}},	//   klin, רבינ, kmyn, רשיי,
   {{0xb7671787,0x6606180d,0x31af0233,0x00000000}},	//   стой, fukk, müze_, --,
   {{0x63a47a4f,0x7a3606fa,0x65a0042c,0xb8ce0033}},	//   dlin, _دعائ, höhu, _কল_,
   {{0x9c7c3360,0xb69b020a,0x6aa20372,0x00000000}},	//   _rečj, ngâi, _iyof, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a47a50,0xe3b01e56,0x63b60088,0x07f70037}},	//   glin, فرق_, gmyn, _اروع_,
   {{0x3d090b95,0x9c7c0106,0xe800097c,0x2769001c}},	// [7c30] _साले_, _bečk, लंका_, _مشکی_,
   {{0x9c7c02dd,0xf77f7a51,0x6f1b0451,0xed590a9e}},	//   _večj, liç_, _sbuc, _tuži_,
   {{0x63a442f0,0x9c7c7a52,0x61e60090,0x6e3b06f7}},	//   blin, _dečk, _ewkl, _srub,
   {{0xceeb00bf,0x2d8c7a52,0x63a47a53,0x66fb0179}},	//   اران_, _ajde_, clin, ्लिक_,
   {{0x44210483,0x799a7a54,0x67c802c6,0xf1bf0094}},	//   _hph_, kotw, _ději, _mráz_,
   {{0xabd50859,0x44210e1d,0x3d0e0980,0x81d411c0}},	//   оциј, _kph_, _ठाणे_, _хорх,
   {{0x4c69028d,0x7afd381f,0x6b5c0257,0x44210063}},	//   рийн_, ósto, _légu, _jph_,
   {{0x6f1b4dae,0x88bc00b6,0x2d9e004d,0x68370174}},	//   _ubuc, vděp, _ekte_, _ụdi,
   {{0x6e3b023f,0xc8da009d,0x291c5b8f,0xc33400ca}},	//   _urub, _म्हट, _bbva_, פוץ_,
   {{0x3ead7a55,0x69db4096,0x799a7a56,0x00000000}},	//   _izet_, rpue, gotw, --,
   {{0x69db00c7,0xfd1000e3,0x291c007e,0x442100fe}},	//   spue, _سجل_, _dbva_, _nph_,
   {{0xae0d0179,0x63a47a57,0x65a00364,0x69db00c2}},	//   _समान_, xlin, höht, ppue,
   {{0x3f9f1ee3,0xe8ee22fb,0x63a47a58,0xf3f100de}},	//   _mkuu_, _ол_, vlin, ận_,
   {{0x66061f45,0x6b897a59,0x63a41d91,0x6b5c0257}},	//   rukk, lneg, wlin, _dégu,
   {{0x66067a5a,0x68e1197e,0x63a472c1,0x6b5c0032}},	//   sukk, mbld, tlin, _eégu,
   {{0x44210871,0x69cb7a5b,0xf8b200a1,0x69c37a5c}},	//   _dph_, _kuge, _קשה_, _hine,
   {{0x7aeb0068,0x69cb7a5d,0x63b61f40,0x44217a5e}},	// [7c40] _megt, _juge, rmyn, _eph_,
   {{0x69cb600a,0x7aeb7a5f,0xdb0b05fe,0x850600cd}},	//   _muge, _legt, _aigü, _بودن,
   {{0x69cb7a60,0x3ead0181,0x9c7c0087,0x4f9600ae}},	//   _luge, _azet_, _večk, орду,
   {{0xee3a4b95,0xe29a22ff,0x69c37a61,0x6b897a62}},	//   ине_, _вам_, _line, jneg,
   {{0x6b897a59,0x69c301e9,0xe297224a,0x7c210154}},	//   dneg, _oine, _маю_, _aplr,
   {{0xafe60cf5,0x7bc27a63,0x463b00c1,0xc0aa1850}},	//   _могл, _siou, יענע, _نازل_,
   {{0x69cb3e61,0xa0a30e05,0x69d91900,0x64587a64}},	//   _auge, _жард, _atwe, _àvid,
   {{0x69cb7a65,0x69c37a66,0x6b897a67,0x0b8a0215}},	//   _buge, _aine, gneg, јски_,
   {{0x69c37a68,0xf77f7a69,0x7aeb7a6a,0x094a0aec}},	//   _bine, viç_, _degt, ачни_,
   {{0x6b5c30ca,0xdc3e0146,0x79887a6b,0x9c7c0d62}},	//   _régu, líče, undw, _leči,
   {{0x69c37a6c,0x6b897a6d,0xcb6a232c,0x6b5c7a6e}},	//   _dine, bneg, _каже_, _ségu,
   {{0x69c33477,0x2d9c00e9,0x4421005c,0x6b9b04d4}},	//   _eine, love_, _rph_, coug,
   {{0x69cb7103,0x799a7a6f,0x69c3361a,0xf77f3b82}},	//   _guge, potw, _fine, riç_,
   {{0x44210167,0x27690d83,0x6b800350,0x854400ae}},	//   _pph_, _گشتی_, limg, мэсе,
   {{0xd37b0394,0x69cb02e2,0x9c7c00cc,0x00000000}},	//   ача_, _zuge, _beči, --,
   {{0x569502fd,0x69c37a70,0x4421037a,0xdd1e00b6}},	//   _найт, _zine, _vph_, jížd,
   {{0x9c7c0284,0x60f9055b,0x69c30233,0xdc3e00d4}},	// [7c50] _deči, йная_, _yine, díče,
   {{0x7bda003d,0x69c310d8,0x290c00f3,0xdb0b1f72}},	//   _ottu, _xine, ngda_, _sigü,
   {{0x2d9c45ca,0x44210167,0xced80294,0x38690d2a}},	//   dove_, _uph_, _ịzụr, _ƙari_,
   {{0x6b5c0103,0xf1bf7a71,0x00000000,0x00000000}},	//   _mégs, _spád_, --, --,
   {{0x6b890b27,0x7bda7a72,0x7aeb0665,0x2d9c00cc}},	//   vneg, _attu, _regt, fove_,
   {{0xa3e200a5,0x69cb0193,0x6b890034,0x9c7c2f54}},	//   नीक_, _ruge, wneg, _zeči,
   {{0x6b897a73,0x69c37a74,0x81cd0081,0x6b9b00e7}},	//   tneg, _rine, _রবি_, toug,
   {{0x69c35ed5,0x3f9f6257,0x69cb41f4,0x2b460a02}},	//   _sine, _ukuu_, _puge, _cnoc_,
   {{0x8cd8033a,0x34a8033a,0x6b897a75,0x6b9b0054}},	//   नुहो, _गर्द, rneg, roug,
   {{0x69c301ec,0x6b897a62,0x290c0212,0x7aeb24a9}},	//   _qine, sneg, ggda_, _wegt,
   {{0xe73a016e,0xc7a61d2e,0x6b8932b9,0x69c31173}},	//   бен_, зинк, pneg, _vine,
   {{0x69cb7a76,0x69c37a77,0xfb380076,0x00000000}},	//   _tuge, _wine, _وأنت_, --,
   {{0x69c37a78,0x1dcb007a,0x9c7c7a79,0x656e0a02}},	//   _tine, ादित, _reči, thbh,
   {{0x2eed1215,0x9c7c7a7a,0x69c3009c,0x98ae0383}},	//   _leef_, _seči, _uine, _zafč_,
   {{0x98a23097,0x80aa00a5,0x70aa0006,0x04432887}},	//   _пише, _करें, _करेल, нерн,
   {{0x2d9c0039,0x1dcb0789,0x57fa00ca,0x2eed7a7b}},	//   zove_, ादात, _הלקו, _neef_,
   {{0x9c7c02dd,0x02060761,0x2d9c7a7c,0x00000000}},	// [7c60] _veči, язан, yove_, --,
   {{0xdce3013f,0xe1f70f1e,0x59ce02d5,0x867b00d7}},	//   minė, ягу_, _हंसर, _לרפו,
   {{0x2d9c04eb,0xdce3013f,0xb4d807ad,0x64a60ed7}},	//   vove_, linė, ाडी_, _хана,
   {{0x7981019c,0xed580031,0x0e8e0174,0x0dca4c46}},	//   hilw, _soľ_, kịtị_, буки_,
   {{0xdce3013f,0x67360167,0x733b006e,0x290c0120}},	//   ninė, _mayj, _העכס, ygda_,
   {{0x09da0081,0x237f0e43,0x2ca5066a,0x6b5c05ef}},	//   _দিলা, ďuje_, _byld_, _négr,
   {{0xdee6165d,0x80e30081,0xfe6f0018,0xcb980076}},	//   _нови, _পাচ্, نگے_, ينتش_,
   {{0x2eed0ab2,0x8fa30f32,0x39470049,0xdce3013f}},	//   _geef_, _засе, _anns_, kinė,
   {{0xa2a20490,0x0e6601b3,0xdce30138,0x6b80058f}},	//   _कुम्, _экан, jinė, rimg,
   {{0x49730cd1,0xdce30138,0x2ca502b6,0xa978004d}},	//   ельс, dinė, _fyld_, ійну_,
   {{0xa3ac00a3,0x6b5c00fd,0x6d5a009c,0x00000000}},	//   गता_, _dégr, _iota, --,
   {{0x290203a3,0x6d5a7a7d,0x61f600c2,0xdce300c6}},	//   şka_, _hota, ksyl, finė,
   {{0xd05c01d4,0x8f9b0341,0xdce30138,0xda3400c2}},	//   _verə, מיטי, ginė, _целы,
   {{0x6d5a02fd,0xe5c400c2,0x66000437,0xdb1102c3}},	//   _jota, ессо, ámka, åför,
   {{0x6d5a7a7e,0xf3670ed7,0xb33b0233,0x6d48039f}},	//   _mota, птан, _akça, _mnda,
   {{0x6371070a,0x26c9192a,0xdce30138,0xd3a40c33}},	//   _mång, _ugao_, binė, еруп,
   {{0x6d487a7f,0x6371070a,0x6d5a007a,0xdce3013f}},	// [7c70] _onda, _lång, _oota, cinė,
   {{0x6d5a2b41,0x636300aa,0x00000000,0x00000000}},	//   _nota, _mõni, --, --,
   {{0x9c7c7a80,0x776d30e1,0x7feb0286,0x00000000}},	//   _keču, _klax, صراف_, --,
   {{0x6d487a81,0x7981019f,0xb9100294,0x00000000}},	//   _anda, zilw, talụ_, --,
   {{0x6d5a3c57,0x44331df6,0x3209020b,0x00000000}},	//   _bota, _hsx_, quay_, --,
   {{0x6d5a1c07,0xdca51312,0x4d64004d,0x776d0090}},	//   _cota, мали, нків, _llax,
   {{0x6d5a7a82,0x2eed000b,0x6b5c0349,0x256f0233}},	//   _dota, _teef_, _régr, _güle_,
   {{0xe9d90870,0x8d770421,0x92c10033,0xa2b40851}},	//   оки_, _کارا, ুরী_, _आरम्,
   {{0x6d5a7a83,0x44330085,0x00000000,0x00000000}},	//   _fota, _lsx_, --, --,
   {{0x63717a84,0xdce30138,0xceb200ca,0x776d7944}},	//   _hånd, vinė, _יין_, _alax,
   {{0x6371070a,0x6b5c0018,0x44337a85,0x7c670037}},	//   _gång, _végr, _nsx_, _عائل,
   {{0xdce301b3,0x6d5a7a86,0x0e8e0134,0x61f600f0}},	//   tinė, _zota, mịrị_, ysyl,
   {{0x27e002e6,0x6371038b,0x0e8e0294,0x00000000}},	//   _čine_, _månd, lịrị_, --,
   {{0xdce3013f,0x18697a87,0x776d039f,0x7f5b0231}},	//   rinė, _мали_, _elax, _louq,
   {{0x64a37a88,0xdce30138,0xa2c00f8f,0x38690d2a}},	//   вара, sinė, लेन्, _ƙaru_,
   {{0x04100081,0x70aa009f,0xdce30138,0xb4ae00aa}},	//   াবলী_, _करौल, pinė, _औरी_,
   {{0x03a32284,0xcad20134,0x3aba00c1,0x0e8e0174}},	// [7c80] тито, _kịrị, ַמענ, hịrị_,
   {{0x657e0060,0x7e620051,0x61f600f0,0xa2a233dc}},	//   _umph, vyop, rsyl, _कुण्,
   {{0x443c0018,0x637100f2,0x68fc0131,0x7f5b0b87}},	//   _év_, _bånd, órdi, _bouq,
   {{0x6d5a7a89,0x0e8e0134,0xfd570065,0x1e86007b}},	//   _sota, dịrị_, _ifaṣ, млем,
   {{0xf1af13ae,0x63710149,0x63a9003d,0x6d4802fa}},	//   _जीवन, _sång, ċent, _pnda,
   {{0x7e620113,0x7f49039f,0x6d5a026d,0x00000000}},	//   ryop, _eneq, _qota, --,
   {{0xa2a21362,0x7e62022b,0x7f5b014b,0x3f6a4c89}},	//   _कुत्, syop, _fouq, _диво_,
   {{0x5a34133d,0x6d5a7a8a,0xcf260dce,0xd00f0cd2}},	//   енит, _wota, _ترسي, _خلف_,
   {{0x0e8e0134,0x00000000,0x00000000,0x00000000}},	//   rịsị_, --, --, --,
   {{0x6d487a8b,0x2138005c,0x0e8e0134,0x80cc0033}},	//   _unda, _jarh_, bịrị_, িরক্,
   {{0x9c7c7a8c,0xcad20134,0x776d002b,0x0e8e0134}},	//   _peču, _dịrị, _plax, pịsị_,
   {{0x6d0e007d,0xd7cf2fc2,0x95cb0396,0x09e6004d}},	//   _साँग_, _संरच, жува_, _жодн,
   {{0x9f650257,0x9c7c7a8d,0x64480120,0x00000000}},	//   étés_, _veču, ådin, --,
   {{0x63711a08,0xe8942246,0x00000000,0x00000000}},	//   _måne, _паль, --, --,
   {{0xd7ef0095,0x637102fe,0x776d0314,0x00000000}},	//   _шу_, _låne, _tlax, --,
   {{0x3a267a8e,0x57fb00ca,0x00000000,0x00000000}},	//   _kpop_, _ולהו, --, --,
   {{0xe1f02204,0x2eba009d,0x7afd22bf,0x6d0e1fbb}},	// [7c90] لسل_, ेशोत, ósti, _सांग_,
   {{0x9f450649,0x9b800134,0xae050179,0x00000000}},	//   _ìlú_, ịghị, _रिबन_, --,
   {{0xb4eb074c,0xd7f800d3,0x92c10081,0x7f5b0558}},	//   मरी_, nsă_, ুরে_, _pouq,
   {{0x20df099d,0xb0df05a5,0xd34700d1,0x50df02c6}},	//   _प्रध, _प्रग, _تیره_, _प्रष,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xee387a8f,0x236901ee,0x0e8e0134,0xae1100a4}},	//   ьні_, lkaj_, tịrị_, डंबन_,
   {{0xdca2180b,0x77b60072,0x7f5b014b,0x00000000}},	//   лаши, láxe, _touq, --,
   {{0xe51f030b,0x0e8e06c0,0x23697a90,0x9c7c05db}},	//   म्ति_, rịrị_, nkaj_, _rečt,
   {{0xcad20134,0xa3b60034,0x0e8e06c0,0x3d9500d3}},	//   _pịrị, _चीफ_, sịrị_, _зиар,
   {{0xa3b61784,0x7d790bf4,0xa3cf0096,0x9c7c00d8}},	//   _चीन_, _عمار_, शदा_, _pečt,
   {{0xe73a0c59,0x2919007f,0xc6892252,0x00000000}},	//   пен_, ęsa_, _פא_, --,
   {{0xe73a4c46,0x66000094,0xd6d20037,0x9c7c05db}},	//   чем_, ámko, طقس_, _večt,
   {{0x2b1406ed,0x15ba0084,0xd7f800d3,0x6608007f}},	//   _धातु_, зывы_, asă_, ądko,
   {{0x636300aa,0xdb0902ac,0x00000000,0x00000000}},	//   _mõnu, kleë, --, --,
   {{0xa5bb007f,0xf89b0504,0x7afd007f,0x2b5d0090}},	//   twór, _بخشش_, óstw, _kowc_,
   {{0x636a0146,0x00000000,0x00000000,0x00000000}},	//   _výno, --, --, --,
   {{0x672402a4,0xe2970e0e,0x00000000,0x00000000}},	// [7ca0] _ibij, еат_, --, --,
   {{0x764402a4,0x6b550103,0x249f020e,0x6371298b}},	//   _iriy, _vágy, şuma_, _råne,
   {{0xaadf030b,0xaf0600ae,0x80a80033,0xc483022a}},	//   नडाक, епел, কেন্, _блэк,
   {{0x44447a91,0x91e65fdd,0x76447a92,0x3cfe03a9}},	//   _ir_, _поме, _kriy, _sdtv_,
   {{0xa3bd0251,0x67247a93,0xb17b0e9f,0x3cfe7a94}},	//   इगर_, _mbij, _ståe, _pdtv_,
   {{0x4444793d,0x61e47a95,0x256f00aa,0x764403a9}},	//   _kr_, mpil, _küla_, _mriy,
   {{0x6724015c,0x7b66007e,0x61e47a96,0x2240465a}},	//   _obij, етпе, lpil, lvik_,
   {{0x444400a1,0x93e80179,0x61e40f18,0x65c70139}},	//   _mr_, टीएच_, opil, _kéhì,
   {{0x6d4b0037,0x224029d2,0x00000000,0x00000000}},	//   álaí, nvik_, --, --,
   {{0x44441723,0xc27b193b,0x67247a97,0xee377a98}},	//   _or_, פריי, _abij, _яну_,
   {{0x7644602b,0x9c7c0117,0xe894013f,0xdce300e8}},	//   _ariy, _večs, тань, zinī,
   {{0xc6a728b9,0xd7f800ae,0x76440383,0x61e47a99}},	//   ерги, rsă_, _briy, kpil,
   {{0x44447a9a,0x3d17007a,0x764401dc,0x2240007e}},	//   _ar_, _नामे_, _criy, jvik_,
   {{0x44447a9b,0xb4eb0f65,0x76441a3a,0xd7f800ae}},	//   _br_, मरे_, _driy, psă_,
   {{0x97a7123a,0x77931e49,0x76447a9c,0x670a0096}},	//   _прил, _میدا, _eriy, _वाचक_,
   {{0x5334064f,0xe3b304f4,0x644304d8,0x76445ce9}},	//   лест, ارس_, _ánim, _friy,
   {{0x44445ec1,0x61e42846,0x69ca2959,0x76440194}},	// [7cb0] _er_, gpil, _kife, _griy,
   {{0x7c287a9d,0x23697a9e,0x660f5fa4,0x98ae078e}},	//   _opdr, skaj_, muck, _gafă_,
   {{0x44447a9f,0x6b8225d1,0x6363007a,0x661d7aa0}},	//   _gr_, _omog, _sõnu, ltsk,
   {{0xb4bf05a5,0x661d7aa1,0x69ca7aa2,0x61e401d3}},	//   ेशी_, otsk, _life, bpil,
   {{0x63ad3d6a,0x660f22d4,0x7c281dfc,0x22400146}},	//   mlan, nuck, _apdr, cvik_,
   {{0x44441a2e,0x63ad3980,0x69ca02ad,0x6b827aa3}},	//   _yr_, llan, _nife, _amog,
   {{0xeb990f8d,0x320914d0,0x63ad7aa4,0x98a700b6}},	//   мик_, lray_, olan, _daně_,
   {{0x3f867aa5,0xdb007aa6,0x0b450131,0x661d33f1}},	//   ciou_, nomè, тнин, ktsk,
   {{0x63ad7aa7,0xdb1a7aa8,0x660f08a9,0x27e01197}},	//   ilan, _autó, juck, _čina_,
   {{0x63ad067d,0x6b820036,0x6724007e,0x69ca2316}},	//   hlan, _emog, _sbij, _cife,
   {{0x2d873b30,0x66e640ca,0x644501bb,0x61e401d3}},	//   mine_, кона, _nrhi, zpil,
   {{0x63ad7aa9,0x44447aaa,0x76447aab,0x6e290129}},	//   jlan, _rr_, _priy, _kpeb,
   {{0x44447aac,0x2d87003b,0x7ae97aad,0x69ca7aae}},	//   _sr_, oine_, mbet, _fife,
   {{0x44445be7,0x7ae90973,0x320900fc,0x61e400d9}},	//   _pr_, lbet, dray_, vpil,
   {{0x64a63ba4,0x61fd1918,0x7bcb7aaf,0x661d057a}},	//   тава, _avsl, _kigu, atsk,
   {{0x672400e9,0x2d877ab0,0x32097ab1,0x63ad7ab2}},	//   _ubij, hine_, fray_, glan,
   {{0x7bcb7ab3,0x644501bf,0x3209026d,0x3f86137f}},	// [7cc0] _migu, _erhi, gray_, viou_,
   {{0x44447ab4,0x63ad37b7,0x2d877ab5,0x22407ab6}},	//   _tr_, alan, jine_, rvik_,
   {{0x44447ab7,0x2d870c0b,0x61e47ab8,0xa2a20e19}},	//   _ur_, dine_, spil, _कुर्,
   {{0x63ad7ab9,0x7bcb7aba,0xe80907ad,0x32097abb}},	//   clan, _nigu, _विना_, bray_,
   {{0x63a47abc,0x7ae90429,0x3f864205,0x2d8772cd}},	//   moin, dbet, riou_, fine_,
   {{0x63a47abd,0x7bcb33dd,0x2d87188c,0x6b827abe}},	//   loin, _aigu, gine_, _smog,
   {{0x69ca785e,0x7bcb7abf,0x3c3c00b6,0x2fda001c}},	//   _rife, _bigu, dává_, _آورد_,
   {{0xdb1a05fe,0x63a400c2,0x69ca7ac0,0x2d877ac1}},	//   _autò, noin, _sife, aine_,
   {{0x7bcb1a27,0x450a0033,0xb5fb01f9,0xf1bf488f}},	//   _digu, শ্যক_, száz, _opál_,
   {{0x63ad7ac2,0x63710572,0x7bcb003e,0x661d033b}},	//   zlan, _måna, _eigu, vtsk,
   {{0x63ad2001,0x63a40084,0x6371320e,0x7ae97ac3}},	//   ylan, koin, _låna, bbet,
   {{0x7ae91821,0x7bcb7ac4,0x63ad0092,0x661d1e81}},	//   cbet, _gigu, xlan, ttsk,
   {{0xa2a21161,0x673d01df,0x63ad01ce,0x69ca0078}},	//   _कुल्, rdsj, vlan, _tife,
   {{0x661d00e9,0x63ad7ac5,0x58d33d51,0xdb001f97}},	//   rtsk, wlan, _кошт, domé,
   {{0x63ad7ac6,0x661d7ac7,0xb4bf0ff9,0xa2c016f8}},	//   tlan, stsk, ेशे_, लेस्,
   {{0x63ad7ac8,0x79881b99,0x661d05db,0x3f8402ac}},	//   ulan, lidw, ptsk, _nmmu_,
   {{0x80d70378,0x2d877ac9,0x32090188,0xdb007aca}},	// [7cd0] _बलदे, yine_, uray_, romè,
   {{0xdb0009b5,0x3f8400aa,0x32091dbd,0x63a401b9}},	//   llmä, _ammu_, rray_, aoin,
   {{0x31c41d1c,0x7ae901e8,0x77b60072,0x00000000}},	//   рств, ybet, láxa, --,
   {{0x63ad00a7,0x2d875605,0x620807e7,0xa5bb0131}},	//   qlan, wine_, ürlü, stód,
   {{0x7bcb013d,0xfe7000ab,0xdb000042,0x1287010d}},	//   _rigu, يده_, comé, _شمسی_,
   {{0x2cac02e0,0x7ae900f0,0xbdf80076,0x00000000}},	//   _bydd_, wbet, ئرنا_, --,
   {{0x2d877acb,0x7ae91cab,0x7bcb7acc,0x3c3c02c6}},	//   rine_, tbet, _pigu, vává_,
   {{0x2d877acd,0x2cac02ad,0x9c7c0117,0x80be00a4}},	//   sine_, _dydd_, _večp, वेळे,
   {{0x7ae96396,0x2d872af0,0x7bcb7ace,0xd6ae0081}},	//   rbet, pine_, _vigu, _গল্প,
   {{0x2cac02ad,0x7ae601e8,0x2d874184,0x7bcb47ea}},	//   _fydd_, ıkta, qine_, _wigu,
   {{0x7bcb02c9,0x378a0c58,0x186902a0,0xb4bf00a3}},	//   _tigu, ебно_, хани_, ेशो_,
   {{0xab842a84,0x1dcb0861,0x3c3c4691,0x00000000}},	//   _кучк, ादकत, sává_, --,
   {{0x79887acf,0x63a47ad0,0x6b89004b,0xb99201f3}},	//   bidw, voin, mieg, _گلوب,
   {{0x6b897ad1,0x63710149,0x39580212,0x2fcd7ad2}},	//   lieg, _råna, örst_, _lieg_,
   {{0x232a1c0e,0x63a47ad3,0xe1ff0558,0x69c14eed}},	//   нови_, toin, _avó_, mmle,
   {{0x69c101e8,0x6b897ad4,0xf7721f11,0x05140033}},	//   lmle, nieg, _دات_, াজের_,
   {{0x63a47ad5,0x256f0006,0xc7a9012b,0x6378137f}},	// [7ce0] roin, _küll_, _جدول_, _líng,
   {{0x63a42f7d,0xdb004229,0x6b8901e9,0x764b01f9}},	//   soin, romé, hieg, _ágya,
   {{0x6b890067,0xf3f100de,0x4f0a40fc,0x256f042c}},	//   kieg, ật_, енен_, _müll_,
   {{0xdfcf0037,0x6b897ad6,0x443a0133,0x00000000}},	//   سيه_, jieg, _isp_, --,
   {{0x2cac02e0,0xef2101d3,0x00000000,0x00000000}},	//   _sydd_, daļā_, --, --,
   {{0xa0a6013f,0x00000000,0x00000000,0x00000000}},	//   _багд, --, --, --,
   {{0x7988003d,0x50b802d5,0x00000000,0x00000000}},	//   vidw, _अरिष, --, --,
   {{0x40930080,0x3f847ad7,0x637800b3,0x6b897ad8}},	//   _الفر, _ummu_, _díng, gieg,
   {{0x49742082,0xfce635c1,0x443a001c,0x298a0c37}},	//   илис, _бозо, _lsp_, есно_,
   {{0x753e0167,0x20b80336,0x291800b7,0xaac02918}},	//   _napz, _अराध, üra_, शेषक,
   {{0xa3c40067,0x6b897ad9,0x7d1a0063,0x175540fc}},	//   एगा_, bieg, _icts, авня,
   {{0xa3d80f77,0x7c3a7ada,0x68e4008b,0xe517074c}},	//   ादन_, _istr, _şidd, _ताहि_,
   {{0xb8cb1792,0x7afd003e,0xb4bf1bc3,0x00000000}},	//   _कु_, ðste, ेश्_, --,
   {{0xda7b0054,0x1c184ff1,0x26d2083e,0x443a7adb}},	//   _אנדר, _धमाल_, _egyo_, _bsp_,
   {{0x443a7adc,0x68fa7add,0x753e5568,0x00000000}},	//   _csp_, matd, _dapz, --,
   {{0x1dd407e2,0x68fa013c,0xdb190154,0xdb210031}},	//   ददात, latd, _chwè, _štúr,
   {{0xa2c00454,0x50f518e4,0x32551828,0x644a0072}},	// [7cf0] लेल्, изат, швар, _áfin,
   {{0x637822e7,0xa5bb255c,0x6b8901d3,0x2fcd0364}},	//   _aínd, stób, zieg, _sieg_,
   {{0x443a7ade,0xb03507ce,0x403500d3,0x491c0b7f}},	//   _gsp_, рнеш, реес, _मानो_,
   {{0x68fa013c,0x3ead023b,0x2fcd0090,0x00000000}},	//   hatd, _pyet_, _qieg_, --,
   {{0x63780065,0x68fa7adf,0x6b8901d3,0x673f02a1}},	//   _dínd, katd, vieg, _maqj,
   {{0x6b897ae0,0x443a0124,0x3da9008f,0x2fcd000b}},	//   wieg, _ysp_, ъкло_, _wieg_,
   {{0x636a0088,0x6b897ae1,0x6db90031,0x7c3a7ae2}},	//   _sýni, tieg, _kňaz, _cstr,
   {{0x290a0018,0x3d170096,0x673f0052,0x7d1a0062}},	//   óban_, _नावे_, _naqj, _ects,
   {{0x7c3a7ae3,0xc9550ab3,0x3f9c00fd,0x1c2100aa}},	//   _estr, атны, évue_, _महकल_,
   {{0x636a0220,0x6b894151,0x68fa0270,0x63780072}},	//   _výni, sieg, gatd, _tíng,
   {{0xb8dd0e28,0x6b897ae4,0x69c17ae5,0x00000000}},	//   _आर_, pieg, rmle, --,
   {{0x443a7ae6,0xc7a600d6,0x07a632ac,0x63711f60}},	//   _rsp_, римк, рамн, _sånn,
   {{0x68fa013c,0x6b5c0103,0x7afb569d,0x7e6b0124}},	//   batd, _négy, maut, nygp,
   {{0x7afb02fd,0xb17b0212,0x443a7ae7,0x6e3b0350}},	//   laut, _stån, _psp_, _msub,
   {{0x69db7ae8,0x63787ae9,0x673f00dd,0x7c3a01af}},	//   lque, _líne, _faqj, _xstr,
   {{0x7afb7aea,0x289a2252,0x00000000,0x00000000}},	//   naut, _שיקא, --, --,
   {{0x69db7aeb,0x6e3b1e59,0x2b9a00e8,0x00000000}},	// [7d00] nque, _nsub, nīca_, --,
   {{0x60e71c4c,0x7afb67d9,0x6f1b6a26,0xc5fb006e}},	//   имум_, haut, _acuc, _שפיט,
   {{0x7afb7aec,0x205644aa,0x6e3b4e54,0x6b5c0018}},	//   kaut, штар, _asub, _végz,
   {{0xf8b200a1,0x7afb7aed,0x888c006e,0xd00700d3}},	//   חשב_, jaut, עראַ, реце_,
   {{0xee7a1170,0x68fa00a7,0x9ea7032d,0x44380150}},	//   خصات_, yatd, авца_, lwr_,
   {{0x6f1b039f,0x7afb7aee,0x7c3a5b0b,0x00000000}},	//   _ecuc, eaut, _pstr, --,
   {{0x7afb068d,0x998d00a5,0x6e3b7aef,0x20130167}},	//   faut, steś_, _esub, cuxi_,
   {{0x7afb7af0,0xe45700c1,0x61e60167,0x7c3a5bdf}},	//   gaut, שיקט_, _ktkl, _vstr,
   {{0x32000154,0x7c3a007f,0x3f671009,0x00000000}},	//   nsiy_, _wstr, _тито_, --,
   {{0xd90e0260,0x9f5a0036,0xd90d001c,0x6e227af1}},	//   ذیب_, cupò_, فیه_, mtob,
   {{0x7c3a18b4,0x68fa00a7,0x7afb7af2,0x7764015e}},	//   _ustr, ratd, baut, _boix,
   {{0x61e61419,0x44380150,0x69db7af3,0x7764015e}},	//   _otkl, dwr_, bque, _coix,
   {{0xdb0011ce,0x69db7af4,0x68fa5db9,0x7ae205bd}},	//   nomí, cque, patd, _ifot,
   {{0x61e902a5,0xe81800ae,0x68fa1a4a,0x6e2d7af5}},	//   _çeli, _бокч_, qatd, çabi,
   {{0x61e60029,0x99990220,0x44380150,0x776400b3}},	//   _atkl, ísť_, gwr_, _foix,
   {{0x887700a1,0x8c3c0092,0x539800d6,0x7f40039f}},	//   _כתוב_, _uyğu, ався_, _namq,
   {{0xdb1b042c,0x00000000,0x00000000,0x00000000}},	// [7d10] hluß, --, --, --,
   {{0x9f58008f,0x2fd87af6,0x68f8007e,0x6f1b0036}},	//   _avrà_, _burg_, _jevd, _scuc,
   {{0x7bde2733,0x69db4c20,0x75357af7,0x53352c13}},	//   ípul, zque, mezz, _лент,
   {{0x75357af8,0x68f87af9,0x00000000,0x00000000}},	//   lezz, _levd, --, --,
   {{0xfce50f32,0x03560089,0x7afb02e3,0x69db00fd}},	//   боло, _הירש_, vaut, xque,
   {{0x75354963,0x290a255c,0x0638006e,0x6adf049d}},	//   nezz, óbal_, ינדט_, नड्र,
   {{0x7afb3a39,0x656500bd,0x254b00c6,0x00000000}},	//   taut, _mohh, mėlė_, --,
   {{0x7535008f,0x20017afa,0xd498028c,0xdfb80867}},	//   hezz, mshi_, יכות_, _ناقص_,
   {{0x8e8500e3,0x65650270,0x75357afb,0x1efa006e}},	//   _الذه, _oohh, kezz, _תּלמ,
   {{0x69db7afc,0x75355b96,0x7afb7afd,0x77647afe}},	//   rque, jezz, saut, _soix,
   {{0x69db78ec,0x20017aff,0x6d4129cb,0x7afb7b00}},	//   sque, nshi_, _iala, paut,
   {{0x6d417b01,0xb17b017a,0x20010051,0x6d433feb}},	//   _hala, _stål, ishi_, ldna,
   {{0x6d414b10,0x75352ae2,0x2001010a,0x254b0138}},	//   _kala, fezz, hshi_, kėlė_,
   {{0x6d417b02,0x6d437b03,0xf1db08d4,0x69d90113}},	//   _jala, ndna, _बढ़न, _iuwe,
   {{0x69d97b04,0xa3b3009d,0xf3f10023,0x200700d4}},	//   _huwe, टतं_, ập_, ánil_,
   {{0x6d417b05,0x69d97b06,0x660f00e7,0x44380150}},	//   _lala, _kuwe, brck, rwr_,
   {{0x69d9525b,0x7af9009e,0x75350361,0x64430234}},	// [7d20] _juwe, _mewt, bezz, _šnit,
   {{0x865b00a1,0x69d97b07,0x3a3d00dc,0x75353292}},	//   _עדיי, _muwe, _mswp_, cezz,
   {{0xa2b413ae,0x69d97b08,0x600a32d4,0xfd9e0174}},	//   _आरक्, _luwe, унем_, jụọ_,
   {{0x6d417b09,0x6604354e,0xdb000610,0x69d9029a}},	//   _aala, _kvik, tomí, _ouwe,
   {{0x471b0130,0x69d97b0a,0x6d43029a,0x61e605e8}},	//   רונג, _nuwe, fdna, _utkl,
   {{0xdb007b0b,0x7ae229ca,0xd2b700ca,0x20017b0c}},	//   romí, _sfot, _ללכת_, bshi_,
   {{0x6d417b0d,0x6e227b0e,0x6fb60604,0xdc2a1f11}},	//   _dala, stob, _همسا, استه_,
   {{0x5f96054f,0x6d411519,0x68f87b0f,0xdb000363}},	//   _الرئ, _eala, _sevd, pomí,
   {{0x8d1a23bb,0x2fdf007e,0x7afd003e,0x386c00f0}},	//   _مزار_, _čugi_, ðsta, wydr_,
   {{0x6d417b10,0xa3d81362,0x69d97b11,0xad650037}},	//   _gala, ादा_, _duwe, _واله,
   {{0x2c0b09b4,0x69d90f5a,0x7bce0036,0x66047b12}},	//   _معنی_, _euwe, _èbuo, _avik,
   {{0x6565007e,0xbfb60023,0x69d9024a,0x00000000}},	//   _sohh, _điềm_, _fuwe, --,
   {{0x75352fce,0x6d417b13,0x0ab60d74,0x7bda7b14}},	//   tezz, _yala, _احاد, _hutu,
   {{0x7bda7b15,0x6d416ac9,0x2d8e00e7,0xd943101b}},	//   _kutu, _xala, nife_, _нечи,
   {{0x75357b16,0x7bda1d2d,0x7aed002d,0x20017b17}},	//   rezz, _jutu, _întâ, xshi_,
   {{0xa5bb1de7,0x25740212,0x7bda00db,0x02a30174}},	//   ctón, _häll_, _mutu, swọọ,
   {{0x75357b18,0x7d082545,0x2fc6042d,0x6d437b19}},	// [7d30] pezz, _odds, dmog_, ydna,
   {{0x7bda0ba0,0x20010d6a,0xdb190154,0x764d7b1a}},	//   _outu, tshi_, _jiwò, _iray,
   {{0x7bda7b1b,0x6d417b1c,0x610b00d9,0x93e00096}},	//   _nutu, _rala, vēlē, _खूपच_,
   {{0x20017b1d,0x63782218,0x256f00a7,0x00000000}},	//   rshi_, _vínc, _sülh_, --,
   {{0x672d00dd,0x20010085,0x787f0103,0xfd9e0174}},	//   _mbaj, sshi_, _kávé, wụọ_,
   {{0x7bda7b1e,0x61ed7b1f,0x6d41680e,0x69d94b60}},	//   _butu, mpal, _qala, _ruwe,
   {{0x6d417b20,0x7bda7414,0x69d97b21,0x6d437b22}},	//   _vala, _cutu, _suwe, rdna,
   {{0x6d417b23,0x69d900a6,0xa2c009c4,0x637800ea}},	//   _wala, _puwe, लेक्, _kína,
   {{0x6d41485c,0x2ca900a5,0x61ed7b24,0xdce102c6}},	//   _tala, ład_, npal, _holč,
   {{0x672d7b25,0x2d8e001f,0x3f8f7b26,0xe8f97b27}},	//   _abaj, cife_, ligu_, шло_,
   {{0x764d4808,0x7bda72fc,0x66047b28,0x201e0212}},	//   _aray, _gutu, _svik, _ätit_,
   {{0x69d97b29,0x764d7b2a,0xa6ca078b,0x3f8f7b2b}},	//   _tuwe, _bray, илна_, nigu_,
   {{0x99d733c6,0x764d24f9,0xa5bb7b2c,0x7bda7b2d}},	//   _اتصا, _cray, rtón, _zutu,
   {{0x764d7b2e,0x1a9a006e,0x7bda04d6,0x2249084e}},	//   _dray, _דינע, _yutu, dvak_,
   {{0x6f097b2f,0x764d0188,0x04437b30,0x3f8f01e9}},	//   _odec, _eray, мерн, kigu_,
   {{0x3f8f02e6,0xb5fb0103,0x672d7b31,0x764d014b}},	//   jigu_, gyás, _gbaj, _fray,
   {{0x27e002e6,0x61ed152a,0x3f8f041c,0x068300e5}},	// [7d40] _čini_, gpal, digu_, _огън,
   {{0x6f097b32,0xa1c3004d,0xa5bb0165,0x645a0f18}},	//   _adec, дбуд, ntól, ätis,
   {{0x397a006e,0x98a5004b,0x00000000,0x00000000}},	//   סטענ, telę_, --, --,
   {{0x7bda7b33,0xdce10218,0x637801cd,0x3f8f010a}},	//   _rutu, _dolč, _fína, gigu_,
   {{0x6f090150,0x7bda7b34,0xc6280081,0x3ea07b35}},	//   _ddec, _sutu, মিকা_, çit_,
   {{0x63a94092,0x6f0901e8,0xdb000018,0x63b67b36}},	//   čene, _edec, domá, llyn,
   {{0xd0072f17,0xdb0005fe,0x60237b37,0xdce1037d}},	//   _мере_, tomà, _одра, _golč,
   {{0x63b602ad,0x3f8f14f3,0xdb090076,0xdb0001f9}},	//   nlyn, cigu_, tleá, fomá,
   {{0xde030d9b,0xdb001094,0x81dc0033,0x7bda00d1}},	//   _опти, gomá, ণীর_, _wutu,
   {{0x7bda7b38,0x6f090034,0x77bd0072,0x325700ca}},	//   _tutu, _zdec, déxa, קסים_,
   {{0x61ed7b39,0x7bda00c2,0x25740212,0xdb090076}},	//   zpal, _uutu, _väll_, sleá,
   {{0xdbf00081,0x764d7b3a,0x00000000,0x00000000}},	//   _টিপস_, _pray, --, --,
   {{0x61e200e3,0xdb00037a,0x63b600f0,0x7bc2039f}},	//   íoll, comá, dlyn, _ihou,
   {{0xd49b07bf,0x00000000,0x00000000,0x00000000}},	//   арб_, --, --, --,
   {{0x9f4701e5,0x7bc2646c,0x6378003e,0x938b0131}},	//   ënë_, _khou, _sína, асаа_,
   {{0xe51705d4,0x764d7b3b,0x200707c0,0x63b67b3c}},	//   _ताकि_, _tray, šnik_, glyn,
   {{0xc175008f,0x61ed7b3d,0x764d59bf,0x6f090141}},	// [7d50] плащ, upal, _uray, _rdec,
   {{0x799a0c05,0x3d040034,0xdce11656,0x22490565}},	//   nntw, रणों_, _polč, rvak_,
   {{0x61ed7b3e,0xe520007a,0x80070ae3,0x3f8f7b3f}},	//   spal, _बाति_, ючае, tigu_,
   {{0x61ed7b40,0x2612030b,0x2d9e0218,0xdb000103}},	//   ppal, _तिमी_, _ajte_, yomá,
   {{0xfce52fd4,0x3f8f7b41,0x63ad2012,0x249f020e}},	//   поло, rigu_, moan, ğumu_,
   {{0x63ad7b42,0x799a023e,0x11da00ca,0xdce10141}},	//   loan, jntw, _לחשב, _tolč,
   {{0x7afd003e,0x3f8f7b43,0x69c800d2,0x63780139}},	//   ðsto, pigu_, dmde, _mínn,
   {{0x7bc27b44,0xdb000d9f,0x69c81044,0x63ad7b45}},	//   _chou, tomá, emde, noan,
   {{0xdb0e00e3,0x63ad020a,0x3eb901cd,0x00000000}},	//   ódál, ioan, _ást_, --,
   {{0x8d770dd0,0x63ad7b46,0xc8b802d5,0xdb007b47}},	//   _بارا, hoan, ॉइंट, romá,
   {{0xa3bd10ed,0xf8ce1efb,0x63ad7b48,0x6aa20167}},	//   ेगा_, _हृदय, koan, _exof,
   {{0xdb000146,0x63ad00b3,0xa5bb73b7,0x91790023}},	//   pomá, joan, stól, _lần_,
   {{0x7bc97b49,0x63ad7b4a,0xa5bb0072,0x644300c6}},	//   mmeu, doan, ptól, _šnip,
   {{0x7bc27b4b,0x00000000,0x00000000,0x00000000}},	//   _zhou, --, --, --,
   {{0x69c37b4c,0x63ad002d,0x77bd0072,0x9879006e}},	//   _ihne, foan, séxa, _לאַט,
   {{0x63ad7b4d,0x6b9b7b4e,0x46a6084c,0x7bc9029a}},	//   goan, nnug, _найв, nmeu,
   {{0x171b00a1,0x63b67b4f,0x63787b50,0x00000000}},	// [7d60] _הופע, rlyn, _fínn, --,
   {{0x0f140455,0x91790023,0x63780065,0x63b67b51}},	//   डल्स_, _cần_, _gínn, slyn,
   {{0x63b600d4,0x63ad01ce,0x443c05aa,0x00000000}},	//   plyn, boan, _èv_, --,
   {{0x63a97b52,0x63ad7b53,0x77b60072,0x53a60e06}},	//   čenc, coan, fáxi, _хамб,
   {{0x69c800f0,0x69c30364,0x7bc901cb,0x00000000}},	//   ymde, _ohne, dmeu, --,
   {{0x7bc20054,0x64582fd7,0x25740212,0x917900fe}},	//   _shou, _àvis, _sälj_, _gần_,
   {{0x7bc200f9,0x6458124d,0x62840036,0x00000000}},	//   _phou, _ávid, lzio, --,
   {{0x26c00036,0x316a02a1,0xa2b3049d,0x69c37b54}},	//   _ozio_, _hobz_, _आडम्, _ahne,
   {{0x62840465,0x25740222,0xc3330054,0x0d8600ae}},	//   nzio, _välj_, תוח_, _елан,
   {{0x63ad4750,0x628470e5,0x69c307bc,0x6371320e}},	//   zoan, izio, _chne, _våni,
   {{0xac7606fa,0x7bc20054,0x63ad0051,0x201a00f9}},	//   _عائش, _thou, yoan, nupi_,
   {{0x62840a00,0xba2a001c,0xe69500c2,0x6f020239}},	//   kzio, _هستم_, димы, naoc,
   {{0x2be40081,0x27e0038d,0x00000000,0x00000000}},	//   _গিয়ে_, _činu_, --, --,
   {{0xa2cd3162,0x62841c8a,0x69c301b9,0xf80600ae}},	//   _दृष्, dzio, _ghne, _ечин,
   {{0x92b900c7,0x63ad7b55,0x628400e5,0x26c067a5}},	//   _চলে_, toan, ezio, _ezio_,
   {{0x201a7b56,0x636808f9,0xd6db00ae,0x46ae0129}},	//   dupi_, пруг_, _утк_, ọtọ_,
   {{0xa2cd0f82,0x6f027b57,0x63ad7b58,0x623400d3}},	// [7d70] _दृश्, daoc, roan, нету,
   {{0x645801b3,0x932700cd,0x291e7b59,0x63ad7b5a}},	//   _švie, _کردن, ngta_, soan,
   {{0xf1c800e3,0x62847b5b,0x63ad62c2,0x20077b5c}},	//   أولى_, azio, poan, éni_,
   {{0x27f8045e,0x6f0200e7,0x31190096,0x63780065}},	//   árny_, gaoc, _पाकृ_, _jínl,
   {{0xa3e30455,0xa3aa00a5,0x09140081,0x32540138}},	//   _फंड_, खकर_, ত্যু_, _звяр,
   {{0xdd9104f4,0xed560360,0x361c00ca,0xee380120}},	//   ضوع_, дош_, מודד, яні_,
   {{0x4034222a,0x201a028d,0x8c4200c2,0x6f020134}},	//   _перс, cupi_, веще, baoc,
   {{0x291e7b5d,0xdce101d3,0xf09200ca,0x26db019f}},	//   egta_, _dolā, _סנן_, _ngqo_,
   {{0x7bc94af2,0x2bdf00aa,0x00000000,0x00000000}},	//   rmeu, _पंवा, --, --,
   {{0x98bc00d9,0x291e0063,0x64480537,0x7bc901cb}},	//   _savā_, ggta_, ædik, smeu,
   {{0x7d037b5e,0x07a63f19,0xc7a61e70,0xa3ad31f4}},	//   mans, данн, динк, गवा_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2eff020d,0x00000000,0x00000000,0x00000000}},	//   _meuf_, --, --, --,
   {{0xa3b60e50,0xdd990154,0x6f020117,0x89da021e}},	//   _चीज_, _dwňg_, zaoc, _וחסי,
   {{0x2eff2db2,0x6fad00a4,0x98bc00e8,0x00000000}},	//   _oeuf_, टकां, _tavā_, --,
   {{0x39477b5f,0x2eff025a,0x7d035389,0x63780094}},	//   _hans_, _neuf_, hans, _víno,
   {{0x39477b60,0x6f021711,0x7d0300db,0x71760037}},	// [7d80] _kans_, vaoc, kans, وهرا,
   {{0x62847b61,0x201a7b62,0x1de10251,0x76447b63}},	//   rzio, tupi_, _पढ़त, _isiy,
   {{0x7d037b64,0x39477b65,0x6f021711,0x83c63a7a}},	//   dans, _mans_, taoc, _обож,
   {{0x44441723,0x39471b50,0x20070161,0x628401e9}},	//   _is_, _lans_, ânia_, pzio,
   {{0x7d037b66,0x6f020a39,0x201a0167,0x644e00f2}},	//   fans, raoc, supi_, lvbi,
   {{0x7d037b67,0x39473195,0x753c289d,0xa3e31e9f}},	//   gans, _nans_, nerz, _फूड_,
   {{0x672403c6,0xac970190,0x6378033c,0x00000000}},	//   _ocij, ونها_, _línm, --,
   {{0x7644039f,0x753c7b68,0xdd990154,0x444406e5}},	//   _osiy, herz, _awňd_, _ms_,
   {{0x44440b4b,0x753c39a5,0x00000000,0x00000000}},	//   _ls_, kerz, --, --,
   {{0x44447b69,0x7d037b6a,0x98bc020a,0x00000000}},	//   _os_, cans, _navă_, --,
   {{0x39471729,0x6d5a7b6b,0x753c7b6c,0x76447b6d}},	//   _dans_, _inta, derz, _asiy,
   {{0x6d487b6e,0x657e5f35,0x6d4a2bf6,0x55ea0033}},	//   _hada, _alph, ldfa, _কয়েক_,
   {{0x44441723,0xa5bb00e3,0x753c01bf,0xe4e700d6}},	//   _as_, ltói, ferz, дібн,
   {{0x6d4a4192,0x39474f24,0x637117d2,0x753c7b6f}},	//   ndfa, _gans_, _lånt, gerz,
   {{0x45d42820,0xa5bb00e3,0x6d481dbd,0x76440201}},	//   торс, ntói, _mada, _esiy,
   {{0x6d487b70,0x44447b71,0x7d037b72,0x69d87b73}},	//   _lada, _ds_, zans, _hive,
   {{0x44447b74,0x7d037b75,0x69d87b76,0x2eff00e7}},	// [7d90] _es_, yans, _kive, _reuf_,
   {{0xca4800de,0x7c2a7b77,0x398002f1,0x69d85f93}},	//   _mờ_, ktfr, _fòse_, _jive,
   {{0x69d80018,0x661d7b78,0x7d037b79,0x3f1511db}},	//   _mive, lusk, vans, едес,
   {{0x69d82555,0x7d037b7a,0x64457b7b,0x6d480694}},	//   _live, wans, _ishi, _aada,
   {{0x6d487b7c,0x42790130,0xdd9501b6,0x8db5013f}},	//   _bada, _זאָג, нады, нскі,
   {{0x6d487b7d,0x32091821,0x917900fe,0x7c2a2c28}},	//   _cada, msay_, _dẫn_, ftfr,
   {{0x7d037b7e,0xfc310d74,0xabd507c8,0x7c2a0537}},	//   rans, احت_, нциј, gtfr,
   {{0x39471bdd,0x6d5a7b7f,0x7d037b80,0x661d45e6}},	//   _sans_, _enta, sans, kusk,
   {{0x32097b81,0x7d031c04,0x6d487b82,0xca480019}},	//   nsay_, pans, _fada, _cờ_,
   {{0x6d487b83,0x64457b84,0xf99100e3,0x661d7b85}},	//   _gada, _oshi, طبخ_, dusk,
   {{0x7b6723a3,0x6445023f,0x673d7b86,0xb9072c82}},	//   _отде, _nshi, fesj, _भल_,
   {{0x7d0177b1,0x673d025a,0x70dc24eb,0xc052006e}},	//   _hels, gesj, _बल्ल, אזט_,
   {{0x753c7b87,0x64457b88,0x44447b89,0x6d487b8a}},	//   terz, _ashi, _ss_, _yada,
   {{0x69d87b8b,0x44447b8c,0x7d017b8d,0x32095475}},	//   _give, _ps_, _jels, dsay_,
   {{0x4444005a,0x29057b8e,0x64a315e5,0x753c7b8f}},	//   _qs_, mala_, гара, rerz,
   {{0x29056706,0x38781484,0x753c008f,0x661d1b3c}},	//   lala_, ørre_, serz, busk,
   {{0x44447b90,0x6445019f,0xd2a744b2,0x661d7b91}},	// [7da0] _ws_, _eshi, екте_, cusk,
   {{0x29057b92,0x6445023b,0x27e90307,0xe2970e05}},	//   nala_, _fshi, _čanj_, хау_,
   {{0x44447b93,0xc7b908c5,0x290500ae,0x06f40caf}},	//   _us_, suđe_, iala_, _आभाव_,
   {{0xdee6117a,0x6d48320b,0xb17b0ec9,0x8520009f}},	//   ходи, _sada, _ståt, _बाँट_,
   {{0x6d487b94,0x7d010018,0x61e400bd,0xa2d61f11}},	//   _pada, _bels, qqil, _سيست,
   {{0x29051206,0x6d487b95,0xd00a0d62,0xa3d80c9c}},	//   jala_, _qada, _неге_, ादक_,
   {{0x6d487b96,0x69d84bff,0x7d017b97,0xca480023}},	//   _vada, _rive, _dels, _sờ_,
   {{0x6d487b98,0x69d87b99,0x5a341676,0x7c2a7b9a}},	//   _wada, _sive, внит, rtfr,
   {{0x7d017b9b,0x7bd932c3,0x6d5a005c,0xada6004b}},	//   _fels, _diwu, _tnta, _заал,
   {{0x29057b9c,0x7d017b9d,0xf8ab00de,0x7bde7b9e}},	//   gala_, _gels, ười_, ípus,
   {{0x69d83c46,0x673d1394,0x00000000,0x00000000}},	//   _vive, tesj, --, --,
   {{0x32094055,0x661d4949,0x7ae93bec,0xca480019}},	//   ysay_, tusk, ccet, _tờ_,
   {{0x69d80ba0,0x7d017b9f,0x95cb22f6,0x673d7ba0}},	//   _tive, _yels, зува_, resj,
   {{0xae02007d,0x661d2429,0xceb30341,0xbf0c009d}},	//   रीयन_, rusk, ריש_, हणुन_,
   {{0x7bd91114,0x280202c6,0xf484224a,0x94a82b99}},	//   _yiwu, ásně_, гутн, етта_,
   {{0x63a90995,0x661d7ba1,0x32092621,0x58bb00ca}},	//   čeno, pusk, tsay_, _ממוצ,
   {{0xdb1b2226,0xaac9030b,0xdcfa022b,0x00000000}},	// [7db0] fluê, ाइएक, _altč, --,
   {{0x644501bb,0x660d039f,0x320934bb,0x2007016d}},	//   _tshi, _ivak, rsay_, ânio_,
   {{0xbf0c0454,0x64454753,0x21210063,0x7d0173f0}},	//   हणून_, _ushi, rghh_, _rels,
   {{0x29051769,0x7d011484,0x29fd0220,0x660d0559}},	//   zala_, _sels, yňa_, _kvak,
   {{0x29057ba2,0x7d010f56,0xe8d90023,0x61fd008c}},	//   yala_, _pels, _đọ_, _uwsl,
   {{0x236900cc,0x29fd0220,0x7ae97ba3,0xdb00002b}},	//   ljaj_, vňa_, wcet, comú,
   {{0xae02009f,0x7bd9001c,0x00000000,0x00000000}},	//   रीबन_, _piwu, --, --,
   {{0x290567dc,0x660d02e6,0xd9c9000c,0x257401bf}},	//   wala_, _ovak, रष्ट, _hält_,
   {{0x7ae9020a,0x7d017ba4,0xa3e30caf,0x99dd0031}},	//   rcet, _tels, _फूस_, yvňu,
   {{0x7ae91ac8,0x29fd0e4b,0x7dc4015e,0x00000000}},	//   scet, rňa_, ròsc, --,
   {{0x29057ba5,0x788620cc,0x98a51352,0x7bd90449}},	//   rala_, _révé, тине, _tiwu,
   {{0xc6260081,0xf4270081,0x23690063,0x29fd0031}},	//   যবসা_, মবার_, jjaj_, pňa_,
   {{0x23692cea,0x81e60081,0xe9ce061b,0x07a3020f}},	//   djaj_, _যৌন_, _вк_, раян,
   {{0x2905067d,0x660d1b30,0x64a67ba6,0x00000000}},	//   qala_, _dvak, вага, --,
   {{0xe1ff0032,0x232a45b1,0x00000000,0x00000000}},	//   _awó_, мови_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe2974b8b,0x91e33974,0x3a2d7ba7,0x59c60034}},	// [7dc0] ват_, иоте, ntep_, _रीडर,
   {{0x91a700fe,0x161700c3,0xdce815d7,0x307600d3}},	//   _địa_, _तितर_, _podč, куес,
   {{0x63787ba8,0x660d21f7,0x00000000,0x00000000}},	//   _líni, _zvak, --, --,
   {{0x443a7ba9,0xdb00227a,0x00000000,0x00000000}},	//   _ipp_, llmö, --, --,
   {{0x25740212,0xae0200c3,0x443a00d8,0x3e340076}},	//   _fält_, _रौशन_, _hpp_, افتر,
   {{0x1ea933c6,0xa5bb0131,0x443a7baa,0x3c0c02c6}},	//   راني_, stóv, _kpp_, těv_,
   {{0xa2d607ad,0x50c6121d,0x443a7bab,0x61f6007b}},	//   _मृत्, _वरिष, _jpp_, lpyl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443a7bac,0xa3c90285,0x00000000,0x00000000}},	//   _lpp_, _लीफ_, --, --,
   {{0x443a00f3,0x3f867bad,0x1e830426,0xa3c900c3}},	//   _opp_, lhou_, _тлум, _लीन_,
   {{0x660d03ce,0x99630077,0xcad20294,0x63787bae}},	//   _svak, ртыл, _gịnị, _tính,
   {{0xa3e6000f,0x3f867baf,0x2b4d0131,0x68f5020e}},	//   _पढ़_, nhou_, cdec_, ızda,
   {{0x6b8208dd,0xb5fb0018,0xa9340ff1,0x3a2d0072}},	//   _ilog, lyáz, _белш, ctep_,
   {{0xe85416cc,0xdb11003e,0x00000000,0x00000000}},	//   _منتد, ðgön, --, --,
   {{0x6b82052f,0xdb1b0428,0x984a008f,0x3f86084e}},	//   _klog, fluè, _цяла_, khou_,
   {{0x443a0350,0x31db1462,0x64430131,0x4de2074c}},	//   _dpp_, बद्ध, _ânim, खदाई_,
   {{0x28ce007d,0x2369033b,0x31350e05,0x6b82007e}},	// [7dd0] हेरि, rjaj_, леар, _mlog,
   {{0x7c3a7bb0,0x6b827bb1,0x2b4d0094,0x224d0234}},	//   _optr, _llog, zdec_, _šeks_,
   {{0x6b82026e,0x443a171d,0x43951751,0x00000000}},	//   _olog, _gpp_, _банс, --,
   {{0x547a0266,0x5ecc0033,0x3f860f5a,0x00000000}},	//   _נטרו, িশনে, ghou_, --,
   {{0xb2872787,0x3ea905fe,0x61e20037,0x443a033b}},	//   _рынк, çat_, íolt, _zpp_,
   {{0x6b822f8e,0x3ea9003d,0x7c3a0113,0xdca50e1d}},	//   _alog, ħat_, _bptr, лали,
   {{0xe8d90019,0x637800e3,0xe8df0174,0xb5fb0103}},	//   _đỏ_, _síni, ndụl_, gyáz,
   {{0x3f8600d4,0x6b827bb2,0x291801cd,0x0a497bb3}},	//   chou_, _clog, óran_, езий_,
   {{0xe9d93f98,0x69ca0080,0x29c2003e,0x2b4d7bb4}},	//   нки_, _bhfe, rðan_, rdec_,
   {{0x6b827bb5,0x2b4d0063,0x6e3b039f,0x00000000}},	//   _elog, sdec_, _ipub, --,
   {{0xa3e3121d,0x6b827bb6,0x2d8702bc,0xb7b60174}},	//   _फूल_, _flog, mhne_, bụl,
   {{0xdebb0d2a,0x0e8e0134,0x2919020e,0xb8ee0139}},	//   _sauƙ, kịlị_, şsa_, _lẹhì,
   {{0x64577bb7,0x7afb048e,0x6378003e,0xaac700bc}},	//   _arxi, mbut, _kínv, _लरिक,
   {{0xceb2004f,0x1a9a0130,0x3f867bb8,0x4a9a00c1}},	//   צים_, _אינע, zhou_, _אינג,
   {{0xc7b908c5,0x3ceb70de,0x23360636,0x00000000}},	//   suđa_, _चलने_, лхар, --,
   {{0xe520007a,0x6e3b0034,0x7afb7bb9,0xf77205bc}},	//   _बाकि_, _opub, nbut, _چاک_,
   {{0x31710113,0x0e8e0174,0xa5bb5991,0xf7720103}},	// [7de0] _bozz_, gịlị_, dróf, _ناک_,
   {{0x2d870087,0x7afb0113,0x6fec013c,0x00000000}},	//   jhne_, hbut, _ağca, --,
   {{0xef1a1121,0x443a7bba,0x3f860665,0x61f60565}},	//   еме_, _upp_, thou_, spyl,
   {{0x77bd03be,0x20550fb0,0x7afb0087,0xa5bb0328}},	//   téxi, штур, jbut, stót,
   {{0x63a432a7,0x3f86057a,0x6b8201b9,0x7c3a0231}},	//   mnin, rhou_, _rlog, _sptr,
   {{0x63a47bbb,0xf98754c8,0xc0e342e0,0xa5bb7bbc}},	//   lnin, _طب_, _горк, ltór,
   {{0x6b821e36,0x6c660018,0x63a47bbd,0x00000000}},	//   _plog, العہ_, onin, --,
   {{0x63a47bbe,0x7afb1ba1,0xa5bb386a,0xbb740859}},	//   nnin, gbut, cróf, ргиј,
   {{0xe8d900ef,0x3f840496,0x6b820087,0x63a468db}},	//   _đề_, _ilmu_, _vlog, inin,
   {{0xdd8f300d,0x7afb6aa7,0xb9290174,0x2d9802c3}},	//   _فوق_, abut, matụ_, _öre_,
   {{0x63a40b6a,0xa5bb00a5,0x61e607ac,0xa3b404df}},	//   knin, któr, _lukl, टवा_,
   {{0x6b8200e9,0x63a47bbf,0x8c1b040a,0xf09300ca}},	//   _ulog, jnin, _טובי, מנת_,
   {{0x63a40bab,0x7ae27bc0,0x91b90861,0x00000000}},	//   dnin, _igot, ्तमै, --,
   {{0xceb30105,0x63a45d92,0x7d0a068d,0x63780088}},	//   מיר_, enin, nafs, _mínu,
   {{0x7ae2039f,0x63a40088,0x645822a4,0x61e67bc1}},	//   _kgot, fnin, _ávil, _aukl,
   {{0x63a45e11,0x98132761,0x7d0a7bc2,0x7bc000dc}},	//   gnin, _ابوا, hafs, nlmu,
   {{0x31710ca7,0x61e60113,0x799a0a4b,0xd7f8020a}},	// [7df0] _pozz_, _cukl, oitw, lpă_,
   {{0xf5277bc3,0xa5bb7bc4,0x3f84510d,0x61e600d4}},	//   _сфин, atór, _almu_, _dukl,
   {{0x31c40084,0x63a47bc5,0x533517c5,0xa5bb01f9}},	//   сств, bnin, _кент, tróf,
   {{0xa5bb2027,0x7ae27bc6,0x63a40141,0xa3d60034}},	//   ctór, _ngot, cnin, िगण_,
   {{0x11d900e3,0x44317bc7,0x2d870091,0xaf0400d6}},	//   _لوحة_, ltz_, thne_, спіл,
   {{0x394e005c,0x7ae21186,0x3f843045,0xbdf8071c}},	//   _nafs_, _agot, _elmu_, ارنا_,
   {{0x44317bc8,0x8bf00081,0x799a1082,0x7afb5e11}},	//   ntz_, _টিউন_, ditw, tbut,
   {{0x69ca0f35,0x61e603e0,0x443101e9,0x543c00c1}},	//   _सीबी, _yukl, itz_, געהא,
   {{0xa3d60be4,0x7afb0800,0x2d8753d0,0xfaa507cb}},	//   िगत_, rbut, phne_, рапо,
   {{0x44237bc9,0x7ae20a00,0x661d0786,0x8e840037}},	//   kuj_, _egot, drsk, _الكه,
   {{0x63a44bb2,0x661d7bca,0x2d857bcb,0x442303e3}},	//   ynin, ersk, _ille_, juj_,
   {{0x6d437bcc,0x3ebf0eac,0x44230ed9,0x63a40212}},	//   lena, _kyut_, duj_, xnin,
   {{0x63a47bcd,0x44317bce,0xe8ee0d9b,0x799a2d3b}},	//   vnin, etz_, _мл_, bitw,
   {{0x6d4302e6,0x399b0065,0x44317bcf,0x63780076}},	//   nena, _dásè_, ftz_, _línt,
   {{0x44230067,0xa5071a18,0x661d7bd0,0x61e67bd1}},	//   guj_, реса_, arsk, _sukl,
   {{0x61e6042d,0x6d437bd2,0x29072168,0x6b9b00e5}},	//   _pukl, hena, _hena_, niug,
   {{0x6d437bd3,0x29077bd4,0x63a47bd5,0x27e701ce}},	// [7e00] kena, _kena_, rnin, _hunn_,
   {{0x63a40073,0xa5bb7bd6,0x69c17bd7,0xda18009d}},	//   snin, stór, nlle, _दिसत_,
   {{0x69c117ec,0x29077bd8,0x63780102,0x63a47bd9}},	//   ille, _mena_, _sínu, pnin,
   {{0x2d8521ad,0x29077bda,0x61e67bdb,0xcad20294}},	//   _alle_, _lena_, _tukl, _dịjị,
   {{0x2bdf0f78,0x7d0a0dc1,0x3a3d0085,0x799a02a4}},	//   _पंजा, tafs, _npwp_, yitw,
   {{0x29071e4f,0x66047bdc,0xdd8f0f98,0xd65700ca}},	//   _nena_, _mwik, وون_, יינת_,
   {{0xa0a36600,0xa067008f,0x29180076,0x3f9c020d}},	//   _дард, _кара_, óram_, évus_,
   {{0x27e00d64,0x2d8510af,0x6f0b039f,0x69c17bdd}},	//   _niin_, _elle_, cagc, elle,
   {{0x6d433ad9,0x29077bde,0xfe020ed3,0x7d0a7bdf}},	//   bena, _bena_, रीशस_, pafs,
   {{0x63a90c00,0x6d430e4d,0x27e0009c,0x27e70120}},	//   čeni, cena, _aiin_, _bunn_,
   {{0xe8d9011b,0x2bdf1d48,0x290702a7,0x3ceb0b89}},	//   _để_, _पंचा, _dena_, _चलते_,
   {{0x27e702e5,0x7ae202dd,0x779300cd,0x6b9b00e5}},	//   _dunn_, _ugot, تیبا, ciug,
   {{0x27e07be0,0x29077be1,0x799a0a4b,0x661d000b}},	//   _diin_, _fena_, pitw, ursk,
   {{0x44237be2,0x6604134a,0x2d9c0052,0x27e70120}},	//   tuj_, _dwik, nive_, _funn_,
   {{0x290c7be3,0x7d087be4,0x67d50012,0x98a50138}},	//   mada_, _meds, _локу, delė_,
   {{0x290c7be5,0x6d437be6,0x44230c6f,0x052700c7}},	//   lada_, zena, ruj_, য়ের_,
   {{0x44237be7,0x29070201,0x6d437be8,0xa7870260}},	// [7e10] suj_, _yena_, yena, _مشکو,
   {{0x63787535,0x7d080501,0x29077be9,0x764d4b62}},	//   _sínt, _neds, _xena_, _isay,
   {{0x6378002b,0x6d433f43,0x2d9c7bea,0x5067016d}},	//   _pínt, vena, dive_, штаа,
   {{0x290c7beb,0x6d437bec,0x00000000,0x00000000}},	//   hada_, wena, --, --,
   {{0x7d080021,0xef18004d,0xa3b40096,0xb7b60134}},	//   _beds, рмі_, टवर_, wụk,
   {{0x2d9c7bed,0x2bdf0d7a,0x22490124,0x63780031}},	//   give_, _पूजा, mwak_, _fíns,
   {{0xeb993119,0x290c7bee,0x29077bef,0x672d0542}},	//   лик_, dada_, _rena_, _ocaj,
   {{0x29077bf0,0x672d01fa,0x1b495cb1,0x7d087bf1}},	//   _sena_, _ncaj, узии_, _eeds,
   {{0x290c7bf2,0x6d437bf3,0x69c10472,0x61ed7bf4}},	//   fada_, pena, tlle, nqal,
   {{0x8d74054f,0x27e07bf5,0x7d7400e3,0x6f0905e3}},	//   _والا, _siin_, _والط, _heec,
   {{0x69c102ad,0x66e63e86,0x6d8a0018,0xb8ef0285}},	//   rlle, йона, _حملہ_, _शर_,
   {{0x4cd00081,0x29070201,0x69c17bf6,0x07a600ae}},	//   _স্কু, _wena_, slle, самн,
   {{0x290c7bf7,0x2907068d,0x6fda00b6,0x6d680131}},	//   bada_, _tena_, _důch, _àsaú,
   {{0x225e033d,0x6f097bf8,0x27e702c3,0x27180174}},	//   _čtk_, _leec, _tunn_, ọn_,
   {{0xf7f52c66,0x443e0428,0x27e07bf9,0x63a802c6}},	//   _استد, ït_, _tiin_, édno,
   {{0x087600c1,0x2d9c7bfa,0x66047bfb,0x9f9e0052}},	//   _לעצט_, zive_, _twik, rçës_,
   {{0xae1c218b,0x224900f9,0x66047bfc,0x98a50138}},	// [7e20] _निधन_, gwak_, _uwik, telė_,
   {{0x394517fc,0xa06a0c3f,0x63bd058f,0x00000000}},	//   nels_, лаза_, _eksn, --,
   {{0x63780065,0x557700ca,0xa99a006e,0x7ee60037}},	//   _dínr, _העין_, נבער, مكان,
   {{0x290c0b0b,0x543b00c1,0x3945057a,0xdb1b0042}},	//   zada_, _געטא, hels_, fluí,
   {{0x290c7bfd,0x2d9c2849,0x394534d0,0x63780032}},	//   yada_, tive_, kels_, _fínr,
   {{0xa116037f,0x13bd0081,0x00000000,0x00000000}},	//   _دوست, _আওয়, --, --,
   {{0x308600e3,0x2d9c4bf9,0x39457bfe,0x290c7bff}},	//   _الأف, rive_, dels_, vada_,
   {{0x7d08043e,0x290c7c00,0x207b0142,0x394502ac}},	//   _weds, wada_, _גאלא, eels_,
   {{0x290c7c01,0xdb1b693a,0x39457c02,0x6e9600e3}},	//   tada_, cluí, fels_, _الذا,
   {{0x99660e45,0xdb003916,0xd90e00d0,0xd7fa30fa}},	//   стил, tomó, ریب_, лум_,
   {{0x91bb0089,0x6f090172,0x1cba2268,0xc1bb0142}},	//   רמיי, _yeec, _صائب_, רמיש,
   {{0xe61f0161,0x3a245b1a,0xdb007c03,0x00000000}},	//   trô_, pump_, romó, --,
   {{0x290c06db,0x8f9b00a1,0xfa33001c,0x39451063}},	//   pada_, ריכי, _فرود, bels_,
   {{0x290c23f4,0x394576c0,0x00000000,0x00000000}},	//   qada_, cels_, --, --,
   {{0x499b7c04,0x3f9d01c2,0xa2db314f,0x96f9534b}},	//   _תשוב, yiwu_, पेन्, _кейт_,
   {{0x764d1114,0x07a41fdb,0x26120096,0x00000000}},	//   _tsay, _најн, _तिची_, --,
   {{0x7dcd7c05,0x52150110,0x06d70033,0x00000000}},	// [7e30] núsc, юдат, _থ্রি, --,
   {{0x6f090072,0x61ed31ed,0x35f80037,0x27e10094}},	//   _seec, rqal, _اريد_, _činy_,
   {{0xa5bb07ff,0xd49800d3,0x9ee90452,0x6f09034b}},	//   prób, _гря_, لفضل_, _peec,
   {{0xd7c90b94,0x657700dd,0xe7c91677,0x69ac009d}},	//   रतिच, _hoxh, रतिप, ीकडी,
   {{0x7dcd05fe,0x6db55566,0x61ed013c,0xa3d600c3}},	//   júsc, ойду, qqal, िगर_,
   {{0xed59439e,0xdb020102,0x6f09026d,0x00000000}},	//   рок_, _skoð, _weec, --,
   {{0xe7c92ebd,0xd7c9009d,0x39457c06,0xc05807bf}},	//   रताप, रताच, vels_, _літ_,
   {{0xa2d01e5e,0xdd990154,0x1ee70a85,0x39457c07}},	//   _दरम्, _kwňk_, _طوطی_, wels_,
   {{0x69251e78,0xb4fb0096,0x39450b87,0xdb00015e}},	//   омпа, ्राय_, tels_, tomò,
   {{0xe8df00ef,0x3cf100a7,0x3979007b,0x6577039f}},	//   _giới_, _üzv_, рсию_, _noxh,
   {{0xa3d9143d,0x39457c08,0x0cab008f,0xa6db04c8}},	//   ाषा_, rels_, _стаи_, seðl,
   {{0x39457c09,0x656500fe,0x00000000,0x00000000}},	//   sels_, _anhh, --, --,
   {{0x39457c0a,0x70c61362,0x0556008f,0xa9693a1f}},	//   pels_, _वर्ल, отвя, _вила_,
   {{0x4cd00033,0x00000000,0x00000000,0x00000000}},	//   _স্টু, --, --, --,
   {{0xe73200e3,0xa5bb0034,0xc7b90234,0x776400bd}},	//   _قصة_, wróc, srđa_, _tnix,
   {{0xd2521673,0x66020052,0x59b30285,0x00000000}},	//   ونز_, _çoko, ुतकर, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [7e40] --, --, --, --,
   {{0x602604a1,0x65770052,0x10a63e1e,0xb143002d}},	//   жджа, _goxh, оизн, мнул,
   {{0xa2e60012,0x25e30251,0xf21e00a5,0xd46a00d3}},	//   _монд, _टूटी_, यूज़_, _тине_,
   {{0xddc90067,0x645e00e5,0x7dcd05e6,0xd00f33e7}},	//   _treś, _irpi, yúsc, ئلن_,
   {{0x88cf0081,0x645e00c4,0xa3e33516,0x63a900c4}},	//   রশিক, _hrpi, _फूट_, čent,
   {{0x7c66048f,0xdd9013c3,0x6a800065,0x00000000}},	//   قابل, عوث_, _láfú, --,
   {{0x0b8a0e3a,0x00000000,0x00000000,0x00000000}},	//   исии_, --, --, --,
   {{0x3860050d,0x224200dc,0x261b0285,0x00000000}},	//   _čir_, _kpkk_, _बिली_, --,
   {{0x6f026df6,0x22420063,0x9f4d0364,0xe946007b}},	//   mboc, _jpkk_, _hieß_, охно,
   {{0x2fc67c0b,0x22420063,0x290a7c0c,0xa3ea0285}},	//   llog_, _mpkk_, úba_, मदा_,
   {{0x6c4a0068,0x2fc67c0d,0x8157006e,0x65770090}},	//   _خلاف_, olog_, קסטע_, _roxh,
   {{0x6f027c0e,0xa3c900aa,0x69ca0034,0x00000000}},	//   nboc, _लीं_, _सीरी, --,
   {{0x8bd70130,0xdb0901bf,0x9f4d0364,0x66020233}},	//   _וואו_, ließ, _ließ_, _çokl,
   {{0x26c500d9,0x644000ae,0x94ab00e5,0x281400d1}},	//   ālo_, ămin, атба_, _فوتس,
   {{0x7dcd0037,0xe8d900de,0xdb0901bf,0x645e0357}},	//   núsa, _đệ_, nieß, _crpi,
   {{0x27fe00ec,0x645e0234,0x8c1b00ca,0x2fc60113}},	//   mptn_, _drpi, יולי, jlog_,
   {{0x51f8055b,0xe1f00688,0xdb090364,0xe80602d5}},	// [7e50] жную_, نسل_, hieß, वीरा_,
   {{0x6e221b30,0x7d1a0027,0x94d500d3,0x162000c3}},	//   drob, _ndts, _нопц, _बितर_,
   {{0x6616025b,0xf48500cd,0x6e227c0f,0x2fc600f0}},	//   _zvyk, _رادی, erob, flog_,
   {{0x63a90074,0x2fc6015c,0x4fe8004b,0xb4d7052c}},	//   čens, glog_, імін_, िधी_,
   {{0x8d651612,0x6e227c10,0x6cf80096,0x51872813}},	//   звле, grob, ुरंग_, _дува,
   {{0xf2d20341,0xfe1c0ded,0x00000000,0x00000000}},	//   _נעם_, _निरस_, --, --,
   {{0x1fa7086a,0x60181b60,0x4e17030b,0x30a419e8}},	//   _драг, _моря_, _निकै_, _жртв,
   {{0x997c00e8,0x31780154,0x00000000,0x00000000}},	//   _jāņu_, _zorz_, --, --,
   {{0x6f1b0880,0x00000000,0x00000000,0x00000000}},	//   _iduc, --, --, --,
   {{0xacf4015a,0x00000000,0x00000000,0x00000000}},	//   _قسمت, --, --, --,
   {{0x7c5900cd,0xc8d506eb,0x00000000,0x00000000}},	//   _دلار_, डेंट, --, --,
   {{0xe73a4a30,0x7b6407df,0xaadf1677,0xe8df00fe}},	//   щем_, _отче, _पृथक, _giời_,
   {{0x9877033b,0x00000000,0x00000000,0x00000000}},	//   _išče_, --, --, --,
   {{0x386a0080,0x645e00c4,0x00000000,0x00000000}},	//   óirí_, _prpi, --, --,
   {{0x6e22007f,0x26183aee,0x2fc66ffc,0x00000000}},	//   zrob, _भटकी_, ylog_, --,
   {{0x6d860088,0xfbcb0179,0x6e22041c,0xf7723160}},	//   _aðal, ातिम, yrob, _ساب_,
   {{0xe8d900ef,0x00000000,0x00000000,0x00000000}},	// [7e60] _độ_, --, --, --,
   {{0x6f1b002d,0x645e4ce2,0x7dc405fe,0xdce1022b}},	//   _aduc, _trpi, pòsi, _anlč,
   {{0x757b00a1,0xdefa007b,0x645e007b,0xfbcb0f8f}},	//   _הטיפ, был_, _urpi, ाताम,
   {{0x91e64faa,0x442a007a,0x444400ca,0x98be00ae}},	//   _номе, mub_, _ip_, letă_,
   {{0x2fc601a2,0x443808fa,0x645c7c11,0x444454f4}},	//   rlog_, ltr_, lvri, _hp_,
   {{0x6f1b72a7,0x6e227c12,0x44447c13,0x6f022b39}},	//   _educ, rrob, _kp_, sboc,
   {{0x44387c14,0x442a01d4,0x645c0629,0x00000000}},	//   ntr_, nub_, nvri, --,
   {{0x444400a1,0x7dcd3176,0x76440154,0x00000000}},	//   _mp_, rúsa, _opiy, --,
   {{0x442a7c15,0x3f860146,0xaa58327e,0xa5bb7c16}},	//   hub_, mkou_, ципу_, drón,
   {{0x44447c17,0x442a5369,0x3f86035c,0x41be1c0a}},	//   _op_, kub_, lkou_, ्तिस,
   {{0x444400a5,0xdd8f00e3,0x442a7c18,0x6d4a0051}},	//   _np_, _حول_, jub_, mefa,
   {{0x3f8614b1,0x442a7c19,0x6d4a7c1a,0x7e600234}},	//   nkou_, dub_, lefa, _krmp,
   {{0x44440c3e,0xf1be0bd9,0xab270c10,0x41be1e05}},	//   _ap_, ्तान, _хоча_, ्तास,
   {{0x6d4a7c1b,0xcaa500e3,0x44380653,0x3f860094}},	//   nefa, _تصمي, ftr_, hkou_,
   {{0x69da01bf,0x442a1abf,0x69c7003d,0x7c3801c0}},	//   mmte, gub_, ċjet, ntvr,
   {{0x69c87c1c,0x6d4a7c1d,0x9f440052,0x3f860094}},	//   llde, hefa, _dimë_, jkou_,
   {{0x26dd02b4,0x290e7c1e,0x201c0e94,0x443800f0}},	// [7e70] _àwo_, _kefa_, švil_, atr_,
   {{0x290e006d,0x442a00bc,0x645c0036,0x6d4a6487}},	//   _jefa_, bub_, bvri, jefa,
   {{0x7bc27c1f,0x6d4a13ea,0x69da1183,0xa5bb1f20}},	//   _okou, defa, imte, któz,
   {{0x2d8c02a7,0x290e13a1,0x6445019f,0x3f8601c2}},	//   _alde_, _lefa_, _iphi, gkou_,
   {{0x059600bf,0x63ad7c20,0xddc9002d,0x44440f1c}},	//   _رایگ, mnan, _creş, _zp_,
   {{0x290e063d,0x44447c21,0x7bc27c22,0x6d4a7c23}},	//   _nefa_, _yp_, _akou, gefa,
   {{0x63ad4285,0xeb99686c,0xfd1033c6,0x444454f4}},	//   onan, жий_, اجه_, _xp_,
   {{0x63ad7c24,0x3f860618,0x69c87c25,0x2d8c01e8}},	//   nnan, ckou_, elde, _elde_,
   {{0x6d4a0939,0x63ad7c26,0x8e77048f,0xddc900d3}},	//   befa, inan, _عارض, _greş,
   {{0x64457c27,0xdb000088,0x442a7c28,0x7bc205aa}},	//   _ophi, rnmá, yub_, _ekou,
   {{0x8af90465,0x6d410222,0x61e7002d,0x63ad0b6a}},	//   _днес_, _ibla, _mijl, knan,
   {{0x44440454,0x69c87c29,0x63ad43da,0xb6a60565}},	//   _rp_, alde, jnan, димл,
   {{0x2bb800e3,0x63ad7c2a,0xa5bb381f,0x6445019f}},	//   _عامة_, dnan, rrón, _aphi,
   {{0x7bc904ea,0x442a7c2b,0x7bc2030b,0x290e0088}},	//   lleu, tub_, _zkou, _gefa_,
   {{0x29050472,0xf8d1417a,0x61fd00d9,0x04b508cb}},	//   mbla_, _हरिय, _atsl, естя,
   {{0x442a7c2c,0x6d5808a9,0x645c1183,0x7bdb00c2}},	//   rub_, zdva, rvri, nmuu,
   {{0x44387c2d,0x442a7c2e,0x61e70126,0x3f86025b}},	// [7e80] str_, sub_, _bijl, vkou_,
   {{0x44447c2f,0xf8d106ed,0x63ad7c30,0x61ef7c31}},	//   _tp_, _हराय, anan, _ducl,
   {{0x44447c32,0x3f8d0257,0x3f86025b,0x7bc97c33}},	//   _up_, _bleu_, tkou_, kleu,
   {{0x6d417c34,0xddc9002d,0x6d4a7c35,0xe1ff0076}},	//   _abla, _preş, wefa, _bród_,
   {{0x63a42bc4,0x6d4a7c36,0x3f860146,0x69c87c37}},	//   miin, tefa, rkou_, ylde,
   {{0xf98703ed,0x7bc2057a,0x3f867c38,0x63a41c33}},	//   _شب_, _skou, skou_, liin,
   {{0x7bc90150,0x6d586a15,0x98a50138,0x3f860094}},	//   fleu, rdva, delį_, pkou_,
   {{0x63a47c39,0x290e7c3a,0x6d414ea8,0xb50a28fb}},	//   niin, _sefa_, _ebla, वरुप_,
   {{0x6d4a1ce2,0x7c3801c0,0xa5bb0103,0xb7b60174}},	//   pefa, stvr, rtóz, yụr,
   {{0x63ad5810,0x63a47c3b,0x6d41009c,0x98a500c6}},	//   znan, hiin, _gbla, gelį_,
   {{0x69c8070a,0x63a41f44,0x9f4439a4,0x69da7c3c}},	//   rlde, kiin, _aimé_, rmte,
   {{0x7bc97c3d,0x63a47c3e,0x29c2003e,0x998d00c4}},	//   cleu, jiin, gðar_, rteš_,
   {{0x63ad585e,0x63a47c3f,0xb50a022d,0x291800e3}},	//   vnan, diin, वरूप_, óras_,
   {{0x7bc07c40,0x63ad0034,0x27fc00fe,0x63a401d0}},	//   lomu, wnan, _ttvn_, eiin,
   {{0x63ad7c41,0x63a400d3,0x69cb0034,0x04c90037}},	//   tnan, fiin, हतरी, سوري_,
   {{0x63a47c42,0x7bc07c43,0xb4af009d,0x394c0212}},	//   giin, nomu, _कशी_, leds_,
   {{0xdce800b6,0x61e701c0,0xb60400b6,0xc2990829}},	// [7e90] _podě, _pijl, tvář, чках_,
   {{0xef190067,0x63ad7c44,0x6493013f,0x660d7c45}},	//   _może_, snan, ežiū, _iwak,
   {{0x31c40ff7,0xfe7000bf,0x27e9063f,0x63a40283}},	//   тств, یده_, _kian_, biin,
   {{0x660d641f,0x27e953da,0x6e2b019c,0x63a47c46}},	//   _kwak, _jian_, tugb, ciin,
   {{0x27e900e3,0xdb0000e3,0x61e7022e,0x61fd13f8}},	//   _mian_, cimé, _tijl, _utsl,
   {{0x660d35fe,0x6e2b7c47,0xc10500e3,0xe1ff0139}},	//   _mwak, rugb, _سوري, _itó_,
   {{0x660d0863,0x6fca2347,0x6e2b00f9,0x27e901ff}},	//   _lwak, kých, sugb, _oian_,
   {{0x7bc97c48,0x7bc00415,0xf09200ca,0xa5bb0143}},	//   uleu, gomu, _ענן_, dróm,
   {{0x7bc97c49,0xa5bb22bf,0x26c90270,0x7bdb0878}},	//   rleu, tról, _nyao_, rmuu,
   {{0x6d410542,0x2dd40848,0x63a43121,0x7bc96378}},	//   _ubla, _ажур, ziin, sleu,
   {{0x63a40694,0x27e97c4a,0xf8b109e5,0x186924f7}},	//   yiin, _bian_, دکش_, чани_,
   {{0x1cb8029e,0x660d21e9,0x27e92e6a,0x2918003e}},	//   _غالب_, _bwak, _cian_, órar_,
   {{0x29c20102,0x27e97c4b,0x3dc50063,0x63a47c4c}},	//   rðar_, _dian_, _kklw_, viin,
   {{0x201c7c4d,0x2bb2007f,0xdb0002c3,0x6b897c4e}},	//   ávik_, ुकथा, anmä, lkeg,
   {{0xf8c603a2,0x63a47c4f,0xe1ff026e,0x27e9009c}},	//   _रुपय, tiin, _ató_, _fian_,
   {{0x27e900ef,0x69c15d21,0xe1fa2fd2,0x6b890407}},	//   _gian_, lole, зга_, nkeg,
   {{0x63a428d1,0xd24f0018,0x660d7c50,0x00000000}},	// [7ea0] riin, ینہ_, _gwak, --,
   {{0x63bb02fb,0x69c17c51,0x63a47c52,0x71a328f1}},	//   čuna, nole, siin, гауз,
   {{0x64a65ce2,0x7bc0368e,0x660d01c0,0x63a47c53}},	//   _чана, yomu, _zwak, piin,
   {{0x69c17c54,0xd00f0604,0x63a4008c,0x00000000}},	//   hole, صله_, qiin, --,
   {{0x69c16a99,0x6493013f,0x59b1030b,0x657e7c55}},	//   kole, ržiū, ीकार, _koph,
   {{0x6b8901ff,0x6fae00aa,0x00000000,0x00000000}},	//   ekeg, ंचहू, --, --,
   {{0x961d06ed,0x3cf000aa,0x00000000,0x00000000}},	//   _भट्ट_, _चलीं_, --, --,
   {{0xa3d0045f,0x657e039f,0x00000000,0x00000000}},	//   षति_, _loph, --, --,
   {{0x7fd700c1,0x6fca0146,0x27e97c56,0x69c17c57}},	//   _טולס_, vých, _rian_, fole,
   {{0x7c963d03,0x69c17c58,0x27e97c59,0x25f40789}},	//   _прец, gole, _sian_, ंदनी_,
   {{0xa3d004dd,0x394c7c5a,0x27e97c5b,0x660d057a}},	//   षता_, reds_, _pian_, _swak,
   {{0x6d5a7c5c,0x27e97c5d,0xb9071101,0x61be02c6}},	//   _hata, _qian_, _मृ_, ्तुष,
   {{0x8f9b0c6a,0x657e7c5e,0x3cfd3e2a,0x27e97c5f}},	//   ליטי, _boph, रुवे_, _vian_,
   {{0x69c17c60,0x6d5a7c61,0xca570341,0x26c90051}},	//   cole, _jata, _ניוז_, _vyao_,
   {{0x6d5a7c62,0xf367171b,0x27e931fb,0x80a0009d}},	//   _mata, нтан, _tian_, _गेले,
   {{0x660d0198,0x63780139,0x00000000,0x00000000}},	//   _twak, _kíny, --, --,
   {{0x660d75bc,0xe1f30602,0x776d01c8,0x657e033c}},	// [7eb0] _uwak, اسر_, _inax, _foph,
   {{0x37be0134,0x9f5800da,0x00000000,0x00000000}},	//   ọstụ_, _dtrí_, --, --,
   {{0x4427026e,0xf4840565,0x2bac02c6,0xfbb202c6}},	//   _ín_, _буян, pěch_, ुकाम,
   {{0x6d5a4a00,0x69c17c63,0x441a0796,0xda21007a}},	//   _aata, zole, _קורס, _मिलत_,
   {{0x69c12826,0xed590fe3,0x59d00ff9,0x69d800bc}},	//   yole, дол_, हतार, _ohve,
   {{0xdca522ee,0x6d5a7c64,0x00000000,0x00000000}},	//   кали, _cata, --, --,
   {{0x6d5a5c5b,0x69c10897,0xe73f00aa,0x21647c65}},	//   _data, vole, lnõu_, _стяг,
   {{0x69c17c66,0x6d5a5ded,0x69d80302,0x4a450ff7}},	//   wole, _eata, _ahve, внив,
   {{0x69c17c67,0xe9d92da1,0x6d5a7c68,0x6b8901df}},	//   tole, мки_, _fata, rkeg,
   {{0x6d5a7c69,0x6b897c6a,0xe8f61c32,0x98be0034}},	//   _gata, skeg, кль_, letę_,
   {{0x69c17c6b,0x00000000,0x00000000,0x00000000}},	//   role, --, --, --,
   {{0xf0ee00a5,0x7dcd0220,0x69c11a5b,0x657e7c6c}},	//   _जल्द_, kúsk, sole, _soph,
   {{0x6d5a3d61,0x69c10982,0x98b108bb,0xfc4a00d4}},	//   _yata, pole, ızı_, číš_,
   {{0x443a0161,0x9f4a0428,0x6d5a0188,0x657e039f}},	//   _pqp_, _rubí_, _xata, _qoph,
   {{0x64a301b6,0xf99200ca,0x69ca0179,0x9f4a034f}},	//   аара, _דרג_, _सीटी, _subí_,
   {{0x7afb7c6d,0x69d8023b,0x260f0096,0xc32311cc}},	//   ncut, _zhve, तीही_, имск,
   {{0xcb120130,0xf5060465,0xb5fb0146,0x657e7c6e}},	// [7ec0] ילן_, _изпо, rvác, _toph,
   {{0x3cf00034,0x61be0d7a,0x442e0231,0x00000000}},	//   _चलें_, ्तेष, _ªf_, --,
   {{0x98bc00c6,0x7afb0113,0x00000000,0x00000000}},	//   _davė_, kcut, --, --,
   {{0x34b700ca,0x637800ee,0x00000000,0x00000000}},	//   _יפים_, _nínx, --, --,
   {{0x6d5a7c6f,0xa3bf0251,0x753b6126,0x8e3701c3}},	//   _pata, इवर_, đuzv, نسور_,
   {{0x6d5a7c70,0x3cfd030b,0xa2af0096,0x00000000}},	//   _qata, रुले_, ंपर्, --,
   {{0x6d5a01e8,0x71a32b85,0x7f5b1f3b,0x6e3b039f}},	//   _vata, _тарз, _fauq, _equb,
   {{0x6d5a7c71,0x7c8321b6,0x5a34142f,0x6fd8016d}},	//   _wata, руше, гнит, fíce,
   {{0x6d5a7c72,0xa92a01b6,0x4e0b0034,0x00000000}},	//   _tata, міне_, सीआई_, --,
   {{0xce37028c,0x0e9b00a1,0x7afb0850,0x49743b88}},	//   _באמת_, _חשמל, acut, улос,
   {{0x7d187c73,0x7e6247b2,0x00000000,0x00000000}},	//   mavs, lvop, --, --,
   {{0x7f42037a,0x7d187c74,0x00000000,0x00000000}},	//   nfoq, lavs, --, --,
   {{0x95cb0396,0xdcfa022b,0x07a401b3,0x9f4a0139}},	//   дува_, _lotč, раўн, _mubà_,
   {{0x7d180a32,0xc1be009f,0x2b46063d,0x00000000}},	//   navs, ्तोग, _hboc_, --,
   {{0x499200cd,0x6fc20096,0x2a660094,0x00000000}},	//   _میکر, षकां, _hrob_, --,
   {{0x63bb011d,0x7d180c08,0x395e7c75,0x395c4095}},	//   čuno, havs, ldts_, _havs_,
   {{0x25f4009d,0x7f5b646c,0x7d180559,0x61d91855}},	// [7ed0] ंदणी_, _rauq, kavs, емая_,
   {{0xa2a7009d,0xdb000146,0x661d0170,0xe4a7661e}},	//   _घेण्, dimí, mssk, _армо,
   {{0x7d1800cc,0x395c7c76,0xd49800d3,0x00000000}},	//   davs, _mavs_, _аря_, --,
   {{0x443103a3,0x9f4a00ee,0x9f440139,0x7dcd1c9d}},	//   muz_, _cubà_, _fimí_, músi,
   {{0x2a66023e,0x661d0973,0x7afb026a,0x637800b3}},	//   _nrob_, nssk, vcut, _rínx,
   {{0xaac610ed,0xbbcb04f8,0xef19009e,0x3cfe016d}},	//   _लड़क, ात्क, _doża_, _cftv_,
   {{0x44317c77,0x00000000,0x00000000,0x00000000}},	//   nuz_, --, --, --,
   {{0x38691500,0x661d5d95,0x00000000,0x00000000}},	//   _čar_, kssk, --, --,
   {{0x99153ad2,0x7dcd003e,0xe8d900de,0x3989003e}},	//   льні, húsi, _đố_, _húsi_,
   {{0x7afb7c78,0x661d02fe,0x44317c79,0x395c5ac1}},	//   scut, dssk, kuz_, _cavs_,
   {{0xe73a416d,0x5fb72b8a,0x3cf0025b,0x44317c7a}},	//   нен_, _अदाल, ňové_, juz_,
   {{0x44317c7b,0x2a666df6,0x39890072,0x6f190034}},	//   duz_, _frob_, _músi_, nawc,
   {{0x661d25cc,0xd9450cd7,0x395c7c7c,0xe81f02d5}},	//   gssk, _бели, _favs_, _मटका_,
   {{0x2bcb0557,0x44317c7d,0x442a09ac,0x64a601b6}},	//   ातका, fuz_, trb_, гага,
   {{0x44310634,0x280202c6,0x6fb30034,0x661d02ac}},	//   guz_, ěrné_, ंचां, assk,
   {{0xe7bb08fa,0xf3e61249,0x2b5f7c7e,0x386700b3}},	//   _उदयप, ужбо, nduc_, _irnr_,
   {{0xe2976289,0x6f190067,0xb5fb0018,0x3a3f2c98}},	// [7ee0] гат_, dawc, lván, ntup_,
   {{0x44317c7f,0x66047c80,0xdcfa0b18,0xef1900bd}},	//   buz_, _itik, _potč, _roża_,
   {{0x03a64444,0x00000000,0x00000000,0x00000000}},	//   _бино, --, --, --,
   {{0x66042d1f,0xdb000076,0x7c3c00bc,0x3a3f0233}},	//   _ktik, timí, _ärri, ktup_,
   {{0x6d4300dc,0x7d187c81,0xde58097a,0x52750565}},	//   ffna, tavs, талі_, _куру,
   {{0x66040239,0x21a60a0e,0x9f580503,0x7f420231}},	//   _mtik, _сигм, _dtrá_, sfoq,
   {{0x67240268,0x4c942976,0xac940138,0x00000000}},	//   _odij, рийс, райш, --,
   {{0xa2db3ec9,0x22407c82,0x67247c83,0x61ee0d1f}},	//   पेक्, otik_, _ndij, _hibl,
   {{0x22400f8b,0x61ee1d49,0x38670072,0x44317c84}},	//   ntik_, _kibl, _arnr_, zuz_,
   {{0x6e930080,0x2fc67c85,0x325700ca,0x22407c86}},	//   _الكا, loog_, נסים_, itik_,
   {{0x66047c87,0xeaaf110a,0x58d47c88,0x99630fe9}},	//   _atik, قعی_, ронт, стыл,
   {{0x661d1a88,0x1620009f,0x4431008b,0x61ee7c89}},	//   tssk, _बिखर_, vuz_, _libl,
   {{0x395c00d9,0x61ee0076,0xc6a71a54,0x2a667c8a}},	//   _tavs_, _oibl, урни, _urob_,
   {{0x6b827c8b,0x2fc60505,0xbf10007d,0x443102a7}},	//   _hoog, hoog_, ारुन_, tuz_,
   {{0x660469b5,0xdb09016d,0x68fb00ca,0x6f004bcd}},	//   _etik, lneá, _אלוה, _ofmc,
   {{0x44317c8c,0x6b827c2e,0x61ee594c,0x69d85685}},	//   ruz_, _joog, _aibl, _नीती,
   {{0x6d487c8d,0x248d00d9,0x6b82008c,0x22400124}},	// [7ef0] _obda, ņem_, _moog, gtik_,
   {{0x6b82025e,0x61ee2c69,0x6f190034,0x67240117}},	//   _loog, _cibl, wawc, _zdij,
   {{0x61ee7c8e,0x22407c8f,0xbf10136b,0x23600381}},	//   _dibl, atik_, ारंभ_, bdij_,
   {{0x547a0089,0x6d481819,0x283700c1,0x6b823634}},	//   _סטרו, _abda, רנאך_, _noog,
   {{0xe6d30789,0xb5fb025b,0x61ee00b3,0xa2cc00b6}},	//   _सरोज, zván, _fibl, _थुप्,
   {{0x32091331,0x61ee7c90,0x764d1dc3,0x6d430364}},	//   mpay_, _gibl, _mpay, ufna,
   {{0x6b827c91,0x3209599d,0xf5380089,0xfaf100e3}},	//   _boog, lpay_, אטור_, يثة_,
   {{0x5f945c84,0x3b85180b,0x442138f0,0xba251439}},	//   _лист, рлиг, _mvh_, адик,
   {{0x320902f1,0x499902ec,0x7f8400e3,0x6b827c92}},	//   npay_, втня_, _القن, _doog,
   {{0xa9a50058,0x7e697c93,0xb5fb0018,0x44217ad3}},	//   риод, _irep, tván, _ovh_,
   {{0xe8d900ef,0x224001e9,0x6d8a0018,0x06cd0033}},	//   _đồ_, ztik_, _جملہ_, রেমি,
   {{0x66e622d1,0x7e697c94,0x6b8232e8,0xfc300f43}},	//   иона, _krep, _goog, _رحم_,
   {{0xcaf40068,0x6fd8058a,0x25aa0286,0x00000000}},	//   _اسمب, níca, ندسي_, --,
   {{0xceb2004f,0x320903a8,0x6b8243da,0x80d60096}},	//   קים_, dpay_, _zoog, _भरले,
   {{0x61ee0039,0x443e0257,0x98a20cc6,0x2fc6023e}},	//   _ribl, ît_, _мише, yoog_,
   {{0x6b820694,0x25aa0150,0x7e690072,0x2fc601fa}},	//   _xoog, sibl_, _orep, xoog_,
   {{0x57250080,0xdb002299,0x61ee0c56,0x23600cb9}},	// [7f00] _طريق, nimá, _pibl, rdij_,
   {{0x224001e9,0x6fd824c7,0xa06a2195,0x645a003e}},	//   rtik_, díca, каза_, ætis,
   {{0xb5fb025b,0x7e697c95,0xef1a0396,0xdb09029a}},	//   hvál, _arep, вме_, gieë,
   {{0x7e2a059b,0x6fd822a4,0x9e663cee,0xa5bb0103}},	//   віка_, fíca, ивед, csób,
   {{0x5de60747,0x764d0063,0xee3705cb,0x2fc6318e}},	//   ажда, _xpay, инц_, roog_,
   {{0x7e697c96,0xe0da3097,0xac2603f2,0x2fc67c97}},	//   _drep, _авг_, афик, soog_,
   {{0x20b902fd,0x7e697c98,0xdb090146,0xe6d309c4}},	//   _быть_, _erep, šnýc, _सर्ज,
   {{0x7ac60b0a,0x00000000,0x00000000,0x00000000}},	//   испе, --, --, --,
   {{0x7e69298b,0xcb671d2e,0xb5fb0103,0x3a2d004d}},	//   _grep, рање_, gvál, grep_,
   {{0x798300f0,0xdca62e0f,0xf96a6561,0xa3e800a4}},	//   _conw, _кази, трий_, यगड_,
   {{0x3f8435ba,0x6b820188,0xdddb01d3,0xd0f700ca}},	//   _komu_, _toog, _bruņ, ימית_,
   {{0x320907ac,0x6fb80285,0x00000000,0x00000000}},	//   ypay_, ेकिं, --, --,
   {{0xdb000072,0x798303c3,0x00000000,0x00000000}},	//   cimá, _fonw, --, --,
   {{0xd5b800c2,0x3f847c99,0x680101d3,0x798300eb}},	//   асс_, _lomu_, _sēde, _gonw,
   {{0x5fb8063c,0xd5b8008f,0x6fb80096,0xa4d507bf}},	//   ेकाल, рся_, ेकां, сові,
   {{0x987b00ca,0x7983029a,0xdce101d3,0xddce0031}},	//   _ירוק, _zonw, _solī, ždňa,
   {{0x764d0d4c,0x680101d3,0xb7dc0327,0x675401c3}},	// [7f10] _upay, _vēde, _בקהי, _ذخير,
   {{0x69c87c9a,0x69c7033b,0x7e69150c,0xf6500401}},	//   node, čjeg, _rrep, _آئي_,
   {{0x32090383,0xd3710037,0x3f840239,0x7e6903a9}},	//   spay_, _فهد_, _bomu_, _srep,
   {{0x7e690133,0xdb090126,0xe456006e,0xff530103}},	//   _prep, rieë, _פירט_, تخط_,
   {{0xd37a0130,0x6db20067,0xdb000074,0x63ad7c9b}},	//   _ערשט, kład, ximá, mian,
   {{0x63ad7c9c,0x9877077e,0xdb091044,0x69c8037a}},	//   lian, _ušće_, pieë, jode,
   {{0x40950080,0x7dcd6823,0x69c87c9d,0xe0e50081}},	//   _الأر, dúst, dode, _প্রভ,
   {{0x1fa4125c,0x63ad7c9e,0xa3d734d8,0xdb001e6f}},	//   _друг, nian, िति_, timá,
   {{0x69c86284,0x7e690062,0x00000000,0x00000000}},	//   fode, _urep, --, --,
   {{0x63ad7c9f,0x389701d4,0x69c87ca0,0x7dcd1789}},	//   hian, lərə_, gode, gúst,
   {{0xa3d71179,0x63ad7ca1,0x2d851197,0x6ca74d76}},	//   िता_, kian, _iole_, _траж,
   {{0x63ad2a08,0x2d857ca2,0x25f40d75,0x660000d4}},	//   jian, _hole_, ंदली_, ímko,
   {{0x2d857ca3,0x69c87ca4,0x63ad16ea,0xe8d90019}},	//   _kole_, bode, dian, _đổ_,
   {{0xb8dd0f71,0x69c87ca5,0x799a5b2f,0x2d857ca6}},	//   _আর_, code, chtw, _jole_,
   {{0x63ad7ca7,0x2d857ca8,0x232a45b1,0xdcfa00d3}},	//   fian, _mole_, лови_, _hotă,
   {{0x73997ca9,0x63ad7caa,0x96963006,0x2d850139}},	//   атус_, gian, _грош, _lole_,
   {{0x3f840af0,0x67d80139,0x27e00f20,0x63b600c6}},	// [7f20] _romu_, _e̟jó, _ihin_, rnyn,
   {{0x59c71488,0x2d850d62,0x3f8400e8,0x4223004d}},	//   रकिर, _nole_, _somu_, ядув,
   {{0xaace4422,0x442e0653,0x389700a7,0x7dcd01cd}},	//   _हुनक, _íf_, fərə_, húss,
   {{0x2d850065,0x7bc90234,0xa5bb0231,0x61e5010b}},	//   _aole_, joeu, brós, amhl,
   {{0x59c71efb,0xdfcf00ab,0x27e001ec,0x2fdf7cab}},	//   रकार, ريه_, _mhin_, _dhug_,
   {{0x3f840172,0x6b9b700f,0x2d850158,0x00000000}},	//   _womu_, ehug, _cole_, --,
   {{0x2d850b16,0x3f840618,0x69c82029,0xef1902a1}},	//   _dole_, _tomu_, vode, _feż_,
   {{0x6fb60391,0x6b9b12ff,0x09d00e19,0x27e07cac}},	//   _امرا, ghug, हत्य, _nhin_,
   {{0xb99861f2,0x26d2010a,0x2d857cad,0x00000000}},	//   ивих_, _nyyo_, _fole_, --,
   {{0x29187cae,0x63ad7caf,0x645e7cb0,0x2d857cb1}},	//   úra_, zian, _ospi, _gole_,
   {{0x69c87cb2,0x6fd81094,0x26c00167,0x7d1a1044}},	//   rode, níco, _axio_, _iets,
   {{0x69c87cb3,0x6b9b7cb4,0x7d1a7cb5,0x7bc93eaf}},	//   sode, chug, _hets, coeu,
   {{0x98b801e8,0x6e2216da,0x27f20350,0x9f580131}},	//   ırı_, nsob, _diyn_, _purê_,
   {{0x63ad00a5,0xe8940457,0xb60600e7,0x389700a7}},	//   wian, _маль, dašč, zərə_,
   {{0x63ad7cb6,0x291e7cb7,0x7d1a198c,0x7afd0146}},	//   tian, mata_, _mets, žste,
   {{0x291e7cb8,0x52153df8,0x27e0036b,0xdb090131}},	//   lata_, ждат, _ghin_, rneç,
   {{0x63ad7cb9,0xdb0000c2,0x6f027cba,0x00000000}},	// [7f30] rian, mimä, dcoc, --,
   {{0x63ad7cbb,0x00000000,0x00000000,0x00000000}},	//   sian, --, --, --,
   {{0x63ad7cbc,0x661600a5,0x98a70367,0x2d857cbd}},	//   pian, _zwyk, _yanı_, _role_,
   {{0x291e7cbe,0xdcee00b6,0x55550018,0xdb000329}},	//   hata_, žděn, _اپگر, nimä,
   {{0x28cf3245,0xdce8013f,0x15f90e50,0x2d851a5b}},	//   _सुनि, _kodė, ंदिर_, _pole_,
   {{0xac097cbf,0xdb0031e8,0x7d1a02ac,0x2ea90096}},	//   анка_, himä, _cets, _कधीत,
   {{0x291e7cc0,0xef190067,0x7d1a7cc1,0x2fdf10f0}},	//   data_, _też_, _dets, _thug_,
   {{0x2d857cc2,0x6f027cc3,0x316300e7,0x7d1a01d0}},	//   _wole_, ccoc, _hajz_, _eets,
   {{0x291e7cc4,0x2d857cc5,0x7bc916e7,0x6b9b7cc6}},	//   fata_, _tole_, roeu, rhug,
   {{0x291e7cc7,0x6b9b0010,0x89a91c4c,0x7d1a7cc8}},	//   gata_, shug, рков_, _gets,
   {{0x27e06ffc,0x00000000,0x00000000,0x00000000}},	//   _phin_, --, --, --,
   {{0xe73a7cc9,0x443100d4,0xa3ae09a0,0xa3ab0285}},	//   шем_, drz_, _औषध_, कोम_,
   {{0x291e3cd2,0x06cd0081,0x6f1b13a9,0x4431007f}},	//   bata_, রেসি, _meuc, erz_,
   {{0x291e27db,0x6f1b7cca,0x6f027ccb,0x290100aa}},	//   cata_, _leuc, zcoc, _üha_,
   {{0xe8d900de,0x5fc900b6,0xe9b80018,0x6f021881}},	//   _đỗ_, िकाल, _دنوں_, ycoc,
   {{0xaace009d,0x6f1b2831,0x130a013f,0x2bcc0096}},	//   _हुडक, _neuc, рнай_, ावया,
   {{0x645e0034,0x26c00072,0x4226008f,0xd5e40023}},	// [7f40] _wspi, _uxio_, юдав, _trì,
   {{0xb60615d1,0x7764015e,0xb5fb0094,0x6fd804c3}},	//   rašč, _haix, dváh, tíco,
   {{0x645e0ea3,0x7d1a7ccc,0x6f1b009c,0x776401e9}},	//   _uspi, _rets, _beuc, _kaix,
   {{0x44387ccd,0x291e7cce,0x7d1a2b43,0x6e227ccf}},	//   mur_, zata_, _sets, tsob,
   {{0x291e7cd0,0x91e613b0,0x44387cd1,0x7d1a7cd2}},	//   yata_, _моме, lur_, _pets,
   {{0x44447cd3,0x7981023e,0x20070428,0x60430174}},	//   _kq_, jjlw, ínic_, _ọmet,
   {{0x44387cd4,0x6f1b7cd5,0x645c5202,0x7d1a7cd6}},	//   nur_, _feuc, nwri, _vets,
   {{0x4444013d,0x291e7cd7,0x7d1a49e3,0x776405fe}},	//   _mq_, wata_, _wets, _naix,
   {{0x44383fe3,0x291e7cd8,0x7d1a0068,0x7c23023e}},	//   hur_, tata_, _tets, asnr,
   {{0x44387cd9,0x44440161,0x59dd009f,0x2b917cda}},	//   kur_, _oq_, _नीदर, _lách_,
   {{0x26180782,0x291e7cdb,0x77645bdb,0x6d587cdc}},	//   बीसी_, rata_, _baix, meva,
   {{0x77645bdb,0x291e7cdd,0x37ab08f9,0x645c00f0}},	//   _caix, sata_, ртон_, dwri,
   {{0x291e7cde,0x44447cdf,0x4438025a,0x7c380039}},	//   pata_, _aq_, eur_, luvr,
   {{0x44387ce0,0x6d580006,0x95cb7ce1,0x291e7ce2}},	//   fur_, neva, рума_, qata_,
   {{0x44387ce3,0x77647ce4,0x2b9100de,0x76910065}},	//   gur_, _faix, _bách_, _bóyú,
   {{0x2b9100ef,0x442d163c,0x69a60976,0x77640a00}},	//   _cách_, če_, टोरी, _gaix,
   {{0xdce801b3,0x6d587ce5,0x2b9100de,0x291c0095}},	// [7f50] _todė, keva, _dách_, _keva_,
   {{0x44380f8b,0x7dcd0146,0x44440052,0xa5bb002b}},	//   bur_, júsp, _fq_, cróp,
   {{0x6d587ce6,0x291c0472,0x6f1b009c,0x155a00ca}},	//   deva, _meva_, _peuc, _הכתב,
   {{0x65657ce7,0x291c7ce8,0x9ee900e3,0x7c3800c4}},	//   _hahh, _leva_, مفضل_, duvr,
   {{0x1d0952ae,0xa3ab08c0,0x6447057a,0xee3816dd}},	//   бели_, कोण_, ltji, жні_,
   {{0x6d585d92,0xed59188d,0x291c7ce9,0x00000000}},	//   geva, сок_, _neva_, --,
   {{0x64470185,0x6f1b0072,0x44447cea,0x61fd0570}},	//   ntji, _teuc, _xq_, _husl,
   {{0x2b910019,0x2121005c,0x291c0072,0x61f57ceb}},	//   _xách_, lahh_, _aeva_, _hizl,
   {{0x60d55768,0x6d587cec,0x44387ced,0x291c0036}},	//   _hyzm, beva, zur_, _beva_,
   {{0x291c0012,0x39451116,0x6d587cee,0x397900c2}},	//   _ceva_, чног, ceva, ссию_,
   {{0x6445006c,0x7764137f,0x6d410092,0x291c7cef}},	//   _nqhi, _paix, _icla, _deva_,
   {{0x44387cf0,0xf09200c1,0x65657cf1,0x6db20034}},	//   vur_, גנט_, _aahh, płac,
   {{0xa5bb7cf2,0x443800bf,0x776405fe,0x2b910023}},	//   tróp, wur_, _vaix, _rách_,
   {{0x44387cf3,0x2b910028,0x44447cf4,0xa5076dce}},	//   tur_, _sách_, _pq_, зера_,
   {{0x61fd02e2,0x44447cf5,0x3e5d06a3,0x64590034}},	//   _ausl, _qq_, _lňt_, _ćwic,
   {{0x44387cf6,0x61f50029,0x9f46057a,0x6d580141}},	//   rur_, _aizl, rmoë_, zeva,
   {{0x44387cf7,0x44440c56,0x61f5008b,0x2b910023}},	// [7f60] sur_, _wq_, _bizl, _vách_,
   {{0x44387cf8,0xdb190174,0x44447cf9,0x61fd7cfa}},	//   pur_, _akwü, _tq_, _dusl,
   {{0x443800dd,0x6d587cfb,0xb4fb00a1,0x2b9100de}},	//   qur_, veva, _לפיי, _tách_,
   {{0xd9c70b94,0xa3d705d6,0x6d411d32,0x20072c68}},	//   रकुट, ितः_, _acla, ínia_,
   {{0x6d587cfc,0xc333028c,0xf1bf06cb,0x29077cfd}},	//   teva, _אור_, _iván_, _ofna_,
   {{0x61f508bb,0x6d4a0257,0x5155283b,0x6da33549}},	//   _gizl, uffa, _отсу, нича,
   {{0x6d587cfe,0x6d4a7cff,0x6e390124,0x6fd80031}},	//   reva, rffa, auwb, níck,
   {{0x291c16c8,0x6d587d00,0x6d41574d,0xb8860072}},	//   _seva_, seva, _ecla, _laíñ,
   {{0xacf60080,0x6d587d01,0x8d1a00cd,0x291c21d5}},	//   _فسات, peva, _هزار_, _peva_,
   {{0xe7d60081,0xd90d00cd,0x64470313,0x6d4100da}},	//   _সংগঠ, لیه_, ytji, _gcla,
   {{0x291c37b4,0x6565009c,0x00000000,0x00000000}},	//   _veva_, _rahh, --, --,
   {{0xd8384582,0x48a70109,0xef190090,0x65657d02}},	//   ruč_, ятым_, _pożi_, _sahh,
   {{0x291c0472,0xb886002b,0xe1ff00fe,0xf1cc007f}},	//   _teva_, _baíñ, _trói_, ़कान,
   {{0x25f40f78,0x246700b6,0x291c063d,0x00000000}},	//   ंदगी_, jímá_, _ueva_, --,
   {{0x58d302c1,0x38c8001c,0x64470313,0x25de00c3}},	//   _пошт, _باشی_, utji, _गठरी_,
   {{0xb4bd02e8,0x61fd01b3,0x64470185,0x61f503a3}},	//   _अशी_, _pusl, rtji, _sizl,
   {{0x672d0af0,0x6fd802c6,0xdd3100c6,0x680800d2}},	// [7f70] _idaj, mích, _lęši, _děde,
   {{0x660d7d03,0x61f500a7,0xe7e11492,0xd1310037}},	//   _itak, _qizl, _गीता_, ئما_,
   {{0xf9930130,0xe2f900d6,0x660d0051,0x21210167}},	//   ערע_, _мені_, _htak, rahh_,
   {{0x2905058a,0x63bb166d,0x6d417d04,0xa5bb0072}},	//   zcla_, čuns, _scla, isóm,
   {{0x8d7412eb,0x7c2805e8,0x7bc40138,0x39a30032}},	//   کانا, _avdr, čiul, _jésù_,
   {{0x660d0010,0xddc90034,0xdce801d3,0x22497d05}},	//   _mtak, _speł, _godī, mtak_,
   {{0x22497d06,0x1b2100c7,0x2a6f7d07,0x1be9534b}},	//   ltak_, _যাবে_, _srgb_, одки_,
   {{0x660d7d08,0x23697d09,0x2b980257,0xdfd100e3}},	//   _otak, ndaj_, _déco_, _شيء_,
   {{0x660d7d0a,0x22497d0b,0x9dab00e5,0x00000000}},	//   _ntak, ntak_, _лъжа_, --,
   {{0x672d7461,0x2fcf0d90,0xf1bf05e4,0x48050d57}},	//   _adaj, logg_, ्विन, мпов,
   {{0x660d7d0c,0xb88603be,0xa3bf1c83,0x2369033b}},	//   _atak, _raíñ, ेवा_, kdaj_,
   {{0x29052f0b,0x2369023e,0x22497d0d,0x00000000}},	//   scla_, jdaj_, ktak_, --,
   {{0xf1bf072d,0x41bf262c,0xe9ce17a6,0xdce102fb}},	//   ्वान, ्वास, _ак_, _malč,
   {{0xe1ff0067,0x6b8b7d0e,0x22493b69,0x660d0113}},	//   _osób_, _hogg, dtak_, _dtak,
   {{0x660d7d0f,0xb886002b,0x330b0134,0x6b8b18f0}},	//   _etak, _vaíñ, _ụbọ_, _kogg,
   {{0xb4ae02e8,0x6b8b7d10,0xd8d600c1,0x660d0078}},	//   _कधी_, _jogg, _קוקט_, _ftak,
   {{0x6b8b36d6,0x680802c6,0x6fd81515,0x22497d11}},	// [7f80] _mogg, _věde, síck, gtak_,
   {{0x6b8b0b97,0x23660106,0x672d7d12,0x6fd848a9}},	//   _logg, žoj_, _zdaj, míci,
   {{0x6fd87d13,0x757b00a1,0x6e290027,0x6b8b000b}},	//   líci, _וטיפ, _aveb, _oogg,
   {{0x6b8b0212,0x9ec6001c,0x00000000,0x00000000}},	//   _nogg, وزشه, --, --,
   {{0x5e5a0018,0x6fd87d14,0x6da61543,0x00000000}},	//   تجاج_, níci, мида, --,
   {{0x6db200a5,0x6b8b010a,0x20560927,0x00000000}},	//   ałan, _aogg, _отбр, --,
   {{0x6b8b008a,0x798a084e,0x00000000,0x00000000}},	//   _bogg, _rofw, --, --,
   {{0xc0e30b2f,0x200501dc,0x00000000,0x00000000}},	//   _роск, _élia_, --, --,
   {{0x6b8b0d18,0xf1bf05f1,0x6aad0141,0x00000000}},	//   _dogg, _ovál_, _žafr, --,
   {{0xc27b0105,0xb33b01e8,0x6fd80220,0xc86400ae}},	//   קריי, _ilçe, díci, еӂии,
   {{0x31377c04,0xe8df00ef,0x6b8b7d15,0x013700ca}},	//   ונים_, _thời_, _fogg, ורית_,
   {{0x6b8b7d16,0x3f8602f1,0xb5fb0094,0x660d007f}},	//   _gogg, njou_, kvát, _ptak,
   {{0x4ae2099d,0xaae20a30,0xd90e0260,0x59ab00b6}},	//   _परिव, _परिक, _پیج_, टोहर,
   {{0x28cf05cd,0xa5bb0088,0xe8df00de,0x2d8c7d17}},	//   _सुवि, msók, _giỏi_, _jode_,
   {{0x2d8c05d0,0x94d43397,0x1b210033,0xa4d4004d}},	//   _mode_, ворц, _যাতে_, ворі,
   {{0x69da7d18,0x22497d19,0x660d0517,0x2d8c6869}},	//   llte, ttak_, _ttak, _lode_,
   {{0x45d521a1,0xe8df0019,0xdb020161,0xa3ab00c0}},	// [7f90] _поис, _khởi_, _emoç, कोष_,
   {{0x22490335,0x3ea600d9,0xdce100e7,0xa3e403a2}},	//   rtak_, dzot_, _salč, _पीठ_,
   {{0x22497d1a,0x69da0013,0xdce10128,0x5576006e}},	//   stak_, ilte, _palč, _װערן_,
   {{0x2d9e7d1b,0xa3ab2a06,0x69da01bf,0x22497d1c}},	//   _alte_, कोश_, hlte, ptak_,
   {{0x2d8c71d3,0x1d097d1d,0xdce17d1e,0x00000000}},	//   _bode_, пели_, _valč, --,
   {{0x7bc21bdd,0x2d8c7d1f,0x6b8b013d,0x6db200a5}},	//   _ajou, _code_, _sogg, słan,
   {{0x6fd86cf4,0x6b8b7d20,0x37d60081,0x2d8c1cab}},	//   zíci, _pogg, _সংঘর, _dode_,
   {{0xd9c702d5,0x69da1090,0x99d5015a,0x00000000}},	//   रक्ट, elte, کتبا, --,
   {{0x3e350dd0,0x2d8c0161,0x7bc27d21,0xddc9020a}},	//   _سفار, _fode_, _djou, _creţ,
   {{0x2d8c0170,0x00000000,0x00000000,0x00000000}},	//   _gode_, --, --, --,
   {{0xf7462453,0x2bcc6bbd,0x00000000,0x00000000}},	//   нено, ावशा, --, --,
   {{0x6fd87d22,0x2bac007f,0x69da3ba9,0x00000000}},	//   tíci, yści_, alte, --,
   {{0xf6d5004d,0xddc9078e,0x00000000,0x00000000}},	//   віря, _greţ, --, --,
   {{0x7bdb7d23,0x6fd8255b,0xd945430b,0x6280014b}},	//   lluu, ríci, _чеки, _àmoi,
   {{0x680802c6,0x80d400b6,0x2edc5660,0x64a601b3}},	//   _vědc, _बुढे, _बर्त, хава,
   {{0xb4e002e8,0x8646004d,0xdce802c6,0x6fd80131}},	//   _तरी_, _зниж, _andě, píci,
   {{0x211a00e3,0x5a0c006e,0x7bdb00c2,0xa1360037}},	// [7fa0] كتاب_, ַלאַ, iluu, فراش,
   {{0xb5fb1e14,0x4ae200b7,0x00000000,0x00000000}},	//   rvát, _परसव, --, --,
   {{0x3f9f246f,0xe8df0019,0xd00f001c,0x98a60d62}},	//   _bluu_, _khối_, ملل_, ćiće_,
   {{0x67267d24,0x6db200a5,0x3f8d00b3,0x2d8c7d25}},	//   nakj, ałal, _coeu_, _sode_,
   {{0x2d8c1379,0xdb0000dd,0xaace0187,0x63a47d26}},	//   _pode_, shmë, _हुंक, mhin,
   {{0x63a47d27,0x06cd0033,0x7bc201cb,0xaca40174}},	//   lhin, রেকি, _sjou, stọr,
   {{0x8fa60002,0x2d8c1206,0x71d700ca,0x00000000}},	//   _заве, _vode_, _נולד_, --,
   {{0x63a47d28,0xddc900d3,0xe1ff00fe,0x2d870216}},	//   nhin, _preţ, _trót_, ajne_,
   {{0x8fa30983,0x0a0a0294,0x67260167,0x6284002b}},	//   _сате, _bụụr, dakj, nxio,
   {{0x7a5300e3,0xa2c1030b,0x3202083e,0xddc9020a}},	//   اضيا, लपत्, _muky_, _vreţ,
   {{0x63a47d29,0x320200d4,0x41be00c3,0x7bc2022b}},	//   khin, _luky_, _एआईस, _tjou,
   {{0xe8df00de,0x7c2a25cc,0x7bdb0188,0x00000000}},	//   _chối_, msfr, cluu, --,
   {{0xd6db0dde,0x63a47d2a,0x12c40033,0x7c2a7088}},	//   ято_, dhin, ্ধুদ, lsfr,
   {{0xddc97d2b,0xa6db003e,0x77930103,0x63a4010a}},	//   _kreš, ggða, ئیکا, ehin,
   {{0x6fd838c0,0x395e7d2c,0xa9670b1b,0x67267d2d}},	//   lícu, mets_, _чија_, bakj,
   {{0x395e7d2e,0xa3ab0067,0x7c33025b,0x98ab020a}},	//   lets_, कों_, _údrž, şcă_,
   {{0x27e902fd,0x44380091,0x2d870034,0xdcfa00b6}},	// [7fb0] _ihan_, arr_, yjne_, _potě,
   {{0x395e7d2f,0x63a4008a,0xb6bc00ca,0xddc97d30}},	//   nets_, ahin, _מצחי, _oreš,
   {{0x6fd80fb6,0x63a47d31,0x55ac00c1,0x31c40859}},	//   hícu, bhin, _זייַ, уств,
   {{0x63a47d32,0x2a6600b6,0x7c2a4095,0xf1c201d3}},	//   chin, _osob_, dsfr, ekšā_,
   {{0x395e0f05,0x9f580428,0x6d9d01b9,0x8e08004d}},	//   kets_, _durà_, _dèan, енів_,
   {{0x395e04ea,0x200e05fe,0xddc914f3,0x672601cb}},	//   jets_, ífic_, _breš, zakj,
   {{0x395e02fe,0x7c2a25cc,0x27e97d33,0x225901ff}},	//   dets_, gsfr, _ohan_, _hpsk_,
   {{0x27e90019,0xe7e1009f,0x69c70117,0x201120a3}},	//   _nhan_, _गीला_, čjem, _itzi_,
   {{0x272000c7,0x395e0257,0x20032e36,0x7bdb7d34}},	//   _ভালো_, fets_, _huji_, rluu,
   {{0x395e032e,0x6ca73c18,0x63a4023b,0x27e90188}},	//   gets_, _преж, zhin, _ahan_,
   {{0x07a60bd5,0xe73a21fd,0xddc903ce,0xe8df0019}},	//   ванн, мен_, _greš, _phối_,
   {{0x27e97d35,0x63a4023b,0x6fd8037a,0x2123009e}},	//   _chan_, xhin, bícu, _lejh_,
   {{0x27e97d36,0x395e7d37,0x7c2402ef,0x2a660027}},	//   _dhan_, bets_, ćire, _gsob_,
   {{0x6d437d38,0x3202025b,0x2606016d,0x395e412d}},	//   ngna, _ruky_, _vôo_, cets_,
   {{0x63a47d39,0x44380154,0xb5fb37b9,0x6d437d3a}},	//   thin, urr_, tvár, igna,
   {{0x6b897d3b,0x2fdd01fa,0x6fd80220,0x27e9009e}},	//   njeg, jlwg_, níct, _ghan_,
   {{0x442a080e,0xb5fb0103,0xb146085f,0x752705db}},	// [7fc0] ssb_, rvár, кнал, bajz,
   {{0x40960cf5,0x63a466b3,0xd5af00e3,0x63b602ad}},	//   крет, shin, _وفي_, siyn,
   {{0x69c17d3c,0x657e0037,0xd59b00ca,0x6604007b}},	//   inle, _inph, _חביל, _huik,
   {{0xee0c0294,0x66047b04,0xd00f0604,0x20030113}},	//   _aṅụr, _kuik, زله_, _duji_,
   {{0x67247d3d,0xf773006e,0x7f830037,0xfe430a3a}},	//   _meij, יקא_, شلون, инцо,
   {{0xdd8f00e3,0xddc97d3e,0x6d430222,0x7c2a7d3f}},	//   يون_, _preš, ggna, tsfr,
   {{0x395e0429,0x8bc64000,0x20037d40,0x66047d41}},	//   vets_, ксид, _guji_, _luik,
   {{0x6fd80eb8,0x6b897d42,0xfbcf0190,0x6b9b0009}},	//   tícu, gjeg, يتي_, gkug,
   {{0x27e902ad,0x60270018,0x395e0429,0x61fc0367}},	//   _rhan_, _témá, tets_, _kirl,
   {{0x27e923e8,0xddc900d9,0x49733ae2,0xa3e40789}},	//   _shan_, _treš, альс, _पीस_,
   {{0x67241aed,0x395e76bb,0x6b890292,0xb90a000f}},	//   _beij, rets_, bjeg, _मर_,
   {{0x2a66006c,0x66047d43,0x69c17d44,0x395e256f}},	//   _tsob_, _buik, anle, sets_,
   {{0x395e134d,0x61fc009c,0x67240381,0x6f0d1ba6}},	//   pets_, _oirl, _deij, ñaci,
   {{0x66040db1,0x61fc001c,0x7e7d065b,0xe5c4007b}},	//   _duik, _nirl, _áspe, ассо,
   {{0x67241390,0x27e954d2,0xd4040423,0xb33b7d45}},	//   _feij, _than_, ияти, _alça,
   {{0x2003005c,0x212302ef,0xdcfa0090,0x6e2d02ef}},	//   _ruji_, _sejh_, _antċ, šabi,
   {{0x61fc0390,0x68e601d4,0xe5c701b3,0x22400062}},	// [7fd0] _birl, əkda, _асно, guik_,
   {{0x61bf000d,0x20030d17,0x61fc078e,0x67240381}},	//   ्वेष, _puji_, _cirl, _zeij,
   {{0x351a00a1,0xa5bb03be,0xd47900c1,0x6aa90036}},	//   _אותנ, dróx, _װאָל, zzef,
   {{0xff2500cd,0x2240646b,0x5ecc0081,0x6fd4004d}},	//   ابای, buik_, ়েছে, аціє,
   {{0xdd951736,0x69c17d46,0x22845566,0x200301c2}},	//   лады, ynle, _кург, _wuji_,
   {{0xdce81f8a,0x6d430bb6,0x61fc7d47,0x26180034}},	//   _aldı, ugna, _girl, बीटी_,
   {{0x6d43266d,0x20110a00,0x6b897d48,0x6f040660}},	//   rgna, _utzi_, tjeg, žica,
   {{0x16030789,0xdfd50084,0x5f943456,0x290e4cb8}},	//   लदार_, _собы, _кист, _affa_,
   {{0x67247d49,0x00000000,0x00000000,0x00000000}},	//   _reij, --, --, --,
   {{0x67247d4a,0x442102e7,0x66047d4b,0x6b9b0957}},	//   _seij, _owh_, _ruik, skug,
   {{0x6b897d4c,0x69c17d4d,0x6604355d,0x6aa90018}},	//   pjeg, rnle, _suik, szef,
   {{0x66047d4e,0x290e3aeb,0x6fd80072,0x00000000}},	//   _puik, _effa_, lícr, --,
   {{0x7bd90129,0x44210113,0x9b740246,0x776d041c}},	//   _ikwu, _awh_, _خالص, _daax,
   {{0x66036dce,0xfd4b0139,0x44217d4f,0x1dc307ad}},	//   спра, _aamẹ, _bwh_, वचित,
   {{0x67247d50,0x64a3689d,0x657e020b,0x776d01ee}},	//   _teij, бара, _vnph, _faax,
   {{0x387801c5,0x644e0003,0x61fc7d51,0x77a6037a}},	//   ærre_, rtbi, _sirl, _bóxe,
   {{0xade3000f,0x3a2d31c7,0x644e2dfc,0x77a60072}},	// [7fe0] गतान_, nsep_, stbi, _cóxe,
   {{0x2240043e,0xc4861e79,0xa3e4152c,0xc56624f7}},	//   ruik_, _блок, _पीर_, _скок,
   {{0x7e697d52,0x7bd900ac,0x6fd80072,0x3329008c}},	//   _asep, _okwu, dícr, baax_,
   {{0x7bd90129,0xdd2f00b6,0x00000000,0x00000000}},	//   _nkwu, měři, --, --,
   {{0x7e690103,0x61fc00f0,0xc7d700ca,0x9f44015e}},	//   _csep, _tirl, נוני_, _simó_,
   {{0x61fc00e3,0x7bd900ac,0x7d0100eb,0x60dc00ce}},	//   _uirl, _akwu, _cgls, _tyrm,
   {{0x2d9c5de7,0x7e697d53,0x00000000,0x00000000}},	//   rkve_, _esep, --, --,
   {{0x5a34133d,0x69d80181,0x2d9c6b69,0x62800231}},	//   анит, _skve, skve_, _àmos,
   {{0x6f9300e3,0xdee30fd8,0x776d0188,0x00000000}},	//   _القض, _готи, _raax, --,
   {{0x776d008a,0x7bd900ac,0x9966294a,0x9f4400ee}},	//   _saax, _ekwu, утил, _timó_,
   {{0x61d700c1,0x6df30037,0x680800b6,0x23bf007b}},	//   רויף_, _اكلا, _vědo, näjä_,
   {{0xb8ec000f,0xdb000231,0xab83594b,0x00000000}},	//   _रख_, rimó, _гушк, --,
   {{0x12bf0033,0x00000000,0x00000000,0x00000000}},	//   _আর্দ, --, --, --,
   {{0x290e028d,0x776d0188,0x2bcc0c38,0xcad700ca}},	//   _uffa_, _waax, ावका, _עוגת_,
   {{0xd37b6070,0x4d7b006e,0x44210113,0x3329008c}},	//   нча_, ערלע, _qwh_, taax_,
   {{0xdce80094,0xc2c50037,0x2849006e,0x987b0142}},	//   _nadč, ليزي, _סעפּ, _טרוק,
   {{0x0ce116f8,0x00000000,0x00000000,0x00000000}},	// [7ff0] _फर्म, --, --, --,
   {{0xdb000037,0xdcfa022b,0x442101ce,0x00000000}},	//   dhmí, _antč, _twh_, --,
   {{0xe1e50096,0x7e697344,0x00000000,0x00000000}},	//   _कठीण_, _ssep, --, --,
   {{0x0eb9022c,0x7f27071c,0xf3670c3f,0x7afd0206}},	//   кулы_, اءال, _стон, žsti,
   {{0xe80b0285,0x00000000,0x00000000,0x00000000}},	//   _संभा_, --, --, --,
   {{0xed5958f2,0x518730c0,0xdcfa02f1,0x7e693b84}},	//   ток_, _сума, _entč, _vsep,
   {{0x962601d3,0xdb0b030a,0x62806c99,0x00000000}},	//   _ziņā, _amgá, _àmor, --,
   {{0xa0c40037,0x69c60103,0x200c0113,0x7e69039f}},	//   _ايفو, éken, _édia_, _tsep,
   {{0x49c90f84,0x7c2400e7,0x3860007e,0x7e690415}},	//   клин_, ćira, _ćira_, _usep,
   {{0x49953519,0x00000000,0x00000000,0x00000000}},	//   ршит, --, --, --,
   {{0xdd7a0130,0x28cf0caf,0xdb007d54,0xc6890266}},	//   _שטעל, _सुखि, rimò, _קא_,
   {{0xc5e900a1,0x7bd900ac,0xdd2f00b6,0x6e2d00e7}},	//   _חד_, _ukwu, věři, šabu,
   {{0x7bc400c6,0x00000000,0x00000000,0x00000000}},	//   čiut, --, --, --,
   {{0x64a601b6,0xdb022f8a,0x487900d3,0x7ae60233}},	//   аага, _aloè, _асия_, ükte,
   {{0x232a1907,0xe8df0023,0x07a601b3,0x00000000}},	//   кови_, _phổi_, _вайн, --,
   {{0x9207250d,0xda0800de,0x00000000,0x00000000}},	//   _वंशज_, _hỏa_, --, --,

   {{0xe2970303,0x6db20034,0x99dd0094,0x00000000}},	// [8000] аат_, cław, stňu, --,
   {{0x23bf0084,0x00000000,0x00000000,0x00000000}},	//   täjä_, --, --, --,
   {{0xaf060012,0xe8df00de,0x21676f46,0x806611ba}},	//   апел, _thổi_, рихи_, рвеж,
   {{0xdfcf0adb,0x645e1cb2,0xf3ff0023,0xadc30065}},	//   ويل_, _ippi, _giã_, _itẹn,
   {{0x3ea00080,0x00000000,0x00000000,0x00000000}},	//   áit_, --, --, --,
   {{0xa5bb0131,0x00000000,0x00000000,0x00000000}},	//   lsór, --, --, --,
   {{0x3ea0030b,0xdc87008f,0x0ba6007e,0xbc670192}},	//   šit_, исъл_, ишим, لمون_,
   {{0xa5bb016d,0x201a007b,0x6ac10285,0x00000000}},	//   nsór, mppi_, शपूर, --,
   {{0xa3ab632d,0x2fc60039,0xe8d90019,0xaab80260}},	//   कोट_, mnog_, _đỡ_, دگار_,
   {{0x2fc603ce,0x645e0084,0xb997007b,0xddc90206}},	//   lnog_, _oppi, ивых_, _preť,
   {{0x1ddf009f,0xdb24001c,0x2fc60e94,0x2b98014b}},	//   _पीटत, _هوای, onog_, _sécu_,
   {{0x225238da,0xa6b20033,0xeb9a020f,0x2fc600f0}},	//   ktyk_, _টুইট, _шие_, nnog_,
   {{0x645e7d55,0xadc30065,0x6b827d56,0x2fc60270}},	//   _appi, _atẹn, _inog, inog_,
   {{0x2b9800fd,0xddc90031,0x6d9d0113,0x25a501cd}},	//   _vécu_, _treť, _rèak, óll_,
   {{0x893700a1,0x63a60167,0x6db20034,0x6b827d57}},	//   _כרגע_, _blkn, sław, _knog,
   {{0x2fc602e6,0x248d00e9,0xf69900cd,0x7afd0181}},	//   jnog_, ćem_, _منبع_, ľstv,
   {{0x6b8200e9,0x2fc603ce,0x7afd0074,0x2f0d109d}},	// [8010] _mnog, dnog_, žstv, _lógó_,
   {{0xd5b82917,0x00000000,0x00000000,0x00000000}},	//   _всю_, --, --, --,
   {{0x6b821197,0xbf2202d5,0xa3d51bec,0x00000000}},	//   _onog, मरून_, _гонч, --,
   {{0xb0be0096,0x02d9212c,0x6b820172,0x2fc60218}},	//   ्थजग, _موجب_, _nnog, gnog_,
   {{0x44310018,0x6e674e10,0xdb0900d2,0x201a7d58}},	//   lsz_, ртеж, áníc, appi_,
   {{0x94740260,0x69c60103,0xf2960266,0x6b824aab}},	//   _ادیا, ékel, _הכשר_, _anog,
   {{0x2fc60039,0x6d5a0154,0x403405e1,0xdb090a7f}},	//   bnog_, _dbta, _мерс, šníc,
   {{0x2fc604a3,0xa3ab074c,0x69ca0e94,0xdfd400c6}},	//   cnog_, कोच_, _ajfe, _досы,
   {{0xe9d91cf2,0x2918008e,0x3d9500ae,0x31710090}},	//   лки_, ıran_, _лиар, _kazz_,
   {{0x44316bbc,0x6b82028d,0x7e7b0172,0x3171436f}},	//   ksz_, _enog, _irup, _jazz_,
   {{0xa3d734d8,0x66160170,0x8d740e25,0x7e7b0117}},	//   ाका_, _styk, _باقا, _hrup,
   {{0x44310103,0x6b8201b9,0x997d02c6,0x6813044c}},	//   dsz_, _gnog, pňů_, _năde,
   {{0xeab32204,0x443100a5,0x9c7c0146,0xda0800de}},	//   _بعض_, esz_, _vyče, _tỏa_,
   {{0x2fc61419,0xb21b052f,0x31710063,0x4df900c1}},	//   znog_, _kræf, _nazz_, רפֿא,
   {{0x64a37d59,0x6813020a,0x443101f9,0x7f5b0415}},	//   пара, _băde, gsz_, _obuq,
   {{0x44330036,0x6813020a,0x73065ca3,0x7e7b010a}},	//   _dvx_, _căde, спаз, _orup,
   {{0x2fc602e6,0x28a50096,0x3a3f002b,0x6813020a}},	// [8020] vnog_, खनवि, nrup_, _dăde,
   {{0xa5bb0396,0x31710036,0x7f5b063d,0xda0a0d75}},	//   ssór, _cazz_, _abuq, _हंसत_,
   {{0x2fc602e6,0x7e7b00bf,0x645e7d5a,0xa9ba006e}},	//   tnog_, _arup, _uppi, נזער,
   {{0x43860080,0xfdb0000f,0x3a3f0085,0xa2d302f0}},	//   _الحق, जफ्फ, krup_, _भुक्,
   {{0x2fc603ce,0x291e008a,0x7e561c17,0xddcb7d5b}},	//   rnog_, ybta_, стец, _šišk,
   {{0x3a3f052f,0x7f5b0372,0x6b822779,0xdb02014b}},	//   drup_, _ebuq, _snog, _cloî,
   {{0x2fc6005f,0x38600ca7,0x40960037,0x7c240580}},	//   pnog_, _ćiro_, _الزر, ćiro,
   {{0x79832903,0x20180036,0x200a020a,0x22400634}},	//   _annw, _itri_, _iubi_, orik_,
   {{0x22400501,0xa92a0138,0x3f8403e3,0x752e022e}},	//   nrik_, ліне_, _inmu_, kabz,
   {{0x388e0253,0xf96a00d3,0x44310034,0x200a5a33}},	//   ləri_, урий_, ysz_, _kubi_,
   {{0x22407d5c,0x3bd6097a,0x291e7d5d,0xe802074c}},	//   hrik_, _людс, rbta_, _रूखा_,
   {{0x96f92eb1,0x65ab1210,0x212a0167,0x200a7d5e}},	//   иент_, _mühe, _lebh_, _mubi_,
   {{0x9f580af0,0x44317d5f,0x65ab00aa,0x200a71f5}},	//   _burú_, wsz_, _lühe, _lubi_,
   {{0x44310018,0x22407d60,0x6d4a541b,0x388e00a7}},	//   tsz_, drik_, ngfa, həri_,
   {{0x69da7d61,0xe8d90028,0x69c87d62,0x200a7d63}},	//   mote, _đủ_, mnde, _nubi_,
   {{0x7ae27d64,0x67d4013d,0x22407d65,0x443107ff}},	//   _kyot, _нощу, frik_, rsz_,
   {{0x44310018,0xddc27d66,0xc1b90829,0x672f0034}},	// [8030] ssz_, dvož, алах_, macj,
   {{0x69da7d67,0x672f0067,0x69c87d68,0x64410472}},	//   note, lacj, nnde, àlis,
   {{0x43952813,0x388e0092,0x64410145,0x200a2ab6}},	//   _данс, fəri_, álid, _cubi_,
   {{0x200a1114,0x64477d69,0x672f0034,0x8afd02c6}},	//   _dubi_, muji, nacj, deřn,
   {{0x69da7d6a,0x63ad7d6b,0x7e7b0092,0x7ae27d6c}},	//   kote, mhan, _qrup, _nyot,
   {{0x63ad00c9,0x69da7d6d,0xd65800a1,0x37cf0081}},	//   lhan, jote, ציות_, রতির,
   {{0x645503f3,0x672f0067,0x200a04a3,0xa2c10ff9}},	//   ntzi, kacj, _gubi_, लपक्,
   {{0xeb992de9,0x69c87d6e,0x7e7b7d6f,0xa3e900b6}},	//   рии_, ende, _trup, यति_,
   {{0xbfa8016e,0x7e7b0193,0x69da7d70,0x64477d71}},	//   _утре_, _urup, fote, huji,
   {{0x49997d72,0xfeb804c6,0x64472822,0xb21b02b6}},	//   ртия_, _طاقت_, kuji, _træf,
   {{0xa3e906ec,0x63ad7d73,0x644700e7,0x5c7500ae}},	//   यता_, khan, juji, _флет,
   {{0x69c87d74,0x998600a5,0xaa59136c,0x8b671a13}},	//   ande, _ktoś_, _виду_, _دائم,
   {{0x63ad7d75,0x69da7d76,0x6db20034,0xa3d80403}},	//   dhan, bote, płat, िवस_,
   {{0x98a511d9,0x7bc925a8,0x63ad41be,0x2a6f039f}},	//   _миле, lneu, ehan, _isgb_,
   {{0x63ad01a2,0x2fcd0167,0xe885004d,0x23a700bc}},	//   fhan, _ojeg_, _єгип, _sõja_,
   {{0x63ad7d77,0x7bc97d78,0x2fcd03ab,0x4226008f}},	//   ghan, nneu, _njeg_, ждав,
   {{0xa3bb1085,0x27e07d79,0x200a7d7a,0xf11a0037}},	// [8040] _अगर_, _ikin_, _subi_, لغات_,
   {{0x22404a7b,0x0f220789,0x64477d7b,0x68e32085}},	//   rrik_, मर्स_, buji, _kynd,
   {{0x106a0f8d,0x13a8001c,0x7bc97d7c,0x27e001ff}},	//   рией_, _هندی_, kneu, _kkin_,
   {{0x68e364f8,0x63ad7d7d,0xa3ae030b,0x69da7d7e}},	//   _mynd, chan, _कति_, zote,
   {{0xa3d70f78,0x27e0005c,0x69da7d7f,0x69c60103}},	//   ाकर_, _mkin_, yote, ékek,
   {{0x672f0067,0x200a3292,0x63a47d80,0x64410220}},	//   zacj, _tubi_, lkin, šlie,
   {{0x6d4a0ba1,0x7ae207ac,0x2018028d,0xb21b02b6}},	//   rgfa, _syot, _utri_, _præg,
   {{0x63a47d81,0x7bc90257,0x3f8401c2,0x69c800f0}},	//   nkin, gneu, _unmu_, wnde,
   {{0x298a1300,0x63a47d82,0xb21b3e59,0x8cda0f38}},	//   асно_, ikin, _græd, _पुरो,
   {{0x69c86b54,0x7ae20051,0x672f0034,0xad25001c}},	//   unde, _vyot, wacj, _فرمو,
   {{0x20047d83,0x672f00a5,0x27e00085,0xb4e92065}},	//   _kimi_, tacj, _bkin_, _बरे_,
   {{0x29070222,0x63a40126,0x69da7d84,0x27e003e3}},	//   _egna_, jkin, sote, _ckin_,
   {{0x20041ee3,0x672f0067,0x69da1cc0,0x63ad7d85}},	//   _mimi_, racj, pote, vhan,
   {{0x7bc07d86,0x20047d87,0x63ad03e3,0x1dbc0469}},	//   limu, _limi_, whan, ्चित,
   {{0x63ad7d88,0x63a414f3,0x68e3122c,0x00000000}},	//   than, fkin, _gynd, --,
   {{0x20044880,0x64550a00,0x52153120,0x63a42447}},	//   _nimi_, rtzi, здат, gkin,
   {{0xe8100251,0x1dbc1677,0x645501c0,0xdb0b0212}},	// [8050] _ठंडा_, ्चात, stzi, _umgå,
   {{0x63ad08f0,0x7bc07d89,0xddc200a5,0x20047d8a}},	//   shan, himu, rtoś, _aimi_,
   {{0x672d063f,0x660d0113,0x63a47d8b,0x7bc07d8c}},	//   _keaj, _huak, bkin, kimu,
   {{0x63a400a1,0x7bc0013f,0xedc34c5b,0x8608001c}},	//   ckin, jimu, वच्छ, _دقیق_,
   {{0xa3e40251,0x7bc07d8d,0xa77c00c1,0xab5d0034}},	//   _पीट_, dimu, יראפ, niże,
   {{0x98a5002d,0x7bc90150,0x6aa000f0,0x22490634}},	//   nală_, wneu, dymf, muak_,
   {{0xdd8e00e3,0x22490a00,0x20040234,0x660500aa}},	//   اوى_, luak_, _fimi_, _mihk,
   {{0x7bc07d8e,0xb21b052f,0xdb020072,0x7a200134}},	//   gimu, _træd, _eloí, _ịtac,
   {{0xdce30128,0x224901e9,0x68e600a7,0x0f320103}},	//   menč, nuak_, əkdi, _سکند,
   {{0x63a402a7,0x20040995,0xae4400cd,0x27e000ca}},	//   zkin, _zimi_, _آپلو, _skin_,
   {{0x63a47d8f,0x7bc07d90,0x660d0124,0x7bc9084e}},	//   ykin, bimu, _auak, pneu,
   {{0xf7721a13,0x224901e9,0x6e297d91,0x68e37d92}},	//   راج_, kuak_, _kweb, _vynd,
   {{0xa3c10b7f,0x290700dc,0x68e37d93,0x63a47d94}},	//   ्चन_, _tgna_, _wynd, vkin,
   {{0x224901e9,0x68e37d95,0xdb000161,0x660d0167}},	//   duak_, _tynd, rimô, _duak,
   {{0x63a47d96,0x69c17d97,0x2a6d48f5,0x9479141b}},	//   tkin, mile, lweb_, осту_,
   {{0x69c17d98,0x6f097d99,0xdce34f88,0xfd4c0294}},	//   lile, _ngec, jenč, _belụ,
   {{0xc64a0080,0x69c10091,0x6e290129,0x9f420174}},	// [8060] _اجعل_, oile, _nweb, _óké_,
   {{0x20047d9a,0x63a43a50,0xb6bb0054,0x867b0105}},	//   _simi_, skin, _לצפי, _פריו,
   {{0x63a47d9b,0x036a42d1,0xddc90128,0xa067008f}},	//   pkin, _линк_, _brež, заха_,
   {{0xb21b01c5,0x69c17d9c,0x22497d9d,0x6e290517}},	//   _dræb, hile, buak_, _bweb,
   {{0x69c17d9e,0x7bc0013f,0xddc90357,0xff03224a}},	//   kile, vimu, _drež, няшн,
   {{0x69c17d9f,0x6e29039f,0x3e5e00e8,0x7bc00169}},	//   jile, _dweb, vātā_, wimu,
   {{0x69c17da0,0x6e297da1,0x20047da2,0xdce30234}},	//   dile, _eweb, _timi_, benč,
   {{0x65ab0092,0x6b990849,0xdce30f1c,0xdb00007b}},	//   _müha, _cowg, cenč, yhmä,
   {{0xadc30028,0x7bc07da3,0xe94400cd,0xb4e9009d}},	//   _quản, rimu, وردی, _बर्_,
   {{0x7bc07da4,0x69c17da5,0xddc90141,0x00000000}},	//   simu, gile, _zrež, --,
   {{0x7bc032e3,0x224901e9,0x672d7da6,0x98a5020a}},	//   pimu, zuak_, _peaj, vală_,
   {{0x37ab2c11,0xeb972082,0x65b00084,0x660d00dc}},	//   стон_, _них_, _lähd, _puak,
   {{0x69c17da7,0x98a500d3,0xcb070037,0x66051d4b}},	//   bile, tală_, _عيون_, _pihk,
   {{0x69c17da8,0xe94400bf,0xf9c4110a,0x65b00084}},	//   cile, _آرشی, _تحصی, _nähd,
   {{0x98a500d3,0xe7e816e2,0x66050329,0xd31a0174}},	//   rală_, _टीका_, _vihk, _ọtụr,
   {{0x224902a7,0x660d100b,0x00000000,0x00000000}},	//   tuak_, _tuak, --, --,
   {{0xdce37da9,0x98a500ae,0x644a0120,0xe2f80120}},	// [8070] venč, pală_, _åfin, зеті_,
   {{0x22490a00,0x67d201d3,0x6e290463,0x00000000}},	//   ruak_, māja, _rweb, --,
   {{0xddc940a2,0x224901e9,0xdce31e4d,0xe7cf0033}},	//   _prež, suak_, tenč, রতীয,
   {{0x69c17daa,0x6577023b,0x6e29009c,0xece000a3}},	//   zile, _haxh, _pweb, _फड़फ,
   {{0x69c17ac9,0xee3800d6,0xddc90095,0x67d200e8}},	//   yile, зні_, _vrež, nāja,
   {{0x05010081,0xfce511a0,0xb21b0537,0x9c7c00d4}},	//   ্রীর_, моло, _træb, _vyčn,
   {{0x6577023b,0x00000000,0x00000000,0x00000000}},	//   _maxh, --, --, --,
   {{0x09b7009d,0x64c50234,0x98a500c6,0x6e29149c}},	//   ेच्य, _ičić, nalą_, _tweb,
   {{0x69c17dab,0x34ca0285,0x00000000,0x00000000}},	//   tile, _रश्द, --, --,
   {{0x67d200e8,0x00000000,0x00000000,0x00000000}},	//   dāja, --, --, --,
   {{0x69c1074e,0xe3c208bb,0xf7462ac0,0xef190090}},	//   rile, lmış_, мено, _anżi_,
   {{0x69c17dac,0x2a6d028a,0x00000000,0x00000000}},	//   sile, pweb_, --, --,
   {{0x65b01c73,0xe3c207d1,0x69c17dad,0x657750bb}},	//   _lähe, nmış_, pile, _baxh,
   {{0x65ab007a,0x9c7c033b,0x6b8401b5,0x00000000}},	//   _püha, _izčr, _òigr, --,
   {{0xa5070097,0x65b07dae,0x00000000,0x00000000}},	//   дера_, _nähe, --, --,
   {{0x64416e49,0xe3c2026a,0x25b40138,0x00000000}},	//   ália, kmış_, _šalį_, --,
   {{0xd5b20018,0x7c240234,0x00000000,0x00000000}},	// [8080] _لفظ_, ćiri, --, --,
   {{0xb1430fe9,0xa0a60b36,0x65ab0364,0x64417daf}},	//   кнул, мазд, _hühn, šlia,
   {{0xb21b052f,0x00000000,0x00000000,0x00000000}},	//   _præc, --, --, --,
   {{0x201c00d9,0xddc902a1,0xa3e91da8,0x443a084e}},	//   īvi_, _ereż, यतः_, _ivp_,
   {{0x65b000c2,0xfe6f0604,0x05d20034,0x00000000}},	//   _tähd, لدو_, _सदाब, --,
   {{0x443a4918,0x7e6d0231,0x00000000,0x00000000}},	//   _kvp_, çapa, --, --,
   {{0x91035c95,0x443a00c4,0x4438007e,0x70562259}},	//   _апре, _jvp_, nsr_, _تنزا,
   {{0xda0800ef,0xe8df0023,0x3a7421b4,0x3178042c}},	//   _hỏi_, _chọi_, елир, _harz_,
   {{0xe6c802d5,0x290a6404,0x261400bc,0x9c7c00d4}},	//   रपोज, žbam_, _näo_, _tyčo,
   {{0x6e227db0,0x67d201d3,0x44380063,0xd90d001c}},	//   mpob, vāja, ksr_, میه_,
   {{0xda0800de,0x65ab0364,0xa3ae10e9,0x317802ac}},	//   _mỏi_, _bühn, कसा_, _marz_,
   {{0x67d200d9,0x7ac61a9f,0xcb6a00ae,0xda08020b}},	//   tāja, _осле, _фаде_, _lỏi_,
   {{0x4438084e,0x7c38084e,0x00000000,0x00000000}},	//   esr_, lsvr, --, --,
   {{0x58d47db1,0xdb0b054e,0x67d20877,0xdcfa00e8}},	//   _полт, _algè, rāja, _notī,
   {{0x9f58037a,0x7c38000b,0x798a0154,0x443a0233}},	//   _juró_, nsvr, _infw, _cvp_,
   {{0x67d200d9,0x60d50063,0xe3c20342,0x7c3805c2}},	//   pāja, _rxzm, ymış_, isvr,
   {{0x05010081,0xddc9003d,0x9f9c003e,0x00000000}},	// [8090] ্রের_, _preż, víð_, --,
   {{0x51f8055b,0xd13102fc,0x2a6600dc,0x00000000}},	//   дную_, اما_, _mpob_, --,
   {{0x75357db2,0x9f9c003e,0x443a023e,0x53350a29}},	//   mazz, tíð_, _gvp_, _пент,
   {{0x75352fce,0x65b04207,0xa29516dd,0xe3c203e0}},	//   lazz, _vähe, _замі, tmış_,
   {{0x59de1344,0x9f5800b3,0x7c3a0b85,0x9f9c01cd}},	//   नकार, _auró_, _avtr, ríð_,
   {{0x7535003d,0x65b00006,0xe3c2008b,0x50670450}},	//   nazz, _tähe, rmış_, _отба,
   {{0x3ea96a6a,0x64c50095,0xda0800fe,0xe8df0174}},	//   šat_, _učić, _gỏi_, tbọl_,
   {{0x6aca1c83,0x9f580487,0xe3c20367,0x753547be}},	//   ापूर, _duró_, pmış_, hazz,
   {{0x753504f9,0xb4bc0ed3,0x67f600b6,0x995802c6}},	//   kazz, _अध्_, náje, láři_,
   {{0xf9910080,0x75350078,0x20117db3,0xf1b2006e}},	//   ابة_, jazz, _kuzi_, ָסט_,
   {{0xa3c1087c,0xfc3000e3,0x20110051,0x39580013}},	//   ्चा_, _نحن_, _juzi_, òrsa_,
   {{0x20111937,0x24860031,0x798a0154,0x9f440206}},	//   _muzi_, _čom_, _enfw, _shmú_,
   {{0xa6834441,0x6b8b64ea,0xe9f90565,0x80d90081}},	//   гляд, _ingg, _енді_, ভেচ্,
   {{0xceb2534e,0x75353543,0x6e3b246c,0x201105aa}},	//   נים_, gazz, _mvub, _ouzi_,
   {{0xdb0b0257,0x77a603be,0x6f1b0559,0x995800d2}},	//   _algé, _lóxi, _ofuc, jáři_,
   {{0x44380131,0xae0f055c,0x67d200e8,0x00000000}},	//   rsr_, ादान_, mājo, --,
   {{0xe8df0019,0x6b8b005c,0x65ab01bf,0x20113280}},	// [80a0] _khỏi_, _mngg, _kühl, _auzi_,
   {{0x75350451,0x6b8b010a,0x3ec2013c,0x2fcf03a9}},	//   cazz, _lngg, _üstə_, engg_,
   {{0x03a600d3,0x65ab0364,0x6e3b0512,0x25a500c2}},	//   _зино, _mühl, _avub, ölle_,
   {{0x201100cc,0x644e7db4,0x3878003e,0x645c01ce}},	//   _duzi_, mubi, ærri_, mtri,
   {{0xdfcf0037,0xe1ff0139,0x31780233,0x7764039f}},	//   حين_, _ipón_, _tarz_, _mbix,
   {{0x6b8b0cd0,0xdd9000e3,0xda080023,0xc90e0034}},	//   _angg, شوب_, _tỏi_, _सलेम_,
   {{0x20110218,0x9f580036,0xa067219d,0x6e226df6}},	//   _guzi_, _durò_, _пара_, spob,
   {{0x67d201d3,0x2a660167,0x7c38000b,0x656e019f}},	//   dājo, _ppob_, rsvr, hebh,
   {{0x645c7db5,0x644e0a3d,0xdd8f0281,0xab66058f}},	//   htri, hubi, _گول_, _asüü,
   {{0x644e7db6,0x6b8b7db7,0x9f580428,0x77640062}},	//   kubi, _engg, _turó_, _abix,
   {{0xa3d0110f,0x75357db8,0x2d8c7db9,0xd8f800d6}},	//   वचा_, vazz, _inde_, ьної_,
   {{0xe7cf0081,0x645c7dba,0x2fc600f0,0x2d9e33c4}},	//   রত্য, dtri, niog_, _hote_,
   {{0x2d9e14b1,0x753503e5,0xb5fb10d9,0x65ab01bf}},	//   _kote_, tazz, ntág, _fühl,
   {{0xb21b01c5,0x2d9e023b,0x645c01bf,0xb8940037}},	//   _bræn, _jote_, ftri, _للتع,
   {{0x753504f9,0xa4d400d6,0x645c1fab,0x2d9e004d}},	//   razz, горі, gtri, _mote_,
   {{0x3ea60bb6,0x61fe0381,0x201101c6,0xd3781146}},	//   kyot_, empl, _ruzi_, нчу_,
   {{0x2d8c7dbb,0x75357dbc,0x21310154,0x71790831}},	// [80b0] _onde_, pazz, _pezh_, мбар_,
   {{0x2d9e32b8,0x20110580,0x644e7dbd,0xb21b003e}},	//   _note_, _puzi_, bubi, _fræn,
   {{0xb21b469f,0x644e034f,0x645c1b14,0x765d00f9}},	//   _græn, cubi, ctri, ltsy,
   {{0x442103ea,0x201c7dbe,0x61fe7dbf,0xb4ad2c5f}},	//   _ith_, ívia_, ampl, कनी_,
   {{0x2d9e7dc0,0x3ea67dc1,0x539a00ca,0x290a0117}},	//   _bote_, gyot_, _חירו, žbah_,
   {{0x7bc27dc2,0x2d9e7dc3,0xbea20426,0x644800d9}},	//   _amou, _cote_, рашк, šdie,
   {{0xeb996561,0xabd507c8,0xe81000b6,0x1048007b}},	//   дий_, кциј, _ठूला_, _пяти_,
   {{0x2d8c7dc4,0x77a660d3,0x291c0154,0x33290188}},	//   _ende_, _tóxi, _afva_, nbax_,
   {{0x98ac01d3,0x2d8c0231,0x68080139,0xdddb078e}},	//   vadā_, _fnde_, _lèjì, _cruţ,
   {{0x8d74001c,0x44210503,0xb5fb0072,0x2d9e7dc5}},	//   _ماما, _oth_, ntád, _gote_,
   {{0xb604000d,0x645c7dc6,0xe80b0251,0x6b8b005c}},	//   ntář, xtri, _सूखा_, _tngg,
   {{0x2d9e068d,0x6b8b234a,0x22497b56,0x2ca7003e}},	//   _zote_, _ungg, krak_, mynd_,
   {{0x2d9e068d,0x44217dc7,0x22491a0d,0x31a40103}},	//   _yote_, _ath_, jrak_, _közt_,
   {{0x645c7dc8,0x644e7dc9,0xa5bb7dca,0xdce802c6}},	//   ttri, tubi, spón, _nadě,
   {{0x44211d49,0x22490a00,0x657c0364,0x69c3009e}},	//   _cth_, erak_, rdrh, _imne,
   {{0x764f4b24,0x2c7c00b6,0x224931d4,0x63790231}},	//   bucy, ládá_, frak_, нсур_,
   {{0x261905d4,0x6d4102e6,0x644e7dcb,0x7e690069}},	// [80c0] _यूपी_, _odla, subi, _npep,
   {{0xb21b0021,0x3f8d0428,0xa9240220,0x7aeb0138}},	//   _træn, _aneu_, peľň, _mygt,
   {{0x2d9e7dcc,0x7e690383,0x7aeb7dcd,0x9c7c00d4}},	//   _rote_, _apep, _lygt, _vyčk,
   {{0x6d417dce,0xdce80038,0x2d9e7dcf,0x22497dd0}},	//   _adla, _podľ, _sote_, brak_,
   {{0x2d9e0c56,0xa3c1074c,0x69c37dd1,0x9c7c00d4}},	//   _pote_, ्चर_, _omne, _tyčk,
   {{0x2fc6013f,0x442100ec,0x6296023e,0x7bc2084e}},	//   siog_, _yth_, mxyo, _smou,
   {{0x6da31e6e,0x6aca1efb,0x2d9e7dd2,0xfc6405bc}},	//   рија, ाप्र, _vote_, اختی,
   {{0x2d9e068d,0x62867dd3,0x8fa31a9c,0x65ab00aa}},	//   _wote_, _krko, _касе, _rühm,
   {{0xcb6719e8,0x2d9e1399,0x00000000,0x00000000}},	//   тање_, _tote_, --, --,
   {{0x2d8c0012,0x62862cea,0x7aeb052f,0xa0000294}},	//   _unde_, _mrko, _dygt, _ịchị,
   {{0x313700a1,0x22494a8d,0x1cba0103,0xc7d7020b}},	//   כנים_, zrak_, _غائب_, _ởđâu_,
   {{0x97a71312,0x69c30856,0x765d66bd,0x62867dd4}},	//   трол, _emne, ttsy, _orko,
   {{0xdddb2449,0xa2c20980,0x6296023e,0x00000000}},	//   _hruš, _रेल्, jxyo, --,
   {{0xdddb0542,0x765d4492,0xdbd1003e,0x764f0169}},	//   _kruš, rtsy, lýðs, rucy,
   {{0xd5b80d64,0xb4ad218b,0x81d80081,0xe4a40dd8}},	//   тся_, कने_, াতা_, арто,
   {{0x62860106,0x9cd70327,0x88bc00d2,0x7c4500d8}},	//   _brko, דולה_, yběj, _útrž,
   {{0x27e97dd5,0x69c800c2,0x70bd0af1,0xd6d800d3}},	// [80d0] _ikan_, oide, ्प्ल, _атэ_,
   {{0x224903f3,0x69c860c9,0x645a0472,0x65b0042c}},	//   rrak_, nide, àtic, _hähn,
   {{0x62867dd6,0x69c8008c,0x44210113,0x10142259}},	//   _erko, iide, _uth_, لبند,
   {{0x63b61347,0x69c87dd7,0x22497dd8,0x43951e11}},	//   chyn, hide, prak_, _самс,
   {{0x69c87dd9,0x250909b4,0x3f8100b6,0xa3e0007f}},	//   kide, _ترکی_, ěhu_, दकर_,
   {{0x7aeb02b6,0xdddb3692,0x69c87dda,0x00000000}},	//   _rygt, _bruš, jide, --,
   {{0x27e91296,0x61e5025b,0x69c87ddb,0x25a100b6}},	//   _okan_, mohl, dide, _mohl_,
   {{0x63ad7ddc,0xb5fb7ddd,0xdb090396,0xfe7300cd}},	//   nkan, ntáb, nheç, _پدر_,
   {{0x1a6509b4,0x7e690051,0x98ae0154,0xb5fb0072}},	//   ایتی_, _upep, _defč_, itáb,
   {{0x27e966bf,0x69c87dde,0x63ad005a,0x6d417ddf}},	//   _akan_, gide, hkan, _udla,
   {{0xcb550241,0x27e9005c,0xbb5500cd,0x64410307}},	//   _مناظ, _bkan_, _مناب, šlij,
   {{0x63ad7de0,0x61e57de1,0x69c82afe,0x00000000}},	//   jkan, hohl, aide, --,
   {{0x69c803f3,0x200d013d,0xdddb0618,0x61e57de2}},	//   bide, _miei_, _zruš, kohl,
   {{0x27e97de3,0x63ad7de4,0x7bc97de5,0x69c87de6}},	//   _ekan_, ekan, lieu, cide,
   {{0x98ac00ae,0x63b60178,0x443e7de7,0x74163a1d}},	//   radă_, thyn, ét_, اورا,
   {{0x7bc97de8,0x63ad172a,0x62860335,0xa6960a28}},	//   nieu, gkan, _prko, _број,
   {{0xe1fa03fc,0x63b656d8,0x6abb01bf,0x6aa95445}},	// [80e0] ега_, rhyn, nzuf, nyef,
   {{0x63ad7de9,0x201c016d,0x7c3e7dea,0x65b00364}},	//   akan, ívio_, špri, _zähn,
   {{0x11d70080,0x9c7c73c9,0x7056071c,0x63ad0ff6}},	//   دولة_, _tyči, انصا, bkan,
   {{0x69c87deb,0x63ad7dec,0xee3a23bf,0xe29a7ded}},	//   zide, ckan, енд_, _зам_,
   {{0xdddb1419,0x6da6322c,0xa2cb030b,0x657e7dee}},	//   _sruš, лида, _सेप्, _kaph,
   {{0xdddb7def,0x657e1cd1,0x00000000,0x00000000}},	//   _pruš, _japh, --, --,
   {{0x657e7df0,0xb5fb0224,0x66160381,0x7bc9014b}},	//   _maph, ltác, _luyk, fieu,
   {{0x657e067d,0x7bc95a20,0x69c87df1,0xafe6386f}},	//   _laph, gieu, wide, _собл,
   {{0x69c87a1a,0xb5fb7df2,0xdb0b03a8,0x4ed500e5}},	//   tide, ntác, _algâ, _кюфт,
   {{0x657e0201,0xb33b7df3,0x63ad7df4,0x27e97df5}},	//   _naph, _moça, zkan, _skan_,
   {{0x63ad0694,0x0c260f32,0xdddb08a9,0x6b9b009e}},	//   ykan, _смен, _uruš, bjug,
   {{0x7bc90257,0x7a860018,0x644101d3,0x63ad0634}},	//   cieu, _مشتم, šlik, xkan,
   {{0xb8eb147f,0x78ba0018,0x657e0201,0x1994246d}},	//   _रे_, sztv, _baph, _валя,
   {{0x2d9c00dd,0x3eb90233,0x657e5d01,0x00000000}},	//   njve_, _üste_, _caph, --,
   {{0xf367180b,0x63ad731a,0x6d5a0090,0x69d801cb}},	//   лтан, tkan, _mcta, _ijve,
   {{0x25a102e2,0x67f60220,0x65ab7df6,0x61e567c5}},	//   _wohl_, pája, _mühi, wohl,
   {{0x6d5a30d3,0x65ab007a,0x9c130134,0xb33b0131}},	// [80f0] _octa, _lühi, họpu, _coça,
   {{0x63ad7df7,0xb5fb7df8,0x657e0066,0x61fc00d4}},	//   skan, stáb, _gaph, _chrl,
   {{0x63ad7df9,0xb5fb381f,0x3f155136,0x7c2d6126}},	//   pkan, ptáb, адес, ćark,
   {{0x61fc01bf,0x62840565,0x61e57dfa,0xa85700ca}},	//   _ehrl, bvio, sohl, ריאה_,
   {{0xd9f6007d,0xb5fb0fb6,0x6b9b00e7,0x657e0201}},	//   ुगात_, ctác, vjug, _yaph,
   {{0xdcfa0702,0xdca54367,0x777f0090,0x00000000}},	//   _altı, иали, _laqx, --,
   {{0x7bc97dfb,0x9f6b01b3,0x00000000,0x00000000}},	//   tieu, _праз_, --, --,
   {{0x38bb0032,0x0ec000a4,0x00000000,0x00000000}},	//   _láré_, _शेकड, --, --,
   {{0x7bc97dfc,0x6b9b058f,0x00000000,0x00000000}},	//   rieu, rjug, --, --,
   {{0x7bc9025a,0x7e7b7dfd,0xe8190789,0xa2d80096}},	//   sieu, _isup, _नंदा_, _यशस्,
   {{0xe8f614fa,0x6abb7dfe,0x8afd00b6,0x7bc97dff}},	//   иль_, szuf, teřs, pieu,
   {{0x657e7e00,0xd7060e2d,0xe73a00c2,0x628301d3}},	//   _saph, изни, ъем_, ānoj,
   {{0x2bb800e3,0x67d200d9,0x38bb0139,0x777f02a1}},	//   _حالة_, nāji, _báré_, _daqx,
   {{0xb33b016d,0xc9870284,0x657e019f,0x00000000}},	//   _roça, _људи, _qaph, --,
   {{0xab5d003d,0x88830018,0xb21b77d4,0xc9d400d1}},	//   viżj, _ایجن, _fræk, _دموک,
   {{0x03262549,0x65b001bf,0x657e0201,0x7e7b033b}},	//   рдан, _zähl, _waph, _osup,
   {{0x61fc01b9,0x290a00c4,0xdb003341,0xa1c67e01}},	// [8100] _phrl, žbat_, ckmä, абад,
   {{0x62847e02,0xc04606cf,0xb5fb0437,0x6146004d}},	//   rvio, لخصو, rtác, режа,
   {{0x7e7b002d,0x67f60181,0x62840131,0x753c7e03}},	//   _asup, nájo, svio, marz,
   {{0x753c0034,0xb5fb0844,0x00000000,0x00000000}},	//   larz, ptác, --, --,
   {{0xfe7212eb,0xdce1013f,0x7e7b0103,0x67d201d3}},	//   تدا_, _kalė, _csup, gāji,
   {{0x22407e04,0x7981023e,0x9c4600ae,0x753c3ec6}},	//   msik_, jdlw, ахил, narz,
   {{0x224012f5,0x7e7b40ab,0x260f0090,0x65b0042c}},	//   lsik_, _esup, _ożon_, _nähm,
   {{0xafe318be,0x207b006e,0xaa661e9e,0x21380381}},	//   _досл, _באלא, аток, _herh_,
   {{0x753c00a5,0x201801ee,0x41dd0285,0xdb000120}},	//   karz, _huri_, _मदमस, kkmå,
   {{0x1daa05a4,0x20187e05,0x65ab00aa,0x753c0034}},	//   _कवित, _kuri_, _tühi, jarz,
   {{0x20187e06,0x753c00a5,0xdcfa0154,0x00000000}},	//   _juri_, darz, _katč, --,
   {{0x201826c5,0x22407e07,0x65b002e2,0xab2a4aa9}},	//   _muri_, ksik_, _wähl, _рода_,
   {{0x95cb016e,0x2018010a,0x2a76001c,0xdcfa659e}},	//   вува_, _luri_, _خداح, _matč,
   {{0x6d587e08,0x6703009d,0x753c01ff,0x9c7c0154}},	//   ngva, रेषक_, garz, _fyčt,
   {{0xb21b01c5,0x20187e09,0x44257e0a,0x94a841c8}},	//   _træk, _nuri_, ël_, атта_,
   {{0xf77f0161,0x7e62224d,0x47354c81,0xdb1b003e}},	//   moço_, ktop, _унис, nnuð,
   {{0x7e621197,0x20180d2a,0x673d0b65,0x22400d1f}},	// [8110] jtop, _auri_, masj, gsik_,
   {{0xdce101b3,0x2018023f,0x673d7e0b,0xa2cb152c}},	//   _galė, _buri_, lasj, _सेण्,
   {{0x2018181b,0x6703097c,0x7e7b7e0c,0x00000000}},	//   _curi_, रेरक_, _ssup, --,
   {{0x9f05054f,0x64556610,0x67d20029,0x673d7e0d}},	//   موضو, muzi, tāji, nasj,
   {{0x64557e0e,0xd244002d,0x20187e0f,0x213800bd}},	//   luzi, _мэри, _euri_, _ferh_,
   {{0x51871b4b,0x2b460036,0x20187e10,0x6d582c81}},	//   _тума, _adoc_, _furi_, ggva,
   {{0x20187e11,0x673d7e12,0x64557e13,0xb5b800ca}},	//   _guri_, kasj, nuzi, שלוח_,
   {{0x7e7b00a6,0x32190146,0xdd3a00ae,0x14d80266}},	//   _tsup, _kusy_, păşi, יוול_,
   {{0x20187e14,0xa3af0006,0xef1902a1,0x673d0208}},	//   _zuri_, _कवन_, _gaża_, dasj,
   {{0x64552828,0x3a3f0167,0x6ea400b6,0x00000000}},	//   kuzi, rsup_, कहरु, --,
   {{0xe73a0b73,0x480a2290,0x3a260172,0x32197e15}},	//   лен_, леон_, _etop_, _lusy_,
   {{0x64557e16,0x753c00a5,0x673d00d6,0xf3ff00de}},	//   duzi, warz, gasj, _nhã_,
   {{0xa969282a,0x31af026a,0x753c7e17,0x681300ae}},	//   _била_, _kızı_, tarz, _rădu,
   {{0xa2c20c38,0x64a6097a,0xf77f016d,0xc4c60076}},	//   _रेग्, бага, boço_, متزو,
   {{0xa34a013d,0x681300ae,0x64557e18,0x7e627e19}},	//   лзва_, _pădu, guzi, ztop,
   {{0xb4e800a3,0x201802a4,0x22405f88,0x321978f3}},	//   _बडी_, _ruri_, tsik_, _busy_,
   {{0xe29733d0,0x175700a1,0xb1460c2b,0x2018260d}},	// [8120] бат_, _הספר_, йнал, _suri_,
   {{0x20187e1a,0x64557e1b,0x22407e1c,0x044630fd}},	//   _puri_, buzi, rsik_, _леон,
   {{0x64557e1d,0x22407e1e,0x32110113,0xf8b70179}},	//   cuzi, ssik_, _dizy_, आनिय,
   {{0x44440797,0xb5fb0328,0x7e627e1f,0xa3bc0b42}},	//   _iv_, ntán, ttop, _अति_,
   {{0x44441cea,0x201859f0,0xb5fb0072,0xdd1c02c6}},	//   _hv_, _wuri_, itán, _záři,
   {{0x20187e20,0x3f8064dc,0x62830034,0x2c610076}},	//   _turi_, žiu_, łnoc, fód_,
   {{0x7e627e21,0x444400bf,0xdfd200e3,0xad65001c}},	//   stop, _jv_, _فيس_, تانه,
   {{0x3a267e22,0xdce302c6,0x7e627e23,0x63a671cb}},	//   _ptop_, leně, ptop, _jokn,
   {{0x44440b4b,0x67d20b4b,0xa5bb00e3,0x673d004d}},	//   _lv_, nāju, spói, vasj,
   {{0x44447e24,0x67247e25,0xbda50037,0xc27b0089}},	//   _ov_, _afij, _وحلو, נריי,
   {{0xd90d00cd,0x673d00d6,0x7644022b,0x6d487e26}},	//   نیه_, tasj, _aviy, _idda,
   {{0x200530ea,0x200600fe,0xf77f0131,0x00000000}},	//   _èlit_, nmoi_, roço_, --,
   {{0x44447e27,0x673d00d6,0x67d200e8,0x00000000}},	//   _av_, rasj, jāju, --,
   {{0x64557e28,0xb21b01c5,0x44447e29,0x673d7e12}},	//   tuzi, _kræv, _bv_, sasj,
   {{0x63a67e2a,0x3219425a,0x69ca7e2b,0xb062007b}},	//   _bokn, _susy_, _imfe, ääll,
   {{0x44447e2c,0x6455013d,0xb5fb0610,0x6d48010a}},	//   _dv_, ruzi, ctán, _ldda,
   {{0x6d487e2d,0x67d201d3,0x64550cfd,0x776d02a1}},	// [8130] _odda, gāju, suzi, _ibax,
   {{0x6b827e2e,0x44440c09,0xf1bf0af0,0x00000000}},	//   _laog, _fv_, _etán_, --,
   {{0x63a67e2f,0x00000000,0x00000000,0x00000000}},	//   _fokn, --, --, --,
   {{0x6d487e30,0x6b827e31,0x776d02a1,0x00000000}},	//   _adda, _naog, _jbax, --,
   {{0x2c610034,0xa77c00c1,0x44447e32,0x6da57e33}},	//   wód_, טראפ, _zv_, жила,
   {{0x444402a7,0x2bb139d4,0x6b82009c,0x98a700b6}},	//   _yv_, जस्थ, _aaog, _ceně_,
   {{0x44447e34,0x65b002fd,0x6b827e35,0x4c920284}},	//   _xv_, _sähk, _baog, дијс,
   {{0x2c6100a5,0x6d480517,0xaba9008f,0x65b013ce}},	//   ród_, _edda, рвиз_, _pähk,
   {{0x6025013f,0xb21b02b6,0x00000000,0x00000000}},	//   _dėme, _usæd, --, --,
   {{0x776d0415,0x3eb2004d,0x65ab042c,0x00000000}},	//   _abax, øyte_, _mühs, --,
   {{0xa3e90569,0x6b8201f7,0x98a500ae,0x18697e36}},	//   मका_, _faog, цине, шани_,
   {{0x4e1d1757,0x2a7d022e,0x98ac02c6,0x444432e8}},	//   _पढाई_, _tswb_, ladě_, _rv_,
   {{0x63a600bd,0xd9454116,0x69cf4fe5,0x8883001c}},	//   _rokn, _дели, éces, زیکن,
   {{0x67d200d9,0xb5fb6b06,0x63a67e37,0x00000000}},	//   vāju, stán, _sokn, --,
   {{0xd5e40174,0x833a40fc,0xa50a1262,0x63a60141}},	//   _arị, ичат_, рева_, _pokn,
   {{0x4444786f,0x67d20029,0x04570037,0xa7fd026a}},	//   _vv_, tāju, تلفة_, ltın,
   {{0x9f5f0028,0x65b00d80,0x79837e38,0xdce300b6}},	// [8140] _thuê_, _lähi, _kanw, teně,
   {{0xb5fb128f,0x444454f4,0xa7fd03e0,0x79837e39}},	//   ntál, _tv_, ntın, _janw,
   {{0xef1a07f3,0xdce10029,0x79837e3a,0x6e290150}},	//   аме_, _dalī, _manw, _ateb,
   {{0xf1bf0068,0xb5fb0037,0x69c601f9,0x26c201c8}},	//   _után_, htál, ékez, ozko_,
   {{0x64410220,0x26c20634,0x5de60110,0x1ec70e06}},	//   šlit, nzko_, ожда, олци_,
   {{0x6b820013,0x7bcb0150,0x26c201e9,0x798301c2}},	//   _saog, _amgu, izko_, _nanw,
   {{0x6e290172,0x201e020a,0xa5bb3f96,0x225202ac}},	//   _eteb, _îti_, mpót, lryk_,
   {{0xdee604f5,0x0b8a0318,0x7983043e,0x5a340cb0}},	//   _доби, рски_, _aanw, пнит,
   {{0x79837e3b,0xed5a2ff8,0xdfcf0076,0x00000000}},	//   _banw, _воз_, _شيك_, --,
   {{0x6d4801c5,0x3f840051,0x65b00364,0x6b820a4b}},	//   _udda, _hamu_, _fähi, _waog,
   {{0x3f8403b4,0xd7fb535e,0x79837e3c,0x7c281f60}},	//   _kamu_, иум_, _danw, _utdr,
   {{0x3f841084,0x3f8613a9,0xc7c7004d,0xd7f900ae}},	//   _jamu_, ndou_, існи, ptăm_,
   {{0x79830178,0x236901fa,0x8ad60018,0x46c500b6}},	//   _fanw, vfaj_, _بتائ, _लेखह,
   {{0x69ca7e3d,0x98a501d3,0x3f847e3e,0x7ae2039f}},	//   _umfe, galē_, _lamu_, _ixot,
   {{0x26c20634,0x776d00bd,0xe3b35f34,0x00000000}},	//   azko_, _tbax, ورر_, --,
   {{0x3f847e3f,0xdce100d9,0x3f8600b6,0x776d3bbf}},	//   _namu_, _salī, jdou_, _ubax,
   {{0x1ddb110f,0xdce10029,0x23ae003e,0x79837e40}},	// [8150] _बदलत, _palī, _nýju_, _yanw,
   {{0x69da7e41,0x7afd003e,0xd2500103,0x3f84007b}},	//   nnte, ýsti, کنے_, _aamu_,
   {{0x65ab02e2,0x6e297e42,0xb5fb7e43,0x3f847e44}},	//   _führ, _steb, ntám, _bamu_,
   {{0xd47a0130,0xa3af0c8c,0xb5fb0018,0x69da01bf}},	//   _פארל, _कवि_, ztál, hnte,
   {{0x3f847e45,0x539a00a1,0xa7fd0092,0xddc90117}},	//   _damu_, _הירו, ytın, _vsež,
   {{0xa7fd0092,0xd65800ca,0xa5bb0131,0xf2d2006e}},	//   xtın, קיות_, mpós, _װעל_,
   {{0x21ef01bf,0x9f35258b,0x7ae2039f,0x98ac00d2}},	//   bühr_, _неві, _axot, radě_,
   {{0x69da7e46,0x79830af0,0x65b02a3c,0x3f847e47}},	//   ente, _sanw, _vähi, _gamu_,
   {{0x79830085,0x6e2905e8,0x2fdf05db,0xa7fd0233}},	//   _panw, _uteb, _ijug_, ttın,
   {{0x3f847e48,0x65b0007a,0x69da7e49,0xfeb8001c}},	//   _zamu_, _tähi, gnte, _بافت_,
   {{0xb5fb2299,0x798303ee,0x7c2d2beb,0xa7fd008b}},	//   rtál, _vanw, ćars, rtın,
   {{0xb5fb7e4a,0x2d857e4b,0xf1bf2159,0x79830abb}},	//   stál, _hale_, _stál_, _wanw,
   {{0x2d857e4c,0xa2cb397e,0x1995008f,0x7bdb0188}},	//   _kale_, _सेल्, _надя, mnuu,
   {{0x2d857e4d,0x2d8701df,0xa7fd0367,0x3f860094}},	//   _jale_, ndne_, ltıl, zdou_,
   {{0x64a624e4,0x628f7e4e,0x2d8527f0,0x291c0031}},	//   чава, _arco, _male_, ázať_,
   {{0x42260b73,0x22527e4f,0xa7fd03a3,0x03a37e50}},	//   здав, tryk_, ntıl, нисо,
   {{0x27e07e51,0xab5d0034,0xe29722f6,0x3f860094}},	// [8160] _ijin_, liżs, пат_, vdou_,
   {{0x3f840a75,0xb4663a6f,0x2d85019f,0x764629ed}},	//   _samu_, _екол, _nale_, msky,
   {{0xe1ff00c9,0x628f0451,0x106a1cb1,0x76467e52}},	//   _após_, _erco, сией_, lsky,
   {{0x20552cbf,0x2d85008c,0xa2a70096,0x3f8616e7}},	//   ьтур, _aale_, _टॅक्, udou_,
   {{0x76467e53,0x3f8613a9,0xa3e90789,0x69da7e54}},	//   nsky, rdou_, मकर_, ynte,
   {{0x63b67e55,0xa6db0088,0x2d857e56,0x628300d9}},	//   lkyn, naða, _cale_, ānot,
   {{0x3f844b6a,0xddc900ae,0xc0e3596a,0xb21b3459}},	//   _tamu_, _speţ, _зорк, _fræs,
   {{0x69dd04ea,0x63a47e57,0xb21b02b6,0x27e00294}},	//   ésen, njin, _græs, _njin_,
   {{0x2d857e58,0x7d020065,0xc9860284,0xb21b01cd}},	//   _fale_, _bírí, пуни, _hrær,
   {{0x764669f2,0x69da7e59,0x27e00d2a,0x2918004d}},	//   dsky, unte, _ajin_, øra_,
   {{0x69da7e5a,0x63b600f3,0x7d020076,0xd90e0103}},	//   rnte, kkyn, _dírí, دیث_,
   {{0x2d857432,0x63a47e5b,0x7ae20634,0xdc9b021e}},	//   _zale_, jjin, _txot, _ליבל,
   {{0x443a7e5c,0x2c0b0018,0x6e220201,0x63b61054}},	//   _awp_, _اعلی_, nqob, dkyn,
   {{0x7afd31da,0x7d020139,0xca9700ca,0x2d850231}},	//   üste, _gírí, _מדדי_, _xale_,
   {{0x68420032,0x628f00c4,0x20040ca3,0x00000000}},	//   _dídá, _srco, _ohmi_, --,
   {{0x27e01175,0x63a400dd,0xa3bc30a8,0x0877006e}},	//   _gjin_, gjin, _अतः_, _זעהט_,
   {{0x52150120,0x00000000,0x00000000,0x00000000}},	// [8170] ддат, --, --, --,
   {{0xbba90557,0x673f023b,0x940b00a7,0x38c2020d}},	//   _छक्क, _heqj, _əmək_, _géré_,
   {{0xb21b01c5,0x2d8502f1,0x673f0052,0xa3ea0179}},	//   _præs, _rale_, _keqj, यवश_,
   {{0x2d857e5d,0x64550335,0x44310231,0x7d1a0f5a}},	//   _sale_, mrzi, mpz_, _agts,
   {{0x7c3a0090,0x63bd009e,0x2d855244,0x66170062}},	//   _awtr, _ilsn, _pale_, _kixk,
   {{0x645501c0,0x00000000,0x00000000,0x00000000}},	//   orzi, --, --, --,
   {{0x2d857e5e,0xac09022c,0x2d877e5f,0x69bb02d5}},	//   _vale_, онка_, rdne_, एससी,
   {{0x2d857e60,0x395e00d9,0x2fdf00d1,0x799805aa}},	//   _wale_, egts_, _ujug_, _anvw,
   {{0xfe700979,0x2d857e61,0x7c3a7e62,0xa7fd0e63}},	//   _مدل_, _tale_, _ewtr, rtıl,
   {{0x3ce800a5,0x27f27e63,0xb5fb0103,0x9588007f}},	//   _चुके_, _skyn_, stáj, _krąż,
   {{0x6d435279,0x3cf0025b,0xdddb005f,0x6f030139}},	//   mana, čové_, _kruž, _fìbí,
   {{0x65b0069d,0x7bc07e64,0xdb260281,0x2fdd00f0}},	//   _läht, chmu, _قومی, nnwg_,
   {{0xb8f47150,0xa6db003e,0x443a793f,0xdcfa00ae}},	//   _से_, taða, _swp_, _tată,
   {{0x76467e65,0x65b01d2d,0x273c0028,0x6b897e66}},	//   rsky, _näht, ận_, ldeg,
   {{0xdddb03ce,0x69c17e67,0x76460ce7,0x63a47e68}},	//   _oruž, mhle, ssky, tjin,
   {{0x6d437e69,0x6b897e6a,0x6f1b7e6b,0x76467e6c}},	//   hana, ndeg, _nguc, psky,
   {{0x59e11efb,0xdb0b11ce,0xa3af000f,0x41aa4f8c}},	// [8180] _पदार, _algú, _कवर_, ован_,
   {{0x6d437e6d,0x69c10201,0x63b67e6e,0x63a47e6f}},	//   jana, nhle, skyn, sjin,
   {{0x6d437e70,0x657c7e71,0x7bc70138,0x628b0212}},	//   dana, merh, _įjun, ågor,
   {{0x645c7e72,0xdd8f037f,0x657c5537,0x3fbe0081}},	//   muri, یون_, lerh, েক্ষ,
   {{0x6d437e73,0xdddb174d,0x798802ad,0xdfcf0037}},	//   fana, _druž, yddw, جين_,
   {{0x657c02e2,0x60c900b6,0x8445001c,0xb21b0170}},	//   nerh, _řeme, _تخیل, _trær,
   {{0x645c7e74,0x69c17e75,0x7bc07e76,0x6e3b7e77}},	//   nuri, dhle, thmu, _ewub,
   {{0x6d430009,0xdddb7e78,0x6b897e79,0x645c020a}},	//   aana, _gruž, gdeg, iuri,
   {{0x645c0440,0x657c16f3,0x60ce0138,0x00000000}},	//   huri, kerh, žimė, --,
   {{0x645c7e7a,0x69c103dc,0x7bc00052,0x657c037a}},	//   kuri, ghle, shmu, jerh,
   {{0x6e2001e5,0x798800f0,0x315700ca,0xad65001c}},	//   _humb, rddw, ויין_, _ساله,
   {{0x6e207e7b,0x9b930037,0x69c10206,0x00000000}},	//   _kumb, _للمت, ahle, --,
   {{0xdce801b3,0x6e207e7c,0x661701e9,0x38b40139}},	//   _padė, _jumb, _pixk, _búrú_,
   {{0xceb30130,0x645c7e7d,0x69c17e7e,0x6e207e7f}},	//   דיש_, furi, chle, _mumb,
   {{0x67d529b7,0x6e207a09,0xb5fb00e3,0x645c1556}},	//   _поку, _lumb, ntái, guri,
   {{0x6d437e80,0xe8020285,0x00000000,0x00000000}},	//   zana, ोषणा_, --, --,
   {{0x657c0f22,0x6e207e81,0x659530da,0x644a0088}},	// [8190] berh, _numb, _запу, _æfin,
   {{0x645c7e82,0x6d437e83,0x765d7e84,0x4905030b}},	//   buri, xana, musy, हेको_,
   {{0xdddb0106,0x6d437e85,0x765d20c1,0x645c7e86}},	//   _pruž, vana, lusy, curi,
   {{0x6d431c04,0x93c90018,0xef19009e,0x69c102c6}},	//   wana, _راجہ_, _każi_, zhle,
   {{0x65b0198c,0x6d43669b,0x6e207e87,0xee383006}},	//   _täht, tana, _cumb, дні_,
   {{0xa2bf3d34,0x9f4d01f7,0x44213a23,0x6e207e88}},	//   लैण्, _cheò_, _kuh_, _dumb,
   {{0x6d437e89,0x44210031,0x22497e8a,0x00000000}},	//   rana, _juh_, lsak_, --,
   {{0x6d437e8b,0x65b002e2,0x765d7e8c,0x6e20696b}},	//   sana, _jähr, kusy, _fumb,
   {{0x6d437e8d,0x6b897e8e,0x6e207e8f,0x645c7e90}},	//   pana, rdeg, _gumb, zuri,
   {{0x645c5197,0x6d437e91,0x9f4d009c,0x6b897e92}},	//   yuri, qana, _gheò_, sdeg,
   {{0x657c0b7c,0x6d4100d9,0xe8f9313c,0x645c7e93}},	//   verh, _iela, яло_, xuri,
   {{0xf092193b,0x6d417e94,0x22497e95,0x657c7e96}},	//   אנט_, _hela, ksak_, werh,
   {{0x6d4114f7,0x657c1a02,0x3e690220,0xe3c20587}},	//   _kela, terh, nút_, nlış_,
   {{0x6d410d17,0x9aa4114c,0xdb090084,0x22490f63}},	//   _jela, _جمهو, rkeä, dsak_,
   {{0x6d411268,0x66032cad,0x394506e5,0xccf2006e}},	//   _mela, упра, mals_, ָכן_,
   {{0x6d415d10,0x645c7e97,0x765d3996,0xd8d60266}},	//   _lela, ruri, busy, _רוקט_,
   {{0x22497e98,0x02061caa,0x44216a46,0xef190078}},	// [81a0] gsak_, езан, _euh_, _fażi_,
   {{0x6d417e99,0x645c7e9a,0xe8890019,0x442100dc}},	//   _nela, puri, _kẻ_, _fuh_,
   {{0x6e201084,0x65b001bf,0xdddb0034,0x21f40364}},	//   _sumb, _fähr, _druż, fähr_,
   {{0xa2cb3fac,0xfe461e9e,0xe8890023,0x6e207e9b}},	//   _सेक्, ендо, _mẻ_, _pumb,
   {{0xe8890019,0x394500d9,0xc7d70289,0x9f5f0503}},	//   _lẻ_, kals_, עוני_, _ghuí_,
   {{0x6d41731a,0x6da310f7,0x6e200239,0xdce1020e}},	//   _cela, лича, _vumb, _anlı,
   {{0x6d417e9c,0x8d1a0068,0x7c21009c,0xdbde0139}},	//   _dela, _ہزار_, _culr, _fíìn,
   {{0xb5fb00e3,0x6d4100aa,0x8aa60a7c,0x5120074c}},	//   rtái, _eela, ерод, _बलुआ_,
   {{0xb5fb0080,0x6d417e9d,0xdb0b01dc,0x6e200a4b}},	//   stái, _fela, _jogè, _uumb,
   {{0x39457e9e,0x7afd0092,0xbe13097d,0xa7fd026a}},	//   gals_, üsta, _موقع, ptık,
   {{0x815700c1,0x7c214aa1,0x888100d1,0x224919a8}},	//   עסטע_, _gulr, لیون, zsak_,
   {{0xfa88011b,0x6d410a00,0x765d7e9f,0xb5fb7ea0}},	//   _từ_, _zela, tusy, ntáv,
   {{0x42db0081,0x44217ea1,0x6d417ea2,0x7d270212}},	//   _দর্শ, _suh_, _yela, _årså,
   {{0x39457ea3,0x44217ea4,0xc8f4008f,0x6d410072}},	//   cals_, _puh_, _излъ, _xela,
   {{0x62867ea5,0xd90e0421,0x00000000,0x00000000}},	//   _asko, _دید_, --, --,
   {{0x22497ea6,0xdcf80095,0x765d0270,0x00000000}},	//   tsak_, jevč, pusy, --,
   {{0xd25103c5,0x672d03a9,0x798a0350,0x44210113}},	// [81b0] شنا_, _ifaj, _kafw, _wuh_,
   {{0x4421383f,0x65b002e2,0x22497ea7,0x62860167}},	//   _tuh_, _währ, rsak_, _dsko,
   {{0x62867ea8,0x22497ea9,0xe8890023,0xd498007b}},	//   _esko, ssak_, _xẻ_, _зря_,
   {{0x6d411268,0x3fcf0081,0x9e3502e3,0x3e692e92}},	//   _sela, িক্ষ, ведч, tút_,
   {{0xdb0b00dd,0x69dd0018,0x62860350,0xaad00d7e}},	//   _vogë, ések, _gsko, _तेलक,
   {{0xdce80029,0x3e697eaa,0x00000000,0x00000000}},	//   _gadī, rút_, --, --,
   {{0x63af08a9,0x00000000,0x00000000,0x00000000}},	//   _kocn, --, --, --,
   {{0xe8890028,0x6d417eab,0x0ed202d5,0x1adc007f}},	//   _rẻ_, _wela, _देवड, मपंथ,
   {{0x6d412129,0x39457eac,0xe8890028,0x63af12c5}},	//   _tela, tals_, _sẻ_, _mocn,
   {{0x798a00f0,0x6d41277e,0x00000000,0x00000000}},	//   _cafw, _uela, --, --,
   {{0x39457ead,0xb90200d6,0x764d76b0,0x00000000}},	//   rals_, изьк, _avay, --,
   {{0x39457eae,0xe8890028,0xb9090592,0x63af3751}},	//   sals_, _vẻ_, _यश_, _nocn,
   {{0x5fa602d5,0x394512c9,0xae2104f1,0xdb190154}},	//   कॉटल, pals_, मदिन_, _emwò,
   {{0xceb2004f,0xeab00037,0xe88900fe,0x798a0178}},	//   סים_, _دعم_, _tẻ_, _gafw,
   {{0xdce800d9,0xddc200d9,0x6b8b7eaf,0x443e0513}},	//   _radī, ntoš, _kagg, èt_,
   {{0x087600c1,0x5eb70033,0xfe210ed5,0x00000000}},	//   _יעצט_, _আইনে, मदास_, --,
   {{0x6b8b7eb0,0x2a6d1bdf,0x61e206aa,0x63af0a39}},	// [81c0] _magg, nteb_, éolo, _docn,
   {{0xb65b0089,0x00da08ba,0x53c602d5,0x628605db}},	//   _קדיש, وبات_, रोजश, _vsko,
   {{0xdce80029,0xb33b013c,0x645a0072,0x00000000}},	//   _vadī, _poçt, átid, --,
   {{0x6b8b11b9,0x705300bf,0x2a6d7eb1,0x93c700ae}},	//   _nagg, شنها, kteb_, _plăţ,
   {{0x62860eaf,0xb5fb001f,0x4ad00096,0xb4d202d5}},	//   _usko, rtáv, _तेंव, _वधु_,
   {{0xb5fb7eb2,0x8d630831,0xa2cb02d5,0x6b8b008c}},	//   stáv, авље, _सेट्, _aagg,
   {{0x6b8b7eb3,0xb5fb030b,0xcbe60d1d,0x3ea000ae}},	//   _bagg, ptáv, кции, ţit_,
   {{0x09da0096,0x61fe7eb4,0x6b8b0036,0xe457006e}},	//   यच्य, llpl, _cagg, דיקט_,
   {{0xd00f0080,0x6b8b7eb5,0x2a6d023e,0xf77f0555}},	//   _ذلك_, _dagg, gteb_, veç_,
   {{0xb4d2009d,0x672d0090,0xb5fb6db0,0x00000000}},	//   _वधू_, _sfaj, ntát, --,
   {{0x2d9e1368,0x2d8c026a,0x61fe084e,0xdddb00d4}},	//   _inte_, _iade_, ilpl, _usuš,
   {{0x2d8c070a,0x6b8b006d,0xe8e00023,0x798a0350}},	//   _hade_, _gagg, _ngụy_, _wafw,
   {{0x2d8c4f10,0xc9aa0a28,0x19581402,0x63af6c8d}},	//   _kade_, _овде_, _залы_, _rocn,
   {{0x2d8c026e,0xea7700a1,0xa4d500d6,0x7bc200b6}},	//   _jade_, _סגור_, гогі, _hlou,
   {{0x63af04a3,0x2d8c0054,0xc7c70f84,0xf3677eb6}},	//   _pocn, _made_, _аспи, ктан,
   {{0x2d8c7eb7,0x6b8b008a,0x61fe31ae,0xd407007b}},	//   _lade_, _xagg, elpl, тяги,
   {{0x2d9e08a8,0xf8e20be4,0x63af0542,0x2fc6001c}},	// [81d0] _onte_, _पशुप, _vocn, dhog_,
   {{0x80be0033,0x00000000,0x00000000,0x00000000}},	//   ্পন্, --, --, --,
   {{0x4427016a,0xc95300f5,0x63af64ed,0xaad900c3}},	//   _în_, שמע_, _tocn, _बेनक,
   {{0x2d9e7eb8,0x4433015d,0xb4c100a5,0x2fc60270}},	//   _ante_, _itx_, ्छी_, ghog_,
   {{0x6b8b7eb9,0x4ea7008f,0x6b807eba,0x44337ebb}},	//   _ragg, ържа, demg, _htx_,
   {{0xf2d20054,0x7bc249f3,0x2d8c7ebc,0x1d094e08}},	//   _פעם_, _alou, _cade_, нели_,
   {{0x6b8b34e1,0x7bc27ebd,0x2d8c7ebe,0x44330063}},	//   _pagg, _blou, _dade_, _jtx_,
   {{0x2d9e7ebf,0xddc27ec0,0x7bc264da,0x2fc600eb}},	//   _ente_, rtoš, _clou, chog_,
   {{0x3f9f025e,0x7bc2000d,0xee840761,0xddc27ec1}},	//   _inuu_, _dlou, _выхо, stoš,
   {{0xdcbb0020,0x2d8c0c56,0x5fb902e8,0x6b8b0283}},	//   _още_, _gade_, _आवडल, _wagg,
   {{0x2dd800e3,0xf7460467,0x2a6d01fa,0x7bc27ec2}},	//   _شبكة_, лено, steb_, _flou,
   {{0xf77252c6,0x7ae40335,0x628400f0,0x00000000}},	//   حاد_, _žite, ywio, --,
   {{0x63a00428,0x2d8c7ec3,0xb5fb0103,0xa6db01cd}},	//   _òmni, _yade_, jtás, naðh,
   {{0x88c50d74,0x2bcf0b94,0x7bc21419,0x2d8c0072}},	//   _متعل, तोरा, _zlou, _xade_,
   {{0x79810060,0x987900c1,0x437611b6,0xa3ea008f}},	//   melw, _טאַט, луат, едва_,
   {{0x79810060,0xa7667ec4,0xb5fb0220,0x645a0428}},	//   lelw, _скид, tuác, àtiq,
   {{0xa3b500aa,0x4ebe0033,0x00000000,0x00000000}},	// [81e0] _जकर_, _অশ্ল, --, --,
   {{0x79814aeb,0x10a6004d,0x6d45003e,0x8146770e}},	//   nelw, лизн, ðhal, انان,
   {{0x2d8c161f,0xdce3013f,0xb5fb3916,0x98be00ae}},	//   _rade_, menė, rtát, mată_,
   {{0xb5fb7ec5,0x2d8c7ec6,0xf1bf7ec7,0x98be00d3}},	//   gráf, _sade_, _stát_, lată_,
   {{0x2d8c7ec8,0x79810060,0xdcf801d3,0x661e0154}},	//   _pade_, kelw, devā, _kipk,
   {{0x7bc2030b,0x98be00d3,0x7e7b0167,0xb5fb35e3}},	//   _slou, nată_, _dpup, ltár,
   {{0x2d8c01e8,0x7bc27ec9,0x6adc0d7a,0x5b26457f}},	//   _vade_, _plou, मप्र, льпа,
   {{0xb5fb7eca,0xba5419e8,0x69c301ce,0x1faa004d}},	//   ntár, авиј, _alne, _якби_,
   {{0x2d8c7ecb,0x79817ecc,0x7dc6003e,0x6b807ecd}},	//   _tade_, felw, _aðse, remg,
   {{0x79810150,0xfd650129,0x98be020a,0x644e0a1f}},	//   gelw, _metụ, jată_, ksbi,
   {{0x98be00d3,0x291862da,0x6d4a7ece,0xb5fb0103}},	//   dată_, ära_, mafa, ktár,
   {{0x6d4a7ecf,0xa6db0088,0x644e057e,0x7bc27ed0}},	//   lafa, laði, dsbi, _ulou,
   {{0x645c01e9,0x79817ed1,0xa5bb3210,0x00000000}},	//   erri, belw, mpóz, --,
   {{0x6d4a7ed2,0xa6db003e,0xb5fb001f,0x98be00ae}},	//   nafa, naði, etár, gată_,
   {{0xb4c11bc3,0x69c80527,0xd5b803fb,0x644e0973}},	//   ्छे_, mhde, уся_, gsbi,
   {{0xa3cf24cf,0x5335136e,0x3cfe020b,0x833500e5}},	//   वों_, реат, _mytv_, рнах,
   {{0x6d4a7ed3,0x645c01ff,0x5b7b00c1,0x69da1ace}},	// [81f0] kafa, arri, ערמא, oite,
   {{0x645a0b0b,0x98be002d,0xb5fb0103,0xd5671994}},	//   átic, cată_, rtás, _стип,
   {{0xb5fb0610,0x161e007f,0xdb0007ee,0x00000000}},	//   tráf, _यूटर_, ckmö, --,
   {{0x645a0995,0x09e17ed4,0xb5fb1946,0x79810201}},	//   štic, _पद्य, ctár, zelw,
   {{0x6d4a7ed5,0x236b020a,0xbea57ed6,0x764f7ed7}},	//   fafa, _iccj_, ралк, nscy,
   {{0x6d4a1621,0x2b4900c4,0xa6db01cd,0x00000000}},	//   gafa, _žac_, gaði, --,
   {{0x63ad013f,0xa7fd008b,0xa2d91fb4,0x79817ed8}},	//   ojan, ntıs, _नेत्, velw,
   {{0x63ad7ed9,0x98be00d3,0x69c30220,0x79817eda}},	//   njan, zată_, _slne, welw,
   {{0x69da7edb,0x6d4a7edc,0x2b460154,0x6e94450e}},	//   fite, bafa, _deoc_, _литу,
   {{0x27e97edd,0x69c80099,0x2b460383,0x63ad032c}},	//   _ajan_, ghde, _eeoc_, hjan,
   {{0xe73a0a0e,0x63ad7ede,0x98be00ae,0x765d4251}},	//   кен_, kjan, vată_, ersy,
   {{0xc600178c,0x79810060,0xb5fb7edf,0x63ad779b}},	//   ोग्य_, selw, hrád, jjan,
   {{0x63ad7ee0,0x98be00d3,0xb5fb2f26,0x00000000}},	//   djan, tată_, vtár, --,
   {{0x69c87ee1,0x7bc90257,0x644e16f7,0x7d1c0076}},	//   chde, lheu, tsbi, _úrsc,
   {{0x98be002d,0x645c7ee2,0x39477ee3,0x0446215f}},	//   rată_, urri, _iens_, ребн,
   {{0x7bc90257,0xdb0b40e2,0x63ad7ee4,0x6d4a02a4}},	//   nheu, _logí, gjan, zafa,
   {{0x6d4a10bd,0x661e7ee5,0x644e7ee6,0xe1fa67cb}},	// [8200] yafa, _tipk, ssbi, вга_,
   {{0x3947224d,0xb5fb7ee7,0x6d4a7ee8,0x644e34cb}},	//   _jens_, stár, xafa, psbi,
   {{0xa3af0789,0x64a67ee9,0x63ad7eea,0x057700ca}},	//   _कवच_, _тана, bjan, _דגים_,
   {{0x69da0a0f,0x6d4a0010,0x76440193,0x63ad0034}},	//   zite, wafa, _kwiy, cjan,
   {{0xe8e206ae,0x6d4a76d8,0x2a7d023e,0x69da0384}},	//   _पश्च, tafa, _npwb_, yite,
   {{0x444416da,0x39470472,0x69da7eeb,0x76440079}},	//   _kw_, _nens_, xite, _mwiy,
   {{0xa6db003e,0x6724063d,0x98a500c6,0x00000000}},	//   raði, _ogij, dalį_, --,
   {{0x44443128,0x69da7eec,0x6d4a7eed,0xe7c10081}},	//   _mw_, wite, safa, _উদ্য,
   {{0x44440283,0x39470bfe,0x79a63397,0xada600c6}},	//   _lw_, _bens_, арне, _каал,
   {{0x44440283,0x63ad7eee,0x49730457,0x39470428}},	//   _ow_, zjan, ольс, _cens_,
   {{0x7644155e,0x394713c8,0x58d800d6,0x27e9003d}},	//   _awiy, _dens_, удня_, _pjan_,
   {{0x69da7eef,0x39470272,0x6d480a00,0x7bc97ef0}},	//   site, _eens_, _heda, cheu,
   {{0x44447ef1,0x6d4803ec,0xd6d82a6a,0xaa585d18}},	//   _aw_, _keda, атр_, _силу_,
   {{0x6d4803ce,0x44446708,0x394704c7,0x69da023b}},	//   _jeda, _bw_, _gens_, qite,
   {{0x6d4801ce,0xf77f24ba,0x63ad12c9,0x58d37ef2}},	//   _meda, ança_, tjan, _мошт,
   {{0x7c2803ce,0x44447ef3,0x6d487ef4,0x394c052f}},	//   _mudr, _dw_, _leda, lads_,
   {{0x7c287ef5,0xadf60557,0x7179028d,0x24181402}},	// [8210] _ludr, इवान_, лбар_, роты_,
   {{0x6f090067,0x63ad7ef6,0x3947002b,0x394c7ef7}},	//   _rzec, sjan, _xens_, nads_,
   {{0x44447ef8,0x63ad7ef9,0x26f80281,0x2ba90961}},	//   _gw_, pjan, _مریخ_, कामा,
   {{0xb21b0537,0xdb0b0231,0x6445039f,0x6d487efa}},	//   _spæd, _jogã, _iwhi, _aeda,
   {{0x7c287efb,0x69d801be,0x44447efc,0xed590b21}},	//   _audr, _omve, _zw_, гол_,
   {{0x444402e0,0x62830034,0x7c280836,0xdef801b3}},	//   _yw_, łnos, _budr, шых_,
   {{0x444404de,0xa6db0102,0x6d487efd,0x7bc90131}},	//   _xw_, maðu, _deda, theu,
   {{0x39477efe,0x23697eff,0x1dd95ed7,0x6d480188}},	//   _sens_, ngaj_, _भगवत, _eeda,
   {{0x6d487f00,0x7bc901d0,0x6f090a39,0x7c280cc2}},	//   _feda, rheu, _uzec, _eudr,
   {{0x6d485e94,0xa6db0088,0x7bc90381,0x764405bd}},	//   _geda, naðu, sheu, _rwiy,
   {{0xa3e81fbb,0x7c287f01,0x5dfa006e,0x39477f02}},	//   _बदल_, _gudr, _עפענ, _vens_,
   {{0x4444092f,0x39470305,0x6e217b3f,0x5fc71e93}},	//   _rw_, _wens_, _hilb, लसिल,
   {{0x34b23e1b,0x7f49026d,0xa7fd026a,0x7d017f03}},	//   ीन्द, _meeq, ttır, _hyls,
   {{0x44447f04,0x6e290033,0x6e217f05,0x28b900e3}},	//   _pw_, _mueb, _jilb, _مطبخ_,
   {{0x4444022e,0xdb0b0161,0x69c101d0,0x6e217f06}},	//   _qw_, _fogã, mkle, _milb,
   {{0xf1bf0019,0x69c1000b,0x44447f07,0xa7fd026a}},	//   _quán_, lkle, _vw_, stır,
   {{0xa7fd01e8,0x6e290270,0x98be16d7,0x6e2101b9}},	// [8220] ptır, _nueb, ratą_, _oilb,
   {{0x44447f08,0x01d70080,0x69c17f09,0xb5fb7f0a}},	//   _tw_, موقع_, nkle, nuál,
   {{0x444426f1,0xb5fb3ecc,0x0219004d,0x7d01084e}},	//   _uw_, bráb, ріть_, _nyls,
   {{0x68fc0364,0x6e217f0b,0x3897020a,0x69c100bc}},	//   ürdi, _ailb, _măr_, hkle,
   {{0x6e2102a7,0x7f49008a,0x7c287f0c,0x319f01d3}},	//   _bilb, _deeq, _sudr, _bāzē_,
   {{0x4422059f,0x6e21009c,0x7bd97f0d,0x226502c6}},	//   _hik_, _cilb, _amwu, ňský_,
   {{0x6d487f0e,0xb5fb025b,0x394c00d9,0x69c101cb}},	//   _veda, duál, vads_, dkle,
   {{0x6d487f0f,0x9b6a0c2b,0x44220c45,0x5a341167}},	//   _weda, ушка_, _jik_, онит,
   {{0x6d487f10,0x44227f11,0x394c4ec8,0x15f80c17}},	//   _teda, _mik_, tads_, ंकार_,
   {{0x6d4803a9,0xf4000033,0x2a6400ae,0xd83a00d3}},	//   _ueda, ্দির_, rumb_, лэм_,
   {{0xf4c30033,0x7bde014b,0x48b80033,0x00000000}},	//   _ঈশ্ব, épus, ুপ্র, --,
   {{0x44220eb2,0xaad90251,0x69dd00fd,0xa3bd0557}},	//   _nik_, _बेवक, éser, _अवध_,
   {{0x645a0af0,0x66c847ff,0x95cb34df,0x1bfb0142}},	//   átin, бург_, гува_, _גלאב,
   {{0xf1bf0890,0x44220149,0x7c220441,0x69d84a27}},	//   _cuál_, _aik_, _hior, _umve,
   {{0x645a7f12,0xdce301d3,0x7c220350,0xb9db00ca}},	//   štin, venī, _kior, _תחוש,
   {{0x44227f13,0xeda50473,0xdc37006e,0x00000000}},	//   _cik_, _गच्छ, מאלט_, --,
   {{0x44223769,0x7c227f14,0x780509b0,0xa6db003e}},	// [8230] _dik_, _mior, रतीक_, taðu,
   {{0x7c220072,0x44227f15,0xdb0b0103,0xe4e7084c}},	//   _lior, _eik_, _jogá, _гімн,
   {{0x44220021,0xa6db04c8,0x6e29009c,0x00000000}},	//   _fik_, raðu, _sueb, --,
   {{0xdb0b0080,0x6e2914e2,0x442201c5,0x6d5e7f16}},	//   _logá, _pueb, _gik_, ópan,
   {{0x6e210154,0x7ae40e9e,0x80da0081,0x69c17f17}},	//   _pilb, _žitn, _বুদ্, ykle,
   {{0x628f02a1,0xb5fb0579,0x7c227f18,0x44227f19}},	//   _isco, xuál, _aior, _zik_,
   {{0x7c227f1a,0x442200dc,0x6e217f1b,0xa91c0206}},	//   _bior, _yik_, _vilb, deľo,
   {{0x23c904a9,0xa91c0038,0x7c22378c,0x6e217f1c}},	//   रसिद, teľn, _cior, _wilb,
   {{0x6e217f1d,0xb5fb4729,0x3e72002d,0x7c227f1e}},	//   _tilb, tuál, cât_, _dior,
   {{0x80be00c7,0x8d77037f,0xe9d90c58,0x7d01007b}},	//   ্পর্, _دارا, рко_, _tyls,
   {{0x7c22013d,0x15fa00a5,0x23c91e05,0x99990103}},	//   _fior, ृतसर_, रसाद, ésű_,
   {{0x7c220020,0xdd0e1f8a,0x2d877f1f,0x7bd90193}},	//   _gior, lışm, lene_, _umwu,
   {{0x44225383,0x2d87057a,0xdb0b0103,0x69c1000b}},	//   _rik_, oene_, _fogá, pkle,
   {{0x44227aab,0x2d877f20,0xdd0e03a3,0x992b00c2}},	//   _sik_, nene_, nışm, _сюда_,
   {{0x628f013d,0x629d7f21,0xe73a2fad,0x2d875b9f}},	//   _asco, _arso, _кей_, iene_,
   {{0xb5fb7f22,0x2d872fa2,0x9c130174,0x3f860072}},	//   trác, hene_, kọmu, xeou_,
   {{0x2d877f23,0xb5fb0220,0x44220572,0xdd0e0233}},	// [8240] kene_, urác, _vik_, kışm,
   {{0xe16600e3,0xdb0b002b,0x93c700fe,0x225228bb}},	//   تدري, _xogá, _hoặ, rsyk_,
   {{0x44222fd9,0x2d8702ec,0x628f34d2,0x30861850}},	//   _tik_, dene_, _esco, تلاف,
   {{0xb5fb025b,0x443a0034,0xf2a600ae,0x987a006e}},	//   prác, _itp_, _димп, ירעק,
   {{0x7c227f24,0xfe6f0452,0x2d877f25,0xe4d700d1}},	//   _rior, ندو_, fene_, _هویت_,
   {{0x2d877f26,0x7c220013,0x443a7f27,0x7ae40095}},	//   gene_, _sior, _ktp_, _žito,
   {{0x7c227f28,0x50b5002d,0x00000000,0x00000000}},	//   _pior, _есту, --, --,
   {{0xe3bf037a,0x443a01ce,0x2d87010a,0x261100a3}},	//   _tiñe_, _mtp_, aene_, _दीनी_,
   {{0x2d877f29,0xa91c0038,0xf413028c,0x7c2200ae}},	//   bene_, teľo, ופה_, _vior,
   {{0x2006023b,0x443a5c8c,0x7e620113,0x00000000}},	//   lloi_, _otp_, mrop, --,
   {{0x09b7054f,0x28f80f1e,0x443a1f65,0x7c227f2a}},	//   تطيع_, сень_, _ntp_, _tior,
   {{0x61b72a06,0x7c3a003d,0xc6a705cb,0xfbc33456}},	//   _आक्ष, _ittr, орги, _обхо,
   {{0xf98f00d0,0x645a005f,0xa91c0031,0x1dd700a4}},	//   ربی_, štil, peľo, भोवत,
   {{0x443a24e2,0x63a609b5,0x02a30134,0x00000000}},	//   _btp_, _ankn, nrụọ, --,
   {{0x69ca0167,0x6672001c,0x200601ff,0x7988363c}},	//   _ilfe, وگیر, kloi_, medw,
   {{0x798864a3,0xd6db5fa3,0x629d00d2,0x00000000}},	//   ledw, _вто_, _prso, --,
   {{0x2d877f2b,0xa6db003e,0x249700c6,0x6d5a4ddd}},	// [8250] yene_, raðs, _žemė_, _odta,
   {{0x7988471a,0xd13b7f2c,0xed8800c6,0x443a3ff0}},	//   nedw, рха_, šųjų_, _ftp_,
   {{0x2d8764e9,0xf8ca1784,0x9f380129,0x7e621cab}},	//   vene_, ानिय, _ịmụt, erop,
   {{0x6d5a7f2d,0x7e6201af,0x2d87001c,0x00000000}},	//   _adta, frop, wene_, --,
   {{0x2d8702ec,0x7c3a7f2e,0x6da5017b,0x79880172}},	//   tene_, _attr, зила, kedw,
   {{0xb2ba00ca,0xa2ba00ca,0xf8ca0386,0x79880350}},	//   _המשר, _המשט, ानाय, jedw,
   {{0x2d877f2f,0x7d1c003e,0xdd0e03a3,0x23bf1b79}},	//   rene_, _úrsl, rışm, _एकाद,
   {{0x5ba92311,0x2d877f30,0x69ca4212,0x628d024a}},	//   ским_, sene_, _alfe, owao,
   {{0xe9d93d7c,0x2d8770c4,0xdce70555,0x7e62436f}},	//   йки_, pene_, ğlıl, crop,
   {{0x6ca7321c,0x2ba91c83,0xedd50037,0x5dd50103}},	//   _мреж, काहा, _عياد, _عقائ,
   {{0x6d437f31,0x98a551ad,0x290301cd,0x00000000}},	//   mbna, чине, æja_, --,
   {{0x69ca7f32,0xe29f0088,0x628d7f33,0x7f5b0090}},	//   _elfe, _orð_, kwao, _jduq,
   {{0xb9021f83,0x7bcb129d,0x629800d9,0xfaa55ca3}},	//   _ने_, _ilgu, āvok, _хало,
   {{0xceb2004f,0x645a005f,0x6b8952d2,0x7c3a0149}},	//   עים_, štim, leeg, _yttr,
   {{0x64a32680,0x64557f34,0x00000000,0x00000000}},	//   нара, gszi, --, --,
   {{0x3cde0006,0xe8d600ca,0x6e3b7f35,0x78bc7f36}},	//   _कइसे_, _מוצר_, _otub, ärve,
   {{0x27370019,0x443a0167,0xa3bd02d5,0x6e3b05bd}},	// [8260] _ủng_, _wtp_, _अवर_, _ntub,
   {{0x443a02e7,0x6b89008c,0x00000000,0x00000000}},	//   _ttp_, heeg, --, --,
   {{0x7e6200bd,0x6e3b7f37,0x55bb00ca,0x2ec42581}},	//   wrop, _atub, _המיו, वन्त,
   {{0x7e62632f,0xd7af0096,0x63a600ca,0x79887f38}},	//   trop, टायच, _unkn, zedw,
   {{0xdfcf3345,0x7f5b0090,0x539b00ca,0x00000000}},	//   دين_, _dduq, _היכו, --,
   {{0x7bcb40e2,0xb5fb5348,0x2b9800de,0xf2d300c1}},	//   _algu, hrán, _ức_, _טער_,
   {{0x200604ea,0xd7cc009d,0xb5fb0088,0x79880154}},	//   ploi_, ासाच, krán, vedw,
   {{0x79887f39,0x6b897f3a,0x00000000,0x00000000}},	//   wedw, geeg, --, --,
   {{0xdcfa00d9,0xb5fb182b,0x645501f9,0x00000000}},	//   _patē, drán, zszi, --,
   {{0xe3bf0933,0x6d5a052f,0xed57129c,0x6d43009c}},	//   _miña_, _udta, _ноу_, cbna,
   {{0xe3bf0933,0xb5fb7f3b,0x7c3a0578,0x798800f0}},	//   _liña_, frán, _uttr, redw,
   {{0x61fe004a,0x79887f3c,0x22400eac,0x7aed02c6}},	//   hopl, sedw, kpik_, _žate,
   {{0x61fe1fce,0xe3bf0033,0x2ba93ec9,0xe9a6554c}},	//   kopl, _niña_, कारा, _надп,
   {{0x64550068,0x61fe0381,0x00000000,0x00000000}},	//   tszi, jopl, --, --,
   {{0xb5fb033d,0xe97b00a1,0xa97b00ca,0x15143ac9}},	//   brán, _הנוש, _האוכ, едря,
   {{0xb5fb35e3,0x64557f34,0xd6d114ea,0x00000000}},	//   ntáz, rszi, _لقب_, --,
   {{0x64550018,0x0edb04f1,0x6458003e,0x61fe00bc}},	// [8270] sszi, _मेंड, _ævin, fopl,
   {{0x61fe14f3,0x645501f9,0x2902013c,0x00000000}},	//   gopl, pszi, əkar_, --,
   {{0x25d800c1,0x06380470,0x25fc0336,0x00000000}},	//   _מוזן_, _وسیع_, ोतरी_, --,
   {{0xe29f003e,0x00000000,0x00000000,0x00000000}},	//   _eyða_, --, --, --,
   {{0x6ff500a5,0xf8a96c66,0x7dcf01df,0x98be02c6}},	//   jące, _छप्प, _løse, tatě_,
   {{0x6b897632,0xbea20293,0xdb07020d,0xac392458}},	//   weeg, ташк, _éléc, очих_,
   {{0x6b897f3d,0x2ba9063c,0x26c2007f,0xddc205db}},	//   teeg, काला, zyko_, btož,
   {{0x2fc604a3,0x5f940752,0xaac8030b,0x7aa5001f}},	//   ckog_, _пист, ाईंक, дииз,
   {{0x6b89008a,0x8d872dfb,0x60180084,0xc33400a1}},	//   reeg, _нужд, _хотя_, עוץ_,
   {{0x26c20138,0x00000000,0x00000000,0x00000000}},	//   vyko_, --, --, --,
   {{0xb5fb5374,0x8d74110a,0x378a3e1e,0x69a10096}},	//   trán, _سالا, обно_, _कोणी,
   {{0x66e67f3e,0x2fcd0113,0x7bcb00b7,0x645a7f3f}},	//   дома, _jleg_, _ulgu, štik,
   {{0xb5fb04d8,0xab0b00cd,0x7e6b00f9,0xa3c308c0}},	//   rrán, _اتاق_, nugp, ्सन_,
   {{0xb21b1050,0x26110251,0x61fe00b3,0xe3bf034f}},	//   _spæn, _दीदी_, xopl, _riña_,
   {{0x7e6b0270,0x2fcd7f40,0x00000000,0x00000000}},	//   hugp, _oleg_, --, --,
   {{0xe3bf00e1,0xf7720037,0x2259058f,0x290701ee}},	//   _piña_, _شاب_, _bvsk_, _iyna_,
   {{0x61fe7f41,0x27e001c2,0x422637b1,0x764b0537}},	// [8280] topl, _imin_, ддав, _ægyp,
   {{0x3cde05a7,0xe3bf04d8,0x2fcd00ae,0x394e00ee}},	//   _कइले_, _viña_, _aleg_, _xefs_,
   {{0x61fe7f42,0x2fc608c5,0xb7d70d7f,0x00000000}},	//   ropl, tkog_, _رویا_, --,
   {{0xe3bf0933,0x2fcd0113,0x4f0a10b8,0xb5fb00b6}},	//   _tiña_, _cleg_, онен_, hrál,
   {{0xa91c0220,0xa24800cd,0xb5fb15bf,0x2fc609ac}},	//   teľk, _ریال_, král, rkog_,
   {{0x2fc60335,0x7d1c003e,0x7d780037,0x29070e63}},	//   skog_, _úrsk, سمبر_, _oyna_,
   {{0x6da3125f,0xfba900a4,0x27e000ce,0x00000000}},	//   тија, कांम, _omin_, --,
   {{0x27e007ac,0xcfaa0308,0x2fcd033c,0x3ea900d2}},	//   _nmin_, _باسم_, _gleg_, ťata_,
   {{0x29077f43,0xdb19022b,0xb5fb0143,0x298a14e7}},	//   _ayna_, _jowè, rtáz, осно_,
   {{0x27e07f44,0x29070185,0xb5fb446d,0x600a02c6}},	//   _amin_, _byna_, stáz, kýmk,
   {{0xf1bf0019,0x00000000,0x00000000,0x00000000}},	//   _quái_, --, --, --,
   {{0x62867f45,0x29070150,0x3cf10094,0x5ba5004d}},	//   _opko, _dyna_, ťový_, _пріз,
   {{0xb5fb470e,0x6b827f46,0xbc1b006e,0xdb190154}},	//   brál, _ibog, _וואש, _nowè,
   {{0x34953d7b,0x27e06209,0x7dcf02b6,0x00000000}},	//   нагр, _emin_, _tøse, --,
   {{0xe4e400d6,0x628600d9,0x7d0802b6,0x6e28008c}},	//   вітн, _apko, _jyds, _midb,
   {{0xddc9030b,0x00000000,0x00000000,0x00000000}},	//   _dveř, --, --, --,
   {{0x52152249,0x6b82612b,0xe0d0001c,0x7d0800f2}},	// [8290] едат, _mbog, یزم_, _lyds,
   {{0x2fcd057a,0x26000096,0x764d40f5,0x91e40284}},	//   _sleg_, ळवणी_, _iway, вође,
   {{0x3cde02e8,0x2b05030b,0x764d1df6,0x35f80037}},	//   _केले_, _हुनु_, _hway, _تريد_,
   {{0x764d7f47,0x799802f1,0x6e280503,0x2ef50c37}},	//   _kway, _lavw, _aidb, нзер,
   {{0x733a00c1,0xddc900b6,0xf8ca17ad,0xde58004d}},	//   _מערס, _zveř, ानुप, дачі_,
   {{0x6b827f48,0x63bd7f49,0x764d0c56,0x7c9500be}},	//   _abog, _hosn, _mway, ериц,
   {{0x63bd0088,0x6aa20167,0x61e5019f,0x7e6b0270}},	//   _kosn, _arof, mihl, sugp,
   {{0x672d7f4a,0xe3bf08a8,0x61e54568,0x6aa20150}},	//   _ngaj, _miño_, lihl, _brof,
   {{0xb5fb0018,0x29071672,0x6aa27f4b,0xba250cfc}},	//   trál, _syna_, _crof, ндик,
   {{0x672d006d,0x6e2802a1,0x63bd7f4c,0x6aa25be1}},	//   _agaj, _gidb, _losn, _drof,
   {{0xe3bf09b3,0x764d7f4d,0x6aa20139,0x5eb70081}},	//   _niño_, _away, _erof, _আইটে,
   {{0x6b8202b4,0x63bd1c74,0xb21b32a7,0x69c80124}},	//   _gbog, _nosn, _spæl, akde,
   {{0x0aeb00bf,0x34c8049d,0x6aa27f4e,0xd90f0018}},	//   _براي_, रन्द, _grof, دیں_,
   {{0x764d022b,0x6b820106,0x69c83547,0x7bc900c2}},	//   _dway, _zbog, ckde, lkeu,
   {{0x63bd0719,0x764d063d,0x61e505db,0x27e00090}},	//   _bosn, _eway, dihl, _tmin_,
   {{0x6b9b7f4f,0x63bd009b,0x7ae41ce4,0x7bc97f50}},	//   ndug, _cosn, _žiti, nkeu,
   {{0x7bc900c2,0x6f1d0094,0x764d7f51,0x61e5019f}},	// [82a0] ikeu, _úsch, _gway, fihl,
   {{0x7bc900ce,0x6b992e9d,0x00000000,0x00000000}},	//   hkeu, _lawg, --, --,
   {{0xb5fb0146,0x717300e3,0x7bc900c2,0xddc902c6}},	//   kráj, اهما, kkeu, _uveř,
   {{0x78bc0ac9,0x543b006e,0x69a1049d,0x7bc9029a}},	//   ørvi, _מעטא, _कोसी, jkeu,
   {{0x4906009f,0x7bc904e2,0xfeb700cd,0xdddb7f52}},	//   _सुनो_, dkeu, فاوت_, _spuš,
   {{0x63bd0094,0xdb0b0032,0x2fda0113,0x6aa20052}},	//   _zosn, _fogú, _کورد_, _rrof,
   {{0x7bc90381,0x00000000,0x00000000,0x00000000}},	//   fkeu, --, --, --,
   {{0x6b9b11b9,0x8cb100aa,0xe8df0023,0xdb0b0131}},	//   gdug, _अपरो, _chửi_, _ingê,
   {{0x60e0013f,0x6b997f53,0x7d08084e,0xa3c30285}},	//   žymė, _dawg, _wyds, ्सत_,
   {{0x7d08057a,0xf77f0131,0x764d7f54,0x67eb007b}},	//   _tyds, diça_, _rway, köjä,
   {{0x764d7f55,0x5fc406ed,0xdddb00cb,0xe0be0033}},	//   _sway, _वकाल, _upuš, _আধুন,
   {{0x6b826bea,0x6b9901c2,0x61e50201,0x2d9c0103}},	//   _ubog, _gawg, zihl, ldve_,
   {{0xcf930130,0x63bd7f56,0xdb090052,0x00000000}},	//   נטש_, _rosn, vjeç, --,
   {{0x764d06a3,0xceb30089,0x63bd0034,0x5b13036c}},	//   _vway, איש_, _sosn, _сміт,
   {{0x63bd2956,0x6b9901fa,0xc95300ca,0x00000000}},	//   _posn, _yawg, _עמק_, --,
   {{0xe3bf08a8,0x7dd4009c,0x439400c2,0x764d1e59}},	//   _viño_, _fàsg, ласс, _tway,
   {{0x32010146,0xf77f016d,0x8c1b00ca,0x764d7f57}},	// [82b0] tohy_, ciça_, לולי, _uway,
   {{0x8cb100a5,0x63bd0167,0x2d8e037a,0x00000000}},	//   _अपलो, _wosn, jefe_, --,
   {{0xc95300c1,0x61e531c2,0x6f090449,0x32011ea1}},	//   רמע_, rihl, _syec, rohy_,
   {{0x61e50060,0x60c50084,0x00000000,0x00000000}},	//   sihl, ryhm, --, --,
   {{0xee3840ca,0xd356040a,0x61e5033b,0x4433009e}},	//   ені_, _שישי_, pihl, _hux_,
   {{0xfce501a0,0x442b7f58,0x7bc901c0,0x1d094a09}},	//   коло, _hic_, wkeu, мели_,
   {{0x645a3b92,0x6b9b7f59,0xace80018,0x7bc97f5a}},	//   štiv, tdug, ٹرول_, tkeu,
   {{0x443343c3,0xddc2013f,0x00000000,0x00000000}},	//   _mux_, ruoš, --, --,
   {{0x7bc91f45,0x44337f5b,0x442b0d54,0xdfd40450}},	//   rkeu, _lux_, _mic_, _соты,
   {{0x3f8f0088,0xddc2013f,0x7bc93ade,0xda0b00aa}},	//   legu_, puoš, skeu, _सीखत_,
   {{0xa3c328fb,0x99910018,0x442b0e69,0x443301af}},	//   ्सा_, öző_, _oic_, _nux_,
   {{0x442b4d7b,0xf7720397,0x3f8f02ad,0x59a60fef}},	//   _nic_, جاد_, negu_, _कोठर,
   {{0x443310af,0xa91c0031,0xed580206,0x00000000}},	//   _aux_, deľu, _hoľa_, --,
   {{0x442b76ca,0x7d0401e8,0xdce10491,0x443300d8}},	//   _aic_, şise, _halı, _bux_,
   {{0xdce101e8,0xa5072636,0x6018065b,0xd6271061}},	//   _kalı, вера_, líme, торе_,
   {{0x442b7f5c,0x3f8f0880,0x443301ee,0x7c2b54b8}},	//   _cic_, jegu_, _dux_, _jigr,
   {{0x442b7f5d,0x4433025a,0x2ebd1687,0xa2060110}},	// [82c0] _dic_, _eux_, ्नोत, впад,
   {{0xb1432f03,0x7c2b7f5e,0x602c0345,0x00000000}},	//   инул, _ligr, _aşma, --,
   {{0xe0d200e3,0xd6a909b4,0x27f7110a,0xd12f0037}},	//   جزء_, _قدیم_, _سفید_, زمن_,
   {{0x7c2b7f5f,0x2d8500a1,0xa3a902d5,0x442b7f60}},	//   _nigr, _able_, _गोप_, _gic_,
   {{0xc3200081,0x645c3155,0x7dd4015e,0x6ff300aa}},	//   _ফ্রি_, lsri, _làse, _अदरख_,
   {{0x442b00d3,0x61437f61,0x3f8f00aa,0xf1bf0023}},	//   _zic_, _вера, aegu_, _quát_,
   {{0xdce103a3,0x2d8e7f62,0x91e30b31,0x319b00ca}},	//   _balı, refe_, _торе, _קבלנ,
   {{0x44207f63,0xb5fb7f64,0xd9ca13ae,0xbeb7030b}},	//   nmi_, nuár, िस्ट, _šíře,
   {{0xde770018,0x44207f65,0x601800e1,0xdce1071d}},	//   _لینڈ_, imi_, gíme, _dalı,
   {{0x79a61b82,0x683e01d3,0x98b8001f,0x7c2b03a8}},	//   трие, _līde, елот_, _eigr,
   {{0x4420714b,0x4ce00081,0x6d587f66,0xb5fb0103}},	//   kmi_, _পুরু, mava, lság,
   {{0x6d587f67,0x44207f68,0x7c2b01af,0xa91c0220}},	//   lava, jmi_, _gigr, deľt,
   {{0xb5fb0068,0x290200a5,0x44203b31,0xf4080081}},	//   nság, łka_, dmi_, লগার_,
   {{0x6d587f69,0x442b00dd,0x44207f6a,0x7dcf0939}},	//   nava, _sic_, emi_, _løsn,
   {{0xdb0b00d1,0x645c0212,0xdce1026a,0x44330113}},	//   _angè, gsri, _yalı, _qux_,
   {{0x6d5869b0,0xdce10abd,0xa3dd00a5,0xa77507c8}},	//   hava, _xalı, थों_, _слич,
   {{0x6d587f6b,0xb5fb0037,0xf1ae0096,0xf77f0231}},	// [82d0] kava, hrái, घांन, liço_,
   {{0x44207f6c,0x6d5803ce,0xb5fb3fff,0x61550103}},	//   ami_, java, dság, انائ,
   {{0x3c380018,0x3f8f7f6d,0x44205c56,0x765d13d1}},	//   _név_, tegu_, bmi_, lssy,
   {{0x44207f6e,0x926b00d3,0xb5fb016d,0xe4a4004d}},	//   cmi_, _орга_, cuár, _трьо,
   {{0x645a02e6,0x35a805d4,0x765d7f6f,0xb5fb0103}},	//   štit, _छोड़, nssy, gság,
   {{0xa3c302e8,0x6d587f70,0x3e7b025a,0x65757bb8}},	//   ्सव_, gava, rêt_, ngzh,
   {{0xdb0b0257,0x7c2b7f71,0xc1720327,0x2c0f0096}},	//   _ingé, _pigr, _לחם_, ातलं_,
   {{0x7c3e0074,0x1fa4371f,0xdce10092,0xf77f0231}},	//   ípra, _круг, _qalı, diço_,
   {{0xdb130174,0x7c2b0c09,0x765d0381,0x00000000}},	//   _ọ́nụ, _vigr, jssy, --,
   {{0x44207f72,0x3c380257,0x3cde049d,0x765d0407}},	//   zmi_, _fév_, _केके_, dssy,
   {{0x7c2b7f73,0x44207f74,0xd7af0096,0xdce1013c}},	//   _tigr, ymi_, टांच, _talı,
   {{0x366a04fd,0x1b050033,0xbbeb0037,0xf0922252}},	//   намо_, শেষে_, _غرام_, זנט_,
   {{0x442019f3,0xff7a006e,0xaba801c3,0x765d7604}},	//   vmi_, עטשמ, _جهنم_, gssy,
   {{0x645c7f75,0x00000000,0x00000000,0x00000000}},	//   tsri, --, --, --,
   {{0x07a6004b,0x44207f76,0x2a7f00aa,0xda19009f}},	//   _байн, tmi_, ltub_, _नीयत_,
   {{0x44207f77,0xdb0b7f78,0x80a70096,0x00000000}},	//   umi_, _angé, घटने, --,
   {{0xdcfa00d9,0x6d580453,0xaa36006e,0xb5fb0131}},	// [82e0] _patī, yava, ָטעק_, ruár,
   {{0xd05a01ce,0x644110d9,0xddd40181,0x76444a6c}},	//   ерді_, ílic, _ťažk, _itiy,
   {{0x6d587f79,0x2a7f00aa,0x8fa63028,0x44201206}},	//   vava, htub_, лаже, pmi_,
   {{0x44441723,0xb4c205cd,0x2a7f7f7a,0x2e3906a3}},	//   _it_, ्नी_, ktub_, _bèf_,
   {{0x6d587f7b,0x44447f7c,0xa3c30b89,0x2a7f01fa}},	//   tava, _ht_, ्सर_, jtub_,
   {{0x270300de,0xb5fb0674,0x98be00c6,0x00000000}},	//   ổng_, trái, lbtą_, --,
   {{0x6d580213,0xb5fb0018,0x44440efd,0xa3a9009d}},	//   rava, sság, _jt_, _गोड_,
   {{0x7dc60102,0xb5fb0037,0x7dd400ee,0x249a00c4}},	//   _aðst, rrái, _bàsc, _mspm_,
   {{0x44440ad3,0xb4c2000d,0x0aea00e3,0x9fb8025b}},	//   _lt_, ्नु_, عربي_, nčí_,
   {{0x44447f7d,0xc27b006e,0x765d0120,0x776401ff}},	//   _ot_, עריי, vssy, _adix,
   {{0x28f825a9,0x26e20081,0x7d0501bf,0x249a0095}},	//   тень_, _গুলো_, ühst, _nspm_,
   {{0x20061507,0x2a7f0124,0x7dcf01df,0x765d2e7f}},	//   nooi_, btub_, _løsl, tssy,
   {{0x4444004f,0xa91c0181,0x2d9e00d7,0x9fb8023c}},	//   _at_, teľs, _kate_, jčí_,
   {{0xb5fb0074,0x0cb600c7,0x9fb80094,0x765d6676}},	//   hráv, জনীত, dčí_, rssy,
   {{0x76447f7e,0x444406f5,0x2d9e32a8,0xa4d4004d}},	//   _etiy, _ct_, _mate_, борі,
   {{0x44447f7f,0x261a009f,0x2d9e42de,0xd90e05bc}},	//   _dt_, _मीठी_, _late_, _ویک_,
   {{0x44447f80,0xfc3f025b,0x569501b6,0xe5e5110a}},	// [82f0] _et_, _čím_, _тапт, _نزدی,
   {{0x2d9e7f81,0x444400ca,0x545513c7,0x00000000}},	//   _nate_, _ft_, _квот, --,
   {{0x92b50033,0x2e390154,0x200602ac,0xa0a7007b}},	//   জনে_, _sèf_, fooi_, ышал,
   {{0xb4d100af,0x64457f82,0x2006057a,0x66070095}},	//   वनी_, _ithi, gooi_, lojk,
   {{0x2d9e7f83,0xd24400d3,0x444402db,0xa3d200b7}},	//   _bate_, _гэси, _zt_, वसर_,
   {{0xd6580054,0x6da50983,0x22490f8b,0x2d9e002d}},	//   ניות_, рика, mpak_, _cate_,
   {{0xeb991116,0x2d9e539d,0xabd504f5,0xa3b91757}},	//   вий_, _date_, ициј, चाप_,
   {{0x3ff900c1,0xb5fb03be,0x2d9e0172,0x9e95001c}},	//   _ספּע, nsáb, _eate_, _پارچ,
   {{0x22493018,0x59a6009f,0xffb400ae,0x2d9e0a5f}},	//   npak_, _कोहर, _уйтэ, _fate_,
   {{0x3a2e0042,0x64450201,0xe88507f0,0x2d9e7f84}},	//   _cifp_, _othi, агоп, _gate_,
   {{0x7c950397,0x6ce400d6,0x66072a6c,0x2a7f00aa}},	//   _خلاص, _ліце, dojk, stub_,
   {{0x224906a8,0x2d210096,0x2d9e033b,0x44447f85}},	//   kpak_, मधील_, _zate_, _rt_,
   {{0x64457f86,0xa3b902b0,0x2d9e7f87,0x60180094}},	//   _athi, चान_, _yate_, níma,
   {{0x7bc2023e,0x9fb800b6,0xe4da001c,0x98a51009}},	//   _zoou, včí_, پورت_, _вике,
   {{0xb4c21827,0xd5e40174,0x69c37f88,0xa50a7748}},	//   ्ने_, _apị, _ione, тева_,
   {{0xa3a90251,0xb5fb3916,0x69c33b79,0x64410143}},	//   _गोद_, dráu, _hone, ília,
   {{0x44447f89,0x64457f8a,0x60180897,0xe61a0aeb}},	// [8300] _wt_, _ethi, jíma, _иди_,
   {{0x44447f8b,0xbbd23245,0x365b0266,0x69c37f8c}},	//   _tt_, _तत्क, _שכינ, _jone,
   {{0x44447f8d,0x673b3fa3,0x69c37f8e,0x2d9e00a1}},	//   _ut_, žuje, _mone, _rate_,
   {{0xddc20029,0x6d417f8f,0x03a647cd,0x53ca0378}},	//   droš, _afla, _тимо, _रविश,
   {{0x20061044,0x6d41033c,0x00000000,0x00000000}},	//   rooi_, _bfla, --, --,
   {{0x2b4d7f90,0x69c30193,0x7dd401f7,0xcf250037}},	//   ebec_, _none, _bàsa, حرمي,
   {{0xb5fb025b,0x090b0033,0x64450231,0x00000000}},	//   práv, হেতু_, _xthi, --,
   {{0xa3b904a9,0x0b8a42d1,0x2d9e01af,0x6d417f91}},	//   चाय_, тски_, _wate_, _efla,
   {{0x2a6d7f92,0x6d4100f0,0x99580094,0x69c31b9e}},	//   greb_, _ffla, ráži_, _bone,
   {{0x4e7b0054,0x644300fd,0x7dd40441,0x995800d4}},	//   _באמצ, _énig, _fàsa, sáži_,
   {{0x69c37f93,0x660700e9,0xb4c2033a,0x313717f5}},	//   _done, vojk, ्नो_, ינים_,
   {{0x0aea7f94,0xb4c2030b,0xe69500c2,0x6445009c}},	//   _идей_, ्नै_, бимы, _rthi,
   {{0x69c37f95,0x8674004d,0xb5fb0094,0x00000000}},	//   _fone, оляє, krát, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe4a41312,0xb4d1149b,0xb5fb7f96,0xb8eb0033}},	//   орто, वने_, drát, _রে_,
   {{0x8335008f,0x69c31173,0x00000000,0x00000000}},	//   снах, _zone, --, --,
   {{0x69c37f97,0x66077f98,0x60180072,0xe8df020b}},	// [8310] _yone, pojk, xíma, _phủi_,
   {{0x2249084e,0xf5950037,0x683e01d3,0x3f86014b}},	//   rpak_, _الدج, _zīda, efou_,
   {{0xd1380465,0x64457f99,0x22490085,0x439522ee}},	//   рху_, _uthi, spak_, _ланс,
   {{0x60180088,0x2fc400b3,0x224900f9,0x7dd4009c}},	//   tíma, _comg_, ppak_, _ràsa,
   {{0x6d4101bf,0xbea50fd5,0x27f201f9,0x7dd401b9}},	//   _pfla, салк, ézni_, _sàsa,
   {{0xb5fb08ec,0x629d7f9a,0x0cb60081,0x25a101c2}},	//   crát, _isso, জনৈত, _jahl_,
   {{0x27e97f9b,0x69c37f9c,0x3c93015a,0x98be00c6}},	//   _oman_, _rone, تیاز, matė_,
   {{0x69c32476,0x27e97f9d,0x2a6d7f9e,0x351c00ca}},	//   _sone, _nman_, treb_, כוונ,
   {{0x69c302c8,0x2b4d7f9f,0x00000000,0x00000000}},	//   _pone, rbec_, --, --,
   {{0x27e9048e,0xdef81736,0x25a17fa0,0x69da00a1}},	//   _aman_, _тыс_, _nahl_, ghte,
   {{0x69c37fa1,0xc7a62105,0x07a63732,0x2d872a4e}},	//   _vone, бинк, банн, mfne_,
   {{0x69c30126,0xb5fb2f31,0x629d7fa2,0x27e90085}},	//   _wone, krás, _osso, _cman_,
   {{0x69c33b7a,0x7bdb008a,0x7ccc00e8,0x69da1909}},	//   _tone, mhuu, _vērš, bhte,
   {{0x69da7fa3,0x27e902a7,0x69c30a4b,0xb5fb0103}},	//   chte, _eman_, _uone, drás,
   {{0x629d7de6,0x044607c8,0xb5fb0146,0x25a10407}},	//   _asso, себн, vrát, _dahl_,
   {{0xe29a0231,0x3dc5010a,0x083a006e,0xb5fb0653}},	//   лаб_, _lolw_, _געקל, frás,
   {{0xaaa700bc,0xb5fb2ef7,0x01360076,0x00000000}},	// [8320] कटिक, trát, معاد, --,
   {{0x2d8700e7,0x25a10090,0xb5fb0437,0x00000000}},	//   jfne_, _gahl_, urát, --,
   {{0x629d7fa4,0x6f1b04d8,0x27e97fa5,0x00000000}},	//   _esso, _azuc, _yman_, --,
   {{0x25a17fa6,0x201f7fa7,0x93960781,0xdb0b00d4}},	//   _zahl_, _chui_, _اجدا, _angí,
   {{0x248c003d,0x69da7fa8,0x201f009c,0xdfa50037}},	//   ħdmu_, yhte, _dhui_, تحلي,
   {{0x443a1da7,0x62840212,0xe196002d,0x00000000}},	//   _kup_, mtio, _урмэ, --,
   {{0x62840084,0xf41f00c2,0x29c9002b,0x3ea6007b}},	//   ltio, _yhä_, _lúas_, svot_,
   {{0xd00a7fa9,0x443a1419,0xb33b02a5,0x4f650246}},	//   _себе_, _mup_, _kaça, _واقف,
   {{0x63a47faa,0x62847e86,0x69da7fab,0x443a7fac}},	//   idin, ntio, thte, _lup_,
   {{0x984a013d,0xb33b1f32,0x27e91613,0x2e3b00ca}},	//   ляма_, _maça, _sman_, _עגבנ,
   {{0xb5fb2a44,0x8b6600cd,0xdb4f0fbe,0x7e62298b}},	//   krár, _هاشم, _ню_, lsop,
   {{0x62847fad,0x69da01e5,0x9f4d00dd,0x63a47fae}},	//   ktio, shte, _vjeç_, jdin,
   {{0x6d5a17b6,0x63a47faf,0xb4d112f2,0x68920018}},	//   _keta, ddin, वन्_, _کیجئ,
   {{0x29c90933,0x7c3a4695,0xd6d800d6,0x64410161}},	//   _dúas_, _kutr, стю_, ílio,
   {{0xdce80b88,0x6d5a7fb0,0x395e7fb1,0x69d803cf}},	//   _kadı, _meta, mats_, _ilve,
   {{0x6d5a5de7,0x27e979f8,0x395e7fb2,0x7c3a01e9}},	//   _leta, _uman_, lats_, _mutr,
   {{0xb33b25da,0x7c3a08a9,0x82f80037,0x6d5a0113}},	// [8330] _caça, _lutr, مركز_, _oeta,
   {{0x7c3a1371,0x395e0990,0x63a47fb3,0xb5fb0018}},	//   _outr, nats_, adin, rrás,
   {{0xceeb00bf,0x533522ee,0x62847fb4,0x443a3848}},	//   گران_, _мент, atio, _gup_,
   {{0xb33b7fb5,0xdea100cd,0x395e7fb6,0x6d5a1305}},	//   _faça, ویزی, hats_, _aeta,
   {{0x62847fb7,0x7c3a10af,0x6d5a7fb8,0x69d81ba6}},	//   ctio, _autr, _beta, _olve,
   {{0x31350c0d,0x6d5a7fb9,0xdcf8013f,0x395e0428}},	//   _февр, _ceta, nevė, jats_,
   {{0x395e7fba,0x7c3a00d3,0x59a6030b,0x201f00de}},	//   dats_, _cutr, _कोइर, _thui_,
   {{0x69d87fbb,0x7c3a7fbc,0x6d5a00ee,0x7e620537}},	//   _alve, _dutr, _eeta, bsop,
   {{0xe9d94159,0x6d5a7fbd,0x7bdb7fbe,0x7c3a01b9}},	//   ики_, _feta, rhuu, _eutr,
   {{0x395e7fbf,0x29c908a8,0x63a47fc0,0x7bc0023e}},	//   gats_, _rúas_, zdin, ajmu,
   {{0x29c922e7,0x63a47fc1,0x628401e9,0x6e3b7fc2}},	//   _súas_, ydin, ztio, _huub,
   {{0x69d87fc3,0x6d5a7fc4,0x6e3b7fc5,0x29c90143}},	//   _elve, _zeta, _kuub, _púas_,
   {{0x395e3f40,0x6d5a7fc6,0x443a7177,0xf4010081}},	//   bats_, _yeta, _sup_, ্ষার_,
   {{0x395e33dd,0x63a40238,0x6d5a7fc7,0xb33b016d}},	//   cats_, wdin, _xeta, _raça,
   {{0x64a313a7,0x63a47fc8,0x04430ebf,0xdce81e6b}},	//   мара, tdin, десн, _yadı,
   {{0x63a47fc9,0x29c908a8,0x7f5b0487,0x62847fca}},	//   udin, _túas_, _neuq, ttio,
   {{0x63a47fcb,0x98a503a3,0x62847fcc,0xb33b013c}},	// [8340] rdin, malı_, utio, _qaça,
   {{0x63a42d92,0xe69312eb,0x62847fcd,0xb21b02b6}},	//   sdin, _کلید, rtio, _spær,
   {{0x628417fc,0xdbd101e8,0x6d5a790c,0x443a7fce}},	//   stio, _güçl, _reta, _uup_,
   {{0x6284537d,0x98a507aa,0x8c350139,0xb33b016d}},	//   ptio, nalı_, _as̟o, _taça,
   {{0x4e965e51,0x52750231,0x4422042c,0x3ead044c}},	//   تشار, _нуру, _ihk_, _cret_,
   {{0x7c3a0cd0,0x3ead0472,0x2bd2009d,0x7e620063}},	//   _putr, _dret_, तस्थ, rsop,
   {{0x395e7fcf,0xaff50068,0x98a50511,0x6b892522}},	//   vats_, _کہنا_, kalı_, ffeg,
   {{0xdce801d4,0x6d5a7fd0,0xaa663051,0xd007007e}},	//   _qadı, _weta, оток, _десе_,
   {{0x6d5a10e3,0x395e16c8,0x98a507e7,0x6e3b008c}},	//   _teta, tats_, dalı_, _guub,
   {{0x670e0cce,0xddc200a5,0x2360023e,0x6e21009c}},	//   _सड़क_, społ, haij_, _ghlb,
   {{0x395e7fd1,0xeb9a667a,0x2cac0150,0xdce80233}},	//   rats_, _вие_, _urdd_, _tadı,
   {{0x395e7fd2,0xf8ad05bc,0xb09b00ca,0x00000000}},	//   sats_, اکو_, ביטר, --,
   {{0x395e7fd3,0x37075779,0x394961f0,0x2ba3030b}},	//   pats_, ючов, _şase_, _खोटा,
   {{0x69d809af,0x555800d3,0x00000000,0x00000000}},	//   _ulve, жаря_, --, --,
   {{0x7c227fd4,0xd90f0012,0x98a504a8,0x00000000}},	//   _khor, _ць_, balı_, --,
   {{0x44227fd5,0x98a51e6b,0xb5fb266c,0xd70c0134}},	//   _chk_, calı_, rráq, ọrịr,
   {{0xe1f32ba0,0x7c227fd6,0xa2ad0403,0x00000000}},	// [8350] وسط_, _mhor, ीमध्, --,
   {{0x44220006,0xdddb0344,0x7dd401ec,0x6448002b}},	//   _ehk_, _spuž, _bàsm, ídic,
   {{0x7c220634,0x6e3b7fd7,0x395c0154,0xb88102c6}},	//   _ohor, _suub, _mevs_, žíve,
   {{0x3ead7fd8,0xf4941ac9,0x62352436,0x7ddd60e7}},	//   _pret_, _کشید, _нему, _mèse,
   {{0xb3ba00a1,0x00000000,0x00000000,0x00000000}},	//   _המרכ, --, --, --,
   {{0x7c227fd9,0x270a00ef,0x2ba700de,0x3ead023b}},	//   _ahor, ờng_, _ốc_, _vret_,
   {{0x98a5008e,0xc5f40089,0x7c22152f,0x6b890124}},	//   yalı_, ודס_, _bhor, tfeg,
   {{0x442926bb,0x3ead7fda,0xb33b4466,0x6d430037}},	//   nma_, _tret_, _maço, scna,
   {{0x6aa47fdb,0x7c227fdc,0xe7af00a5,0xb33b20df}},	//   _šifr, _dhor, _जोधप, _laço,
   {{0xe9d942d1,0xaca30129,0x7c227fdd,0xba220077}},	//   ско_, _ahụm, _ehor, ндык,
   {{0x7c220080,0x44294051,0xb33b0072,0x98a5020e}},	//   _fhor, kma_, _naço, talı_,
   {{0x7c227fde,0x44290d94,0xdb0b0042,0x2360023e}},	//   _ghor, jma_, _engá, xaij_,
   {{0x44297fdf,0x98a503a3,0x98ab01e8,0xbb3a0327}},	//   dma_, ralı_, ılık_, _העני,
   {{0x44297fe0,0x7c220146,0x7ddd0113,0x44227fe1}},	//   ema_, _zhor, _hèsb, _shk_,
   {{0x7c297fe2,0x98a50587,0x44220479,0xb5fb00b6}},	//   omer, palı_, _phk_, psán,
   {{0x442927d8,0x7c294d66,0xc2467fe3,0x7c220216}},	//   gma_, nmer, знак, _xhor,
   {{0x2360005c,0xb77b00ca,0x8afd00d2,0x00000000}},	// [8360] raij_, _האפש, baře, --,
   {{0x44297fe4,0xb33b025a,0x7c297fe5,0xa7fd07aa}},	//   ama_, _faço, hmer, nsın,
   {{0x7c297fe6,0x655700ca,0x7e7901cb,0x00000000}},	//   kmer, _מביא_, euwp, --,
   {{0xb4b800c3,0x7c297fe7,0x00000000,0x00000000}},	//   चमी_, jmer, --, --,
   {{0xa3b93856,0xa7fd026a,0x7c2945ca,0xb33b026a}},	//   चार_, ksın, dmer, _maçl,
   {{0x63a67fe8,0x7c2200a1,0x7c290220,0x471b006e}},	//   _hakn, _shor, emer, זונג,
   {{0x7c227fe9,0x63a61528,0x61ee493a,0x7c290364}},	//   _phor, _kakn, _imbl, fmer,
   {{0x7c297fea,0xdcf801d3,0x8fa30138,0x00000000}},	//   gmer, levī, _пасе, --,
   {{0x63a6113a,0x7f44037a,0x291a05db,0x00000000}},	//   _makn, ñiqu, _špa_, --,
   {{0xdca63347,0x6e93003f,0x63a67feb,0x7ddd02f1}},	//   _нази, _سلما, _lakn, _pèse,
   {{0x44297fec,0xa3190b89,0x7c297fed,0x660e008a}},	//   yma_, _दर्ज_, bmer, dobk,
   {{0x7c227fee,0x44297fef,0x00000000,0x00000000}},	//   _uhor, xma_, --, --,
   {{0x61ee7ff0,0x00000000,0x00000000,0x00000000}},	//   _ombl, --, --, --,
   {{0x1a9b00c1,0xdb0b0037,0xb33b0131,0x78bc02c3}},	//   _לידע, _ungá, _paço, ärvs,
   {{0x44297ff1,0xdcf801d3,0xa3b92231,0x25780fd6}},	//   tma_, devī, चाल_, ябрь_,
   {{0x44297ff2,0x7dcf00d6,0x69ca7ff3,0x799a0051}},	//   uma_, _høst, _hofe, letw,
   {{0xdb0b0131,0xb5fb0143,0x6aa200bd,0x6d480381}},	// [8370] _fogõ, lsám, _jsof, _ofda,
   {{0x7c292e85,0x799a7ff4,0x764d62fb,0x69ca0072}},	//   zmer, netw, _itay, _jofe,
   {{0x7c2900f0,0x4429026a,0x9f4f00fd,0x662800b6}},	//   ymer, pma_, ligé_, řské,
   {{0xc10400ab,0x6d487ff5,0xa7fd026a,0xb33b0233}},	//   روني, _afda, zsın, _kaçm,
   {{0x6da52f03,0x799a4788,0x9ac5010a,0x1ea80076}},	//   дила, ketw, _kuŋŋ, كاوي_,
   {{0x6b821ea5,0x69ca00f0,0x764d0a4b,0x2d8109dc}},	//   _acog, _nofe, _mtay, ühe_,
   {{0x63a62f6b,0xdca2013d,0x70942383,0x6aa20af0}},	//   _yakn, ващи, _парф, _asof,
   {{0x764d0172,0x660e024a,0x00000000,0x00000000}},	//   _otay, zobk, --, --,
   {{0x200f7ff6,0x764d05bd,0x69ca7ff7,0xcf9200d7}},	//   mogi_, _ntay, _bofe, _בטן_,
   {{0x7c297ff8,0x39e902ec,0x69ca3476,0x27e1003d}},	//   smer, ідно_, _cofe, _ċina_,
   {{0xdd1c025b,0x764d6cc5,0x7c29004d,0xa7fd0511}},	//   _záži, _atay, pmer, rsın,
   {{0x7e690138,0x200f7ff9,0x764d0172,0x9b0e0129}},	//   _kvep, nogi_, _btay, ịhịa_,
   {{0x7bcb7ffa,0x799a7ffb,0x63a67ffc,0x00000000}},	//   _iogu, betw, _rakn, --,
   {{0x63a60b6a,0x6b9b7ffd,0x7bcb037a,0x69ca7ffe}},	//   _sakn, leug, _hogu, _gofe,
   {{0xa3b9007d,0x660e06c2,0x7bcb7fff,0x764d0172}},	//   चां_, robk, _kogu, _etay,
   {{0x660e35c2,0x00000000,0x00000000,0x00000000}},	//   sobk, --, --, --,
   {{0x7bcb02e6,0x63a632fa,0xa3e40635,0x64430113}},	// [8380] _mogu, _vakn, भोग_, _énin,
   {{0x7bcb8000,0x6b9b0126,0x00da0037,0x69ca7472}},	//   _logu, heug, يبات_, _xofe,
   {{0x7dcf0170,0x00000000,0x00000000,0x00000000}},	//   _løss, --, --, --,
   {{0xef1a31f6,0x200f8001,0x7bcb8002,0x799a0034}},	//   оме_, gogi_, _nogu, zetw,
   {{0x6018414c,0x6b9b8003,0xb33b00a7,0x27f901f9}},	//   ními, deug, _xaçm, érni_,
   {{0x6b820451,0x61ee47b9,0xdd1c0094,0xbc4a23c3}},	//   _scog, _umbl, _váži, очие_,
   {{0xb4bc00b7,0x200f8004,0x7dcf0ac9,0x6aa20090}},	//   _आपो_, bogi_, _røst, _ssof,
   {{0x69ca8005,0x7dcf8006,0x7bcb36fe,0x6b9b024a}},	//   _sofe, _søst, _cogu, geug,
   {{0x7bcb8007,0x1eaa00cd,0x5a34008f,0x61fe8008}},	//   _dogu, _بازي_, ннит, onpl,
   {{0x61fe01ce,0x00000000,0x00000000,0x00000000}},	//   nnpl, --, --, --,
   {{0x2d9c01e5,0x799a8009,0xb33b026a,0x764d02f4}},	//   meve_, retw, _saçm, _stay,
   {{0x2d9c800a,0x6aa20044,0x9f4f014b,0x00000000}},	//   leve_, _tsof, tigé_, --,
   {{0xa2fd007f,0x69ca3a30,0xb33b013c,0xfb8705bc}},	//   _एशेज_, _tofe, _qaçm, _آدمی,
   {{0x2d9c00dd,0x7dd40472,0x7bcb0052,0x9f4f020d}},	//   neve_, _bàsi, _zogu, rigé_,
   {{0x200f800b,0x163400c2,0x43953a6f,0xf7f70076}},	//   yogi_, теря, навс, _يسعد,
   {{0x7bcb03be,0x43941cb1,0x6aad0b14,0x6b802375}},	//   _xogu, касс, _šafi, ngmg,
   {{0x4e0e0034,0x764d7bdc,0x2d9c023b,0x200f003e}},	// [8390] ाकाई_, _utay, keve_, vogi_,
   {{0x2d9c800c,0x6b9b02e2,0xdbd6007a,0x00000000}},	//   jeve_, zeug, _hääl, --,
   {{0xdb0b0222,0x2d9c800d,0x200f800e,0x7e69800f}},	//   _ingå, deve_, togi_, _svep,
   {{0x61fe1044,0x4f940396,0x00000000,0x00000000}},	//   anpl, вршу, --, --,
   {{0x2d9c0216,0x809f023a,0x7bcb1190,0x00000000}},	//   feve_, _गैरे, _rogu, --,
   {{0x44390054,0x0ea800d6,0x2d9c0052,0x8eb2001c}},	//   _his_, ькій_, geve_, اموش,
   {{0x44398010,0x7bcb8011,0x7ddd015e,0x23d33e2a}},	//   _kis_, _pogu, _cèsa, _सवाद,
   {{0x44398012,0x2d8e0172,0x00000000,0x00000000}},	//   _jis_, affe_, --, --,
   {{0x44398013,0xeab10037,0x2d9c0052,0xa7fd0345}},	//   _mis_, اعب_, beve_, rsıl,
   {{0x44398014,0x3f9d8015,0x7bcb8016,0x2d9c8017}},	//   _lis_, lewu_, _wogu, ceve_,
   {{0x7bcb8018,0x443900c2,0x2fdf41e9,0x00000000}},	//   _togu, _ois_, _klug_, --,
   {{0xf7720dd0,0x44390049,0xdb0b4796,0xddc200b6}},	//   داد_, _nis_, _angå, dpoř,
   {{0x2fcd057a,0xa3b914e5,0x80d600a4,0x00000000}},	//   _moeg_, चाई_, _मॅने, --,
   {{0x44390514,0x64a60138,0x6448016d,0xa2c302c6}},	//   _ais_, нага, ídio, रमन्,
   {{0x44398019,0xb8f400c7,0x809f0557,0xd4f504d9}},	//   _bis_, _সে_, _गैले, вяты,
   {{0x2d9c801a,0x04570037,0xdb0b02c3,0x00000000}},	//   zeve_, علقة_, _engå, --,
   {{0x4439801b,0x42264b34,0x27e001d4,0xb22635c1}},	// [83a0] _dis_, едав, _ilin_, емал,
   {{0x4439801c,0x2fdf0124,0x06570266,0x3ea40350}},	//   _eis_, _alug_, _רייך_, _rsmt_,
   {{0x4439801d,0x40962529,0x2fcd1cab,0x61fe07ee}},	//   _fis_, эрат, _boeg_, rnpl,
   {{0x4439801e,0x8afd00b6,0xdb1b037a,0x3f9d010a}},	//   _gis_, zařa, zjuá, gewu_,
   {{0x2d9c01e5,0x245e030b,0x2fcd00f9,0xa3a9058f}},	//   teve_, lům_, _doeg_, _गोट_,
   {{0x4439801f,0x2d8e00fd,0x27f20167,0x27e0030a}},	//   _zis_, uffe_, _lmyn_, _llin_,
   {{0x2d9c00dd,0x27e00fc4,0x443938c3,0x245e00b6}},	//   reve_, _olin_, _yis_, nům_,
   {{0x4439006c,0x2d9c48a3,0x80261ac9,0x2d85009c}},	//   _xis_, seve_, _سرزم, _ecle_,
   {{0x7c3902ad,0x2d9c023b,0x67240361,0xd0078020}},	//   _diwr, peve_, _nzij, _чете_,
   {{0x27e08021,0x8e970341,0x245e00b6,0x2c570034}},	//   _alin_, _אדמו_, kům_, _będę_,
   {{0xdbd602fd,0x27e03788,0x29181d15,0x22428022}},	//   _pääl, _blin_, æra_, _lukk_,
   {{0x1ae68023,0x245e02c6,0xa3b0142e,0x27e08024}},	//   _поем, dům_, _टोल_, _clin_,
   {{0x44398025,0x6e3a003d,0x6d4a0037,0x7bc609a1}},	//   _ris_, _kitb, ocfa, ökuu,
   {{0x443901bb,0x7afd1f72,0x27e045a5,0x6e3a009e}},	//   _sis_, úste, _elin_, _jitb,
   {{0x44398026,0xdbd60084,0xe4e400d6,0x6e3a0364}},	//   _pis_, _tääl, гітн, _mitb,
   {{0x4439006c,0xa4010033,0x75d8008b,0xb5fb02c6}},	//   _qis_, ্ষ্য_, _ağzı, zsáh,
   {{0x44395be7,0x98ac03a3,0x1b0e0081,0x53350070}},	// [83b0] _vis_, madı_, াইকে_, теат,
   {{0x44390979,0x69da34cb,0x98ac0511,0x6e3a02a1}},	//   _wis_, nkte, ladı_, _nitb,
   {{0x27e000c2,0x6567033b,0x69c88027,0x2fcd00bc}},	//   _ylin_, majh, ijde, _poeg_,
   {{0x44398028,0x6e3a009c,0x98ac03e0,0xddc28029}},	//   _uis_, _aitb, nadı_, grož,
   {{0x2fcd01a2,0x6e3a802a,0x2fdf1507,0x60db03e3}},	//   _voeg_, _bitb, _vlug_, _ƙums,
   {{0x7d1a02ac,0x20040095,0x0c9500e5,0x69da01cb}},	//   _byts, _ejmi_, вшия, jkte,
   {{0x301b00e3,0x63ad802b,0xdb0077d4,0x628d007b}},	//   _فترة_, odan, ndmæ, ltao,
   {{0x69da802c,0x22420167,0x6e3a0634,0x40340cd1}},	//   ekte, _yukk_, _eitb, _бесс,
   {{0x628d802d,0xb5fb0076,0x244700fe,0xc95510e0}},	//   ntao, asái, _lõm_, ктны,
   {{0x63ad802e,0x4e352259,0x00000000,0x00000000}},	//   hdan, _شفاء, --, --,
   {{0x63ad802f,0x27e08030,0x9b950037,0xb33b0052}},	//   kdan, _plin_, _للات, _daçi,
   {{0x79810150,0x6e3a029a,0x394000ae,0x78bc02c3}},	//   sglw, _zitb, _şist_, årva,
   {{0x63ad8031,0x21e401bf,0x7d1a01ff,0x7d04173c}},	//   ddan, _höhe_, _zyts, şist,
   {{0x7ae90068,0x69da3977,0x245e00b6,0x68ed0d2a}},	//   mzet, ckte, tům_, _ƙadd,
   {{0xa806013d,0x2bc51a09,0xc5632ba6,0x7ae98032}},	//   _изкл, वापा, ркск, lzet,
   {{0x63ad8033,0x7bc90f20,0x6f1600a5,0x245e00b6}},	//   gdan, njeu, życi, rům_,
   {{0x7ae98034,0xf6261d5c,0x628d0124,0xd5b10023}},	// [83c0] nzet, _идио, gtao, ốc_,
   {{0x867b00ca,0x63ad8035,0xa3220e4c,0x7ae901ff}},	//   _קריו, adan, _मरीज_, izet,
   {{0xa50a3703,0x3d1602e8,0x8fa65cb1,0x63ad8036}},	//   _цена_, _पुढे_, каже, bdan,
   {{0x44448037,0x63ad8038,0x7ddd0113,0x776401ff}},	//   _iu_, cdan, _bèso, _jeix,
   {{0x44448039,0x69da004d,0x77640042,0x2bc5274c}},	//   _hu_, ykte, _meix, वाना,
   {{0x4444803a,0x77640072,0x249a0063,0x7ae9803b}},	//   _ku_, _leix, _kppm_, dzet,
   {{0x4444803c,0x6f0939bc,0x7ae9029a,0xdb0b0139}},	//   _ju_, _exec, ezet, _ingù,
   {{0x4444803d,0x3d1602e8,0xb5fb00e3,0x6e3a0abf}},	//   _mu_, _पुणे_, rsái, _witb,
   {{0x4444803e,0x7ae90103,0x249a0167,0xdb020072}},	//   _lu_, gzet, _lppm_, _taoí,
   {{0x4444803f,0xbda50678,0x6e3a0305,0x7dd4015e}},	//   _ou_, _محمو, _uitb, _càst,
   {{0x44448040,0x717b00f5,0x69da535a,0x63ad6d11}},	//   _nu_, וניס, rkte, ydan,
   {{0xb5fb0396,0x63ad4628,0x7e60039f,0x383400d3}},	//   nsáv, xdan, _kwmp, инэр,
   {{0x44448041,0x77648042,0x63ad04eb,0x051f0081}},	//   _au_, _deix, vdan, _দলের_,
   {{0x44448043,0x764401c2,0xceb300ca,0x7dd400b3}},	//   _bu_, _duiy, ביש_, _gàst,
   {{0x44441ae2,0x77648044,0x657a00e3,0x63ad004d}},	//   _cu_, _feix, ótha, tdan,
   {{0x249a0063,0x490b00b6,0x77648045,0xe6c00234}},	//   _dppm_, _ठुटो_, _geix, žišć,
   {{0x44448046,0x63ad8047,0x76448048,0xa2c30961}},	// [83d0] _eu_, rdan, _guiy, रमध्,
   {{0x44448049,0xa294013a,0x628d028d,0xddc20034}},	//   _fu_, рафі, rtao, groż,
   {{0x4444064b,0x7ae9804a,0x94d5804b,0x82340037}},	//   _gu_, zzet, _сонц, شركا,
   {{0x65650e76,0x7ddd0c56,0x776400b3,0x66154243}},	//   _hehh, _pèso, _xeix, lozk,
   {{0x44443477,0x6445804c,0x9ac40078,0x7e6000f0}},	//   _zu_, _huhi, _jiċċ, _cwmp,
   {{0xee3802ec,0x7ae97523,0x8d54013d,0x9f5f0231}},	//   вні_, vzet, атъч, _ijuí_,
   {{0x4444804d,0x6445007a,0x656500bc,0x00000000}},	//   _xu_, _juhi, _mehh, --,
   {{0x6445804e,0x7ae9804f,0xac960037,0x6f09015e}},	//   _muhi, tzet, انيا_, _txec,
   {{0x7ae900e9,0x77644acf,0x7e600150,0x66151fd4}},	//   uzet, _reix, _gwmp, kozk,
   {{0x7ae98050,0x77648051,0x7bdb8052,0x2d83052f}},	//   rzet, _seix, skuu, _øje_,
   {{0x6d4157df,0x7ae90018,0x77645bdb,0x66150062}},	//   _igla, szet, _peix, dozk,
   {{0x44448053,0xdce33488,0x9ac4003d,0x442b024a}},	//   _ru_, nanč, _biċċ, _nhc_,
   {{0x644500aa,0xe7371aad,0xddc200e8,0xa7fd173c}},	//   _auhi, лею_, lsoš, nrıy,
   {{0x44448054,0x64458055,0x661501e9,0xdb0b0216}},	//   _pu_, _buhi, gozk, _lagë,
   {{0x444410af,0x77648056,0x65650167,0xdce333f4}},	//   _qu_, _teix, _dehh, kanč,
   {{0x44448057,0xdce3013f,0x644505bd,0x76440172}},	//   _vu_, janč, _duhi, _tuiy,
   {{0x6d411c54,0x44448058,0x03260290,0xdce30138}},	// [83e0] _ogla, _wu_, удан, danč,
   {{0x44448059,0x6d41114c,0x00000000,0x00000000}},	//   _tu_, _ngla, --, --,
   {{0x44440fdc,0x6445023f,0x442b0131,0xdb0b0216}},	//   _uu_, _guhi, _fhc_, _bagë,
   {{0x2a6d805a,0x6d41173c,0xbe8a5a67,0xdce300c6}},	//   kseb_, _agla, еске_, ganč,
   {{0x442063fd,0x4432805b,0xdce10090,0x4e9307e8}},	//   mli_, mmy_, _felċ, مشور,
   {{0x44321670,0xc69300a1,0x6143083c,0xb33b0131}},	//   lmy_, צאו_, _гера, _caçu,
   {{0x4420805c,0xa3b90096,0x00000000,0x00000000}},	//   oli_, चाच_, --, --,
   {{0x442008bb,0x4432805d,0x3a74249b,0x75f40092}},	//   nli_, nmy_, алир, _düzə,
   {{0xaf0658c0,0xe20b00a5,0x00000000,0x00000000}},	//   _спал, łóż_, --, --,
   {{0x44204a8d,0x2a970080,0x3f86805e,0x443203a9}},	//   hli_, ائية_, lgou_, hmy_,
   {{0x683e013f,0x021700a1,0xdb0b0113,0x75f400a7}},	//   _būda, רחים_, _lagè, _güzə,
   {{0x3f8606a3,0x6445805f,0x44321670,0x9a86100f}},	//   ngou_, _ruhi, jmy_, _букл,
   {{0xeab20d74,0x64458060,0x3f8601c2,0xdb19007f}},	//   _دعا_, _suhi, igou_, _dowó,
   {{0x44208061,0x44320034,0x64458062,0xa8a68063}},	//   eli_, emy_, _puhi, _брик,
   {{0x44208064,0x656500e7,0x4993001c,0x66158065}},	//   fli_, _vehh, _ایپر, rozk,
   {{0x44208066,0xdb0b1cb0,0xb3550307,0x66150062}},	//   gli_, _bagè, ркаш, sozk,
   {{0xdce30218,0x81ae0033,0x442b464f,0x2bc50d7e}},	// [83f0] vanč, কান_, _vhc_, वाता,
   {{0x44208067,0x44328068,0xe1ff0113,0xdb190383}},	//   ali_, amy_, _lvóv_, _kowò,
   {{0x44208069,0xdce33603,0xdb0b0052,0x4395013f}},	//   bli_, tanč, _pagë, _канс,
   {{0xb4c302e8,0x4420806a,0x673b0995,0x7ddd0154}},	//   ्ही_, cli_, žuju, _vèsm,
   {{0x8d652983,0xdce32281,0xea0000de,0x6d4100f9}},	//   авле, ranč, _giầy_, _pgla,
   {{0x3f7500ef,0x7dd405fe,0xc27a00ca,0xb5fb0103}},	//   ều_, _bàsq, _ברשי, csát,
   {{0x5ed300c7,0x463c13b6,0x228f806b,0xdce362fd}},	//   _দেশে, געגע, lük_, panč,
   {{0x0b45261f,0x2a6d007a,0xf0b30018,0x2bc500b6}},	//   шнин, tseb_, _پیچھ, वाधा,
   {{0x63af806c,0x4a451fdb,0xdb0b0113,0x228f806d}},	//   _macn, јнов, _kagé, nük_,
   {{0x6d4102e6,0xe9d91107,0x44206209,0x63af0181}},	//   _ugla, тко_, zli_, _lacn,
   {{0xf1b2193b,0x4420806e,0x44320034,0x2bc5034d}},	//   קסט_, yli_, ymy_, वादा,
   {{0x629d1507,0x5b15008f,0x44206acd,0xd5b10023}},	//   _opso, _кмет, xli_, ốn_,
   {{0x228f0018,0x4420806f,0x25a302b6,0x7b470206}},	//   jük_, vli_, fejl_, rčuľ,
   {{0x2d8763dc,0x44208070,0xeaf8010d,0xdb190383}},	//   ngne_, wli_, _حرمت_, _fowò,
   {{0x44208071,0x64a60ac6,0x629d02e6,0xb0a40034}},	//   tli_, шава, _apso, _गैंग,
   {{0x864603d9,0x44208072,0x2407362f,0xdb0b0428}},	//   _книж, uli_, анси_, _pagè,

   {{0x44208073,0x443212fb,0xade50e72,0xdb0b00cd}},	// [8400] rli_, rmy_, कसान_, _bagé,
   {{0x442028be,0xd5a409e5,0x63af00e3,0x68e400b6}},	//   sli_, _الدی, _eacn, _řidi,
   {{0x161f0635,0xb5fb8074,0x68e40022,0x10a64ede}},	//   _मीटर_, rsát, _ƙidi, риен,
   {{0x44205673,0x03960b7a,0x998700c6,0x2d878075}},	//   qli_, _троя, _kinų_, egne_,
   {{0x63a410a5,0x614611db,0x3f860558,0xdce18076}},	//   mein, _вега, rgou_, _delč,
   {{0x63af8077,0xdd90097d,0xde03004d,0x3f860231}},	//   _zacn, سوب_, опчи, sgou_,
   {{0xcbe61807,0x00000000,0x00000000,0x00000000}},	//   иции, --, --, --,
   {{0xdb000068,0x63a48078,0xa7fd026a,0x2d91026a}},	//   lemé, nein, nsıt, _özen_,
   {{0x75e20181,0xee3a12d3,0x6fb3071c,0xdee31a18}},	//   _rôzn, _ана_, _بمقا, _доти,
   {{0x63a402dc,0xe61f0257,0x3e320018,0x2a7901f9}},	//   hein, ntôt_, _بہتر, ásba_,
   {{0x63a48079,0x228f0230,0x68ed03e3,0x7e6d00e7}},	//   kein, zük_, _ƙada, šapt,
   {{0x228f06d7,0x62840350,0xab83180b,0xdce80206}},	//   yük_, kuio, _душк, _obdĺ,
   {{0x34df00a8,0xf1c93542,0x63a4807a,0x7bc2807b}},	//   नन्द, रामन, dein, _inou,
   {{0x6284044c,0x00000000,0x00000000,0x00000000}},	//   duio, --, --, --,
   {{0x63a4807c,0xb4c340c1,0x65bc0212,0xd4370037}},	//   fein, ्हे_, _såhä, لعرب,
   {{0xe3b006fa,0x228f807d,0x63a4807e,0xdb0b01dc}},	//   ورق_, tük_, gein, _sagé,
   {{0x4df80251,0x809f00a5,0xe69500e3,0x2d8c39b6}},	// [8410] ्चाई_, _गैजे, _الخد, _ocde_,
   {{0x228f0e10,0x7e7d0120,0xf48700d3,0x00000000}},	//   rük_, _åspi, _кумн, --,
   {{0xea000028,0x63af113c,0x63a422b7,0x228f01f9}},	//   _giấy_, _tacn, bein, sük_,
   {{0x64570a00,0x63a40257,0x5f7400e3,0x7bc20154}},	//   _itxi, cein, قاهر, _nnou,
   {{0x2bc5009d,0xa3bc009f,0x75e40174,0x539a0327}},	//   वासा, _आफत_, _ọziz, _גירו,
   {{0x75eb008e,0xa18432e3,0x7bc2807f,0x1d092156}},	//   _düzg, _мысл, _anou, лели_,
   {{0x2d878080,0xddc900d3,0xa7fd00a7,0xeb992458}},	//   rgne_, _aveţ, nsıs, гий_,
   {{0x6e4500cd,0x3ff900c1,0x9145008b,0x7ddd022b}},	//   _هنرم, _עפּע, şığı_, _mèsi,
   {{0x75eb0103,0x7ddd00b3,0x00000000,0x00000000}},	//   _küzd, _lèsi, --, --,
   {{0x3ead001f,0x63a46c46,0x7bc200a1,0x2bc50e19}},	//   _iset_, zein, _enou, वाहा,
   {{0x645701bb,0xacb50dce,0x34b31178,0x63a48081}},	//   _ntxi, _دماغ, ुमोद, yein,
   {{0x0cb302d5,0x3ead00c4,0xdb000103,0x63a40072}},	//   ंटीम, _kset_, zemé, xein,
   {{0xe9ce2277,0x64570a00,0x05c30034,0xca4800fe}},	//   _ек_, _atxi, शांब, _hờn_,
   {{0x63a40150,0x2bc51792,0x6aa9010a,0x00000000}},	//   wein, वावा, mwef, --,
   {{0x8afd00b6,0x04b500a9,0xb4260308,0x00000000}},	//   daři, остя, معرو, --,
   {{0x6b898082,0x7ddd01dc,0x680b0034,0x78bc0c89}},	//   ngeg, _dèsi, lędn, ærve,
   {{0x63a48083,0xb5fb001f,0xdb000103,0xdb0b003e}},	// [8420] rein, rsár, temé, _ingó,
   {{0xb5fb497e,0x05aa0761,0x45868084,0x75eb0233}},	//   ssár, _свой_, _угов, _rüzg,
   {{0x3ead58fb,0x656e0201,0xdb000103,0xe1ff0558}},	//   _aset_, mabh, remé, _avós_,
   {{0x656e8085,0x6b89029a,0x6aa90172,0xe61f0206}},	//   labh, jgeg, kwef, stôt_,
   {{0x6b898086,0x69c30084,0x200600fd,0x840801f9}},	//   dgeg, _onne, rnoi_, _előá,
   {{0x2d910b88,0x656e01b5,0x41c924cf,0x244e0220}},	//   _özel_, nabh, राणस, _kým_,
   {{0x27040d39,0x645c8087,0xa3cc030b,0x6b898088}},	//   रपुर_, npri, लाप_, fgeg,
   {{0x69c38089,0x656e808a,0x6b8901d0,0x61fe808b}},	//   _anne, habh, ggeg, lipl,
   {{0x6ff50067,0x75eb01e8,0xdb00181f,0x656e019f}},	//   jący, _yüzd, ndmø, kabh,
   {{0xd9100260,0x69c3037a,0x645c3f0f,0xdd3a020a}},	//   ویش_, _cnne, kpri, găţi,
   {{0x645c1fce,0x656e01b9,0x236001c0,0x621b00ca}},	//   jpri, dabh, kbij_, רויק,
   {{0x69c3808c,0xa3cc0b89,0x61fe01e8,0x321a0094}},	//   _enne, लाफ_, hipl, hopy_,
   {{0xdce101d3,0xa3cc05e4,0xead45ec9,0x321a2907}},	//   _ielā, लान_, _фоль, kopy_,
   {{0x15eb00d6,0xfc490094,0x645c01cb,0x656e808d}},	//   уємо_, slíš_, fpri, gabh,
   {{0x645c808e,0x0f05007f,0x6ff5007f,0xdd080206}},	//   gpri, _शख्स_, rącz, _lôžo,
   {{0x61fe18f0,0x98a700c6,0x00000000,0x00000000}},	//   eipl, _agnė_, --, --,
   {{0x27e9808f,0x645c8090,0x290b020a,0x7ddd0154}},	// [8430] _ilan_, apri, şcat_, _wèsi,
   {{0x672d05bd,0x645c8091,0xdb090072,0xb33b00a7}},	//   _izaj, bpri, ndeá, _qaçq,
   {{0x463c0130,0x637f009c,0x645c014b,0x00000000}},	//   _געזע, _cànà, cpri, --,
   {{0x75eb0b88,0xdb090037,0x2b4600de,0xd5bf01d3}},	//   _düze, hdeá, _ngoc_, žādi_,
   {{0xf41f007b,0x62350f80,0x765d8092,0x877c0142}},	//   _ikä_, _мему, npsy, ראדי,
   {{0x27180028,0x321a1cdf,0xe057001c,0x765d02ac}},	//   ọng_, copy_, _هیئت_, ipsy,
   {{0x27e9436c,0x75eb074e,0x2bc50efb,0x6b891c81}},	//   _olan_, _güze, वाला, tgeg,
   {{0xa9f304a9,0x8c421612,0xa3cc009d,0x5f94016a}},	//   ेच्छ_, меще, लाय_, _нист,
   {{0xdd3a0012,0x22430ab2,0x6b8931fc,0xdb0b8093}},	//   tăţi, _kijk_, rgeg, _angò,
   {{0x6b898094,0x645c5f5c,0x75eb026a,0x27e98095}},	//   sgeg, ypri, _yüze, _alan_,
   {{0x27e906a3,0x672d05bd,0xdd3a020a,0x224b8096}},	//   _blan_, _azaj, răţi, _luck_,
   {{0xe73a0832,0x61fe0634,0x2243029a,0x645c00f2}},	//   иен_, zipl, _lijk_, vpri,
   {{0x672d007f,0x00000000,0x00000000,0x00000000}},	//   _czaj, --, --, --,
   {{0xcb3600a1,0x645c8097,0x27e98098,0x672d1ce4}},	//   _ואני_, tpri, _elan_, _dzaj,
   {{0x656e152f,0x236001c0,0x2ea600b6,0x15433761}},	//   rabh, tbij_, _गन्त, дерм,
   {{0x27e971e0,0x656e8099,0x645c809a,0xa6ca0f36}},	//   _glan_, sabh, rpri, _نوبل_,
   {{0xe1fa0ecc,0x23600505,0xa3cc417e,0x681201d3}},	// [8440] ага_, rbij_, लाब_, gāde,
   {{0x244e135f,0xf65300a1,0x645c809b,0xf77f01e8}},	//   _tým_, _קצת_, ppri, rkçe_,
   {{0x321a06f7,0x224301c0,0x645a00b6,0x397a006e}},	//   ropy_, _dijk_, ítid, שטענ,
   {{0x389a006e,0x224301cb,0xa3de00b7,0x67e60139}},	//   ייענ, _eijk_, _तकि_, _mójo,
   {{0xddc95c85,0x2d580fd6,0x8b0401c2,0x224b042c}},	//   _sveš, биль_, ƙƙin, _guck_,
   {{0xddc9030b,0x8cb80285,0x661c00d4,0x6249007e}},	//   _kteř, ्मलो, nork, _džod,
   {{0xc0c900c9,0x3ea9003d,0x9cca6c6e,0xafe600d3}},	//   _луѓе_, ħata_, рыла_, _довл,
   {{0xd00a28dc,0x394701ec,0x63b6809c,0x2d80020a}},	//   _тебе_, _agns_, ndyn, şie_,
   {{0x661c809d,0x00000000,0x00000000,0x00000000}},	//   kork, --, --, --,
   {{0x661c809e,0xdca66368,0x27e9461a,0x00000000}},	//   jork, _мази, _slan_, --,
   {{0x27e97dc2,0xf2df0019,0x672403a5,0x629679dd}},	//   _plan_, _ngân_, _ayij, htyo,
   {{0x67240169,0x00000000,0x00000000,0x00000000}},	//   _byij, --, --, --,
   {{0x661c354e,0x99d30281,0x63b600f0,0x67240027}},	//   fork, ستیا, ddyn, _cyij,
   {{0xdcfa01e8,0x2d9e02ef,0xe1ff0139,0x661c809f}},	//   _hatı, _jbte_, _awón_, gork,
   {{0xdcfa0b88,0x224b80a0,0x22430126,0x20070103}},	//   _katı, _suck_, _rijk_, énik_,
   {{0x69d81a08,0x27e980a1,0x7ddd00b3,0x00000000}},	//   _hove, _ulan_, _hèst, --,
   {{0x672d80a2,0x69d880a3,0xa3bc074c,0x00000000}},	// [8450] _uzaj, _kove, _आफर_, --,
   {{0x69d838b8,0x661c005c,0x681201d3,0xdcfa013c}},	//   _jove, cork, rāde, _latı,
   {{0x69d800a1,0xef580174,0xb4b5022a,0x90991d57}},	//   _move, _ịfụn, _эйнш, свет_,
   {{0x2bb62f8f,0x6d48699b,0x22430126,0x9f970428}},	//   _अफगा, _agda, _wijk_, _açò_,
   {{0x9e6400d6,0xed5929a4,0x61fc00ee,0xfe570504}},	//   двід, бол_, _fmrl, زیاب_,
   {{0x764500ec,0x764d026a,0xb5fb002b,0xa37b00bc}},	//   _jihy, _muay, lpáb, _slõh,
   {{0x459c0130,0x5ed30081,0xdcfa008b,0xdb0b00d4}},	//   יסגע, _দেখে, _batı, _vagí,
   {{0x6e950084,0xf1c9058f,0xdc390555,0xdb00020a}},	//   _нибу, रावन, tçın, demâ,
   {{0x81ae0f71,0x69d80505,0xa3cc03a2,0x7ddd55ed}},	//   কার_, _bove, लात_, _bèst,
   {{0x69d880a4,0x7e690129,0x78540018,0x2cbe02a1}},	//   _cove, _iwep, ڈیوز_, _frtd_,
   {{0x69d880a5,0x6c4900e3,0x661c80a6,0x31bd0033}},	//   _dove, _الصف_, vork, _আকাশ,
   {{0x764d80a7,0x201d0034,0x3ebf7eeb,0x69ce2104}},	//   _buay, nowi_, _krut_, öber,
   {{0xdce800b6,0x7ddd80a8,0x00000000,0x00000000}},	//   _oddě, _fèst, --, --,
   {{0x7e6980a9,0x69d839c3,0x2ca90034,0x7bd90139}},	//   _mwep, _gove, ładu_, _howu,
   {{0xdcfa0587,0x201d2235,0x661c80aa,0x7bd9039f}},	//   _yatı, kowi_, rork, _kowu,
   {{0x69d880ab,0x661c0095,0xdcfa0092,0x6b9b0172}},	//   _zove, sork, _xatı, nfug,
   {{0x661c005a,0x764d80ac,0x7e690294,0x63b680ad}},	// [8460] pork, _guay, _nwep, rdyn,
   {{0x69d80933,0x42230396,0x629680ae,0x3f9f0188}},	//   _xove, едув, rtyo, _abuu_,
   {{0x81ae00c7,0x629680af,0x94760037,0x68e100eb}},	//   কাল_, styo, _عددا, nyld,
   {{0x3ebf80b0,0x26c0042d,0x624980b1,0x7bd958da}},	//   _brut_, _krio_, _džob, _nowu,
   {{0x1dc73db8,0x6446343c,0x44223229,0x6d4800f9}},	//   लांत, _iiki, _ikk_, _pgda,
   {{0xdcfa0702,0x68e121d0,0x442200c4,0x7e6902ac}},	//   _satı, kyld, _hkk_, _dwep,
   {{0x64580257,0x7e6900ac,0x8afd00b6,0x7bd958da}},	//   _évid, _ewep, kařs, _bowu,
   {{0x75eb01d4,0x6446006d,0x26c0203f,0xdcfa00a7}},	//   _müza, _jiki, _orio_, _qatı,
   {{0x64460682,0x5a344db9,0x3ebf80b2,0x776d0072}},	//   _miki, мнит, _grut_, _reax,
   {{0x644680b3,0x68e101c5,0x62840138,0x7c661ac9}},	//   _liki, fyld, irio, _فاصل,
   {{0x9b4600cd,0x776d0042,0x68e1181f,0x7bd9022b}},	//   _فناو, _peax, gyld, _fowu,
   {{0x6446612b,0x683f013f,0x7bd9010a,0x76450167}},	//   _niki, _kūdi, _gowu, _sihy,
   {{0x9f4d0149,0x7c2280b4,0x69d880b5,0x26c080b6}},	//   _umeå_, _ikor, _tove, _crio_,
   {{0x64460a75,0x4a7b0105,0x628480b7,0x5558002d}},	//   _aiki, _פרוב, drio, заря_,
   {{0x644680b8,0x2c5500d9,0xa99b00ca,0xa35a0134}},	//   _biki, _kāda_, _הבור, _ọnụe,
   {{0x64462bc2,0x683f0029,0x671e000f,0x26c080b9}},	//   _ciki, _līdz, _युवक_, _frio_,
   {{0x442201c5,0xe80200a5,0x5edc0033,0xf1a73ac9}},	// [8470] _dkk_, _लगता_, _মেসে, зрен,
   {{0xda0c0bd9,0x98b0030b,0x644680ba,0x44220653}},	//   िचित_, _जनाए, _eiki, _ekk_,
   {{0x628411ce,0xdb0b0068,0x7c2280bb,0x64465257}},	//   ario, _magá, _okor, _fiki,
   {{0x644680bc,0x3ebf80bd,0x7c2202a4,0x683f0d7c}},	//   _giki, _prut_, _nkor, _būdi,
   {{0x442980be,0xf3ff016d,0xdfce001c,0x4ea701b3}},	//   mla_, _imã_, شيو_, яржа,
   {{0x44291bb8,0x7c2280bf,0x644680c0,0x6abb80c1}},	//   lla_, _akor, _ziki, vvuf,
   {{0x442980c2,0xd9a9009f,0x623400d3,0x6114125f}},	//   ola_, _कसौट, _черу, _здру,
   {{0x44297c7b,0x69dc0704,0x681201d3,0x7ddd00ee}},	//   nla_, ören, kāda, _pèss,
   {{0x4429057c,0x3ebf5d10,0x52df0081,0x6b9b2084}},	//   ila_, _urut_, _নেতৃ, rfug,
   {{0x442980c3,0x7c2280c4,0xf2df0023,0x00000000}},	//   hla_, _ekor, _ngâm_, --,
   {{0x9b5980c5,0xdb000231,0x00000000,0x00000000}},	//   _диет_, temã, --, --,
   {{0xad1a07a6,0x3f8f0496,0x442980c6,0x9d1a006e}},	//   _ווער, nggu_, jla_, _וועט,
   {{0x442980c7,0x7c29074e,0x64461114,0xa3cc1e9f}},	//   dla_, mler, _riki, लास_,
   {{0x64a680c8,0x644680c9,0x44220220,0xde8f0134}},	//   мага, _siki, _skk_, lịsi_,
   {{0xe64320f9,0x644680ca,0x69b2009d,0x442980cb}},	//   терп, _piki, _असती, fla_,
   {{0x7c290b88,0xdb0080cc,0x26c07085,0x7c3b80cd}},	//   nler, lemá, _trio_, nmur,
   {{0x41c9110f,0xec0900ef,0xe2971c99,0xf1c9009d}},	// [8480] रांस, yến_, мат_, रांन,
   {{0x644680ce,0x7c2980cf,0x5ef3000d,0xa3cc80d0}},	//   _wiki, hler, ्छन्_, लाह_,
   {{0x442980d1,0x644680d2,0x7c2980d3,0x683f01d3}},	//   bla_, _tiki, kler, _rīdz,
   {{0x628480d4,0x442980d5,0xe8d600c1,0x442280d6}},	//   prio, cla_, ווער_, _ukk_,
   {{0x7c29038c,0x442080d7,0xa284001c,0x4e931454}},	//   dler, moi_, _سیاو, نشور,
   {{0xa3cc00a5,0x442080d8,0x7bdd01bf,0xa06a147c}},	//   लाव_, loi_, ösun, _мага_,
   {{0x7c2980d9,0x212c0076,0x213e01f7,0x00000000}},	//   fler, _ádh_, _àth_, --,
   {{0x7c296265,0x442080da,0xdb0005fe,0x7c3b80db}},	//   gler, noi_, temà, gmur,
   {{0xc9860cfc,0x34ab2fc2,0x6aa80789,0xdb0b17eb}},	//   муни, _चन्द, कबेर, _pagá,
   {{0x442980dc,0x7c2980dd,0x645e0335,0x7e6280de}},	//   zla_, aler, _otpi, mpop,
   {{0x44290702,0x7c290515,0x442080df,0xca480019}},	//   yla_, bler, koi_, _mời_,
   {{0xca4800ef,0x7c221632,0x4420023b,0x442980e0}},	//   _lời_, _ukor, joi_, xla_,
   {{0x8c431369,0x442980e1,0xdb0b0674,0x442080e2}},	//   _реце, vla_, _tagá, doi_,
   {{0x7c207899,0x7e620a4b,0x442980e3,0x2a690233}},	//   lomr, ipop, wla_, _çaba_,
   {{0x442980e4,0x68120877,0x442080e5,0x00000000}},	//   tla_, sāda, foi_, --,
   {{0x442080e6,0x44290517,0x61ee648b,0x7c2025d9}},	//   goi_, ula_, _albl, nomr,
   {{0x6d5a1e81,0x7e622652,0x00000000,0x00000000}},	// [8490] _ofta, jpop, --, --,
   {{0x442980e7,0x7c290b88,0x68ed00b6,0xca4800fe}},	//   sla_, zler, _řadi, _bời_,
   {{0x442080e8,0x7c2901e8,0x624980e9,0x7c3b013c}},	//   boi_, yler, _džoa, ymur,
   {{0x6d5a80ea,0x44290092,0x44204e18,0x3f1575a4}},	//   _afta, qla_, coi_, ндес,
   {{0x63ad80eb,0xed590f86,0xa3cc074c,0x7c2980ec}},	//   mean, пол_, लार_, vler,
   {{0x63ad80ed,0xed5980ee,0x69dc0149,0x6575023b}},	//   lean, чок_, örel, nazh,
   {{0x7c29074e,0x7c200167,0x7c3b80ef,0x09b70033}},	//   tler, fomr, tmur, জামা,
   {{0x63ad80f0,0x7f85003f,0x69ca80f1,0x7c2001df}},	//   nean, _سلطن, _anfe, gomr,
   {{0x7c29074e,0xdb001f9f,0x00000000,0x00000000}},	//   rler, temá, --, --,
   {{0x63ad10f0,0x7c2980f2,0xe1ff00a5,0xf1d2397e}},	//   hean, sler, _swój_, सायन,
   {{0x7c2901e8,0x317180f3,0xbc6800e3,0x63ad80f4}},	//   pler, _mezz_, _يمكن_, kean,
   {{0x442080f5,0x63ad044c,0xcc5600ca,0xd0fa0142}},	//   xoi_, jean, _טבעי_, פּיר,
   {{0x7bcb80f6,0x63ad80f7,0x6d470018,0x442080f8}},	//   _ingu, dean, _újab, voi_,
   {{0x6575023b,0xba3900c1,0xe8020336,0x31710357}},	//   gazh, _צײַט, _लगवा_, _nezz_,
   {{0x442080f9,0xe1ff00a5,0xa3cc00c3,0x64a380fa}},	//   toi_, _twój_, लाल_, лара,
   {{0xca4800de,0x63ad4115,0xd7210294,0x3d0200aa}},	//   _rời_, gean, ụrịr, _वइसे_,
   {{0x442080fb,0x6f1600a5,0x75f00031,0x68360042}},	// [84a0] roi_, życz, _väzb, gáde,
   {{0x442080fc,0x171b00a1,0x31161acf,0xd5b1020b}},	//   soi_, _מופע, нфес, ốt_,
   {{0x63ad80fd,0x4420002d,0x7bcb0201,0x7ddd2d8a}},	//   bean, poi_, _ongu, _rèsp,
   {{0x63ad378c,0xca4800de,0xa25b016d,0x7e620381}},	//   cean, _vời_, _irôn, tpop,
   {{0x3f9a00a5,0xfbd3030b,0xa2e3008f,0x2bd31da8}},	//   ępu_, थानम, _бояд, थाना,
   {{0x7bcb2025,0x7e6280fe,0x200f0113,0xa25b020b}},	//   _angu, rpop, angi_, _krôn,
   {{0x3f6a1121,0x987e030b,0x7bcb0167,0x7e7c01d3}},	//   _ниво_, _péče_, _bngu, _ārpu,
   {{0xa2c40336,0x22b2022b,0x65750216,0x00000000}},	//   रिप्, _kņk_, zazh, --,
   {{0xa3e804dd,0x7c200407,0x20065ef7,0x7a38075f}},	//   _भवन_, romr, mioi_, мпир_,
   {{0x7bcb80ff,0x7c200501,0x200601e9,0xdc12020e}},	//   _engu, somr, lioi_, rşın,
   {{0x2bb8022d,0x63ad0d0a,0x681201d3,0xa7fd020e}},	//   _आसपा, yean, rādn, msız,
   {{0xc02e00ef,0x9cd700a1,0x7c653a1d,0x63ad1d55}},	//   _điều_, _רואה_, _شامل, xean,
   {{0x09e6204e,0x63ad00ae,0x95cb0cba,0x68360072}},	//   _подн, vean, пува_, xáde,
   {{0xa2c408c0,0x69ca8100,0xa7fd071d,0x70020134}},	//   रिन्, _unfe, nsız, ọcha,
   {{0x63ad22c4,0xa25b0161,0xf484282a,0xb4cb8101}},	//   tean, _crôn, лутн, लमे_,
   {{0x657500dd,0xdb0002b6,0x6836002b,0xa25b03a8}},	//   sazh, remæ, táde, _drôn,
   {{0x63ad0fab,0x6249809e,0x75eb008b,0xa7fd026a}},	// [84b0] rean, _džon, _yüzl, ksız,
   {{0x63ad8102,0x22b2022b,0x00000000,0x00000000}},	//   sean, _dņk_, --, --,
   {{0x63ad8103,0xddc9026a,0xdb0001a5,0x68367136}},	//   pean, _ateş, lemä, sáde,
   {{0x660726f1,0xe5000179,0x200f8104,0x22b205aa}},	//   lijk, ोपरि_, ungi_, _fņk_,
   {{0x44398105,0x236900d3,0xdb0012f1,0x00000000}},	//   _ihs_, mbaj_, nemä, --,
   {{0x6da522d1,0xada5098f,0xdee25d18,0xd65800ca}},	//   тика, такл, роши, עיות_,
   {{0x1fa7059b,0x270d00a5,0xdb0000bc,0x00000000}},	//   _праг, सपुर_, hemä, --,
   {{0xdb000084,0x3035007b,0xc60e00a4,0x00000000}},	//   kemä, _ребё, _सद्य_, --,
   {{0x66070ab2,0x443924e8,0x38600218,0xef652ddc}},	//   kijk, _mhs_, _čira_, ğıdı_,
   {{0x7d7900bf,0x3ea20212,0xdb008106,0x00000000}},	//   _آمار_, _äkta_, demä, --,
   {{0x443902a1,0x9be700d6,0x66078107,0x2fcd0313}},	//   _ohs_, _підк, dijk, _kneg_,
   {{0x7bcb8108,0x6e238109,0x681201d3,0xeab10103}},	//   _ungu, lonb, rādo, _نعت_,
   {{0x26c4030b,0x9f4f0328,0x98a201d3,0xdb001489}},	//   ímo_, ligó_, ākā_, gemä,
   {{0xb5fb0143,0x2fdf0072,0xa25b020d,0x6e230e37}},	//   spán, _loug_, _prôn, nonb,
   {{0x44390967,0xdce300b6,0xb5fb109d,0x2bb81024}},	//   _bhs_, vaně, mpál, _आसमा,
   {{0xa3cc030b,0x3fbc0033,0x6f1e007f,0x00000000}},	//   लाइ_, _অক্ষ, ępcz, --,
   {{0x6e23810a,0x660700e7,0xe61a0396,0x2006007b}},	// [84c0] konb, bijk, _оди_, vioi_,
   {{0xf1aa00bf,0xf1d20789,0xa25b810b,0xa2c40034}},	//   باره_, साधन, _trôn, रिब्,
   {{0x27e0810c,0xdce300b6,0x2fdf05aa,0x63862569}},	//   _koin_, raně, _boug_, _игна,
   {{0x27e0810d,0x4f0a2b16,0xaf120134,0xdd1c00d4}},	//   _join_, мнен_, dụrụ, _náši,
   {{0x6e23810e,0x27e0810f,0x22650094,0xa7fd0367}},	//   fonb, _moin_, čský_, tsız,
   {{0x27e00257,0x2fcd0167,0x27f200f0,0x00000000}},	//   _loin_, _eneg_, _llyn_, --,
   {{0x44390085,0xa7fd0367,0xa37b00aa,0x60260138}},	//   _yhs_, rsız, _klõp, _адва,
   {{0x27e002fd,0xeb9715de,0x0b8a192f,0x6ce3004d}},	//   _noin_, вић_, фски_, ріше,
   {{0xea000019,0x2d963edd,0x78ad0357,0x00000000}},	//   _nhảy_, _арес, _ćava, --,
   {{0xee373bbc,0x27e0036b,0x09d00033,0xdb001322}},	//   _ану_, _aoin_, িস্থ, jemå,
   {{0x5a3300c6,0x6736022b,0x645a8110,0xdb0009af}},	//   рнэт, _azyj, ítil, demå,
   {{0x66070126,0x6a860450,0xdb008111,0x27e0461e}},	//   wijk, _алда, temä, _coin_,
   {{0xa3cc5516,0x4ab6000c,0xea0000de,0x6b820af0}},	//   लाई_, _अनिव, _chảy_, _idog,
   {{0x44397e18,0x27e00527,0xa25b00fd,0xe91804a1}},	//   _shs_, _eoin_, _drôl, _полі_,
   {{0x66070ab2,0x62496826,0x48e30215,0x27e0014b}},	//   rijk, _džol, _војв, _foin_,
   {{0xe7873a8c,0xe41400d6,0xdb1901dc,0x27f200f0}},	//   _руко, адсь, _bawè, _glyn_,
   {{0x6b820010,0x98be07e7,0x9f5f0113,0x00000000}},	// [84d0] _mdog, matı_, _umué_, --,
   {{0x2fcd8112,0x35b5413c,0x98be0491,0x44390313}},	//   _sneg_, _сбор, latı_, _whs_,
   {{0x21a402ec,0x68360618,0x68e802ad,0x6b828113}},	//   риєм, láda, nydd, _odog,
   {{0x6b828114,0x98be0491,0x672d0361,0xb5fb0094}},	//   _ndog, natı_, _kyaj, zpál,
   {{0x6e238115,0x628b33c3,0xdd0100cc,0x68e800f0}},	//   tonb, ágod, _čuđe, hydd,
   {{0x6b825944,0x68e80212,0x00000000,0x00000000}},	//   _adog, kydd, --, --,
   {{0xa0b8194c,0x98be03e0,0x672d0172,0x683600d4}},	//   _игру_, katı_, _lyaj, háda,
   {{0x5f452296,0x68e80150,0x2fcd2f91,0x9f4f8116}},	//   _منزل, dydd, _uneg_, rigó_,
   {{0x63bd8117,0x0a490b91,0x6b820150,0xba251372}},	//   _masn, нзий_, _ddog, лдик,
   {{0x27e08118,0x6b827f33,0x63bd8119,0xa2c41178}},	//   _soin_, _edog, _lasn, रित्,
   {{0x779400bf,0x27e00096,0x27f20146,0x9b952c31}},	//   لیغا, _poin_, _plyn_, _ملات,
   {{0xf64900f5,0x69da022e,0x672d2cd0,0xa25b020d}},	//   _זצ_, ajte, _byaj, _arôm,
   {{0xa9a524ec,0x27e000c2,0x672d0079,0x09df0033}},	//   _билд, _voin_, _cyaj, যোগা,
   {{0x68e80150,0x7bdb0f06,0x63bd014a,0x00000000}},	//   bydd, ljuu, _aasn, --,
   {{0x7ae9811a,0xdb0013f8,0xa25b020d,0x672d0361}},	//   lyet, remå, _drôm, _eyaj,
   {{0x63bd1dd4,0x62490e94,0x6f1b00a7,0xdb1903a9}},	//   _casn, _džom, _oxuc, _pawè,
   {{0x7ae9811b,0xdb1903a9,0x437511c0,0x7afb042c}},	// [84e0] nyet, _bawé, руст, nzut,
   {{0x3c3a023b,0x764b00fd,0x63bd0076,0xdb0b0503}},	//   mëve_, _égyp, _easn, _bagú,
   {{0x98a671a2,0x3c3a00dd,0x63bd00f0,0xa5b7006e}},	//   čiće_, lëve_, _fasn, _גליק_,
   {{0x63bd811c,0xe3b21a37,0xb4e010e9,0x41d2080f}},	//   _gasn, _ارد_, थही_, साहस,
   {{0x3c3a00dd,0x7e2a325f,0x63a4811d,0x42d50138}},	//   nëve_, ніка_, mfin, _кіру,
   {{0x63a4811e,0xa3cc2373,0xdcba013d,0xdb19001c}},	//   lfin, लाक_, ещи_, _gawé,
   {{0xa1161dec,0x98be03a3,0xea0000de,0x3c3a023b}},	//   _صورت, yatı_, _nhạy_, hëve_,
   {{0x3c3a00dd,0x2004811f,0x63a45e8d,0x7ae90350}},	//   këve_, _ummi_, nfin, fyet,
   {{0x68e802e0,0x3c3a023b,0x7ae98120,0x63a401cd}},	//   wydd, jëve_, gyet, ifin,
   {{0x49745566,0x3c3a023b,0x672d0079,0x63a4595e}},	//   шлос, dëve_, _ryaj, hfin,
   {{0xea000028,0x48150f1a,0xbc664c82,0x6ec20034}},	//   _chạy_, имос, _свек, लिवु,
   {{0x68e84a11,0x59d2030b,0x63a414f3,0x68ed01c2}},	//   rydd, ताहर, jfin, _ƙadr,
   {{0x6b7b00f5,0x63bd0995,0x5eb80081,0x68e80150}},	//   _טראנ, _rasn, _আপডে, sydd,
   {{0x63bd00d9,0x68360146,0x65950396,0x672d0350}},	//   _sasn, ráda, јаву, _vyaj,
   {{0x63bd8121,0x81da0033,0x68360094,0x7a3400ee}},	//   _pasn, ়সা_, mádn, làto,
   {{0x59d21e05,0xa3cc0da9,0x75eb01e8,0x68362299}},	//   तावर, लाग_, _müzi, ládn,
   {{0x2ba6244d,0xfba642d4,0x917500ae,0xa29504a1}},	// [84f0] क्या, क्यम, игац, разі,
   {{0xddc95455,0x63a41df2,0x78610174,0x26c90231}},	//   _svež, afin, ịvet, _irao_,
   {{0x7afb028d,0xfaf90138,0x155a00ca,0x273b0032}},	//   zzut, lbūt_, _בכתב, _fàní_,
   {{0xa2950f1e,0x26c9042d,0x7ae900a7,0x63a48122}},	//   _камі, _krao_, yyet, cfin,
   {{0x442b00e7,0xf8c90139,0xe37a00d7,0x00000000}},	//   _ikc_, _asẹ́_, _שרשר, --,
   {{0x7bc70029,0x644f0890,0x7ae98123,0x64570188}},	//   ējum, _hici, vyet, _kuxi,
   {{0x644f8124,0x2c5501d3,0xc21200ca,0x3c3a0052}},	//   _kici, _kādi_, _והם_, zëve_,
   {{0x7afb156a,0x26c90542,0x9990042d,0x6a85008f}},	//   tzut, _orao_, _čaši_, алиа,
   {{0x64570085,0x5fab0789,0xde5900d6,0xa7fd0555}},	//   _luxi, _टॉयल, _разі_, rpıl,
   {{0x644f8125,0x7ae98126,0x7bdb00aa,0x7afb0034}},	//   _lici, ryet, sjuu, rzut,
   {{0x7ae98127,0x387e00bf,0x63a48128,0x7cd91a37}},	//   syet, gstr_, yfin, _جواز_,
   {{0x644f8129,0x3c3a00dd,0x7ae9812a,0xf7461e11}},	//   _nici, tëve_, pyet, иено,
   {{0xaa672d64,0x681200e8,0x6577812b,0x00000000}},	//   _стек, nādi, _bexh, --,
   {{0x3c3a01e5,0xd9451a18,0x644f0029,0x442b01af}},	//   rëve_, _кели, _aici, _akc_,
   {{0x442b02ef,0x3c3a0052,0x00000000,0x00000000}},	//   _bkc_, sëve_, --, --,
   {{0x3ead02e6,0x4aa909d0,0x69c1812c,0x442b01af}},	//   _opet_, _कहाव, ldle, _ckc_,
   {{0x63a4812d,0x26c908a8,0x02064be7,0x683610a8}},	// [8500] rfin, _grao_, азан, ládo,
   {{0x69c1812e,0x6457137f,0x667b00c1,0xe1f745d6}},	//   ndle, _fuxi, _שטיק, агу_,
   {{0x03a61127,0x657c812f,0x63a40970,0x69c100f0}},	//   _кино, marh, pfin, idle,
   {{0x8fa62249,0x3ead00e7,0x657c2e0e,0x2a7f8130}},	//   раде, _bpet_, larh, ksub_,
   {{0xfe461c1b,0x3ead8131,0x681201d3,0x64448132}},	//   андо, _cpet_, gādi, mmii,
   {{0x44328133,0x657c8134,0x64440084,0x3ead0085}},	//   lly_, narh, lmii, _dpet_,
   {{0xeb0e0179,0xa2c40034,0x644f8135,0x69c18136}},	//   ाप्त_, रिव्, _yici, ddle,
   {{0x8aa61dc6,0x317801bf,0x69c18137,0x443200ca}},	//   арод, _herz_, edle, nly_,
   {{0x44328138,0x69c101c0,0x7d0f00a7,0xa25b0231}},	//   ily_, fdle, _əksə, _esôf,
   {{0x2c0b0814,0x44328139,0x69c101cb,0x00000000}},	//   _یعنی_, hly_, gdle, --,
   {{0x245c025b,0x6577023b,0x68360094,0x2360033b}},	//   _ním_, _rexh, rádn, kcij_,
   {{0x2a7f019c,0x68360094,0xfaa6539a,0x65773f0f}},	//   bsub_, sádn, _вадо, _sexh,
   {{0x67013fdd,0x644f813a,0x645703be,0x4432813b}},	//   _लेखक_, _rici, _suxi, dly_,
   {{0x644f813c,0xfaf939c1,0x2b920068,0x6836813d}},	//   _sici, rbūt_, _ایکس, ládl,
   {{0x6ab60782,0x644f813e,0xe7874e08,0x245c0018}},	//   _अनुर, _pici, _купо, _cím_,
   {{0x628d813f,0x26c90019,0xc5f401c2,0x64570212}},	//   trao, _trao_, _ruɓe_, _vuxi,
   {{0x657c0bc6,0xd2510602,0xa2c40473,0x644f2233}},	// [8510] barh, سنا_, रिष्, _vici,
   {{0x2ba6000c,0x644f0150,0xfba60213,0x628d8140}},	//   क्ता, _wici, क्तम, rrao,
   {{0x3ead02dd,0x443275ae,0x644f8141,0x2c5501d3}},	//   _spet_, bly_, _tici, _tādi_,
   {{0xa2c41388,0x442b792c,0x1ab6009f,0x644f0441}},	//   रिश्, _ukc_, _अनूठ, _uici,
   {{0x44298142,0x683d025a,0x7a3d0257,0x69c18143}},	//   moa_, céde, lète, ydle,
   {{0x4429464e,0xc5f403e3,0x681200e8,0xee2100a4}},	//   loa_, _tuɓe_, rādi, यवेध_,
   {{0x22591484,0xa3cc009d,0xde8f0174,0x7a3d17f9}},	//   _husk_, लाच_, nịzi_, nète,
   {{0x44298144,0x5f94385a,0x2a7f8145,0x3ea90428}},	//   noa_, _мист, tsub_, çats_,
   {{0x8d871e49,0x44290634,0x4e940037,0xde8f0174}},	//   _نشان, ioa_, _وشكر, hịzi_,
   {{0x44298146,0xdce3007e,0x4432080f,0xe9d91b4b}},	//   hoa_, sanđ, zly_, уко_,
   {{0x44298147,0x69c18148,0x44320213,0x225900d8}},	//   koa_, rdle, yly_, _lusk_,
   {{0xc5e90089,0x44298149,0x98160037,0x6836291d}},	//   _אד_, joa_, إبدا, rádo,
   {{0x4429814a,0xf3ff0081,0x290b00a5,0xdb096c0b}},	//   doa_, ্কার_, ńca_, rdeó,
   {{0xd999110a,0x7c29086f,0x69dc4478,0xdb1b0558}},	//   _صنعت_, loer, öret, nduí,
   {{0x4429814b,0x443200ca,0x2bbd00a8,0x1da90085}},	//   foa_, tly_, ्यपा, च्यत,
   {{0x442902a7,0x7ddd0c56,0x2bda02d5,0x245c00b6}},	//   goa_, _vèsy, भाया, _vím_,
   {{0x44320054,0x9ad30134,0x77640090,0xd1860036}},	// [8520] rly_, _aịzi, _ifix, йлай,
   {{0x245c000d,0x4432814c,0x51560d62,0xe29700c6}},	//   _tím_, sly_, стау, саф_,
   {{0x4432814d,0xef650702,0x2c5500d9,0x4429814e}},	//   ply_, ğını_, _kādu_, boa_,
   {{0xef65008e,0xea000019,0x7c29084e,0x660e814f}},	//   şını_, _thầy_, joer, libk,
   {{0x3178009e,0x63b60188,0x1aec0081,0x2bbd09b0}},	//   _terz_, meyn, _জেনে_, ्यना,
   {{0x21f600e3,0x63b68150,0x62968151,0x75eb00a7}},	//   _اكسس, leyn, muyo, _füzu,
   {{0xec090028,0x62968152,0x2a6601b9,0x00000000}},	//   yết_, luyo, _stob_, --,
   {{0x8fa320a7,0x63b60188,0x660e00a7,0x00000000}},	//   _насе, neyn, hibk, --,
   {{0x629601e8,0x00000000,0x00000000,0x00000000}},	//   nuyo, --, --, --,
   {{0x660e8153,0x44290a00,0x2d9801df,0x77648154}},	//   jibk, zoa_, _øre_, _afix,
   {{0x7c290f6f,0xe1ff0072,0x44290124,0x00000000}},	//   boer, _otón_, yoa_, --,
   {{0x3137040a,0x62968155,0x442901e9,0x7c29797a}},	//   מנים_, kuyo, xoa_, coer,
   {{0xf1c80789,0x63b64c47,0x44298156,0x41c804f8}},	//   रयान, deyn, voa_, रयास,
   {{0xe1ff0072,0x77640072,0x7bc28157,0xa2ae142e}},	//   _atón_, _efix, _haou, ुबन्,
   {{0x44298158,0x7bc22f8a,0xdcf8389a,0x2d9e02a1}},	//   toa_, _kaou, kavč, _mcte_,
   {{0x7a3d00fd,0x320a03a8,0x63b6008c,0x2bbd00ec}},	//   rète, _amby_, geyn, ्यया,
   {{0x44292050,0x62960f4f,0x8af70092,0xdcf8033b}},	// [8530] roa_, guyo, _çəti, davč,
   {{0x44298147,0xf77f8159,0x660e008c,0xbb3b006e}},	//   soa_, laç_, cibk, רעמי,
   {{0x2bbd00b6,0xd13b58ad,0x97350018,0x4429815a}},	//   ्यमा, уха_, _دکھا, poa_,
   {{0x2d9e284d,0x753a0364,0x9f440154,0x2259007f}},	//   _acte_, ütze, _komè_, _tusk_,
   {{0x539a0054,0x7c29043e,0x201c001f,0x9f4d033c}},	//   _דירו, voer, évia_, _bleá_,
   {{0xdc3c01d3,0x2ba60469,0x7a2f00f3,0x2bbd09a0}},	//   kšēj, क्सा, nøtt, ्यभा,
   {{0x7c29000b,0x7bc265a8,0x0cd70033,0xdddb078e}},	//   toer, _baou, তন্ত, _avuţ,
   {{0x7bc200fd,0xea8900d3,0x61e705db,0x2d9e0216}},	//   _caou, абил_, _hojl, _ecte_,
   {{0x7bc21428,0x0ae60084,0x7c290db1,0x624980e9}},	//   _daou, ждый_, roer, _džov,
   {{0x200f815b,0x8885062a,0xc9a60084,0x7ae60212}},	//   ligi_, олож, овье_, äkta,
   {{0x63b60188,0x995801d3,0xdb090328,0xdc3c00e8}},	//   yeyn, kšņi_, rdeñ, gšēj,
   {{0x200f815c,0xf77f4369,0x69dc0212,0x6296026a}},	//   nigi_, gaç_, örer, yuyo,
   {{0xe9d93c97,0x9f44023b,0xddc201d3,0x3cdf0980}},	//   _вкл_, _romë_, lpoš, _कपडे_,
   {{0xdce8030b,0x63b6008a,0xf3f100de,0x2a6d023e}},	//   _nedě, weyn, ện_, mpeb_,
   {{0x2c5500d9,0x7bc2815d,0x2ba60469,0x63b631ed}},	//   _tādu_, _yaou, क्वा, teyn,
   {{0x69c3815e,0x6296815f,0x6b9b8160,0xa3e50789}},	//   _hane, tuyo, ngug, बॉल_,
   {{0xe29a3947,0x69c38161,0x2c5500d9,0x63b62586}},	// [8540] раз_, _kane, _kāds_, reyn,
   {{0x69c38162,0xea0000ef,0x629642ec,0x63b60092}},	//   _jane, _thấy_, ruyo, seyn,
   {{0x69c334d2,0x7f862268,0x7e6901ff,0xd793001c}},	//   _mane, قلان, _atep, _علیخ,
   {{0x69c302a7,0xd7dd009d,0x629679ea,0x200f3ba5}},	//   _lane, यायच, puyo, gigi_,
   {{0x7bc28163,0x2a6d023e,0xdcf80e9e,0xb5fb0094}},	//   _raou, jpeb_, ravč, rpáv,
   {{0x62860cc9,0x7bc23ca6,0xdc8a015f,0xb5fb00d4}},	//   _ivko, _saou, асил_, spáv,
   {{0xb5fb3536,0xf77f026a,0xac94007b,0xd7ca00a4}},	//   mpát, yaç_, чайш, ियाच,
   {{0x7a340472,0x69c38164,0x62840138,0x6b9b8165}},	//   màti, _aane, osio, ggug,
   {{0x62848166,0x69c38167,0x2fc60513,0xfba60966}},	//   nsio, _bane, mdog_, क्षम,
   {{0x094a08c3,0x3ebb040a,0xc33300a1,0x62840150}},	//   ични_, _דצמב, ווח_, isio,
   {{0x69c38168,0x61e302e2,0x5fcf0096,0xf8160023}},	//   _dane, önli, _सोडल, ước_,
   {{0x62848169,0x2fc62839,0x2ba60ff9,0xc5f403e3}},	//   ksio, ndog_, क्शा, _ruɓa_,
   {{0x3ea6816a,0x0aba1850,0x7a2f038c,0x6b8000f9}},	//   ntot_, _خطاب_, tøtt, mamg,
   {{0x6284816b,0x2ba60e19,0x200f083e,0x3ea601d3}},	//   dsio, क्रा, zigi_, itot_,
   {{0xd37b816c,0x09ac0081,0xf77f05fe,0x6286169c}},	//   ича_, _কোথা, paç_, _avko,
   {{0x248d816d,0x683f00d9,0x6b800051,0x3ea60d1f}},	//   čem_, _lūdz, namg, ktot_,
   {{0x2bbd0835,0x27e9816e,0x4abc0789,0x78b30106}},	// [8550] ्यता, _ioan_, ्टिव, čevš,
   {{0x69c30933,0x27e900de,0xdb00016d,0xef65071d}},	//   _xane, _hoan_, lemó, ğımı_,
   {{0x7e6945da,0x7fd50138,0xef650367,0x60ce00b3}},	//   _step, зілі, şımı_, _crbm,
   {{0x27e9816f,0xdb0b0154,0x9ed9007b,0x2fc60113}},	//   _joan_, _magò, ймет_, gdog_,
   {{0x200f8170,0x6b800009,0x15ff0101,0x27e96a49}},	//   rigi_, damg, _उतार_, _moan_,
   {{0xdd910c5e,0x8e0800d6,0x27e900ca,0xa25b0031}},	//   روع_, онів_, _loan_, _drôt,
   {{0x69c38171,0x6b800134,0x69c5003e,0xc1820103}},	//   _rane, _ịgab, _óhei, _سینٹ,
   {{0x69c300cd,0x251c00c1,0x6458028d,0xcfb4008f}},	//   _sane, יווא, _èvie, _обсъ,
   {{0x68360094,0x3ebf0479,0x7e698172,0xdce101d3}},	//   sádk, _usut_, _utep, _pelē,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c3007a,0x2fc4005c,0x2a6d023e,0x27e90154}},	//   _vane, _yamg_, speb_, _boan_,
   {{0x69c38173,0x2c63026a,0x3f9d8174,0x62848175}},	//   _wane, _gıda_, ngwu_, ysio,
   {{0x27e98176,0x24982ead,0x68360131,0x00000000}},	//   _doan_, wurm_, nádi, --,
   {{0x2c5500d9,0x63af0120,0x24986255,0x5747022a}},	//   _tāds_, _abcn, turm_, язям_,
   {{0x2eb80378,0x79810172,0x33f60686,0x8cce0034}},	//   _इन्त, malw, пчас, थियो,
   {{0x628405a7,0x683d8177,0x69a10d7e,0x27e9033c}},	//   tsio, lédn, _खाडी, _goan_,
   {{0x2bad02e8,0x6284013f,0x9f442027,0x26c00239}},	// [8560] झ्या, usio, _tomé_, _usio_,
   {{0x798141f5,0x2bb8218b,0x200d0161,0xada60031}},	//   nalw, _आस्थ, _amei_, _krúž,
   {{0x628432b8,0xfbbd1efb,0x201c001f,0xd625450f}},	//   ssio, ्याम, évio_, _تعيي,
   {{0x61fe8178,0x657e01af,0x62848179,0x7981817a}},	//   shpl, _heph, psio, halw,
   {{0x78820018,0xb5fb3859,0x657e0201,0x645e817b}},	//   _kívá, mpár, _keph, _hupi,
   {{0x645e817c,0x3ea633e2,0x67360084,0x6f02817d}},	//   _kupi, rtot_, _myyj, rzoc,
   {{0x3ea6817e,0xa2c4022d,0x324300d6,0x79814aeb}},	//   stot_, रिक्, _черг, dalw,
   {{0x657e817f,0xdcf80325,0x645e2d3b,0xdb00002b}},	//   _leph, gavā, _mupi, xemó,
   {{0x20070052,0x798100f0,0x68360231,0xcb670da5}},	//   ënie_, falw, cádi, чање_,
   {{0x657e7a4f,0xeaaf5e51,0x3958038c,0x3dc50150}},	//   _neph, اعي_, ørs_, _galw_,
   {{0x6d5a019c,0xb5fb0103,0x645e0138,0xdb0000b3}},	//   _igta, kpár, _nupi, gemò,
   {{0x1ae68180,0x20070b68,0xe7db0033,0x00000000}},	//   _ноем, énix_, দস্য, --,
   {{0xa3c01152,0x79813944,0x645e084e,0x27e98181}},	//   ंजन_, balw, _aupi, _voan_,
   {{0x09e3468c,0x657e8182,0x645e26e3,0x798101ee}},	//   _почн, _ceph, _bupi, calw,
   {{0x69c802ad,0x27e900de,0x67248183,0x6d5a0270}},	//   mdde, _toan_, _exij, _mgta,
   {{0x645e70a3,0x69c88184,0x03c40cba,0xc6a700d3}},	//   _dupi, ldde, нсум, _ерои,
   {{0x32558185,0x6d5a0188,0x69c88186,0x683d020d}},	// [8570] двар, _ogta, odde, lédo,
   {{0x69c80d23,0x6d5a00f9,0x645e0350,0x00000000}},	//   ndde, _ngta, _fupi, --,
   {{0x645e8187,0xdb0b003e,0x69c820a8,0x98af007e}},	//   _gupi, _lagð, idde, čaće_,
   {{0x68360161,0x657e3b3f,0x79810060,0x3f152cf1}},	//   tádi, _zeph, zalw, мдес,
   {{0x63ad7911,0x69d801a2,0x6249809e,0x6d5a061d}},	//   mfan, _onve, _džor, _bgta,
   {{0x63ad8188,0x68361e6f,0xfe701790,0xa2f62252}},	//   lfan, rádi, ادن_, _חמשה_,
   {{0x64580257,0x63ad0051,0x79818189,0x38690031}},	//   _évit, ofan, valw, _čaro_,
   {{0xeb992de9,0x69d842e5,0x63ad818a,0x2bda1f77}},	//   ции_, _anve, nfan, भाषा,
   {{0x79810735,0x63ad818b,0x06e30033,0x680b0034}},	//   talw, ifan, নৈতি, będz,
   {{0x7d180076,0x9ce700d3,0x7e7b063d,0xada60206}},	//   éasú, _нцел, _iwup, _prúž,
   {{0x39453e04,0x02ba30a8,0xf8af09e5,0x7e7b028d}},	//   ьног, _उन्न, اکت_, _hwup,
   {{0xe73a0e18,0x657e3e4d,0x645e818c,0x7e7b0294}},	//   жем_, _seph, _rupi, _kwup,
   {{0x7bd90134,0x63ad818d,0x7c2d706b,0x645e3f43}},	//   _inwu, dfan, čard, _supi,
   {{0x2bbd0693,0x4abc04f1,0x63ad084e,0x7bc9342c}},	//   ्यवा, ्टरव, efan, ldeu,
   {{0x64a31248,0x63ad6ecf,0x683d014b,0x6aa9093e}},	//   кара, ffan, cédo, ltef,
   {{0x7bc9818e,0x04431824,0x6724023e,0x645a0428}},	//   ndeu, весн, _txij, ítiq,
   {{0x6aa9183b,0xc1ea4e42,0xa1c637fa,0x27440139}},	// [8580] ntef, одаж_, мбад, _dèní_,
   {{0x26d20193,0x3f8d00ee,0x7f5b0372,0x63ad250c}},	//   _iryo_, _adeu_, _aguq, afan,
   {{0x106a16fa,0x7640030b,0x7bd90294,0x7e7b0372}},	//   цией_, ůmys, _onwu, _awup,
   {{0x680b007f,0x00000000,0x00000000,0x00000000}},	//   wędz, --, --, --,
   {{0x69c814ef,0x6d41061d,0x6aa902ef,0x7bc95486}},	//   ydde, _azla, jtef, ddeu,
   {{0x7bd90134,0xb8060033,0x7f5b0372,0x4422007b}},	//   _anwu, োকিত_, _eguq, _hjk_,
   {{0xdb0b0102,0x7e7b818f,0xd8390106,0x7bc90629}},	//   _sagð, _ewup, luče_, fdeu,
   {{0x7bc98190,0x26d20172,0x6aa9526d,0x00000000}},	//   gdeu, _oryo_, ftef, --,
   {{0x7e7b0134,0xe7dd00a4,0x680b007f,0x00000000}},	//   _gwup, यासप, pędz, --,
   {{0x765f02e7,0x44220085,0xe7ac0285,0x00000000}},	//   _ruqy, _ljk_, ट्सप, --,
   {{0x69c80150,0x63ad8191,0x44220167,0x26d28192}},	//   rdde, yfan, _ojk_, _aryo_,
   {{0x7e608193,0xb8e600a5,0x628b0103,0x00000000}},	//   _kump, _उन_, ágok, --,
   {{0xd83907c0,0x7c222767,0x19945951,0x26d201cb}},	//   juče_, _ijor, _заля, _cryo_,
   {{0xc1c8033a,0x7c2d0ca7,0x69d88194,0x7e608195}},	//   रयोग, čare, _unve, _mump,
   {{0x7e6014f7,0x63ad0088,0x395c002b,0x55588196}},	//   _lump, tfan, _igvs_, даря_,
   {{0xeac80028,0x60c901d3,0x64460090,0x63ad8197}},	//   _kỹ_, _ņemo, _chki, ufan,
   {{0x63ad8198,0x7e6012b7,0x4caa0081,0x26c500d9}},	// [8590] rfan, _nump, কিটু, ālos_,
   {{0xeac80028,0x7c228199,0x63ad819a,0xd71b02d5}},	//   _mỹ_, _ljor, sfan, नपीठ_,
   {{0x63ad819b,0x22580691,0x62960513,0xf1a400e5}},	//   pfan, _dirk_, aryo, ъртн,
   {{0x6615819c,0xd83900e7,0x5fcf02d5,0x7c220350}},	//   lizk, buče_, _सोशल, _njor,
   {{0x7e60819d,0x644d819e,0x6d410034,0xef190090}},	//   _cump, mmai, _szla, _beża_,
   {{0x7c22819f,0xc27a00ca,0x00000000,0x00000000}},	//   _ajor, _מרשי, --, --,
   {{0x271b0b61,0xdce300d9,0x644d6e61,0x5c5500d3}},	//   नपुर_, manī, omai, нтиф,
   {{0x6aa9017a,0x7bc934eb,0x66150062,0x7f5b0372}},	//   ttef, udeu, hizk, _uguq,
   {{0x7bc981a0,0x4ea4098f,0x7c2281a1,0x7e6081a2}},	//   rdeu, _арха, _djor, _gump,
   {{0x89a9036a,0x644d0037,0x6f2500ae,0x7bc92b13}},	//   чков_, hmai, ărcă, sdeu,
   {{0x07a600f7,0xf1b200c1,0x6d4181a3,0x66150a00}},	//   нанн, נסט_, _uzla, dizk,
   {{0x7c2220ab,0x60da0103,0x00000000,0x00000000}},	//   _gjor, _átme, --, --,
   {{0xdce10138,0xaffa006e,0x644d81a4,0x00000000}},	//   _pelė, פּטי, dmai, --,
   {{0x6a170068,0xd8390039,0x3ea20149,0x64460052}},	//   _تبصر, vuče_, _åkte_, _shki,
   {{0x4422005c,0x2ba6277c,0x00000000,0x00000000}},	//   _pjk_, क्का, --, --,
   {{0x7c3b0bb6,0x22586961,0x6296022b,0xa7fd00a7}},	//   nlur, _sirk_, tryo, lqın,
   {{0x22580138,0x7c3b81a5,0x66150062,0x130a013f}},	// [85a0] _pirk_, ilur, bizk, чнай_,
   {{0xe7ac1344,0x644d81a6,0x167700ca,0xf3ff0231}},	//   ट्रप, amai, _רגיל_, _elã_,
   {{0x644d81a7,0x2258710c,0xdcfa022b,0x7c3b484b}},	//   bmai, _virk_, _petč, klur,
   {{0x4ea673e0,0x644d03a9,0xd8396b69,0x00000000}},	//   ерка, cmai, puče_, --,
   {{0x442081a8,0x44320fa0,0x61f3038c,0x20070052}},	//   mni_, moy_, ådlø, ënia_,
   {{0x44320256,0xf2df00de,0xf487001c,0x7c2201cb}},	//   loy_, _ngây_, _تایی, _sjor,
   {{0x442081a9,0x6143013f,0xeac80019,0x7e6081aa}},	//   oni_, _бера, _sỹ_, _wump,
   {{0x442081ab,0x2bba0080,0x443281ac,0x7e6056f4}},	//   nni_, ساعة_, noy_, _tump,
   {{0xe7e40640,0x61ee181a,0x7e6007ac,0x701700ca}},	//   गाना_, _kobl, _uump, _נחמד_,
   {{0xfce6816c,0x4432265b,0x442081ad,0x3f860154}},	//   _позо, hoy_, hni_, laou_,
   {{0x44207825,0x443200a6,0x61ee4acf,0x7c3b18f8}},	//   kni_, koy_, _mobl, blur,
   {{0x4432411b,0x7c3b5f7a,0x644d0124,0x27ff81ae}},	//   joy_, clur, xmai, óun_,
   {{0xd6d82f1f,0x443281af,0x66153c21,0x00000000}},	//   нтр_, doy_, tizk, --,
   {{0x442081b0,0x6b8206a8,0x80d00179,0x63a600d7}},	//   eni_, _heog, सटाइ, _ackn,
   {{0x44200102,0xa4d881b1,0x661581b2,0x443200fc}},	//   fni_, ндру_, rizk, foy_,
   {{0x442018ba,0x493b00a1,0x443281b3,0x61ee009c}},	//   gni_, _מגוו, goy_, _aobl,
   {{0x61ee4a11,0x236981b4,0x644d7c6b,0x6587002d}},	// [85b0] _bobl, rcaj_, rmai, _пынз,
   {{0x442081b5,0x6b8281b6,0x61ee81b7,0x64580036}},	//   ani_, _leog, _cobl, _èvin,
   {{0x442081b8,0x443281b9,0x61ee81ba,0x69ca0134}},	//   bni_, boy_, _dobl, _mafe,
   {{0x44201197,0x69ca81bb,0x00000000,0x00000000}},	//   cni_, _lafe, --, --,
   {{0x539a09c1,0x6abc07e2,0x69a1009d,0x6da50208}},	//   _קישו, ्टोर, _खाली, вила,
   {{0x44d101b3,0xdce80029,0x69ca81bc,0x61ee81bd}},	//   _ką_, _nedē, _nafe, _gobl,
   {{0x6b821386,0x44d181be,0x7c3b00ae,0xe7e4046e}},	//   _beog, _ją_, tlur, गामा_,
   {{0xa158116d,0xbbbd2183,0xdce1020a,0x69ca026d}},	//   _часу_, ्येक, _află, _aafe,
   {{0x2fc000aa,0x9f4400ee,0x7c3b0212,0x6b8281bf}},	//   õige_, _gomà_, rlur, _deog,
   {{0x442081c0,0x2bd102d5,0x7c3b81c1,0x00000000}},	//   zni_, _दोरा, slur, --,
   {{0xd7dd0454,0x7c3b81c2,0x44320c23,0xe7dd0096}},	//   यांच, plur, yoy_, यांप,
   {{0x5b150c0d,0x6b8221ad,0x2d872fa2,0x629f0060}},	//   _имет, _geog, lane_, kuqo,
   {{0x25de11d7,0x2d8700ae,0xa91c0206,0x7bcb033c}},	//   खाली_, oane_, baľo, _iagu,
   {{0x442081c3,0xa7fd01d4,0x7bcb81c4,0x69ca0129}},	//   wni_, qqın, _hagu, _gafe,
   {{0x59a6007d,0x44320081,0x7bcb81c5,0x2aab01c5}},	//   _खातर, toy_, _kagu, løb_,
   {{0x2d870a44,0x442081c6,0x6b8208a8,0x61ee81c7}},	//   hane_, uni_, _xeog, _sobl,
   {{0x61ee81c8,0x2d874f39,0x6b84007a,0x660600c2}},	// [85c0] _pobl, kane_, _õige, _аппа,
   {{0x7bcb81c9,0x9f440428,0x443281ca,0x60d50034}},	//   _lagu, _romà_, soy_, _brzm,
   {{0x2d8781cb,0x443202c9,0x60c700b3,0x64580036}},	//   dane_, poy_, _csjm, _èvio,
   {{0x7bcb81cc,0x442081cd,0x2aab02b6,0xef1a00c2}},	//   _nagu, qni_, køb_, мме_,
   {{0xa2c1000f,0xe7aa02b0,0x2d8781ce,0x7e2a04a1}},	//   रौद्, _कानप, fane_, міка_,
   {{0x63a481cf,0x2d8781d0,0x998c00b6,0x61ee00cc}},	//   lgin, gane_, vodů_, _uobl,
   {{0x7bcb81d1,0x6abc05a4,0x69ca81d2,0xc0e30219}},	//   _bagu, ्ट्र, _rafe, _корк,
   {{0x63a481d3,0x69ca81d4,0x25ad7a52,0xab5d007f}},	//   ngin, _safe, đeli_, jeżd,
   {{0x5a342457,0xf41309c1,0x67ff00dd,0x7bcb81d5}},	//   лнит, יפה_, _bëjn, _dagu,
   {{0x2d8781d6,0x683d81d7,0xbd8a001c,0xdb1e003e}},	//   cane_, médi, _آنان_, _þvíl,
   {{0x3f840113,0xde880129,0x683d014b,0x798303a8}},	//   _kemu_, lị_, lédi, _denw,
   {{0x3f8481d8,0x7bcb81d9,0x63a401c0,0x798318f0}},	//   _jemu_, _gagu, jgin, _eenw,
   {{0x44d10d1b,0x69ca0305,0x8a060423,0x3f8481da}},	//   _są_, _tafe, _изде, _memu_,
   {{0x7bc00006,0xb60202c6,0x3f8481db,0x6aa00027}},	//   lemu, _žáro, _lemu_, mumf,
   {{0x6d5c0181,0x20062eb4,0x7bcb81dc,0xde880174}},	//   _úrad, khoi_, _yagu, hị_,
   {{0x2d8781dd,0x7bc00f8b,0x2ba640c1,0x63a4243b}},	//   zane_, nemu, क्चा, ggin,
   {{0x2d8781de,0x36d581df,0x38690995,0xde880174}},	// [85d0] yane_, _сопр, _čari_, jị_,
   {{0x44d116e0,0x26c90ca7,0x2d8781e0,0x7bc081e1}},	//   _tą_, _isao_, xane_, hemu,
   {{0x7bc081e2,0x21640ef7,0xa37b0131,0xcfb10033}},	//   kemu, ртуг, _anõe, _ঘোষন,
   {{0x2d8781e3,0xf8b307a6,0x3f8404eb,0x7bc081e4}},	//   wane_, ישע_, _cemu_, jemu,
   {{0x539a0054,0x2d877c68,0x645d00a6,0x6aa003d6}},	//   _אירו, tane_, _iisi, jumf,
   {{0x7bcb81e5,0x645d81e6,0x3dcc0150,0x79880194}},	//   _sagu, _hisi, _cadw_, jadw,
   {{0x2d8781e7,0x645d7b15,0x3f84039f,0x00000000}},	//   rane_, _kisi, _femu_, --,
   {{0x7bc081e8,0x645d81e9,0x2bda009d,0x44390022}},	//   gemu, _jisi, भागा, _jks_,
   {{0x2d8781ea,0x798300f0,0x5f3800ae,0x7a3d0428}},	//   pane_, _penw, _аптя_, lèti,
   {{0xf99100e3,0x443947ea,0x7bcb4864,0x3dcc0150}},	//   حبة_, _lks_, _wagu, _gadw_,
   {{0x7bcb81eb,0x63a41b16,0x7a3d0428,0xa2ca81ec}},	//   _tagu, ygin, nèti, _सैन्,
   {{0x645d81ed,0x2d850f56,0x7bcb0350,0xb21b0537}},	//   _nisi, _hele_, _uagu, _kvæs,
   {{0xa3e7178d,0x63a40555,0xf4090033,0xe9ce208b}},	//   पान_, vgin, রচার_, _лк_,
   {{0x64a63097,0x2d8581ee,0x645d81ef,0x96635833}},	//   лага, _jele_, _aisi, скре,
   {{0x69c181f0,0x2d8581f1,0x5e5600c1,0x63a418f0}},	//   mele, _mele_, טישע_, tgin,
   {{0x69c181f2,0x2d8581f3,0x63a40138,0x645d81f4}},	//   lele, _lele_, ugin, _cisi,
   {{0x645d81f5,0xe29781f6,0x63a481f7,0x628d019c}},	// [85e0] _disi, лат_, rgin, gsao,
   {{0x69c13264,0x645d75c5,0x443981f8,0x3f842aea}},	//   nele, _eisi, _eks_, _semu_,
   {{0x645d81f9,0x34aa2976,0x5a1600c1,0x27e00559}},	//   _fisi, _явно_, נקען_, _knin_,
   {{0x69c181fa,0x645d81fb,0xf3f100de,0xf65f00f2}},	//   hele, _gisi, ệt_, mvær_,
   {{0x69c181fc,0x2d8581fd,0x877b00c1,0x765e81fe}},	//   kele, _bele_, גאני, _kipy,
   {{0x2d850a29,0x69c181ff,0x645d2824,0x765e0051}},	//   _cele_, jele, _zisi, _jipy,
   {{0x3f84263e,0x69c18200,0x7bc05794,0x2d850c97}},	//   _temu_, dele, temu, _dele_,
   {{0x683d8201,0x29180037,0x9bf400d3,0x682807e7}},	//   pédi, úram_, рзич, yıda,
   {{0x20048202,0x69c18203,0xb21b052f,0xcff700ca}},	//   _ilmi_, fele, _ivær, _עצמה_,
   {{0x69c13b7a,0x7bc08204,0x27e08205,0xdcfa00d3}},	//   gele, semu, _anin_, _cetă,
   {{0x7bc0005c,0x79880150,0x27e000bd,0x6e3a4ca8}},	//   pemu, radw, _bnin_, _iktb,
   {{0x3157193b,0x2d8504a3,0x00000000,0x00000000}},	//   טיין_, _zele_, --, --,
   {{0xcaf6012b,0x645d7bff,0x765e010a,0xa7fd00a7}},	//   _حساب, _risi, _bipy, qqım,
   {{0x645d37e5,0x6828008b,0x75eb026a,0x7afd13c8}},	//   _sisi, rıda, _yüzy, øste,
   {{0x44398206,0xab5d03e5,0xe4e40c10,0x765e00f0}},	//   _pks_, reże, бітн, _dipy,
   {{0x33750c63,0x645d8207,0xddc27a52,0xe7870284}},	//   ргар, _qisi, jpož, _суко,
   {{0x52151d64,0x65950a8e,0x26c903d6,0x20070052}},	// [85f0] адат, _капу, _usao_, ënim_,
   {{0x947509b4,0x7a3d05fe,0x765e0027,0x98a80d77}},	//   _نگرا, tèti, _gipy, _कमाए,
   {{0x2d8514b1,0x44398208,0x628d007b,0x00000000}},	//   _rele_, _tks_, ssao, --,
   {{0x69c18209,0x2d85820a,0xe8d700ca,0x4439820b}},	//   zele, _sele_, טובר_, _uks_,
   {{0x2d85820c,0xdee52b49,0x69c1820d,0x66f7022d}},	//   _pele_, роли, yele, ुनिक_,
   {{0x2bda33dc,0x69c13531,0x20040092,0xb8820579}},	//   _मोबा, xele, _elmi_, _číns,
   {{0x2d85820e,0x7e71820f,0xd83900e7,0x0638006e}},	//   _vele_, _žepč, jučo_, אנגט_,
   {{0xd6f7007d,0x67ff023b,0xdcfa00ae,0x92e70033}},	//   ुनाथ_, _bëjm, _setă, বনী_,
   {{0x69c18210,0x2d858211,0x80040c79,0xbda70cc8}},	//   tele, _tele_, _учре, _محاو,
   {{0x7c875bc7,0x2ba702e8,0x27e003e5,0x2ef44460}},	//   _буде, _गावा, _snin_, _узур,
   {{0xd9453097,0x69c18212,0x7cdc020a,0xb4c400aa}},	//   рени, rele, _cără, _एने_,
   {{0x78a18213,0x7cdc078e,0x00000000,0x00000000}},	//   rulv, _dără, --, --,
   {{0x24860220,0x09e52cde,0x290c007f,0x44240b12}},	//   _ňom_, _волн, azda_, _ım_,
   {{0xcaf40018,0x78a15cfe,0x3e6b00f3,0xd8390234}},	//   _دسمب, pulv, _møt_, vrče_,
   {{0x7afb00a7,0x765e0239,0x18a51141,0x4416433f}},	//   lyut, _vipy, _тайм, афат,
   {{0x3ced0d1b,0x00000000,0x00000000,0x00000000}},	//   _अपने_, --, --, --,
   {{0x7afb15d2,0xddc2042d,0x883b00ca,0x765e00f0}},	// [8600] nyut, vpož, _בתקו, _tipy,
   {{0xb21b1484,0xe1ff8214,0x9359718e,0xf65f13b9}},	//   _svær, _stór_, урсу_, svær_,
   {{0x61fe0b77,0x661c8215,0x6f660831,0x1da900ec}},	//   rkpl, mirk, авез, च्छत,
   {{0x661c36c6,0x7afb0d1f,0x2c6a009c,0xa3e70285}},	//   lirk, kyut, _rùd_, पाण_,
   {{0xdfcf00e3,0x683d0257,0x00000000,0x00000000}},	//   بين_, cédu, --, --,
   {{0x27350023,0xd0b300a7,0x661c8216,0x7ae901ff}},	//   ụng_, hşət, nirk, dxet,
   {{0x6da31d2e,0xb21b052f,0x6ce60120,0x49150285}},	//   ција, _tvær, ріле, _फेलो_,
   {{0x661c005a,0x6d480094,0x8fa38217,0x77640372}},	//   hirk, _vzda, _масе, _ngix,
   {{0x15f806e4,0x6da65a65,0xa3e7034d,0x7cdc020a}},	//   ुसार_, _виза, पात_, _sără,
   {{0x3860009c,0x7cdc00ae,0x99664460,0x00000000}},	//   _aiir_, _pără, штил, --,
   {{0x885900d3,0xd4910023,0xddc9374d,0x3860041c}},	//   лиос_, ời_, _uteš, _biir_,
   {{0xb8860065,0xeb972440,0x290c8218,0x7afb0079}},	//   _atíò, _виц_, rzda_, byut,
   {{0x661c02e7,0x3860026d,0xab6600b7,0x00000000}},	//   firk, _diir_, _etüü, --,
   {{0x661c8219,0x18660831,0xfa3300cd,0x2bda0006}},	//   girk, _књиг, _ورود, _मोता,
   {{0xedf407e2,0xe65400d6,0x6605025b,0x3860821a}},	//   _अवैध_, івсь, _vlhk, _fiir_,
   {{0x539800d6,0x672d023e,0xd3781229,0xab5d0034}},	//   ився_, _txaj, ичу_, leża,
   {{0x24580084,0x21670606,0x661c821b,0xe1670291}},	// [8610] рать_, атег, birk, ађен,
   {{0x661c821c,0x3d17007a,0x683d6818,0x00000000}},	//   cirk, _भइले_, rédu, --,
   {{0x35f800cd,0x92e70081,0x2f740294,0x3e6b0120}},	//   _خريد_, বনে_, _ịnọ_, _søt_,
   {{0x9ad30174,0x4e950037,0xf1e000b6,0x00000000}},	//   _dịji, مشتر, नाउन, --,
   {{0x645a821d,0x201c05fe,0xc257001c,0x1de2136b}},	//   ïtie, èvia_, _نخست, पांत,
   {{0xee3802ec,0x72050037,0x442b020b,0x00000000}},	//   ані_, _اوسم, _hjc_, --,
   {{0x93fb009d,0x70946ceb,0xa19400d3,0x00000000}},	//   _एकाच_, _марф, _фасч, --,
   {{0x7afb821e,0x661c821f,0x7ae91164,0x5fcf007a}},	//   tyut, zirk, txet, _सोचल,
   {{0xb5fb0072,0x7d0600a7,0x442b014b,0x201d0aa9}},	//   bpáx, _əksi, _mjc_, miwi_,
   {{0x7ae908a8,0x201d8220,0x7afb0124,0x1a055c34}},	//   rxet, liwi_, ryut, спом,
   {{0x661c3f88,0x7afb0063,0x7e690350,0xe7e400a4}},	//   virk, syut, _huep, गाला_,
   {{0x661c8221,0x7e690051,0x68fc0b81,0x201d0066}},	//   wirk, _kuep, ørda, niwi_,
   {{0x7e610084,0x661c8222,0x41c700a4,0x00000000}},	//   _kilp, tirk, रजास, --,
   {{0x998500e3,0xa2db030b,0x6d418223,0xbb3a006e}},	//   _الثو, निन्, _kyla, _געני,
   {{0x644f01b9,0x201d8224,0x661c8225,0xa5078226}},	//   _bhci, kiwi_, rirk, бера_,
   {{0x644f3430,0x69de0428,0xf3f10023,0x38b18227}},	//   _chci, _òper, ệp_, már_,
   {{0x38b1595f,0x661c282c,0x63b602ad,0x3ebf8228}},	// [8620] lár_, pirk, rfyn, _nput_,
   {{0xe3b20979,0x6d41026a,0x442b0027,0xd5a40103}},	//   _کرد_, _oyla, _ejc_, _بلدی,
   {{0x6d418229,0x7c2d0087,0x04b6008f,0x38b1822a}},	//   _nyla, čarj, _успя, nár_,
   {{0xddc2003d,0x7e61009c,0x44d8033d,0x4f0a036a}},	//   spoż, _ailp, _ič_, лнен_,
   {{0x248d00d9,0x6d410511,0x38b11e6f,0x44d800e7}},	//   ņemt_, _ayla, hár_, _hč_,
   {{0x44d8033a,0x6444822b,0x6d41822c,0x26c00134}},	//   _kč_, llii, _byla, _mpio_,
   {{0x38b13e07,0xdd99004d,0x64445e37,0xa0a33c75}},	//   jár_, рші_, olii, _нард,
   {{0x6d4102ad,0x7bf8090f,0x3a741312,0x8aa60cc6}},	//   _dyla, рнир_, олир, брод,
   {{0x44d806a3,0xa3e002d5,0xaf063a69,0x93fb00ca}},	//   _lč_, _दफन_, _упал, טלקי,
   {{0x98b80396,0x3ea606a8,0x2fc603dc,0x7afd0f14}},	//   алот_, muot_, leog_, østa,
   {{0xeb9a1ac8,0x2cbe0085,0x26c00143,0x644400aa}},	//   _бие_, _uptd_, _apio_, klii,
   {{0xfaa601b3,0x394201d3,0x2fc60076,0x7e612502}},	//   _гадо, āks_, neog_, _zilp,
   {{0xab5d00a5,0xa3e70176,0x3ea6822d,0xde8f0174}},	//   leżn, पास_, nuot_, gịhi_,
   {{0x8627333f,0x9f440139,0x6e240037,0x201d822e}},	//   сьме, _bomú_, éibh, ziwi_,
   {{0x61f51fe8,0x9f4405fe,0x555900e5,0x6d41822f}},	//   _rozl, _comú_, равя_, _xyla,
   {{0x937900ae,0x61f50555,0x44d8022b,0x93f600a7}},	//   рбат_, _sozl, _dč_, _şərə,
   {{0x7a3d8230,0xa3ba007a,0xe3b00037,0x7cff0032}},	// [8630] mètr, _आउर_, عرف_, _kàrú,
   {{0x44d80c56,0x32078231,0x21673aa7,0x9f440139}},	//   _fč_, óny_, стаг, _fomú_,
   {{0x201d8232,0x61f50117,0x7e6900ed,0x64447803}},	//   tiwi_, _vozl, _suep, blii,
   {{0x7e6102e3,0x6d4116cf,0x64440188,0x248d01d3}},	//   _silp, _ryla, clii, ņems_,
   {{0x8d6509fe,0x44298233,0x38b14668,0x7e6946b4}},	//   овле, mna_, zár_, _quep,
   {{0x443b8234,0xdc990e06,0x201d0051,0xa3e70096}},	//   loq_, атиш_, siwi_, पाव_,
   {{0xd7aa1349,0xcc860423,0xfbda0409,0x2bda1152}},	//   _कालच, обще_, _मोहम, _मोहा,
   {{0x6b800124,0x251c006e,0xe7d9030b,0x6b8400bc}},	//   gbmg, טווא, _बोलप, _õigl,
   {{0xab292277,0x7e610b81,0x34c6009f,0x3ebf0095}},	//   ропа_, _tilp, _लन्द, _uput_,
   {{0x44298235,0x38b18236,0x3f8f8237,0x3ea00037}},	//   hna_, tár_, lagu_, áite_,
   {{0x29030224,0x442932a7,0xd7ea8238,0x798a05aa}},	//   ája_, kna_, амне_, _defw,
   {{0x3ea0011d,0x2ca78239,0x290b00a5,0x38b1823a}},	//   šite_, mund_, ąca_, rár_,
   {{0x7c3b823b,0x2ca70bab,0x38b1823c,0x29030087}},	//   mour, lund_, sár_, šja_,
   {{0x44d8823d,0x386a0037,0x38b1823c,0x6b8b823e}},	//   _pč_, úirí_, pár_, _hegg,
   {{0x4429823f,0x7c298240,0x3f8f01e9,0xdb190154}},	//   fna_, oner, kagu_, _gawò,
   {{0x44298241,0x68360181,0xf1ac0640,0x44d800b6}},	//   gna_, hádz, _चाहन, _vč_,
   {{0xdb1100fd,0x2ca70407,0x6b8b8242,0x64442a92}},	// [8640] éfèr, hund_, _megg, rlii,
   {{0x44298243,0x6b8b8244,0x44d88245,0x2bd1009d}},	//   ana_, _legg, _tč_, _दोघा,
   {{0x44298246,0x63af02fd,0x7c3b06a3,0x644400aa}},	//   bna_, ännö, kour, plii,
   {{0x7c3b04ea,0x2d8e5ce9,0x6b8b8247,0x2ca7058f}},	//   jour, wafe_, _negg, dund_,
   {{0x44208248,0xa3e7218b,0x7c3b8249,0x7c29824a}},	//   mii_, पार_, dour, dner,
   {{0x4420824b,0xa6e30088,0x7bdc01d3,0x2ca7824c}},	//   lii_, æðis, ērum, fund_,
   {{0x6b8b4012,0x798a14d0,0x6143824d,0xe7aa824e}},	//   _begg, _refw, _жера, _कांप,
   {{0x4420824f,0x7c3b8250,0x2d8e8251,0x3f8f0079}},	//   nii_, gour, safe_, cagu_,
   {{0x9c870220,0x6b8b0188,0x00000000,0x00000000}},	//   _počú, _degg, --, --,
   {{0x44208252,0x44293b0d,0xdb190c56,0x2ca755e8}},	//   hii_, zna_, _pawò, bund_,
   {{0x44298253,0x4420008a,0x7c3b8254,0xd8390039}},	//   yna_, kii_, bour, luči_,
   {{0x44208255,0x44298256,0x2d8c3174,0x7c2900e7}},	//   jii_, xna_, _hede_, cner,
   {{0x44200fdc,0x44293e75,0x77640465,0x2d8c8257}},	//   dii_, vna_, държ, _kede_,
   {{0x6b8b0ab2,0x2d8c8258,0x44298259,0x7c200350}},	//   _zegg, _jede_, wna_, limr,
   {{0xa3e734d8,0x69c8825a,0x4420825b,0x2d8c825c}},	//   पाल_, mede, fii_, _mede_,
   {{0x4420825d,0x69c8825e,0x4429825f,0x2d8c8260}},	//   gii_, lede, una_, _lede_,
   {{0x44290b6a,0x443b0078,0xd8390128,0xdeb401c2}},	// [8650] rna_, roq_, juči_, ƙaƙi,
   {{0x69c819d8,0x7c2d00cc,0xdb11025a,0x2d8c8261}},	//   nede, čari, éfér, _nede_,
   {{0x44208262,0x44298263,0x68360181,0x7c298264}},	//   bii_, pna_, vádz, yner,
   {{0x44208265,0x69c88266,0x98b304a3,0x44298267}},	//   cii_, hede, žeći_, qna_,
   {{0x6b8b8268,0x63ad1d46,0x2d8c8269,0x3f8f826a}},	//   _regg, mgan, _bede_, ragu_,
   {{0x69c8760d,0x63ad826b,0x2ca756a1,0x6b8b826c}},	//   jede, lgan, tund_, _segg,
   {{0x7c3b826d,0x69c8826e,0xeb993b2f,0x6b8b008f}},	//   tour, dede, бий_, _pegg,
   {{0x63ad3e80,0x2ca7826f,0x7c298270,0xae1d009f}},	//   ngan, rund_, uner, _भगवन_,
   {{0x2ca70bd8,0x2d8c8271,0x6b8b0c09,0x7c3b00d3}},	//   sund_, _fede_, _vegg, rour,
   {{0x44200012,0x6b8b5d73,0x7e7b8272,0x2d8c1f12}},	//   zii_, _wegg, _itup, _gede_,
   {{0x4420026e,0x9f440383,0x6b8b0036,0x7c3b3d66}},	//   yii_, _anmè_, _tegg, pour,
   {{0x44200694,0xdd8f0018,0x63ad0381,0x9c821405}},	//   xii_, _سوچ_, jgan, áčen,
   {{0x44208273,0x63ad2f99,0x3f8d02ac,0x00000000}},	//   vii_, dgan, _meeu_, --,
   {{0x9c820b27,0x4420008a,0x63ad8274,0x7bc90db1}},	//   ščen, wii_, egan, leeu,
   {{0x44206762,0x63ad8275,0xa5078276,0xd83f033b}},	//   tii_, fgan, пера_, ščaj_,
   {{0x61e72608,0x68fc4478,0x27350294,0x00000000}},	//   _anjl, ärde, ụna_, --,
   {{0x44208277,0xaabd0179,0xd387448a,0x7e7b0027}},	// [8660] rii_, ्बिक, яйте_, _ntup,
   {{0x442075df,0x63ad8278,0x9c7c05db,0x601c013c}},	//   sii_, agan, _hrče, _içmə,
   {{0x44208279,0x2d8c827a,0x7e7b827b,0x04462105}},	//   pii_, _rede_, _atup, _неон,
   {{0x44200188,0x35b2034c,0x69c8827c,0xa3e70213}},	//   qii_, _जाड़, zede, पाः_,
   {{0xf8a8099d,0x66fe0455,0x2d8c827d,0x69c819a8}},	//   _कम्प, ॉनिक_, _pede_, yede,
   {{0xd839150a,0x2c710076,0x69c8002b,0x00000000}},	//   ruči_, _bád_, xede, --,
   {{0x2d8c827e,0xe81d009f,0x6458028d,0x7e7b007b}},	//   _vede_, _पगला_, _èvis, _etup,
   {{0x8aa608d9,0x69c8827f,0x8cbd0034,0x78a82ba4}},	//   прод, wede, _शहरो, vudv,
   {{0x62967445,0x69c88280,0x2d8c8281,0xa5ad0034}},	//   nsyo, tede, _tede_, _जालौ,
   {{0x2c71009c,0x20060062,0x7d2701f9,0x00000000}},	//   _fád_, lkoi_, ársá, --,
   {{0xb4c80034,0x63ad8282,0xf8ad0d5b,0x00000000}},	//   ोटो_, ygan, لکي_, --,
   {{0x62967447,0x4c1609b4,0x78a81816,0xd491020b}},	//   ksyo, _عباس, rudv, ầm_,
   {{0x78a8052f,0x63ad8283,0x3e5d0383,0x569400e5}},	//   sudv, vgan, _sňti_, наят,
   {{0xa2db0e5e,0x7afd8284,0x00000000,0x00000000}},	//   निस्, äste, --, --,
   {{0x63ad8285,0x19bb00a1,0x49bb03c2,0x200600ce}},	//   tgan, _המוב, _המוס, kkoi_,
   {{0x9c7c0106,0x63ad8286,0x2be5007f,0x00000000}},	//   _grče, ugan, काएं_, --,
   {{0x95cb12e7,0x27e92d53,0x62960270,0x979c00ca}},	// [8670] _луна_, _inan_, gsyo, _השחק,
   {{0x20c841e8,0x386e8287,0xb0c800b7,0x00000000}},	//   रबंध, _kufr_, रबंग, --,
   {{0x7e7b023c,0x7e7c0087,0x7fd5004d,0x63ad8288}},	//   _stup, _črpa, ділі, pgan,
   {{0x2c71499e,0x3ce000b6,0x00000000,0x00000000}},	//   _rád_, किने_, --, --,
   {{0xdcf801d3,0x9ea9004d,0xb2740120,0x00000000}},	//   kavē, івка_, _пляш, --,
   {{0x6da513cb,0x2c710146,0x9f5f00ee,0x273c00fe}},	//   фика, _pád_, _lluç_, ửng_,
   {{0x27e9022b,0xed560396,0x5578006e,0xdce10090}},	//   _onan_, мош_, לעגן_, _melħ,
   {{0x1b1e0081,0x27e901c2,0x7ae400e4,0x3ea004ad}},	//   _পড়ে_, _nnan_, _šita, šita_,
   {{0x7bc98289,0xa7fd00a7,0x7e7b0a4b,0x3ef800ae}},	//   reeu, yqır, _utup, _ентэ_,
   {{0x27e9828a,0xef19009e,0xf2d4006e,0xe81006e4}},	//   _anan_, _feżr_, געץ_, ासभा_,
   {{0x07a64441,0x200d000b,0x6aa90036,0x6ce4018a}},	//   манн, _klei_, suef, _піце,
   {{0x27e9009c,0x6e23008c,0x236600c6,0xc5f80eeb}},	//   _cnan_, linb, žoji_, ुस्य_,
   {{0xa3e71cff,0x27e901ff,0x59a60285,0xc9f50076}},	//   पाई_, _dnan_, _खाचर, _يستع,
   {{0x200d0472,0x27e9022b,0xf1ac06e4,0x69250284}},	//   _llei_, _enan_, _चाइन, _омла,
   {{0x9c7c2174,0xa6c90103,0x00000000,0x00000000}},	//   _trče, _ہوٹل_, --, --,
   {{0x9c7c828b,0x6e23828c,0xa41c0033,0x23d500d3}},	//   _urče, hinb, থক্য_, нцур,
   {{0xe1fa828d,0x60c902ef,0x1dae0096,0x04430e2f}},	// [8680] ога_, _ćema, _घालत, тетн,
   {{0x629620c1,0x7d03828e,0x27e92ef0,0x6e2d020d}},	//   rsyo, kyns, _znan_, éabl,
   {{0x6296805d,0x04030081,0x200d00f3,0x2006007b}},	//   ssyo, রোধী_, _blei_, tkoi_,
   {{0xa2db04dd,0x629606a3,0x39470f5a,0x00000000}},	//   निश्, psyo, _myns_, --,
   {{0xee3a5fc1,0x2006023b,0xf1aa001c,0x20070131}},	//   онд_, rkoi_, _واسه_, ênia_,
   {{0xa2db0f82,0x6e230023,0xb8140033,0x2006828f}},	//   निर्, ginb, াচিত_, skoi_,
   {{0xd5ed0023,0x0caa004d,0x00000000,0x00000000}},	//   _quả, ітки_, --, --,
   {{0x61fc5275,0x8af8016c,0x92c20033,0x00000000}},	//   _horl, знис_, ্মী_, --,
   {{0x61fc7932,0x3f861e7d,0x3e7b044c,0x00000000}},	//   _korl, mbou_, _câtă_, --,
   {{0x4efb00ca,0x3f868290,0x27e9009c,0x13d70033}},	//   _והמו, lbou_, _snan_, হায়,
   {{0x61fc8291,0xe7eb5620,0x3ea63106,0x27e90154}},	//   _morl, टाला_, lrot_, _pnan_,
   {{0x3f868292,0x00000000,0x00000000,0x00000000}},	//   nbou_, --, --, --,
   {{0x61fc01a2,0x5bbc142e,0x3f8601c2,0xdb2400c2}},	//   _oorl, ्जीव, ibou_, äräy,
   {{0x8a03008f,0x61fc8293,0x394702b6,0x7ae20f20}},	//   _изче, _norl, _fyns_, _irot,
   {{0x92bb0f71,0x443f0019,0x7ae28294,0x387c00c4}},	//   _আছে_, _ưu_, _hrot, _utvr_,
   {{0x27e92a0b,0x69da8295,0x69d8411b,0x7ae28296}},	//   _unan_, ldte, _have, _krot,
   {{0x69d88297,0x61fc8298,0x776d0072,0x32550293}},	// [8690] _kave, _borl, _igax, евар,
   {{0x69da5cfe,0xf3ff0019,0x61fc8299,0x69d8829a}},	//   ndte, _giãn_, _corl, _jave,
   {{0x69d8829b,0xe7e40096,0x38b8829c,0x2f7c0294}},	//   _mave, गाचा_, nér_, _ịmụ_,
   {{0x69d80856,0x3f86084e,0x7ae20634,0xa2a7142e}},	//   _lave, gbou_, _orot, _चिप्,
   {{0x9f400682,0x61fc2844,0x3d170ed3,0x38b80018}},	//   ðið_, _forl, _भेजे_, hér_,
   {{0x7bc2004f,0x61fc829d,0x7cd30092,0xc33200a1}},	//   _abou, _gorl, _hərə, _תוך_,
   {{0xeb99002d,0x8c450c63,0x7ae2829e,0x6d4800eb}},	//   пий_, неке, _arot, _cyda,
   {{0x200d00d3,0x61fc03a3,0xeb990084,0x7ae2829f}},	//   _ulei_, _zorl, чии_, _brot,
   {{0x69d882a0,0x394713f8,0x0e35249c,0x3ea60167}},	//   _bave, _syns_, _знаю, crot_,
   {{0x9c8219d0,0x7ae282a1,0x7c870012,0x7f49039f}},	//   ščan, _drot, _жуде, _iyeq,
   {{0xd8261369,0x386982a2,0x69d882a3,0x38b882a4}},	//   едни, _biar_, _dave, gér_,
   {{0x7ae282a5,0x69d882a6,0x386901ec,0xe73a1974}},	//   _frot, _eave, _ciar_, зем_,
   {{0x7ae282a7,0x69d882a8,0x38690cd9,0xe9a513a4}},	//   _grot, _fave, _diar_, _залп,
   {{0x69d882a9,0x9c7c82aa,0x3f860094,0x7bd9039f}},	//   _gave, _hrča, zbou_, _hawu,
   {{0x7bd982ab,0x69c382ac,0x3869009c,0x3f8657b8}},	//   _kawu, _ibne, _fiar_, ybou_,
   {{0x69d8200b,0xe73a0084,0xb60200b6,0x7bdb82ad}},	//   _zave, _ней_, _žádo, nduu,
   {{0x7cd30092,0x7bd982ae,0x3f860094,0x9c7c007e}},	// [86a0] _dərə, _mawu, vbou_, _mrča,
   {{0x68e31523,0x386900ae,0x7bd982af,0x1dae00b6}},	//   _krnd, _ziar_, _lawu, _घाइत,
   {{0xa3ea07f3,0x61fc01bf,0x4fc62cf0,0x3f8652e8}},	//   _една_, _vorl, есла, tbou_,
   {{0x61fc0054,0xfbae055e,0x7bd953dd,0x7cd300a7}},	//   _worl, _टाइम, _nawu, _gərə,
   {{0x3f8682b0,0x7bdb787e,0x6d484fbc,0x69c3033b}},	//   rbou_, dduu, _syda, _obne,
   {{0xf2d30089,0x7ae2023b,0x7cd300a7,0x3f865406}},	//   _געש_, _rrot, _zərə, sbou_,
   {{0x8fa601b3,0x7f49063d,0x9c7c050d,0x44220e2b}},	//   _паве, _eyeq, _brča, _kmk_,
   {{0x6d4818ed,0x961d0c16,0x69d81cf5,0x69c36042}},	//   _vyda, _नष्ट_, _save, _abne,
   {{0x69d882b1,0x6d480067,0x442200f9,0x7bd982b2}},	//   _pave, _wyda, _mmk_, _dawu,
   {{0x386910f0,0x38b882b3,0x7afd4249,0x7bdb363c}},	//   _siar_, tér_, ästa, aduu,
   {{0x0b8a0d64,0x290a0018,0x9f4482b4,0x64463585}},	//   _если_, ába_, _tomó_, _okki,
   {{0x7ae282b5,0x68e31528,0x7bd982b6,0x69d84e6d}},	//   _trot, _drnd, _gawu, _wave,
   {{0x38b805f1,0x7ae282b7,0x38690167,0x290a033b}},	//   sér_, _urot, _viar_, šba_,
   {{0x8cd71492,0x442282b8,0x6446083e,0x290500b6}},	//   _मनमो, _amk_, _akki, byla_,
   {{0x248d00e9,0x7bd982b9,0xaaa60096,0xf8a40f96}},	//   ćemo_, _yawu, _खिडक, _खटिय,
   {{0x60c70167,0x21030031,0x7c220078,0x7cd3013c}},	//   _rpjm, nčiť_, _jmor, _qərə,
   {{0x6b840006,0x2bc2009d,0xfbc2521f,0xe7c132d1}},	// [86b0] _õigu, व्या, व्यम, ष्णप,
   {{0xa2a70eeb,0x21030031,0x644682ba,0xf3ff0231}},	//   _चिठ्, hčiť_, _ekki, _tião_,
   {{0x7cd30253,0x5f9526be,0x7c2282bb,0x2007016d}},	//   _tərə, виет, _omor, ênio_,
   {{0xf8b3006e,0x9f5f0139,0x21030206,0x00000000}},	//   טשע_, _iluú_, jčiť_, --,
   {{0x628303ce,0x644d82bc,0x7bd9001c,0x21030206}},	//   ćnos, mlai, _rawu, dčiť_,
   {{0x62353bf9,0x9c7c0039,0x2ab90c56,0x6250007a}},	//   _регу, _srča, vèb_, näol,
   {{0xdce100a5,0x644d82bd,0x7bd916db,0x25d800ca}},	//   _oglą, olai, _pawu, גוון_,
   {{0x644d82be,0x8ca206ed,0x69c30167,0x26c9031a}},	//   nlai, _गिरो, _sbne, _opao_,
   {{0x7bdb82bf,0x68e309ac,0x2fcf0113,0x00000000}},	//   rduu, _srnd, megg_, --,
   {{0xaca300ac,0x644d0a1b,0x2fcf00d6,0x7c2282c0}},	//   _amụm, hlai, legg_, _emor,
   {{0x644d82c1,0x9c7c005f,0x7bd982c2,0x6abb82c3}},	//   klai, _trča, _tawu, stuf,
   {{0x9c7c3472,0x645a0138,0x00000000,0x00000000}},	//   _krčn, įtik, --, --,
   {{0x9aa4046b,0x6b8947fd,0x644d82c4,0xe9ce5e39}},	//   _ممنو, mbeg, dlai, _кк_,
   {{0x442282c5,0x7c221548,0x25fd0285,0x644d82c6}},	//   _smk_, _zmor, रॉली_, elai,
   {{0x4422593a,0x6aa982c7,0x644d5a43,0x00000000}},	//   _pmk_, lref, flai, --,
   {{0x644d17ea,0x69c182c8,0x6b8982c9,0x00000000}},	//   glai, lfle, nbeg, --,
   {{0xe297251c,0x4909030b,0x23270e06,0x00000000}},	// [86c0] кат_, ानको_, воти_, --,
   {{0x644d82ca,0x69c182cb,0x175700ca,0x6b8900e7}},	//   alai, nfle, _בספר_, hbeg,
   {{0x644d82cc,0x62840503,0x442201ae,0x6aa900eb}},	//   blai, spio, _tmk_, href,
   {{0x644d299c,0x6aa9004d,0x6284166f,0x764e5d95}},	//   clai, kref, ppio, llby,
   {{0x443208b6,0x37dc0033,0x7ed30037,0x6aa90537}},	//   mny_, ধাপর, لزوا, jref,
   {{0xa2a71d69,0x44321670,0x7c2282cd,0x6aa900f0}},	//   _चित्, lny_, _smor, dref,
   {{0x61ee0212,0x44323212,0x6aa9042c,0x7c22024a}},	//   _inbl, ony_, eref, _pmor,
   {{0x443282ce,0xa3b60e1f,0x6b8982cf,0x2cf282d0}},	//   nny_, च्च_, gbeg, _अपील_,
   {{0x44323918,0x0e6601b6,0x6aa919bf,0x00000000}},	//   iny_, _акан, gref, --,
   {{0x44322d31,0x2bae009d,0x2a6a0103,0x2bd4009f}},	//   hny_, _टाका, öbb_, _दसवा,
   {{0x26c9015c,0x644d82d1,0x38c80421,0x6b890565}},	//   _spao_, ylai, رادی_, bbeg,
   {{0x443282d2,0x27ed22e7,0x3ea92956,0x27ff0088}},	//   jny_, ñen_, šate_, ðun_,
   {{0x44321643,0x34cb07e2,0x25a100ec,0x61ee084e}},	//   dny_, ाब्द, _pdhl_, _onbl,
   {{0xb8823e63,0x27ed01f9,0x00000000,0x00000000}},	//   üíst, űen_, --, --,
   {{0x659482d3,0x6b8400bc,0x644d2c5a,0xca4700d1}},	//   расу, _õigs, tlai, _جلوه_,
   {{0x443282d4,0x644d82d5,0x32110094,0x61ee82d6}},	//   gny_, ulai, _slzy_, _anbl,
   {{0x644d82d7,0x26c908c5,0x36050037,0x2fcf23ff}},	// [86d0] rlai, _upao_, _موظف, vegg_,
   {{0x44320067,0x644d82d8,0x61ee0167,0x6b890b14}},	//   any_, slai, _cnbl, zbeg,
   {{0x26080067,0x2481061d,0x9c7c0087,0x443206e9}},	//   _सकती_, _uthm_, _srčn, bny_,
   {{0xa28300cd,0x44321c5c,0xfbc202d5,0x61ee0062}},	//   _نیرو, cny_, _वॉलम, _enbl,
   {{0x442982d9,0xceeb0260,0x6da582da,0x42552ce3}},	//   mia_, بران_, гила, _منحر,
   {{0xdce80092,0x3eaf3e59,0x00000000,0x00000000}},	//   _addı, rugt_, --, --,
   {{0x6b89050d,0x6ecf030b,0x2c78033c,0x6abd1e18}},	//   tbeg, _धनकु, _céd_, ्ब्र,
   {{0x442982db,0x6aa9279f,0x8af701d4,0xfd290139}},	//   nia_, tref, _çəki, _akìí_,
   {{0x985f003d,0x00000000,0x00000000,0x00000000}},	//   _eċċ_, --, --, --,
   {{0x442982dc,0x6aa982dd,0xe8f964e9,0x44321799}},	//   hia_, rref, ело_, zny_,
   {{0x442982de,0x44320067,0x69c182df,0xbef3007d}},	//   kia_, yny_, rfle, _आपुन_,
   {{0x442982e0,0x9816012b,0x6aa982e1,0x7cca00a7}},	//   jia_, ابدا, pref, _sərg,
   {{0x44320074,0xfaa52fd4,0x69c101bf,0x3e790113}},	//   vny_, _сало, pfle, _jèt_,
   {{0x443200a5,0x3e790c56,0x98e500e3,0x7cca00a7}},	//   wny_, _mèt_, _مكتو, _fərd,
   {{0x03a63d94,0x44321c5c,0x845a82e2,0x3e7906a3}},	//   ливо, tny_, ерат_, _lèt_,
   {{0x442982e3,0x41c66bbd,0x387a0231,0x00000000}},	//   gia_, र्नस, _épra_, --,
   {{0x44321670,0x3e7906a3,0x7cca013c,0x64440e22}},	// [86e0] rny_, _nèt_, _zərd, roii,
   {{0x7c2982e4,0x442982e5,0x443282e6,0x613a82e2}},	//   hier, aia_, sny_, нчер_,
   {{0x7c2982e7,0xd00a008f,0x44325b0b,0x00000000}},	//   kier, неже_, pny_, --,
   {{0x3e790c56,0x7c2982e8,0xb4c000a3,0x2d980141}},	//   _bèt_, jier, ंझी_, _žre_,
   {{0xadf02674,0x539b00a1,0x3e790113,0x7afd2e3e}},	//   चालन_, _איכו, _cèt_, ästl,
   {{0x61467ca9,0x3e7902f1,0x63b682e9,0x7c294c1e}},	//   _бега, _dèt_, lgyn, eier,
   {{0x7c2982ea,0xa3bb82eb,0x16b16935,0x00000000}},	//   fier, _घाम_, _जम्ब, --,
   {{0x7c2982ec,0x3e7914b1,0x09ac0096,0x63b682ed}},	//   gier, _fèt_, चल्य, ngyn,
   {{0xee3a0291,0xaae60037,0x7cca013c,0x00000000}},	//   _зна_, اسبو, _sərd, --,
   {{0x442982ee,0x32bb00c1,0x7c29000b,0x9c7c0094}},	//   zia_, עזיד, aier, _určo,
   {{0x7c2982ef,0x41c6055e,0x44292502,0xf1c60efb}},	//   bier, र्यस, yia_, र्यन,
   {{0x7c2982f0,0xaae60cd2,0x386d0212,0x64c70117}},	//   cier, _مستو, öer_, nčiš,
   {{0x95cb63df,0x66c8088f,0x6b9d01ab,0x7d0a0313}},	//   нува_, лург_, ðsge, lyfs,
   {{0x442982f1,0x998c00c6,0x00000000,0x00000000}},	//   wia_, rodų_, --, --,
   {{0x442982f2,0x7cca01d4,0x799a82f3,0xa2a70861}},	//   tia_, _hərb, matw, _चिह्,
   {{0xb4c50006,0x799a82f4,0x44297ec3,0x2a6e009c}},	//   _एही_, latw, uia_, _hifb_,
   {{0x290d0206,0x00000000,0x00000000,0x00000000}},	// [86f0] čkať_, --, --, --,
   {{0x442922f3,0x7c2982f5,0x799a7d56,0xcb5700ca}},	//   sia_, zier, natw, רסמה_,
   {{0x44291dbd,0x3e7906a3,0x60130511,0x74160281}},	//   pia_, _sèt_, _açma, _چوپا,
   {{0xb4fa17f5,0x4429023b,0x7c2982f6,0x3e790383}},	//   _ספרי, qia_, xier, _pèt_,
   {{0x7c2982f7,0x539a00a1,0x443901c0,0x799a82f8}},	//   vier, _בירו, _ijs_, katw,
   {{0x7c290067,0x867c00c1,0x9f5f00fd,0x7afd00bc}},	//   wier, ערוו, _joué_, ästm,
   {{0x7c2982f9,0x44394c04,0x88c702c6,0x799a0079}},	//   tier, _kjs_, _kněž, datw,
   {{0x3e7914b1,0x9f5f020d,0x00000000,0x00000000}},	//   _tèt_, _loué_, --, --,
   {{0x7c2982fa,0x799a0193,0xfaa500d3,0xaca30032}},	//   rier, fatw, шапо, _irọl,
   {{0x7c2982fb,0x5ec80081,0xb4c5007a,0x2fdf5ccb}},	//   sier, লিশে, _एहू_, _haug_,
   {{0x63b600c6,0x2bc2009d,0x2bae02d5,0xe8f60012}},	//   ygyn, व्हा, _टाचा, алэ_,
   {{0xfc6700e5,0xb0b600d7,0x00000000,0x00000000}},	//   _съзн, ספרס_, --, --,
   {{0x799a2bf4,0x41c6262c,0xf3ff020b,0x00000000}},	//   batw, र्डस, _giãi_, --,
   {{0x81ab00c7,0x2fdf006c,0x6b9b811e,0x645d0036}},	//   ক্ত_, _laug_, laug, _ahsi,
   {{0xe9460177,0x4439016d,0x7cca00a7,0x9f5f014b}},	//   _پروی, _bjs_, _zərb, _doué_,
   {{0x3ea00106,0xf81400bf,0xb38600ae,0x7ae482fc}},	//   šiti_, _دستگ, рлал, _šiti,
   {{0xd46782fd,0xb226018a,0x27e00013,0x422622cb}},	// [8700] рите_, амал, _iain_, адав,
   {{0x27e082fe,0x26060161,0xa3e60179,0x6b9b82ff}},	//   _hain_, _vôos_, _योर_, haug,
   {{0x27e0048e,0x6b9b8300,0x2fdf26c9,0xdcf801d3}},	//   _kain_, kaug, _baug_, ravī,
   {{0x2fdf006c,0xe3b22b38,0x4375084c,0x888c006e}},	//   _caug_, _برد_, _гурт, גראַ,
   {{0x2fdf01b3,0x27e034c0,0xa3bb0d75,0x6b9b8301}},	//   _daug_, _main_, _घात_, daug,
   {{0x27e048d4,0x7ae400e3,0x44d8022b,0x3942007f}},	//   _lain_, _áiti, _kō_, ększ_,
   {{0x10a342b9,0x7cca00a7,0xadf70037,0x27e00062}},	//   _мирн, _sərb, شروط_, _oain_,
   {{0xeca71244,0x27e08302,0xa3c92172,0x7d0a0313}},	//   _गिरफ, _nain_, ल्प_, ryfs,
   {{0xf1c6022d,0x9c7c04e9,0x41c608c0,0x7cca00a7}},	//   र्थन, _krčk, र्थस, _qərb,
   {{0x2fdf0197,0xdb09026a,0x20040231,0xdca61fbf}},	//   _zaug_, zgeç, _homi_, _важи,
   {{0x27e08303,0x44d8022b,0x2d9c00dd,0x20048304}},	//   _bain_, _nō_, mave_, _komi_,
   {{0xf1c6000d,0x2d9c8305,0x62860106,0xb8ce00a3}},	//   र्तन, lave_, _otko, _ओट_,
   {{0x27e06304,0x799a0239,0xeafa0281,0x2c0b0470}},	//   _dain_, patw, _جرات_, _جعلی_,
   {{0x2d9c8306,0xa3c9030b,0x44d805aa,0x27e00441}},	//   nave_, ल्न_, _bō_, _eain_,
   {{0x69ca023e,0x44393079,0xf8da00c3,0x27e0398a}},	//   _ibfe, _pjs_, _बनिय, _fain_,
   {{0x20048307,0x25ad8308,0x27e08309,0x25e7115b}},	//   _nomi_, şel_, _gain_, _छोरी_,
   {{0x81e000c7,0x2fdf01bb,0x9c7c26dd,0x2d9c830a}},	// [8710] থান_, _raug_, _brčk, kave_,
   {{0x98da1827,0xf8da00a5,0x27e0830b,0x41b500e3}},	//   _बनाए, _बनाय, _zain_, إمار,
   {{0x20040f20,0x2fdf022e,0x2d9c830c,0x27e001c2}},	//   _bomi_, _paug_, dave_, _yain_,
   {{0x2ef50eea,0x2fdf006c,0x20040131,0x28a91592}},	//   йзер, _qaug_, _comi_, _किसि,
   {{0x2004830d,0x6d5a3d7d,0x9c7c830e,0x2d9c830f}},	//   _domi_, _azta, _frčk, fave_,
   {{0x9c7c00e9,0x2d9c7fb8,0x41c600c3,0x6b820558}},	//   _grčk, gave_, र्दस, _afog,
   {{0x2fdf0197,0x20048310,0x6b9b8311,0x00000000}},	//   _taug_, _fomi_, taug, --,
   {{0x2d820018,0xf53800a1,0x3c3a01d3,0x26c27bd0}},	//   _őket_, ינוי_, tīva_, ytko_,
   {{0xa3c922f1,0x6d5a0a00,0x6b9b8312,0x3f151402}},	//   ल्य_, _ezta, raug, _удас,
   {{0x6b9b01b3,0x752800a5,0x27e08313,0x3f9d6204}},	//   saug, ździ, _sain_, lawu_,
   {{0x799802f1,0x27e08314,0xd94524dc,0xdea30103}},	//   _devw, _pain_, сени, _ایڈی,
   {{0xa3c9417a,0xa3e60034,0x00000000,0x00000000}},	//   ल्म_, _यों_, --, --,
   {{0x27e002fd,0xdce30702,0x7bda040a,0x39540181}},	//   _vain_, manı, _תקנו, _časť_,
   {{0xdce307d1,0x44d80154,0x26c28315,0x27e08316}},	//   lanı, _pō_, rtko_, _wain_,
   {{0x26c20067,0x27e08317,0x94790743,0x291e0034}},	//   stko_, _tain_, исту_, czta_,
   {{0x2d9c8318,0xdce303a3,0x38a30092,0x93f60092}},	//   zave_, nanı, mır_, _şəbə,
   {{0x38a30390,0xb3440092,0x7cca0092,0x60dc0124}},	// [8720] lır_, _keçə, _məra, _ssrm,
   {{0x81ab00c7,0x9c8202dd,0x20048319,0x66050113}},	//   ক্স_, ščin, _somi_, _gohk,
   {{0x999a07a6,0x38a307d1,0xdce3008e,0x3860061d}},	//   רבעט, nır_, kanı, _khir_,
   {{0x68fc0212,0xef1a831a,0x00000000,0x00000000}},	//   ärdi, лме_, --, --,
   {{0x2d9c831b,0x9f490088,0x9c7c03ab,0x7aed0146}},	//   tave_, ðað_, _trčk, _šatn,
   {{0x6b82008f,0x38a3026a,0x7bcb010a,0xe3b20421}},	//   _sfog, kır_, _abgu, _برگ_,
   {{0x2d9c831c,0x557700c1,0x7cca00a7,0x6ce600c6}},	//   rave_, זעצן_, _bəra, сіле,
   {{0x38a308fd,0x2d9c5f06,0x6d5a030b,0x5b1400c2}},	//   dır_, save_, _vzta, жмит,
   {{0xa3bb018b,0x34d4074c,0x2d9c831d,0x682f0065}},	//   _घास_, दबुद, pave_, _lòdè,
   {{0x38600472,0x38a3026a,0x290c1e8f,0xff1700ca}},	//   _ahir_, fır_, tyda_, _הקמת_,
   {{0x19580fdf,0x66050837,0x2bca02ec,0xa3c9022d}},	//   раны_, _rohk, _було_, ल्ड_,
   {{0x38601c26,0x28a942c3,0xdce3020e,0xbc668276}},	//   _chir_, _किरि, canı, _увек,
   {{0x291e3c90,0xe81f02d5,0x28da0096,0x41d800c3}},	//   szta_, मोगा_, _बनवि, ड़ास,
   {{0xe84c00b6,0x38a303e0,0x09e300c2,0xbb3b006e}},	//   ětší, bır_, _ночн, _געדי,
   {{0xe65400d6,0x38600a02,0x9c7c00c4,0x00000000}},	//   ївсь, _fhir_, _brči, --,
   {{0x69c80313,0x3860009c,0xddda01f9,0x00000000}},	//   lfde, _ghir_, _mitő, --,
   {{0x24580084,0x00000000,0x00000000,0x00000000}},	// [8730] сать_, --, --, --,
   {{0xdce307aa,0xa3bb0b95,0x80cd00df,0x3f9d01c2}},	//   zanı, _घाव_, _सहदे, wawu_,
   {{0xdce30dea,0xa25b0038,0x69c8084e,0x00000000}},	//   yanı, _spôs, ifde, --,
   {{0x9f551e9e,0x9c7c831e,0x32180172,0x64410072}},	//   овеч, _grči, _elry_, élid,
   {{0x38a3008e,0xdce30740,0x81ab0081,0x51871cda}},	//   zır_, vanı, ক্ষ_, _губа,
   {{0x7aed005f,0x38a30f28,0x628d1b38,0x261400bc}},	//   _šato, yır_, mpao, _näol_,
   {{0xdce30491,0xed5922f9,0x38a300a7,0xa3c90521}},	//   tanı, шок_, xır_, ल्थ_,
   {{0x7cca01d4,0xe0d200c1,0x69c8112f,0xb344013c}},	//   _qəra, _קײן_, efde, _seçə,
   {{0xdce3008e,0x442b831f,0x628d028d,0x3ea40027}},	//   ranı, _mmc_, npao, _gvmt_,
   {{0x38a31f8a,0x88c90084,0x3860008a,0xdce308bb}},	//   tır_, алов_, _shir_, sanı,
   {{0xdce303e0,0x61e50013,0x999e00b6,0xac192914}},	//   panı, idhl, nitř_, _кожу_,
   {{0xb90110ed,0x38a3008e,0x7e7b8320,0xdce300a7}},	//   _नई_, rır_, _kuup, qanı,
   {{0xf7720678,0x38a301e8,0xa9a505da,0x2fcd0027}},	//   باد_, sır_, _дилд, _mbeg_,
   {{0x7ae94c77,0xa9692249,0x96140285,0x7bc922da}},	//   mvet, _кила_, डसेट_, lfeu,
   {{0xf3870294,0x00000000,0x00000000,0x00000000}},	//   _ụtọa, --, --, --,
   {{0x69de8321,0x69c5007f,0x00000000,0x00000000}},	//   _óper, ़्री, --, --,
   {{0xa2062cd8,0x9c7c015c,0x628d2375,0x7ae98092}},	// [8740] опад, _isče, gpao, nvet,
   {{0xe1f77e36,0xe2460037,0x915f020b,0x00000000}},	//   огу_, آخري, _sắp_, --,
   {{0x9c7c07c0,0x6026224a,0x7ae98322,0x7c2b00f3}},	//   _trči, оджа, hvet, _omgr,
   {{0x9c7c0074,0x2eed39a4,0x2d8500ae,0x7ae98323}},	//   _urči, _bref_, _afle_, kvet,
   {{0xaad834d8,0x644100fd,0x6d410212,0x6589020d}},	//   _बैंक, élie, _axla, _éphé,
   {{0x6ce50e72,0x0caa0b73,0x7ae90149,0xee3700c6}},	//   किंग_, атии_, dvet, онч_,
   {{0x90c33974,0x7bc94226,0xb7bb016d,0x2478022b}},	//   _обре, ffeu, lhãe, _fōme_,
   {{0x8aa62c22,0x26d200f9,0x984d007f,0x00000000}},	//   ород, _opyo_, _iść_, --,
   {{0x8af701d4,0xada60161,0x7ae90103,0xf1c30090}},	//   _şərh, _маал, gvet, _feġġ_,
   {{0x7ae402ef,0x82f700d7,0x00000000,0x00000000}},	//   _šits, קציב_, --, --,
   {{0x7ae90451,0x91bb00ca,0x7c2b00b3,0xb21b003e}},	//   avet, סמטי, _fmgr, _stæk,
   {{0x81c20033,0xd90f0103,0x00000000,0x00000000}},	//   ্যি_, ئیٹ_, --, --,
   {{0xb901033a,0x09e623bf,0x2eed0124,0x7ae91813}},	//   _नै_, _модн, _xref_, cvet,
   {{0x60c50e16,0x5eeb05d6,0xceb30266,0xdcfa00e8}},	//   ythm, चित्_, ויש_, _netī,
   {{0x81c200c7,0x80c90034,0x70c9007a,0x3ce000a4}},	//   ্যা_, _रहें, _रहेल, किटे_,
   {{0xb8670470,0x3cdd00bc,0x00000000,0x00000000}},	//   _باتو, _कईसे_, --, --,
   {{0xd7631e49,0x442b014b,0xb60700e5,0x00000000}},	// [8750] _تنظی, _vmc_, _дянк, --,
   {{0xd2511a13,0x628d0235,0x51f807bf,0x00000000}},	//   رنا_, rpao, оную_, --,
   {{0x2127011b,0x7ae90018,0x6ad30081,0x7e7b4880}},	//   ành_, zvet, তিযো, _suup,
   {{0x60c500f0,0x442b01cb,0x7e7b4880,0x7ae98324}},	//   rthm, _umc_, _puup, yvet,
   {{0xfd4c00de,0x51871553,0x387c007e,0x644d5f53}},	//   _triề, _мува, _luvr_, moai,
   {{0xc27a00a1,0x7ae9026a,0x201d08cc,0x644d007b}},	//   _לרשי, vvet, shwi_, loai,
   {{0x7c2b00b3,0x00000000,0x00000000,0x00000000}},	//   _pmgr, --, --, --,
   {{0x7ae9023b,0x2eed8325,0xa80603be,0x644d28f1}},	//   tvet, _tref_, _mañá, noai,
   {{0xeab10037,0x7ae900ae,0x7bc98326,0x8cd700a3}},	//   رعة_, uvet, rfeu, _मनको,
   {{0x7ae9202b,0xa9250db2,0x644d8327,0x00000000}},	//   rvet, здол, hoai, --,
   {{0x7ae959cb,0xf1b200c1,0x81bd0033,0x9a240076}},	//   svet, עסט_, _আসা_, بعين,
   {{0xb33b00a7,0x7ae90103,0x00000000,0x00000000}},	//   _keçd, pvet, --, --,
   {{0xa3e60e28,0xe7375601,0x644d01e9,0x3f8a00a7}},	//   _योग_, зея_, doai, _əbu_,
   {{0xa3c92a06,0x3e6006a3,0x59c253b8,0x7afd2dd3}},	//   ल्स_, pòte_, _शायर, ästu,
   {{0x182800cd,0x99fa00ca,0x7ae40076,0x2935006e}},	//   _وقتی_, _לפספ, _áitr, _מאַן_,
   {{0x7c3b8328,0xaca30174,0x00000000,0x00000000}},	//   nnur, _anịm, --, --,
   {{0x3cdd0067,0xc86500e3,0x9343002d,0xd06300a7}},	// [8760] _कैसे_, _تطوي, енте, _ürək,
   {{0xe4760012,0x7c3b042c,0x754701f9,0x00000000}},	//   _нумэ, hnur, érzé, --,
   {{0x64411f97,0xa8060072,0xa3c9007a,0x757b00ca}},	//   élic, _gañá, ल्ह_, _לטיפ,
   {{0x628141f9,0xdb1b0231,0x1eaa6e50,0x00000000}},	//   _člov, rguê, ماتي_, --,
   {{0x443213e0,0x59bd07ad,0xe7c10efb,0x00000000}},	//   miy_, ्भार, ष्टप, --,
   {{0x290a00f3,0x00000000,0x00000000,0x00000000}},	//   øbak_, --, --, --,
   {{0x39a60080,0xa3c902d5,0x00000000,0x00000000}},	//   hísí_, ल्व_, --, --,
   {{0xafe38329,0x4420152a,0x320a0167,0xef861a5c}},	//   _посл, nhi_, _hoby_, _хлап,
   {{0x44203edf,0x764e0220,0xa06707bf,0xef1a4aa9}},	//   ihi_, koby, _хата_, _ума_,
   {{0x7de500e3,0x7c42007e,0x3f86002b,0x39140c58}},	//   _يسلم, _štrč, lcou_, дмор,
   {{0x69bd0c16,0x4420832a,0x44321a4a,0x3ea600e8}},	//   _शारी, khi_, kiy_, lsot_,
   {{0x44206c5c,0x29020335,0x443201ee,0x3f864777}},	//   jhi_, ćka_, jiy_, ncou_,
   {{0x4420832b,0x2d9e832c,0xe66700e5,0x7bc2039f}},	//   dhi_, _kete_, зтво, _icou,
   {{0x2d9e832d,0x2b09030b,0x29e202a1,0x68fc02c3}},	//   _jete_, िहरु_, _bħaż_, ärds,
   {{0x2d9e14b1,0x644d832e,0x00000000,0x00000000}},	//   _mete_, toai, --, --,
   {{0x4420832f,0x69da20a8,0x2d9e81e7,0x9c7c0146}},	//   ghi_, lete, _lete_, _urču,
   {{0x78ba8330,0x320a00d8,0x644d45f9,0x877c0142}},	// [8770] lutv, _boby_, roai, _פאזי,
   {{0x4420008a,0x69da4287,0x2d9e8331,0x7aed0031}},	//   ahi_, nete, _nete_, _šatk,
   {{0x776101d4,0x320a033d,0xf4850260,0x44208332}},	//   əlxa, _doby_, _تاخی, bhi_,
   {{0x44208333,0x69da8334,0x98c508a9,0x7ae28335}},	//   chi_, hete, žući_, _osot,
   {{0xa2a71085,0x69da8336,0x7ae269f5,0x2d9e0a00}},	//   _चिट्, kete, _nsot, _bete_,
   {{0x2d9e04a3,0x69da8337,0x7bc28338,0x78ba0b85}},	//   _cete_, jete, _acou, kutv,
   {{0x2d9e0291,0xd0d40465,0xe81e009f,0x7ae28339}},	//   _dete_, _поръ, _पतला_, _asot,
   {{0x61e70103,0xdb1b02cd,0xea8921fd,0x00000000}},	//   _hajl, lgué, обил_, --,
   {{0x2d9e833a,0x81e00081,0x61e70095,0x8ca9058f}},	//   _fete_, থার_, _kajl, _टिको,
   {{0xb33b0b88,0xdb1b5bdb,0x69da833b,0x4420833c}},	//   _geçe, ngué, gete, zhi_,
   {{0x7ae2833d,0x61e718c4,0x4420833e,0x186a5598}},	//   _esot, _majl, yhi_, жани_,
   {{0x44205da1,0x61e7023e,0x443201ee,0xf092006e}},	//   xhi_, _lajl, xiy_, כנט_,
   {{0x4432833f,0x764e294f,0x69da8340,0x44203d81}},	//   viy_, toby, bete, vhi_,
   {{0x61e78341,0xc60d00b6,0xdb0000b3,0xf1cf2337}},	//   _najl, _सकृय_, damè, स्मन,
   {{0x44208342,0x4432022b,0x320a028d,0x764e8343}},	//   thi_, tiy_, _roby_, roby,
   {{0x4420063f,0x68fc0fbc,0xe73a002d,0xe29a001f}},	//   uhi_, årde, _мей_, жаа_,
   {{0x44208344,0x21a60e05,0x00000000,0x00000000}},	// [8780] rhi_, дизм, --, --,
   {{0x44208345,0x7cca013c,0x61e701ee,0x00000000}},	//   shi_, _sərm, _cajl, --,
   {{0xb4660e3a,0x2d9e8346,0x4420067d,0x25e71362}},	//   _окол, _rete_, phi_, _छोटी_,
   {{0x69da8347,0xb33b01e8,0x2d9e8348,0xdb1b002b}},	//   zete, _seçe, _sete_, agué,
   {{0x61e78349,0x63a45624,0x3f86137f,0x69da834a}},	//   _fajl, main, rcou_, yete,
   {{0x3f8602cd,0x3f9f6117,0xd04c0092,0xb21b052f}},	//   scou_, _eeuu_, _əhəm, _stæv,
   {{0x2d9e00dd,0x69da834b,0x28dd045f,0x7ae202a1}},	//   _vete_, vete, _फैलि, _ssot,
   {{0x69da834c,0x2d9e834d,0x2284834e,0x69c36aaf}},	//   wete, _wete_, _kök_, _acne,
   {{0x2d9e834f,0x69c300b3,0xe45700ca,0x2fc40154}},	//   _tete_, _bcne, ויקט_, _icmg_,
   {{0x63a48350,0x7ae2033b,0x6ffe020a,0x78ba8351}},	//   hain, _vsot, _făcâ, tutv,
   {{0x63a48352,0x29188353,0x69da8354,0x7cca01d4}},	//   kain, ára_, rete, _mərk,
   {{0x63a48355,0x7ae28356,0x9c7c0154,0x78ba1e81}},	//   jain, _tsot, _frčr, rutv,
   {{0x63a48357,0x78ba0f63,0x44c80364,0x291800c6}},	//   dain, sutv, eß_, šra_,
   {{0x69da8358,0x7afd3813,0x7bc000f2,0x69c3033c}},	//   qete, åste, lgmu, _gcne,
   {{0x2edb0d77,0x61e702ef,0x63a48359,0xdb000610}},	//   _यन्त, _rajl, fain, damé,
   {{0x63a403ea,0x69ca0961,0x61e70542,0x7aed00d8}},	//   gain, त्री, _sajl, _šati,
   {{0xeabc0081,0x61e7022e,0x2bd00096,0x53340cb0}},	// [8790] _অনুম, _pajl, थ्या, ветт,
   {{0x27e93beb,0xdb00835a,0x2284835b,0xc2c40037}},	//   _haan_, ramè, _dök_, ئيلي,
   {{0x63a4835c,0xd13100e3,0x61e7835d,0x31c4008f}},	//   bain, دما_, _vajl, ъств,
   {{0x3cf40213,0x27e94d4e,0x63a40b87,0x20060216}},	//   ्मने_, _jaan_, cain, gjoi_,
   {{0x61e7835e,0x0f350260,0x27e90242,0x22840233}},	//   _tajl, رکرد, _maan_, _gök_,
   {{0x780c009d,0x27e9835f,0xe61f0231,0x00000000}},	//   _हक्क_, _laan_, mpôs_, --,
   {{0xf41f0212,0x25a18360,0x00000000,0x00000000}},	//   _klä_, _mehl_, --, --,
   {{0x7cca0092,0x3eb20138,0x27e9041c,0x2d870076}},	//   _mərh, šyta_, _naan_, scne_,
   {{0xef54008f,0x316300c4,0x3da702cf,0x00000000}},	//   _акть, _hzjz_, _жреб, --,
   {{0x63a48361,0xfdf30378,0x6abb0188,0xf41f007b}},	//   zain, _आफिस_, ruuf, _llä_,
   {{0x27e909e3,0x09e10033,0x200d0313,0xf65f02b6}},	//   _baan_, বালা, _koei_, rtæl_,
   {{0x2b4007c0,0x628f1515,0x9f440146,0x27e90188}},	//   _žice_, _otco, _samé_, _caan_,
   {{0x63a42a67,0x27e91d11,0xcc3a00c1,0x7d180220}},	//   vain, _daan_, _צענט, časť,
   {{0x63a48362,0x2284238c,0xd9455a78,0x787e00e8}},	//   wain, _rök_, _пели, _būvd,
   {{0x2284070a,0xa50a3097,0x63a44e3f,0x6aa9465f}},	//   _sök_, чева_, tain, lsef,
   {{0x27e98363,0x6b89005a,0x7dd30587,0x3c3a00d9}},	//   _gaan_, nceg, lısı, tīvi_,
   {{0x41b63574,0x63a4372f,0xdb008364,0x6aa90b81}},	// [87a0] есет, rain, tamé, nsef,
   {{0x69c1036e,0x80c90081,0x7764019f,0x7cca00a7}},	//   ngle, রবন্, _izix, _fərh,
   {{0x63a48365,0x27e98366,0x629d02a1,0xdb008367}},	//   pain, _yaan_, _ewso, ramé,
   {{0xa2b21d48,0x59cf18ff,0x81c20033,0x7dd300a7}},	//   ेंद्, त्तर, ্যই_, hısı,
   {{0x7cca0092,0xe8df0174,0x200d43bf,0x6aa90537}},	//   _tərk, diọm_, _doei_, jsef,
   {{0x69c11100,0x6aa943cc,0x41c70096,0x00000000}},	//   jgle, dsef, _लायस, --,
   {{0x69c1042d,0x3243014d,0x7cca0092,0x201f0131}},	//   dgle, _серг, _kəri, _flui_,
   {{0x59c22231,0x388501d3,0xdee644ab,0x2c610031}},	//   _शाहर, _pērn_, _поби, tóda_,
   {{0xdcea8368,0x27e90270,0x6aa90ce3,0xd00f0076}},	//   rafı, _raan_, gsef, _الق_,
   {{0x27e98369,0x69c1836a,0xf3ff00de,0x7cca013c}},	//   _saan_, ggle, _nhãn_, _ləri,
   {{0x27e91359,0x395802b6,0x7764039f,0x0dc90076}},	//   _paan_, ærs_, _azix, _تبقى_,
   {{0x7cca00a7,0xb8d82172,0x00000000,0x00000000}},	//   _nəri, _चि_, --, --,
   {{0x27e902fd,0x7cca0092,0x81ab0033,0x8cc106eb}},	//   _vaan_, _sərh, ক্ট_, रंथो,
   {{0x27e90694,0x49920260,0x7e7d34a5,0xdb020161}},	//   _waan_, _حیدر, _èspe, _adoç,
   {{0x6441025a,0x27e9008c,0x787e00e8,0x77640415}},	//   élio, _taan_, _būve, _ezix,
   {{0xb4e102f0,0x7cca00a7,0xa6f500d3,0x25a10381}},	//   _धनी_, _cəri, _азиш, _wehl_,
   {{0x7cca0092,0x200d0f5a,0x3869063d,0x6b370139}},	// [87b0] _dəri, _roei_, _ihar_, _kámẹ,
   {{0xbbdd836b,0x200d0167,0x38690090,0xe61f0231}},	//   _मस्क, _soei_, _hhar_, rpôs_,
   {{0xb21b0120,0xb33b0216,0xe61f0231,0x00000000}},	//   _stæs, _deça, spôs_, --,
   {{0x443f01ff,0x6e951167,0xa3bb03a2,0x386901c2}},	//   _ñu_, виду, _घाट_, _jhar_,
   {{0xdee563fe,0xb4e1074c,0x7dd301e8,0x644800fd}},	//   толи, _धनु_, yısı, édie,
   {{0xed590231,0xde940037,0x6d5a1e8f,0x7cca00a7}},	//   мол_, اجنب, _byta, _zəri,
   {{0x6d5a0034,0x7e7a0113,0x38690634,0x7d1800d8}},	//   _cyta, _ditp, _ohar_, _časá,
   {{0x2ef50c0d,0x201f002d,0x3869003d,0x7cca00a7}},	//   _избр, _ului_, _nhar_, _xəri,
   {{0x6b890ca7,0x69c111fc,0x93f6013c,0x7dd32ddc}},	//   rceg, tgle, _şəkə, tısı,
   {{0x6aa943ef,0x69c1836c,0x6b890451,0x00000000}},	//   rsef, ugle, sceg, --,
   {{0x69c125ea,0xd94503fc,0xf1c62231,0x7dd30511}},	//   rgle, тени, र्टन, rısı,
   {{0xe73a10f7,0x69c1836d,0x7e7a029a,0x68fc0212}},	//   дем_, sgle, _zitp, årda,
   {{0x2616007a,0x7dd3008b,0x3869836e,0x00000000}},	//   _नकदी_, pısı, _dhar_, --,
   {{0xdb1b60d3,0x628016e7,0x00000000,0x00000000}},	//   nguí, _émoi, --, --,
   {{0xf3ff001f,0xc5e40033,0xdddb836f,0xe5a313c7}},	//   _chão_, মালপ, _otuž, риси,
   {{0x38698370,0x7cca00a7,0x3cf20285,0xe8d600ca}},	//   _ghar_, _qəri, ंटते_, _יוצר_,
   {{0xb33b0396,0x24860031,0x46e700ae,0x00000000}},	// [87c0] _peça, _čomu_, _адын_, --,
   {{0xb21b8371,0x42230ba9,0x6448020d,0x00000000}},	//   _stær, адув, édib, --,
   {{0xb33b00dd,0x3ead00b3,0x21760cbe,0xa5b7006e}},	//   _veça, _avet_, туар, _בליק_,
   {{0x6e2132dd,0xf1c60966,0x6d5a0138,0xeaf10179}},	//   _allb, र्जन, _ryta, _अछूत_,
   {{0x44220390,0xdfcf00e3,0x3ead61ff,0x8fc500cd}},	//   _ilk_, تين_, _cvet_, ازمن,
   {{0x6d5a0067,0x93f601d4,0x81a50068,0x62968372}},	//   _pyta, _şəhə, _محفل, mpyo,
   {{0xa3c9000c,0x3ead01e8,0x10a3004d,0x7f490850}},	//   ल्क_, _evet_, _висн, _exeq,
   {{0x6d5a1867,0xdc2a001c,0x59cf0d1a,0x7a240154}},	//   _vyta, بسته_, त्सर, _mòte,
   {{0xdee316e6,0x629606a3,0x44220231,0xa3bb00aa}},	//   _коти, npyo, _mlk_, _घाघ_,
   {{0x7e7a0db1,0x3869185e,0x1dc90096,0x7afd20ab}},	//   _uitp, _shar_, _रायत, åsta,
   {{0x332902a1,0x21bb00a1,0x386900f9,0x23e20034}},	//   zzax_, וזיא, _phar_, _पसंद,
   {{0x28c40455,0x3c3a01d3,0x25a7080e,0x92a9007f}},	//   लंबि, tīvu_, _žnl_, nałó,
   {{0x7c2202a6,0x387b0023,0x6441020d,0x7a240154}},	//   _ilor, _viqr_, élim, _pòtd,
   {{0xb8f400e3,0x44228373,0x70d2009f,0x7c226c50}},	//   _مكتب, _alk_, _सहूल, _hlor,
   {{0x38690099,0x55581612,0x4a7b040a,0x03c708a1}},	//   _thar_, варя_, _קרוב, ксам,
   {{0x41c600b7,0x9965004d,0x7c220154,0x00000000}},	//   र्घस, _стіл, _jlor, --,
   {{0x245802fd,0x0cbf0336,0x284a006e,0x7c2201dc}},	// [87d0] тать_, _एम्म, _רעפּ, _mlor,
   {{0x7c228374,0x4422043e,0x9f440472,0xdddb1515}},	//   _llor, _elk_, _camí_, _stuž,
   {{0x3ead2450,0x0cbd00c7,0x7c220d79,0xe01e0251}},	//   _svet_, _আন্ত, _olor, पसंद_,
   {{0xa2c30455,0x76558375,0x00000000,0x00000000}},	//   िंद्, lozy, --, --,
   {{0xa3cc0789,0x539a00a1,0x3c3a00d9,0x03d60796}},	//   _शॉट_, _רישו, hīvs_, _גורם_,
   {{0x7c228376,0x518700f6,0x09bd0033,0x7a2405aa}},	//   _alor, _шума, _অস্থ, _lòtb,
   {{0xb4b100a5,0x7c22684d,0x81cc0033,0xed560e2c}},	//   _ऑटो_, _blor, _শোক_, лош_,
   {{0x20f3084f,0x30da00c1,0x09ab0096,0x68260094}},	//   _ići_, _אַמע, चण्य, _kóde,
   {{0x3211109b,0xaca30065,0x0a390fe9,0x00000000}},	//   _kozy_, _isọl, ечны_, --,
   {{0x7c228377,0x20f30f39,0xb33b00fd,0xdb000072}},	//   _elor, _kći_, _leço, camí,
   {{0x07a602ec,0x7c228378,0x9ad30134,0xc7a608f9}},	//   ланн, _flor, _gịnw, линк,
   {{0x30da00c1,0x7c228379,0xf5ec00aa,0xc5e900ca}},	//   ײַטע, _glor, _छोड़ि_, _מד_,
   {{0x9f8a007a,0x6b9b837a,0x78ba01cb,0xb5110033}},	//   _tööd_, mbug, artv, _হেলথ_,
   {{0x2aba00a1,0x7c22837b,0x6b9b0270,0x20f300c4}},	//   _נמצא, _zlor, lbug, _oći_,
   {{0x70d20251,0x00000000,0x00000000,0x00000000}},	//   _सहेल, --, --, --,
   {{0x4ab70034,0xc90f02d5,0x44220036,0x74162296}},	//   _इटाव, ाहीम_, _qlk_, دورا,
   {{0xe1fa3031,0x68260143,0xa92000a7,0x442247e1}},	// [87e0] нга_, _códe, _çörə, _vlk_,
   {{0x55e6837c,0x26c20900,0x869b006e,0x7cca0092}},	//   _сооб, muko_, _רייז, _zəru,
   {{0x26c2837d,0x4422065c,0x00000000,0x00000000}},	//   luko_, _tlk_, --, --,
   {{0xe29a16dd,0x4422837e,0x7cca00a7,0xadc30065}},	//   _пам_, _ulk_, _mərt, _imẹl,
   {{0xdd9209b4,0x6456039f,0xdb004098,0x26c2837f}},	//   موش_, moyi, tamí, nuko_,
   {{0x69d38380,0xc1e70177,0x628600f9,0x7c22567b}},	//   _बॉली, _مکمل_, _iuko, _slor,
   {{0x62868381,0x26c20384,0x7c228382,0x63a6171d}},	//   _huko, huko_, _plor, _kekn,
   {{0x62868383,0x61ee403b,0xe4f707e2,0x26c201e9}},	//   _kuko, _habl, ुमति_, kuko_,
   {{0x61ee8384,0x7c2200dd,0xa3c9000c,0x81e70081}},	//   _kabl, _vlor, ल्ट_, ভার_,
   {{0x628601a6,0x61ee068e,0xddc81a30,0x26c28385}},	//   _muko, _jabl, _hidž, duko_,
   {{0x5bc60602,0x61ee1019,0x64440084,0x325700a1}},	//   _مقال, _mabl, knii, רסים_,
   {{0x64568386,0x61ee3317,0x26c24671,0x2fc602c9}},	//   joyi, _labl, fuko_, ngog_,
   {{0xcc5700f5,0xb33b00fd,0xddc80a39,0x6444008c}},	//   _גבאי_, _reço, _midž, dnii,
   {{0x27ed8387,0xa2c3023a,0x63a601ff,0x9f44061c}},	//   žen_, िंस्, _aekn, _mamà_,
   {{0xf99300a1,0x62868388,0x63a61183,0x5559008f}},	//   _פרק_, _auko, _bekn, тавя_,
   {{0x682622e7,0x62868389,0x375606c0,0x26c24874}},	//   _póde, _buko, ọdụ_, buko_,
   {{0x92590303,0x765500a5,0x6b820051,0x6286838a}},	// [87f0] ваат_, pozy, _mgog, _cuko,
   {{0x61ee838b,0x6286838c,0xbb3b00c1,0x6444838d}},	//   _cabl, _duko, געמי, anii,
   {{0xa3d53457,0x321100b6,0xddc8007e,0x61ee838e}},	//   _конч, _vozy_, _bidž, _dabl,
   {{0x63a634b3,0x6b82838f,0x2ef51553,0x00000000}},	//   _gekn, _ngog, изер, --,
   {{0x69d84f2f,0x61ee8390,0xddc801b3,0x6286092f}},	//   _obve, _fabl, _didž, _guko,
   {{0x44298391,0x443b8392,0x6b828393,0xaca40134}},	//   lha_, liq_, _agog, chịp,
   {{0x6b9b0090,0x62868394,0x20f3005f,0xe808030b}},	//   tbug, _zuko, _ući_, षामा_,
   {{0x44291371,0x62868395,0x26c28396,0x6aa206b0}},	//   nha_, _yuko, yuko_, _bwof,
   {{0x628000fd,0x26161c05,0xcda90037,0x6b9b066a}},	//   _émot, _नकली_, _لهذه_, rbug,
   {{0x6abb8397,0x26c24513,0x6b9b02c9,0x443b3177}},	//   rruf, vuko_, sbug, hiq_,
   {{0x5d84223e,0x64561114,0x44298398,0x7cca00a7}},	//   _المل, yoyi, kha_, _dərs,
   {{0x26c203f3,0x44298399,0x67fb00c2,0x3ea0020a}},	//   tuko_, jha_, _räjä, ţite_,
   {{0x4429839a,0x8c1a00a1,0xd90f0068,0x7c29839b}},	//   dha_, _שוני, تیں_, mher,
   {{0x7c29839c,0x26c2839d,0xc9870315,0x7cca00a7}},	//   lher, ruko_, _суди, _tərt,
   {{0x64a62ba6,0x26c2839e,0x63a6135f,0x443b839f}},	//   раба, suko_, _pekn, fiq_,
   {{0x44295b2d,0x6286005f,0x26c20051,0x7c2983a0}},	//   gha_, _puko, puko_, nher,

   {{0x645683a1,0x81c10081,0x66e66ff6,0x644400aa}},	// [8800] royi, ্জন_, _топа, rnii,
   {{0x628602e6,0xb33b01e8,0xc69300a1,0x61ee83a2}},	//   _vuko, _geçm, _ואז_, _qabl,
   {{0x442983a3,0x55bb00a1,0x61ee0087,0x7c2983a4}},	//   bha_, _במיו, _vabl, kher,
   {{0x442983a5,0x628683a6,0xfa8800de,0xeaa70037}},	//   cha_, _tuko, _lừa_, _وع_,
   {{0x442083a7,0x628607ac,0x7c3b044c,0x00000000}},	//   mki_, _uuko, diur, --,
   {{0x61ee009c,0x4096064f,0x7bd957cc,0x9c7c0357}},	//   _uabl, _врат, _abwu, _isči,
   {{0xac260f99,0xdb000653,0xcd06016d,0x61438063}},	//   ифик, damá, рчли, _дера,
   {{0x20e8008e,0x7c2983a8,0x6aa20c56,0x7c3b83a9}},	//   _işi_, gher, _pwof, giur,
   {{0x787f00d9,0x5a34008f,0xfa8800fe,0x7af9030a}},	//   _būvn, йнит, _bừa_, _crwt,
   {{0x442083aa,0x7a24009c,0x24780154,0xdb00003e}},	//   hki_, _bòta, _dōmi_, gamá,
   {{0x4420298f,0x7c290201,0xfa8800de,0x443b00a7}},	//   kki_, bher, _dừa_, yiq_,
   {{0x7c2972ce,0xb33b07aa,0x442983ab,0x442083ac}},	//   cher, _seçm, xha_, jki_,
   {{0x09e100c7,0x442083ad,0x81ac0081,0x4429047e}},	//   বাজা, dki_, _গান_, vha_,
   {{0x442083ae,0x44290078,0xaadb0341,0x20c9009d}},	//   eki_, wha_, _סחור, ांमध,
   {{0x442983af,0x442083b0,0x5fd7045f,0x443b83b1}},	//   tha_, fki_, ण्डल, tiq_,
   {{0xe97b00a1,0x442001af,0x69c84c28,0x442983b2}},	//   _בנוש, gki_, lgde, uha_,
   {{0x442983b3,0xf7731ac9,0x443b83b4,0xdcfa009e}},	// [8810] rha_, _باغ_, riq_, _fetħ,
   {{0x442983b5,0x44205702,0x69c80d3e,0xc7b10018}},	//   sha_, aki_, ngde, _بڑھ_,
   {{0x442083b6,0x442943f6,0x2a6903e3,0xe7ee00b6}},	//   bki_, pha_, _ɗab_, _जसमा_,
   {{0xa3ce05d4,0x059600cd,0x1dc9009d,0x44290078}},	//   _राय_, _پایگ, _राहत, qha_,
   {{0x63ad83b7,0xd9f816e2,0x161b009d,0x44397f07}},	//   maan, ्ञात_, _नकार_, _ims_,
   {{0x63ad83b8,0x6da20396,0x7c2900ca,0x00000000}},	//   laan, пиша, wher, --,
   {{0xa3ce2ebd,0x7c29687a,0x443983b9,0x61e5019f}},	//   _राम_, ther, _kms_, mehl,
   {{0x63ad83ba,0x1be90769,0x61e583bb,0x443900aa}},	//   naan, удии_, lehl, _jms_,
   {{0x7c3b83bc,0x7c2983bd,0x443901ce,0xdb003e43}},	//   riur, rher, _mms_, tamá,
   {{0x442083be,0x7c2983bf,0x63ad83c0,0x7a2406a3}},	//   zki_, sher, haan, _pòta,
   {{0x63ad83c1,0xfa880028,0x60c5005c,0x442083c2}},	//   kaan, _vừa_, nuhm, yki_,
   {{0x5c7514da,0x7bd902a4,0x6a25001c,0x44390565}},	//   _улет, _ubwu, _گفتم, _nms_,
   {{0x4420011d,0x63ad83c3,0xceb2006e,0x7bc90a4b}},	//   vki_, daan, ּיל_, mgeu,
   {{0x44200067,0x69dd0103,0x63ad0381,0x7ae90361}},	//   wki_, őseb, eaan, mwet,
   {{0x442083c4,0x63ad83c5,0xfa3400cd,0x6448016d}},	//   tki_, faan, _برند, édio,
   {{0x63ad83c6,0x3eb2013f,0x7bc983c7,0x442083c8}},	//   gaan, šyti_, ngeu, uki_,
   {{0x442083c9,0x7ae983ca,0xd467455b,0x61e501bf}},	// [8820] rki_, nwet, сите_, fehl,
   {{0x645d618a,0x7afd00c2,0x27f20188,0xddd80206}},	//   _eksi, ästy, _hayn_, covň,
   {{0xf77f001f,0x63ad3fdc,0x5a3a00c1,0x442083cb}},	//   meça_, baan, נגעה, pki_,
   {{0x7ae95b7d,0x63ad83cc,0xf77f0131,0x00000000}},	//   kwet, caan, leça_, --,
   {{0x9ad300ac,0x61e583cd,0x92f600d6,0x69c82ba4}},	//   _dịkw, behl, _учні, ygde,
   {{0x60c502e7,0x7cca0092,0xd2520018,0xf77f0131}},	//   buhm, _bərp, _رنز_, neça_,
   {{0x645d02fd,0x443900c2,0x20e8020a,0x00000000}},	//   _yksi, _yms_, _uşi_, --,
   {{0x1e862cad,0x69c801fa,0x9c7c00c4,0x7bc900fc}},	//   _глам, wgde, _opče, ggeu,
   {{0x09ac0081,0x9c7c0154,0xf1cf02c6,0x00000000}},	//   _খাবা, _osčv, स्कन, --,
   {{0x98a70b88,0xb33b01d4,0x23ad0138,0x63ad083e}},	//   _aynı_, _seçk, mųjų_, zaan,
   {{0x63ad83ce,0xf8ad01dc,0xf77f0131,0x69c801cb}},	//   yaan, نکي_, deça_, rgde,
   {{0x63ad025e,0xbb8600e3,0x27f2008c,0x6448014b}},	//   xaan, _الإي, _cayn_, édil,
   {{0xf1a80d77,0x23ad0138,0x291800bc,0x63ad83cf}},	//   गरान, nųjų_, ärab_, vaan,
   {{0x63ad83d0,0x7afd052f,0x41c73212,0x6594008f}},	//   waan, æste, _लाइस, зару,
   {{0x43960857,0x00000000,0x00000000,0x00000000}},	//   _ọrụ_, --, --, --,
   {{0x682608a8,0x25bf83d1,0x539900c2,0x443900ee}},	//   _tóda, şul_, рвая_, _qms_,
   {{0xb33b0253,0x63ad83d2,0xf77f0396,0x52151a19}},	// [8830] _keçi, raan, beça_, одат,
   {{0x63ad1f9a,0x9ad30174,0x9c7c14f3,0x23ad00c6}},	//   saan, _sịkw, _isču, dųjų_,
   {{0x63ad83d3,0x6826025b,0x443900c2,0xdb000e22}},	//   paan, _módn, _tms_, lamä,
   {{0x63ad008a,0x16070789,0x60c5005c,0x4439821f}},	//   qaan, शावर_, ruhm, _ums_,
   {{0xa3ce0b89,0x60c50899,0x287c00c1,0x661701c8}},	//   _रात_, suhm, אנאמ, _koxk,
   {{0xae03022d,0x31350642,0x2c4c00b6,0x200405aa}},	//   लाइन_, _дегр, věda_, _enmi_,
   {{0xac0919cb,0x661701ff,0x7a3f0139,0xdb000d67}},	//   инка_, _moxk, _látè, hamä,
   {{0xa4b800a1,0x7ae983d4,0x291e0138,0x787f00e8}},	//   צלחה_, twet, dyta_, _būvm,
   {{0x7bc90257,0xdb004638,0xddc3044c,0x00000000}},	//   rgeu, jamä, conş, --,
   {{0x394508d1,0x7ae958fe,0xf7cb02c6,0x2d9111bc}},	//   жног, rwet, ážní_, _üze_,
   {{0xa96932d3,0x7ae983d5,0xa3c91c3b,0x291e83d6}},	//   рина_, swet, ईला_, gyta_,
   {{0xe8df0028,0x3dc90022,0x6605020b,0x00000000}},	//   hiệm_, ɗawa_, _anhk, --,
   {{0xb6a30451,0x661701cb,0x00000000,0x00000000}},	//   миял, _boxk, --, --,
   {{0xb33b0b88,0x27f2008a,0x291e83d7,0x38ca00d1}},	//   _geçi, _wayn_, byta_, دایی_,
   {{0xf77f68a4,0x186a020f,0xa979006e,0x81c10033}},	//   reça_, _каки_, _דאַכ, ্জা_,
   {{0xb4660f1e,0xccf200a1,0xdb0000bc,0x3e690031}},	//   ікал, וכל_, bamä, kúto_,
   {{0x987b006e,0x38600113,0xe88900fe,0xf77f0131}},	// [8840] _דאקט, _ikir_, _kẻo_, peça_,
   {{0xfe650421,0x682610a8,0xc4e61cf2,0x23ad00c6}},	//   _سگ_, _kódo, _джой, vųjų_,
   {{0x765c12ff,0xae031860,0xd46a0b91,0xbf8a085f}},	//   mory, लाईन_, _вине_, абеж_,
   {{0x81e70f71,0x30761119,0x68260018,0xd5b10023}},	//   ভাগ_, цузс, _módo, ức_,
   {{0x087700c1,0xdd940077,0x437613c9,0x291e007f}},	//   קענט_, палы, _фунт, zyta_,
   {{0xdcba013d,0xa0a683d8,0x7a2400b3,0xe88900fe}},	//   ащи_, _магд, _ròto, _nẻo_,
   {{0x25ba366c,0xb33b83d9,0x388500e8,0x00000000}},	//   _mdpl_, _reçi, _mērs_, --,
   {{0x09b40f71,0xb33b0dea,0x290001b3,0x765c83da}},	//   জ্ঞা, _seçi, _čia_, hory,
   {{0x2d961037,0x63b90034,0xa2b20dc4,0x765c83db}},	//   _дрес, ówni, ेंट्, kory,
   {{0x291e013f,0xfce683dc,0x386000d1,0xa2c20c38}},	//   tyta_, _мозо, _akir_, _लिन्,
   {{0x195802e3,0xe8890023,0xdb000212,0xed5a0243}},	//   саны_, _dẻo_, damå, _тож_,
   {{0x291e83dd,0x8c140081,0x32183c59,0x25ba00c4}},	//   ryta_, ়োজন_, _lory_, _adpl_,
   {{0x249a0085,0x765c83de,0x6d4d020e,0xe94400d1}},	//   _atpm_, fory, şaat, ترکی,
   {{0x765c83df,0x09b40033,0xddda0154,0xb60400ae}},	//   gory, জ্জা, _oktō, мяск,
   {{0x45d400e5,0x00000000,0x00000000,0x00000000}},	//   ьорс, --, --, --,
   {{0x69da085e,0xdb000220,0x25a60218,0x784401f9}},	//   lfte, pamä, _đole_, tőve,
   {{0xf77f001f,0x2602058f,0x833500e5,0x00000000}},	// [8850] meço_, शाखी_, чнах, --,
   {{0x62800451,0x69da0364,0xf1c30023,0x7ae283e0}},	//   _èmol, nfte, _giờ_, _mpot,
   {{0x64410349,0xd2500103,0x439583e1,0x92cb0033}},	//   élis, ڑنے_, _нанс, লবে_,
   {{0x155a00a1,0x7ae27916,0x47c20a43,0x00000000}},	//   _לכתב, _opot, ষ্ঠী, --,
   {{0x63a2058a,0x06fb0378,0x60db0a39,0x37b00033}},	//   ñone, एटिव_, _ćumu, _কামর,
   {{0xee38004d,0x442b039f,0x69da0381,0x00000000}},	//   оні_, _hlc_, jfte, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61f583e2,0xa2c2030b,0x765c7906,0xc1040037}},	//   _hazl, _लिम्, zory, _توفي,
   {{0xf77f0161,0x9c130134,0x69da83e3,0x765c3642}},	//   deço_, _lọgh, ffte, yory,
   {{0x61f5061d,0x7a24022b,0x442b3794,0x88c9007e}},	//   _jazl, _fòtm, _llc_, блов_,
   {{0x61f583e4,0x442b009b,0x9c130134,0x644f007f}},	//   _mazl, _olc_, _nọgh, _ojci,
   {{0x7c2d025b,0x66e6004d,0x69da83e5,0x1bd50e3f}},	//   ďars, пома, afte, _ходя,
   {{0x765c83e6,0x249a0332,0x7ae20090,0x00000000}},	//   tory, _stpm_, _gpot, --,
   {{0xa3ce000f,0x682608a8,0xa6e30088,0xe8890023}},	//   _राह_, _tódo, óðar, _hẻm_,
   {{0x7afb83e7,0x00000000,0x00000000,0x00000000}},	//   lvut, --, --, --,
   {{0x765c83e8,0xc48308c3,0x0446036a,0xccf200c1}},	//   sory, елск, чебн, עכן_,
   {{0xa2c30789,0x27e00d2a,0x32180034,0x61f583e9}},	// [8860] िंग्, _ibin_, _pory_, _bazl,
   {{0x17570054,0x2fdf0124,0xa3ce0592,0x00000000}},	//   _מספר_, _abug_, _राव_, --,
   {{0x2eff02e7,0x442b83ea,0x00000000,0x00000000}},	//   _aruf_, _flc_, --, --,
   {{0x44240019,0x442b702c,0x1fd630a8,0xbe8a022f}},	//   _ôm_, _glc_, ठभेड, бске_,
   {{0x61f50b88,0xdb0b0052,0x290a615d,0x27e00052}},	//   _fazl, _degë, ̣ba_, _mbin_,
   {{0xe297007e,0x63a483eb,0x61f50233,0x7bdb06b0}},	//   _хар_, lbin, _gazl, efuu,
   {{0x8fa65fdd,0xe6a9099d,0xa1160018,0xd24f2c9a}},	//   _наве, _कब्ज, _عورت, _صنف_,
   {{0xdb0b0216,0x00000000,0x00000000,0x00000000}},	//   _gegë, --, --, --,
   {{0x63a483ec,0x61f50233,0x06e40033,0xd90d01dc}},	//   ibin, _yazl, মিডি, ییه_,
   {{0x27e00a75,0x3f80013f,0x2d9683ed,0x7afd77d4}},	//   _abin_, žius_, _храс, æsta,
   {{0xdca302ec,0x69da2ead,0x27e0010a,0x3b861f3e}},	//   _захи, rfte, _bbin_, _елег,
   {{0x63a460d1,0x00000000,0x00000000,0x00000000}},	//   jbin, --, --, --,
   {{0x7ae200e9,0xf77f0396,0x442b03a9,0x41dd0ded}},	//   _upot, reço_, _rlc_, न्डस,
   {{0x4b7b00ca,0xa7fb83ee,0x63a40172,0x00000000}},	//   _האדו, doñe, ebin, --,
   {{0x7a2d11ce,0x1c200251,0x68260103,0xf77f0231}},	//   _fútb, _बवाल_, _módj, peço_,
   {{0x63a483ef,0xd2510018,0x442b028d,0x27e00032}},	//   gbin, ھنا_, _qlc_, _gbin_,
   {{0xd7670068,0xa5f900ae,0x64411022,0x67bc00ca}},	// [8870] _ڈاکٹ, _депу_, éliq, _המחק,
   {{0x26cb83f0,0x9c130134,0xdb0b59c9,0xb18b007b}},	//   muco_, _tọgh, _degè, ссаж_,
   {{0x4fd52776,0x21270028,0xb33b00fd,0x26cb20df}},	//   джет, ánh_, _reçu, luco_,
   {{0x2eff0063,0x35d30336,0x41745f34,0x27e00090}},	//   _pruf_, _ताड़, رالس, _xbin_,
   {{0xa7fb22e7,0x26d983f1,0x26cb0143,0x644d03dc}},	//   coñe, ntso_, nuco_, mnai,
   {{0x2f230029,0x644d00e4,0x63af83f2,0x645f0abd}},	//   _rīgā_, lnai, _hecn, loqi,
   {{0x644d83f3,0x3cf70034,0xb33b0052,0xcfb500e5}},	//   onai, ंटें_, _veçu, _обвъ,
   {{0x628709b3,0x13b10081,0xaca30174,0x9f440036}},	//   _hijo, _ছাড়, _haịm, _lamù_,
   {{0xb33b01e8,0x644d83f4,0x2eff0063,0x7bdb590f}},	//   _geçt, inai, _uruf_, rfuu,
   {{0x644d0091,0x7afb007a,0x26cb413a,0x628783f5}},	//   hnai, rvut, duco_, _jijo,
   {{0xdb0b0018,0xd90f00cd,0x63a483f6,0x7a2401b9}},	//   _megé, ایع_, ybin, _mòth,
   {{0x629d6510,0x41dd0d7a,0x628783f7,0xf1dd83f8}},	//   _otso, न्तस, _lijo, न्तन,
   {{0x629d0197,0x09ac0081,0x210100cb,0xc5f20033}},	//   _ntso, _খারা, lčić_, ঞাসা_,
   {{0xdb26001c,0x628783f9,0xdb0b00b3,0x59d41e93}},	//   _توهی, _nijo, _regè, _दायर,
   {{0x2101005f,0x63a40a2c,0x1ddf04f8,0x9856282a}},	//   nčić_, tbin, प्यत, _отиш,
   {{0x628f83fa,0x644d83fb,0x27e00085,0xdb0b0113}},	//   _buco, gnai, _ubin_, _pegè,
   {{0x4b7a0130,0x628783fc,0x43431bc1,0xf7d700ca}},	// [8880] ַטעג, _bijo, ветв, _חופש_,
   {{0x644d117b,0xb5ca001c,0x62870a39,0x210102ef}},	//   anai, _بودم_, _cijo, kčić_,
   {{0x628733dd,0x644d83fd,0x3cf90034,0x87050281}},	//   _dijo, bnai, ्मों_, _قبیل,
   {{0x28c519af,0xa7fb08a8,0x644d10e4,0xcf46022a}},	//   _विनि, poñe, cnai, мней,
   {{0x6287034f,0x987b006e,0x628f0079,0xdd92001c}},	//   _fijo, קאנט, _guco, نوش_,
   {{0x628783fe,0xf1dd5ed7,0x14e200a4,0x41dd142e}},	//   _gijo, न्दन, _पहाण, न्दस,
   {{0x21670315,0x00000000,0x00000000,0x00000000}},	//   _жири_, --, --, --,
   {{0x628701ff,0x00000000,0x00000000,0x00000000}},	//   _zijo, --, --, --,
   {{0x984600d9,0x998c0095,0x3c4305aa,0x6e930076}},	//   _dēļ_, ridž_, _sèvè_, _للقا,
   {{0x4d762ce3,0xe7e1023a,0x210100c4,0x7a240139}},	//   _قطار, ग्ना_, bčić_, _kòti,
   {{0xa3c01fbb,0xa3ce009d,0x2d8c007e,0x644d83ff}},	//   ीला_, रला_, _igde_, ynai,
   {{0x699e000d,0x2b400995,0x26cb8400,0x3ea9044c}},	//   _ख्री, _žicu_, tuco_, ţate_,
   {{0xa7744766,0x2ba400c0,0x63af0d62,0x44321d42}},	//   ключ, _ग्या, _recn, dhy_,
   {{0x68fc8401,0x26d90a00,0xb8f40081,0x764e0d2d}},	//   årds, rtso_, _হন_, gnby,
   {{0x236d00e7,0x628f8402,0x63af0559,0x644d8403}},	//   _šej_, _suco, _pecn, tnai,
   {{0x62878404,0x660203e3,0xdb0b0103,0xc2990805}},	//   _sijo, _ɗoki, _segé, зках_,
   {{0xf48413fc,0x62875148,0x8c1b00ca,0x6595678b}},	// [8890] турн, _pijo, קומי, _папу,
   {{0x644d2460,0x9c130174,0x4432041c,0x00000000}},	//   snai, _kọch, ahy_, --,
   {{0x62876915,0xc5f200ca,0xa3d700a4,0x00000000}},	//   _vijo, _גדי_, _साप_, --,
   {{0x4432277e,0x210108a9,0x628f007e,0x2d8c8405}},	//   chy_, včić_, _tuco, _agde_,
   {{0x28c5099d,0x44295895,0xceeb00cd,0x62870161}},	//   _विभि, mka_, تران_, _tijo,
   {{0x44298406,0x7876016d,0x7a2405aa,0x999e00d2}},	//   lka_, máve, _fòti, ditů_,
   {{0x44298407,0x78768408,0x7a240428,0x9c130129}},	//   oka_, láve, _gòti, _nọch,
   {{0x44298409,0xa3d70fef,0x210108c5,0x2cac01cb}},	//   nka_, _साफ_, rčić_, _dwdd_,
   {{0x4429840a,0x78760161,0x00000000,0x00000000}},	//   ika_, náve, --, --,
   {{0xe9d9121c,0xa2c202d5,0x6ec4023a,0x21010880}},	//   чко_, _लिस्, _रितु, pčić_,
   {{0x4429840b,0x68463153,0x186a1d62,0x00000000}},	//   kka_, енна, зани_, --,
   {{0x787602c6,0xdce800e8,0x00000000,0x00000000}},	//   káve, _uzdā, --, --,
   {{0xbbbd009d,0x442913e2,0x7876016d,0x3ead0383}},	//   ोलीक, dka_, jáve, _jwet_,
   {{0x4429840c,0x78766596,0xf65200e3,0x68260072}},	//   eka_, dáve, ائح_, _módi,
   {{0x44290694,0x7c29840d,0xa9661da9,0x78760231}},	//   fka_, oker, _пиша_, eáve,
   {{0x4429840e,0x1ddf009d,0x3f8d0350,0x3e860139}},	//   gka_, प्तत, _ngeu_, _kítì_,
   {{0x7c29043e,0x28c500a5,0x78760161,0x443200d8}},	// [88a0] iker, _विडि, gáve, rhy_,
   {{0x4429840f,0xe1f70528,0x7a2405aa,0x5efe00b7}},	//   aka_, нгу_, _dòtw, लिस्_,
   {{0x4429025e,0x7c290f56,0x3ead32c3,0x44328410}},	//   bka_, kker, _awet_, phy_,
   {{0x44298411,0x7c298412,0x768b0034,0xbe8a0831}},	//   cka_, jker, _użyc, пске_,
   {{0x68260b0b,0x5fd1007d,0xc8ec277c,0x63b6008a}},	//   _códi, _हारल, _जन्म_, mayn,
   {{0x80db0081,0x63b6008a,0x7c298413,0x3ead0383}},	//   ণিজ্, layn, eker, _dwet_,
   {{0x3da502ec,0xa3d70b94,0x00000000,0x00000000}},	//   тріб, _साम_, --, --,
   {{0x63b6008a,0x7c298414,0x3ead022b,0x00000000}},	//   nayn, gker, _fwet_, --,
   {{0xa3ce00b6,0x661e8415,0x00000000,0x00000000}},	//   _राई_, _oopk, --, --,
   {{0x44298416,0x63b60188,0x7c298417,0x7a2d0206}},	//   zka_, hayn, aker, _púta,
   {{0x44290067,0x7876016d,0xaac216f8,0x63b60972}},	//   yka_, záve, _शिवक, kayn,
   {{0x2fc000e3,0x7c298418,0x44298419,0x63b60188}},	//   óigh_, cker, xka_, jayn,
   {{0x63b6008a,0x5a4600d3,0xa7fb1d55,0xead40208}},	//   dayn, _пэка, goña, _роль,
   {{0x442900a5,0x7876841a,0xaa570076,0x00000000}},	//   wka_, váve, _كلنا_, --,
   {{0x68260154,0x2bf40285,0xe4c4065c,0x00000000}},	//   _nódw, _आसां_, лётн, --,
   {{0x4429841b,0xd6db0f0c,0x7876001f,0x63b6841c}},	//   uka_, _ето_, táve, gayn,
   {{0x4429841d,0x78ba841e,0xa3d7048a,0x07f808ba}},	// [88b0] rka_, lstv, _साठ_, _سريع_,
   {{0x7876841f,0x51f832e3,0x2296052f,0x7c290a00}},	//   ráve, нную_, _dæk_, zker,
   {{0x78ba00d2,0x63b60188,0x68260d5a,0x7fd5224a}},	//   nstv, bayn, _sódi, вілі,
   {{0x64488420,0x3ead00a6,0x764706a3,0x68262c2d}},	//   édit, _pwet_, lijy, _pódi,
   {{0x141a13b6,0xdb0b052f,0x00000000,0x00000000}},	//   _חורב, _udgø, --, --,
   {{0xf77400c1,0x78ba345b,0x26141f88,0xd16700e5}},	//   נקס_, kstv, दायी_, _зъби,
   {{0x7c298421,0xf402002d,0x916500cd,0x28c50861}},	//   tker, _faţă_, _شهره, _विधि,
   {{0x5fd80e50,0xa3e702d5,0x3e72020a,0x00000000}},	//   _डायल, _मॉम_, râta_, --,
   {{0x3ed90037,0xce9500c2,0x7647423c,0x26db039f}},	//   _زواج_, _разъ, kijy, _nqqo_,
   {{0x7c294021,0x63b61326,0x28c51492,0x00000000}},	//   sker, zayn, _विदि, --,
   {{0x07a62a6a,0x2dd800e3,0xaca30174,0x63b6008c}},	//   канн, _سبلة_, _kpọl, yayn,
   {{0x63b60694,0x661e8422,0x201f2f8a,0x25aa0acc}},	//   xayn, _sopk, _joui_, कर्ण,
   {{0xfc46025b,0x2918004d,0xf65f3459,0x442c00e8}},	//   ších_, ørar_, rræn_, _ēd_,
   {{0xceb21723,0x2c4c030b,0x63b60188,0x248b037a}},	//   שים_, vědi_, wayn, _aicm_,
   {{0xfa880023,0x63b6008c,0xdb0b0103,0x78ba374d}},	//   _cừu_, tayn, _megí, cstv,
   {{0x2ae504dd,0x6b9b00e7,0xa7fb0042,0x7a2d0031}},	//   _कहाँ_, ncug, poña, _kúto,
   {{0xd4670478,0x63b6680e,0x7e638423,0xdd1900bd}},	// [88c0] тите_, rayn, konp, _aħże,
   {{0xa3d70d1b,0x229601c5,0x7d082db2,0x200d5d47}},	//   _साथ_, _væk_, _jérô, _anei_,
   {{0x64a64efe,0x3e692a19,0x6abe0179,0x200d024a}},	//   _шана, nútu_, _एट्र, _bnei_,
   {{0x63b6008a,0xc95200ca,0xd91a00c1,0x00000000}},	//   qayn, סמא_, וועל, --,
   {{0x78ba025b,0x63780139,0x200d078e,0x66f41677}},	//   zstv, _dúní, _dnei_, ेटिक_,
   {{0x71a300ae,0x78ba00f2,0x00000000,0x00000000}},	//   _варз, ystv, --, --,
   {{0x61fc8424,0x7a2d0206,0x614619d4,0x2d5700d3}},	//   _iarl, _pútn, _рева, кишь_,
   {{0x61fc6493,0xdfd200e3,0x7a2d0018,0xab86571b}},	//   _harl, _خير_, _búto, купк,
   {{0x61fc8425,0xa3e4030b,0x45180033,0x1e860f34}},	//   _karl, प्य_, ঠনিক_, _алам,
   {{0x682608ec,0x78ba0dab,0x61fe8426,0x61fc2e2f}},	//   _módu, tstv, ndpl, _jarl,
   {{0x3ea68427,0x02de00aa,0x2d9e0027,0xd917007b}},	//   lpot_, नझुन, _ifte_, вья_,
   {{0xa3ce250d,0xa3d70ccb,0x9b430470,0x6d5a034f}},	//   _राग_, _साध_, انیو, _ixta,
   {{0x6f028428,0x6826124d,0x3ea602f1,0x8cca058f}},	//   nvoc, _nódu, npot_, संको,
   {{0x78ba113c,0x6f020af3,0xa4d50c10,0x672002c3}},	//   pstv, ivoc, логі, ämja,
   {{0xfa770054,0xa3ce8429,0x97320103,0xa3d700ec}},	//   _שעות_, _राख_, لکیا, _साद_,
   {{0x7876025b,0x3c310146,0x54540379,0x61fe1cab}},	//   rávc, _káva_, авст, edpl,
   {{0x2d9e0b81,0x61fc3bd7,0x337511d9,0xa85800ca}},	// [88d0] _ofte_, _barl, угар, _שיחה_,
   {{0x35f5261f,0x61fc842a,0xdb00842b,0x41b50037}},	//   _спор, _carl, lamó, امار,
   {{0x61fc842c,0x78762299,0xdb0b0081,0x3ea601cb}},	//   _darl, láva, _regí, epot_,
   {{0xdb0b0068,0x61fc00a1,0x2d9e0fb2,0x05d30179}},	//   _segí, _earl, _afte_, _ताँब,
   {{0x6d5a01d4,0x78764729,0xc695006e,0x6aa2063d}},	//   _axta, náva, נאַ_, _ntof,
   {{0x7bc2842d,0x61fc0986,0x9f4f0216,0x00000000}},	//   _adou, _garl, legë_, --,
   {{0xeb99842e,0x7e63842f,0x787670f9,0xa2820281}},	//   ний_, ronp, háva, _ایلو,
   {{0x200d0012,0x7876128f,0xdb0b0161,0x1bb90037}},	//   _unei_, káva, _negã, رابع_,
   {{0x05d30980,0x9d230033,0x28c518ff,0x787600ea}},	//   _तांब, বছেন_, _विहि, jáva,
   {{0x78760871,0x38696bd7,0x3c310220,0x7bc28430}},	//   dáva, _akar_, _dáva_, _edou,
   {{0x2ba40521,0x776d6747,0x6abb01ab,0x00000000}},	//   _ग्वा, _ayax, ssuf, --,
   {{0x1ddf0569,0x2c090034,0x6e218431,0xb8eb397e}},	//   प्रत, वाओं_, _holb, _लि_,
   {{0x28c509a0,0x09e508c3,0x6e218432,0x44f5030b}},	//   _विवि, _болн, _kolb, _ať_,
   {{0x38698433,0xaf76006e,0x6e2105db,0x7f3a0142}},	//   _ekar_, טערס_, _jolb, געשו,
   {{0x69c3030b,0x6e2108c5,0x69d8009d,0xa3ea00d3}},	//   _idne, _molb, _माती, ндва_,
   {{0x04435736,0x24800559,0x78768434,0x00000000}},	//   бесн, umim_, báva, --,
   {{0x24801fd5,0x9f4405aa,0xb69b0231,0x00000000}},	// [88e0] rmim_, _lamò_, lvân, --,
   {{0xf1a90979,0x2907100b,0x24800131,0xdb0b00b3}},	//   نامه_, _krna_, smim_, _megà,
   {{0x3ebf0012,0x19b600c1,0x61fe0b97,0x4fa61e54}},	//   _avut_, רפער_, rdpl, гиев,
   {{0x6aad04f9,0x61fc8435,0x68fc052f,0x6f0201cb}},	//   _ħafn, _warl, ærdi, tvoc,
   {{0x61fc8436,0xc7d700a1,0x6e213c30,0x785200d9}},	//   _tarl, רוני_, _bolb, tāvj,
   {{0x6e218437,0xccfa0831,0x44228438,0x3ea602ac}},	//   _colb, ећи_, _hok_, rpot_,
   {{0x6aa2338b,0x44225a15,0xf8c5218b,0xe807000d}},	//   _stof, _kok_, _विषय, षयमा_,
   {{0x44228439,0x69c300f0,0x68260103,0x3b0611bc}},	//   _jok_, _adne, _móds, _proq_,
   {{0x628e843a,0x5a340b70,0x2907843b,0xa3d70490}},	//   _kibo, инит, _arna_, _सास_,
   {{0xa3e400e2,0xa2d5110f,0x2ba40789,0x4422843c}},	//   प्त_, यंत्, _ग्रा, _lok_,
   {{0x8d9316cc,0x44221db5,0x290700e9,0x26c0843d}},	//   _المش, _ook_, _crna_, _avio_,
   {{0x628e843e,0x44220170,0x69c3843f,0x78768440}},	//   _libo, _nok_, _edne, táva,
   {{0xa3ce0e72,0x29078441,0x56950095,0xdb008442}},	//   _राज_, _erna_, рагт, ramó,
   {{0x7c223584,0x7876662a,0x44228443,0x628e8444}},	//   _hoor, ráva, _aok_, _nibo,
   {{0x44224ec8,0x78768445,0x7a3600d3,0x55588446}},	//   _bok_, sáva, _câte, гаря_,
   {{0x442201e8,0x26de00d3,0x628e283d,0x78761f20}},	//   _cok_, ător_, _aibo, páva,
   {{0x442203ce,0x7c228447,0x628e0512,0xf1a70b31}},	// [88f0] _dok_, _moor, _bibo, грен,
   {{0x7c228448,0x628e8449,0x644600e7,0x7d080c96}},	//   _loor, _cibo, _emki, _ords,
   {{0x645a132d,0x4422844a,0xdb0b0018,0x7a3600fd}},	//   étic, _fok_, _megá, _gâte,
   {{0x7c22844b,0xe8d7040a,0x6e210c2e,0x72d50f94}},	//   _noor, רואר_, _solb, _комф,
   {{0x44c101b3,0x6e21844c,0x27e9666f,0xb3ba00a1}},	//   lė_, _polb, _mban_, _במרכ,
   {{0x7d0808a9,0xa1940077,0x628e844d,0xdb0b1f72}},	//   _brds, _гарч, _gibo, _negá,
   {{0x44c101b3,0x4422844e,0x7c2209e3,0xa3dc412e}},	//   nė_, _yok_, _boor, _ठाम_,
   {{0x0c250cfc,0x63ad844f,0x628e8450,0x62800036}},	//   рмин, nban, _zibo, _èmor,
   {{0x63ad8451,0x29070106,0x78a418c5,0x7c2251cb}},	//   iban, _srna_, _čiva, _door,
   {{0x44c101b3,0x4a451e61,0x27e936cc,0x6f0919f0}},	//   kė_, рнов, _aban_, _irec,
   {{0x7c220837,0x8e840080,0x63ad8452,0x5fb9007f}},	//   _foor, _الله, kban, _उजाल,
   {{0x7bc7013f,0x44c1013f,0x7c22008a,0x2a6500f9}},	//   ėjus, dė_, _goor, solb_,
   {{0xf7720dd0,0x2907005c,0xeb8e0a29,0x2bab030b}},	//   تاد_, _wrna_, _фи_, _ट्या,
   {{0x44228453,0xbb3a03c2,0x63ad6237,0x27e901e9}},	//   _sok_, _בעני, eban, _eban_,
   {{0x628e8454,0x89da00a1,0x44c1013f,0x7c220085}},	//   _ribo, _יחסי, gė_, _yoor,
   {{0x63ad8455,0x6f098456,0x628e348a,0x07b0026e}},	//   gban, _orec, _sibo, _fẹẹr,
   {{0x6aa48457,0xa3d7274c,0xc2460284,0x07b00139}},	// [8900] _çift, _सार_, анак, _gẹẹr,
   {{0x63ad7692,0xb77b0327,0x15460291,0x8cd6023a}},	//   aban, _באפש, _веом, _यमलो,
   {{0xe0da8458,0x44228459,0xeaf20490,0x628e845a}},	//   тве_, _tok_, _अन्त_, _vibo,
   {{0x6f09845b,0x35dc05a7,0x628e845c,0x4ea62155}},	//   _brec, _बाड़, _wibo, арка,
   {{0x6f0911ce,0xe7e802e8,0x628e845d,0x2bdc0096}},	//   _crec, ट्या_, _tibo, _याबा,
   {{0x7c227c8b,0x6f09845e,0x7d000018,0x78760031}},	//   _soor, _drec, járá, kávo,
   {{0x7c223447,0xdb0b0146,0x2ce80470,0xdd9901ce}},	//   _poor, _regá, اظتی_, уші_,
   {{0x6456845f,0x6f098460,0x69d8009d,0xf65f02b6}},	//   nnyi, _frec, _माही, træk_,
   {{0x7c222cbc,0xadba0037,0x44c10138,0xbea30d0f}},	//   _voor, _لهذا_, zė_, _матк,
   {{0x7c220db8,0x5a342cf2,0xc9860012,0x00000000}},	//   _woor, снот, иуни, --,
   {{0xa3d70c8c,0x78760871,0x63ad8461,0xdca30095}},	//   _साल_, rávn, yban, _дахи,
   {{0x44c1013f,0x3e7b00fd,0x63ad8462,0x7a2d4232}},	//   vė_, rête_, xban, _lúth,
   {{0x787d01f9,0x63ad2e7f,0x2487022b,0x00000000}},	//   jéve, vban, _ènmi_, --,
   {{0x44c101b3,0xa3e42a06,0x59dd058f,0xdb0b0537}},	//   tė_, प्स_, _मायर, _begæ,
   {{0x3a7b006e,0x00000000,0x00000000,0x00000000}},	//   _שטוד, --, --, --,
   {{0x27e91098,0x44c10138,0xe3b3212c,0x64560103}},	//   _uban_, rė_, ترس_, gnyi,
   {{0x63ad7c6b,0x44c1013f,0x98ab0034,0x9259001f}},	// [8910] rban, sė_, ącą_, гаат_,
   {{0xe7e80067,0x44c1013f,0xa6e3003e,0x63ad8463}},	//   ट्ठा_, pė_, óður, sban,
   {{0x261417ff,0x6f0900e9,0x63ad5cf1,0x92580219}},	//   दारी_, _srec, pban, шафт_,
   {{0xe3b847ff,0x785201d3,0x7d000103,0xc43500d1}},	//   _ключ_, tāvi, zárá, _اکست,
   {{0x6da511cc,0x59c60096,0x644d8464,0x7a2d0076}},	//   била, लणार, miai, _fúth,
   {{0x644d240c,0x14b80177,0x6f090220,0x2ca50072}},	//   liai, _حدیث_, _vrec, _ptld_,
   {{0x6f090150,0x30a40859,0x7d0001f9,0x7c9422e4}},	//   _wrec, _мртв, várá, орыц,
   {{0x6f090012,0x644d8465,0x628501b9,0x80cc02d5}},	//   _trec, niai, lmho, _हिते,
   {{0x6f0900d3,0x7a240383,0x7d0049d6,0x00000000}},	//   _urec, _pòtp, tárá, --,
   {{0x6ce702ec,0xe8f936c9,0x644d8466,0x78760103}},	//   _віде, гло_, hiai, távo,
   {{0xa3d717ff,0x69d800aa,0x644d02e3,0x999e0138}},	//   सला_, _मारी, kiai, entų_,
   {{0x9b9500e3,0x628501ec,0x78760094,0x2bdd00bc}},	//   _الإت, hmho, rávo, क्खू_,
   {{0xbb850080,0x64568467,0x644d8468,0x2bdc0640}},	//   _الشي, vnyi, diai, _याता,
   {{0x3c3801f9,0x7c3b1175,0x00000000,0x00000000}},	//   _véve_, lhur, --, --,
   {{0x64a60131,0x2ba6030b,0xe6435053,0x644d8469}},	//   саба, síců_, черп, fiai,
   {{0x7c3b846a,0x644d846b,0x2c610031,0x6285846c}},	//   nhur, giai, tódy_, emho,
   {{0xd3b908a1,0x6456846d,0x624b007f,0x00000000}},	// [8920] русі_, rnyi, rżon, --,
   {{0x26c215f4,0xf77201f9,0x787d846e,0x00000000}},	//   msko_, _واک_, réve, --,
   {{0x787d0018,0x2bf9846f,0x764e3fab,0x644d8470}},	//   séve, ्यां_, miby, biai,
   {{0x644d8471,0xdb008472,0x764e8473,0x00000000}},	//   ciai, mamö, liby, --,
   {{0x26c20c00,0x44320074,0x7c3b8474,0x2f184e41}},	//   nsko_, mky_, dhur, роль_,
   {{0x44320343,0x40968475,0x50960831,0x764e0150}},	//   lky_, _грат, _грађ, niby,
   {{0x1619000f,0xdc110081,0x44200138,0x44328476}},	//   दातर_, িউনস_, oji_, oky_,
   {{0x44328477,0x93c5020b,0xa06a0fe3,0x3897078e}},	//   nky_, _ngắ, _саба_, _gări_,
   {{0x26c215f4,0x9b5837e8,0x443205d6,0x764e0b58}},	//   jsko_, рипт_, iky_, kiby,
   {{0x7a3600fc,0x00000000,0x00000000,0x00000000}},	//   _bâta, --, --, --,
   {{0x290a0161,0xe3bf0072,0xd7f500c2,0xfe45001c}},	//   íba_, _loña_, озны, _بکنی,
   {{0x4432025b,0x44208478,0xdb0b0149,0xdb003acb}},	//   jky_, jji_, _begä, damö,
   {{0x44320871,0x44208479,0x7c6500e3,0x644d847a}},	//   dky_, dji_, _بالل, viai,
   {{0x4420847b,0x68fc02b6,0x645a014b,0x9aa4001c}},	//   eji_, ærds, étin, _همچو,
   {{0x644d847c,0x443200d4,0x59dd06eb,0x4420847d}},	//   tiai, fky_, _मातर, fji_,
   {{0x442000dd,0xb4e91827,0x26c21e4d,0x69da7855}},	//   gji_, _यही_, bsko_, lgte,
   {{0x644d847e,0x91b91031,0x249a404d,0xe3bf0328}},	// [8930] riai, игат_, _eupm_, _coña_,
   {{0x44201ee3,0x644d847f,0xe3bf0610,0x3897020a}},	//   aji_, siai, _doña_, _sări_,
   {{0x44320074,0xdce8030b,0x44208480,0x43958481}},	//   bky_, _vzdě, bji_, _манс,
   {{0x44200d1b,0x44320621,0x6a6f00f2,0x2e2b00f2}},	//   cji_, cky_, løft, _løft_,
   {{0x443904ea,0x9f0500e3,0xcee82ce3,0xd7fc006e}},	//   _ils_, توشو, مرون_, טהאל,
   {{0x4ac20096,0xdb0000bc,0x00000000,0x00000000}},	//   _शिजव, namõ, --, --,
   {{0xfe7000bf,0x7c3b8482,0x44398483,0x7ae20372}},	//   رده_, thur, _kls_, _aqot,
   {{0x5ac91719,0x3cfe8484,0x26c26392,0x69da008c}},	//   алим_, _dstv_, ysko_, egte,
   {{0xc0520341,0xb4d60ed3,0x7c3b12ea,0x9c7c0154}},	//   _חזן_, _सम्_, rhur, _apčs,
   {{0x7c3b8485,0x44320074,0x44208486,0x26c28487}},	//   shur, zky_, zji_, vsko_,
   {{0x9d551574,0x261d16e2,0x26c20034,0x35d30034}},	//   _بنات, मानी_, wsko_, _ताज़,
   {{0x186a1bec,0xa4140033,0x69da1044,0x2a6e01ff}},	//   рами_, _সত্য_, agte, _ekfb_,
   {{0x4432272c,0x28c5218b,0x44208488,0xdb0b34cb}},	//   vky_, _विकि, vji_, _begå,
   {{0x44398489,0x80ca0033,0x44200a4b,0x00000000}},	//   _als_, _রহস্, wji_, --,
   {{0x4432431e,0xa2c2000d,0x764e848a,0xf1dd000d}},	//   tky_, _लिङ्, riby, न्छन,
   {{0xd5dc05d4,0x7bdb848b,0xe3bf0042,0x00000000}},	//   _बावज, nguu, _poña_, --,
   {{0x4420848c,0x44320074,0x42261e54,0x2bdc009d}},	// [8940] rji_, rky_, одав, _यासा,
   {{0x4439429b,0x44320871,0x442000a5,0x6aa400e3}},	//   _els_, sky_, sji_, _éife,
   {{0x10a60c0d,0x44320074,0x4420848d,0x4439848e}},	//   циен, pky_, pji_, _fls_,
   {{0xa2a2000f,0x7876025b,0x23e103a2,0x4439848f}},	//   _कंप्, dávk, _फायद, _gls_,
   {{0x69da052f,0xa25b0220,0x7e6a3001,0x7680007b}},	//   ygte, _kvôl, tofp, pöyd,
   {{0x63a48490,0x246100c6,0x00000000,0x00000000}},	//   lcin, rėme_, --, --,
   {{0x672f00a5,0x61ee02a1,0x5efe05d6,0x7afb010a}},	//   zycj, _ibbl, लिङ्_, ewut,
   {{0x7a2d8491,0x3cfe02ef,0x27e001c2,0x2fda0421}},	//   _mútu, _vstv_, _ncin_, _خورد_,
   {{0x63a48492,0x6a7400b3,0x00000000,0x00000000}},	//   icin, làfi, --, --,
   {{0x27e003e3,0x2004054c,0x298a0e96,0x20060634}},	//   _acin_, _hami_, исно_, ldoi_,
   {{0x200437a6,0x63a48493,0xc27b00c1,0x69da8494}},	//   _kami_, kcin, שריי, rgte,
   {{0x20041114,0x20068495,0x63a400cc,0x6e2800e7}},	//   _jami_, ndoi_, jcin, _hodb,
   {{0x61ee68fc,0x7bc08496,0x7c652729,0x78ad12e8}},	//   _obbl, mamu, _عامل, _čave,
   {{0x63a400d9,0x20048497,0xddda0103,0x27e00052}},	//   ecin, _lami_, _kitű, _ecin_,
   {{0x65948498,0x63a400e7,0x27e001b9,0x6e280ac1}},	//   дару, fcin, _fcin_, _modb,
   {{0x320d08bb,0x20048499,0x7bc0628e,0x63a40060}},	//   _şey_, _nami_, namu, gcin,
   {{0x2aa00383,0xa3dc0096,0x00000000,0x00000000}},	// [8950] _jòb_, _ठार_, --, --,
   {{0x7bc02b51,0x20040af0,0xdb190154,0x290e007e}},	//   hamu, _aami_, _dewè, _krfa_,
   {{0x31c42983,0x7bc0849a,0x26d9849b,0x2004849c}},	//   ьств, kamu, luso_, _bami_,
   {{0x7bc0849d,0x2004849e,0x6e3a4fd9,0xa295097a}},	//   jamu, _cami_, _altb, _намі,
   {{0xdefb02fd,0x7bc0849f,0x81e700c7,0x63bd0029}},	//   рые_, damu, _মোঃ_, _iesn,
   {{0x46d3007d,0x9e34084c,0x6e28008c,0xdcef0a39}},	//   _तिनह, мечч, _codb, šečl,
   {{0x660584a0,0x2004805d,0x23980134,0xe3bf01ff}},	//   _mahk, _fami_, _ọji_, _joño_,
   {{0x660584a1,0x629d84a2,0x69ca84a3,0x60c5023b}},	//   _lahk, _kuso, _adfe, mshm,
   {{0x768b0067,0x6e2801c5,0x290e03e3,0x629d84a4}},	//   _używ, _fodb, _arfa_, _juso,
   {{0x2bab0c16,0x629d84a5,0x63bd3b31,0x66051d94}},	//   _ट्रा, _muso, _lesn, _nahk,
   {{0x629d84a6,0x60c5023b,0x7bc00115,0x20040201}},	//   _luso, nshm, bamu, _yami_,
   {{0xa3d70ef8,0x26d90b21,0x7bc0649e,0x63bd84a7}},	//   _साग_, fuso_, camu, _nesn,
   {{0x66052664,0xdb0b0018,0x78760146,0x60c50052}},	//   _bahk, _legú, návi, hshm,
   {{0x8b050067,0x629584a8,0x60c500dd,0xd9455be3}},	//   _częś, _nizo, kshm, _нели,
   {{0x69c184a9,0x60c500dd,0xe3bf0a43,0x63bd84aa}},	//   male, jshm, _coño_, _besn,
   {{0x69c10060,0x629d84ab,0x26d984ac,0x629500b3}},	//   lale, _buso, buso_, _aizo,
   {{0x63a43c99,0xe36384ad,0x62950018,0x60c500dd}},	// [8960] rcin, екти, _bizo, eshm,
   {{0x69c184ae,0x6295006d,0x7bc00193,0x63a484af}},	//   nale, _cizo, zamu, scin,
   {{0x200406a3,0x6d430039,0x7bc00595,0x7bcb00cc}},	//   _pami_, jzna, yamu, _odgu,
   {{0x38a10080,0x7bc0008a,0x63bd73d7,0x6e280087}},	//   _mór_, xamu, _gesn, _sodb,
   {{0x69c13813,0x7bc00006,0x629d023f,0x200457b7}},	//   kale, vamu, _guso, _vami_,
   {{0x69c184b0,0x20040201,0x629544b8,0xdd900068}},	//   jale, _wami_, _gizo, نڈا_,
   {{0x69c184b1,0x7bc084b2,0x2ee6572b,0x602624f7}},	//   dale, tamu, stof_, _едва,
   {{0xb0d1009d,0xf8c51efb,0x629d0332,0x62954102}},	//   _हितग, _विजय, _yuso, _zizo,
   {{0x7bc084b3,0x69c151d9,0x2a6c0120,0x00000000}},	//   ramu, fale, todb_, --,
   {{0x69c184b4,0x7bc084b5,0x7f3b00a1,0x3860041c}},	//   gale, samu, _העמו, _ajir_,
   {{0x7bc00fa0,0xa3dc2065,0xd90e00d1,0x6605007b}},	//   pamu, ठला_, ایب_, _rahk,
   {{0x315713b6,0x7d7b00c1,0x660584b6,0xe7e80e1f}},	//   ליין_, _פראג, _sahk, ट्ला_,
   {{0x63bd1208,0xe3bf03be,0x47340a29,0x60c50216}},	//   _resn, _soño_, еняс, zshm,
   {{0x69c184b7,0x38a10102,0xe45f2e0e,0xe3bf002b}},	//   cale, _fór_, _sjö_, _poño_,
   {{0x26d9259e,0x7876025b,0x776403be,0x629d0270}},	//   suso_, závi, _exix, _suso,
   {{0x26d984b8,0x629d6c76,0xab5d00a5,0xdb0b002b}},	//   puso_, _puso, saże, _regú,
   {{0xdb0b09e9,0x248984b9,0x63bd2029,0x660584ba}},	// [8970] _segú, rmam_, _vesn, _tahk,
   {{0x60c500dd,0x4ad40cf6,0xddc30181,0xaad41677}},	//   tshm, _दिनव, konš, _दिनक,
   {{0x63bd0211,0x787d00fd,0x24890233,0xe3b00103}},	//   _tesn, névo, pmam_, ئرہ_,
   {{0x69c184bb,0x60c500dd,0x629d0517,0xe0d002fc}},	//   zale, rshm, _tuso, ازل_,
   {{0xe80e039d,0x69c184bc,0xd7db00c3,0x60c584bd}},	//   ियता_, yale, _भाईच, sshm,
   {{0x442b84be,0x78760146,0x69d80096,0x238a0031}},	//   _hoc_, rávi, _मागी, ňujú_,
   {{0xc21200a1,0x60c50216,0x00000000,0x00000000}},	//   _בהם_, qshm, --, --,
   {{0x442b211c,0x6b820294,0x2cac00fe,0x00000000}},	//   _joc_, _ọgan, _dtdd_, --,
   {{0xe821110f,0x69c1388d,0x442b84bf,0x6d430018}},	//   याना_, tale, _moc_, szna,
   {{0x442b0012,0x38a184c0,0x05dc000d,0x3da70c58}},	//   _loc_, _pór_, _बाइब, _храб,
   {{0xda1f0096,0x8c3c03e0,0xd94517de,0x644f039f}},	//   बाबत_, _buğd, фени, _omci,
   {{0x69c184c1,0x442b109b,0x7a2405aa,0x6d5f013c}},	//   sale, _noc_, _mòty, şqas,
   {{0xa3d70b95,0x260a02d5,0x9874078e,0x00000000}},	//   _साज_, ायली_, _aţă_, --,
   {{0x69c10201,0xf1ba00de,0x7ae984c2,0x7a3f020d}},	//   qale, ươi_, mtet, _bête,
   {{0x6a7d0472,0x442b84c3,0xd4f50109,0x1de00ff9}},	//   lèfo, _boc_, няты, _नासत,
   {{0x998301b3,0x26c40018,0x3ead044c,0x776401ff}},	//   ųjų_, ámos_, _otet_, _txix,
   {{0x7ae984c4,0x7c2b0124,0xa2d5417a,0x442b15bc}},	// [8980] ntet, _mogr, यंग्, _doc_,
   {{0x7c2b11ce,0x7ae984c5,0x7a3f0257,0x2fcd0150}},	//   _logr, itet, _fête, _adeg_,
   {{0x361b0130,0x442b396a,0x26c904a3,0x7ae94f9b}},	//   _וויד, _foc_, _zvao_, htet,
   {{0xdfcf0080,0x7ae9694b,0x3c310146,0x442b84c6}},	//   ليم_, ktet, _kávu_, _goc_,
   {{0xbefa09b4,0x7ae90018,0xbea345b1,0xe29f003e}},	//   تراض_, jtet, вачк, _guð_,
   {{0x768b0d1b,0x2d9a00d6,0x0caa0e3a,0xe3bf01ff}},	//   _użyt, øpe_, отии_, _zeñ_,
   {{0xa3e54d14,0xe821000d,0x16db1757,0xe2971456}},	//   _नाम_, यामा_, _बम्ब, _цар_,
   {{0x09c6009d,0x442b0428,0x7ae984c7,0x2be30096}},	//   लण्य, _xoc_, ftet, _गाणं_,
   {{0xae1e034d,0x78ad0357,0xe7f443e2,0x7ae984c8}},	//   पादन_, _čava, ेजना_, gtet,
   {{0x1e831c99,0x00000000,0x00000000,0x00000000}},	//   _алум, --, --, --,
   {{0x7ae984c9,0x6d5f11bc,0x7c2b2bc0,0x00000000}},	//   atet, şqar, _fogr, --,
   {{0x7c2b03a9,0x00000000,0x00000000,0x00000000}},	//   _gogr, --, --, --,
   {{0x5b360391,0x6ec11e05,0xf1de0285,0x8c110033}},	//   _تعار, रीपु, मलान, িউশন_,
   {{0x6b8249fc,0x442b794c,0x00000000,0x00000000}},	//   _izog, _soc_, --, --,
   {{0x442b0472,0x00000000,0x00000000,0x00000000}},	//   _poc_, --, --, --,
   {{0x7a3f0257,0x443d0034,0x7c2b002b,0x2c17007f}},	//   _vête, ów_, _xogr, थाएं_,
   {{0x52154a54,0x7d1c01cd,0x00000000,0x00000000}},	// [8990] ндат, _ársf, --, --,
   {{0x7a3f00fd,0x6b82024a,0x7a240154,0x00000000}},	//   _tête, _mzog, _pòty, --,
   {{0x7ae9224f,0xb06b16de,0x442b0632,0xf77000d1}},	//   ztet, ордж_, _toc_, _مای_,
   {{0x7ae91e55,0x64480472,0x442b84ca,0x76550383}},	//   ytet, èdit, _uoc_, lizy,
   {{0x6b8205bd,0x7c2b041c,0x00000000,0x00000000}},	//   _nzog, _rogr, --, --,
   {{0xa3cd02d5,0x7c2b84cb,0x00000000,0x00000000}},	//   रणव_, _sogr, --, --,
   {{0xdfd50084,0xba3d00b6,0x6b82246c,0xdb1b0072}},	//   _повы, způs, _azog, rauí,
   {{0x9b0524e9,0xfd6500de,0xaca30174,0xdde9001c}},	//   езид, _khuẩ, _nrụl, ترچه_,
   {{0xed580181,0x3ead84cc,0x7ae900c2,0x2499037a}},	//   _veľa_, _utet_, utet, _mism_,
   {{0x7ae984cd,0xe29f003e,0x3b0d0216,0xa9251553}},	//   rtet, _urðu_, rveq_, едол,
   {{0x7ae963f5,0x61e10102,0x29116a6b,0x7c2b0037}},	//   stet, _öllu, íza_, _togr,
   {{0x39580037,0x24990117,0x00000000,0x00000000}},	//   úrsa_, _nism_, --, --,
   {{0x765584ce,0x628700dc,0x00000000,0x00000000}},	//   fizy, _ohjo, --, --,
   {{0xceb284cf,0x00000000,0x00000000,0x00000000}},	//   רים_, --, --, --,
   {{0xa8060587,0x00000000,0x00000000,0x00000000}},	//   _alış, --, --, --,
   {{0x52aa008f,0xe82102d5,0x2af300aa,0x00000000}},	//   звам_, याणा_, _अहाँ_, --,
   {{0x96965dd5,0xfd650028,0x9c82025b,0x69dc00a5}},	// [89a0] _прош, _chuẩ, íčin, óreg,
   {{0xa3dc2dfd,0xe814009f,0xc20a00aa,0xdbdb0139}},	//   _ठाक_, _तोता_, _होखब_, _láàf,
   {{0x78ab002d,0x261d00c3,0xc6930142,0x00000000}},	//   _învă, मारी_, _גאז_, --,
   {{0xe29a344d,0x41e2009d,0xa06784d0,0xdfd200cd}},	//   _нам_, _पावस, наха_, ايش_,
   {{0x645684d1,0x0665001c,0x11d60120,0x00000000}},	//   miyi, _سایپ, _півр, --,
   {{0x645684d2,0x20e0009d,0x09d50033,0x21760138}},	//   liyi, खंदळ_, ত্তা, _зубр,
   {{0x787600d4,0xe7e600a4,0x00000000,0x00000000}},	//   návs, _काढा_, --, --,
   {{0x6456408e,0xab5d007f,0xcd03007b,0x00000000}},	//   niyi, waża, учши, --,
   {{0xeaaf00cd,0x81e70081,0x6a7400b3,0x00000000}},	//   یعی_, _মোট_, dàfr, --,
   {{0xc33300a1,0x5a3402b3,0x61fe84d3,0xfe6d001c}},	//   טוח_, тнот, nepl, _وگو_,
   {{0x76551e2a,0xab5d00a5,0x6fa400a4,0x645684d4}},	//   vizy, raża, _ओलां, kiyi,
   {{0xfaa684d5,0x80d33087,0x9cd7028c,0x415b006e}},	//   _задо, _डिसे, _טובה_, לדיג,
   {{0x64440694,0x645601d4,0xe66707ec,0x61fe004d}},	//   dhii, diyi, етво, kepl,
   {{0x320a0185,0x61fe25f2,0x7b0601d3,0xb6045d83}},	//   _naby_, jepl, ērtī, ляск,
   {{0xe8210d0b,0x5fd0009d,0x61fe84d6,0x64560188}},	//   यादा_, हणाल, depl, fiyi,
   {{0x60de0808,0x765506a3,0x644400ae,0x7bc205aa}},	//   dupm, sizy, ghii, _jeou,
   {{0xc299333f,0x2fc6019c,0x7bc20154,0x00000000}},	// [89b0] дках_, daog_, _meou, --,
   {{0x6467025b,0x61fe57d4,0x7a360257,0x216700d3}},	//   _špič, gepl, _bâti, нтег,
   {{0x65950a28,0x645684d7,0x41e2142e,0x6444010a}},	//   _јану, biyi, _पारस, bhii,
   {{0x6444020a,0x26cb84d8,0x00000000,0x00000000}},	//   chii, osco_, --, --,
   {{0x320a84d9,0x61fe84da,0x00000000,0x00000000}},	//   _faby_, bepl, --, --,
   {{0xee387a8f,0x2009013f,0x787600d4,0xdce100e8}},	//   нні_, žai_, návr, _uzlī,
   {{0x25e90d39,0x4429013f,0x78ad0234,0xab5d007f}},	//   _जानी_, oja_, _čavo, gażn,
   {{0xeb992ad3,0x09d90096,0x2d9e0313,0x00000000}},	//   мий_, ढल्य, _egte_, --,
   {{0xe7db2748,0x00000000,0x00000000,0x00000000}},	//   _भाजप, --, --, --,
   {{0x442984db,0x6aa201af,0xc334028c,0x64565784}},	//   hja_, _duof, רוץ_, ziyi,
   {{0x442921f9,0x186a28c2,0x00000000,0x00000000}},	//   kja_, дани_, --, --,
   {{0x442984dc,0x2d850b88,0x7bc205c2,0x2c17007f}},	//   jja_, _izle_, _geou, थाओं_,
   {{0x442984dd,0xf09207a6,0x7c2984de,0x3f9f0239}},	//   dja_, ינט_, mjer, _mguu_,
   {{0x7c290429,0x7c3b84df,0x442984e0,0x7a3f014b}},	//   ljer, lkur, eja_, _fêta,
   {{0x442984e1,0x3aeb004d,0x26cb028d,0x61fe00f2}},	//   fja_, løp_, asco_, vepl,
   {{0x442984e2,0x69c384e3,0x2907008a,0x320a00f9}},	//   gja_, _hene, _isna_, _saby_,
   {{0xe29a0131,0x64562f6e,0x69c384e4,0x64440f18}},	// [89c0] даа_, riyi, _kene, rhii,
   {{0x69c355fe,0x64440694,0x442984e5,0x3f9f0134}},	//   _jene, shii, aja_, _aguu_,
   {{0x442984e6,0x7c3b84e7,0xa5d900c1,0x3ebf0113}},	//   bja_, kkur, _אַרי, _awut_,
   {{0x44290d1b,0xdefa004b,0x61fe5cfe,0x78ad080e}},	//   cja_, дык_, sepl, _čavl,
   {{0xab5d00a5,0x3aeb004d,0xdee337fa,0x61fe0381}},	//   ważn, jøp_, иоци, pepl,
   {{0x29071909,0x6f0202db,0x7c290537,0x00000000}},	//   _osna_, rwoc, ejer, --,
   {{0x40966b41,0x71761f11,0x78a30079,0x7c2900f2}},	//   _арат, _شهرا, _nunv, fjer,
   {{0xdb0b0396,0x629c84e8,0x7c2984e9,0x7c3b84ea}},	//   _negó, _hiro, gjer, gkur,
   {{0x629c84eb,0xbea6013d,0x3f840335,0xe7e6009f}},	//   _kiro, _разк, _uzmu_, कलना_,
   {{0x69c384ec,0x629c84ed,0x442984ee,0x6569026a}},	//   _cene, _jiro, zja_, şehi,
   {{0x69c384ef,0x442984f0,0x7c2901c5,0x787d5320}},	//   _dene, yja_, bjer, lévi,
   {{0xc17300a1,0x629c023b,0x69c384f1,0xe3bf0143}},	//   יחת_, _liro, _eene, _toñi_,
   {{0x442984f2,0x69c384f3,0xada20088,0x2fc40063}},	//   vja_, _fene, _þúsu, _memg_,
   {{0x629c84f4,0xcf9300ca,0x78a3010a,0xc2110ff9}},	//   _niro, יטר_, _funv, _डोंब_,
   {{0x69c884f5,0xd49b2cd8,0xa3d5007e,0x644801d3}},	//   made, дра_, ловч, īdin,
   {{0x030e143d,0x629c401d,0x69c384f6,0x04b80018}},	//   सिंह_, _airo, _zene, کھیں_,
   {{0x629c84f7,0x34940219,0x6d5c0094,0x69c353dc}},	// [89d0] _biro, ратр, _žral, _yene,
   {{0x442984f8,0x69c80b6a,0xa3e502e8,0xe1f00080}},	//   sja_, nade, _नाव_, قسم_,
   {{0x442984f9,0xdb0b0472,0x629c84fa,0x645a05fe}},	//   pja_, _segü, _diro, ètic,
   {{0x442901e5,0x629c0029,0x69c884fb,0x645a0257}},	//   qja_, _eiro, hade, étit,
   {{0x7c29029b,0x63ad84fc,0xe7e8055c,0x60ce01dc}},	//   vjer, mcan, ट्टा_, _evbm,
   {{0x629c84fd,0x69c884fe,0x3ea40bc6,0x7ae00124}},	//   _giro, jade, _dumt_, dumt,
   {{0x69c8132d,0x7c290dd9,0x69c384ff,0xf41f0212}},	//   dade, tjer, _rene, _knä_,
   {{0x63ad8500,0x69c38501,0x6edb074c,0x69c8034f}},	//   ncan, _sene, _निपु, eade,
   {{0x69c32adc,0x7c295873,0x69c88502,0xab5d0034}},	//   _pene, rjer, fade, rażo,
   {{0x69c88503,0x27e90d30,0x6f092461,0x629c4d86}},	//   gade, _acan_, _isec, _xiro,
   {{0x6a7d015e,0x63ad8504,0x00000000,0x00000000}},	//   nèfi, kcan, --, --,
   {{0x69c38505,0xb8cb06eb,0x5fab00b6,0x7b1500d1}},	//   _wene, _कं_, _छलफल, _مبتذ,
   {{0x69c38506,0x69c88507,0xeaae0012,0x7bc90113}},	//   _tene, bade, _ый_, maeu,
   {{0xf1e2000d,0xe81400aa,0x69c30a4b,0x27e90027}},	//   _पाइन, _तोरा_, _uene, _ecan_,
   {{0x629c4621,0xa3e5397e,0x1543007e,0x290714f3}},	//   _riro, _नाश_, берм, _usna_,
   {{0x7bc98508,0x6f0901ac,0x60da0149,0x68e18509}},	//   naeu, _osec, _åtmi, muld,
   {{0x629c850a,0xa3e500a3,0xe73a00ae,0xd46700d3}},	// [89e0] _piro, _नार_, _чеп_, уите_,
   {{0x629c0090,0x63ad850b,0x09d50081,0x9c140134}},	//   _qiro, acan, ত্রা, _nọny,
   {{0x25e906eb,0xa49400cd,0x645a00fd,0x6f09850c}},	//   _जाती_, _نیست, étis, _asec,
   {{0x63ad013d,0x69c8850d,0x61e502bc,0x629c850e}},	//   ccan, zade, aghl, _wiro,
   {{0x68e1850f,0x69c88510,0x2ca5009c,0x24808511}},	//   huld, yade, _auld_, mlim_,
   {{0x248001e5,0xd252110a,0x69c84336,0x99850138}},	//   llim_, _طنز_, xade, nklų_,
   {{0x69c88512,0x6f098513,0x9c140174,0x59dd009f}},	//   vade, _esec, _dọny, _माजर,
   {{0x68e15c63,0x2ca50313,0x69c88514,0x6ecd00c3}},	//   duld, _duld_, wade, _सिचु,
   {{0x6edb19af,0x38a80257,0x9f4a00c2,0xfbcf096a}},	//   _नियु, _sûr_, ämän_, ستي_,
   {{0x2ca501c5,0xdd8f0401,0x7ae08515,0x68e1052f}},	//   _fuld_, _کوم_, rumt, fuld,
   {{0x63ad0253,0xe8210454,0x2ca5713b,0x6e9300e3}},	//   ycan, याला_, _guld_, _اللا,
   {{0x69c88516,0x7a3f00fc,0x00000000,0x00000000}},	//   sade, _fêto, --, --,
   {{0xd90e00bf,0x63ad08a9,0xb8cb00bc,0x41c400a4}},	//   زیک_, vcan, _कू_, षरास,
   {{0xdd20000d,0x1994013f,0x7a36014b,0x68e18517}},	//   _může, _каля, _pâtu, buld,
   {{0x68e1001f,0xe7ed030b,0x63ad8518,0x65950396}},	//   culd, _झापा_, tcan, раву,
   {{0xf1e2030b,0x63ad037a,0x93b50d4f,0x00000000}},	//   _पाउन, ucan, рбац, --,
   {{0x28da000d,0x32550c2d,0x855b0139,0x386901ee}},	// [89f0] _भिडि, авар, _dìtẹ, _ijar_,
   {{0x61e5023e,0x200d00dc,0x6fc711c6,0x24920206}},	//   ughl, _saei_, ारभू, amym_,
   {{0x78ad015c,0xdfd10037,0x63ad1ba9,0xdb0b01ab}},	//   _čavk, قيا_, pcan, _legð,
   {{0x3f158519,0x776d0090,0x00000000,0x00000000}},	//   идес, _kxax, --, --,
   {{0x260a009d,0x68e1020e,0xddc5851a,0x6b84009c}},	//   ायची_, zuld, абли, _ùigh,
   {{0xed59851b,0x6a7d06a3,0x68e10555,0x6f091e15}},	//   кол_, pèfi, yuld, _vsec,
   {{0x51840138,0x776d016d,0xe7e614e5,0x9d451b60}},	//   _гута, _lxax, _काला_, рейд,
   {{0x201f0012,0x68e12d15,0x3ff900c1,0xfc31071c}},	//   _unui_, vuld, _שפּע, تحت_,
   {{0x6f09404b,0x28c200aa,0x5ac6004b,0x00000000}},	//   _usec, वीसि, алым_, --,
   {{0x3869851c,0xa2dd0ff9,0xf2d4006e,0x68e1851d}},	//   _ajar_, _पिन्, זעץ_, tuld,
   {{0xa9691456,0x8bd5177a,0xd8260ce5,0xb4d400aa}},	//   тина_, _نقاش, адни, _हटे_,
   {{0xe73a5ac0,0x68e1851e,0x25fb02d5,0x657e02ac}},	//   вем_, ruld, _लॉबी_, _ryph,
   {{0x81dd00c7,0x657e76b0,0x38690078,0xb887003e}},	//   থ্য_, _syph, _djar_, _smíð,
   {{0xbb840037,0x68e17143,0x00000000,0x00000000}},	//   _الهي, puld, --, --,
   {{0x776d0072,0x64480138,0x43b30134,0xf4841ac9}},	//   _exax, ūdim, _ụrụ_, ماری,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645a025a,0x24801f1f,0xb86501c3,0x00000000}},	// [8a00] étiq, rlim_, _داوو, --,
   {{0x41b61230,0x26d205bd,0xb22300ae,0x42234e5c}},	//   рсат, _ivyo_, омул, одув,
   {{0x4fc6013f,0x765c851f,0x3cf402d5,0x00000000}},	//   асла, miry, _आहें_, --,
   {{0x765c8520,0xf9920327,0x1aee0033,0x41e2088d}},	//   liry, קרא_, ড়িতে_, _पाकस,
   {{0x64468521,0x2d810364,0x442200d7,0x00000000}},	//   _ilki, ühen_, _ink_, --,
   {{0x44226d32,0x00000000,0x00000000,0x00000000}},	//   _hnk_, --, --, --,
   {{0xb4e40455,0xdb0b01cd,0x9c4625a9,0xc1170018}},	//   _नमो_, _segð, ихил, _پہنچ_,
   {{0x10a31011,0x26d20239,0x765c01c2,0x00000000}},	//   _фитн, _ovyo_, hiry, --,
   {{0xd5c62a45,0x765c8522,0x44220234,0xaa660e2d}},	//   वराज, kiry, _mnk_, иток,
   {{0x44228523,0x850600b6,0x00000000,0x00000000}},	//   _lnk_, शबाट_, --, --,
   {{0x29188524,0x021700ca,0x00000000,0x00000000}},	//   íra_, בחים_, --, --,
   {{0xdb190364,0xd9ea10e9,0xdb09015e,0xa3e500bc}},	//   _bewä, ज्जत_, cceï, _नाइ_,
   {{0x7c2201e9,0x95cb63df,0x9a862d06,0x29020a7f}},	//   _inor, кува_, _кукл, ňka_,
   {{0xdbf800c7,0x64468525,0x44228526,0xfd110103}},	//   _অফিস_, _alki, _ank_, _بجے_,
   {{0x693400d3,0x03c76ab4,0x00000000,0x00000000}},	//   _ынку, исам, --, --,
   {{0x38694b82,0x71270281,0x645a0231,0xa99b00d7}},	//   _ujar_, یرال, étip, _בבור,
   {{0xdb1902e2,0x499212eb,0xf1a70114,0x765c8527}},	// [8a10] _gewä, _دیگر, арен, biry,
   {{0xe4e700d6,0x7d1a01bf,0xab79006e,0x00000000}},	//   _кімн, _orts, אָעז, --,
   {{0x2459004c,0x6441648b,0x80f58528,0xdcfa0031}},	//   _бань_, ëlis, спех, _bytč,
   {{0x44222245,0x5f9534df,0x7d1501f9,0x00000000}},	//   _gnk_, биет, _ázsi, --,
   {{0x93fa00a1,0xa28200bf,0xdfce0037,0x09de0033}},	//   _גלרי, _کیلو, ريو_, ব্যা,
   {{0xc3320130,0x9f560103,0x2b4d044c,0x00000000}},	//   _צום_, ágát_, vzec_, --,
   {{0x4ac40285,0x00000000,0x00000000,0x00000000}},	//   लीसव, --, --, --,
   {{0x765c3128,0x0c2537f2,0x44228529,0xdb0b01f9}},	//   ziry, смин, _xnk_, _megö,
   {{0xa3e5074c,0x3cfe2c68,0x93ef0096,0x753c007f}},	//   _नाई_, _eptv_, _छानच_, zyrz,
   {{0xaca30129,0x3e7b0257,0x4a453947,0x79e70018}},	//   _anụm, rêts_, снов, جودہ_,
   {{0xc7a600ae,0x499900c2,0x28c20285,0xdd152259}},	//   йинк, ытия_, वीलि, _دواخ,
   {{0x6f1b852a,0xa92700d8,0x3211852b,0xa2dd00a4}},	//   _kruc, _alží, _lazy_, _पिढ्,
   {{0x44d300a5,0x683f00dd,0xac7400e3,0xaad4000d}},	//   eć_, _mëdh, _بالش, _दिएक,
   {{0xa3e50179,0x7c220141,0x00000000,0x00000000}},	//   _नाउ_, _znor, --, --,
   {{0x25e90abe,0xf1ca025b,0x765c852c,0x44220063}},	//   _जारी_, ntáž_, riry, _pnk_,
   {{0x47c61c4c,0x6f1b852d,0x765c852e,0x673d0216}},	//   _убив, _oruc, siry, bysj,
   {{0x2327483b,0xe1fa3407,0x44d30034,0xa2dd349f}},	// [8a20] боти_, лга_, ać_, _पिण्,
   {{0x154630fd,0x175700ca,0xe7e600c3,0x6aa401ec}},	//   _геом, _לספר_, कलवा_, _èife,
   {{0x0ce21348,0xd17901b3,0xdfda00e5,0x00000000}},	//   _মন্ত, асці_, гъл_, --,
   {{0xdd2c013f,0xd6cf0281,0x6f1b852f,0x00000000}},	//   _nėšt, _تقی_, _bruc, --,
   {{0xa2a20455,0x21d812eb,0x261d0096,0xd00f0037}},	//   _कंट्, _نژاد_, माची_, عله_,
   {{0x6f1b02e2,0x787d488f,0x7d1a0381,0xa7fb2dc1}},	//   _druc, névr, _prts, miñe,
   {{0xd1320391,0x6f1b0174,0xa3cc0789,0x61e301cd}},	//   _عمر_, _eruc, _रजा_, ónle,
   {{0xf0638530,0x6f1b8531,0xf65f02b6,0x5c0604d9}},	//   _експ, _fruc, lsæt_, сяка,
   {{0x25e9121d,0x7c2200d8,0x00000000,0x00000000}},	//   _जाली_, _vnor, --, --,
   {{0xd90e03ed,0x683f0052,0xd8f8004d,0x09c80033}},	//   فیت_, _zëdh, аної_, _শাহা,
   {{0x5d860080,0x28f8004d,0x627b021e,0x7d1a0062}},	//   _الال, шень_, רנינ, _urts,
   {{0x96eb0138,0x673d007b,0x89d80504,0xa7fb01ff}},	//   льга_, tysj, دوگر_, kiñe,
   {{0x21270023,0x3c3800fd,0x6c7b006e,0x9b960037}},	//   ̣nh_, _févr_, _גראד, _الشت,
   {{0xe66705cf,0x1bf85dda,0x25a500f2,0x9c1c0174}},	//   стмо, ्जवल_, øll_, ị̄á_,
   {{0x321100a5,0xf65f0537,0x00000000,0x00000000}},	//   _razy_, dsæt_, --, --,
   {{0x6b82083e,0x00000000,0x00000000,0x00000000}},	//   _kyog, --, --, --,
   {{0x69ca8532,0x200601ff,0xa7fb01ff,0xf7f400d1}},	// [8a30] _kefe, deoi_, giñe, _رسيد,
   {{0xa3e5143d,0x6b8212ba,0x69ca1e6c,0xe8216935}},	//   _नाक_, _myog, _jefe, याका_,
   {{0x69ca0139,0x6b820361,0x66070095,0x6f1b009c}},	//   _mefe, _lyog, mejk, _sruc,
   {{0x69ca8533,0x753a0364,0x06ed02d5,0x6607007f}},	//   _lefe, ätze, _जमाव_, lejk,
   {{0x644d445f,0x69ca01a2,0x171c00c1,0xa7fb0042}},	//   mhai, _oefe, ָווע, ciñe,
   {{0x644d8534,0x30a7734e,0x5bb309c3,0x69ca5c9e}},	//   lhai, _грав, ीर्व, _nefe,
   {{0x6b820a15,0xc2120796,0x00000000,0x00000000}},	//   _ayog, _קהל_, --, --,
   {{0x69d83199,0x628503e5,0x6b82220a,0x69ca010a}},	//   _adve, llho, _byog, _aefe,
   {{0x69ca8535,0x290e0072,0x6f1b62c5,0x62850313}},	//   _befe, _asfa_, _uruc, olho,
   {{0xe8f90ce5,0x6b8200f9,0x645f019f,0x2fcf0b85}},	//   ало_, _dyog, hiqi, lagg_,
   {{0x644d8536,0x69ca51a2,0x2461013f,0x61fa0018}},	//   khai, _defe, nėms_, _ötle,
   {{0xa3e51677,0xc85a004d,0x290e033c,0x00000000}},	//   _नाग_, ршої_, _dsfa_, --,
   {{0x644d0055,0x7bcb00d9,0x291c5a7e,0xdb190139}},	//   dhai, _iegu, _erva_, _lewú,
   {{0x69ca1ae8,0xe7e60693,0xceb2006e,0x8afa021e}},	//   _gefe, _काका_, ויך_, _כהני,
   {{0x69c18537,0x7bcb10e3,0xe5a30360,0x644d8538}},	//   mble, _kegu, дири, fhai,
   {{0x644d445f,0xe3ba2249,0x62858539,0x76a00649}},	//   ghai, рба_, elho, _báyì,
   {{0x764b0138,0x4dca0033,0x69c1853a,0x7bcb853b}},	// [8a40] _įgyv, _রাসূ, oble, _megu,
   {{0x7bcb853c,0x69c1853d,0xa7fb08a8,0x69ca0042}},	//   _legu, nble, riñe, _xefe,
   {{0x644d445f,0x60c7022e,0x03a613cb,0x6aa3003d}},	//   bhai, _cwjm, _мино, _minf,
   {{0x644d107f,0xef1a4d79,0x6edb0557,0x7983185a}},	//   chai, име_, _निशु, _mynw,
   {{0x2f18334a,0x63b40034,0xda090f42,0x9f4f00b3}},	//   соль_, ągną, _वसंत_, degó_,
   {{0x64440694,0x6aa3853e,0x78a40673,0x21761603}},	//   lkii, _ninf, _liiv, _дубр,
   {{0x69ca853f,0x69c100f9,0xbc4a1f0d,0xe0d702b3}},	//   _refe, dble, ичие_, _мвр_,
   {{0x64448540,0xdee61167,0x69ca8541,0x3c310146}},	//   nkii, _моби, _sefe, _kávy_,
   {{0x9e663967,0x533700c1,0xa2cd02d5,0x00000000}},	//   _двад, ַנטן_, दीप्, --,
   {{0x645f0372,0x7bcb0af0,0xa2dd1f88,0x6b820027}},	//   ziqi, _eegu, _पिस्, _vyog,
   {{0x644400c2,0x644d8542,0x645f8543,0x7bcb003e}},	//   kkii, yhai, yiqi, _fegu,
   {{0x69ba0557,0x6aa38544,0x644d0197,0x7bcb8545}},	//   _श्री, _einf, xhai, _gegu,
   {{0x6444008a,0x6aa38546,0x78a400bc,0x6b824100}},	//   dkii, _finf, _diiv, _uyog,
   {{0x69d802b6,0x46dc1d72,0x6aa306a5,0x291c00d4}},	//   _udve, _बिरह, _ginf, _trva_,
   {{0x644d328f,0x66078547,0x7bcb8548,0x34950221}},	//   thai, rejk, _yegu, завр,
   {{0xe0190454,0x68e88549,0x246100c6,0x2cac854a}},	//   _नोंद_, mudd, vėms_, _mudd_,
   {{0x68e8854b,0x644d854c,0x6285039f,0x44c85c70}},	// [8a50] ludd, rhai, tlho, aş_,
   {{0x659542d1,0x644d854d,0x645f854e,0x24610138}},	//   _напу, shai, siqi, tėms_,
   {{0xdb090080,0x68e8854f,0xceb900b6,0x64440188}},	//   iceá, nudd, _stř_, bkii,
   {{0x26c90010,0x645f8550,0x224a01ff,0x246100c6}},	//   _kwao_, qiqi, _elbk_, rėms_,
   {{0x7bcb8551,0x645d8552,0x68e88553,0x2fcf5c3d}},	//   _regu, _imsi, hudd, ragg_,
   {{0x44390e9f,0x68e88554,0x2cac42e2,0x26c90051}},	//   _hos_, kudd, _budd_, _mwao_,
   {{0x44398555,0x7bcb8556,0x6aa318ba,0x68e8083e}},	//   _kos_, _pegu, _rinf, judd,
   {{0x44398557,0xef930018,0x68e81503,0x00000000}},	//   _jos_, _قیاد, dudd, --,
   {{0x44398558,0xab655876,0x9f4f0a43,0x7bcb8559}},	//   _mos_, явил, regó_, _vegu,
   {{0x4439855a,0x7e55003f,0x68e8083e,0x78a400c2}},	//   _los_, _عناص, fudd, _siiv,
   {{0x2cac855b,0x7bcb855c,0x3ead19bf,0x69c1855d}},	//   _gudd_, _tegu, _huet_, rble,
   {{0x69c10364,0x186a2917,0x00000000,0x00000000}},	//   sble, сами_, --, --,
   {{0x2fcd023e,0x3ea5022b,0x6aa30078,0xa2dd02d5}},	//   _meeg_, _kilt_, _tinf, _पिष्,
   {{0x2fcd855e,0x44391379,0x68e8855f,0x645d101e}},	//   _leeg_, _aos_, budd, _amsi,
   {{0x7ae98560,0x78a4032c,0xa9668561,0x764b00c6}},	//   luet, _tiiv, _ниша_, _įgyt,
   {{0x442611ce,0x2fcd0d7d,0x44398562,0x3ea50036}},	//   ño_, _neeg_, _cos_, _lilt_,
   {{0x443918c8,0x6444008a,0xdcf42461,0x7ae98563}},	// [8a60] _dos_, rkii, _đačk, nuet,
   {{0xa7fb08a8,0x64442bc4,0x7c3932dd,0x2fcd0036}},	//   miña, skii, _lowr, _aeeg_,
   {{0xe82102e8,0x44398564,0xa3e50eeb,0xc00600d6}},	//   याचा_, _fos_, _नाच_, зпек,
   {{0x1bea00a5,0x44398565,0x3ea50037,0x7ae901e9}},	//   _टाइल_, _gos_, _ailt_, kuet,
   {{0x9cf80081,0x2fcd8566,0xdfcf00ab,0x3ea50381}},	//   _আছেন_, _deeg_, ايه_, _bilt_,
   {{0x44390197,0x412a075f,0x3ea5026a,0xb1465f33}},	//   _zos_, _лого_, _cilt_, _енгл,
   {{0xe7ed02e8,0x4439022e,0x2056007e,0x7d780103}},	//   _झाला_, _yos_, _етар, غمبر_,
   {{0x44398567,0x68e80517,0xbab8194c,0x3ead00ee}},	//   _xos_, vudd, огих_, _fuet_,
   {{0x7ae9167e,0xdee3235c,0x7c39041c,0x3ea50973}},	//   guet, _поти, _dowr, _filt_,
   {{0x78ad706c,0x68e8083e,0x2fcd022e,0x2eb504a1}},	//   _čavr, tudd, _zeeg_, _ісус,
   {{0x6e2801c5,0x2fcd023e,0xdb090076,0x00000000}},	//   _indb, _yeeg_, rceá, --,
   {{0x68e88568,0x5f1309a1,0x765e8569,0x7c39008c}},	//   rudd, _धनम्_, _ampy, _gowr,
   {{0x443907bc,0x68e8856a,0x6e3a0078,0xfaf70470}},	//   _ros_, sudd, _kotb, _فروغ_,
   {{0xc6a4856b,0x76890088,0xdb9b00ca,0xe81d0eeb}},	//   ерси, mþyk, _הסדר, _बोरा_,
   {{0x92e900c7,0x4439856c,0x6fcc009d,0x92b90033}},	//   _মনে_, _pos_, ारां, _ঘটে_,
   {{0x765e1cd8,0x6e3a022b,0x00000000,0x00000000}},	//   _empy, _lotb, --, --,
   {{0x4439856d,0xe3b00678,0xa7fb08a8,0xe7c302f0}},	// [8a70] _vos_, ارف_, ciña, _व्यप,
   {{0x4439856e,0xe603007b,0x52d8007b,0x00000000}},	//   _wos_, ätää, ямую_, --,
   {{0x4439856f,0x463c2252,0x00000000,0x00000000}},	//   _tos_, _לעזע, --, --,
   {{0x645d019f,0x2fcd01fa,0x4add0fef,0xaadd0cce}},	//   _umsi, _qeeg_, _मिलव, _मिलक,
   {{0x3ea5007a,0x24890eaa,0x66178570,0x6e3a0381}},	//   _pilt_, mlam_, _kaxk, _botb,
   {{0x6e3a009c,0x2fcd0a88,0x2d858571,0xf774006e}},	//   _cotb, _weeg_, _pyle_, עקס_,
   {{0x66170694,0x7c3900a5,0x3ea5753f,0x2fcd023e}},	//   _maxk, _powr, _vilt_, _teeg_,
   {{0x3ea50505,0x7ae901e9,0x3cde0fef,0xe81d417e}},	//   _wilt_, tuet, _गिरे_, _बोला_,
   {{0x4add009d,0x2ca600f0,0xa3d500c3,0xa7fb0072}},	//   _मिळव, _diod_, _सजन_, xiña,
   {{0x39456eb1,0x2d8500a5,0x7ae901e9,0x4ad70018}},	//   дног, _tyle_, ruet, _ہاتھ_,
   {{0x24898572,0x7ae90634,0x2ca60381,0x7c390e2a}},	//   klam_, suet, _fiod_, _towr,
   {{0x25c61c83,0x6d430138,0x7e63007b,0xa7fb002b}},	//   वर्ण, myna, linp, tiña,
   {{0x6d438573,0xba55008f,0x00000000,0x00000000}},	//   lyna, _откъ, --, --,
   {{0xc8790702,0xa7fb08a8,0xdb21034f,0x6f04028e}},	//   duğu_, riña, _ñuño, çici,
   {{0x98720146,0x6d438574,0xa7fb0042,0x00000000}},	//   láč_, nyna, siña, --,
   {{0xd7ff002d,0x7e6300e7,0x78b301d3,0xa7fb0042}},	//   şări_, hinp, ēgvā, piña,
   {{0x64bc0039,0xd5af0068,0x6d430150,0x98720094}},	// [8a80] _očig, افہ_, hyna, náč_,
   {{0x24898575,0xe29701b6,0x63b6007f,0x7e6302ac}},	//   alam_, дау_, scyn, jinp,
   {{0x6aad0036,0xe8e000fe,0x987200d4,0x6e3a0365}},	//   _èaff, _trụy_, háč_, _rotb,
   {{0x24898576,0x7d1c003e,0xb7db006e,0x98720094}},	//   clam_, _ársi, ַקצי, káč_,
   {{0xc879026a,0x6e3a084e,0x6d43008c,0xe29a00ba}},	//   cuğu_, _potb, eyna, _мам_,
   {{0xdcba2a6e,0x64670034,0x2ca601ec,0x00000000}},	//   ощи_, ąpił, _siod_, --,
   {{0x0ee002e8,0x2df9001c,0x00000000,0x00000000}},	//   _निवड, سبوک_, --, --,
   {{0x25de2183,0x32180167,0x5b140832,0xfd4e0134}},	//   कृती_, _hary_, емит, _zukọ,
   {{0xc5e60081,0xa3c1007a,0x2fc669b9,0x3218007f}},	//   খ্যা_, ुरत_, mbog_, _kary_,
   {{0x6d438577,0x2fc607ac,0x1c1e0285,0x6934002d}},	//   byna, lbog_, _मोरल_, еноу,
   {{0x6d431b50,0xc87f0364,0x321800ca,0x00000000}},	//   cyna, toß_, _mary_, --,
   {{0xb90608c0,0x7b661bc1,0x00000000,0x00000000}},	//   _पि_, _отле, --, --,
   {{0xdca3255a,0xd78b00e3,0x3860009e,0x24897033}},	//   _раци, تخدم_, _dmir_, vlam_,
   {{0x3860004a,0x3eb90890,0x61fe01cb,0x00000000}},	//   _emir_, _éste_, jfpl, --,
   {{0x2489219b,0xb88602c6,0x00000000,0x00000000}},	//   tlam_, _smíš, --, --,
   {{0xa7fb08a8,0xd49815ef,0x6617008c,0x88c400d2}},	//   miño, дру_, _waxk, _vděč,
   {{0x6d4300a5,0x2fc6052f,0x32180891,0x61fe08bc}},	// [8a90] zyna, dbog_, _bary_, ffpl,
   {{0x32188578,0x24898579,0xae0000aa,0xa2b00285}},	//   _cary_, slam_, ल्मन_, _अंर्,
   {{0x248901e8,0xe3b00068,0x3218109b,0xa7fb0042}},	//   plam_, ارہ_, _dary_, niño,
   {{0x61fe1044,0x2fc6857a,0x64bc009c,0x00000000}},	//   afpl, gbog_, _dčid, --,
   {{0xe4560132,0xdb020028,0x442b857b,0xdee50aec}},	//   _נישט_, _ngoà, _inc_, холи,
   {{0x645a01d3,0xee38036c,0x6d433773,0x98720e4b}},	//   ītie, мні_, tyna, váč_,
   {{0x7e63857c,0x645a857d,0x00000000,0x00000000}},	//   rinp, ūtie, --, --,
   {{0xa1946eaa,0x6d43857e,0xa3c1049d,0x442b00ee}},	//   _расч, ryna, ुरि_, _jnc_,
   {{0x7e632d12,0x2ef4013d,0x442b0449,0x00000000}},	//   pinp, _изтр, _mnc_, --,
   {{0x442b0124,0x850f030b,0x1eea0281,0x08c5168c}},	//   _lnc_, ाबाट_, _رومی_, нбон,
   {{0xa3c114e5,0xf8660848,0x09c80033,0x26d901c2}},	//   ुरा_, евно, _শাখা, esso_,
   {{0x66e62bcf,0x9ac400bd,0x987200d4,0x88bc02c6}},	//   нома, _boċċ, páč_, dvěd,
   {{0x7c2b60c8,0x394901c2,0x00000000,0x00000000}},	//   _ingr, _ƙass_, --, --,
   {{0x95860095,0x442b857f,0x9ac400bd,0xa7fb0072}},	//   елге, _anc_, _doċċ, biño,
   {{0xa7fb0933,0x26d98580,0x23b50174,0xf202278e}},	//   ciño, asso_, _ụja_, र्फ़_,
   {{0x236d05db,0x14e100a4,0x00000000,0x00000000}},	//   _žeja_, _फिरण, --, --,
   {{0x2c0100a5,0xae000b95,0x27e0517d,0x24801ac3}},	// [8aa0] व्यू_, ल्डन_, _idin_, roim_,
   {{0x98d308d4,0xb77b00ca,0x7afb0634,0x644f11bc}},	//   _दबाए, _מאפש, itut, _elci,
   {{0x26c00ea3,0x61fe0149,0x7c2b8581,0xaf3605bc}},	//   _htio_, rfpl, _ongr, کرات,
   {{0x67248582,0xdfcf0080,0x2ee63da0,0x442b034f}},	//   _krij, ميم_, trof_, _gnc_,
   {{0x2fdf030a,0x00000000,0x00000000,0x00000000}},	//   _ddug_, --, --, --,
   {{0x7c2b3a7b,0x2fc66f3e,0xdb020023,0x29070c09}},	//   _angr, sbog_, _ngoá, _opna_,
   {{0xa3e40b89,0xafe607ec,0x27e08583,0xa7fb0072}},	//   _नया_, _повл, _odin_, xiño,
   {{0x2ee635dd,0x09d80096,0xa7fb002b,0x76a70139}},	//   prof_, ढण्य, viño, _kéyì,
   {{0x7afb1d11,0xdb1901bf,0x88bc02c6,0x290705db}},	//   gtut, _gewü, zvěd, _apna_,
   {{0x27e062ac,0x1f632f9f,0xef17013f,0xa7fb3c30}},	//   _adin_, _скум, _яму_, tiño,
   {{0x7afb0634,0x694614f3,0x753a042c,0xa3c000b6}},	//   atut, _očeš, ätzl, ँडा_,
   {{0x67248584,0xa7fb04d8,0xc17300ca,0x291a05db}},	//   _brij, riño, טחת_, _špas_,
   {{0x67242392,0x442b0027,0xdb0b01dc,0xa7fb213e}},	//   _crij, _rnc_, _nggè, siño,
   {{0x67240355,0x27e07b0f,0x442b00e5,0x34a92397}},	//   _drij, _edin_, _snc_, कद्द,
   {{0x25a50222,0x7c2b6676,0x67248585,0x27e001b9}},	//   äll_, _yngr, _erij, _fdin_,
   {{0x6d5802dd,0x67248586,0x27e0015c,0x629e01cb}},	//   izva, _frij, _gdin_, empo,
   {{0xc6a757ff,0x67248587,0x6aaa8588,0x88bc00b6}},	// [8ab0] _прои, _grij, _kiff, svěd,
   {{0x6aaa003d,0x6d580146,0x76a70139,0x68e8029a}},	//   _jiff, kzva, _déyì, ordd,
   {{0x442b45fd,0xf1240109,0x7afb01e9,0xa2dd05e4}},	//   _tnc_, льцо, ztut, _पिक्,
   {{0x644f8589,0x6aaa7ff9,0xd37101c3,0x7afb007f}},	//   _ulci, _liff, _نهج_, ytut,
   {{0xa2cd50da,0x7ff40190,0xdb19022b,0x798a084e}},	//   दीश्, اسما, _lewò, _lyfw,
   {{0x9f4f00bf,0x6aaa858a,0x00000000,0x00000000}},	//   nggé_, _niff, --, --,
   {{0x92a60067,0xdd910068,0xa194028d,0x93c600d3}},	//   _dołą, گوں_, _барч, sfăş,
   {{0x7afb013d,0x6aaa0178,0xcf7b0037,0x00000000}},	//   ttut, _aiff, _فإذا_, --,
   {{0xdd910068,0x200f858b,0xa3b9055c,0x32cf0034}},	//   دوں_, megi_, _चलन_, nży_,
   {{0x7afb63d1,0x200f858c,0xdb190154,0x7a3e02c6}},	//   rtut, legi_, _bewò, _nátě,
   {{0x7afb858d,0x6aaa17fc,0x67240292,0x26c00036}},	//   stut, _diff, _srij, _stio_,
   {{0x6724460e,0x201d858e,0x200f858f,0xdb190154}},	//   _prij, ndwi_, negi_, _dewò,
   {{0x6aaa8590,0xddd80087,0x7bc90441,0x3776147c}},	//   _fiff, lovš, mbeu, тынс,
   {{0x672478ff,0x31cb16f8,0x63bd02ce,0xdb19022b}},	//   _vrij, िरोध, _afsn, _fewò,
   {{0x6b8b4012,0x7ae98591,0xe81d37b3,0x32cf0034}},	//   _hygg, lret, _बोका_, eży_,
   {{0xc9520054,0x27e0100b,0x15ee0034,0x7bc90acb}},	//   _כמו_, _udin_, _जाकर_, nbeu,
   {{0x64a3013f,0x93431b82,0x7ae95cfe,0xfbd200ca}},	// [8ac0] рата, анте, nret, יתן_,
   {{0x7ae9002b,0x6b8b0b97,0xddd80ebd,0x00000000}},	//   iret, _mygg, kovš, --,
   {{0xd8770068,0x64930092,0x69ce003e,0x7bc91cab}},	//   _سمیت_, mçin, ðbei, kbeu,
   {{0x6946175b,0xddd80211,0x62870063,0x7a3e02c6}},	//   _učeš, dovš, _ekjo, _zátě,
   {{0x92a600a5,0x00000000,0x00000000,0x00000000}},	//   _połą, --, --, --,
   {{0x7ae90515,0x68e80150,0x975b00ca,0xad65001c}},	//   dret, yrdd, ודנט, گاهه,
   {{0x7ae98592,0x200f8593,0xddd805db,0x621b00d7}},	//   eret, begi_, govš, _קולק,
   {{0x6aaa8594,0x200f59cf,0x7ae98595,0x00000000}},	//   _siff, cegi_, fret, --,
   {{0x2d8101bf,0x8fa31061,0x307500d3,0x6aaa07ee}},	//   üher_, _вате, _сурс, _piff,
   {{0x5ea61dec,0x3eb90890,0x628304e9,0x6d5e002b}},	//   _شمال, _ésta_, čnog, úpas,
   {{0x7ae98596,0x3eab0206,0x67d50131,0x00000000}},	//   aret, žitú_, лону, --,
   {{0x7ae98597,0x4bda0177,0x00000000,0x00000000}},	//   bret, _آباد_, --, --,
   {{0x7ae91c8d,0xa3d6074c,0x9f5f01f9,0x6aaa3763}},	//   cret, हरन_, őrök_, _tiff,
   {{0xceb30341,0x200f8598,0xe94400d1,0x25bf1677}},	//   ייש_, zegi_, _مربی, ्रेण,
   {{0x984f00a5,0x3eac038c,0xc7c707c8,0x200f0174}},	//   jęć_, _midt_, _испи, yegi_,
   {{0x3eac0021,0x628702fe,0x57f52872,0x3dd80033}},	//   _lidt_, _skjo, _спит, _সাফল,
   {{0xb27533fd,0x2d8c8599,0x6672001c,0x200f01cd}},	// [8ad0] глаш, _lyde_, شگیر, vegi_,
   {{0x7aef0472,0x78ad023e,0x325400ae,0xbebd00e8}},	//   àcti, _hiav, авур, _brūn,
   {{0x200f452d,0xf1a71940,0x2d8c02b6,0x7ae9859a}},	//   tegi_, тран, _nyde_, zret,
   {{0x25ff04f1,0x7ae94e52,0x62800072,0x6722007e}},	//   श्री_, yret, _ímon, _šoji,
   {{0x200f859b,0x78ad0350,0x3eac4fb5,0x00000000}},	//   regi_, _miav, _bidt_, --,
   {{0x644d02fd,0x6b8b09ce,0x7ae9859c,0x2d8c02b6}},	//   lkai, _rygg, vret, _byde_,
   {{0x6285859d,0x30a74214,0xa3c70096,0x2d8c0231}},	//   moho, _арав, _उभा_, _cyde_,
   {{0x6285859e,0xc17200a1,0x644d859f,0x3a2e037a}},	//   loho, _החל_, nkai, _anfp_,
   {{0x6f09050d,0xac9600e3,0xca850451,0x7bc9855d}},	//   _upec, دنيا_, лгий, rbeu,
   {{0x7ae985a0,0x3f7a0130,0x62850146,0x7bc985a1}},	//   rret, _אָבע, noho, sbeu,
   {{0x644d0084,0x2ba4034c,0x64bc0206,0x186a0161}},	//   kkai, खेबा, _očia, еани_,
   {{0x7ae901ce,0x62856572,0x78ad404c,0x6b8b3fe4}},	//   pret, hoho, _ciav, _tygg,
   {{0x78ad85a2,0x7d1c01cd,0x38ba00e8,0x3b090c37}},	//   _diav, _ársr, _vīra_, _чело_,
   {{0x644d00c6,0x75d60037,0x7c3b49ac,0x00000000}},	//   ekai, طيرا, ljur, --,
   {{0xdb0b052f,0xa507061b,0x649a2b49,0x291901d3}},	//   _afgø, лера_, етар_, āsas_,
   {{0x7c3b0706,0x644d608a,0x78ad85a3,0x88bc00d2}},	//   njur, gkai, _giav, svěc,
   {{0x28d70c9c,0x33d500f3,0x8c1d0033,0x998700c6}},	// [8ae0] _भौति, ріст, থাপন_, _tonų_,
   {{0x6456092f,0x62851081,0x7e1d06ae,0x64930555}},	//   shyi, goho, पयोग_, lçil,
   {{0x4fea1d3f,0x00e65833,0x3eac009e,0x64560027}},	//   емен_, ужен, _ridt_, phyi,
   {{0x6493013c,0x644d00c6,0x00000000,0x00000000}},	//   nçil, ckai, --, --,
   {{0x442085a4,0x628585a5,0xbe8a2f93,0x9f34004d}},	//   mdi_, boho, нске_, релі,
   {{0xd2521a37,0x764e85a6,0x628585a7,0x661e05db}},	//   _انس_, nkby, coho, _japk,
   {{0x442085a8,0x3eac038c,0x6493020e,0x0caa007b}},	//   odi_, _vidt_, kçil, нтии_,
   {{0x661e013f,0x8fa60cc0,0x3ed609f4,0x628309ac}},	//   _lapk, _бабе, _مقرر, čnoe,
   {{0x442085a9,0x78ad00e5,0xa2dd009f,0x0a6a0114}},	//   idi_, _riav, _पिछ्, ерни_,
   {{0x644d02a7,0x442085aa,0x2d8c4e5f,0x661e0103}},	//   zkai, hdi_, _tyde_, _napk,
   {{0x199485ab,0x78ad0451,0x61e304c8,0x4420028e}},	//   раня, _piav, ónli, kdi_,
   {{0x4d7b0c6a,0x44201420,0x6ac30081,0x228f00bc}},	//   _ארבע, jdi_, _শিরো, tükk_,
   {{0xa2b004dd,0xead4280f,0x442085ac,0x629c025b}},	//   _अंग्, _толь, ddi_, _ohro,
   {{0x442085ad,0x2bd2102d,0xa25b0231,0x661e1175}},	//   edi_, सरवा, _atôn, _capk,
   {{0x69da85ae,0x644d02fd,0xa4d500d6,0x78ad023e}},	//   mate, tkai, робі, _tiav,
   {{0x69da85af,0x442085b0,0x24180ae3,0x645a2224}},	//   late, gdi_, лосы_, ūtin,
   {{0x644d383f,0x629c0091,0xe805014e,0x335800d3}},	// [8af0] rkai, _bhro, ष्णा_, гатэ_,
   {{0x644d85b1,0x629c09ff,0x442085b2,0x7d1a85b3}},	//   skai, _chro, adi_, _osts,
   {{0x212700ef,0x44200694,0x629c0a02,0x62852365}},	//   ính_, bdi_, _dhro, roho,
   {{0x69da85b4,0x62850193,0xa3d60bf5,0x4420008c}},	//   hate, soho, हरण_, cdi_,
   {{0x629c0cc2,0xa3cb0285,0xa7fb01ff,0x7d1a85b5}},	//   _fhro, _र्य_, giñi, _asts,
   {{0x20d7097d,0x4e0002d5,0xbea55e66,0x629c036b}},	//   _مترج, ल्लई_, шалк, _ghro,
   {{0x69da85b6,0xa3b91362,0x6d4a1384,0x2dd80076}},	//   date, _चला_, gyfa, ابهة_,
   {{0x6ee700d0,0x3eb90314,0x629c2347,0x64bc2f54}},	//   _مسئل, _ésto_, _zhro, _očin,
   {{0x7c3b85b7,0x69da00f0,0x9202074c,0xbebd12b8}},	//   rjur, fate, र्वज_, _krūm,
   {{0xf41f0149,0xc33200ca,0x5a650b21,0x5e8700d3}},	//   _skäl_, קוי_, ркоб, _субз,
   {{0x442085b8,0x649307aa,0x00000000,0x00000000}},	//   ydi_, tçil, --, --,
   {{0x186a2082,0x38ca00cd,0xc60e1178,0x661e85b9}},	//   тами_, کایی_, ाज्य_, _sapk,
   {{0x69da85ba,0x4420003d,0x6c840037,0x661e85bb}},	//   bate, vdi_, _النم, _papk,
   {{0x69da00a1,0xfed70081,0x79e70018,0xdb19042c}},	//   cate, _সমাধ, _صوبہ_, _bewö,
   {{0x442000a7,0x2876022c,0x321300d4,0xd46a0161}},	//   tdi_, _выпр, dexy_, виве_,
   {{0x442085bc,0x2b09423b,0x629c85bd,0x7bdb07ac}},	//   udi_, _वहाँ_, _shro, nauu,
   {{0x442085be,0xa3c7009f,0x629c2f3f,0x6266689d}},	// [8b00] rdi_, _उभर_, _phro, аваа,
   {{0x91e6136c,0x442085bf,0x224300e7,0x09a90033}},	//   роже, sdi_, _cojk_, _খ্যা,
   {{0x2cf41860,0x442085c0,0x6f1b0072,0xdb1901bf}},	//   _इमेल_, pdi_, _asuc, _gewö,
   {{0x69da85c1,0x442085c2,0x3fc600d1,0x00000000}},	//   zate, qdi_, شگری_, --,
   {{0x629c0054,0x69da85c3,0x60c903f1,0x6d4a00f0}},	//   _thro, yate, _čeme, wyfa,
   {{0xa116001c,0x69da85c4,0x00000000,0x00000000}},	//   _پورت, xate, --, --,
   {{0x69da85c5,0x320a0072,0xde57004d,0x2bd2178c}},	//   vate, _ibby_, ращі_, सरला,
   {{0x69da85c6,0x6d4a85c7,0xa3d6055c,0x00000000}},	//   wate, ryfa, हरि_, --,
   {{0x69da85c8,0x00000000,0x00000000,0x00000000}},	//   tate, --, --, --,
   {{0x38ba5790,0x6f0285c9,0x00000000,0x00000000}},	//   _për_, mtoc, --, --,
   {{0xa3d60cce,0x6f0213fe,0x7bdb2633,0x8be80033}},	//   हरा_, ltoc, bauu, ক্ষন_,
   {{0x69da85ca,0x64bc0095,0x00000000,0x00000000}},	//   sate, _pčin, --, --,
   {{0x69da4722,0x98be00c6,0x00000000,0x00000000}},	//   pate, dytą_, --, --,
   {{0x7ae23581,0x69da262e,0xddc3020a,0xd68705da}},	//   _ivot, qate, minţ, румп,
   {{0x046785cb,0x24920150,0x69d800e8,0x2d8302b6}},	//   атам, flym_, _ieve, _øjet_,
   {{0x6f0285cc,0x69d885cd,0x290e0079,0x00000000}},	//   ktoc, _heve, _ipfa_, --,
   {{0x69d885ce,0xddc300ae,0x64930555,0x212a0076}},	// [8b10] _keve, ninţ, lçik, _arbh_,
   {{0x35f50848,0x78b8026a,0x60c9007e,0xa2cd00c3}},	//   _упор, _kuvv, _čemb, दीग्,
   {{0xdfd100e3,0x69d805fe,0x661585cf,0x3869042f}},	//   كيا_, _meve, mezk, _kmar_,
   {{0x69d8438b,0x23bd0032,0x320a0139,0x66150634}},	//   _leve, _dájó_, _ebby_, lezk,
   {{0x53350130,0xdefb00c2,0x386901c2,0x69d8029a}},	//   _האָב_, тые_, _mmar_, _oeve,
   {{0x9e640a8d,0x69d885d0,0xddc3002d,0x66150a00}},	//   овід, _neve, dinţ, nezk,
   {{0x7ae200d9,0xc21200a1,0xd6580796,0x9d4547c4}},	//   _avot, _מהם_, שיות_, сейд,
   {{0xeb9985d1,0xddc3044c,0x3ce91206,0x661585d2}},	//   лий_, finţ, čav_, hezk,
   {{0x69d885d3,0x290e05bd,0x6f1b6cbe,0x26180d75}},	//   _beve, _apfa_, _usuc, _फसली_,
   {{0x38697f73,0x2fdd01fa,0x69d885d4,0x00000000}},	//   _amar_, lawg_, _ceve, --,
   {{0x69d82930,0x8d950080,0x661502a7,0x7bdb00f9}},	//   _deve, _الاش, dezk, pauu,
   {{0xa85604f5,0x3d0100a5,0x6e214304,0xe73a0231}},	//   стој, mów_, _halb, гем_,
   {{0x6e2185d5,0x41a7009d,0x8b6800d6,0x907a22fe}},	//   _kalb, केतस, _київ_, רטרי,
   {{0x69d80272,0x661501e9,0x65c33407,0x00000000}},	//   _geve, gezk, збра, --,
   {{0x3d010067,0x7bd90332,0x6e2185d6,0xa3aa08c0}},	//   nów_, _kewu, _malb, गेन_,
   {{0x69d86292,0xab5d0034,0x6f0285d7,0x00000000}},	//   _zeve, waży, ytoc, --,
   {{0x7bd9005a,0x0443349e,0x3aba00c1,0x03a30a8e}},	// [8b20] _mewu, четн, ָמענ, зито,
   {{0x3d010d1b,0x64bc26dd,0xb69b85d8,0xd9f902d5}},	//   ków_, _učio, ltân, ्भित_,
   {{0x248962fb,0x3d010034,0xd46a0012,0x0219004d}},	//   boam_, jów_, _бине_, шіть_,
   {{0x7bd907f5,0x3d0100a5,0x6e2101c5,0x6f0285d9}},	//   _newu, dów_, _aalb, ttoc,
   {{0x8bff0081,0xd9f90096,0x442285da,0x00000000}},	//   ্যান_, ्भात_, _iak_, --,
   {{0x44220498,0x644685db,0x6f0285dc,0xddc300ae}},	//   _hak_, _hoki, rtoc, vinţ,
   {{0x6f0285dd,0x644601b3,0x7bd935a5,0x44222281}},	//   stoc, _koki, _bewu, _kak_,
   {{0x44220f66,0x644685de,0x69c385df,0xa3cb02d5}},	//   _jak_, _joki, _afne, रुप_,
   {{0x6e2101b5,0x442285e0,0x6446013f,0x236085e1}},	//   _falb, _mak_, _moki, nzij_,
   {{0xc333004f,0x69d801e5,0x6e2185e2,0x6e960b05}},	//   פות_, _qeve, _galb, _الطا,
   {{0x3d0100a5,0x78b80abd,0xa3b90006,0xddc3020a}},	//   ców_, _quvv, _चलल_, sinţ,
   {{0x4422440c,0x69d801cb,0x76450085,0x7bd98088}},	//   _nak_, _weve, _sohy, _gewu,
   {{0x76450074,0x69d885e3,0x66150a00,0xe787205c}},	//   _pohy, _teve, tezk, суно,
   {{0x7c220113,0x7aef058a,0xa3cb009d,0x64bc14f3}},	//   _haor, ácte, रुन_, _ičij,
   {{0xe57300e3,0x66150a00,0x555800d3,0x290e0079}},	//   سطس_, rezk, баря_, _upfa_,
   {{0x386985e4,0x2fdd01fa,0x661501e9,0xb69b044c}},	//   _umar_, xawg_, sezk, ctân,
   {{0x7c2285e5,0x644685e6,0x27e90a75,0x442285e7}},	// [8b30] _maor, _doki, _idan_, _dak_,
   {{0x765c2f96,0x7c22058f,0x27e985e8,0x44220634}},	//   chry, _laor, _hdan_, _eak_,
   {{0xbebd2c2e,0x672d033d,0xf65200a1,0x4422084e}},	//   _trūk, _hraj, _חצי_, _fak_,
   {{0x442285e9,0x7c2204a3,0x6e2185ea,0x64bc005f}},	//   _gak_, _naor, _salb, _očij,
   {{0x3d010034,0xc1e90103,0x932707e8,0x69c185eb}},	//   wów_, _نکال_, _ارجن, ycle,
   {{0x3d010067,0x6e2121f5,0xc33200f5,0x442285ec}},	//   tów_, _qalb, _קום_, _zak_,
   {{0xed594778,0x442285ed,0x7c220154,0x7bd900dc}},	//   рой_, _yak_, _baor, _pewu,
   {{0x3d010067,0x6e210694,0x7c2285ee,0x09e1009d}},	//   rów_, _walb, _caor, पण्य,
   {{0x3d010067,0x6e2185ef,0x7c221909,0xe3bf002b}},	//   sów_, _talb, _daor, _gañe_,
   {{0xe9d904e6,0x27e985f0,0xda6500d6,0x3d0100a5}},	//   шко_, _adan_, івни, pów_,
   {{0x69c185f1,0x26c90167,0xd9450731,0x672d85f2}},	//   rcle, _atao_, цени, _araj,
   {{0x672d85f3,0x27e9796c,0x7c22010b,0x69c11224}},	//   _braj, _cdan_, _gaor, scle,
   {{0x442285f4,0xb69b85f5,0x644685f6,0xeb8e4438}},	//   _rak_, rtân, _roki, _ци_,
   {{0x442280a8,0x8aa71a57,0xb69b85f5,0x672d85f7}},	//   _sak_, _уред, stân, _draj,
   {{0x442285f8,0x64460181,0x27e902a1,0xa96616e6}},	//   _pak_, _poki, _fdan_, _миша_,
   {{0x7c220072,0x229400c2,0x2360029a,0x74b95a5c}},	//   _xaor, mäki_, tzij_, сурс_,
   {{0xc5d90081,0x6446013f,0x442285f9,0x47a80081}},	// [8b40] _তারপ, _voki, _vak_, _ক্রী,
   {{0x442285fa,0x394902c6,0xd1960e2c,0x4375171b}},	//   _wak_, _řasy_, ошењ, чуст,
   {{0x644685fb,0x2905034f,0xe5a61e11,0xa2da0096}},	//   _toki, ntla_, _фини, _पौर्,
   {{0xd00a0284,0x4422010a,0x00000000,0x00000000}},	//   реде_, _uak_, --, --,
   {{0x9eaa4be7,0x245c0103,0x4ea605b8,0x290500bc}},	//   авда_, _címe_, орка, htla_,
   {{0xe29785fc,0x7c220099,0x412a3164,0x648100e8}},	//   _мая_, _saor, _кого_, rķie,
   {{0x910357ff,0xf987046b,0x7c220095,0x998c007f}},	//   _опре, _آب_, _paor, zedł_,
   {{0x6ee30134,0x9c7c05aa,0x2fc40131,0xa4b700ca}},	//   _ọber, _evčn, _ufmg_, חלקה_,
   {{0x6fd00251,0x27e901b9,0x00000000,0x00000000}},	//   _ड्यू, _rdan_, --, --,
   {{0xda4a04c9,0xc3140033,0x764800c2,0x7c22024a}},	//   рчил_, সিপি_, ödyl, _waor,
   {{0x26c908a9,0x91bb00a1,0x7c2285fd,0xc1bb00c1}},	//   _stao_, ימיי, _taor, ימיש,
   {{0x672d7cdd,0xc867004d,0x00000000,0x00000000}},	//   _praj, ітни, --, --,
   {{0xa92700d4,0x3b0700ae,0x5a4600d3,0xdd1e0e43}},	//   _poží, _мецо_, _мэка, níže,
   {{0x672d2002,0x00000000,0x00000000,0x00000000}},	//   _vraj, --, --, --,
   {{0xa3c80129,0xe5990120,0x746b0131,0x00000000}},	//   _ọbịa_, скві_, арав_, --,
   {{0x672d85fe,0xd6db02fd,0x27e985ff,0x00000000}},	//   _traj, _кто_, _udan_, --,
   {{0xddcb0031,0x8c1b00ca,0x672d04ff,0x2458007b}},	// [8b50] _čižm, סומי, _uraj, цать_,
   {{0x6cea02d5,0xbebd00c6,0x00000000,0x00000000}},	//   _टिंग_, _krūv, --, --,
   {{0xc0150084,0x7d0d0034,0x30154be7,0xe2a601cd}},	//   змещ, łasz, здер, íðan_,
   {{0x351a00ca,0x00000000,0x00000000,0x00000000}},	//   _פורנ, --, --, --,
   {{0x80dc0033,0xce95008f,0xa3cb0287,0x00000000}},	//   মূল্, падъ, रुण_, --,
   {{0x51875ae8,0x245c00b6,0x29058600,0xb2ba00ca}},	//   _дуба, _víme_, ytla_, _למשר,
   {{0xdfd529c2,0xdb1b03be,0x29058601,0x00000000}},	//   _новы, rcuí, xtla_, --,
   {{0x0b45008f,0xc57c00a1,0x80270018,0xdb1b0072}},	//   знин, ירות, _برآم, scuí,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xadf424f7,0xe8f92fad,0x00000000,0x00000000}},	//   _опуш, бло_, --, --,
   {{0xdcef0138,0xbd6b22f6,0x2905034f,0x00000000}},	//   _įdėt, _трае_, utla_, --,
   {{0x315600c1,0x787600e8,0x48dc00a3,0x29053ed0}},	//   פירן_, kšve, _खबरो_, rtla_,
   {{0x29052ce2,0x69cc09c4,0xd5b801d3,0x00000000}},	//   stla_, _द्वी, žām_, --,
   {{0xfe79030b,0xd11b0096,0x00000000,0x00000000}},	//   _svůj_, नबाण_, --, --,
   {{0xceb202f8,0x64a6013f,0x845a08f9,0x0f1800a4}},	//   תים_, зава, брат_, _धन्स_,
   {{0x98a30fd6,0x00000000,0x00000000,0x00000000}},	//   _пище, --, --, --,
   {{0x08770142,0x00000000,0x00000000,0x00000000}},	// [8b60] _מעקט_, --, --, --,
   {{0x27e2005c,0x00000000,0x00000000,0x00000000}},	//   lakn_, --, --, --,
   {{0x657a0076,0xfe7902c6,0x6d4512f1,0x00000000}},	//   úthd, _tvůj_, ähal, --,
   {{0xdd1e02c6,0x48dd0179,0xa06a0284,0x27e210ca}},	//   tíže, कीयो_, љада_, nakn_,
   {{0xddcf030b,0x00000000,0x00000000,0x00000000}},	//   _řeše, --, --, --,
   {{0xdd94198b,0x00000000,0x00000000,0x00000000}},	//   малы, --, --, --,
   {{0x64930092,0x64bc009c,0x20da01f3,0x09da0033}},	//   rçiv, _dōig, _دوزخ_, _দালা,
   {{0x321a00a5,0x9e6609b4,0x244e00b6,0xd007004d}},	//   lepy_, _کارن, _týmu_, _несе_,
   {{0xaae60037,0xbd010381,0x00000000,0x00000000}},	//   أسبو, _éénd, --, --,
   {{0x7aef2e86,0xe3bf1ba6,0x78a40027,0xc9860b99}},	//   ácta, _maña_, _ahiv, зуми,
   {{0xfe45015a,0x2d9e0062,0x00000000,0x00000000}},	//   _تکنی, _uzte_, --, --,
   {{0x78a48602,0x7ac6016d,0x6b82023e,0xeb9a00ae}},	//   _chiv, _еске, _txog, _лие_,
   {{0x2bd2121d,0xb9032397,0xc05300d7,0x00000000}},	//   _ध्या, _पौ_, גזר_, --,
   {{0x80d20081,0x195816c0,0x78a400b7,0x00000000}},	//   _হিন্, _малы_, _ehiv, --,
   {{0x25ba008c,0x555800d3,0x00000000,0x00000000}},	//   _dgpl_, паря_, --, --,
   {{0x958400a5,0xbebd2c2e,0x78a400ae,0xe3bf8603}},	//   _łącz, _krūt, _ghiv, _baña_,
   {{0xa2b500d6,0xe3bf058a,0x00000000,0x00000000}},	// [8b70] дбач, _caña_, --, --,
   {{0x645f023b,0xe3bf034f,0xe3b00037,0xf1a72249}},	//   shqi, _daña_, طرق_, прен,
   {{0x68fa01ce,0x00000000,0x00000000,0x00000000}},	//   nutd, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442973bb,0x44398604,0xe3bf03be,0x645d0078}},	//   mda_, _ins_, _gaña_, _ilsi,
   {{0x443916a2,0x5fce00a3,0xef18325f,0x479c006e}},	//   _hns_, हुबल, ямі_, ציגס,
   {{0x44290694,0xc1050190,0x00000000,0x00000000}},	//   oda_, _توزي, --, --,
   {{0x44298605,0xf53800c1,0xcac90084,0x68fa0124}},	//   nda_, לטור_, огие_, dutd,
   {{0xdb09026a,0x64938606,0x89f5065c,0xbf2400d2}},	//   _önüm, lçis, мянц, áště,
   {{0x44298607,0x2bff0033,0x1dc60c8c,0x1a650e27}},	//   hda_, ্যেই_, रुआत, بیتی_,
   {{0x44398608,0x44298609,0x27e2005c,0x3ebf0124}},	//   _ons_, kda_, takn_, _huut_,
   {{0x4429860a,0x2fdf057a,0x4439084e,0x644b00bc}},	//   jda_, _jeug_, _nns_, ögil,
   {{0x4429841d,0xbebd00d9,0x61fe0149,0xf4030033}},	//   dda_, _grūt, ygpl, উজার_,
   {{0x4439860b,0x4429860c,0x3ebf0084,0xda0e00de}},	//   _ans_, eda_, _muut_, _hỏng_,
   {{0x7afb03cf,0x27e2005c,0x4439860d,0xfbd10966}},	//   luut, pakn_, _bns_, _सभाम,
   {{0x4429860e,0x5ed30081,0x64bc0f1c,0x00000000}},	//   gda_, _সিনে, _očiv, --,
   {{0x7c29860f,0x7afb0084,0xda0e00de,0x3ebf057a}},	// [8b80] ider, nuut, _mỏng_, _nuut_,
   {{0x44398610,0x44266f53,0x645d8611,0x67248612}},	//   _ens_, žo_, _elsi, _isij,
   {{0x44298613,0x661c8614,0x27e002dc,0x7c295c06}},	//   bda_, merk, _kein_, kder,
   {{0x7c298615,0x7afb8616,0x44290694,0x3ebf8617}},	//   jder, kuut, cda_, _buut_,
   {{0x27e002dc,0x2fdf01b5,0xa3aa0d29,0xa37b016d}},	//   _mein_, _deug_, गेश_, _peõe,
   {{0x7c298618,0x27e002ad,0x3a270124,0x27450052}},	//   eder, _lein_, _nanp_, _hënë_,
   {{0xda0e00de,0x2ee60063,0xa3aa00b6,0xa3cb0287}},	//   _bỏng_, ssof_, गेर_, रुव_,
   {{0x67248619,0x27e025ea,0x32c4026a,0x661c861a}},	//   _osij, _nein_, _köy_, herk,
   {{0x1dcf3ec9,0x7afb861b,0x20040167,0xafe30002}},	//   _स्वत, guut, _icmi_, _шотл,
   {{0xdb2200a5,0x2745023b,0x661c861c,0x8d562ea7}},	//   _źród, _lënë_, jerk, _отеч,
   {{0x44297bfd,0x27e00bd8,0x6724861d,0x61e100aa}},	//   yda_, _bein_, _asij, _õlle,
   {{0x44290694,0x7afb861e,0x26c000e5,0x6e280188}},	//   xda_, buut, _buio_, _hadb,
   {{0x27e002e2,0xfc6709e5,0x26c00072,0x6e280063}},	//   _dein_, _تخلی, _cuio_, _kadb,
   {{0x44390291,0x661c2e6e,0x4429861f,0x9c7c0141}},	//   _sns_, gerk, wda_, _ovčk,
   {{0x44290092,0x27e03f94,0x443900a4,0xa3b1349d}},	//   tda_, _fein_, _pns_, टेन_,
   {{0xd5b814ae,0x44298620,0x6e280973,0x27e08621}},	//   ься_, uda_, _ladb, _gein_,
   {{0x6e3a03ee,0xa3aa009d,0x20c40174,0x38ba01d3}},	// [8b90] _ontb, गेल_, _ịkpụ_, _vīru_,
   {{0x44298622,0x27e002a7,0x6e284480,0x76743b4f}},	//   sda_, _zein_, _nadb, _альф,
   {{0x7c295bfe,0x66050365,0x25d600ca,0x26c00350}},	//   yder, _ichk, _אותן_, _zuio_,
   {{0x44295673,0x44398623,0x245c0102,0x603e00d3}},	//   qda_, _uns_, _tíma_, _rămâ,
   {{0x6e28008a,0x22940212,0x7c290216,0x32c4013c}},	//   _badb, täkt_, vder, _göy_,
   {{0xceb800a5,0x603e00d3,0x6da5294a,0x7afb00c2}},	//   _cię_, _pămâ, нила, vuut,
   {{0x61e58624,0xdc3a026a,0x2ca601b9,0xe8200096}},	//   mahl, _açıs, _bhod_, _बसला_,
   {{0x69ca8625,0x61e58626,0x7c298627,0x2ca68628}},	//   _affe, lahl, uder, _chod_,
   {{0x7c29510f,0x27e08629,0x661c2447,0x3ed90781}},	//   rder, _rein_, yerk, _رواج_,
   {{0x27e0862a,0x7c290d38,0x3945862b,0x7afb862c}},	//   _sein_, sder, еног, ruut,
   {{0x661c0b6a,0x7afb862d,0x5bb900ae,0x2d80020a}},	//   verk, suut, _елея_, şier_,
   {{0xed5607a6,0x661c1c7d,0x6e280034,0x7afb862e}},	//   _אבער_, werk, _zadb, puut,
   {{0x661c862f,0x443e0019,0x3a2706a3,0x61e50201}},	//   terk, _đt_, _tanp_, kahl,
   {{0x64bc7858,0xe3bf8630,0x2cad8631,0x7ae96de9}},	//   _očit, _baño_, lmed_, mset,
   {{0x61e5063f,0xa97900c1,0x7ae98632,0xf0fe17e5}},	//   dahl, _מאַכ, lset, _उमेद_,
   {{0x46ea0465,0x7bc98633,0xe3bf058a,0xa3cb007a}},	//   _един_, nceu, _daño_, रुल_,
   {{0x7ae98634,0x2745023b,0x3860610e,0xd9f33fac}},	// [8ba0] nset, _vënë_, _ilir_, _आयात_,
   {{0x7ae98635,0x2cad8636,0x99850018,0x61e5019f}},	//   iset, hmed_, lelő_, gahl,
   {{0x7ae90eef,0xf77f016d,0x50ba0e25,0x6e288637}},	//   hset, maça_, سداد_, _radb,
   {{0xceb81f83,0x68fc05fe,0x62958638,0x7ae98639}},	//   _się_, àrdi, _ekzo, kset,
   {{0xe8050ff9,0x2cad007a,0x61e54c58,0x7ae94c35}},	//   ष्टा_, dmed_, bahl, jset,
   {{0x7ae9863a,0xf77f0428,0x9c7c00c4,0x2ca60141}},	//   dset, naça_, _ivči, _shod_,
   {{0xf65300f5,0x6e280087,0x7ae90cfd,0x21a31894}},	//   רצו_, _vadb, eset, _бирм,
   {{0x7ae93f3f,0x6b9900eb,0x245c0032,0x00000000}},	//   fset, _bywg, _mímo_, --,
   {{0x6e280332,0x3f810740,0x7ae977bf,0x2ca63fa3}},	//   _tadb, şhur_, gset, _vhod_,
   {{0xdb230037,0x3860863b,0x4a540e2f,0x24801dbc}},	//   órái, _alir_, ткос, hnim_,
   {{0x3860863c,0x88bc030b,0x67d500d6,0x2cad863d}},	//   _blir_, jvět, кону, bmed_,
   {{0x248000cb,0x61e5863e,0xa3b1034d,0x8157006e}},	//   jnim_, zahl, टेड_, גסטע_,
   {{0x248003ce,0x64bc1813,0xe7843e93,0x61e5863f}},	//   dnim_, _očis, гуро, yahl,
   {{0xbb3b193b,0x09e30081,0x69ca00eb,0x245c0af0}},	//   _מעדי, _মাথা, _uffe, _bímo_,
   {{0xceb300c1,0x893303c5,0x796601dc,0x38ba01d3}},	//   טיש_, _معيا, _déwé, _vīrs_,
   {{0xd4980cf5,0x61e53388,0xa3cb0285,0x386000f0}},	//   еру_, wahl, रुं_, _glir_,
   {{0x09e30033,0xf77f0131,0x66050154,0x290c0231}},	// [8bb0] _মাতা, baça_, _tchk, ltda_,
   {{0x7afd0472,0x248070e0,0xa1590d4f,0x00000000}},	//   àsti, anim_, мазу_, --,
   {{0xdfd100e3,0x61e58640,0xf7730018,0x290c1a4a}},	//   ليا_, rahl, _جاں_, ntda_,
   {{0x248004a3,0x1b170081,0x61e5683b,0xf993006e}},	//   cnim_, তিতে_, sahl, ארע_,
   {{0xd9ad2b8a,0x61e5019f,0x4f58004d,0xa3cb0213}},	//   _घण्ट, pahl, ницю_, रुः_,
   {{0x7ae978af,0x442b8641,0x644f68e5,0x998501f9}},	//   vset, _hac_, _hoci, zelő_,
   {{0x644f8642,0x64bc1cbc,0xfc3100e3,0x442b8643}},	//   _koci, _učit, لحة_, _kac_,
   {{0x7ae92225,0x63a257e0,0xf3ff0131,0x644f8644}},	//   tset, żone, _imãs_, _joci,
   {{0x644f1ba8,0x1c421ad1,0x2cad4bf9,0x4aa90450}},	//   _moci, рным, rmed_, мкин_,
   {{0x7ae98645,0x248000cb,0x442b8646,0x2cad0ac9}},	//   rset, znim_, _lac_, smed_,
   {{0x442b015e,0x09e30033,0x998501f9,0x00000000}},	//   _oac_, _মাদা, telő_, --,
   {{0x442b0150,0x7ae98647,0x00000000,0x00000000}},	//   _nac_, pset, --, --,
   {{0x998501f9,0x290c013c,0x00000000,0x00000000}},	//   relő_, atda_, --, --,
   {{0xf1b106ae,0x23690034,0xa3d40096,0x99850103}},	//   जधान, dzaj_, सुन_, selő_,
   {{0x442b8648,0x7c2b8649,0xf77f255b,0xd4f504d9}},	//   _bac_, _kagr, raça_, ляты,
   {{0x644f11ce,0x442b864a,0xc4833574,0x38600085}},	//   _coci, _cac_, алск, _ulir_,
   {{0x7c2b864b,0xa3e30101,0xf746246b,0x88bc00b6}},	// [8bc0] _magr, _नजर_, _репо, svět,
   {{0x248008a9,0x7c2b864c,0x442b2bff,0x8bff0081}},	//   snim_, _lagr, _eac_, ্যটন_,
   {{0x442b0012,0x644f0103,0x00000000,0x00000000}},	//   _fac_, _foci, --, --,
   {{0xd00f0bf4,0x7e61864d,0x644f007e,0x27f20169}},	//   قلم_, _allp, _goci, _jdyn_,
   {{0x4420864e,0xbe8a0156,0x1eaa0076,0x00000000}},	//   mei_, мске_, واتي_, --,
   {{0x4420864f,0x290c0092,0x765c5ab4,0xdce10511}},	//   lei_, ytda_, nkry, _aylı,
   {{0x614318c6,0x3cfd030b,0xc0e35833,0xe29700d3}},	//   _кера, रूले_, _воск, _рар_,
   {{0x409529db,0x442b00fe,0x648101d3,0x26d2083e}},	//   _брут, _xac_, eķij, _otyo_,
   {{0x7c2b1868,0x442047d9,0x26d22cb9,0xaf06067f}},	//   _dagr, iei_, _ntyo_, _шпал,
   {{0x7c2b3789,0x44208650,0x27f203a8,0xa25b020b}},	//   _eagr, hei_, _adyn_, _luôn,
   {{0x44208651,0xdd1f0181,0x5ec70081,0x26d2170c}},	//   kei_, píšt, রীদে, _atyo_,
   {{0x7c2b001c,0x290c0abd,0x44208652,0x7e780234}},	//   _gagr, rtda_, jei_, livp,
   {{0x44208653,0x6d58013f,0x27f200f0,0xec1300d1}},	//   dei_, lyva, _ddyn_, _خوند,
   {{0x7c2b8654,0x442b8655,0x7c2001f9,0x00000000}},	//   _zagr, _sac_, lemr, --,
   {{0x644f0891,0x2419055b,0xa25b00de,0x25a50212}},	//   _poci, новы_, _buôn, åll_,
   {{0x44208656,0x629e0381,0xe80a0714,0x00000000}},	//   gei_, elpo, _वाया_, --,
   {{0x52152f68,0x644f1ad8,0xf77f0231,0x00000000}},	// [8bd0] лдат, _voci, maço_, --,
   {{0xf77f8657,0x442b041c,0x7c20010a,0x00000000}},	//   laço_, _wac_, hemr, --,
   {{0xf77007c3,0x44206b39,0x212700ef,0x6d5d01d4}},	//   _های_, bei_, ình_, _əsas,
   {{0xcfde00c7,0x44208658,0x442b8659,0x32070034}},	//   _ডাউন, cei_, _uac_, żny_,
   {{0xd9e3009f,0xdd101054,0xd00e13c3,0x7c2b865a}},	//   _ग़लत_, výše, سلو_, _ragr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2b865b,0xd7e30096,0x6d584030,0x69da0113}},	//   _pagr, पराच, gyva, dbte,
   {{0x0c256321,0x249900dc,0xa6d90033,0x6c350037}},	//   умин, _jksm_, _তিনট, افظا,
   {{0x786609b3,0xf77f0161,0x9e07002d,0xfe7902c6}},	//   _jóve, daço_, _ачел, _dvůr_,
   {{0x78660396,0x1dc7349d,0xd9e30081,0x4a451a0c}},	//   _móve, _ललित, _মাহম, унов,
   {{0x7c2b865c,0x44200103,0xe2a601cd,0x00000000}},	//   _tagr, yei_, íðin_, --,
   {{0x4420865d,0x6f1b0294,0xe43c00b6,0xbbeb1ac9}},	//   xei_, _kpuc, _příč, _آرام_,
   {{0x4420865e,0x78660088,0x7bdb865f,0x81e90081}},	//   vei_, _nóve, mbuu, _যান_,
   {{0x44208660,0x38ca00bf,0x7bdb8661,0xa25b00fe}},	//   wei_, بایی_, lbuu, _suôn,
   {{0x765c8662,0x7cd100d9,0x7afb0407,0xf77f0131}},	//   rkry, _dārg, lrut, baço_,
   {{0x765c0665,0x786646b4,0x7bdb8663,0x6f1b1518}},	//   skry, _bóve, nbuu, _opuc,
   {{0xa25b00de,0x64a304d9,0x26d20079,0x7afb03bd}},	// [8be0] _vuôn, сата, _utyo_, nrut,
   {{0x44208664,0x61468665,0x00000000,0x00000000}},	//   sei_, леза, --, --,
   {{0x629e215b,0x44208666,0xe3b200d0,0xea7600c1}},	//   rlpo, pei_, _گرد_, נגער_,
   {{0x7afb8667,0xb4fb193b,0x04460012,0x628706b0}},	//   krut, _אפטי, _семн, _ejjo,
   {{0xe3b2110a,0x7e780e94,0x7afb0a39,0x00000000}},	//   _درد_, tivp, jrut, --,
   {{0x6d580138,0xb5e20033,0x11da0037,0x644b00bc}},	//   tyva, _বাঁচ, _سورة_, ögiv,
   {{0x2cc90181,0xa3cb142e,0xd24f01c3,0x0166007b}},	//   _ľudí_, रुक_, _عنف_, _скво,
   {{0x7afb8668,0x7bdb21d2,0x4e09030b,0x683b00ce}},	//   frut, gbuu, _साथै_, _mädä,
   {{0x68f50074,0x3075282a,0x7866002b,0x7afb8669}},	//   ázdn, _турс, _xóve, grut,
   {{0xfd5d00ac,0x39140c2b,0x37e10033,0x9c7c022b}},	//   _jizọ, амор, _ভাইর, _avčt,
   {{0x69da0e24,0x7afb3ba9,0x7bdb0bf6,0x00000000}},	//   rbte, arut, bbuu, --,
   {{0x3ebe866a,0x7afb866b,0xd847235c,0x20061175}},	//   _hitt_, brut, ухоп, ngoi_,
   {{0x7afb866c,0xf77f001f,0x7c9300e3,0x70e102d5}},	//   crut, raço_, _النص, _पब्ल,
   {{0x26e5000f,0xcf9300ca,0x6d490034,0x631d0033}},	//   _कबीर_, מטר_, ślał, নিময়_,
   {{0x3ebe24a3,0xf77f0396,0x00000000,0x00000000}},	//   _mitt_, paço_, --, --,
   {{0x3ebe0a8d,0x248d04fa,0x7ae2866d,0x291c016d}},	//   _litt_, čemo_, _kwot, _ipva_,
   {{0x78ad3351,0xb275007e,0x81e90033,0x00000000}},	// [8bf0] _ihav, алаш, _যাব_, --,
   {{0x7aef11ce,0x5ed300c7,0xe7040018,0x7ae20d15}},	//   ácti, _সিলে, _اسٹی, _mwot,
   {{0xf1a746aa,0xcfd60033,0xe796001c,0x2d9e0120}},	//   уран, _হয়ন, _مایک, _nyte_,
   {{0x6f02028d,0x7bdb0188,0x7cd100e8,0x897b0142}},	//   fuoc, xbuu, _jāre, עראצ,
   {{0xb8171757,0xe817018b,0x200901d3,0x78bf0052}},	//   ध्यम_, ध्या_, ļai_, _miqv,
   {{0x62832449,0x7bc20154,0x644d866e,0x3ebe028d}},	//   čnos, _agou, ljai, _citt_,
   {{0x3ebe866f,0xd6580054,0x7ae28670,0x30a71c99}},	//   _ditt_, ריות_, _awot, _брав,
   {{0xeb991227,0x7afb8671,0x3ebe23ff,0x6297002b}},	//   кий_, trut, _eitt_, loxo,
   {{0x6f1b0039,0x50641ad2,0x7bdb8672,0x7ae2030a}},	//   _upuc, _утра, rbuu, _cwot,
   {{0x62858673,0x7cd10029,0x7afb8674,0x3ebe00d6}},	//   nnho, _pārd, rrut, _gitt_,
   {{0x88860747,0x61e78675,0x186a1b10,0xe80a0251}},	//   илож, _mejl, вани_, _वादा_,
   {{0xfa2500c7,0x7cd10029,0x78ad3884,0x61e78676}},	//   বাইল_, _vārd, _chav, _lejl,
   {{0xe9ce1ffa,0x7ae28677,0x7d038678,0xe73a0284}},	//   _мк_, _gwot, luns, њег_,
   {{0x61e7000d,0x6e238679,0xe7f2030b,0x6285867a}},	//   _nejl, nenb, _आएका_, jnho,
   {{0xc6280081,0xfd5d0134,0x7d03867b,0x9f440052}},	//   মালা_, _rizọ, nuns, _pemë_,
   {{0x26c4867c,0x6e23867d,0xdd0100b6,0x6a64009c}},	//   ímos_, henb, _štěs, _iòfa,

   {{0xa3b1009d,0x6e23867e,0x62970072,0xe29a001f}},	// [8c00] टेल_, kenb, foxo, ваа_,
   {{0x6e230381,0x00000000,0x00000000,0x00000000}},	//   jenb, --, --, --,
   {{0x3f9f867f,0x61e701c5,0x6e230dbc,0x7d030559}},	//   _ayuu_, _dejl, denb, juns,
   {{0x3ebe0b6a,0x7d038680,0x78ad023b,0x60c70344}},	//   _sitt_, duns, _xhav, _dujm,
   {{0x61e78681,0x6e232a0d,0x2d9e8682,0x20060052}},	//   _fejl, fenb, _syte_, rgoi_,
   {{0x6e238683,0x81b50081,0x7d0324ae,0x7ea400ee}},	//   genb, ছুই_, funs, ròpo,
   {{0xddc800a5,0x3ebe539e,0x721b0796,0xafe6013f}},	//   _podł, _vitt_, _שולח, _вобл,
   {{0x7ae20c56,0x443206ce,0x245c0065,0xe7f2007f}},	//   _pwot, ndy_, _bími_, _आएगा_,
   {{0x15e6000f,0x6e2373dc,0x3ebe2ba4,0xd24f0018}},	//   करार_, benb, _titt_, _عنہ_,
   {{0xf1aa0034,0x2d9603f2,0x44328684,0x68e3030a}},	//   _करान, _крес, hdy_, _bwnd,
   {{0x44320074,0x7d038685,0x7cd101d3,0x9f440154}},	//   kdy_, cuns, _pāre, _semè_,
   {{0x69c313b9,0x60c08686,0x68e303a8,0x7ae2022b}},	//   _egne, _jimm, _dwnd, _twot,
   {{0x7ad40397,0x629c8687,0x628500f0,0x443264da}},	//   _اقتص, _okro, ynho, ddy_,
   {{0x44320220,0x60c08688,0x7afd8689,0x32dd0af0}},	//   edy_, _limm, áste, _láyò_,
   {{0x5887868a,0xa4d5004d,0x644d7057,0xd49b0d66}},	//   _выпа, собі, tjai, вра_,
   {{0x613000fb,0x60c0868b,0x61e7052f,0x6e23868c}},	//   zólá, _nimm, _sejl, zenb,
   {{0x644d868d,0xa3b10034,0x6e23868e,0x629717eb}},	// [8c10] rjai, टें_, yenb, toxo,
   {{0x628508bc,0xa3cb5e07,0x6e231b03,0x672d0090}},	//   unho, रुज_, xenb, _isaj,
   {{0x61e701c5,0x6285868f,0x6113030b,0x6e2311c5}},	//   _vejl, rnho, dělá, venb,
   {{0x60c0006d,0x27e98690,0x9ef50037,0x6e230381}},	//   _cimm, _jean_, مستش, wenb,
   {{0x6e238691,0x53340084,0x7d038692,0xda060f42}},	//   tenb, _деят, wuns, _शांत_,
   {{0x7d037691,0x672d0051,0x7ead0220,0x98a800b6}},	//   tuns, _msaj, kúpe, _brně_,
   {{0x60c00088,0x4035013d,0x245c6cc8,0x6e23091f}},	//   _fimm, _левс, _sími_, renb,
   {{0x7d038693,0x7cd100d9,0x213e00e3,0x6b8400e7}},	//   runs, _pārb, _átha_, _žiga,
   {{0x6e238694,0x7d0324ae,0x69c300b3,0x98bf00c6}},	//   penb, suns, _pgne, lytė_,
   {{0x44322f29,0x60c002e2,0x7d0300bf,0x26c102a4}},	//   zdy_, _zimm, puns, _niho_,
   {{0x44328695,0x98bf00c6,0xd90c0d7f,0x69c38696}},	//   ydy_, nytė_, نیو_, _vgne,
   {{0x245c003e,0xed350018,0x27e901b9,0x7d7a0142}},	//   _tími_, _پوچھ, _cean_, _גרעג,
   {{0x44320146,0x8c160037,0x672d0103,0xae0e058f}},	//   vdy_, _طيور_, _csaj, _सामन_,
   {{0xa3bd2301,0xa50a2549,0x69c38697,0x98bf00c6}},	//   ेखन_, лега_, _ugne, kytė_,
   {{0x27e98621,0x33f6036c,0x255900d3,0xba740076}},	//   _fean_, йчас, артэ_, _بانت,
   {{0x27e900da,0x29057581,0xe8170403,0x44328698}},	//   _gean_, mula_, ध्दा_, udy_,
   {{0x29058699,0xe73a1b10,0x60c0869a,0x61ea01ab}},	// [8c20] lula_, _сеп_, _rimm, ðflo,
   {{0x200d020a,0x44323572,0xb7d7001c,0x3a250231}},	//   _acei_, sdy_, _پویا_, nelp_,
   {{0x27e90063,0xa3cb00b6,0x62830a39,0xd65700ca}},	//   _yean_, रुङ_, čnop, _היית_,
   {{0x3a25869b,0x64930233,0xcf467775,0x00000000}},	//   help_, kçiy, йней, --,
   {{0x2905869c,0x60c0869d,0x60db007e,0x11d604a1}},	//   hula_, _vimm, _čume, _гібр,
   {{0x412a0a8d,0x2905869e,0xa3d40d75,0x5be009c4}},	//   _його_, kula_, सुर_, नर्व,
   {{0x60c0869f,0xc27b006e,0x290586a0,0x00000000}},	//   _timm, _ערלי, jula_, --,
   {{0x290586a1,0xbf4d00b6,0xcefd0233,0x00000000}},	//   dula_, _šířk, üğün_, --,
   {{0xdee308f9,0xfbcf08ba,0x7cd101d3,0x27e986a2}},	//   _ноти, رتي_, _pārc, _rean_,
   {{0x290586a3,0x7f3b006e,0x3e860504,0x27e91814}},	//   fula_, _געמו, _اشرف, _sean_,
   {{0x290586a4,0x6e931be8,0x6da60e5a,0x27e986a5}},	//   gula_, _علما, _امام, _pean_,
   {{0x6ca609b4,0xc86786a6,0x26c10169,0x244e02c6}},	//   _اصطل, стои, _siho_, _týmy_,
   {{0x27e986a7,0x26c102c9,0x25a400a7,0xb8ef00bc}},	//   _vean_, _piho_, əmli_, _वू_,
   {{0x29050863,0xae1b02d5,0x3cef0096,0x672d05db}},	//   bula_, प्पन_, ींचे_, _vsaj,
   {{0x29051c40,0x280400b6,0x27e900aa,0x81ce0033}},	//   cula_, ásné_, _tean_, ররা_,
   {{0xd49b2ba6,0xd5d90ed3,0x81c00081,0x985d0034}},	//   ург_, _ब्रज, ীরা_, _błąd_,
   {{0x32550848,0x672d0051,0x386903e3,0x7cd10877}},	// [8c30] овар, _usaj, _ilar_, _māra,
   {{0x98bf0138,0xf8c900fe,0x6a64022b,0x00000000}},	//   tytė_, _mẩn_, _mòfo, --,
   {{0x38690709,0xb1130294,0x3495007e,0x50b9001c}},	//   _klar_, rụok, _маор, لگرد_,
   {{0x3e6b00d6,0x7cd10325,0x00000000,0x00000000}},	//   _møte_, _nāra, --, --,
   {{0xddc502ec,0x290510d4,0x248986a8,0xddc80154}},	//   обли, zula_, mnam_, _modņ,
   {{0xdce808bb,0x386905fe,0x787619db,0x539a1777}},	//   _aydı, _llar_, ršvi, _כירו,
   {{0xe80a1085,0x386901d4,0x248986a9,0xb7fb0861}},	//   _वाला_, _olar_, onam_, ्लाम_,
   {{0x29050201,0xf8c900de,0x6ee30174,0xd9e102d5}},	//   vula_, _bẩn_, _ọbur, फर्ट,
   {{0x248986aa,0x290586ab,0xf8c900de,0x76450381}},	//   inam_, wula_, _cẩn_, _onhy,
   {{0x290586ac,0x386986ad,0xf8c900fe,0x19b9002d}},	//   tula_, _alar_, _dẩn_, иунь_,
   {{0xd82629ee,0x386986ae,0x00000000,0x00000000}},	//   одни, _blar_, --, --,
   {{0x290586af,0x386986b0,0xe73a067c,0x764500f0}},	//   rula_, _clar_, аем_, _anhy,
   {{0x290586b1,0xde880294,0xfb850103,0x7a220174}},	//   sula_, lịa_, _بدای, ọtak,
   {{0x290586b2,0x24892224,0x7ae486b3,0x3869058f}},	//   pula_, enam_, _çita, _elar_,
   {{0x66010653,0x65c320f8,0x00000000,0x00000000}},	//   ólka, дбра, --, --,
   {{0x60c95873,0x24890227,0x04435e28,0x9f4f01cd}},	//   _čemp, gnam_, месн, yggð_,
   {{0xd4672de0,0x161b0789,0xc8890b05,0x03a304fd}},	// [8c40] ците_, _पॉवर_, _دخول_, дито,
   {{0xae0e022d,0x25ad00d2,0x78a686b4,0x00000000}},	//   _साधन_, řela_, llkv, --,
   {{0x4fc6186d,0x7cf00037,0x00000000,0x00000000}},	//   осла, _mórá, --, --,
   {{0x1b200033,0xdfd00e00,0xa2aa0d61,0xa06a0c37}},	//   বিতে_, ريت_, _जीर्, јада_,
   {{0x644686b5,0x81e90081,0x00000000,0x00000000}},	//   _inki, _যার_, --, --,
   {{0x72c302fd,0x6b840d12,0x00000000,0x00000000}},	//   _обяз, _žigo, --, --,
   {{0x2612007a,0x68ed0034,0x78660072,0x6a6400b3}},	//   _तानी_, _ładn, _nóvo, _sòfo,
   {{0x6ab214db,0x245c0031,0x22580381,0x00000000}},	//   ँग्र, _tímu_, _hork_, --,
   {{0x3ce900e9,0x3869009c,0x3e6b0120,0x69cf00d2}},	//   ćava_, _rlar_, _søte_, ěcen,
   {{0x248941f9,0x2480008a,0x7afd26ad,0xde880294}},	//   znam_, hiim_, ásta, bịa_,
   {{0x644600c2,0x2bac0378,0x20d70078,0x22582ed2}},	//   _onki, _चरवा, _għid_, _mork_,
   {{0x0b4686b6,0x6f02044c,0x6a64015e,0x4e1600b6}},	//   _мнен, oroc, _tòfo, प्रै_,
   {{0xf8c900fe,0x00000000,0x00000000,0x00000000}},	//   _uẩn_, --, --, --,
   {{0x22580a00,0x644686b7,0x628e00e7,0x95c800e5}},	//   _nork_, _anki, _njbo, жута_,
   {{0xd7fb1c21,0x64c50d61,0x6b600139,0x555800d3}},	//   _куп_, वदेश, _fágú, оаря_,
   {{0x38690d17,0xd14b0260,0x6f02141c,0x88bd00d2}},	//   _ular_, یشان_, kroc, hvěz,
   {{0x248986b8,0x22580aa7,0xde880174,0x4cb40033}},	// [8c50] rnam_, _bork_, zịa_, ঁদপু,
   {{0x644686b9,0xe81702d5,0x9388224a,0x22580133}},	//   _enki, ध्रा_, іста_, _cork_,
   {{0xb1130134,0x7ea40428,0x9c7c0154,0x2480010a}},	//   pụmk, còpi, _pwčl, biim_,
   {{0xc95300c1,0x6f020036,0xd7af0096,0xa3d400aa}},	//   ומע_, froc, _घराच, सुआ_,
   {{0x442986ba,0x6f0286bb,0xddc18308,0x789b0129}},	//   mea_, groc, _bolş, ụkwọ_,
   {{0x442986bc,0xb3ba00d7,0x00000000,0x00000000}},	//   lea_, _למרכ, --, --,
   {{0x30850dd0,0x61fb0022,0x38b20031,0x61140120}},	//   _فلسف, _ɓull, láre_, _одру,
   {{0x442986bd,0x6f0286be,0x68ed0034,0x9f4400b6}},	//   nea_, broc, _łado, _zemí_,
   {{0x4ea704f5,0xa3bd030b,0x225886bf,0xaca30134}},	//   _држа, ेखि_, _york_, _nhụj,
   {{0x28cf018b,0x442986c0,0xa3e20179,0xde880134}},	//   _संदि, hea_, _न्न_, pịa_,
   {{0x44298158,0xd9450e3f,0x98a600d3,0x38b20031}},	//   kea_, чени, зине, háre_,
   {{0x442986c1,0xaca30134,0xa3bd397e,0xda1c1981}},	//   jea_, _kwọl, ेखा_, ब्बत_,
   {{0x442986c2,0xeb8e4129,0xdd100220,0x32110034}},	//   dea_, _чи_, _výťa, _oczy_,
   {{0xc4c60080,0xbb3a028c,0x7ea4015e,0x00000000}},	//   كترو, _לעני, tòpi, --,
   {{0xceb20054,0xc1aa00a5,0x442986c3,0x44f7003d}},	//   גים_, _करेग, fea_, għ_,
   {{0x7c2986c4,0x442986c5,0x6f0286c6,0xfd640065}},	//   neer, gea_, yroc, _airọ,
   {{0x2480008c,0x778300e5,0xe1fa5e6e,0x7c29084e}},	// [8c60] riim_, _плъз, йга_, ieer,
   {{0x7c29226b,0x69de007a,0x1ddd023a,0xf8c900fe}},	//   heer, _õpet, नुमत, _lẩm_,
   {{0x236600e9,0x7c2986c7,0x35a6268e,0x442986c8}},	//   šoj_, keer, _ханг, bea_,
   {{0x225886c9,0x69c30775,0x442986ca,0xdfcf00e3}},	//   _work_, _रणनी, cea_, هيم_,
   {{0xbea6013a,0x22585f1e,0x7c295d92,0xa3e209c3}},	//   падк, _tork_, deer, _न्य_,
   {{0xa3b1074c,0x00000000,0x00000000,0x00000000}},	//   _ओरत_, --, --, --,
   {{0x7c2986cb,0xf8c90023,0xf9870076,0x00000000}},	//   feer, _bẩm_, _أب_, --,
   {{0x7c291edb,0x629e069e,0x672402ef,0xae0e382d}},	//   geer, lopo, _opij, _सावन_,
   {{0x61ee86cc,0xd00f2eb5,0x20f80147,0x0aea0076}},	//   _kebl, _حلق_, lči_, حربي_,
   {{0x442986cd,0x58d4036a,0xa3b182d0,0x2a6a0103}},	//   zea_, моот, टेट_, óbb_,
   {{0x7c290a15,0x442986ce,0x61ee00a5,0xbc671ac9}},	//   beer, yea_, _mebl, زمین_,
   {{0x629e86cf,0x7c290ab2,0x27ed03be,0xb69b0161}},	//   hopo, ceer, úen_, grân,
   {{0xb8d362c3,0x629e86d0,0xf1bf0031,0xbb490037}},	//   _जी_, kopo, čšie_, _وجهك_,
   {{0xcad70054,0x61ee0138,0x44290a4b,0xccf800b6}},	//   _צוות_, _nebl, wea_, _kvě_,
   {{0x442986d1,0x629e0a87,0xf3da0294,0x20f80433}},	//   tea_, dopo, _ọbụn, jči_,
   {{0xa3d4000d,0x81e90081,0x3e6b0120,0x00000000}},	//   सँग_, _যাই_, _møta_, --,
   {{0x442986d2,0xe7e30d1b,0x261a02e8,0x24586da7}},	// [8c70] rea_, _क्या_, म्ही_, чать_,
   {{0x61fc0124,0x7c2986d3,0x61ee09d5,0x7d0a0b14}},	//   _cdrl, zeer, _cebl, kufs,
   {{0x442986d4,0x30150084,0x51f40037,0x7c2986d5}},	//   pea_, ддер, عسكر, yeer,
   {{0x7c2986d6,0x5ee10033,0x00000000,0x00000000}},	//   xeer, _নিবে, --, --,
   {{0x7c293370,0x61ee86d7,0x67f80018,0xde880134}},	//   veer, _febl, lújí, rịn_,
   {{0x7c2986d8,0x61ee0d50,0x9f4405fe,0xddc802ef}},	//   weer, _gebl, _demà_, _emdž,
   {{0x7c2986d9,0xfe0e02d5,0x38880103,0xde880174}},	//   teer, _सारस_, lőre_, mịl_,
   {{0xccf8030b,0x69c30034,0x0b45162b,0x69d83ca9}},	//   _dvě_, _रणबी, днин, _afve,
   {{0x7c2986da,0x06e200c7,0x28cf09c4,0xa0c40037}},	//   reer, _বিভি, _संहि, _سيكو,
   {{0x7c2986db,0xe8f986dc,0x00000000,0x00000000}},	//   seer, оло_, --, --,
   {{0xa6dd00c7,0x7c2986dd,0x382a2c13,0x672486de}},	//   _বিষয়, peer, ожно_, _spij,
   {{0x6d4186df,0x200f4053,0x06e20081,0xc5c50033}},	//   _irla, nggi_, _বিবি, ্রাপ,
   {{0x28cf00c0,0x7bcb07a5,0x61aa023a,0xb69b016d}},	//   _संवि, _iggu, _कर्ष, rrân,
   {{0x753c00b6,0x9f4f00fd,0xa96905cb,0x67240117}},	//   tvrz, gagé_, _мила_, _vpij,
   {{0x64a64587,0xddd80995,0x845a129e,0x2c830139}},	//   дава, nivš, орат_, _gèdè_,
   {{0x161f099d,0x629e86e0,0x6f0b0060,0x20f8033b}},	//   म्बर_, wopo, kugc, vči_,
   {{0xf1fa1e56,0x64a3105b,0x60ce86e1,0x7aed0092}},	// [8c80] قعات_, тата, _subm, _çatd,
   {{0x9f440074,0x7cd100d9,0x66f3009f,0x60ce863d}},	//   _nemá_, _pārl, _अबतक_, _pubm,
   {{0x629e662e,0x85bb0068,0x20f81523,0xddd809ac}},	//   ropo, _واپس_, uči_, jivš,
   {{0x61ee86e2,0x7bcb00cd,0xddd80128,0x629e86e3}},	//   _webl, _nggu, divš, sopo,
   {{0x629e86e4,0x6d4186e5,0xa51e3d34,0x61ee86e6}},	//   popo, _arla, _पहुच_, _tebl,
   {{0xa3bd0455,0x7bcb86e7,0x6d41005c,0x200f0451}},	//   ेखर_, _aggu, _brla, aggi_,
   {{0xa06a0d5e,0x998502c6,0x78a4010a,0x00000000}},	//   _дава_, delů_, _okiv, --,
   {{0x7d0a01bf,0xe0434460,0x78a40169,0x64560169}},	//   rufs, _инси, _nkiv, njyi,
   {{0x6d4123f2,0xc5f40081,0x29051b38,0x7d0a0a39}},	//   _erla, _জানা_, erla_, sufs,
   {{0x78a486e8,0xd90e110a,0x7bcb0517,0x6d4100c4}},	//   _akiv, لیت_, _eggu, _frla,
   {{0xddd80580,0x6d4186e9,0x442202ac,0xfca90d5b}},	//   civš, _grla, _obk_, _کالو_,
   {{0xfe0e0378,0x6e2100d8,0x00000000,0x00000000}},	//   _साँस_, _zblb, --, --,
   {{0x7c2286ea,0x29056500,0x78a405db,0x64560113}},	//   _ibor, arla_, _dkiv, djyi,
   {{0x645601fa,0x7ea40428,0x44221b03,0x78a486eb}},	//   ejyi, còpt, _abk_, _ekiv,
   {{0xda655c4d,0x44220634,0x200f003e,0x3e700065}},	//   _ثاني, _bbk_, yggi_, _gàte_,
   {{0x290c7076,0xf99300ca,0x9f4f014b,0x00000000}},	//   muda_, _שרק_, sagé_, --,
   {{0xfe0e0ccb,0x290c86ec,0x7c2286ed,0x4e00030b}},	// [8c90] _सांस_, luda_, _mbor, ैलाई_,
   {{0xe3b00037,0x44220062,0xdbcc0065,0x78bd58b7}},	//   شرق_, _ebk_, _kóók, lmsv,
   {{0x7c2286ee,0x38b286ef,0x7cd101d3,0x69dc003e}},	//   _obor, lára_, _pārm, ðrey,
   {{0xddd80106,0x5f951880,0x5f00007a,0x44220167}},	//   vivš, ниет, _रिश्_, _gbk_,
   {{0x290c86f0,0x38b20224,0x645d0d4f,0x443b037a}},	//   huda_, nára_, _iosi, mdq_,
   {{0x443986f1,0xddd80106,0x645d0172,0x290c86f2}},	//   _has_, tivš, _hosi, kuda_,
   {{0x4439593a,0x290c86f3,0x6da218be,0x38b286f4}},	//   _kas_, juda_, лиша, hára_,
   {{0x628586f5,0x645d0a9e,0x443986f6,0xfc3100cd}},	//   liho, _josi, _jas_, احث_,
   {{0x443901fa,0x9985030b,0xa3d4030b,0x38b20103}},	//   _mas_, telů_, सुट_, jára_,
   {{0x443986f7,0x78a40bab,0x38b26f08,0x628586f8}},	//   _las_, _skiv, dára_, niho,
   {{0x290c86f9,0x6d4186fa,0x60c986fb,0x443907ee}},	//   guda_, _urla, _kiem, _oas_,
   {{0x60c9013f,0x7aeb023e,0x6a6d0220,0xac1906d8}},	//   _jiem, _twgt, _dúfa, _ходу_,
   {{0x60c914e2,0x442200f3,0x38b201f9,0x00000000}},	//   _miem, _rbk_, gára_, --,
   {{0x786614e2,0x60c986fc,0x442272ac,0x7c2286fd}},	//   _móvi, _liem, _sbk_, _zbor,
   {{0x443986fe,0x645d0150,0xaca30174,0xe818030b}},	//   _bas_, _bosi, _ebụm, _थापा_,
   {{0x443986ff,0x60c98700,0x38b2026e,0x645d5693}},	//   _cas_, _niem, bára_, _cosi,
   {{0x44398701,0x645d8702,0x7c3902ad,0xf487015a}},	// [8ca0] _das_, _dosi, _mawr, رافی,
   {{0x6aa102ad,0xae0e00a5,0x60c90084,0x44398703}},	//   nolf, _साइन_, _aiem, _eas_,
   {{0x26d2068d,0x44398704,0x44220085,0xe853001c}},	//   _huyo_, _fas_, _tbk_, _شنید,
   {{0x645d00ac,0x60c98705,0x61e307aa,0x78660072}},	//   _gosi, _ciem, ınla, _bóvi,
   {{0x765e8706,0xe818000f,0x60c98707,0x9f34004d}},	//   _kopy, _थाना_, _diem, телі,
   {{0x44208708,0x290c8709,0x645d870a,0x7c22870b}},	//   lfi_, yuda_, _zosi, _sbor,
   {{0x4439870c,0x4420870d,0x26d20270,0x645d870e}},	//   _yas_, ofi_, _luyo_, _yosi,
   {{0x8fa64c89,0x4439006c,0x7c3b0bb6,0x4420870f}},	//   _забе, _xas_, gdur, nfi_,
   {{0x7c3954b8,0xddcf00b6,0x44200178,0x3d1c074c}},	//   _dawr, řešn, ifi_, _महके_,
   {{0x60c98710,0x290c8711,0x44200808,0x7c3b8712}},	//   _ziem, tuda_, hfi_, adur,
   {{0x628b020d,0x7c390178,0x7c3b01ee,0x00000000}},	//   égoi, _fawr, bdur, --,
   {{0x290c493f,0x7c228713,0x26d200f9,0xa3b10179}},	//   ruda_, _ubor, _buyo_, _ओरल_,
   {{0x645d66d6,0x26d20890,0xc6f80426,0x27f2008c}},	//   _rosi, _cuyo_, ннях_, _deyn_,
   {{0xb9060033,0x6285037a,0x7c39007f,0x62880154}},	//   _পি_, xiho, _zawr, _ňdon,
   {{0x44398714,0xa8a70315,0x44208715,0xe80a02e8}},	//   _pas_, _прик, ffi_, _वाचा_,
   {{0x44398716,0x68fa5707,0x27f2008c,0x645d3177}},	//   _qas_, mstd, _geyn_, _qosi,
   {{0xe4ed05d4,0x60c98717,0x7cd100d9,0x7689013f}},	// [8cb0] _जबकि_, _riem, _pārk, ržyb,
   {{0x44398718,0x60c98719,0x69da871a,0x645d0b09}},	//   _was_, _siem, ncte, _wosi,
   {{0x4439871b,0x60c9871c,0x645d02fd,0x81a90033}},	//   _tas_, _piem, _tosi, খেন_,
   {{0x44390d7d,0x6285871d,0x3ea50063,0x81e90033}},	//   _uas_, siho, _sklt_, _যাও_,
   {{0x60c9871e,0x6e3a871f,0x62858720,0x15e5009f}},	//   _viem, _batb, piho, _कभार_,
   {{0x60c98721,0x00000000,0x00000000,0x00000000}},	//   _wiem, --, --, --,
   {{0x60c98722,0x6e3a02ad,0x6aa1789c,0x7c3b8723}},	//   _tiem, _datb, volf, tdur,
   {{0xdd8e0080,0x20d7008b,0x6e3a00f9,0x6f040aa0}},	//   توى_, _içi_, _eatb, šica,
   {{0x26121d72,0xaed500d6,0x6e3a4f39,0x7cd100e8}},	//   _ताली_, _розш, _fatb, _māri,
   {{0x39456eb1,0x6a86020d,0x7c3b8724,0xfaf900e8}},	//   вног, _réfè, sdur, rsū_,
   {{0x44208725,0x26d28726,0xdd1e1515,0x71f60033}},	//   yfi_, _suyo_, píše, _চামচ_,
   {{0xcc1400bf,0x6aa13706,0x765e0169,0x00000000}},	//   _مذهب, solf, _sopy, --,
   {{0x69c30d77,0x6c7a006e,0x64d70129,0x2cbf00bc}},	//   _रणवी, _קאנפ, _ụkpụ, mmud_,
   {{0x27f20694,0x2cad0054,0x6b670af0,0xbbd12f8f}},	//   _weyn_, lled_, _eégú, _हलुक,
   {{0xe5a64a54,0x44208727,0x7afb2e94,0x48b6007b}},	//   тиви, tfi_, lsut, _ищит,
   {{0x64be3245,0xb4ac009d,0x26d28728,0xde880134}},	//   ्देश, गते_, _tuyo_, tịk_,
   {{0x44208729,0xe36321b6,0x7afb2ba4,0x3e70009c}},	// [8cc0] rfi_, акти, nsut, _làta_,
   {{0x2cbf6fc5,0x2cad030b,0x09c50033,0x7afb0f06}},	//   hmud_, hled_, _শ্যা, isut,
   {{0xa3ea14fa,0x6e3c22a4,0x386000dc,0x6d6603e3}},	//   _одна_, _órbi, _koir_, ƙraɗ,
   {{0xdee64be7,0x7afb872a,0x24820085,0xa06700e5}},	//   води, ksut, _umkm_, каха_,
   {{0x44fe01b3,0x2cad00f0,0x6e3a03a9,0x3860009c}},	//   lį_, dled_, _patb, _moir_,
   {{0x24922ac2,0x2cad0078,0x3e700441,0x386000fd}},	//   lnym_, eled_, _bàta_, _loir_,
   {{0x44fe01b3,0xda18007d,0x660101cd,0x6e3a1570}},	//   nį_, _दाबत_, ólki, _vatb,
   {{0x2492872b,0x3860025a,0x3e700441,0x00000000}},	//   nnym_, _noir_, _dàta_, --,
   {{0x7afb872c,0x38b90103,0xaec600c6,0x6e3a111d}},	//   gsut, nére_, _абал, _tatb,
   {{0x44fe0138,0x38601909,0xf8ca00fe,0x2ca60f5a}},	//   kį_, _aoir_, _mẩu_, _wkod_,
   {{0xd6e200c7,0x2cad00a1,0x386001b9,0xf8ca0023}},	//   _বিষয, bled_, _boir_, _lẩu_,
   {{0x2cad872d,0x38600527,0xb4ac009d,0xdbcc01ab}},	//   cled_, _coir_, गतो_, _góðk,
   {{0xf8bf025a,0x24923430,0x386001b9,0x7f42394f}},	//   rmé_, dnym_, _doir_, nvoq,
   {{0xb7e306e4,0x7f424a9a,0x7aed0491,0x26f30ccb}},	//   _क्रम_, ivoq, _çata, _अबीर_,
   {{0x7cd100d9,0x2a920065,0x38601c26,0x38720727}},	//   _pāri, _e̟bí_, _foir_, _flyr_,
   {{0x481542d1,0x3860036b,0x588701b6,0xd4980e20}},	//   _смис, _goir_, _шыла, вру_,
   {{0xf8ca0023,0x38b90103,0x3ce909ac,0xa3d41a0c}},	// [8cd0] _cẩu_, gére_, ćavi_, роуч,
   {{0x7afd0b0b,0x7ae20010,0x291e42c7,0xb7d60065}},	//   ásti, _mtot, otta_, _iṣap,
   {{0xdfd10080,0x2cad1064,0x24925984,0x00000000}},	//   ميا_, yled_, bnym_, --,
   {{0x6ef80294,0x3e7001b9,0x2492872e,0x00000000}},	//   _ụbar, _ràta_, cnym_, --,
   {{0x2489872f,0x9ac4009e,0x6f04007e,0x00000000}},	//   miam_, _kaċċ, šicn, --,
   {{0x24894f85,0x9ac4009e,0xee380120,0x6b8d05db}},	//   liam_, _jaċċ, кні_, _žago,
   {{0xc21200a1,0x261b05a7,0x2cad8730,0x7ae25ba8}},	//   _להם_, _बानी_, tled_, _atot,
   {{0x3949585e,0x24898731,0x7afb69b0,0x9ac40090}},	//   _čas_, niam_, tsut, _laċċ,
   {{0x40844cb0,0x291e0c79,0x2cad8732,0x89f504a1}},	//   _турб, etta_, rled_, лянц,
   {{0x38608733,0x7ead0220,0x7afb8734,0x2489022e}},	//   _soir_, kúpi, rsut, hiam_,
   {{0x7afb5de4,0xe73c0b88,0xb7d60065,0x644f155b}},	//   ssut, _küçü, _aṣap, _onci,
   {{0x05a70251,0x7c846289,0x2369026a,0x66e68735}},	//   _गड़ब, _куче, kyaj_, лома,
   {{0x386010af,0x7e618736,0x24898737,0xc8cf0d88}},	//   _voir_, _kolp, diam_, _संकट,
   {{0x644f17fc,0x44fe0138,0x24920034,0x61f58738}},	//   _anci, tį_, wnym_, _nezl,
   {{0x05a4009f,0x249221d7,0x2489604f,0x2c7102c6}},	//   _खुशब, tnym_, fiam_, _záda_,
   {{0x38b90018,0x44fe013f,0x6a790139,0x248957a3}},	//   tére_, rį_, _fùfù, giam_,
   {{0x42262d20,0x4e13030b,0x44fe0138,0x9ac4009e}},	// [8ce0] лдав, ठलाई_, sį_, _faċċ,
   {{0xe7474794,0x78a62a4e,0x44fe0138,0x24920034}},	//   ções_, lokv, pį_, snym_,
   {{0x38b90018,0x600a4be7,0x61f500ae,0x6a640154}},	//   sére_, енем_, _dezl, _kòfr,
   {{0x24898739,0xd00f0037,0xf8ca00fe,0x00000000}},	//   ciam_, كلم_, _tẩu_, --,
   {{0x4432873a,0x7e61873b,0x2ca402ef,0x7cd100e8}},	//   mey_, _bolp, vomd_, _māru,
   {{0x7e61873c,0x291e2452,0x4432873d,0x2c7100b6}},	//   _colp, ytta_, ley_, _ráda_,
   {{0xe2970231,0x60d500e1,0xad261850,0x202501cd}},	//   _сар_, _guzm, ارتو, úsið_,
   {{0x4432873e,0x8c3d00ae,0xd12f01c3,0x2b46873f}},	//   ney_, toşa, _عمق_, _proc_,
   {{0x3a741a53,0x2e1612eb,0x332000bd,0x60c20d2a}},	//   илир, _مباح, ntix_, mmom,
   {{0xc3330054,0x27e0025a,0x7e610d9f,0x4432008a}},	//   צות_, _afin_, _golp, hey_,
   {{0xc27b00c1,0x291e0084,0x6a64022b,0x59d6007f}},	//   גריי, utta_, _bòfr, डखबर,
   {{0x7cd10029,0x291e8740,0x2b468741,0x443201ee}},	//   _pārv, rtta_, _troc_, jey_,
   {{0x44320694,0x24898742,0x27e002a1,0x7ae20239}},	//   dey_, viam_, _dfin_, _utot,
   {{0xbb3b0130,0x248900a5,0x7ead0220,0x27e0009c}},	//   _רעגי, wiam_, túpi, _efin_,
   {{0x24898743,0xceb30341,0x44328744,0x27e000f0}},	//   tiam_, מיש_, fey_, _ffin_,
   {{0x4432008a,0x6d485c4a,0x60d5042d,0x61f5044c}},	//   gey_, _mrda, _ruzm, _sezl,
   {{0x24898745,0xf77312eb,0x05150033,0xe3b00037}},	// [8cf0] riam_, _داغ_, াবের_, كرك_,
   {{0x7cd10029,0xbbd106ed,0x6d488746,0x24898747}},	//   _kārt, _हल्क, _orda, siam_,
   {{0x7e61057a,0x6601003e,0x443213e2,0x4fd56ab4}},	//   _rolp, ólku, bey_, ажет,
   {{0x44328748,0x644f8749,0x60c2874a,0x7cd101d3}},	//   cey_, _unci, gmom, _mārt,
   {{0x6d48874b,0x64db009d,0x7e61874c,0x61f51e6b}},	//   _arda, _मंडळ, _polp, _tezl,
   {{0x8d652de9,0x26dc00c1,0x20040383,0x6d480357}},	//   ивле, עקומ, _edmi_, _brda,
   {{0xed590ee6,0x7e61874d,0xbdf808ba,0x99d500d1}},	//   той_, _volp, ارها_, یتدا,
   {{0xf0bb0470,0x9b05007e,0x7e6102ac,0xbc650e05}},	//   _سازش_, азид, _wolp, рвик,
   {{0x6d48874e,0x290c0890,0xd7c724eb,0xaae4001c}},	//   _erda, erda_, रेमच, یسیو,
   {{0xea240d79,0x4432008b,0x2bd104f1,0xe818030b}},	//   ẹ́rẹ, zey_, _हलका, _थाहा_,
   {{0x4432025e,0x3ea7874f,0xf99100e3,0x672d8750}},	//   yey_, mont_, تبة_, _apaj,
   {{0x18a602fd,0x4432008a,0x92a60034,0xf7462ea7}},	//   рамм, xey_, _załą, аемо,
   {{0xa3d91117,0x290c8751,0xbca400b9,0x4a75007b}},	//   ाशन_, arda_, _امني, _выйт,
   {{0x4b7a0130,0x4432793a,0x7ae98752,0x3ea70154}},	//   _באנו, wey_, mpet, nont_,
   {{0x4432008a,0x33f60b9e,0xfa3405bc,0x00000000}},	//   tey_, ичас, _درند, --,
   {{0xd91a0266,0xfe7902c6,0x26125fc7,0x3ea78753}},	//   _סופל, _stůl_, _ताकी_, hont_,
   {{0x44328754,0x7ae98755,0x3ea78756,0xa3e2009f}},	// [8d00] rey_, npet, kont_, नुष_,
   {{0x14b8009d,0xf2df00de,0x38b90352,0x3ea7028d}},	//   _आठवण, _trân_, méra_, jont_,
   {{0x332000bd,0x7f490314,0x60c28757,0x38b92722}},	//   stix_, _areq, tmom, léra_,
   {{0x03a600d6,0x04468758,0x09d2030b,0x628b020d}},	//   _вимо, _темн, _सल्य, égor,
   {{0x6d480106,0x3ea78759,0x3fcb001c,0x7d0100f2}},	//   _srda, font_, ندهی_, _avls,
   {{0x7f490052,0xa3e200bc,0x290c0e37,0x00000000}},	//   _dreq, नुर_, yrda_, --,
   {{0x80c600a4,0x00000000,0x00000000,0x00000000}},	//   िषदे, --, --, --,
   {{0xa0670b2e,0x290c0357,0x7f49875a,0x9c7c022b}},	//   _каса_, vrda_, _freq, _etčn,
   {{0x7f4900dd,0xa0673e81,0xee3a311c,0x7ae90124}},	//   _greq, _тата_, _ина_, gpet,
   {{0xaa660a8e,0x7cd100d9,0x3a742d06,0x00000000}},	//   ртик, _pārt, слор, --,
   {{0xfce309fe,0x6d480b7e,0x67d500d3,0xc3220033}},	//   _дохо, _urda, йону, নিটি_,
   {{0x7cd101d3,0x2c780139,0x245c0206,0x7ae90216}},	//   _vārt, _béde_, _tímy_, bpet,
   {{0x628001b3,0xb7140e38,0xab830291,0x7ae90428}},	//   _įmon, одящ, _мушк, cpet,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa5f81803,0x28d02301,0xe9370037,0x3abb0796}},	//   ресу_, _संचि, _نسيت_, _שמונ,
   {{0xb8670018,0x63af875b,0xf7a80174,0x57f50307}},	//   _خاتو, _pycn, ọmịk_, _упит,
   {{0xaaba0251,0x4aba007a,0xb4b7009f,0x78ad0169}},	// [8d10] _उठाक, _उठाव, _छठी_, _ikav,
   {{0xe7e306ec,0x00000000,0x00000000,0x00000000}},	//   कुरा_, --, --, --,
   {{0xc5f200a1,0x78ad010a,0x3167044c,0x00000000}},	//   _מדי_, _kkav, ânz_, --,
   {{0x9099022a,0x7ae90565,0x00000000,0x00000000}},	//   ывет_, ypet, --, --,
   {{0xb4b30789,0xc8d0009d,0x28c815e4,0x3ea776c5}},	//   टती_, _संघट, रगति, tont_,
   {{0x14b5009d,0x62870372,0x00000000,0x00000000}},	//   ंतवण, _umjo, --, --,
   {{0x3ea7025a,0x442b875c,0x5d330018,0x60400174}},	//   ront_, _kbc_, تہائ, _ịmef,
   {{0x1ee709b4,0x7ae900cb,0x3ea7875d,0x78ad0169}},	//   _نوری_, tpet, sont_, _nkav,
   {{0x7cd10029,0x3ea70018,0x4aa95cb1,0x7ae9875e}},	//   _pārs, pont_, лкин_, upet,
   {{0xfc3f000d,0x78ad221a,0x7aed0092,0xfe730192}},	//   ží_, _akav, _çatm, _بدر_,
   {{0x7ae9875f,0x186a1e61,0x81a90081,0x8d740dce}},	//   spet, гани_, খের_, _واما,
   {{0x7ae90d63,0x38b900d4,0x31560142,0x00000000}},	//   ppet, téra_, צירן_, --,
   {{0x3b090aeb,0x38b26f71,0x00000000,0x00000000}},	//   _село_, nári_, --, --,
   {{0x78ad00cc,0x442b0703,0x00000000,0x00000000}},	//   _ekav, _abc_, --, --,
   {{0x442b8760,0xceb27c04,0xd5b20e00,0xd9c50081}},	//   _bbc_, פיל_, سفر_, _শ্রম,
   {{0x28d00296,0x475a008f,0x38b20031,0x442b5263}},	//   _सूचि, _броя_, kári_, _cbc_,
   {{0xe29a016d,0xe3ba4268,0x045700e3,0x00000000}},	// [8d20] гаа_, уба_, حلقة_, --,
   {{0x6f04035d,0x975b0142,0x38b24df5,0x7d1c059a}},	//   šick, _עדיט, dári_, _årsg,
   {{0x60264a6f,0x64a60138,0x00000000,0x00000000}},	//   йджа, _гана, --, --,
   {{0xd91a006e,0x38b20231,0x3ebe020b,0x00000000}},	//   טועל, fári_, _shtt_, --,
   {{0xb4c400a5,0x00000000,0x00000000,0x00000000}},	//   एगी_, --, --, --,
   {{0xbea3594b,0xa2e31e46,0x7c2b8761,0x00000000}},	//   пачк, _хорд, _abgr, --,
   {{0x261b1843,0x61fe8762,0x716700d3,0xafe66ab2}},	//   _बासी_, mapl, _ларг_, _гобл,
   {{0x64440a15,0x6ab20c38,0xc4d30089,0x61fe8763}},	//   ndii, ुग्र, הגה_, lapl,
   {{0x7cd101d3,0x3e79014b,0x9e650103,0x00000000}},	//   _pārr, _sète_, _ڈالن, --,
   {{0x9e650080,0xc33300a1,0x527b00c1,0x78ad4563}},	//   _والن, לוח_, ָנטא, _skav,
   {{0x6f028764,0x00000000,0x00000000,0x00000000}},	//   lsoc, --, --, --,
   {{0xc19b0130,0x13b00033,0x2db7006e,0xe9190018}},	//   רשטי, চেয়, _פלאן_, گریڈ_,
   {{0x61fe6692,0x6f026e02,0x64443329,0x83a700c3}},	//   kapl, nsoc, ddii, _कुंआ,
   {{0x442b008c,0x69dc1656,0xeb070076,0x00000000}},	//   _sbc_, žreb, _اقوى_, --,
   {{0xe5c4008f,0x61fe8765,0x7d1c1842,0x00000000}},	//   зсто, dapl, _årsd, --,
   {{0x38b9025a,0xb4b3009d,0x64440270,0x629c0052}},	//   méro_, टते_, gdii, _ajro,
   {{0xf2df0023,0x0ea80285,0x442b0027,0x335800ae}},	// [8d30] _trâm_, गवाड, _vbc_, батэ_,
   {{0x61fe8766,0x60c08767,0x51f80109,0x6f0202c3}},	//   gapl, _ahmm, йную_, dsoc,
   {{0x442b8768,0x629c0113,0x3e6b0120,0x55591cf2}},	//   _tbc_, _djro, _møtt_, _таня_,
   {{0xdd00000d,0x442b1821,0x68e41054,0x00000000}},	//   štěn, _ubc_, _čidl, --,
   {{0xd3410103,0x00000000,0x00000000,0x00000000}},	//   _تہذی, --, --, --,
   {{0x999e0068,0x63bd01d3,0x60c00167,0x59c81cff}},	//   hető_, _izsn, _ehmm, रधार,
   {{0x6cc564ba,0x44290037,0x26db0090,0x38b28769}},	//   ойка, ofa_, _luqo_, sári_,
   {{0x4429876a,0x26d3137f,0x00000000,0x00000000}},	//   nfa_, _lixo_, --, --,
   {{0x290a0068,0xeb990399,0x4429876b,0x5e59001c}},	//   ában_, рип_, ifa_, _پلاس_,
   {{0x090500d6,0x28dd0714,0x00000000,0x00000000}},	//   опон, _नंदि, --, --,
   {{0xdd9b2082,0x64440694,0x16200789,0xa3d92999}},	//   _сша_, ydii, _बाबर_, ाशा_,
   {{0xc5e909c1,0x290b876c,0x4429876d,0x22430357}},	//   _יד_, čca_, jfa_, _lajk_,
   {{0x442902ad,0xdd1e0181,0x27ff003e,0x7c29876e}},	//   dfa_, _víťa, ðuna_, mfer,
   {{0x7c290bd8,0x3e7001b9,0x00000000,0x00000000}},	//   lfer, _càth_, --, --,
   {{0x61fe01e8,0x26d308a8,0x261b0409,0x291101f9}},	//   vapl, _dixo_, _बारी_, ázad_,
   {{0x7416177a,0x26d3137f,0x13ea00c6,0x6f040220}},	//   تورا, _eixo_, рмай_, šici,
   {{0xe1fa0aeb,0x26d3876f,0x61fe12db,0x22430357}},	// [8d40] ига_, _fixo_, tapl, _bajk_,
   {{0x44298770,0x41b61ffa,0x7ce70342,0x00000000}},	//   afa_, осет, _kırd, --,
   {{0xda211349,0x27248771,0x06e20033,0x00000000}},	//   _मानत_, lön_, _বিটি, --,
   {{0x5ee100c7,0x7c290126,0x61fe026a,0x44290169}},	//   _নিজে, jfer, sapl, cfa_,
   {{0xee3a0012,0xaf3633c6,0xd00f0604,0x7c29030a}},	//   инд_, ترات, ئله_, dfer,
   {{0x999e0018,0x7c290364,0x6f028772,0x0cb43751}},	//   zető_, efer, rsoc, ुष्म,
   {{0x7c298773,0x27248774,0x7cd100d9,0x61fc1044}},	//   ffer, hön_, _pārp, _ierl,
   {{0x61fc526d,0x2c7800cd,0x60c00270,0x272431b2}},	//   _herl, _béda_, _uhmm, kön_,
   {{0x60dc8775,0x7a3f013f,0x27248776,0x61fc21ce}},	//   _hurm, kštė, jön_, _kerl,
   {{0x60dc8777,0x61fc28be,0x5ee10033,0x27248778}},	//   _kurm, _jerl, _নিচে, dön_,
   {{0x44298779,0x60dc6473,0xb2bb021e,0x3e70009c}},	//   yfa_, _jurm, שמיר, _ràth_,
   {{0xab2a085f,0x26dc00cb,0x67240078,0xd6e20033}},	//   _вода_, _čvor_, _bqij, _বিজয,
   {{0xd90e0814,0xa09b00c1,0x7d1c0b97,0xaa46007b}},	//   ریک_, שיכט, _årsb, _медл,
   {{0x25e600b6,0x61fc0572,0x00000000,0x00000000}},	//   जुली_, _nerl, --, --,
   {{0x7e6855b1,0x442918d3,0x60dc789e,0x45d4872f}},	//   _modp, tfa_, _nurm, дорс,
   {{0xd5b8333f,0x4429877a,0x61fc0076,0x00000000}},	//   юся_, ufa_, _aerl, --,
   {{0x61fc877b,0x4429877c,0xb2751c47,0x22431500}},	// [8d50] _berl, rfa_, плаш, _pajk_,
   {{0x4429877d,0x4eac0081,0x656e0103,0x9f440032}},	//   sfa_, গগুল, ínhá, _lemó_,
   {{0x60dc877e,0x44290193,0x2fd900e3,0x38690479}},	//   _curm, pfa_, مواد_, _koar_,
   {{0x61fc0305,0x60dc877f,0x7e7a8780,0xdbdc00d4}},	//   _eerl, _durm, _altp, yšák,
   {{0x61fc8781,0x66c0539e,0x76458782,0xdb070511}},	//   _ferl, söke, _kahy, ümüz,
   {{0x61fc8783,0x60dc0188,0x0e6401ce,0x3e790154}},	//   _gerl, _furm, мкін, _bèta_,
   {{0xc6940130,0x7c2902e2,0x60dc8784,0xf3ff001f}},	//   ואס_, tfer, _gurm, _joão_,
   {{0x320101ee,0x61e500f0,0xab65180b,0x61fc042c}},	//   lahy_, lchl, звил, _zerl,
   {{0x7c298785,0x61fc06d7,0x5f9402ec,0xa3ce1677}},	//   rfer, _yerl, _житт, षेप_,
   {{0x61e50527,0x3201041c,0x60dc0167,0x628000c6}},	//   nchl, nahy_, _yurm, _įmok,
   {{0x7c298786,0xa92201b6,0x61e525e1,0x60dc4628}},	//   pfer, ндэл, ichl, _xurm,
   {{0x7e6818ed,0x201d003d,0x27240084,0x88bd00b6}},	//   _zodp, ngwi_, tön_, stěn,
   {{0x38690012,0xacaa00fb,0x31b8178c,0x7bd90174}},	//   _doar_, _اپنے_, _अर्ध, _igwu,
   {{0x7645684d,0x9f5d00bf,0x27248787,0x2b4f00e7}},	//   _cahy, gawé_, rön_, _irgc_,
   {{0x4912033a,0x61e57a71,0x27241023,0x320101ee}},	//   _थियो_, dchl, sön_, dahy_,
   {{0x61fc8788,0x6d41005c,0x38690113,0x07a6021a}},	//   _serl, _msla, _goar_, _найн,
   {{0x61fc14f7,0xd467455b,0x60dc8789,0x6d41878a}},	// [8d60] _perl, чите_, _surm, _lsla,
   {{0x6d4110e1,0x60dc878b,0x2c710139,0x2cad878c}},	//   _osla, _purm, _dádi_, hoed_,
   {{0x61fc0418,0x2905878d,0xd5b00068,0x7bd90134}},	//   _verl, nsla_, _شہر_, _ogwu,
   {{0x64a6878e,0x6d5c0013,0x76450244,0x60dc0491}},	//   _хама, _àrai, _zahy, _vurm,
   {{0x61fc2c09,0xe81f0006,0x6d41878f,0x60dc8790}},	//   _terl, _भासा_, _asla, _wurm,
   {{0x7bd90174,0x2907015c,0x29054117,0x3ae001ec}},	//   _agwu, _ovna_, ksla_, _ròp_,
   {{0xdb070871,0x628e8791,0x427b006e,0x389601d3}},	//   _člán, _imbo, _פאלג, lāru_,
   {{0x64468792,0x2cad03ee,0xc19b00a1,0x2905320e}},	//   _jaki, goed_, _השלי, dsla_,
   {{0x64468793,0x6d41167e,0x4422033c,0x389601d3}},	//   _maki, _esla, _mck_, nāru_,
   {{0x64468794,0x7bd906c0,0x3a060018,0x20d70090}},	//   _laki, _egwu, سکتی_, _għis_,
   {{0x68ed0031,0x2cad0167,0x24800167,0x27ed0072}},	//   _čadc, boed_, khim_, ñeno_,
   {{0x64467acf,0x76458795,0x63a20034,0x387b0231}},	//   _naki, _sahy, żony, _qlqr_,
   {{0x628e0973,0x2480023b,0x61e58796,0x38690558}},	//   _ombo, dhim_, ychl, _voar_,
   {{0x2c7100b6,0x64468797,0x6d418798,0x442207ee}},	//   _rádi_, _aaki, _ysla, _ack_,
   {{0x64468799,0x7647052f,0xa2c008fa,0x32010094}},	//   _baki, rdjy, वतन्, vahy_,
   {{0x628e132d,0x76451084,0x6446879a,0x2480879b}},	//   _ambo, _wahy, _caki, ghim_,
   {{0x6446879c,0x4e1c030b,0x320100b6,0x764543b5}},	// [8d70] _daki, नलाई_, tahy_, _tahy,
   {{0x78af28bd,0x82340281,0x8c3d879d,0xdbf200d2}},	//   locv, فرما, roşi, dříz,
   {{0x7c222b3d,0x250900cd,0x4422052f,0x61e5879e}},	//   _ocor, _برخی_, _fck_, rchl,
   {{0x628e7b7f,0x61e502dc,0xdfd100e3,0x32010094}},	//   _embo, schl, نيا_, sahy_,
   {{0x2cad1044,0x65c70113,0x00000000,0x00000000}},	//   voed_, béhé, --, --,
   {{0x443b0063,0xed59879f,0x290587a0,0x90870103}},	//   leq_, жок_, ysla_, _کمرے_,
   {{0xdd910018,0x787f023b,0x27e90088,0xdca5008f}},	//   کوں_, _zëve, _ofan_, маки,
   {{0xe81f0e4c,0x14bf0a30,0x443b3177,0x7d081d09}},	//   _भाषा_, ्षिण, neq_, _dvds,
   {{0x200d87a1,0xaca30294,0x7c22009c,0x1c42163d}},	//   _idei_, _nkụj, _dcor, тным,
   {{0xddc1020a,0xbdf80103,0x24800052,0x27e94c80}},	//   _colţ, _فرما_, zhim_, _afan_,
   {{0x19c521f4,0x389600d9,0xa9691e61,0x7809009d}},	//   ьбом, kārt_, цина_, वणूक_,
   {{0x162005d4,0x7d1c0856,0x290523ff,0x27e9009c}},	//   _बाहर_, _årsa, rsla_, _cfan_,
   {{0xeaae0012,0xb9040bd9,0x290587a2,0x7c3b87a3}},	//   _ай_, _भू_, ssla_, meur,
   {{0x64466c54,0x7c3b5f49,0x33290063,0x27e901b9}},	//   _saki, leur, dtax_, _efan_,
   {{0xceb2534e,0x644687a4,0x248087a5,0xb4d8087c}},	//   דים_, _paki, thim_, ादे_,
   {{0xd7af0134,0x389600e8,0x00000000,0x00000000}},	//   ụpụr, tāru_, --, --,
   {{0x644687a6,0x4422020b,0x24920350,0x00000000}},	// [8d80] _vaki, _vck_, riym_, --,
   {{0x644687a7,0x7c3b87a8,0x248000dd,0x200d0063}},	//   _waki, heur, shim_, _adei_,
   {{0x644687a9,0x7c3b03ee,0x6f09034f,0x248087aa}},	//   _taki, keur, _avec, phim_,
   {{0x7c3b00fd,0xa9270146,0x442287ab,0x64464b5f}},	//   jeur, _zaží, _uck_, _uaki,
   {{0x9c7c03c6,0x6f094a3d,0x98a70106,0x1eaa00e3}},	//   _juče, _cvec, žića_, ياتي_,
   {{0x442087ac,0x628e87ad,0x00000000,0x00000000}},	//   lgi_, _umbo, --, --,
   {{0x7c3b87ae,0x442000f0,0x9c7c5695,0x389601d3}},	//   feur, ogi_, _luče, nārs_,
   {{0x7c3b87af,0x3e790032,0x547b006e,0xf8c800bc}},	//   geur, _fèto_, ַטיו, रगोप,
   {{0x442087b0,0xcf46513e,0xf2df078e,0x00000000}},	//   igi_, _юнай, _frâu_, --,
   {{0xf2df020a,0x66c000ce,0x00000000,0x00000000}},	//   _grâu_, yöka, --, --,
   {{0x7c3b04ee,0x0217040a,0x6d5c0d62,0xa3ce0096}},	//   beur, וחים_, _šraf, षेत_,
   {{0xb4d8049d,0x3eb901d3,0x7c3b3e60,0x7c22406e}},	//   ादो_, _īsti_, ceur, _ucor,
   {{0x3f8687b1,0x7a370294,0xab9a22aa,0x442087b2}},	//   nzou_, ụtak, _بخار_, dgi_,
   {{0xf98f14df,0x64830006,0xddda000d,0x442087b3}},	//   ابی_, _kõig, _potř, egi_,
   {{0x7ce70233,0x08f70308,0x443b11bc,0x00000000}},	//   _kıra, _قريب_, teq_, --,
   {{0x442087b4,0x261b1133,0x00000000,0x00000000}},	//   ggi_, _बाकी_, --, --,
   {{0x66c00222,0x443b3d42,0x43940a28,0x648300aa}},	// [8d90] söka, req_, ватс, _lõig,
   {{0x7c3b01ff,0x442087b5,0x81c80033,0x629e13ea}},	//   zeur, agi_, উশন_, gnpo,
   {{0x3329003d,0x301587b6,0x6f0987b7,0x44200124}},	//   stax_, едер, _svec, bgi_,
   {{0x8c3d00d3,0x44200124,0x629e6f7b,0xf8ca00fe}},	//   noşt, cgi_, anpo, _bẩy_,
   {{0xb4bd00a5,0xa3b60775,0x7c3b232f,0x25e6007f}},	//   ेगी_, _चुप_, veur, जुकी_,
   {{0x171c006e,0x00000000,0x00000000,0x00000000}},	//   קווע, --, --, --,
   {{0x7ce70b88,0x7c3b0b87,0x7bc287b8,0xddc187b9}},	//   _bıra, teur, _azou, _bolš,
   {{0x0b454d79,0x88bd030b,0x00000000,0x00000000}},	//   енин, stěj, --, --,
   {{0x7c3b87ba,0x6f090542,0xf2df87bb,0x6d5e87bc}},	//   reur, _uvec, _trâu_, äpar,
   {{0xaa451994,0xdb0e00e3,0x7c3b87bd,0x442087be}},	//   хеол, ádál, seur, zgi_,
   {{0x02db40c1,0xa3b60ed3,0x9c7c0f39,0x7c3b014b}},	//   बदुन, _चुन_, _suče, peur,
   {{0x2c710094,0xddc105db,0x30790142,0x00000000}},	//   _pádu_, _golš, פאָנ, --,
   {{0x4420008e,0xd5b801d3,0x4e030ee0,0xf8ca020b}},	//   vgi_, ļām_, _रजाई_, _xẩy_,
   {{0x9c7c0a9e,0xb4d887bf,0x389600e8,0x00000000}},	//   _vuče, ाद्_, tārs_, --,
   {{0x442087c0,0x81e50033,0xe5a300f3,0x00000000}},	//   tgi_, নরা_, гири, --,
   {{0x69c300e9,0x044334fc,0x442087c1,0x9c7c00c4}},	//   _izne, лесн, ugi_, _tuče,
   {{0x221616d9,0xb89b00ca,0x00000000,0x00000000}},	// [8da0] ефер, _מבקש, --, --,
   {{0x44205dcd,0xc7d700ca,0x66290031,0xf8ca00fe}},	//   sgi_, _אופי_, ľský, _rẩy_,
   {{0x7cd100d9,0x66c000c2,0x00da0037,0x44201ba7}},	//   _dārz, löko, سبات_, pgi_,
   {{0x5f060e45,0xfbc70241,0x44fe00b6,0x92c00a43}},	//   езда, _مت_, mů_, ঁদে_,
   {{0x08e60f71,0x44fe00b6,0xddc80034,0x26da0a4b}},	//   _কিছু_, lů_, łoże, _kipo_,
   {{0x7ce70702,0x3f86002b,0xdd94198b,0xf8ca00fe}},	//   _sıra, rzou_, калы, _vẩy_,
   {{0x44fe030b,0xddc100b6,0x78a4037a,0xc5f300ca}},	//   nů_, _polš, _ojiv, נדה_,
   {{0x26da87c2,0xf8ca00de,0x31570327,0x7ce7013c}},	//   _lipo_, _tẩy_, _אילן_, _qıra,
   {{0x8fa3078b,0x44fe00b6,0x4fa31b60,0xddc1007e}},	//   _бате, hů_, _битв, _volš,
   {{0xdee34e26,0xd90e1e49,0x44fe00b6,0x26da87c3}},	//   _софи, میت_, ků_, _nipo_,
   {{0x2d870d1b,0x44fe030b,0x2d9807ee,0xda212674}},	//   czne_, jů_, _äre_, _मारत_,
   {{0x44fe030b,0x6fd607aa,0xb4aa030b,0xa3b600bc}},	//   dů_, _gücü, खको_, _चुभ_,
   {{0x98745ec9,0xc6a710a6,0x00000000,0x00000000}},	//   уляц, ерви, --, --,
   {{0x66c00149,0x7aef002b,0xdcdf03b3,0x6d5c01ec}},	//   sökn, ícte, _पूँछ, _àras,
   {{0x5558002d,0xb60600e7,0x26da0af0,0x7ae26f7b}},	//   наря_, dušč, _dipo_, _huot,
   {{0xf9690120,0x00000000,0x00000000,0x00000000}},	//   _юрій_, --, --, --,
   {{0x291e3292,0x481400c2,0x61fb00e7,0x7ae2007b}},	// [8db0] luta_, _смыс, _đulb, _juot,
   {{0x979c004f,0x64830006,0x7ae20084,0x78bd87c4}},	//   _משחק, _sõid, _muot, llsv,
   {{0x291e01ac,0xf1a71167,0x7ae20084,0x82a41009}},	//   nuta_, хран, _luot, уште,
   {{0x26da0051,0x224a01ff,0xc078004d,0xe0d006cf}},	//   _zipo_, _eabk_, нсії_, مزن_,
   {{0x54543ad2,0x7ae201b3,0x645d0a5f,0x6483007a}},	//   _свят, _nuot, _insi, _võid,
   {{0x291e87c5,0x644d87c6,0x660787c7,0x88bd02c6}},	//   kuta_, ldai, najk, stěh,
   {{0xd658028c,0x291e87c8,0xa3d9274c,0xdea40018}},	//   תיות_, juta_, ाशक_, دیلی,
   {{0x291e87c9,0x2d870034,0x660705db,0x00000000}},	//   duta_, rzne_, hajk, --,
   {{0x7ae20081,0x5ba90243,0x660787ca,0x60c987cb}},	//   _cuot, ьким_, kajk, _ihem,
   {{0x291e87cc,0x644d0013,0xc33200a1,0x7ae20138}},	//   futa_, hdai, סוי_, _duot,
   {{0x645d87cd,0x60c9061d,0x60db0051,0xa9a500d3}},	//   _onsi, _khem, _kium, тинд,
   {{0x66e61be2,0x26da3fe9,0x69c339a2,0x44fe02c6}},	//   кома, _sipo_, _vzne, vů_,
   {{0x26da87ce,0x6ec508fa,0x80cb0081,0x644d00f0}},	//   _pipo_, ितपु, িদপ্, ddai,
   {{0x291e1114,0x09e20cba,0x70ad0f35,0x44fe00b6}},	//   buta_, _кошн, टकुल, tů_,
   {{0xceb20c6a,0x291e002d,0x26da0a4b,0x60c9022b}},	//   ייך_, cuta_, _vipo_, _ohem,
   {{0x44fe030b,0x644d3642,0x224a00dc,0x6b960138}},	//   rů_, gdai, _sabk_, _žygi,
   {{0x44fe030b,0x6b8987cf,0x91e63283,0xe1f287d0}},	// [8dc0] sů_, nzeg, возе, لسا_,
   {{0x645d4710,0x644d1519,0x44fe00b6,0x60db190c}},	//   _ensi, adai, pů_, _aium,
   {{0x44e700de,0x68e30131,0x9c7c0a39,0xb7d50af0}},	//   _gõ_, _jund, _luča, _iṣaa,
   {{0x60db87d1,0xc2f60033,0x764e87d2,0x00000000}},	//   _cium, _চিঠি_, ldby, --,
   {{0x68e387d3,0x1616244d,0x60db0bb3,0x200600e3}},	//   _lund, _तयार_, _dium, raoi_,
   {{0x7ae20423,0x291e87d4,0x60c987d5,0x527687d6}},	//   _ruot, yuta_, _ehem, _руму,
   {{0x60db008f,0x29110146,0x6026008f,0x7ae287d7}},	//   _fium, ázal_, _идва, _suot,
   {{0x291e76f2,0x7d1c87d8,0x7ce70233,0x69b5007f}},	//   vuta_, _årsm, _tırn, _उड़ी,
   {{0x7ae287d9,0x3947007e,0x68e387da,0xcb070037}},	//   _quot, _asns_, _aund, نيين_,
   {{0x7ae221a1,0x291e03f3,0x3a276776,0x68e387db}},	//   _vuot, tuta_, _ccnp_, _bund,
   {{0x200401e5,0x68e387dc,0x38b90018,0x621b00c1}},	//   _kemi_, _cund, kért_, וויק,
   {{0x7ae20d64,0x291e87dd,0x200400dd,0x44e70028}},	//   _tuot, ruta_, _jemi_, _rõ_,
   {{0x6b890067,0xda341119,0x291e87de,0x2b4600b3}},	//   czeg, _белы, suta_, _usoc_,
   {{0x27e003f3,0x291e00ac,0xd9540241,0x68e30bb0}},	//   _egin_, puta_, _منتخ, _fund,
   {{0x660700cc,0x3ce800a3,0x00000000,0x00000000}},	//   rajk, _चूमे_, --, --,
   {{0x20041114,0x44e70019,0xed1000fe,0x61ee3412}},	//   _nemi_, _võ_, _đổi_, _afbl,
   {{0x644d4aac,0xe37400c6,0x68e387df,0x60c903a8}},	// [8dd0] rdai, алты, _zund, _rhem,
   {{0x60c987e0,0xf8bf87e1,0x644d01b5,0x60db0ac1}},	//   _shem, llé_, sdai, _sium,
   {{0x60db87e2,0x60c9023e,0x6b8960a4,0xbff00129}},	//   _pium, _phem, zzeg, _ịhọr,
   {{0x332005fe,0x645d87e3,0x7d1c00c2,0x6605007b}},	//   buix_, _unsi, _ärsy, _hehk,
   {{0x200487e4,0x60db0051,0xe8e000de,0x7d1c1f60}},	//   _demi_, _vium, _ướt_, _årsj,
   {{0x9c7c005f,0x20040139,0xf8bf2b41,0x7ce7020e}},	//   _ruča, _eemi_, hlé_, _fırl,
   {{0x60c987e5,0x66050087,0xf8bf0a7f,0x62950216}},	//   _them, _mehk, klé_, _imzo,
   {{0x68e301ce,0x660500b6,0xe81f02d5,0x6b8918c9}},	//   _rund, _lehk, _भागा_, tzeg,
   {{0xf8bf0094,0x6d483177,0x00000000,0x00000000}},	//   dlé_, _esda, --, --,
   {{0x68e387e6,0x200487e7,0x6b890034,0x7f49063d}},	//   _pund, _zemi_, rzeg, _iseq,
   {{0x6b8987e8,0x200487e9,0x7ce701e8,0x69250077}},	//   szeg, _yemi_, _kırm, ымна,
   {{0x9b450241,0x68e307d7,0x672d00bd,0xf8bf020d}},	//   _منصو, _vund, _bqaj, glé_,
   {{0x9cd600a1,0x68e387ea,0x9c7c00c4,0xc7960ab3}},	//   _עונה_, _wund, _kučn, урны,
   {{0x68e387eb,0x6d5c0037,0x66e3037e,0x2cbf09a1}},	//   _tund, _árac, сора, llud_,
   {{0x9c7c0995,0xf8bf87ec,0xc224001c,0x68e387ed}},	//   _mučn, blé_, یکسو, _uund,
   {{0x21210167,0x672d02a1,0xf8bf020d,0xb4be00b6}},	//   duhh_, _fqaj, clé_, इते_,
   {{0x741300bf,0x20042f54,0x7ce70233,0x00000000}},	// [8de0] صولا, _remi_, _sırl, --,
   {{0xe3b72cd8,0x38b90103,0xe29700ae,0x20040e13}},	//   убу_, sért_, гау_, _semi_,
   {{0x7a7a00c1,0xed4533e7,0x7f4987ee,0xda7a006e}},	//   ערעס, _بھ_, _aseq, ענער,
   {{0xdee60058,0x50ba001c,0x44240ac9,0xc48302f3}},	//   годи, رداد_, _øm_, _глюк,
   {{0x9c7c0128,0x4376002d,0x3ae900fe,0x00000000}},	//   _bučn, _сунт, _núp_, --,
   {{0x91e3387c,0x7d1c75bb,0x69dc00e8,0x527535c1}},	//   _горе, _årsk, žrei, _кусу,
   {{0x20f300e7,0x7f4987ef,0x11d5036c,0xf8bf87f0}},	//   _aćif_, _eseq, _вітр, ylé_,
   {{0x3ae90023,0x115b006e,0x5b14261f,0xdb6a085f}},	//   _búp_, _אדלע, амит, ерол_,
   {{0x3ae90023,0x543b006e,0x6d48014b,0xc61c0033}},	//   _cúp_, געפא, _wsda, দ্যা_,
   {{0x672d0090,0xfce63961,0x00000000,0x00000000}},	//   _rqaj, _божо, --, --,
   {{0x09d70081,0x3ce501df,0x02b7006e,0x8c2601c3}},	//   _দ্বা, _gulv_, רליך_, _مفاه,
   {{0x81d60081,0x2cbf00ae,0xf8bf014b,0x290c80e0}},	//   _সভা_, clud_, ulé_, rsda_,
   {{0xf8bf00fd,0x00000000,0x00000000,0x00000000}},	//   rlé_, --, --, --,
   {{0xf8bf0146,0xe45f0212,0xa3d8055c,0x00000000}},	//   slé_, _snö_, ाधन_, --,
   {{0xf8bf6423,0x45d53164,0x998c09ac,0x6e35047e}},	//   plé_, ровс, ledž_, _özbe,
   {{0x660501c0,0x7793001c,0xd49800d3,0x38600565}},	//   _wehk, _هیجا, гру_, _gnir_,
   {{0x660587f1,0xd5b100c3,0x00000000,0x00000000}},	// [8df0] _tehk, _आँकड़, --, --,
   {{0x63bd16ac,0xa1590d72,0x00000000,0x00000000}},	//   _vysn, казу_, --, --,
   {{0x9c7c2d32,0x21210167,0x63bd87f2,0x00000000}},	//   _ručn, uuhh_, _wysn, --,
   {{0xb4fa0130,0x7ce700a7,0x403556f6,0x63bd004d}},	//   _שפרי, _qırm, редс, _tysn,
   {{0xde053b2f,0x24891909,0x9c7c0141,0x644f078e}},	//   апли, mham_, _pučn, _iaci,
   {{0x644f87f3,0x24893f35,0xd33622fe,0xf8d10285}},	//   _haci, lham_, _דרשה_, सगुप,
   {{0x442b75ee,0x365c00ca,0x3ae987f4,0x9c7c037d}},	//   _kcc_, תכונ, _súp_, _vučn,
   {{0x644f87f5,0xaf340de1,0x248987f6,0x44390231}},	//   _jaci, _گرفت, nham_, _jbs_,
   {{0x9c7c87f7,0xfd4c0019,0x6a85370d,0x7ce70233}},	//   _tučn, _khiể, илиа, _kırk,
   {{0x644f87f8,0x7f840037,0x442b0358,0xdd95065c}},	//   _laci, _الكن, _lcc_, _казы,
   {{0xf8666eb1,0x443987f9,0x442b00ee,0x3da70f50}},	//   авно, _obs_, _occ_, _сраб,
   {{0x442b87fa,0x443987fb,0x2bd202d5,0x9c820094}},	//   _ncc_, _nbs_, देहा, účto,
   {{0x24891423,0x66e65a5c,0x661a87fc,0x00000000}},	//   dham_, рога, ótko, --,
   {{0x443955b7,0x96200034,0x7cca01c2,0x442b32e8}},	//   _abs_, बलेट_, _iƙra, _acc_,
   {{0x442b87fd,0xf4961c9b,0xa5070c59,0x00000000}},	//   _bcc_, араю, иера_, --,
   {{0x3d081085,0x443987fe,0x644f2cf8,0x248924da}},	//   _सबसे_, _cbs_, _caci, gham_,
   {{0x443901e9,0x644f87ff,0x020603fc,0xa20602c1}},	// [8e00] _dbs_, _daci, изан, ипад,
   {{0x442b013d,0xe1f7136c,0x5eaa0033,0xfd4c00fe}},	//   _ecc_, игу_, _চীনে, _chiể,
   {{0x644f120f,0xb1460cc0,0x600a0120,0x00000000}},	//   _faci, рнел, внем_, --,
   {{0x644f3ccf,0x24898800,0x92e40033,0x78a62452}},	//   _gaci, cham_, _নবী_, nnkv,
   {{0x24800270,0xfe46007e,0x64440350,0x00000000}},	//   mkim_, индо, meii, --,
   {{0x644f8801,0x8c4600a7,0x63a900c6,0x6444004d}},	//   _zaci, mişə, _ženg, leii,
   {{0x644f5af3,0xe2970095,0x44390085,0x3f808802}},	//   _yaci, _тар_, _ybs_, šiu_,
   {{0xc0e3103d,0x644f0042,0x67171981,0x00000000}},	//   _фотк, _xaci, _तिलक_, --,
   {{0x8aa647cd,0x60c2019f,0x00000000,0x00000000}},	//   ирод, mlom, --, --,
   {{0xc33309c1,0x60c28803,0x4f9500ae,0x25ad2cda}},	//   קות_, llom, _урсу, şeli_,
   {{0xa3d8007d,0x2d960a8e,0xfc66008f,0x798d0d2a}},	//   ाधड_, _трас, _вълн, _ƙawa,
   {{0x5faa0096,0x00000000,0x00000000,0x00000000}},	//   _कशाल, --, --, --,
   {{0xc7c70e2d,0x2bd222a3,0x24806bea,0xfbd20966}},	//   рсни, देशा, dkim_, देशम,
   {{0x644f8804,0x6d5a1548,0x60c2019f,0x44398805}},	//   _saci, _krta, hlom, _sbs_,
   {{0x2419055b,0x60c28806,0x9c7c0141,0x27f2030a}},	//   ловы_, klom, _lučm, _ffyn_,
   {{0x6d5a005f,0x59f5001c,0x22840212,0x260500a4}},	//   _mrta, _پکیج_, _röka_, वरही_,
   {{0x644f8807,0x22840149,0x60c28808,0xc61c0033}},	// [8e10] _vaci, _söka_, dlom, দ্ধা_,
   {{0x6d5a0702,0x442b083e,0x644f8809,0x2ca900cc}},	//   _orta, _wcc_, _waci, čadi_,
   {{0x644f880a,0x26c30117,0x24890023,0x60c20022}},	//   _taci, mljo_, pham_, flom,
   {{0x60c2880b,0x442b033c,0x2480880c,0x291e008c}},	//   glom, _ucc_, ckim_, irta_,
   {{0x4429880d,0x6d5a0902,0xfd4c00de,0x543a006e}},	//   mga_, _arta, _thiể, _גערא,
   {{0x528500e3,0x6d5a005c,0x291e0167,0x7c3900f0}},	//   _السك, _brta, krta_, _sbwr,
   {{0x6d5a005f,0x4429880e,0x60c2880f,0x6287028d}},	//   _crta, oga_, blom, _iljo,
   {{0x44297e7f,0x291e05db,0x00000000,0x00000000}},	//   nga_, drta_, --, --,
   {{0x291e0890,0x6d5a8810,0x6d5c8811,0x00000000}},	//   erta_, _erta, _áran, --,
   {{0x6d5a00e7,0x2480278c,0x8e740037,0xf2d20142}},	//   _frta, zkim_, _والض, ּעט_,
   {{0xd945364a,0xb4e602b0,0x442980de,0x29110094}},	//   щени, _पढे_, kga_, éza_,
   {{0x9c7c0117,0x8c46013c,0x44298812,0x00000000}},	//   _lučj, yişə, jga_, --,
   {{0x291e8813,0x44298764,0x6d5a0b18,0xf092021e}},	//   arta_, dga_, _zrta, לנט_,
   {{0x442974c0,0x00000000,0x00000000,0x00000000}},	//   ega_, --, --, --,
   {{0xe8f5300d,0x291e0335,0x64440302,0x7afb8814}},	//   _استخ, crta_, teii, lput,
   {{0x44298815,0xdb230088,0x62870141,0x20d702a1}},	//   gga_, _þróu, _aljo, _għix_,
   {{0xf8b31b83,0x7afb8816,0x24808817,0x7c2928c7}},	// [8e20] _משה_, nput, rkim_, iger,
   {{0x6fce009f,0x3d0800aa,0x7c290d87,0x00000000}},	//   _तरबू, _सबले_, hger, --,
   {{0x7c298818,0xc69300a1,0x7afb09a4,0xd5b801d3}},	//   kger, _מאז_, hput, ļās_,
   {{0x660e0188,0x7c2901c0,0x53a64214,0x00000000}},	//   labk, jger, _гамб, --,
   {{0x60c2100b,0x8c460092,0x7afb8819,0x7f5b0381}},	//   rlom, qişə, jput, _cruq,
   {{0x44ee00ef,0xacf80f5e,0x7c295f26,0x6d5a0167}},	//   _ký_, анку_, eger, _prta,
   {{0x7c292cee,0x4c9400e5,0xb7fa0285,0x00000000}},	//   fger, жийс, ूराम_, --,
   {{0x7c29881a,0x629e881b,0x6d5a881c,0x660e008c}},	//   gger, lipo, _vrta, habk,
   {{0x44ee00ef,0xeaf700bf,0x320a0181,0x7afb0d1f}},	//   _lý_, یریت_, _keby_, gput,
   {{0xaa662863,0x337700a1,0x3914881d,0xda4a0a95}},	//   стик, צעים_, омор, учил_,
   {{0x4429881e,0x6d5a0a00,0x44ee0088,0x291e0188}},	//   yga_, _urta, _ný_, urta_,
   {{0x4429002b,0x9c7c0234,0xc17300ca,0x291e1175}},	//   xga_, _mučk, לחת_, rrta_,
   {{0x629e881f,0x9c7c011d,0xeb330260,0x44298820}},	//   kipo, _lučk, _فروخ, vga_,
   {{0x44290694,0x291e033b,0x8bd70327,0x66c08821}},	//   wga_, prta_, _הודו_, köku,
   {{0x787f00dd,0x629e8822,0x7a53048f,0xa2b90b76}},	//   _lëvi, dipo, _رضوا, ्तस्,
   {{0x44298823,0xcd0200a5,0x18a41fdb,0x628714f3}},	//   uga_, mość_, _најм, _sljo,
   {{0x44290655,0x660e236d,0x320a4c93,0x41e70308}},	// [8e30] rga_, babk, _beby_, مساف,
   {{0x660e0694,0x5b7b00c1,0x9c7c1e4d,0x629e8824}},	//   cabk, ארמא, _bučk, gipo,
   {{0xcd0200a5,0x320a0a40,0x7c290f6f,0x9c7c0995}},	//   ność_, _deby_, yger, _vučj,
   {{0xf8c9099d,0xdbd90131,0x657a0c19,0x68f805db}},	//   रतिय, nção, äthe, _mtvd,
   {{0x320a0167,0x3f696804,0x629e00bc,0x7bc2022b}},	//   _feby_, рило_, bipo, _nyou,
   {{0xcd0200a5,0xee3800d6,0x9c7c00c4,0x290200c4}},	//   kość_, йні_, _fučk, ćkaj_,
   {{0x7bc2706e,0x648300bc,0x00000000,0x00000000}},	//   _ayou, _lõim, --, --,
   {{0xa2b90efb,0x7c290428,0x7f5b8825,0x6aa81afd}},	//   ्तव्, uger, _truq, endf,
   {{0x200f8826,0x15fb2f4f,0x68ea042c,0x395c024a}},	//   magi_, ्रार_, _aufd, _arvs_,
   {{0x200f8827,0x7afb8828,0x7c291468,0x78ad0673}},	//   lagi_, rput, sger, _ajav,
   {{0x684685fc,0xddab00c2,0x9f46003e,0xcd020034}},	//   онна, _стал_, lboð_, gość_,
   {{0x660e063f,0x6d418829,0x200f007a,0x7afb00c2}},	//   wabk, _ipla, nagi_, pput,
   {{0x61c61efb,0xc1c61efb,0x3b09105e,0x78ad0b18}},	//   _वर्ष, _वर्ग, _тело_, _djav,
   {{0x200f13b5,0x96ba0581,0x78ad039f,0x66c0007b}},	//   hagi_, руму_, _ejav, yöku,
   {{0xa50a1121,0x649a882a,0x7ae3882b,0x200f882c}},	//   реба_, атар_, _iint, kagi_,
   {{0x9c7c0995,0x7ae321c4,0x660e882d,0x07a600d6}},	//   _ručk, _hint, sabk, _майн,
   {{0x200f0006,0x7ae326d9,0x8c3d01d4,0x69c3882e}},	// [8e40] dagi_, _kint, mişd, _hyne,
   {{0x7ae3882f,0x6d418830,0x9c7c8831,0x66c08832}},	//   _jint, _opla, _pučk, töku,
   {{0x629e8833,0x6d41006c,0x4fea079c,0xb5ca00cd}},	//   ripo, _npla, амен_, _خودم_,
   {{0x7ae32f9c,0x629e8834,0x69c302ad,0x320a025b}},	//   _lint, sipo, _myne, _weby_,
   {{0xa2cb05a5,0x7ae38835,0x69c3526d,0x228400a7}},	//   _तीव्, _oint, _lyne, _hökm_,
   {{0x7ae38836,0xddc102dd,0x68e48837,0x629e023b}},	//   _nint, _dolž, _liid, qipo,
   {{0xa2b900c0,0x200f8838,0x629c8839,0xc04602a3}},	//   ्तर्, bagi_, _imro, _وخرو,
   {{0x6d5c2e72,0x68e42a3c,0x7aeb883a,0x7ae3883b}},	//   _áram, _niid, _bugt, _aint,
   {{0x0a6a11d9,0xcd0200a5,0xc4d300a1,0x3ea61612}},	//   арни_, wość_, וגה_, _диаг,
   {{0x7ae306e1,0x539b09c1,0x34a70775,0xd90e0688}},	//   _cint, ייפו, _गद्द, نیت_,
   {{0x7ae3883c,0x68e4883d,0x9c7c037d,0x69c30178}},	//   _dint, _biid, _luči, _cyne,
   {{0x68e4025e,0x8c46051b,0x7ae3883e,0x57f4013d}},	//   _ciid, _феде, _eint, мпют,
   {{0x68e4883f,0x629c8840,0x98741af8,0x76470027}},	//   _diid, _omro, фляц, tejy,
   {{0x648305a7,0x7ae38841,0x7d1c22bd,0x69c300f0}},	//   _võim, _gint, _årss, _fyne,
   {{0xd49b8842,0x29110fc5,0x68e40188,0x200f01f9}},	//   ара_, ázat_, _fiid, yagi_,
   {{0xd7fb0465,0x7ae38843,0x7aeb2839,0x9c7c1056}},	//   _тук_, _zint, _yugt, _buči,
   {{0x533400e5,0x27e900f9,0x7ae38844,0x200f0f81}},	// [8e50] метт, _igan_, _yint, vagi_,
   {{0xe7f9007d,0x64830006,0xa3e70fef,0x78bd5d4d}},	//   ंडवा_, _kõik, _पलक_, losv,
   {{0x75830260,0x200f8845,0x8c3d0233,0x00e500d1}},	//   _غیرم, tagi_, lişe, ستای,
   {{0x92ab00c7,0x27e9005c,0xa2cb022d,0x66c00212}},	//   খতে_, _jgan_, _तीर्, sökt,
   {{0x200f6a75,0x6483007a,0x161f0fef,0x6d418846}},	//   ragi_, _lõik, _बयार_, _spla,
   {{0xe7e3143d,0x200f8847,0xfce50ebf,0x7aeb8848}},	//   _गणना_, sagi_, поко, _rugt,
   {{0x7ae38849,0x200f083e,0x8c3d2326,0x6285019f}},	//   _rint, pagi_, yişd, mkho,
   {{0x27e9884a,0x69c30034,0x8c3d026a,0x6d41033b}},	//   _ngan_, _ryne, kişe, _vpla,
   {{0x69c305a3,0x68e413e1,0xdd910018,0x2d8a042c}},	//   _syne, _riid, بوں_, _üben_,
   {{0x27e902e8,0x68e4884b,0x8c3d0233,0xee780076}},	//   _agan_, _siid, dişe, _وصلت_,
   {{0x8c3d013c,0x628501ee,0x645600ce,0x00000000}},	//   tişd, ikho, ydyi, --,
   {{0x7aeb884c,0x69c30146,0x7ae34779,0x26c1019f}},	//   _tugt, _vyne, _wint, _akho_,
   {{0x68e41d2d,0x27e9005c,0x7c3b3652,0x69c30150}},	//   _viid, _dgan_, mfur, _wyne,
   {{0x27e9884d,0x7c3b884e,0xaa4100c2,0x33290167}},	//   _egan_, lfur, ärää_, duax_,
   {{0xf484015a,0x68e4884f,0x6f09063d,0x7c3b0350}},	//   واری, _tiid, _lwec, ofur,
   {{0x7c3b8850,0x7ce7026a,0x66c0007b,0x9c7c8851}},	//   nfur, _hırs, töks, _puči,
   {{0x6f090174,0x64560124,0x03260138,0x00000000}},	// [8e60] _nwec, rdyi, ядан, --,
   {{0x9c7c0291,0x7ce7020e,0x27e90381,0x00000000}},	//   _vuči, _yırt, _zgan_, --,
   {{0x867b00a1,0xf67b00a1,0x66c00149,0x200d0139}},	//   _הריו, _האימ, söks, _beei_,
   {{0x6aa101bf,0xd12f1f11,0x9c7c00e7,0x00000000}},	//   hilf, طمه_, _tuči, --,
   {{0xd00f300d,0x6f09039f,0xdce300c6,0x2ee500eb}},	//   اله_, _cwec, lynė, _bilf_,
   {{0x6285070a,0x629c4c9b,0x216a0a99,0x7c3b0167}},	//   ckho, _umro, _лиги_, efur,
   {{0x7c3b8852,0x614308a1,0x6aa10332,0x409618e4}},	//   ffur, _пера, dilf, _ерат,
   {{0xd00f0308,0x61fb0a39,0x399c0031,0xdbf100d2}},	//   _ملف_, _đuli, násť_, břík,
   {{0x3d0809d0,0x769000c2,0x6aa10653,0x7ce70233}},	//   _सबके_, _käyd, filf, _sırt,
   {{0x02be11c7,0x00000000,0x00000000,0x00000000}},	//   ्तिभ, --, --, --,
   {{0xe8e00019,0x6f0901bf,0xd05c0092,0x8c464444}},	//   _ngồi_, _zwec, _surə, _неже,
   {{0xab2a29c2,0xd90e00cd,0x6483007a,0x7c3b0124}},	//   _года_, پیک_, _võik, cfur,
   {{0x2bdb000f,0x7ce701e8,0x4df00557,0x63830088}},	//   मेदा, _fırs, _चलाई_, _mínú,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x94120092,0x7e6800dc,0x7e7a169c,0x78bd01f9}},	//   liyə_, _mndp, _motp, posv,
   {{0x27e9010a,0x52c50b76,0x00000000,0x00000000}},	//   _ugan_, वत्स, --, --,
   {{0x38690037,0xe6671bd1,0x248b00fe,0x9412013c}},	// [8e70] _inar_, _етно, _vlcm_, niyə_,
   {{0x09e000c7,0xedf80976,0x61220174,0xf8bf13c6}},	//   _ম্যা, ुरोध_, _ọlae, loé_,
   {{0x34950265,0xc5fb1362,0x62851cab,0x6f0900f3}},	//   _жанр, ्रीय_, rkho, _swec,
   {{0x9c7c0b14,0xdbf100b6,0x7e680565,0x00000000}},	//   _kuču, třík, _andp, --,
   {{0x3dc502ad,0xef180120,0x00000000,0x00000000}},	//   _sylw_, змі_, --, --,
   {{0x941200a7,0x6e948853,0x00000000,0x00000000}},	//   diyə_, ничу, --, --,
   {{0x38690062,0x2d8a042c,0x6aa101ce,0x00000000}},	//   _onar_, _übel_, vilf, --,
   {{0xdbf1030b,0x7e680375,0x32130158,0x00000000}},	//   přík, _endp, laxy_, --,
   {{0x6aa139ee,0x7c3b8854,0xd6b800d3,0x7e7a059a}},	//   tilf, rfur, yдри, _fotp,
   {{0x38698855,0x66021386,0x3ce800c3,0x3e180012}},	//   _anar_, _đoko, _चूके_, _ноуэ_,
   {{0x6fd9009d,0x3869005c,0x998e0154,0x7d1c3813}},	//   बेरं, _bnar_, _jefň_, _årsp,
   {{0xc68907a6,0x768b01e8,0xe73a0ae3,0x3ce60036}},	//   _דא_, _rüya, оем_, _giov_,
   {{0x2cad8856,0x38b90094,0xf3ff0131,0x38690141}},	//   mned_, néry_, _anão_, _dnar_,
   {{0x2cbf8857,0xdce30138,0xcb1200ca,0x27364d1e}},	//   loud_, tynė, _ילד_, ræn_,
   {{0x66e38858,0x59d10179,0x2cad00ca,0xf8bf0113}},	//   тора, _हरिर, oned_, boé_,
   {{0x2cad8859,0x2cbf000b,0x272a534b,0xf8d200bc}},	//   nned_, noud_, _джип_, _सठिय,
   {{0xaca30174,0x2cad885a,0x03a30e2d,0x00000000}},	// [8e80] _nfọm, ined_, вито, --,
   {{0x2cbf04ee,0x00000000,0x00000000,0x00000000}},	//   houd_, --, --, --,
   {{0x63a90088,0x2cbf6808,0x00000000,0x00000000}},	//   _þenn, koud_, --, --,
   {{0x2a6901c2,0x6d5c071c,0x7df82172,0x00000000}},	//   _ɗaba_, _árai, ुर्ग_, --,
   {{0x7e7a02e6,0x76900084,0x7657008c,0x7e68885b}},	//   _potp, _täyd, _yaxy, _pndp,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x10a6136e,0x60440383,0x00000000,0x00000000}},	//   _живн, _pčmč, --, --,
   {{0x2cad885c,0x2258885d,0x628e0220,0x38b92591}},	//   gned_, _hark_, _hlbo, béry_,
   {{0x628e885e,0x7e7a15d3,0xb0372252,0x00000000}},	//   _klbo, _totp, _קאמפ_, --,
   {{0x6f020890,0x3869885f,0x49744444,0x941200a7}},	//   mpoc, _snar_, елос, riyə_,
   {{0x29187078,0x225800a1,0x2cbf0f5a,0x6f020072}},	//   éra_, _mark_, boud_, lpoc,
   {{0x3af28860,0x648300bc,0x3b860208,0x200601ff}},	//   _tâp_, _hõiv, _олег, nboi_,
   {{0x27ed13ad,0x00000000,0x00000000,0x00000000}},	//   ženo_, --, --, --,
   {{0x3b5300d6,0x9c7c0b18,0x7afd0031,0x95fb0be5}},	//   _шкір, _vuču, íste, ्रेट_,
   {{0x7aef0181,0x555800d3,0x38b90094,0xd90f002d}},	//   íctv, маря_, zéry_, _шь_,
   {{0x628e8861,0x7657008a,0x2bdb00c0,0x38690079}},	//   _albo, _waxy, मेवा, _unar_,
   {{0x628e0146,0x38b90094,0x22580bb0,0x00000000}},	// [8e90] _blbo, xéry_, _bark_, --,
   {{0x1b000033,0xdcee02c6,0x00000000,0x00000000}},	//   _এটাই_, íděn, --, --,
   {{0x22588862,0x6615649a,0x00000000,0x00000000}},	//   _dark_, mazk, --, --,
   {{0x8c3d01d4,0x7e7e4350,0x628e4287,0x2eb90374}},	//   kişa, öppn, _elbo, ेत्त,
   {{0x24898863,0x4df50ed4,0x644d80f4,0x00000000}},	//   mkam_, няйт, meai, --,
   {{0x8d553051,0xed598864,0x2cbf1013,0x24898865}},	//   етич, зок_, woud_, lkam_,
   {{0x20e8008b,0x3f890138,0x2b46078e,0x3ea90234}},	//   _işin_, šau_, _apoc_, đat_,
   {{0x44f58866,0x24898867,0xa2b9142e,0x10170018}},	//   _må_, nkam_, ्तक्, _زبرد,
   {{0x44f5038c,0x2cbf8868,0x2cad00a1,0x66158869}},	//   _lå_, roud_, rned_, kazk,
   {{0x2cbf886a,0x644d886b,0x17fa1178,0x00000000}},	//   soud_, heai, ूर्व_, --,
   {{0x44f50a8d,0xa9691d7b,0xaca300ac,0x2b4600b3}},	//   _nå_, чина_, _ajụj, _epoc_,
   {{0xf1b20341,0x2bb80bd9,0xddc800d2,0x00000000}},	//   רסט_, _उँचा, _nadř, --,
   {{0xeb8e078b,0x6615061d,0x644d886c,0x920f00a8}},	//   _си_, fazk, deai, िराज_,
   {{0x661502a7,0x200600d3,0x248901d3,0xba39006e}},	//   gazk, zboi_, ekam_, _זײַט,
   {{0x49bb0979,0x04463a7a,0x224e01d4,0x6f0200a5}},	//   _باشد_, невн, _ölkə_, zpoc,
   {{0x44f5886d,0x644d020d,0x201f0350,0x00000000}},	//   _då_, geai, _ndui_, --,
   {{0x2258886e,0x661501ff,0x00000000,0x00000000}},	// [8ea0] _park_, bazk, --, --,
   {{0x44f50501,0x78a6886f,0x201f0051,0x7764213e}},	//   _få_, likv, _adui_, _irix,
   {{0x44f50501,0xe5a603fc,0x764e8870,0x394700dc}},	//   _gå_, _чини, meby, _jpns_,
   {{0x78a66404,0x776401ff,0x764e09af,0x1af50033}},	//   nikv, _krix, leby, _ইবনে_,
   {{0xde580f1e,0x225800bc,0xb4be0efb,0x26050096}},	//   далі_, _tark_, ेती_, वरची_,
   {{0x628e0124,0x471b00c1,0x764e8871,0x443201f9}},	//   _ulbo, לונג, neby, lgy_,
   {{0x52be269c,0x6483007a,0x02be0714,0x9ce600d3}},	//   ्तीस, _võiv, ्तीन, нцил,
   {{0x77640933,0x44328872,0xc0e30fb0,0x8c3d0555}},	//   _orix, ngy_, _боск, tişa,
   {{0x61f30052,0x764e8873,0x00000000,0x00000000}},	//   _çelë, keby, --, --,
   {{0x2d9628b9,0x60c2007a,0xd8f8004d,0xadba0076}},	//   _прес, loom, мної_, _فهذا_,
   {{0xddc8050d,0x6f1b0039,0x394700a4,0x78a68874}},	//   _hodž, _zvuc, _cpns_, fikv,
   {{0x27ed0400,0xddc8015c,0x44f50073,0x60c2520d}},	//   øen_, _kodž, _rå_, noom,
   {{0x44f509ce,0x66150a00,0x77648875,0xe787004d}},	//   _så_, tazk, _crix, хуно,
   {{0x44f50501,0x36d53968,0x764e59c1,0xb4d90dc4}},	//   _på_, тогр, geby, ाष्_,
   {{0xd5b85bea,0x6615819c,0x77648876,0x04670818}},	//   ест_, razk, _erix, нтам,
   {{0x3913013d,0x3f860154,0x776403eb,0x44320d18}},	//   _смър, kyou_, _frix, ggy_,
   {{0x60c20694,0x439429db,0x77640072,0x644d0558}},	// [8eb0] doom, гатс, _grix, reai,
   {{0x6d480021,0x66d20088,0xd5fc0174,0x44f51842}},	//   _opda, lækn, riṛ, _tå_,
   {{0x673d0e37,0x7aea003d,0x26c3013f,0x644d8877}},	//   ltsj, _mift, mojo_, peai,
   {{0x251a0796,0x26c38878,0x2ff800d3,0x60c20172}},	//   _קורא, lojo_, енць_, goom,
   {{0x23d50eeb,0x6d482c2e,0x673d1305,0x841600ca}},	//   _दरिद, _apda, ntsj, _בקרב_,
   {{0x7aea8879,0x6aba000f,0x26c30138,0xddda022b}},	//   _nift, ईकोर, nojo_, _katň,
   {{0xd65800a1,0x60c2887a,0x8cb50e2f,0xbd6b00ae}},	//   גיות_, boom, ксич, ярде_,
   {{0x2d51000d,0x0b451d6f,0x27ed033b,0x764e007f}},	//   _vše_, внин, ženj_, zeby,
   {{0x26c3887b,0x6f1b0580,0x9e1501b3,0x66d20537}},	//   kojo_, _uvuc, _адзі, dækn,
   {{0x39470167,0x26c30138,0xdb20119e,0x7aea887c}},	//   _ppns_, jojo_, átál, _cift,
   {{0xe9d92983,0x3ea70018,0x69ca02ad,0xf2d20266}},	//   ько_, mint_, _cyfe, שעי_,
   {{0x3ea74d8b,0x64830006,0x98a64487,0x8c3d00d3}},	//   lint_, _mõis, тиме, mişo,
   {{0x2d87887d,0x3b070af0,0x7aea00d7,0x768b0233}},	//   lyne_, _dípò_, _fift, _tüyl,
   {{0x3ea7887e,0x60c2887f,0x78a68880,0xb69b2972}},	//   nint_, zoom, sikv, spân,
   {{0x69ca02e0,0x764e3f70,0x765c8881,0x673d029a}},	//   _gyfe, reby, rdry, atsj,
   {{0x29058882,0x764e8883,0x765c8798,0xb4be0714}},	//   mpla_, seby, sdry, ेते_,
   {{0x753c0067,0x443200a1,0x78a41937,0x7f4d00a7}},	// [8ec0] strz, rgy_, _imiv, çaql,
   {{0x6483007a,0xddc8843d,0x60c2083e,0x26c3552d}},	//   _sõit, _rodž, woom, cojo_,
   {{0xfbc700bf,0x3ea78884,0xa2b30bf5,0x60c20f18}},	//   _چت_, dint_, _आदर्, toom,
   {{0xfbc75e51,0x2eca3fdd,0x47c80033,0xf8d200c3}},	//   _نت_, ित्त, রেণী, सतिय,
   {{0x64830006,0x3ea78885,0x81e30033,0x66d20537}},	//   _võit, fint_, ফুল_, næko,
   {{0x3ea78886,0x60c28887,0xb146107a,0xeaa70037}},	//   gint_, soom, _ингл, _ضع_,
   {{0x82a30077,0x205600ae,0xdfd20281,0x7aea25cc}},	//   _тарж, _итар, _چيز_, _rift,
   {{0x44222414,0x69ca00f0,0x705601c3,0xdfd2001c}},	//   _jdk_, _ryfe, _جنرا, _نيز_,
   {{0xee3a276c,0x442274b9,0x8c3d07aa,0x69ca057a}},	//   _она_, _mdk_, mişl, _syfe,
   {{0x63a9013f,0x3ea78888,0x44228889,0x7afd2e3f}},	//   _ženk, cint_, _ldk_, ísta,
   {{0x6d4808da,0x7aea2084,0x26c30138,0x2d98057e}},	//   _upda, _vift, vojo_, _åre_,
   {{0x387f38d5,0xa9c302ec,0x386d08a8,0x8c3d07aa}},	//   ður_, рськ, ñer_, nişl,
   {{0x26c3888a,0x7aea03e5,0x7c221a11,0x66d2052f}},	//   tojo_, _tift, _idor, rækn,
   {{0x6d5c0037,0x673d0c53,0x672f015c,0x78a40361}},	//   _áras, rtsj, rucj, _emiv,
   {{0x442202e7,0x673d0f3c,0x26c3888b,0x7c220117}},	//   _bdk_, stsj, rojo_, _kdor,
   {{0x656502ef,0x26c3888c,0x998e0154,0x3ea7888d}},	//   _vrhh, sojo_, _jefō_, zint_,
   {{0x26c352d7,0x7c222b78,0xd6db888e,0x25ba00fc}},	// [8ed0] pojo_, _mdor, _ото_, _expl_,
   {{0x68ed009c,0xaab40179,0x85753c75,0x00000000}},	//   _hiad, ुविक, _блох, --,
   {{0x68ed0018,0x3ea7888f,0x76900084,0xb60200b6}},	//   _kiad, vint_, _käyn, čáte,
   {{0x6483007a,0x66020b18,0x7c228890,0x22840212}},	//   _võis, _đoki, _ndor, _sökt_,
   {{0x3ea78891,0x96b800cd,0x68ed8892,0x10145f34}},	//   tint_, _سایز_, _miad, شبند,
   {{0x645d2c73,0x0ccb0c16,0x2bc6000f,0xaec40f1e}},	//   _hasi, ात्म, _लड़ा, абіл,
   {{0x3ea72b4f,0x41e43006,0x44390095,0x00000000}},	//   rint_, _віта, _kcs_, --,
   {{0x799a00a5,0x3ea70037,0x44390063,0x68ed8893}},	//   dztw, sint_, _jcs_, _niad,
   {{0x645d8894,0x4439701c,0xaca300ac,0x2d870313}},	//   _masi, _mcs_, _ndụm, syne_,
   {{0x44390172,0x7c220062,0x2fcd0113,0xaca30065}},	//   _lcs_, _edor, _iyeg_, _ikọj,
   {{0x68ed01b5,0x8c3d01e8,0x60db8895,0x00000000}},	//   _biad, lişm, _khum, --,
   {{0x645d8896,0x68ed01ec,0xe45f0212,0x443907ee}},	//   _nasi, _ciad, _skön_, _ncs_,
   {{0x7bcb0b88,0x68ed75a9,0x60db003d,0xaa458276}},	//   _uygu, _diad, _mhum, _белл,
   {{0xb4be8897,0x645d8898,0x29058899,0x2fcd0063}},	//   ेत्_, _aasi, ppla_, _myeg_,
   {{0x68ed461a,0x44220052,0x98a600ae,0x60c90172}},	//   _fiad, _pdk_, gulă_, _okem,
   {{0x68ed889a,0x64a32c96,0x78a40660,0xa3ea5598}},	//   _giad, баса, _umiv, едба_,
   {{0x6b89889b,0x645d889c,0x2fcd01fa,0x6b9b01bf}},	// [8ee0] nyeg, _dasi, _nyeg_, nzug,
   {{0x68ed889d,0x60c90b58,0x60db889e,0x645d00a1}},	//   _ziad, _akem, _ahum, _easi,
   {{0x645d889f,0x4422528b,0x60db88a0,0x98a6020a}},	//   _fasi, _tdk_, _bhum, culă_,
   {{0x60db88a1,0x645d88a2,0x44390076,0x3dcc00f0}},	//   _chum, _gasi, _gcs_, _rydw_,
   {{0x4375686c,0x60db00bf,0x8c3d0511,0x69ca114d}},	//   _курт, _dhum, rişl, _सुनी,
   {{0x645d88a3,0x64b7007e,0x60db039f,0xb5ab0103}},	//   _zasi, nćin, _ehum, _آئیے_,
   {{0x645d6610,0x765e0051,0x321a30e6,0x00000000}},	//   _yasi, _mapy, mapy_, --,
   {{0x765e0270,0x27f200f9,0x645d448b,0x60db0063}},	//   _lapy, _ngyn_, _xasi, _ghum,
   {{0x68ed0181,0x2aaa0058,0x79880150,0xa2ba1178}},	//   _riad, етно_, wydw, ्वप्,
   {{0x68ed57e2,0x7c2400e8,0x00000000,0x00000000}},	//   _siad, _ķiru, --, --,
   {{0x68ed328d,0xaa6300c6,0x98b40233,0x6b89010a}},	//   _piad, стык, çeği_, ayeg,
   {{0x6d5a88a4,0x60db88a5,0x81b90033,0xeb9a261f}},	//   _ista, _xhum, _চরম_, _пие_,
   {{0x2ca601c5,0x68ed88a6,0x443988a7,0x8627345a}},	//   _imod_, _viad, _rcs_, льве,
   {{0x68ed88a8,0x645d88a9,0x765e0113,0x66f400d3}},	//   _wiad, _sasi, _capy, спру,
   {{0x645d88aa,0x68ed29cb,0x644488ab,0x58d501a0}},	//   _pasi, _tiad, ffii, _кокт,
   {{0x69d888ac,0x245814fa,0x75280181,0x645d88ad}},	//   _izve, лась_, ádza, _qasi,
   {{0x645d88ae,0x291e88af,0x4439001f,0x60db374c}},	// [8ef0] _vasi, lsta_, _vcs_, _rhum,
   {{0x60db0910,0x645d88b0,0x60c988b1,0x291e2460}},	//   _shum, _wasi, _skem, osta_,
   {{0x645d2675,0x6d5a88b2,0x41553eac,0x60db88b3}},	//   _tasi, _nsta, рвес, _phum,
   {{0x291e0dfb,0x765e00a5,0x3cfb0034,0xd479006e}},	//   ista_, _zapy, _लंबे_, _סאָל,
   {{0x833507a6,0x6d5a88b4,0x441a00ca,0x399b0065}},	//   _דאָס_, _asta, _בורס, _kásé_,
   {{0x291e88b5,0x69d80f1c,0x2ca60178,0x00000000}},	//   ksta_, _ozve, _amod_, --,
   {{0x2ca602a1,0x60db88b6,0x69ce7f09,0x291e05db}},	//   _bmod_, _thum, übel, jsta_,
   {{0x9f0500cd,0x291e0212,0xac850036,0x4c8588b7}},	//   _نورو, dsta_, ргил, рлив,
   {{0x291e88b8,0x6d5a0a46,0xeb99044b,0x8c3d047e}},	//   esta_, _esta, тип_, lişk,
   {{0xea891440,0x7aa514e4,0x6b9b01bf,0x3945004d}},	//   тбол_, риоз, rzug, аног,
   {{0xe8070454,0xd9452c13,0x291e88b9,0xade10640}},	//   _व्हा_, шени, gsta_, गेशन_,
   {{0x290301d3,0x00000000,0x00000000,0x00000000}},	//   īja_, --, --, --,
   {{0x291e516a,0xb8fc88ba,0x765e06a3,0xa3e733c5}},	//   asta_, _ती_, _papy, येम_,
   {{0x6d5a0150,0x6444008c,0xb87b0143,0x00000000}},	//   _ysta, wfii, rmía, --,
   {{0x4416001f,0xe8070096,0xe6170e05,0xc8b6007b}},	//   ифат, _व्वा_, рдс_, _вспы,
   {{0x7786013d,0x765e0051,0x629501ff,0x99d401c3}},	//   _влиз, _wapy, _alzo, _اتها,
   {{0xd3871eac,0x64440be9,0x23e00378,0x765e88bb}},	// [8f00] айте_, rfii, पेंद, _tapy,
   {{0x644400ae,0x386000ca,0x769000c2,0x00000000}},	//   sfii, _hair_, _käym, --,
   {{0xf67b0130,0x867b00a1,0x661c88bc,0x321a88bd}},	//   _סאטמ, _סרטו, mark, rapy_,
   {{0x504664e9,0x65020134,0x386088be,0x44fc0065}},	//   редб, _ọkwụ, _jair_, _ií_,
   {{0xdfcf0080,0x44fc88bf,0x386005d3,0x00000000}},	//   ويم_, _hí_, _mair_, --,
   {{0x44fc02b4,0x661c88c0,0x291e88c1,0x386000cd}},	//   _kí_, nark, ysta_, _lair_,
   {{0x44fc88c2,0xb87b000d,0x00000000,0x00000000}},	//   _jí_, dmín, --, --,
   {{0x44fc88c3,0x661c02a7,0x32180167,0x38600e2b}},	//   _mí_, hark, _hery_, _nair_,
   {{0x44fc88c4,0xb7fd0378,0x32180063,0x6d5a0034}},	//   _lí_, _एलबम_, _kery_, _wsta,
   {{0x661c341b,0x7f3b0327,0xd05c01c2,0x44fc037a}},	//   jark, _בעמו, _turɓ, _oí_,
   {{0x44fc88c5,0x6d5a88c6,0x291e88c7,0x3f420023}},	//   _ní_, _usta, usta_, _hưu_,
   {{0x291e88c8,0x386088c9,0x661788ca,0x9c8300e7}},	//   rsta_, _cair_, _sexk, _ščvr,
   {{0x661c23e8,0x44fc88cb,0x3860852d,0x7f420036}},	//   fark, _aí_, _dair_, ntoq,
   {{0x44fc88cc,0x661c6c3a,0x3f4200de,0x27fe00b6}},	//   _bí_, gark, _mưu_, ětna_,
   {{0x3f420028,0x88d60081,0x45d53122,0x69d817b1}},	//   _lưu_, _সংরক, совс, _uzve,
   {{0x44fc88cd,0x316d88ce,0xd4983429,0x38600150}},	//   _dí_, _čez_, ару_, _gair_,
   {{0x24582c37,0x69ca0bd9,0x7cf50138,0x661c00db}},	// [8f10] шать_, _सुती, _išre, bark,
   {{0x661c88cf,0x44fc026e,0x8c3d0233,0x00000000}},	//   cark, _fí_, tişk, --,
   {{0x44fc0032,0xd5b82917,0x3860037a,0x7f5b0090}},	//   _gí_, _вся_, _yair_, _ssuq,
   {{0x765588d0,0x3f4200de,0x40356ff6,0x76990139}},	//   lezy, _bưu_, седс, _dìye,
   {{0x7535003d,0x32180483,0xb87b0076,0x3f4200fe}},	//   luzz, _fery_, hmío, _cưu_,
   {{0xee3800d6,0x765588d1,0x518742e0,0x3218057a}},	//   ині_, nezy, _куба, _gery_,
   {{0x31e500c7,0x01e500c7,0x8c3d03a3,0x753588d2}},	//   _প্রশ, _প্রদ, lişi, nuzz,
   {{0x69ca1e5e,0x45b800a1,0x661c88d3,0x40344fe3}},	//   _सुधी, יפול_, zark, _месс,
   {{0x661c88d4,0x201d1195,0x8c3d04a8,0x00000000}},	//   yark, mawi_, nişi, --,
   {{0x386088d5,0x753588d6,0x201d2230,0x66d2052f}},	//   _sair_, kuzz, lawi_, rækk,
   {{0xb87b025b,0xec1500cd,0x661c88d7,0x69ca3d34}},	//   rmín, _هواد, vark, _सुदी,
   {{0x44fc0649,0x201d0979,0x661c88d8,0x753503e5}},	//   _rí_, nawi_, wark, duzz,
   {{0x44fc88d9,0x2d8a02d6,0x6d4388da,0x7e6188db}},	//   _sí_, _über_, ltna, _kalp,
   {{0x201d88dc,0x2cad88dd,0x7e630167,0x753503e3}},	//   hawi_, lied_, ndnp, fuzz,
   {{0x7e6188de,0x661c0694,0x201d3dfc,0x753588df}},	//   _malp, rark, kawi_, guzz,
   {{0x661c88e0,0x3860003b,0x201d6e25,0x44fc88e1}},	//   sark, _uair_, jawi_, _ví_,
   {{0xd4670e38,0x201d00dc,0xb226333f,0x32181eb4}},	// [8f20] щите_, dawi_, ймал, _pery_,
   {{0x44fc3d04,0x7535003d,0x6d4388e2,0x2cad091f}},	//   _tí_, buzz, ktna, hied_,
   {{0x32180054,0x3f420019,0x753588e3,0x44fc0037}},	//   _very_, _sưu_, cuzz, _uí_,
   {{0x26ca0201,0x7f42028d,0x201d0112,0x00000000}},	//   lobo_, ttoq, gawi_, --,
   {{0x64560367,0x6d4300de,0x543b006e,0x6d41008c}},	//   meyi, etna, _געכא, _aqla,
   {{0x7e6188e4,0x2480005f,0x64565262,0x7f4288e5}},	//   _calp, ljim_, leyi, rtoq,
   {{0x201d027f,0x7f42003d,0x2cad88e6,0x00000000}},	//   bawi_, stoq, fied_, --,
   {{0x645688e7,0x67240141,0x2cad02ac,0x00000000}},	//   neyi, _ovij, gied_, --,
   {{0x6d690029,0x26ca3663,0x9e3a0037,0x81cd0033}},	//   _īpaš, kobo_, _مساء_, শেদ_,
   {{0x6fb30cd2,0x7af90381,0x0e6a0037,0x26ca03a9}},	//   _عملا, _duwt, _حصري_, jobo_,
   {{0x2cad0934,0x26ca88e8,0x67240b18,0x7d0a4c82}},	//   bied_, dobo_, _avij, _снег_,
   {{0x8c3d0092,0x63bb003e,0x248088e9,0x2cad3f24}},	//   yişi, _þung, jjim_, cied_,
   {{0x672402e6,0x6d5101ac,0x29074f43,0x27ed00c2}},	//   _cvij, čkaš, _etna_, äen_,
   {{0x67240292,0x753503e5,0x1994333f,0x96f80a7c}},	//   _dvij, tuzz, _маля, серт_,
   {{0x59cf022d,0x6aaa05db,0x65943b21,0x201d024a}},	//   _सुपर, _imff, пару, yawi_,
   {{0x75350f2f,0x8c3d0b88,0x24800052,0x00000000}},	//   ruzz, tişi, gjim_, --,
   {{0x26ca88ea,0x3eae0430,0x6e280b6a,0x2bce1073}},	// [8f30] bobo_, kift_, _oddb, _हुमा,
   {{0x63a91c54,0x201d88eb,0x8c3d0587,0x26ca88ec}},	//   _žens, wawi_, rişi, cobo_,
   {{0x67240ea3,0x201d88ed,0x645688ee,0x64ac020a}},	//   _zvij, tawi_, beyi, oşil,
   {{0x2ec105a5,0x6e282d0b,0x4fd5014d,0xd05c03e3}},	//   शक्त, _addb, ожет, _murɗ,
   {{0x643a00c1,0xddda007e,0x21210085,0x7ff40037}},	//   _דערנ, _rotš, sshh_, أسما,
   {{0x3eae0bab,0x6d4388ef,0x171c00c1,0x201d88f0}},	//   gift_, ttna, נווע, sawi_,
   {{0x7e6188f1,0x201d06a8,0xdc991543,0x5184002d}},	//   _valp, pawi_, итиш_, _еута,
   {{0xcc890d62,0x6d4388f2,0xcf2e0233,0x6aaa00eb}},	//   рбие_, rtna, üğüm_, _amff,
   {{0x628702e6,0x6d4388f3,0x7e6188f4,0x2cad88f5}},	//   _kojo, stna, _talp, ried_,
   {{0xa92525a4,0x6f09833f,0x24800d62,0x4ea70859}},	//   одол, _itec, zjim_, _урба,
   {{0x6724029b,0x3f8f02e0,0x2d670039,0x64564c58}},	//   _svij, lygu_, _uđe_, yeyi,
   {{0x62870032,0x26ca0079,0x00000000,0x00000000}},	//   _lojo, wobo_, --, --,
   {{0x776d028d,0x7c3b01c2,0x78bd0042,0x26ca600a}},	//   _crax, mgur, érva, tobo_,
   {{0xa9690245,0xd4910023,0x6287019f,0x236900c4}},	//   _вика_, ền_, _nojo, dvaj_,
   {{0x26ca88f6,0xa2ba034d,0x24990085,0x645688f7}},	//   robo_, ्वस्, _blsm_, teyi,
   {{0x7c3b88f8,0x26ca88f9,0xdbd40328,0x6f091206}},	//   ngur, sobo_, _zúñi, _otec,
   {{0x6724029b,0x628788fa,0x776d36a2,0x52aa03a1}},	// [8f40] _uvij, _bojo, _grax, авам_,
   {{0x628788fb,0x64567c77,0x24920206,0x00000000}},	//   _cojo, seyi, skym_, --,
   {{0x6f09028d,0x62876eb5,0xd67700d7,0x00000000}},	//   _atec, _dojo, _ותיק_, --,
   {{0xd46a0284,0x63bb05db,0x00000000,0x00000000}},	//   _тиме_, _žune, --, --,
   {{0x442088fc,0x161e0835,0x7c3b88fd,0x3eae0d87}},	//   mai_, _बजार_, dgur, tift_,
   {{0xe29a0b21,0x62870216,0x00000000,0x00000000}},	//   _таг_, _gojo, --, --,
   {{0x4127007e,0x3eae0d4b,0x4c943ac9,0xbea3001f}},	//   _моро_, rift_, зийс, ќајк,
   {{0x442088fe,0xfbf80033,0x7c3b88ff,0xc5f30327}},	//   nai_, ঘর্ষ_, ggur, ודו_,
   {{0x1fd10081,0x46da0096,0x3fb60103,0x4420078e}},	//   ়েবস, णताह, _بھاگ_, iai_,
   {{0x7c3b8900,0x20e80233,0xcfa90037,0x00000000}},	//   agur, _eşit_, _طاقم_, --,
   {{0x44208901,0x69ca143d,0xa3ac8902,0x2b44034f}},	//   kai_, _सुशी, _केस_, stmc_,
   {{0x44205093,0x776d6dc5,0x48ab0566,0x7d0d0218}},	//   jai_, _prax, ртом_, ćast,
   {{0x44203faf,0xe6670ebf,0x69ca6c66,0x7cf50138}},	//   dai_, отво, _सुरी, _išra,
   {{0x24550019,0x7c208903,0x2a050134,0x70b800b7}},	//   _ấm_, lamr, ịaru_, ेकुल,
   {{0x44208904,0x62870314,0x00000000,0x00000000}},	//   fai_, _rojo, --, --,
   {{0x442051c0,0x776d0933,0x62871114,0x7c208905}},	//   gai_, _trax, _sojo, namr,
   {{0x62871783,0x8c3d01e8,0x78ad8906,0xddc12207}},	// [8f50] _pojo, mişt, _imav, _palū,
   {{0x8c3d8907,0x7afd8908,0xd25b125f,0x320b0450}},	//   lişt, ísti, јца_, рхан_,
   {{0x44206ad7,0x6f098909,0x7c20890a,0xddc101d3}},	//   bai_, _stec, kamr, _valū,
   {{0x8c3d00d3,0x4420890b,0x00000000,0x00000000}},	//   nişt, cai_, --, --,
   {{0xb4d7009d,0x53443e1e,0x6287890c,0xa2ba24eb}},	//   िती_, _охра, _tojo, ्वश्,
   {{0x81cd00c7,0x66d2003e,0x00000000,0x00000000}},	//   শেষ_, bæku, --, --,
   {{0x78ad007a,0xa2ba0b42,0x7bc2002b,0x442b020b}},	//   _omav, ्वर्, _axou, _kdc_,
   {{0x442b00fc,0x00000000,0x00000000,0x00000000}},	//   _jdc_, --, --, --,
   {{0xbf150f43,0x7c3b890d,0x442b890e,0x998e0154}},	//   _رواب, rgur, _mdc_, _jefņ_,
   {{0x78ad4dae,0x7c3b890f,0x44208910,0x75280220}},	//   _amav, sgur, zai_, ádzk,
   {{0x81cd00c7,0x44208911,0x644f8912,0x186a1543}},	//   শের_, yai_, _obci, бани_,
   {{0xa3ac05a7,0x44208913,0x29e1016d,0x442b0381}},	//   _कइल_, xai_, _açaí_, _ndc_,
   {{0x442005d5,0xf7720037,0xd5b70023,0x2be209a1}},	//   vai_, راح_, ống_, _परया,
   {{0x44208914,0x59cf009f,0x200d00a7,0x78ad48d3}},	//   wai_, _सुथर, əmiş_, _emav,
   {{0x44204f7b,0x442b028d,0xd5b20037,0x049601b3}},	//   tai_, _bdc_, رفر_, праў,
   {{0x2be20f53,0x8c3d2ddc,0x442b0133,0x00000000}},	//   _परमा, mişs, _cdc_, --,
   {{0x44208915,0x59cf007d,0xf1fa0308,0x5ede0861}},	// [8f60] rai_, _सुतर, معات_, गतम्_,
   {{0x44208916,0x7c2000dc,0x2bce1d72,0x6726487c}},	//   sai_, zamr, _हँसा, mskj,
   {{0x442b0361,0x68e408d3,0xa3ac0e50,0x2be260a3}},	//   _fdc_, _khid, _केर_, _परभा,
   {{0xe0d22519,0xfbcb00d2,0x00000000,0x00000000}},	//   رزا_, ाथाम, --, --,
   {{0x672602ec,0x1b010033,0x68e4009c,0x29180103}},	//   nskj, লীতে_, _mhid, áraz_,
   {{0x42550b73,0x63a48917,0x5436001c,0xbea3468f}},	//   _отст, mzin, _برگر, начк,
   {{0x63a48918,0x68e401ff,0x629c0503,0x00000000}},	//   lzin, _ohid, _ilro, --,
   {{0xc5f300ca,0x225a0117,0x5ba607bf,0x63a48919}},	//   עדה_, lepk_, зроз, ozin,
   {{0x8fa322be,0xe457006e,0x7de20139,0x8c3d2af9}},	//   _зате, ליקט_, _bísí, vişt,
   {{0x63a4891a,0x3a74370d,0x8f9b0327,0x68e4024a}},	//   izin, флор, _הימי, _ahid,
   {{0xade8114d,0x68e401b5,0x8c3d250e,0x27e00022}},	//   टेशन_, _bhid, tişt, _azin_,
   {{0x290a0b4b,0x68e4891b,0x2006891c,0x63a478b9}},	//   ība_, _chid, ncoi_, kzin,
   {{0x68e4891d,0x442b891e,0x63a40126,0x8c3d358e}},	//   _dhid, _rdc_, jzin, rişt,
   {{0x63a4891f,0x442b02ef,0x7cc10029,0xf1be034d}},	//   dzin, _sdc_, mēra, ्थान,
   {{0xe5c422ee,0xd49b2223,0x78ad025b,0x27e002a7}},	//   есто, бра_, _tmav, _ezin_,
   {{0xb4d71349,0xe45f0102,0x68e48920,0x68f6026a}},	//   िते_, _mjög_, _ghid, _giyd,
   {{0xa3e702ed,0x63a401cb,0x00000000,0x00000000}},	// [8f70] यें_, gzin, --, --,
   {{0x81d60033,0x68e43fe9,0x00000000,0x00000000}},	//   াইন_, _zhid, --, --,
   {{0x442b052f,0x78bd8921,0x66d2003e,0x2bbe00fe}},	//   _tdc_, onsv, rækt, ịch_,
   {{0x442b8922,0x78bd8923,0x629c01f9,0x00000000}},	//   _udc_, nnsv, _elro, --,
   {{0x644d0063,0x5f94004d,0x00000000,0x00000000}},	//   mfai, ницт, --, --,
   {{0x644d8924,0x7d1a03a8,0x7a2901f9,0x00000000}},	//   lfai, _bwts, _kötő, --,
   {{0x236d1528,0x7d1a030a,0x00000000,0x00000000}},	//   _šejh_, _cwts, --, --,
   {{0x644d8925,0xfd5e0019,0x78bd3001,0x00000000}},	//   nfai, _huyề, jnsv, --,
   {{0x76900d64,0x00000000,0x00000000,0x00000000}},	//   _käyt, --, --, --,
   {{0x09052863,0x68e48926,0x6f1b0027,0x78bd41e9}},	//   мпон, _shid, _iwuc, ensv,
   {{0x63a4013d,0x6e238927,0x661e18ea,0xdd9b00d3}},	//   zzin, manb, _repk, _уша_,
   {{0x6f1b0134,0xb4d78928,0x63a43ff9,0x61ec00a7}},	//   _kwuc, ितो_, yzin, ünlə,
   {{0x644d00e3,0xa3ac0b3f,0x02bf1678,0xb4d700b7}},	//   dfai, _कें_, ्वाभ, ितै_,
   {{0x769002fd,0x7afd4098,0xddc30018,0x672600d6}},	//   _näyt, ístu, lenő, rskj,
   {{0x644d8929,0xa5074444,0x67263200,0x23620141}},	//   ffai, деса_, sskj, _sskj_,
   {{0x63a4892a,0x6e23892b,0x644d0076,0x68e44565}},	//   tzin, hanb, gfai, _uhid,
   {{0xc61d00c7,0x6e23892c,0x661e026a,0x7ce50131}},	// [8f80] _তারা_, kanb, _tepk, mórd,
   {{0x248b0063,0x236f003e,0x7764019f,0xe45f0212}},	//   _eocm_, ægja_, _isix, _sköt_,
   {{0x64a6147c,0x81d60081,0x644d66ab,0x63a4892d}},	//   _жана, াইভ_, bfai, szin,
   {{0x765c892e,0x753c892f,0x38ab0034,0x644d0037}},	//   lery, murz, _górę_, cfai,
   {{0x201f0167,0xa3c80aa1,0x2be200bc,0x213a6413}},	//   _deui_, _ऊँट_, _परधा, suph_,
   {{0xc3330341,0x765c8930,0xb3550421,0x81d60033}},	//   _בוש_, nery, _سیما_, াইব_,
   {{0x6f1b063d,0x00000000,0x00000000,0x00000000}},	//   _ewuc, --, --, --,
   {{0x7764002b,0x2be20caf,0x91e31ac8,0x6e230381}},	//   _osix, _परदा, _росе, aanb,
   {{0x9ce800fb,0x6e238931,0xd00f00b1,0x2bce00a4}},	//   _ہوئے_, banb, _خلق_, _हुशा,
   {{0x765c8932,0xee373c12,0x753c8296,0x25ef00a4}},	//   jery, _ону_, kurz, _आणली_,
   {{0xe87300cd,0x644d8933,0x765c8934,0x7e7a2008}},	//   نندگ, yfai, dery, _intp,
   {{0x6f000051,0x2baf00a4,0x00000000,0x00000000}},	//   _kumc, _जेवा, --, --,
   {{0xb90505a4,0xfbe20d61,0x765c8935,0x2a67037a}},	//   _बी_, _परिम, fery, _fanb_,
   {{0xb4d7074c,0x59cf0c3c,0x765c084e,0x7ce5002b}},	//   ित्_, _सुवर, gery, tórg,
   {{0x77648936,0x3ce6006c,0x7e6802b6,0xdef80078}},	//   _esix, _khov_, _madp, _miċ_,
   {{0x260f0789,0xfbe215e4,0x7ce513a9,0x290e0090}},	//   _त्री_, _पराम, córd, _itfa_,
   {{0xf8bf18ed,0x644d8937,0x69d80126,0x765c0283}},	// [8f90] mné_, rfai, _hyve, bery,
   {{0x386901aa,0xf8bf0343,0xfd5e0028,0x7e6830e6}},	//   _haar_, lné_, _quyề, _nadp,
   {{0x59d400aa,0x6e238938,0x673d004d,0xb035016a}},	//   _ठुमर, vanb, lusj, енеш,
   {{0xf8bf53b7,0x38692cbc,0x65650063,0xa3c81c65}},	//   nné_, _jaar_, _ishh, _ऊँच_,
   {{0x38698939,0x6e23893a,0x769002fd,0xe0d800d6}},	//   _maar_, tanb, _täyt, єві_,
   {{0x6d4a4192,0x9f9c003e,0x9e64084c,0x3869893b}},	//   ftfa, ræða_, квід, _laar_,
   {{0xf8bf53bc,0x6e23893c,0xdef800bd,0xa2cc00a8}},	//   kné_, ranb, _diċ_, तकर्,
   {{0x38694ff3,0x6ac70354,0xf8bf0618,0x6e23893d}},	//   _naar_, रक्र, jné_, sanb,
   {{0xf8bf0871,0xdef8003d,0x26d10415,0x00000000}},	//   dné_, _fiċ_, kozo_, --,
   {{0x961e030b,0x2eca18ff,0x7f49063d,0xb87b01cd}},	//   _बजेट_, ाकृत, _iqeq, nlíf,
   {{0xe9d9013d,0xae740068,0xf9910037,0xd49c0065}},	//   яко_, _جھنڈ, ابخ_, _bọ̀_,
   {{0x6e2102a7,0x3ce6023e,0xf8bf0257,0x7cc100d9}},	//   _helb, _ghov_, gné_, mēro,
   {{0x386901aa,0x7d015160,0x69ce01bf,0x6e211829}},	//   _daar_, _huls, über, _kelb,
   {{0x2cbf007a,0xcb360266,0x753c3751,0x7ce5037a}},	//   lnud_, _נאצי_, turz, sórd,
   {{0x69d808a1,0xf8bf1cf3,0x649a007e,0xba740018}},	//   _gyve, bné_, птар_, _جانت,
   {{0x38690694,0xf8bf025b,0x765c893e,0x753c042d}},	//   _gaar_, cné_, sery, rurz,
   {{0x765c744c,0x26d156b0,0x00000000,0x00000000}},	// [8fa0] pery, bozo_, --, --,
   {{0x2be217ff,0x0566039b,0xb87b6df6,0x386901ff}},	//   _परसा, _звон, glíf, _zaar_,
   {{0x6f00893f,0x7d0102b6,0x7f490372,0x00000000}},	//   _sumc, _nuls, _aqeq, --,
   {{0x76900084,0x38a20181,0x64a61ca7,0x00000000}},	//   _täys, _fóre_, _чама, --,
   {{0x2cbf007a,0x76450150,0x44223fe9,0x7bd90169}},	//   dnud_, _ychy, _iek_, _nywu,
   {{0x7d010694,0xf8bf0363,0x44228940,0x6d4a4abd}},	//   _buls, zné_, _hek_, ttfa,
   {{0xa0a600d6,0x6e210bc6,0x3ce6023e,0xc69303c2}},	//   _завд, _delb, _phov_, ראו_,
   {{0x3ce61071,0x6d4a0bab,0x44228941,0xf8bf0031}},	//   _qhov_, rtfa, _jek_, xné_,
   {{0xf8bf0c01,0x628e8942,0x7af8023e,0x386901c0}},	//   vné_, _kobo, _pivt, _raar_,
   {{0xc3338943,0x6e218944,0x628e8945,0x610c01e8}},	//   נות_, _gelb, _jobo, _eğle,
   {{0xf8bf0871,0x386910ec,0x7afd025b,0x3ce601bb}},	//   tné_, _paar_, ístr, _thov_,
   {{0x26f90e72,0x44228946,0xdd8f0159,0x38690694}},	//   ंद्र_, _nek_, _دوم_, _qaar_,
   {{0xf8bf8947,0x7af88948,0x3869057a,0x26d102a4}},	//   rné_, _tivt, _vaar_, tozo_,
   {{0x386901aa,0xf8bf0074,0x7c2200e3,0x69d801df}},	//   _waar_, sné_, _heor, _tyve,
   {{0xf8bf0074,0xf1d00b7f,0x41d01244,0x7c220167}},	//   pné_, _तुलन, _तुलस, _keor,
   {{0x44228949,0x7c220167,0x7cc800b6,0x3869894a}},	//   _cek_, _jeor, běre, _uaar_,
   {{0x628e894b,0x2a7c029a,0x53340dd8,0x7c2f124d}},	// [8fb0] _bobo, _knvb_, летт, ócri,
   {{0xd01903a2,0x4422894c,0x628e894d,0x7c2270c1}},	//   दर्भ_, _eek_, _cobo, _leor,
   {{0x628e894e,0x44220383,0xd13b00e5,0xc2c45bce}},	//   _dobo, _fek_, яха_, ديلي,
   {{0x6e2102dc,0x7cc100d9,0x4422894f,0xa3ac0b76}},	//   _selb, vēro, _gek_, _केक_,
   {{0x6e2129cb,0x4f080565,0x7d018950,0xb4bf1da8}},	//   _pelb, енін_, _suls, ेवी_,
   {{0x628e025e,0xed5922f9,0x44228951,0x24898952}},	//   _gobo, док_, _zek_, ljam_,
   {{0x2cbf007a,0xa1580457,0x6e218953,0xdca500c2}},	//   tnud_, _пару_, _velb, каки,
   {{0x248918b4,0x628e8954,0x6e2101d0,0x672d0a39}},	//   njam_, _zobo, _welb, _ovaj,
   {{0x6e218955,0x7c223bf8,0x2ef539f8,0xd04901c2}},	//   _telb, _deor, _азар, _sheɗ,
   {{0x3da726d0,0xb87b00b6,0x2be20966,0x7cc802c6}},	//   _преб, hlíd, _पररा, věre,
   {{0x98a61a67,0x7c2201b9,0x2b58044c,0x672d8956}},	//   вине, _feor, ărca_, _avaj,
   {{0x61fa3e43,0x7c228957,0xf3ff00de,0x248933ef}},	//   _útle, _geor, _ngã_, jjam_,
   {{0xeb8e0aec,0xc6260081,0x672d00e7,0xda650095}},	//   _ти_, _বাবা_, _cvaj, _авли,
   {{0x44228958,0xa7fb08a8,0x66e6141a,0x672d3692}},	//   _sek_, xeñe, тога, _dvaj,
   {{0xceb27c04,0x442201e8,0xa6db0088,0x7c220167}},	//   בים_, _pek_, fuðb, _yeor,
   {{0x7c220042,0x00000000,0x00000000,0x00000000}},	//   _xeor, --, --, --,
   {{0xb87b8959,0xe8d7895a,0x44224f1e,0x628e226a}},	// [8fc0] rmít, _בוקר_, _vek_, _pobo,
   {{0x4422895b,0x27fe02c6,0x2b4d895c,0x2489004b}},	//   _wek_, ětnu_, itec_, ajam_,
   {{0x4422895d,0x64b70234,0xa69b00ca,0x00000000}},	//   _tek_, rćir, _חשיפ, --,
   {{0xb87b0042,0xa7fb0143,0x442201ff,0x628e0383}},	//   lmír, señe, _uek_, _wobo,
   {{0xdfd200e3,0x00000000,0x00000000,0x00000000}},	//   جيش_, --, --, --,
   {{0x7c2210f3,0x6e940037,0x5f930e2c,0x6f0d3536}},	//   _seor, طلبا, ришт, íaca,
   {{0x7c2242f3,0x3f8000ae,0xe04600d3,0xc1e6030b}},	//   _peor, ţiu_, _инви, _करिब_,
   {{0x61e30b88,0x7ce50131,0x00000000,0x00000000}},	//   ünle, vórc, --, --,
   {{0x69ca0ccb,0x3dd20034,0x2d81042c,0x00000000}},	//   _सुजी, ływ_, äher_, --,
   {{0xbbe20557,0x60c2895e,0x5be242c3,0x6ee4022b}},	//   _परीक, lnom, _परीव, bòba,
   {{0x672d013f,0xe6be121d,0x5d861f9c,0xe81f00a4}},	//   _svaj, ोवैज, _جلال, परला_,
   {{0x60c2895f,0x6d5a01e8,0x00000000,0x00000000}},	//   nnom, _ipta, --, --,
   {{0x59b2030b,0x0eb6030b,0x3cfb009f,0x2b4d00ee}},	//   ुपहर, _अगाड, _लूटे_, ctec_,
   {{0x7ce58960,0x3f860131,0x00000000,0x00000000}},	//   móra, ixou_, --, --,
   {{0xddda030b,0x60c2084e,0xa5040565,0x7ce5033c}},	//   _patř, knom, иятл, lóra,
   {{0x60c243c5,0x6444008c,0x00000000,0x00000000}},	//   jnom, ggii, --, --,
   {{0x24891db8,0xb87b2ad4,0x56950ed7,0x672d033b}},	// [8fd0] rjam_, smís, _бапт, _uvaj,
   {{0x22470068,0x6d5a8961,0x27e400bc,0x00000000}},	//   ünk_, _opta, ümne_, --,
   {{0xa3e7007d,0xa2ba0c3c,0xddc88962,0xe03900d3}},	//   येज_, ्वज्, _andž, езеч_,
   {{0x60c28963,0xc95300c1,0x38a22773,0x00000000}},	//   gnom, ימע_, _kóra_, --,
   {{0x44298964,0xc43a0054,0x6d5a282c,0xd49100de}},	//   maa_, _אתרי, _apta, ều_,
   {{0x44292531,0x38a28965,0xc1050adb,0x7cf50138}},	//   laa_, _móra_, _موسي, _išri,
   {{0x200903be,0xb87b0161,0xddc10095,0xddc8007e}},	//   ñais_, ilíb, _balš, _endž,
   {{0x44298966,0x7ce500e3,0x27ed02c6,0x26c305db}},	//   naa_, fóra, ženy_, hnjo_,
   {{0xddc1033a,0x7b750604,0xaca30294,0x26c30117}},	//   _dalš, اطبا, _ntụl, knjo_,
   {{0x44298966,0xd90c0068,0x2fc00076,0xc3340796}},	//   haa_, ڈیو_, úige_, בוץ_,
   {{0x44298967,0x26c302dd,0xaca30129,0x2b4d8968}},	//   kaa_, dnjo_, _atụl, stec_,
   {{0xe73a329e,0x44298969,0x3da41cfb,0x93e30096}},	//   нем_, jaa_, _труб, _खरंच_,
   {{0x44290694,0xb8cc896a,0x7c29896b,0x7ce50072}},	//   daa_, _गत_, maer, córa,
   {{0x25ef02e8,0x38a20155,0xd9450293,0x6444008c}},	//   _आणखी_, _dóra_, _беки, wgii,
   {{0x4429896c,0x64a601b3,0x610c0740,0xe5a32731}},	//   faa_, гава, _oğla, бири,
   {{0x38a2896d,0x44290694,0xb87b2347,0x7c29896e}},	//   _fóra_, gaa_, smír, naer,
   {{0x38a200a5,0x78a40010,0xb87b030b,0x7c29010a}},	// [8fe0] _góra_, _iliv, blíb, iaer,
   {{0x7c290150,0x610c0511,0x00000000,0x00000000}},	//   haer, _ağla, --, --,
   {{0x4429896f,0x7c290a00,0x26da0294,0x78a48970}},	//   baa_, kaer, _ikpo_, _kliv,
   {{0x00da0bf4,0x4fa61a53,0x673b0087,0x1b190081}},	//   ربات_, лиев, šuje, _দিনে_,
   {{0xbbe2030b,0x7c298971,0x78a4024a,0x14d700ca}},	//   _परेक, daer, _mliv, _תוכל_,
   {{0x3fcb0421,0x78a400b3,0x00000000,0x00000000}},	//   ردنی_, _lliv, --, --,
   {{0xf9878972,0x00000000,0x00000000,0x00000000}},	//   _اب_, --, --, --,
   {{0x7c291a65,0x7ce54db1,0x00000000,0x00000000}},	//   gaer, tóra, --, --,
   {{0x40932204,0x26da0134,0x00000000,0x00000000}},	//   _القر, _okpo_, --, --,
   {{0x78a48973,0x629e8974,0x44298975,0x3eb88976}},	//   _aliv, nkpo, zaa_, _ört_,
   {{0x78a48977,0x4429025e,0x7c2900f9,0x2d9801df}},	//   _bliv, yaa_, baer, _ære_,
   {{0x44290fdc,0x26da0294,0xe3bf0610,0xb4ce030b}},	//   xaa_, _akpo_, _leña_, शको_,
   {{0x44298978,0xfcd3001c,0x26c38979,0x00000000}},	//   vaa_, _اينج, tnjo_, --,
   {{0x4429897a,0x386d897b,0x78a4019f,0x2d980103}},	//   waa_, žer_, _eliv, _üres_,
   {{0x4429897c,0x78a40090,0x00000000,0x00000000}},	//   taa_, _fliv, --, --,
   {{0x26da0134,0x8933071c,0x26c3211b,0x6e2a0178}},	//   _ekpo_, _اعوا, snjo_, hafb,
   {{0x4429897d,0xbbe20179,0x26c3033b,0x68ed02a1}},	// [8ff0] raa_, _परोक, pnjo_, _ihad,
   {{0x44293791,0x27e903f3,0x7ce50102,0xb603030b}},	//   saa_, _izan_, jórn, část,
   {{0x4429897e,0x68ed897f,0x64ac00ae,0x78a400c2}},	//   paa_, _khad, rşir, _yliv,
   {{0x046729ab,0x4429008c,0x6f0d065b,0x657a0537}},	//   _стом, qaa_, íaco, æthe,
   {{0x68ed44ee,0x68ff00a7,0x7ce51649,0x3f69017b}},	//   _mhad, _miqd, fórn, тило_,
   {{0x1eea00d0,0x63ad0415,0x68ed0113,0x7c290381}},	//   نونی_, mzan, _lhad, waer,
   {{0x63ad3ab5,0x7c2925a8,0x200e003e,0x41e4224a}},	//   lzan, taer, ækið_, _гіта,
   {{0x61fa01cd,0x68ed8980,0x27e98981,0x1b190033}},	//   _útla, _nhad, _ozan_, _দিবে_,
   {{0x63ad5a4b,0xbf151e53,0x7c290283,0x60db8982}},	//   nzan, _ضواب, raer, _ikum,
   {{0xdfd80465,0x60c91a08,0x68ed0051,0xa7fb03be}},	//   _със_, _hjem, _ahad, xeña,
   {{0x78a4084f,0x27e98983,0x68ed39c8,0x60c900d6}},	//   _pliv, _azan_, _bhad, _kjem,
   {{0x7e638984,0x7d0e0146,0xac192b37,0xe45f0212}},	//   lenp, žisé, _роду_, _sjön_,
   {{0x6d438985,0x63ad0559,0x68ed2d8f,0x78a400b6}},	//   luna, jzan, _dhad, _vliv,
   {{0x63ad2ac2,0xbb3a00a1,0x8f9a006e,0x7e638986}},	//   dzan, _יעני, דישי, nenp,
   {{0x6d438987,0x60db8988,0x68ed0099,0xb8250081}},	//   nuna, _okum, _fhad, _ভারত_,
   {{0x60c90fa3,0xa7fb11ce,0x68ed8989,0x78a4898a}},	//   _njem, seña, _ghad, _uliv,

   {{0xd4670478,0x6d431098,0xb2262c22,0xe3bf42be}},	// [9000] шите_, huna, имал, _peña_,
   {{0x2907898b,0x60c90032,0x26da0174,0x27e00032}},	//   _kuna_, _ajem, _ukpo_, _iyin_,
   {{0x6d43898c,0x2907898d,0x5be2218b,0x14c800cd}},	//   juna, _juna_, _पर्व, _مهدی_,
   {{0x3ea5898e,0x2907898f,0x26d88990,0x6d438991}},	//   _allt_, _muna_, loro_, duna,
   {{0x29078992,0x63ad00a5,0xe3bf08a8,0x60c9023b}},	//   _luna_, czan, _teña_, _djem,
   {{0x8d76037f,0x60c914e2,0x60db8993,0x7e6304aa}},	//   لاعا, _ejem, _ekum, genp,
   {{0x6d4326f7,0x29070a75,0x7d7800cd,0x6e2a4900}},	//   guna, _nuna_, امبر_, rafb,
   {{0x26d88994,0x60c9079f,0x00000000,0x00000000}},	//   horo_, _gjem, --, --,
   {{0x29078995,0x6b9b8996,0x7ac68997,0x8fa32a84}},	//   _auna_, gyug, исое, _дате,
   {{0x29078998,0x781f0176,0x26d88999,0x3a270072}},	//   _buna_, पर्क_, joro_, _cenp_,
   {{0x26d8899a,0x63ad899b,0x27e0006d,0x67240065}},	//   doro_, zzan, _ayin_, _awij,
   {{0x7ae1899c,0x27e00154,0x67240512,0x6b9b3833}},	//   allt, _byin_, _bwij, byug,
   {{0x6105013f,0x26d8899d,0x27e00167,0x6b9b0169}},	//   _vėli, foro_, _cyin_, cyug,
   {{0x26d8899e,0x7d08899f,0x29072712,0x67241a3a}},	//   goro_, _kuds, _funa_, _dwij,
   {{0x2907005a,0x68ed89a0,0x6e2889a1,0x7d080154}},	//   _guna_, _thad, _medb, _juds,
   {{0x1b1900c7,0x63ad89a2,0x7d0824da,0x7cc100d9}},	//   _দিতে_, tzan, _muds, tēri,
   {{0x26d889a3,0x6d4389a4,0x78bd32d2,0x67240a4b}},	// [9010] boro_, zuna, misv, _gwij,
   {{0x26d889a5,0x290789a6,0x6d431328,0x63ad7993}},	//   coro_, _yuna_, yuna, rzan,
   {{0x2f0b0021,0x63ad89a7,0x67246474,0x41551fc4}},	//   _søg_, szan, _zwij, свес,
   {{0x6d430517,0x78bd89a8,0xa49b00ee,0x00000000}},	//   vuna, nisv, _diòc, --,
   {{0x95e90068,0x7e6389a9,0x7ae189aa,0x3f670565}},	//   _جبکہ_, tenp, yllt, ртеб,
   {{0x6d4389ab,0x7d083696,0x22950076,0x00000000}},	//   tuna, _buds, _الآس, --,
   {{0x365c00a1,0x2ca6017a,0x6e2803e3,0xdf730139}},	//   דכונ, _blod_, _dedb, _bẹ̀é,
   {{0x60db6976,0x26d80134,0x60c932b9,0x290789ac}},	//   _ukum, zoro_, _ujem, _runa_,
   {{0x29070a75,0x6d436f64,0xdd910068,0x6295404b}},	//   _suna_, suna, توں_, _kozo,
   {{0x6d432f64,0x2900007a,0xe3bf0143,0x6e28009c}},	//   puna, _siia_, _leño_, _gedb,
   {{0xf769004f,0x26d80465,0x629589ad,0x6f09058a}},	//   _רק_, voro_, _mozo, _huec,
   {{0x26d889ae,0x290714f3,0x2ca600eb,0x6f01033c}},	//   woro_, _vuna_, _glod_, _hilc,
   {{0x6f090487,0x290000aa,0x00000000,0x00000000}},	//   _juec, _viia_, --, --,
   {{0x629589af,0x6f09037a,0x290789b0,0x87b9007b}},	//   _nozo, _muec, _tuna_, руют_,
   {{0x26d8605e,0x6f0189b1,0xe5a30ef1,0x776d0042}},	//   roro_, _milc, пири, _esax,
   {{0x26d84829,0x67240126,0xe3bf037a,0xb87b0328}},	//   soro_, _twij, _ceño_, plía,
   {{0x26d889b2,0x6f090314,0x96ba37fa,0x67240113}},	// [9020] poro_, _nuec, _буну_, _uwij,
   {{0x6295020a,0xe2970131,0x00000000,0x00000000}},	//   _cozo, бау_, --, --,
   {{0xed450401,0x04ca00e3,0xb87b0076,0x84e3007a}},	//   _تھ_, _مودي_, ilín, _कीकट_,
   {{0x7ce50610,0x6f012bc0,0x7d082452,0x6f0902db}},	//   fórm, _ailc, _ruds, _buec,
   {{0x44203f74,0x3ebc09ce,0x7d0802e6,0xdee62b49}},	//   mbi_, tivt_, _suds, боди,
   {{0x6f09068f,0x629589b3,0x7d0802b6,0x6f0103a8}},	//   _duec, _gozo, _puds, _cilc,
   {{0x7d0802e7,0x61433549,0x442089b4,0x6e282c9c}},	//   _quds, _нера, obi_, _vedb,
   {{0x5b140a8e,0x442089b5,0x394589b6,0x629589b7}},	//   омит, nbi_, duls_, _zozo,
   {{0x6e280342,0x442089b8,0x00000000,0x00000000}},	//   _tedb, ibi_, --, --,
   {{0xd91a01ef,0x442089b9,0x7d080103,0x3f5200f0}},	//   льм_, hbi_, _tuds, mâu_,
   {{0x19580138,0x442007ac,0x6f09037a,0x78bd89ba}},	//   шаны_, kbi_, _zuec, tisv,
   {{0x442014f3,0x2ca60124,0xb8820206,0x290c013c}},	//   jbi_, _ulod_, _šíra, rqda_,
   {{0x4420011d,0x274b00c2,0xa7fb120d,0x98b800e5}},	//   dbi_, ычно_, reño, слят_,
   {{0x442d0ec8,0xa7fb04d8,0x7bdc0511,0x78bd89bb}},	//   _že_, seño, ğrud, sisv,
   {{0x3abb004f,0x62950220,0x2ba6034c,0x67220052}},	//   _תמונ, _rozo, गनवा, _çojn,
   {{0x442089bc,0x94191773,0xfbe901c2,0xd498513f}},	//   gbi_, ржат_, _øªù_, бру_,
   {{0x611501d4,0x7d0289bd,0xe3bf002b,0x1fb708d4}},	// [9030] _işlə, _mios, _veño_, _अधेड,
   {{0x7d02006b,0xf8bf00fd,0x442089be,0x37b20033}},	//   _lios, lié_, abi_, _টুকর,
   {{0xe3bf08a8,0x6f091d32,0x442089bf,0x00000000}},	//   _teño_, _suec, bbi_, --,
   {{0x6f01041c,0x4420026d,0xf8bf89c0,0x00000000}},	//   _silc, cbi_, nié_, --,
   {{0x7c200abd,0x443989c1,0x6f090c70,0x62952e36}},	//   dbmr, _ids_, _quec, _tozo,
   {{0x442b89c2,0x44396002,0x88cf0081,0xfd110076}},	//   _hec_, _hds_, রতিক, وجب_,
   {{0x442b00ec,0x6f0101d3,0x31353bdd,0xfe70450f}},	//   _kec_, _vilc, _фебр, عده_,
   {{0xdfd57f94,0x7ce50034,0x80271ac9,0x61050138}},	//   _добы, mórk, _درآم, _dėlt,
   {{0x7d0289c3,0x442b89c4,0xf8bf0257,0x25db00b6}},	//   _dios, _mec_, dié_, _खुसी_,
   {{0x442b01d3,0x442089c5,0x00000000,0x00000000}},	//   _lec_, zbi_, --, --,
   {{0xf8bf025a,0x44395a84,0x7d020049,0xf8660467}},	//   fié_, _ods_, _fios, овно,
   {{0x443989c6,0x442b89c7,0x7d0289c8,0x2d530161}},	//   _nds_, _nec_, _gios, mãe_,
   {{0x2cad01c5,0xb87b89c9,0x442004fa,0x7c2b00e8}},	//   mhed_, plín, vbi_, _iegr,
   {{0x05db0251,0x645d4a6a,0x644f0133,0x7d020036}},	//   _मुहब, _absi, _acci, _zios,
   {{0x6603164d,0x442b89ca,0x1c0d02d5,0x442089cb}},	//   дпра, _bec_, _हलाल_, tbi_,
   {{0x03260465,0x442089cc,0x2cad052f,0xf8bf00fd}},	//   ждан, ubi_, nhed_, cié_,
   {{0x7c2b5d1b,0x442b00ca,0x2bf600c1,0x00000000}},	// [9040] _megr, _dec_, ַמען_, --,
   {{0x442089cd,0x645d0090,0x644f00e5,0x7c2b89ce}},	//   sbi_, _ebsi, _ecci, _legr,
   {{0xa3e64153,0x443913a9,0x7c39007f,0x600a8226}},	//   _फरक_, _fds_, _odwr, анем_,
   {{0xddc81999,0x442b4881,0x6ee40428,0x00000000}},	//   _nadš, _gec_, mòbi, --,
   {{0xf8b30054,0x7d020037,0xbe8a4223,0xa3bd18ff}},	//   ושא_, _rios, иске_, ेपण_,
   {{0x7d0289cf,0x877b00f5,0xbea30831,0x7c2b00b7}},	//   _sios, יאני, мачк, _aegr,
   {{0x7c2b89d0,0x7d0200a5,0x10a60394,0xe7e10851}},	//   _begr, _pios, _дивн, _गुना_,
   {{0x442b89d1,0x61ee0106,0x2cad4a62,0x00000000}},	//   _xec_, _izbl, ghed_, --,
   {{0x7cc10029,0x320d07aa,0x7c2b89d2,0xf8bf456c}},	//   vērt, _şeyi_, _degr, vié_,
   {{0x7d0289d3,0x2362061d,0xdcea0342,0x00000000}},	//   _wios, _mpkj_, ınır, --,
   {{0xc27b00f5,0x291800dd,0xf8bf0257,0xfbcf001c}},	//   בריי, ëra_, tié_, فتی_,
   {{0x7c2b35a5,0xb87b00e3,0xbb860190,0x2cad89d4}},	//   _gegr, rlío, _ولاي, ched_,
   {{0x29185873,0x81d60081,0xf8bf89d5,0x4439044c}},	//   ūra_, াইট_, rié_, _rds_,
   {{0x442b7ae7,0xaa5806cf,0x6ee4015e,0x00000000}},	//   _sec_, _طلبا_, fòbi, --,
   {{0x442b89d6,0xf8bf89d7,0x25db4d14,0xa49b01b9}},	//   _pec_, pié_, _खुशी_, _diòn,
   {{0x291e89d8,0x00000000,0x00000000,0x00000000}},	//   mpta_, --, --, --,
   {{0x442b0a32,0x443989d9,0x00000000,0x00000000}},	// [9050] _vec_, _vds_, --, --,
   {{0x04eb0033,0x7cd300ae,0x291e0167,0x98a600c6}},	//   কদের_, măre, opta_, rslą_,
   {{0x644f024a,0x00000000,0x00000000,0x00000000}},	//   _tcci, --, --, --,
   {{0x644f008f,0x443989da,0xf9930089,0x26c40220}},	//   _ucci, _uds_, ורע_, émov_,
   {{0x8e8589db,0xddc8035d,0x7c2b1b9e,0xb4d70efb}},	//   згле, _radš, _regr, ाकी_,
   {{0xa13700bf,0x7ce55216,0x3135129c,0x644d89dc}},	//   _ورزش, móri, _негр, lgai,
   {{0x628789dd,0x2cad89de,0x7ce589df,0x00000000}},	//   _injo, thed_, lóri, --,
   {{0x644d89e0,0x7cc100d9,0x271800b6,0x2f1001ec}},	//   ngai, vērs, něný_, _fàg_,
   {{0x2cad01c5,0x5f7700cd,0x7c2b89e1,0x7f4289e2}},	//   rhed_, _بازر, _vegr, croq,
   {{0x2cad0054,0x7c2b3994,0x00000000,0x00000000}},	//   shed_, _wegr, --, --,
   {{0xa9695053,0x60cb0023,0x25db1176,0x2aa900da}},	//   щина_, ongm, _खुली_, _cúba_,
   {{0x7ce5061a,0x290400bc,0x6aaa03a8,0x6615007f}},	//   kóri, öma_, _elff, eczk,
   {{0x291e00d3,0x7ce501cd,0x628789e3,0x7cd3044c}},	//   apta_, jóri, _onjo, găre,
   {{0x6d4389e4,0x24780134,0xb81c50a4,0x00000000}},	//   orna, _ọm_, _भ्रम_, --,
   {{0xa5d6009f,0x38a20032,0x00000000,0x00000000}},	//   _मुखौ, _lóri_, --, --,
   {{0x628789e5,0x7ce5028a,0x6ee400ee,0x00000000}},	//   _anjo, fóri, ròbi, --,
   {{0x7ce54f7d,0x7cd300ae,0x63060981,0x38600027}},	// [9060] góri, căre, سوال, _ibir_,
   {{0x644d0099,0xe29700ae,0x96960291,0x6d4309ac}},	//   agai, пау_, _хриш, krna,
   {{0x3860003d,0xd24f1f11,0x806614f2,0x869b006e}},	//   _kbir_, انم_, звеж, _הייז,
   {{0x628789e6,0xe7f3030b,0x2f100428,0x38a20065}},	//   _enjo, _घरमा_, _pàg_, _bóri_,
   {{0x443289e7,0x6d4389e8,0x59dd074c,0x98bf020a}},	//   may_, erna, _नुसर, lută_,
   {{0x7f4289e9,0x443289ea,0x332001af,0x291e30e6}},	//   rroq, lay_, mpix_, ypta_,
   {{0x490b030b,0xacf801b3,0x4c94036a,0x98bf00ae}},	//   _ठूलो_, онку_, дийс, nută_,
   {{0x443289e7,0x338f0139,0x7f4289eb,0x38a20139}},	//   nay_, _aáṣé, proq, _fóri_,
   {{0x33200bab,0x6d4303dc,0x6615007f,0x2be10096}},	//   npix_, arna, yczk, _पडणा,
   {{0x443289ec,0x60c289ed,0x38600079,0x6d4389ee}},	//   hay_, liom, _abir_, brna,
   {{0x05db1fbb,0xcc120294,0x80b00557,0x765c00f0}},	//   _मुंब, _bọtị, ंसपे, dfry,
   {{0x48ab5a64,0x4ff60af0,0x6d4a0435,0x3860009c}},	//   стом_, _aṣiṣ, mufa, _cbir_,
   {{0x443289ef,0x765c00f0,0x2d6e02c6,0xa49b009c}},	//   day_, ffry, _hře_, _diòl,
   {{0x291e2ba4,0x2ac20065,0x2be10096,0x36d52877}},	//   ppta_, _débè_, _पडता, фогр,
   {{0x44320188,0xda5b03c2,0x6d4a89f0,0xc9861a9f}},	//   fay_, _הכול, nufa, _хули,
   {{0x443289f1,0x7ce500c9,0xb4d705d4,0xd49889f2}},	//   gay_, tóri, ाके_, пру_,
   {{0x78ad89f3,0x28580037,0x6d430117,0xe8d80266}},	// [9070] _ilav, _رؤية_, zrna, _מוהר_,
   {{0x78ad0871,0x290e89f4,0x6d4a89f5,0x644d89f6}},	//   _hlav, _kufa_, kufa, sgai,
   {{0x443279d1,0x7ce50161,0x98bf00d3,0x26c3033b}},	//   bay_, sóri, cută_, mijo_,
   {{0x4432025e,0x26c389f7,0xd138224a,0x6d4a89f8}},	//   cay_, lijo_, яху_, dufa,
   {{0x7eaf00d6,0xb4e9142e,0x5ec50081,0x78ad0095}},	//   _løpe, यती_, _লীগে, _mlav,
   {{0x78ad89f9,0x26c302dd,0x6d4308a9,0x628703e5}},	//   _llav, nijo_, trna, _unjo,
   {{0x60c27aae,0x290e0022,0x78ad4562,0x6d4a89fa}},	//   biom, _nufa_, _olav, gufa,
   {{0x60c201b9,0xdb00014b,0x00000000,0x00000000}},	//   ciom, lymè, --, --,
   {{0x1ee70177,0x81df0081,0x8f5500cd,0x98bf00ae}},	//   _فوری_, দেশ_, _زناش, zută_,
   {{0x44322f1b,0xb4e93751,0x26c389fb,0x290e00ee}},	//   zay_, यतु_, jijo_, _bufa_,
   {{0x81df1348,0x4432025e,0x26c389fc,0x78ad89fd}},	//   দের_, yay_, dijo_, _blav,
   {{0x4432025e,0xb4d7033a,0x78ad59d4,0x644a0103}},	//   xay_, ाको_, _clav, őfiz,
   {{0x610c0b88,0x443214b1,0x26c30087,0x290e01c2}},	//   _işle, vay_, fijo_, _eufa_,
   {{0x443289fe,0x60c200a5,0x78ad89ff,0x26c3043c}},	//   way_, ziom, _elav, gijo_,
   {{0x44328a00,0x99850979,0x78ad8a01,0x7cd300ae}},	//   tay_, _آلبو, _flav, cărc,
   {{0x1ad50081,0x61fa003e,0x2aa00139,0x7f4b019f}},	//   _হওয়া, _útli, _dòbu_, kugq,
   {{0xa8570054,0x44325f51,0x26c38a02,0xcc120134}},	// [9080] _חיפה_, ray_, bijo_, _kọrị,
   {{0x44328a03,0x26c30b27,0x78ad0031,0x21a60ef1}},	//   say_, cijo_, _zlav, мизм,
   {{0x44326bf2,0x211a00d1,0x60c28a04,0x00000000}},	//   pay_, زتاب_, tiom, --,
   {{0x4432008a,0x6aaa2172,0x4fea07b3,0xbfc60131}},	//   qay_, _छत्र, омен_, мбек,
   {{0x3eac00f9,0x7ae80170,0x7ae3010a,0x68e40350}},	//   _pldt_, yldt, _oknt, _mkid,
   {{0xd2520f43,0x6d588a05,0x60c21f8e,0x6d4a8a06}},	//   _جنس_, ttva, siom, tufa,
   {{0x20561e46,0x60c20036,0x68e48a07,0x21380357}},	//   _отар, piom, _okid, _uvrh_,
   {{0x63a40694,0x290e2911,0x26c30087,0x6d582c94}},	//   oyin, _rufa_, zijo_, rtva,
   {{0x63a4012d,0x629c8a08,0x290e6025,0xb87b2159}},	//   nyin, _koro, _sufa_, slík,
   {{0x68e4707b,0x3b070257,0x629c63a9,0x610c0233}},	//   _akid, _cinq_, _joro, _eşle,
   {{0x6da6114c,0x629c8a09,0x26c302dd,0x7ae84fb5}},	//   _تمام, _moro, vijo_, rldt,
   {{0x629c1084,0xa9c300d6,0x7ae3010a,0x68f600f0}},	//   _loro, тськ, _eknt, _chyd,
   {{0x26c30087,0xe81e0034,0x7cd3020a,0x6f0805aa}},	//   tijo_, पड़ा_, sărc, _kidc,
   {{0x629c8a0a,0x290e8a0b,0xb4d73542,0x68e48a0c}},	//   _noro, _tufa_, ाक्_, _ekid,
   {{0xd49b2820,0x26c302dd,0x6f0812ba,0x7cd3020a}},	//   ора_, rijo_, _midc, lăra,
   {{0xb4e913b8,0x6b8263ed,0x26c30087,0xddc300ae}},	//   यते_, _krog, sijo_, lenţ,
   {{0x629c8a0d,0x7ce500e3,0x26c30087,0x6f08036b}},	// [9090] _boro, mórt, pijo_, _oidc,
   {{0x27e98a0e,0xddc300ae,0x672d026e,0x68fd8a0f}},	//   _iyan_, nenţ, _iwaj, lmsd,
   {{0x610c07aa,0x629c8a10,0x26c18a11,0x63a4083e}},	//   _oğlu, _doro, _imho_, ayin,
   {{0x6b828a12,0x27e91114,0x38a28a13,0x63a402a4}},	//   _orog, _kyan_, _fóru_, byin,
   {{0x63b60067,0x629c8a14,0x6b82023e,0x6f08026d}},	//   czyn, _foro, _nrog, _bidc,
   {{0xd3560054,0x629c8a15,0x672d29f7,0x00000000}},	//   _אישי_, _goro, _mwaj, --,
   {{0xddc3002d,0x20120037,0x672d58da,0xfce58a16}},	//   denţ, íniú_, _lwaj, ноко,
   {{0xf1b200c1,0xeb99456f,0x394c00f9,0x75ce01f9}},	//   _עסן_, зии_, duds_, lőzé,
   {{0x27e906a8,0x68f60150,0x6b828a17,0x672d01c2}},	//   _nyan_, _rhyd, _crog, _nwaj,
   {{0xddc300d3,0x2ef487b6,0x629c8a18,0x00000000}},	//   genţ, _азур, _xoro, --,
   {{0x6b821834,0xa6db0088,0x27e98a19,0x672d8a1a}},	//   _erog, nuðu, _ayan_, _awaj,
   {{0x6b828a1b,0x2d980472,0xb4e90442,0x672d0512}},	//   _frog, _àrea_, यतो_, _bwaj,
   {{0x1b1900c7,0xd8500134,0x7ba700e3,0x29090090}},	//   _দিকে_, _fọnt_, _تصام, _diaa_,
   {{0x27e90bb6,0x9f560103,0xddc300ae,0x68fd000b}},	//   _dyan_, égét_, cenţ, amsd,
   {{0x629c0513,0xcc120294,0x672d0065,0x27e98a1c}},	//   _roro, _kọpị, _ewaj, _eyan_,
   {{0x629c8a1d,0x68e41419,0x63a48a1e,0x80a10034}},	//   _soro, _ukid, tyin, कॉमे,
   {{0x27e98a1f,0x672d0044,0xd8d700c1,0x7ae126ae}},	// [90a0] _gyan_, _gwaj, _רופט_, oolt,
   {{0x63b600a5,0xddc10090,0x996e00a7,0x629c8a20}},	//   rzyn, _balż, nəş_, _qoro,
   {{0x065700c1,0x63b600a5,0x106a004c,0x22470031}},	//   _אייך_, szyn, зией_, ónka_,
   {{0x7ae18a21,0xddc300d3,0x629c0a96,0x62810072}},	//   holt, zenţ, _woro, _ólon,
   {{0x7ae18a22,0x629c8a23,0x1fa700ae,0x00000000}},	//   kolt, _toro, нкци_, --,
   {{0x7cd300d3,0x1fdf0081,0x6b820052,0x00000000}},	//   văra, _বৃহস, _rrog, --,
   {{0xddc300d3,0x7ae13661,0x00000000,0x00000000}},	//   venţ, dolt, --, --,
   {{0x91e38a24,0x7ce501cd,0x00000000,0x00000000}},	//   _сосе, dórs, --, --,
   {{0x290901af,0xddc300d3,0xbbca0096,0xc0a90281}},	//   _riaa_, tenţ, ापेक, _غافل_,
   {{0x394c05fe,0x3f99016d,0x672d0079,0x27e900d7}},	//   tuds_, _àsua_, _rwaj, _ryan_,
   {{0x0c260f1e,0xddc300d3,0xd2b700a1,0x200d008b}},	//   _змен, renţ, גלית_, şmiş_,
   {{0xeb9a01c9,0x013700a1,0x7cd300ae,0xddc3020a}},	//   _ние_, ערכת_, păra, senţ,
   {{0x7ae10c0a,0x28c006ed,0xfaa65cc8,0x00000000}},	//   bolt, शोधि, _падо, --,
   {{0x7ae164d5,0x38a200e3,0x672d0154,0x27e9022b}},	//   colt, _sórt_, _vwaj, _vyan_,
   {{0x45d41e2f,0xd8500174,0x7ce53884,0x7e7a1f60}},	//   горс, _kọlt_, pórt, _matp,
   {{0x27e907ac,0x7e7a0167,0x672d65bf,0x00000000}},	//   _tyan_, _latp, _twaj, --,
   {{0x672d4686,0x32551ac7,0xcb13006e,0x4e1000a3}},	// [90b0] _uwaj, квар, ָלע_, ाशाई_,
   {{0x7e7a005f,0x644800d9,0xa6db01cd,0x1db008c0}},	//   _natp, _ēdie, tuðu, जनात,
   {{0x3f848a25,0x3ce60218,0x35f51553,0xa7fb0062}},	//   _armu_, _okov_, _шпор, reñu,
   {{0xc5f217f5,0x90e7001c,0x7ae10103,0x2ea91e05}},	//   _כדי_, رسان, zolt, कस्त,
   {{0x44298a26,0xef18004d,0x6436006e,0xe45f01cd}},	//   mba_, емі_, _בארא_, _fjör_,
   {{0x44298a27,0x7bdc0587,0x8fa258ad,0x3f840113}},	//   lba_, ğrul, раше, _drmu_,
   {{0x691700d9,0x44298a28,0x00000000,0x00000000}},	//   _aģen, oba_, --, --,
   {{0xfebb00bf,0x44298a29,0x4c855833,0x00000000}},	//   _کارت_, nba_, тлив, --,
   {{0xe803000d,0x44298a2a,0x7e6401f9,0x00000000}},	//   रेमा_, iba_, őipa, --,
   {{0x44291b2b,0x2b4d00ee,0x00000000,0x00000000}},	//   hba_, ruec_, --, --,
   {{0x44290018,0x2d9a004d,0x7ae101f9,0x98bf182c}},	//   kba_, øpet_, rolt, lutę_,
   {{0x44298a2b,0x7ae18a2c,0xe73a1a0c,0x00000000}},	//   jba_, solt, мем_, --,
   {{0x98bf8a2d,0x2d850580,0x7d0b00f9,0xae15049d}},	//   nutę_, _hrle_, _iigs, _ढलान_,
   {{0xaa450002,0x44298a2e,0xbb4207c8,0xfaa28a2f}},	//   _рекл, eba_, _тешк, _вашо,
   {{0x7d0b0124,0x65c38a30,0x44294828,0x79830027}},	//   _kigs, абра, fba_, _urnw,
   {{0x44298a31,0x7d0b8a32,0xf74a00e3,0x2d8500c4}},	//   gba_, _jigs, _قلبي_, _mrle_,
   {{0x7c298a33,0x78bd0216,0x00000000,0x00000000}},	// [90c0] iber, ërve, --, --,
   {{0xb2232863,0x44298a34,0x7c291210,0x96fa00e3}},	//   имул, aba_, hber, _تعبر_,
   {{0x44298a35,0xf8c62b8a,0x98c608fa,0x644b2218}},	//   bba_, _लगाय, _लगाए, ógic,
   {{0x64a68a36,0x7e7a1783,0x44298a37,0x251e0129}},	//   _рама, _satp, cba_, _ọnwụ_,
   {{0xdfcf054f,0x7c295be0,0xddc33c34,0xd34800cd}},	//   ييم_, dber, venš, _سیاه_,
   {{0xb87b0103,0x3ce6052f,0x2d8500c4,0x6d5c00bc}},	//   llít, _skov_, _brle_, _ärak,
   {{0x628e8a38,0x3cde13db,0x127b00c1,0x7c295d41}},	//   _inbo, खवले_, _קאלע, fber,
   {{0x7c298a39,0x7d0b02ef,0x29182226,0xb87b0103}},	//   gber, _cigs, íram_, nlít,
   {{0x2d851e0c,0xe29f01cd,0x7d0b195c,0xaf0600c6}},	//   _erle_, _guðs_, _digs, _апал,
   {{0xc33300a1,0x44298a3a,0x7c298a3b,0x2d9a0120}},	//   סות_, zba_, aber, øpes_,
   {{0x7c298a3c,0x44298a3d,0x2d85015c,0x6da103e3}},	//   bber, yba_, _grle_, rɓac,
   {{0x4429008a,0xa8a72a61,0x00000000,0x00000000}},	//   xba_, трок, --, --,
   {{0x58d40e38,0x4429233f,0x00000000,0x00000000}},	//   роят, vba_, --, --,
   {{0xddda013f,0x4429041c,0xa6db0653,0x00000000}},	//   _natū, wba_, orði, --,
   {{0x55586bee,0x26cd00cb,0x98bf007f,0x61390032}},	//   каря_, đeo_, zutę_, _mùlá,
   {{0x628e8a3e,0x44298a3f,0xa7750012,0x00000000}},	//   _anbo, uba_, _блич, --,
   {{0x93f56428,0x6d4a01bf,0x00000000,0x00000000}},	// [90d0] упац, hrfa, --, --,
   {{0x44298a40,0xf1a733ed,0x00000000,0x00000000}},	//   sba_, крен, --, --,
   {{0xd0110fba,0x7c298a41,0x25a50149,0x3207007b}},	//   ملا_, yber, älld_, äny_,
   {{0x673b26dd,0xf1c3013f,0x30a7008f,0x628e0634}},	//   šuju, _rašė_, ързв, _enbo,
   {{0xb4c113ae,0x7d0b02b6,0x673d502c,0xb87b6165}},	//   ्ची_, _rigs, nssj, llís,
   {{0x7d0b084e,0x4df52887,0x7c291190,0x00000000}},	//   _sigs, ляйт, wber, --,
   {{0x7d0b0a69,0x3ced8a42,0xe8032918,0x00000000}},	//   _pigs, tlev_, रेता_, --,
   {{0x7eb400ee,0xb87b0076,0x0cd10033,0x00000000}},	//   _ràpe, ilís, াত্ত, --,
   {{0x81e80081,0x2d9a004d,0xd05b0022,0x3ced02b6}},	//   মেদ_, øper_, _shuɗ, rlev_,
   {{0x3cff023e,0x3ced8a43,0x7d0b02ac,0x673d059a}},	//   smuv_, slev_, _wigs, dssj,
   {{0xb87b2027,0x7d0b0009,0x3ced1842,0x98a61ca5}},	//   roín, _tigs, plev_, гине,
   {{0xc3240081,0x00000000,0x00000000,0x00000000}},	//   _পিসি_, --, --, --,
   {{0x4c9a0266,0x2a7c00ee,0xf772415a,0x673d487c}},	//   _רבנו, _favb_, حاج_, gssj,
   {{0x1bb80dd0,0x99850103,0x7eb400b3,0x2f1905aa}},	//   _جامع_, _ملتو, _tàpe, _mèg_,
   {{0xb4c12171,0x2f1903a9,0xd46a001f,0x98bf00d2}},	//   ्चू_, _lèg_, ниве_, nutě_,
   {{0x2cad8a44,0xb4ae02d5,0x261800bc,0x00000000}},	//   nked_, कसे_, बुजी_, --,
   {{0x2f1906a3,0x577a0076,0x2b5f020b,0x00000000}},	// [90e0] _nèg_, _أصبح_, ntuc_, --,
   {{0xb87b0146,0x67246dd3,0xa6db003e,0x68e65de7}},	//   slít, _itij, yrði, lokd,
   {{0xe5a61778,0x35a60077,0x673b0087,0x26ca8a45}},	//   _сини, _санг, šujt, mibo_,
   {{0x25a51664,0xbf0f00a5,0x26ca336e,0x00000000}},	//   älle_, ादून_, libo_, --,
   {{0xe3b21b67,0xbea60457,0x6e380094,0x24800270}},	//   _طرح_, ладк, tavb, mdim_,
   {{0xf12400d0,0xdee32917,0x2480008b,0x2360023e}},	//   _نظری, бочи, ldim_, mtij_,
   {{0xccf8030b,0x217555d0,0xddd801f9,0x00000000}},	//   _opět_, _кутр, tevő, --,
   {{0x24808a46,0x26ca8a47,0x645603e3,0x6d4a8a48}},	//   ndim_, hibo_, ngyi, rrfa,
   {{0x26ca8a49,0x1bd4002d,0x24800037,0x61ee00f0}},	//   kibo_, ропя, idim_, _hybl,
   {{0x5a34545a,0x9e65010d,0x00000000,0x00000000}},	//   шнот, _نامن, --, --,
   {{0xddc826dd,0x67240af0,0xd91700c2,0x248004a8}},	//   _hadž, _atij, лья_, kdim_,
   {{0x2cad00a1,0x37d90033,0x1c0d1784,0x91bb00ca}},	//   cked_, _সরবর, _हलचल_, תמטי,
   {{0xa3e40179,0x0a944442,0x2480009e,0x9a8601b6}},	//   _पुल_, _валю, ddim_, _буйл,
   {{0x4b7b00c1,0xddc86a6a,0x29022fbe,0xe6100076}},	//   _נאוו, _madž, amka_, كشف_,
   {{0x67240090,0x61ee02c3,0x00000000,0x00000000}},	//   _etij, _nybl, --, --,
   {{0xb4c139d4,0x64562ea0,0x38c90068,0x00000000}},	//   ्चे_, ggyi, _جاتی_, --,
   {{0x36d502fd,0xddc800cc,0x26ca0283,0x92590396}},	// [90f0] _вопр, _nadž, bibo_, каат_,
   {{0x2f190c56,0x26ca2c90,0xccf8030b,0x09d70081}},	//   _règ_, cibo_, _zpět_, _হরতা,
   {{0x3869003d,0xa49b00b3,0x65950ed7,0x61ee03a8}},	//   _kbar_, _biòt, _тану, _cybl,
   {{0x61ee00eb,0x00000000,0x00000000,0x00000000}},	//   _dybl, --, --, --,
   {{0x443b0253,0x38698a4a,0x00000000,0x00000000}},	//   maq_, _mbar_, --, --,
   {{0x443b8a4b,0x171c00c1,0x6aae02d5,0x3a2900e7}},	//   laq_, עווע, टसोर, _đapo_,
   {{0x4035044b,0xf2d200ca,0xd65800ca,0x38690441}},	//   _вебс, _ועם_, איות_, _obar_,
   {{0x0b450c58,0x443b0092,0x00000000,0x00000000}},	//   анин, naq_, --, --,
   {{0x2cad8a4c,0x60cb1ef8,0x7bc400c6,0x394c18f0}},	//   rked_, migm, _žiur, erds_,
   {{0x4e780678,0x2cad8a4d,0x88bd030b,0x38698a4e}},	//   _محمد_, sked_, spěl, _abar_,
   {{0x67248a4f,0xbd4b00e3,0xe8fa17e9,0x443b023b}},	//   _stij, _سؤال_, кло_, kaq_,
   {{0x254101b3,0xa3b50851,0xb4c10557,0x76450167}},	//   dėl_, जना_, ्चो_, _adhy,
   {{0x26ca7228,0xb8de04f1,0x443b8a50,0x29020e94}},	//   tibo_, _इत_, daq_, rmka_,
   {{0x7c3b865e,0x644b04c8,0x2360022e,0x49b96e50}},	//   laur, ógin, vtij_, _لابد_,
   {{0xceb209c1,0x3cfd0197,0xba740dce,0x443b8a51}},	//   חים_, _khwv_, _دانت, faq_,
   {{0xb4d00096,0x26ca8a52,0x14266c35,0xb4e00ff9}},	//   वचे_, sibo_, рдам, दके_,
   {{0x24808a53,0x03230747,0xa5071d5c,0xd4970023}},	// [9100] rdim_, ждун, рета_, ờng_,
   {{0x23600126,0x7c3b0010,0x6aa38a54,0xddc83e30}},	//   rtij_, haur, _jonf, _radž,
   {{0x6aa389a5,0x7c3b8a55,0x23608a56,0xa49b01b9}},	//   _monf, kaur, stij_, _bhòd,
   {{0x443b0253,0x24800092,0xef86171b,0x92c60033}},	//   caq_, qdim_, илеп, উকে_,
   {{0x6fd600e3,0x7ccd00d9,0x7c3b8a57,0x44228a58}},	//   جزائ, _mērķ, daur, _ifk_,
   {{0x44208a59,0xddc866bb,0xa49b01b9,0x4422004d}},	//   lci_, _vadž, _phòg, _hfk_,
   {{0x4096121c,0x614307ca,0x00000000,0x00000000}},	//   _крат, _мера, --, --,
   {{0x44208a5a,0x8fa61cf2,0x3cfd01fa,0x78a402a8}},	//   nci_, _кабе, _chwv_, _noiv,
   {{0x44250092,0x3d1600a5,0x44208a5b,0x4f0a3283}},	//   _əl_, _पूरे_, ici_, _анан_,
   {{0xf1eb0378,0x2ee7009c,0xfaa61b60,0x78b60138}},	//   _जुड़_, conf_, ршин, _alyv,
   {{0x81e800c7,0x44208a5c,0x4422566d,0x02170327}},	//   মের_, kci_, _ofk_, יחים_,
   {{0xb4e0030b,0x26ef058f,0xa3d6023a,0x00000000}},	//   दको_, छत्र_, िपा_, --,
   {{0x7c228a5d,0x44201999,0x78a40257,0x274b008f}},	//   _ifor, dci_, _doiv, ъчно_,
   {{0x44200067,0x78b60027,0xa49b009c,0x387f0218}},	//   eci_, _elyv, _niòr, žur_,
   {{0x78b60170,0x443b00a7,0xd6d80a29,0x4a310220}},	//   _flyv, taq_, ртя_, äčší_,
   {{0x4422037a,0x6eed0076,0x7c2200bd,0x6b970231}},	//   _cfk_, lúbt, _jfor, _àagê,
   {{0x443b8a5e,0x68ed8a5f,0x8afd000d,0x7cfe023b}},	// [9110] raq_, _ikad, stře, përf,
   {{0x44208a60,0x443b12d4,0xa49b01b9,0x00000000}},	//   aci_, saq_, _shòd, --,
   {{0x44208a61,0x443b0abd,0xa2d817ff,0x7c22042d}},	//   bci_, paq_, _मदर्, _ofor,
   {{0x44208a62,0x7c3b6b23,0x00000000,0x00000000}},	//   cci_, xaur, --, --,
   {{0x44398a63,0x6d4108c5,0xb4fa00a1,0x60cb06a8}},	//   _ies_, _svla, _תפרי, rigm,
   {{0x7c228a64,0x44398a65,0x7cd3002d,0x63ad8a66}},	//   _afor, _hes_, mări, myan,
   {{0x44398a67,0x63ad67dc,0x3cfd023e,0x6aa345b0}},	//   _kes_, lyan, _phwv_, _ronf,
   {{0xec790b57,0x3cfd022e,0x2b4d50cd,0x9c5905b6}},	//   упи_, _qhwv_, trec_, ушку_,
   {{0x60db0051,0x69ce0220,0x7c3b8a68,0xdcb100de}},	//   _ijum, úben, raur, _của_,
   {{0x44398a69,0x7c3b1435,0x2b4d0472,0x7c2200d3}},	//   _les_, saur, rrec_, _efor,
   {{0x7c2202ad,0x443902ad,0x63ad8a6a,0x3cfd023e}},	//   _ffor, _oes_, hyan, _thwv_,
   {{0x44398a6b,0x63ad8a6c,0x3ea50691,0x26de0031}},	//   _nes_, kyan, _holt_, čtom_,
   {{0xef190067,0x442000d2,0x60c900ac,0x63ad023f}},	//   _już_, vci_, _mmem, jyan,
   {{0x63ad1d11,0x6aba8a6d,0x7cd300ae,0x64460167}},	//   dyan, chtf, dări, _sdki,
   {{0x3ea516c8,0x78a402fd,0x442023a0,0x6d5c00aa}},	//   _molt_, _toiv, tci_, _ärat,
   {{0x44398a6e,0x25a50222,0x44208a6f,0xfd560174}},	//   _ces_, älla_, uci_, _albọ,
   {{0x44397bdd,0x44208a70,0x63ad8a71,0x64a31787}},	// [9120] _des_, rci_, gyan, чата,
   {{0x44208a72,0x44398a73,0x29127698,0x60db0139}},	//   sci_, _ees_, _hiya_, _ajum,
   {{0xc6930054,0x44398a74,0x2900023e,0xaca30032}},	//   _זאת_, _fes_, _khia_, _amọj,
   {{0x92d800c7,0x7c394695,0xa14b0068,0x29128a75}},	//   াতে_, _newr, اسلے_, _jiya_,
   {{0x63ad8a76,0x80ca0081,0x7cd300d3,0x29128a77}},	//   cyan, িকল্, cări, _miya_,
   {{0x7c228a78,0x60c98a79,0x291200bf,0x44398a7a}},	//   _sfor, _emem, _liya_, _zes_,
   {{0x11da00e3,0x2912171d,0x44398a7b,0x6da31009}},	//   _صورة_, _oiya_, _yes_, зија,
   {{0x0cb800c7,0x291234e1,0x4439006c,0x3ce00106}},	//   ুক্ত, _niya_, _xes_, čivo_,
   {{0xdfcf0080,0x99850138,0xe4fb023a,0x7cfe0052}},	//   _كيف_, kalų_, ्षति_, jëre,
   {{0x68ed34cb,0x9e6600cd,0x290000ac,0x2912283d}},	//   _skad, _دارن, _ahia_, _aiya_,
   {{0x29128a7c,0x7cd300d3,0x63ad8a7d,0x29000076}},	//   _biya_, zări, zyan, _bhia_,
   {{0x29000028,0x63ad0a75,0x7c22038c,0x7c398a7e}},	//   _chia_, yyan, _ufor, _gewr,
   {{0x29004f6f,0x7d1a0a00,0x2912181d,0x657e8a7f}},	//   _dhia_, _huts, _diya_, _asph,
   {{0x44398a80,0x7d1a8a81,0x99850138,0x7cd3020a}},	//   _ses_, _kuts, galų_, vări,
   {{0x4439023e,0x29126590,0x7cfe023b,0x2ca616a9}},	//   _pes_, _fiya_, përd, _kood_,
   {{0x44398a82,0x63ad8a83,0x7d1a8a84,0x7cd300d3}},	//   _qes_, tyan, _muts, tări,
   {{0x44398a85,0x7d1a8a86,0x7eb400ee,0x67020294}},	// [9130] _ves_, _luts, _nàpo, ịkar,
   {{0x2d8c8a87,0x63ad8a88,0x44398a89,0x7cd300d3}},	//   _orde_, ryan, _wes_, rări,
   {{0x44398a8a,0x63ad7458,0x7d1a8a8b,0x97d8110a}},	//   _tes_, syan, _nuts, _نظیر_,
   {{0x4395013d,0x2ca64e28,0x7cd300ae,0x63ad2c7b}},	//   _дамс, _nood_, pări, pyan,
   {{0x2d8c8460,0x63ad0063,0x3ea51abe,0xa2c20032}},	//   _arde_, qyan, _polt_, _kọ̀m,
   {{0x7d1a0027,0x6b8d0dd9,0xa3d6088d,0x867c006e}},	//   _buts, _šago, िपर_, ָרהו,
   {{0x3ea500fb,0x62958a8c,0x2ca68a8d,0x00000000}},	//   _volt_, _inzo, _bood_, --,
   {{0x60db8a8e,0x60c9158f,0x7d1a8a8f,0x2fdf01fa}},	//   _ujum, _umem, _duts, _txug_,
   {{0x2ca68a90,0x2900023e,0x2d8c0364,0x7d1a01e9}},	//   _dood_, _rhia_, _erde_, _euts,
   {{0x62858a91,0x291234e1,0x29008a92,0x7ed70246}},	//   ndho, _siya_, _shia_, _ازرا,
   {{0x7d1a8a93,0x2ca600a1,0x29128905,0x6ce7004d}},	//   _guts, _food_, _piya_, _ліде,
   {{0x2ca60054,0x29000d7d,0x3f8d023b,0xa3e90f8f}},	//   _good_, _qhia_, _kreu_, यथा_,
   {{0x6d435cf1,0x2bd0007a,0x6130022b,0x61400065}},	//   lsna, _तइया, _kòlò, _kálá,
   {{0x6b8909ad,0x61400139,0x62858a94,0x00000000}},	//   mveg, _jálá, jdho, --,
   {{0x29006f3b,0x628502a1,0x29128a45,0x6b898a95}},	//   _thia_, ddho, _tiya_, lveg,
   {{0x62850e24,0x62950850,0x78bd0364,0xe7f30096}},	//   edho, _anzo, chsv, _घरचा_,
   {{0x42ca0ef7,0x6b898a96,0x7ce5002b,0x6f1b008c}},	// [9140] аган_, nveg, fórz, _nuuc,
   {{0x7cd300d3,0x6d438a97,0xa49b01b9,0x33d5004d}},	//   măru, ksna, _phòc, чіст,
   {{0x64a60831,0x69c10364,0xd9ef10e9,0x2c4c00c6}},	//   _дана, nzle, _घुमत_, lėdų_,
   {{0xa06a529c,0x7d1a8a98,0x3f8d0428,0x62950d8d}},	//   рада_, _ruts, _breu_, _enzo,
   {{0x61406c94,0x3f8d8a99,0x2ca60126,0x44328a9a}},	//   _bálá, _creu_, _rood_, mby_,
   {{0x44326281,0x7f420abd,0x765c0313,0xde930291}},	//   lby_, rsoq, ngry, дашњ,
   {{0x44323f3c,0x01630c5b,0x6d432479,0x2ca600aa}},	//   oby_, _окро, gsna, _pood_,
   {{0xa3ae0693,0x5c98013d,0xafe60b1e,0x6e3a1183}},	//   _कथा_, ския_, _добл, _wetb,
   {{0x3f8d8a9b,0xae7a02fd,0x7d1a03e3,0x61400065}},	//   _greu_, _всех_, _wuts, _fálá,
   {{0x7d1a1779,0x2d8c033b,0x2ca600ca,0x00000000}},	//   _tuts, _trde_, _wood_, --,
   {{0x3860009c,0x44320034,0x2d8c01ff,0x00000000}},	//   _bcir_, kby_, _urde_, --,
   {{0x6d588a9c,0x44328a9d,0x00000000,0x00000000}},	//   muva, jby_, --, --,
   {{0x44328a9e,0x6d581d2d,0xd7fb8a9f,0x7cfe023b}},	//   dby_, luva, рун_, përb,
   {{0x3ce90095,0xdea80044,0x2bd0074c,0x7d02039f}},	//   čave_, _ƙoƙa, _तेया, _hhos,
   {{0xa3d01ae6,0x610c0233,0x62830131,0x6d582132}},	//   _वेब_, _eşli, ônom, nuva,
   {{0x44328aa0,0xd498467a,0x19bb00a1,0xb4b50034}},	//   gby_, ору_, _כמוב, झसे_,
   {{0x7cd300ae,0x6d5813ce,0x7d02033c,0x00000000}},	// [9150] căru, huva, _mhos, --,
   {{0x291c8aa1,0x6d588aa2,0xda780220,0x6d430188}},	//   _kuva_, kuva, neď_, ysna,
   {{0x614033c3,0x62858aa3,0x44326ee1,0x26d18aa4}},	//   _rálá, rdho, bby_, mizo_,
   {{0x3f8d0472,0x26d18aa5,0x6d5815a5,0xd479006e}},	//   _preu_, lizo_, duva, _פאָל,
   {{0x291c8aa6,0x9ac402a1,0x6d5802ac,0x00000000}},	//   _luva_, _keċċ, euva, --,
   {{0x6d4368c0,0x3d1602d5,0x7d028aa7,0x9ac400bd}},	//   tsna, _पंखे_, _ahos, _jeċċ,
   {{0x7d021ac3,0x6d588aa8,0x291c0027,0x00000000}},	//   _bhos, guva, _nuva_, --,
   {{0x6d438aa9,0x3f8d8aaa,0x7d024115,0x6b898aab}},	//   rsna, _treu_, _chos, tveg,
   {{0x6d438aac,0x38a200a5,0x26d11b95,0xf8bf00bf}},	//   ssna, _góry_, kizo_, dhé_,
   {{0x44322347,0x7cd300ae,0x291c0ab9,0x69c18aad}},	//   zby_, văru, _buva_, tzle,
   {{0x44327981,0x7d020091,0xe8e000de,0x6b898aae}},	//   yby_, _fhos, _ngợi_, sveg,
   {{0x291c0a39,0x7d023f12,0xf1b2006e,0x2d5800d3}},	//   _duva_, _ghos, גסט_, _фиць_,
   {{0x7d098aaf,0x69c10068,0x44320074,0x00000000}},	//   mmes, szle, vby_, --,
   {{0x7d098ab0,0x26d18ab1,0x80b90033,0x7cfe0052}},	//   lmes, gizo_, েকট্, përc,
   {{0x4432025b,0x2a3a0796,0x66032549,0x765c8ab2}},	//   tby_, _העצמ, епра, rgry,
   {{0x7d0901e8,0x03260084,0x7d028ab3,0x64a336bf}},	//   nmes, здан, _xhos, наса,
   {{0x44328ab4,0x26d118b1,0x998702c6,0x421a0037}},	// [9160] rby_, bizo_, _jenž_, مزاج_,
   {{0x44320f05,0xb87b26e0,0x7d098ab5,0xd6c41ac9}},	//   sby_, gníf, hmes, _آمدی,
   {{0x7d098ab6,0x7cfe0052,0x00000000,0x00000000}},	//   kmes, hëra, --, --,
   {{0xd12f1e53,0xe803030b,0x7d098ab7,0x3a270381}},	//   امن_, रेका_, jmes, _lfnp_,
   {{0x2cbf07ac,0x7d098ab8,0x7cfe0052,0x7d0200f0}},	//   dhud_, dmes, jëra, _rhos,
   {{0x6d588ab9,0x33fb00ca,0xdfcf0190,0x7d028aba}},	//   tuva, _להכנ, ديه_, _shos,
   {{0x7d0232cc,0xda780038,0x20563e81,0xc0d60037}},	//   _phos, veď_, _нтар, _فيسب,
   {{0x6d588abb,0xa0670c63,0x291c0169,0x7d0913ea}},	//   ruva, _наса_, _ruva_, gmes,
   {{0x6d588abc,0x291c15a5,0x7ebd0154,0x00000000}},	//   suva, _suva_, _sèpe, --,
   {{0xc333004f,0x6d5813ce,0x7d0200ca,0x291c010a}},	//   עות_, puva, _whos, _puva_,
   {{0x7d028abd,0x2eee6dfa,0xf8bf0668,0x7d09880b}},	//   _thos, moff_, thé_, bmes,
   {{0xf8bf00b6,0x38bb0052,0x7d098abe,0xc7d500e5}},	//   uhé_, _bëra_, cmes, джмъ,
   {{0x26d1068d,0xb8e509a1,0x00000000,0x00000000}},	//   tizo_, _एत_, --, --,
   {{0xba170080,0x2eee71f7,0x6b8285f2,0xe803007f}},	//   _فيها_, noff_, _isog, रेगा_,
   {{0x26d14db0,0x35e400d6,0x7cd300ae,0x6594163d}},	//   rizo_, ецтв, părt, нару,
   {{0x6aaa8abf,0x26d18ac0,0x00000000,0x00000000}},	//   _hoff, sizo_, --, --,
   {{0x6aaa5b8c,0xe80302d5,0xa3d00635,0xb87b49aa}},	// [9170] _koff, रेखा_, _वेद_, eníg,
   {{0x672d8ac1,0x6aaa8ac2,0x6d482cea,0xe7050281}},	//   _itaj, _joff, _ovda, _تسبی,
   {{0x6aaa8ac3,0x7d098ac4,0xe1390565,0x38bb0216}},	//   _moff, ymes, ізді_, _zëra_,
   {{0x92bf0081,0x98a600ae,0x61f50031,0x672d009e}},	//   ুকে_, mplă_, _vyzl, _ktaj,
   {{0x248900a6,0x7feb2c9a,0x6b8206c0,0xfaf801d3}},	//   mdam_, حراف_, _nsog, klī_,
   {{0x24898ac5,0x672d0239,0x6aaa0078,0x00000000}},	//   ldam_, _mtaj, _noff, --,
   {{0xa3b50067,0x23698ac6,0x7d098ac7,0xfce50d97}},	//   जनक_, ltaj_, tmes, моко,
   {{0x645f019f,0x62878ac8,0x672d8ac9,0xb87b0072}},	//   ngqi, _hajo, _otaj, alíz,
   {{0x23698aca,0x7d098acb,0x6aaa8acc,0x62878acd}},	//   ntaj_, rmes, _boff, _kajo,
   {{0x88bd000d,0xeab100e3,0x7d098ace,0xe9d917e3}},	//   zpět, ئعة_, smes, жко_,
   {{0x6b828acf,0x672d8ad0,0x6aaa4574,0x1eea01f9}},	//   _esog, _ataj, _doff, _بولی_,
   {{0x62878ad1,0x2b5207aa,0x8d74110a,0x672d02a1}},	//   _lajo, üncü_, _ساما, _btaj,
   {{0xa49b00ef,0x9b94007b,0x00000000,0x00000000}},	//   _phòn, _пицц, --, --,
   {{0x62870941,0x6aaa8ad2,0x24890a84,0x249900fc}},	//   _najo, _goff, edam_, _ansm_,
   {{0x672d8ad3,0x248902ac,0x2369044c,0xd5752458}},	//   _etaj, fdam_, etaj_, нуть,
   {{0x38bb0052,0x00000000,0x00000000,0x00000000}},	//   _tëra_, --, --, --,
   {{0x24860181,0x52aa3b4f,0xd5b800d9,0x62878ad4}},	// [9180] ľom_, овам_, šā_, _bajo,
   {{0x62875009,0x63ab17a5,0x3ce00559,0x00000000}},	//   _cajo, ägna, čivi_, --,
   {{0x7eaf00f3,0x00000000,0x00000000,0x00000000}},	//   _løps, --, --, --,
   {{0x6aaa0bf5,0x6287010a,0x258702c6,0x00000000}},	//   _चक्र, _eajo, sílá_, --,
   {{0xe3b204f4,0x2eee8ad5,0x91ce030b,0x78bd023b}},	//   _شرح_, toff_, _धेरै, ërvi,
   {{0x67001d7d,0x5f93580c,0xd1320452,0x00000000}},	//   ोगिक_, тишт, _لمس_, --,
   {{0x998700c6,0x57ba00b6,0x6b8206b0,0x6aaa45d9}},	//   _menų_, उनुह, _ssog, _roff,
   {{0x6aaa6fe1,0x98bf00d9,0x2eee061d,0x64443e2c}},	//   _soff, kstā_, soff_, naii,
   {{0x7eb400b3,0x60c2014b,0xda7a00e5,0x6aaa0b8e}},	//   _làpi, mhom, оян_, _poff,
   {{0x3ce900e9,0x60c28ad6,0x63ab052f,0x998c02ef}},	//   čava_, lhom, øgni, radž_,
   {{0x28f90f1e,0x644465f7,0x325700a1,0x6c830018}},	//   зень_, kaii, וסים_, رلیم,
   {{0x236900a5,0x7cfe023b,0x60c2014b,0x3eac05db}},	//   ytaj_, mëro, nhom, _hodt_,
   {{0x6aaa8ad7,0x6b820350,0x672d00bd,0x00000000}},	//   _toff, _usog, _qtaj, --,
   {{0x68ef008c,0xe9cf0281,0x9f55014b,0xabfb00d7}},	//   socd, اغی_, égée_, _והדר,
   {{0x62878ad8,0x60c20060,0x7eb400ee,0xa49b01b9}},	//   _rajo, khom, _càpi, _fhòl,
   {{0xb4fb2853,0x3f84007e,0xb4e90714,0x62871175}},	//   ्षेप_, _osmu_, मके_, _sajo,
   {{0x24898ad9,0x60c200bd,0x3d160cce,0x672d8ada}},	// [9190] rdam_, dhom, _पूछे_, _utaj,
   {{0x23698adb,0x78ad8adc,0xb87b037a,0x00000000}},	//   rtaj_, _hoav, coír, --,
   {{0x23698add,0x62878ade,0x7cfe0052,0x3eb901d3}},	//   staj_, _vajo, jëro, _ēst_,
   {{0xe80c8adf,0x62878ae0,0xe3b00018,0xa3d00179}},	//   सेवा_, _wajo, درہ_, _वेव_,
   {{0x6287572e,0x644f0231,0x7eb400b3,0x78ad0120}},	//   _tajo, _idci, _zàpi, _moav,
   {{0x44298ae1,0x69c500bc,0x00000000,0x00000000}},	//   lca_, _üheg, --, --,
   {{0x3f8400d9,0x44290231,0x00000000,0x00000000}},	//   _esmu_, oca_, --, --,
   {{0x60c28ae2,0x00000000,0x00000000,0x00000000}},	//   chom, --, --, --,
   {{0x7cfe00dd,0xfe750396,0x6bd501c3,0x7e88007b}},	//   përn, _плаќ, عتبر, öspä,
   {{0x3eac0170,0xde97006f,0xb4bc02d5,0xa49b01b9}},	//   _godt_, _تجرب, _अत्_, _shòl,
   {{0x98bf013f,0x644f423b,0xa2b2349d,0x78ad0956}},	//   nutė_, _odci, _आकस्, _boav,
   {{0xb4e9000d,0x7eb40472,0x18a61d68,0x998700c6}},	//   मको_, _ràpi, хамм, _senų_,
   {{0x44298ae3,0xeb99008f,0x7eb40428,0xa49b0441}},	//   dca_, _хил_, _sàpi, _chòm,
   {{0x09e567aa,0x7c2902cb,0x8bd600ca,0xa3d02171}},	//   _полн, lcer, _אונו_, _वेष_,
   {{0x44293a4e,0x99850037,0xe8e000fe,0x940b013c}},	//   fca_, _ألبو, _ngủi_, _incə_,
   {{0x442905db,0x442b8ae4,0x78ad0154,0x60c20415}},	//   gca_, _cfc_, _goav, xhom,
   {{0x68e40294,0x42564431,0xa3fe0033,0x1306022f}},	// [91a0] _ijid, етет, ংখ্য_, езам,
   {{0x44298ae5,0x7eb47c05,0x64440e22,0x00000000}},	//   aca_, _tàpi, saii, --,
   {{0x60c20060,0x27260019,0x44290220,0x442b0357}},	//   thom, _hôn_, bca_, _ffc_,
   {{0x44298ae6,0x70f600e3,0x03a64d1a,0x53a62436}},	//   cca_, رسائ, _зимо, _замб,
   {{0xb87b030b,0x74160103,0x7ebd05aa,0x2d8500f3}},	//   lníc, _سوسا, _sèpa, _asle_,
   {{0x7cfe00dd,0x60c285c3,0x27265ad7,0x7c2b8ae7}},	//   tëro, shom, _môn_, _afgr,
   {{0x91e61756,0x629c8ae8,0x27265ac5,0xb87b02c6}},	//   _чове, _inro, _lôn_, nníc,
   {{0x68e40134,0x7c290428,0x7ae3007e,0xcb1b02d5}},	//   _njid, gcer, _ajnt, नदंड_,
   {{0xdcfa00d3,0x63a440a0,0x27260023,0x69080072}},	//   _astă, nxin, _nôn_, iñed,
   {{0x44298ae9,0x68e40139,0x78ad8aea,0x7c298aeb}},	//   zca_, _ajid, _soav, acer,
   {{0x7cfe00dd,0x44298aec,0xb87b1054,0xad650076}},	//   qëro, yca_, jníc, _لانه,
   {{0xb87b0074,0x7c298aed,0x8d5511a1,0x6016008b}},	//   dníc, ccer, _штуч, _gümü,
   {{0xe80c04a9,0x272600de,0x629c029a,0x68e40a39}},	//   सेला_, _côn_, _onro, _djid,
   {{0x68e40294,0x442900a5,0x6f1d0036,0x6da10022}},	//   _ejid, wca_, _èsce, mɓar,
   {{0x6f1a8aee,0x44298aef,0x212d00b6,0x798100f0}},	//   _mitc, tca_, _čeho_, cwlw,
   {{0x44298af0,0x629c8af1,0xa49b01b9,0x27260178}},	//   uca_, _anro, _thòm, _fôn_,
   {{0x44298af2,0x98bf002d,0x6d580f39,0x09d50081}},	// [91b0] rca_, astă_, hrva, _সুপা,
   {{0xa3d002e8,0xb87b0363,0x6d580128,0x68fd8af3}},	//   _वेळ_, bníc, krva, llsd,
   {{0x395e0472,0x442b8af4,0xa2b2022d,0x44291da4}},	//   nuts_, _tfc_, _आकर्, pca_,
   {{0x5fd2007a,0x6d4a38f0,0x6d5800e7,0x9f35004d}},	//   _देहल, dsfa, drva, веді,
   {{0x27260023,0x2bd00096,0x6f1a8af5,0x2d9a0572}},	//   _xôn_, _तेला, _bitc, åpen_,
   {{0xf774040a,0x29090113,0x60160555,0x76478af6}},	//   רקס_, _lhaa_, _sümü, najy,
   {{0xada5013d,0x6d4a1e95,0x09d50033,0x7c298af7}},	//   тайл, gsfa, _সুনা, tcer,
   {{0xeb991011,0x3ce90660,0x27e90231,0x76470169}},	//   дии_, čavo_, _oxan_, hajy,
   {{0xb87b025b,0x26c1001f,0x248b0063,0x764702a4}},	//   zníc, _olho_, _macm_, kajy,
   {{0x2909025e,0x68f68af8,0x7c290a5f,0xe45f02c3}},	//   _ahaa_, _skyd, scer, _flög_,
   {{0x395e05fe,0x272600f0,0xbbeb0018,0x09e5098a}},	//   guts_, _sôn_, _کرام_, тонн,
   {{0x2d980b0b,0xb87b0618,0x29090134,0x26c10161}},	//   _área_, vníc, _chaa_, _alho_,
   {{0x6a852a72,0xb90a0378,0x773a5566,0x291b00bd}},	//   _алла, _मद_, ьянс_, _diqa_,
   {{0xb87b0074,0x395e3f40,0x8afd00b6,0x29090634}},	//   tníc, buts_, ktři, _ehaa_,
   {{0xe6438af9,0x26c10220,0x68e40113,0x395e0d71}},	//   респ, _dlho_, _tjid, cuts_,
   {{0xb87b025b,0x27260019,0x29090294,0x98bf00ae}},	//   rníc, _tôn_, _ghaa_, rstă_,
   {{0x46ea0978,0xb87b0146,0x7bc98afa,0x93590879}},	// [91c0] _один_, sníc, nzeu, ерху_,
   {{0x63a40432,0xa563001c,0xb87b0a7f,0xe80100a4}},	//   rxin, دگین, pníc, ोधरा_,
   {{0x26d80517,0x672400c2,0xe45f0364,0x00000000}},	//   miro_, _huij, _blöd_, --,
   {{0x26d80283,0x6d4a0429,0x67248afb,0x63b6007b}},	//   liro_, vsfa, _kuij, pyyn,
   {{0xc0a908ba,0x6f1a00d7,0x22438afc,0x00000000}},	//   عامل_, _pitc, _fejk_, --,
   {{0x26d8023f,0x6d580146,0x248077df,0x6d4a03bd}},	//   niro_, trva, leim_, tsfa,
   {{0x71a3007e,0x7cfe0052,0x67247d2d,0x6eb30354}},	//   _карз, sërm, _luij, _अवरु,
   {{0x7cfe00dd,0x26d80193,0x67240090,0x76470193}},	//   përm, hiro_, _ouij, zajy,
   {{0xc4d300a1,0x26d801e2,0x2004005f,0x6f1a01af}},	//   יגה_, kiro_, _uzmi_, _titc,
   {{0xbe850602,0x395e8afd,0x24807f26,0x69c802e2}},	//   _مجمو, tuts_, heim_, tzde,
   {{0x24808afe,0x26d88aff,0x02b7006e,0x6aba042c}},	//   keim_, diro_, דליך_, rktf,
   {{0x26d88b00,0x98bf0138,0x395e8b01,0x6fb80469}},	//   eiro_, kstą_, ruts_, ्नपू,
   {{0x26d80d5a,0x26c101fa,0x6724029a,0x2bd90eeb}},	//   firo_, _plho_, _cuij, _बेपा,
   {{0x26d8741c,0xbc1b00a1,0x672401cb,0x7cfe0216}},	//   giro_, _חודש, _duij, kërk,
   {{0xa5f88b02,0x4a7b021e,0x29090113,0x764705bd}},	//   веру_, _חרוב, _thaa_, rajy,
   {{0x851b06c0,0xba1700ca,0x5454004d,0x27e90062}},	//   _ụgbọ_, _בחוץ_, ивст, _txan_,
   {{0xc2992e9e,0x26d88b03,0xb7d90781,0xae2202d5}},	// [91d0] нках_, biro_, _سودا_, मशान_,
   {{0x26d8023f,0x78bd8b04,0x7583010d,0xa49b01b5}},	//   ciro_, lksv, _پیرم, _mhòi,
   {{0x7bc902c3,0x61fc030a,0x67240381,0x926800e5}},	//   zzeu, _cyrl, _zuij, ърта_,
   {{0x61fc8b05,0x78bd01cb,0x00000000,0x00000000}},	//   _dyrl, nksv, --, --,
   {{0xb9ff018b,0x78bd0ab2,0x8afd00b6,0x8fc707e8}},	//   _उर्फ_, iksv, stři, خزان,
   {{0x62341fdb,0x7e63023e,0xc695006e,0x0e640120}},	//   _веру, ugnp, ראַ_, икін,
   {{0x51842d8c,0x72d40f80,0xa49b009c,0x00000000}},	//   _кута, _торф, _phòh, --,
   {{0xa49b0441,0x7d760037,0x7bc94700,0x78bd01cb}},	//   _bhòi, امير_, tzeu, jksv,
   {{0x26d88b06,0x2b1500d6,0xa49b01b5,0xec76013f}},	//   yiro_, льор, _chòi, упы_,
   {{0x7bc901bf,0xa49b0441,0x2b5f0188,0x672480b5}},	//   rzeu, _dhòi, ruuc_, _ruij,
   {{0xdd9101f9,0x186a1110,0x26d88b07,0x7bc93e99}},	//   _دوا_, нани_, viro_, szeu,
   {{0x26d88b08,0x25f700c3,0xa49b01ec,0x00000000}},	//   wiro_, _एड़ी_, _fhòi, --,
   {{0x1cb800bf,0x26d88b09,0x7c3b1aa3,0x672466eb}},	//   _جالب_, tiro_, mbur, _quij,
   {{0x7c3b8b0a,0x67240381,0xcb6603bf,0x00000000}},	//   lbur, _vuij, _саше_, --,
   {{0x649a00b8,0x26d80ab1,0xd94200d3,0x386901b9}},	//   нтар_, riro_, _лещи, _fcar_,
   {{0x77863b4c,0xa7d60602,0x26d88b0b,0xe45f0212}},	//   _близ, _متخص, siro_, _smör_,
   {{0x7c3b8b0c,0xe29a0396,0x03a3311c,0x78ad00b6}},	// [91e0] ibur, наа_, бито, žová,
   {{0x21a6090f,0x764518f0,0x6d4101ee,0x7cfe0216}},	//   лизм, _gehy, _owla, tërk,
   {{0x25a50003,0x3aba00c1,0x28a81179,0x00000000}},	//   ällt_, עמענ, गापि, --,
   {{0x64a64f31,0x705601c3,0x00000000,0x00000000}},	//   _сама, انشا, --, --,
   {{0x7c3b8b0d,0x6d411503,0x00000000,0x00000000}},	//   dbur, _awla, --, --,
   {{0x7cfe0052,0x64468b0e,0x3ce6052f,0x4422080e}},	//   mëri, _heki, _sjov_, _hgk_,
   {{0x64468b0f,0x44220085,0x628e00f9,0x3cff0063}},	//   _keki, _kgk_, _iabo, fluv_,
   {{0x7c3b0129,0x628e8b10,0x64468b11,0x4422061d}},	//   gbur, _habo, _jeki, _jgk_,
   {{0x628e8b12,0x28a82373,0x7cfe023b,0xe0d5007b}},	//   _kabo, गानि, nëri, _тюрь,
   {{0x49741211,0x628e8b13,0x38698b14,0x7c3b3787}},	//   алос, _jabo, _scar_, abur,
   {{0x628e35fe,0x6d4102ad,0x6f1d0036,0xe9f90023}},	//   _mabo, _gwla, _èsca, _đả_,
   {{0x7cfe00dd,0x44228b15,0x628e411b,0x7c3b0491}},	//   këri, _ngk_, _labo, cbur,
   {{0x7c228b16,0x78bd8b17,0xcc120174,0x7cfe023b}},	//   _igor, rksv, _kọmị, jëri,
   {{0x442d0d1b,0x628e3f70,0x44228b18,0x00000000}},	//   _że_, _nabo, _agk_, --,
   {{0x644626f1,0x05bb0018,0x44228b19,0x00000000}},	//   _beki, ردست_, _bgk_, --,
   {{0x64468b1a,0x628e3109,0x44220167,0x7c2202a1}},	//   _ceki, _aabo, _cgk_, _jgor,
   {{0x628e8b1b,0x7c220350,0xd25b8b1c,0x7d0009a1}},	// [91f0] _babo, _mgor, еце_, ilms,
   {{0x628e0d5a,0xf8bf030b,0x25a50149,0x7c3b7fdb}},	//   _cabo, lké_, älls_, zbur,
   {{0xb87b00e3,0x628e8b1d,0x7c3b575e,0x7bdc020e}},	//   nnío, _dabo, ybur, ğruy,
   {{0xf8bf680d,0x7c228b1e,0x38bb023b,0x64467ad2}},	//   nké_, _ngor, _bëri_, _geki,
   {{0x8fa5433f,0xb87b0037,0x628e4393,0x0ed9007f}},	//   рале, hnío, _fabo, _भगदड,
   {{0x7c221381,0x8d550467,0x628e8b1f,0xf8bf53bc}},	//   _agor, атич, _gabo, hké_,
   {{0x56b800c1,0x38bb0052,0x64468b20,0x00000000}},	//   רפון_, _tërh_, _yeki, --,
   {{0x628e0106,0x50b91f88,0xa3e900bc,0xa92700d2}},	//   _zabo, _आविष, _बशा_, _leží,
   {{0x628e55ba,0xf8bf0146,0x7c3b1dbd,0x00000000}},	//   _yabo, dké_, rbur, --,
   {{0x7c3b8b21,0x7c228b22,0x2b4d8b23,0x628e0062}},	//   sbur, _egor, rsec_, _xabo,
   {{0xceb800a5,0xaca30294,0x7c3b084e,0x38bb023b}},	//   _więc_, _agụm, pbur, _zëri_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64468b24,0xfaa54c3e,0xdcfa0138,0xfb850421}},	//   _reki, _вало, _artė, _خدای,
   {{0x64468b25,0x98ab0029,0x41b50e50,0x7c2202dd}},	//   _seki, ībā_, ंहास, _zgor,
   {{0x628e8b26,0xb8cc0081,0xb87b0076,0x2bd91024}},	//   _rabo, _গত_, cnío, _बेता,
   {{0xf8bf582f,0x628e0a75,0xc95200a1,0x7cfe023b}},	//   cké_, _sabo, _ומה_, tëri,
   {{0x628e8b27,0xc2468b28,0x64460233,0x867600d3}},	// [9200] _pabo, инак, _veki, _кынц,
   {{0x64467fc6,0x628e0188,0x29028b29,0x00000000}},	//   _weki, _qabo, llka_, --,
   {{0x64468b2a,0x442208d3,0x35a62a84,0x2902008c}},	//   _teki, _tgk_, _танг, olka_,
   {{0x7cfe01e5,0x628e1ddc,0x2cad003d,0xdfda008f}},	//   përi, _wabo, jjed_, къл_,
   {{0x628e8b2b,0x7cfe00dd,0xddd8030b,0x09e20085}},	//   _tabo, qëri, devš, _पश्य,
   {{0xf8bf00b6,0x7c2253ba,0x62980031,0x00000000}},	//   zké_, _sgor, ôvod, --,
   {{0x91e33e93,0x00000000,0x00000000,0x00000000}},	//   _доре, --, --, --,
   {{0x320a045b,0xcae30033,0x00000000,0x00000000}},	//   _izby_, _নীলফ, --, --,
   {{0xef1a2de0,0x04180081,0xcb670037,0x212d7a8d}},	//   _ама_, ধুরী_, لميه_, _čehi_,
   {{0x657e00d6,0x29028b2c,0x63ab09b5,0x70b601e4}},	//   _opph, elka_, ägni, _अकुल,
   {{0xd90f0979,0x6d602351,0xa92700d4,0x5d860076}},	//   ویت_, ývač, _reží, _خلال,
   {{0x5fdb0285,0x00000000,0x00000000,0x00000000}},	//   _मेडल, --, --, --,
   {{0xdb0202dc,0x69c5007a,0x27ed01e8,0xf8bf057d}},	//   _groß, _ühen, çen_, rké_,
   {{0xf8bf0343,0x2902008a,0x4b7b006e,0x8bd700ca}},	//   ské_, alka_, _סאוו, _דודו_,
   {{0xd5b81456,0xb87b02c6,0x245900d3,0x29028b2d}},	//   аст_, lním, лавь_, blka_,
   {{0x32c400a7,0x98bf182c,0x2d8c0154,0x09330452}},	//   _röya_, ystę_, _msde_, _بروج,
   {{0x5399007b,0x81b40033,0x00000000,0x00000000}},	// [9210] ывая_, _জেল_, --, --,
   {{0xd7fc00ca,0x2d87007f,0x395e01cb,0x7cfe0052}},	//   _בהחל, ywne_, orts_, mëru,
   {{0xa49b01f7,0x21270023,0xdcfa0034,0x00000000}},	//   _bhòt, ênh_, _wstę, --,
   {{0xa49b01ec,0xe0d00037,0x859a00ca,0x00000000}},	//   _chòt, وزن_, _עשרו, --,
   {{0x644d03cf,0xa28300cd,0xcc120294,0x2d8c0042}},	//   maai, _ویرو, _dọkị, _asde_,
   {{0x644d8b2e,0xb87b00b6,0x141a0327,0xddc5004d}},	//   laai, dním, _תושב, йбли,
   {{0xd65800a1,0x29020188,0x63ad044c,0x62858b2f}},	//   ביות_, ylka_, ţină, meho,
   {{0x644d01cb,0x7cfe0216,0xcc8934df,0x00000000}},	//   naai, zërv, убие_, --,
   {{0x1c42055b,0xfd480294,0x7b06003e,0x6f1d0036}},	//   чным, _kemị, rðun, _èsco,
   {{0x62853135,0x2cad0268,0x2cbf8b30,0x61330090}},	//   neho, sjed_, skud_, _eħle,
   {{0x66c20031,0x22470206,0x00000000,0x00000000}},	//   _dôkl, ónky_, --, --,
   {{0xe73a1369,0x7c84108f,0x3ff9006e,0x9f400052}},	//   лем_, _муче, ָפֿע, çiç_,
   {{0xeaae3457,0x8ca400a5,0x395e1044,0x62858b31}},	//   _ей_, कारो, arts_, keho,
   {{0x6285067d,0x6b898b32,0x00000000,0x00000000}},	//   jeho, mweg, --, --,
   {{0x80b800c7,0x628501c5,0x6aa3876e,0xceb200a1}},	//   _আগস্, deho, _innf, הים_,
   {{0x70b6000f,0x644d0b52,0x6b89007f,0x00000000}},	//   _अकेल, gaai, oweg, --,
   {{0x03a313cb,0x6b898b33,0x78a406a3,0x3fe20081}},	// [9220] пито, nweg, _iniv, _বর্ষ,
   {{0x62851393,0xa49b05aa,0x4900030b,0xa3e90285}},	//   geho, _akòd, रतको_, _बशर_,
   {{0x657e5028,0x78a40bab,0xccf90034,0xd9fc0d2a}},	//   _upph, _kniv, koś_, ɓaɓɓ,
   {{0x764e0517,0x6b893683,0x00000000,0x00000000}},	//   laby, kweg, --, --,
   {{0x5fd2007a,0x4432007f,0xbef500a4,0x00000000}},	//   _देखल, mcy_, ेतून_, --,
   {{0x66fa0bd9,0xdfa500e3,0x764e6d01,0xb87b00b6}},	//   ृतिक_, تحمي, naby, vním,
   {{0x171b0130,0x67dc01d3,0x3f8d020a,0x78a40383}},	//   נוצע, lājī, _eseu_, _oniv,
   {{0x6cd439d9,0x44320054,0xccf90034,0xb87b00b6}},	//   تقبا, ncy_, goś_, tním,
   {{0xe81a269c,0x60c21088,0x39ae0092,0x28cc0d77}},	//   नेमा_, mkom, məsi_, ासनि,
   {{0x60c20b97,0x39ae0092,0x644d029a,0xb87b02c6}},	//   lkom, ləsi_, zaai, rním,
   {{0x69c500aa,0x60c26615,0xb87b0094,0xdc3c0a7f}},	//   _ühel, okom, sním, láčk,
   {{0x23608b34,0x66cb01e8,0x26da8b35,0x48ab3c1a}},	//   krij_, _müke, _ampo_, утом_,
   {{0xb87b025b,0x02fa3ffc,0x62858b36,0x7ebd00b3}},	//   lník, ्ताह_, yeho, _sèpi,
   {{0x39ae0092,0x644d1cab,0x98bf00c6,0x224a01ff}},	//   həsi_, waai, putį_, _nebk_,
   {{0x60c28b37,0xb87b0220,0x7afa5389,0xd6d81f02}},	//   kkom, nník, mott, стя_,
   {{0x60c28b38,0xf98f00e3,0x26da0172,0x59de049d}},	//   jkom, _أبو_, _empo_, _फेयर,
   {{0x60c202fe,0x764e8b39,0x644d39b2,0x7cfe023b}},	// [9230] dkom, baby, raai, qëru,
   {{0x7afa0423,0x32553006,0xa49b01f7,0x80b80033}},	//   nott, івер, _chòr, _আগষ্,
   {{0x39ae00a7,0x644d8b3a,0xa49b01ec,0x62858b3b}},	//   fəsi_, paai, _dhòr, reho,
   {{0x60c20256,0x212a0091,0xb87b025b,0x7afa8b3c}},	//   gkom, _dubh_, dník, hott,
   {{0x7afa3b57,0x68ed0051,0x62858b3d,0x212a01b9}},	//   kott, _mjad, peho, _eubh_,
   {{0x24ab0081,0x60c28b3e,0xad59110c,0xa49b01f7}},	//   _ঐতিহ, akom, арих_, _ghòr,
   {{0x7afa8b3f,0x39ae0092,0x68ed8b40,0xb6bc0266}},	//   dott, bəsi_, _ojad, רצוי,
   {{0x6b898b41,0x39ae00a7,0x60c28b42,0xa0c50568}},	//   tweg, cəsi_, ckom, _بيرو,
   {{0x6b89029a,0x7afa0036,0xb87b02c6,0x63ad8b43}},	//   uweg, fott, mníh, nxan,
   {{0xb87b0579,0x63ad33fe,0x78b6037a,0x68ed8b44}},	//   bník, ixan, _soyv, _ajad,
   {{0x6b8901bf,0xb87b0094,0xfc330281,0x7cfe0216}},	//   sweg, cník, _فحش_, tërt,
   {{0xb87b02c6,0xb4e800aa,0x00000000,0x00000000}},	//   nníh, _बदे_, --, --,
   {{0x764e8b45,0x68ed060f,0x60c94d61,0x60db06b0}},	//   taby, _djad, _mlem, _mmum,
   {{0x443200a5,0x7afa8b46,0x272f026a,0x236001c0}},	//   wcy_, cott, _dün_, vrij_,
   {{0x60c91e07,0x764e8b47,0x7cfe00dd,0x60db8b48}},	//   _olem, raby, përt, _omum,
   {{0x78a48b49,0x764e0ab1,0xa3ea0396,0x25a50212}},	//   _univ, saby, адба_, ålla_,
   {{0x272f06d7,0xb87b0074,0x29124051,0x29000239}},	// [9240] _gün_, zník, _ihya_, _ikia_,
   {{0x443200a5,0xdc3c2347,0x60db8b4a,0x59de1cff}},	//   scy_, váčk, _amum, _फेडर,
   {{0x60c21183,0x39ae0092,0x60c98b4b,0xa50a0077}},	//   tkom, təsi_, _blem, _вена_,
   {{0xb87b0074,0x7afa0018,0x6fdb0789,0x03a61110}},	//   vník, zott, _मेहं, _димо,
   {{0x39ae0092,0x2bd92f74,0x888d00c1,0x60c90113}},	//   rəsi_, _बेला, טראַ, _dlem,
   {{0xb87b025b,0x60c28b4c,0x66cb8b4d,0x60db0129}},	//   tník, skom, _tüke, _emum,
   {{0x7afa6271,0x60c98b4e,0xb87b00b6,0x7cfe023b}},	//   vott, _flem, bníh, dërr,
   {{0x41278b4f,0x60c91484,0xb87b0244,0xa0670114}},	//   _фото_, _glem, rník, _маса_,
   {{0x7afa0068,0x2aaa121c,0x8e762787,0xb87b0146}},	//   tott, атно_, _мужч, sník,
   {{0x7cfe00dd,0xb87b0094,0x66d10065,0x00000000}},	//   tërs, pník, _mókù, --,
   {{0x7afa8b50,0xe89500d3,0xd8f9004d,0x60c9007b}},	//   rott, пань, йної_, _ylem,
   {{0x7afa8b51,0x2d9e554a,0xb87b02c6,0x63ad013c}},	//   sott, _irte_, diíc, yxan,
   {{0xdb2400aa,0xdc290037,0xc0530eda,0x00000000}},	//   öpäe, _اسمه_, וזר_, --,
   {{0x6b820036,0xe20a02d5,0x7cfe0052,0x212401b9}},	//   _ipog, _वरूण_, përs, _limh_,
   {{0x2ebc0081,0x344b64a7,0x7bc01373,0x00000000}},	//   _অগাষ, ичан_, lymu, --,
   {{0x63ad8b52,0x70b9007a,0x68ed417b,0x673d00f3}},	//   txan, _आवेल, _ujad, ppsj,
   {{0xb87b030b,0x68fd023b,0x6b820090,0x291900b3}},	// [9250] vníh, mosd, _jpog, mmsa_,
   {{0x63ad8b53,0x212401b9,0x2d9e0364,0x290001ff}},	//   rxan, _aimh_, _orte_, _zkia_,
   {{0x672d023b,0xb87b00b6,0x59ca0d61,0x662802c6}},	//   _huaj, tníh, ानिर, ňské,
   {{0x397b00c1,0x7bc00138,0x672d0dbe,0x6ab801df}},	//   שטאנ, kymu, _kuaj, _lovf,
   {{0x2d9e8b54,0x6d48008a,0xb87b00b6,0x672d0052}},	//   _arte_, _awda, rníh, _juaj,
   {{0x672d00dd,0x2369023e,0x7bc00138,0x24893578}},	//   _muaj, muaj_, dymu, leam_,
   {{0x672d023b,0xf2d200c1,0x2d9e0106,0x2369023e}},	//   _luaj, _װען_, _crte_, luaj_,
   {{0x60db5d5a,0x60c97762,0x62950169,0x24895d94}},	//   _umum, _ulem, _hazo, neam_,
   {{0x62958b55,0x7cfe023b,0x200d01e9,0x672d022b}},	//   _kazo, tërr, _uzei_, _nuaj,
   {{0xdd950fdf,0x3ed500e3,0x62958b56,0x69c5007a}},	//   _назы, _عقار, _jazo, _ühek,
   {{0x62958b57,0x23690197,0x672d0239,0xa9a537fa}},	//   _mazo, huaj_, _auaj, чинд,
   {{0x62958b58,0x68fd0623,0x7f49019f,0x7bc00381}},	//   _lazo, gosd, _kweq, bymu,
   {{0x24898b59,0x672d00e1,0x3a27024a,0x00000000}},	//   deam_, _cuaj, _tgnp_, --,
   {{0x672d0052,0x6b9b05bd,0x291901ec,0x00000000}},	//   _duaj, mvug, amsa_, --,
   {{0x7f490415,0xe5a30508,0x00000000,0x00000000}},	//   _lweq, нири, --, --,
   {{0x01c300c7,0x5fbd063c,0x6fbd0980,0xb87b02c6}},	//   ্পাদ, ्नाल, ्नां, riíc,
   {{0x62958b5a,0x672d8310,0x87b90086,0xe45f0212}},	// [9260] _bazo, _guaj, _дуэт_, _glöm_,
   {{0x479b0054,0x62950143,0xdce3077e,0x179b021e}},	//   _פייס, _cazo, dunč, _פייב,
   {{0x69c18b5b,0xe9f900de,0xdcf40559,0x7bc0007f}},	//   nyle, _đẻ_, _šači, zymu,
   {{0xa06a3d78,0x7ae18b5c,0x24898b5d,0xf8cc097c}},	//   сада_, hilt, ceam_, ासिय,
   {{0x7ae18b5e,0x64448b5f,0xdce302c6,0x00000000}},	//   kilt, mbii, stně, --,
   {{0x62958b60,0x877b0266,0x69c11842,0x7ae1007b}},	//   _gazo, מאני, kyle, jilt,
   {{0x28af06ed,0x6b828b61,0x51552046,0x7ebd0428}},	//   टामि, _spog, _отту, _rèpt,
   {{0x21248b62,0x2d9e1197,0x66cb0092,0x7bc00138}},	//   _uimh_, _vrte_, _müka, tymu,
   {{0xfc3f0fb6,0x62958b63,0x66cb00bc,0x7ebd00b3}},	//   ñía_, _yazo, _lüka, _pèpt,
   {{0x7ae18b64,0x7f3b00a1,0x672d00dd,0x6b82033b}},	//   gilt, _לעמו, _ruaj, _vpog,
   {{0x2d9e02a7,0x68fd8b65,0x7aef0072,0x6b9b010a}},	//   _urte_, tosd, écta, avug,
   {{0x2ca63d82,0xab5d0034,0x7bfd00fe,0x05000033}},	//   _unod_, wyże, ợtốt_, ্দুর_,
   {{0x7ae158b0,0xfaa64564,0x672d00dd,0x8c435e66}},	//   bilt, _надо, _quaj, _чече,
   {{0x0ebe09d0,0x672d023b,0x96eb49b7,0x8c1b00ca}},	//   ्सिड, _vuaj, сьма_, _הודי,
   {{0x24898b66,0x672503cf,0x8b0300d2,0x00000000}},	//   team_, _vihj, ářej, --,
   {{0x23698b67,0x672d00dd,0xb9250037,0x66cb013c}},	//   tuaj_, _tuaj, _تفعي, _düka,
   {{0x62958b68,0x24898b69,0xa3f40565,0x7d020a4b}},	// [9270] _pazo, ream_, епті, _mkos,
   {{0x929400ae,0xab61026a,0x9736006e,0x23690216}},	//   науц, _şüke, _קרתא_, ruaj_,
   {{0x64440517,0x7d020103,0x62958b6a,0x75260634}},	//   bbii, _okos, _vazo, _fikz,
   {{0xc5f2004f,0x2ec51c0a,0x7ae106a3,0x046700c2}},	//   _ידי_, वस्त, zilt, _этом,
   {{0x629501af,0x635e00ae,0x644f01d3,0x041b0033}},	//   _tazo, tănţ, _ieci, _ফ্রী_,
   {{0x7d028b6b,0xc33200c1,0xde0502e1,0xc7d800ca}},	//   _akos, _בוך_, мпли, הודי_,
   {{0x644f2c09,0x7ae147ff,0xd164008f,0x693a02a1}},	//   _keci, vilt, _пъти, _jċed,
   {{0xa2d90179,0x645a00e8,0x69c100d4,0x6b9b00bc}},	//   फोर्, _ētik, vyle, tvug,
   {{0x644f42ad,0x7ae18b6c,0xeb99246b,0x3af5004d}},	//   _meci, tilt, цип_, дянс,
   {{0x644f8b6d,0x2d9c010a,0x637f044c,0x00000000}},	//   _leci, bvve_, mână, --,
   {{0x7ae18b6e,0x44390076,0xa88a8b6f,0x442b00fc}},	//   rilt, _ofs_, ойна_, _ogc_,
   {{0xa3ad030b,0x7ae18b70,0x66d028b4,0xf1b20142}},	//   कमा_, silt, _mäke, דסט_,
   {{0xb8e60bf5,0x66d00149,0x7d098b71,0x7d1b8b72}},	//   _एव_, _läke, mles, mmus,
   {{0x7d090fda,0x645d11bc,0x644f8b73,0x6908002b}},	//   lles, _adsi, _aeci, iñei,
   {{0xcb120054,0x644f00cd,0x66d00084,0x75260381}},	//   _שלו_, _beci, _näke, _pikz,
   {{0xe8f60037,0x65610103,0x442b8b74,0xf50a021a}},	//   _تستخ, álha, _cgc_, інал_,
   {{0x7d098b75,0x073a00e3,0x443901ee,0x64448b76}},	// [9280] iles, _بسبب_, _dfs_, rbii,
   {{0x244c0019,0x7d098b77,0x05000033,0x7d1b8b78}},	//   ếm_, hles, ্দের_, hmus,
   {{0x273402fd,0x63a903e5,0x644f8b79,0xb87b05b4}},	//   _hän_, _ġene, _feci, rnív,
   {{0x7d090018,0x644f8b7a,0x7bcd01d3,0x7c2b00d1}},	//   jles, _geci, _ļaun, _nggr,
   {{0x2d85022b,0x7d1b8b7b,0x7ebd0113,0x7d094f2d}},	//   _aple_, dmus, _rèpr, dles,
   {{0x27340222,0xbea30752,0x44390381,0x644f2562}},	//   _män_, качк, _zfs_, _zeci,
   {{0x27340149,0x7d098b7c,0x3d0a0096,0x00000000}},	//   _län_, fles, ातले_, --,
   {{0x1ee800fb,0x9972030b,0x00000000,0x00000000}},	//   _کوئی_, těže_, --, --,
   {{0x2d858b7d,0x00000000,0x00000000,0x00000000}},	//   _eple_, --, --, --,
   {{0x7d1b7260,0x80da136b,0x00000000,0x00000000}},	//   amus, पोरे, --, --,
   {{0x7c3900f0,0x00000000,0x00000000,0x00000000}},	//   _ffwr, --, --, --,
   {{0x7d098b7e,0x2bd9018b,0x6d584012,0x7d020051}},	//   cles, _बेका, msva, _ukos,
   {{0xad1b0130,0x644f8b7f,0x6d581d46,0xb33b001f}},	//   _וואר, _reci, lsva, _orça,
   {{0x644f8b80,0x44390de9,0xdce300e8,0x98bf0233}},	//   _seci, _sfs_, munā, rttı_,
   {{0x6d582bc3,0x442b2008,0x45d5117c,0x00000000}},	//   nsva, _pgc_, ховс, --,
   {{0xc983002d,0x66d002c3,0x00000000,0x00000000}},	//   _руши, _räke, --, --,
   {{0x66d0070a,0xbf0e2fbd,0xe315001f,0x442b0381}},	// [9290] _säke, िताभ_, емањ, _vgc_,
   {{0xd2510391,0x671607e2,0x6d588b81,0x442b037a}},	//   انا_, _दीपक_, ksva, _wgc_,
   {{0x7d008b82,0x443902e5,0x644f8b83,0x7d098b84}},	//   koms, _tfs_, _teci, yles,
   {{0x90150426,0x645d052f,0x6d583813,0x7d000031}},	//   нфлі, _udsi, dsva, joms,
   {{0x8e853574,0xe8d80341,0x6d5a3135,0x7d098b85}},	//   егле, וואר_, _avta, vles,
   {{0x2bd9009f,0x7a310103,0x6d5801cd,0x00000000}},	//   _बेगा, _műté, fsva, --,
   {{0xdce807d1,0x7d098b86,0x6d588b87,0x7d0018f0}},	//   _ardı, tles, gsva, foms,
   {{0x9f510018,0x6aaa00f0,0xcf7b0037,0x7d0945f9}},	//   ából_, _anff, _وإذا_, ules,
   {{0x7d098b88,0x76550034,0x6d5a0141,0x443e00a7}},	//   rles, kazy, _evta, _ət_,
   {{0xeab10080,0x39452983,0xaad900a5,0x76550094}},	//   اعة_, нног, योंक, jazy,
   {{0x7d1b13ea,0x88e60ff7,0x00000000,0x00000000}},	//   pmus, ежне, --, --,
   {{0x6d4300bd,0x27340154,0x32e60139,0xe0bd0033}},	//   mpna, _pän_, _kíyè_, _আগুন,
   {{0xbbeb01c3,0x6d4329ae,0xa3de0179,0x00000000}},	//   _برام_, lpna, _थें_, --,
   {{0x27340149,0x76550034,0x290b015c,0x8afd00d2}},	//   _vän_, gazy, alca_, kuři,
   {{0x2cbd8b89,0x2499020a,0x48e60b36,0x00000000}},	//   _kowd_, _basm_, _покв, --,
   {{0x05000081,0x942600d3,0x7a310103,0x2734007b}},	//   ্দ্র_, ембе, _fűté, _tän_,
   {{0x3860006b,0x29028b8a,0xb87b0844,0x2cbd1b7b}},	// [92a0] _idir_, moka_, rnít, _mowd_,
   {{0x29028b8b,0x68e68b8c,0xe2971669,0x63061673}},	//   loka_, likd, нау_, روال,
   {{0xa3bc0b94,0xdcff00b6,0x7d002d76,0x00000000}},	//   _अथक_, ívěs, yoms, --,
   {{0x25a5052f,0x26150cce,0x26ca0063,0x6d580f05}},	//   ælle_, _धरती_, lkbo_, vsva,
   {{0x656e8b8d,0x64568b8e,0x7053001c,0xdee6007e}},	//   lubh, mayi, انها, ноди,
   {{0x64565dc8,0x6d588b8f,0x29020193,0x66cb0233}},	//   layi, tsva, hoka_, _nükl,
   {{0x29020517,0xe9f900de,0x6d58007b,0x00000000}},	//   koka_, _đế_, usva, --,
   {{0x6d581842,0x64568b90,0x24800131,0xdd8e0018}},	//   rsva, nayi, nfim_, لوڈ_,
   {{0x29028b91,0x1e8676c3,0x7d008b92,0x68e600a7}},	//   doka_, _плам, roms, dikd,
   {{0x64560060,0x656e0201,0xdce300d9,0x2fc6023e}},	//   hayi, kubh, runā, myog_,
   {{0xfbcf12eb,0x29028b93,0x28f925a9,0xdca600d3}},	//   لتی_, foka_, день_, _пажи,
   {{0x3860009c,0x29028b94,0x23c70032,0x00000000}},	//   _cdir_, goka_, _jíjú_, --,
   {{0x24990063,0x64568b95,0xe78400ae,0x3ebe00bc}},	//   _rasm_, dayi, луро, _kott_,
   {{0x38600253,0x3ebe8b96,0xa49b0139,0xdb06007b}},	//   _edir_, _jott_, _ekòl, ämäk,
   {{0x29028b97,0x3a3700c1,0x3eac0167,0x76558b98}},	//   boka_, _ארום_, _mndt_, razy,
   {{0x3ebe12c7,0x64563f3e,0xade3007a,0x29020027}},	//   _lott_, gayi, _कइसन_, coka_,
   {{0x66cb008e,0xc2992d7b,0x78ad0051,0x3eac052f}},	// [92b0] _yükl, мках_, _inav, _ondt_,
   {{0x3ebe007e,0x00000000,0x00000000,0x00000000}},	//   _nott_, --, --, --,
   {{0x64566ccb,0xa5f9032d,0x999e00c6,0x6d5e00c4}},	//   bayi, _цену_, matų_, špaj,
   {{0x64560a60,0x00000000,0x00000000,0x00000000}},	//   cayi, --, --, --,
   {{0x23c70830,0x3ebe8b99,0x78ad8b9a,0x00000000}},	//   _díjú_, _bott_, _mnav, --,
   {{0x29028b9b,0xdb020f5a,0xaca70103,0x66d002c3}},	//   zoka_, _droë, کھئے_, _käka,
   {{0x3ebe00e5,0x29022964,0x2bd917ff,0x78ad00ee}},	//   _dott_, yoka_, _बेजा, _onav,
   {{0x2fc60009,0x6b8400ae,0x3eac00f2,0x78ad06b0}},	//   byog_, _ţiga, _endt_, _nnav,
   {{0x66d00222,0x98a800d3,0x29028b9c,0x657c0094}},	//   _läka, _lună_, voka_, ztrh,
   {{0x3ebe8b9d,0x78ad8b9e,0x23690335,0x64568b9f}},	//   _gott_, _anav, iraj_, zayi,
   {{0x29028ba0,0xdd9105bc,0x186a1107,0x64568ba1}},	//   toka_, _خوا_, мани_, yayi,
   {{0x48e607f3,0x6f03524f,0x2369181b,0x6d410090}},	//   томв, lonc, kraj_, _itla,
   {{0x290219d0,0x2bd90251,0xda0d0f42,0x5bc40cd2}},	//   roka_, _बेचा, _हरकत_, _متوف,
   {{0x6f038ba2,0x8a051510,0x98a800d3,0xdce300ae}},	//   nonc, _изле, _bună_, bună,
   {{0x64568ba3,0x29028ba4,0xceb20266,0xa50a35c1}},	//   tayi, poka_, סיל_, дева_,
   {{0x320a1672,0x7c3b0707,0xdb020113,0x78ad02b6}},	//   _ryby_, ncur, _aroè, _gnav,
   {{0x6f03109b,0x64568ba5,0xa5075db8,0x68e48ba6}},	// [92c0] konc, rayi, тета_, _imid,
   {{0x64568ba7,0x69c500aa,0x2fc6023e,0x6d411577}},	//   sayi, _ühes, vyog_, _otla,
   {{0x6d41009e,0x64568ba8,0x3ebe8ba9,0x00000000}},	//   _ntla, payi, _rott_, --,
   {{0x3ebe8baa,0x00e6008f,0x64568bab,0x4fea00ce}},	//   _sott_, ъжен, qayi, ммен_,
   {{0x6f030257,0x6d418bac,0x3ebe8bad,0xe9f900fe}},	//   fonc, _atla, _pott_, _đẽ_,
   {{0x1ee6001c,0xdb026808,0x32430131,0x00000000}},	//   ضوعی_, _groè, _верг, --,
   {{0x180f02e8,0x68e48bae,0x2fc6022e,0x693a009e}},	//   _सर्व_, _omid, syog_, _oċea,
   {{0x629c43b5,0xc5f300ca,0x7d1900eb,0xdb9802f3}},	//   _haro, ידו_, _chws, евич_,
   {{0x629c8baf,0xcb670cb8,0x4f2600c6,0x09ca0c3c}},	//   _karo, вање_, _адаб, ान्य,
   {{0x60c08bb0,0x629c2f29,0x629e8bb1,0x78ad030d}},	//   _homm, _jaro, ndpo, _snav,
   {{0x629c8a70,0xddc800a5,0xae1e00b7,0x00000000}},	//   _maro, _wedł, येशन_, --,
   {{0x629c00a6,0xcfa90018,0x779300cd,0x7ae3039f}},	//   _laro, _تاہم_, لیبا, _emnt,
   {{0x98a8020a,0x60c08bb2,0x00000000,0x00000000}},	//   _sună_, _momm, --, --,
   {{0x60c04a9b,0x68e48bb3,0x98a800ae,0x23698bb4}},	//   _lomm, _emid, _pună_, vraj_,
   {{0xd6d802ec,0xe5c414da,0xe80f00b7,0xa4d5004d}},	//   ття_, асто, _सरका_, гові,
   {{0x60c08bb5,0x78ad0a4b,0x23698bb6,0x4aa602d5}},	//   _nomm, _unav, traj_, _कोतव,
   {{0x629c7cb9,0x7b3200a5,0x69c88bb7,0x63a6191d}},	// [92d0] _baro, _dług, lyde, _crkn,
   {{0x629c6b20,0xade3007a,0xfde3007a,0x00000000}},	//   _caro, _कइलन_, _कइलस_, --,
   {{0x69da8bb8,0x6f0300c4,0x60c08bb9,0x66cb00aa}},	//   nzte, vonc, _bomm, _lükk,
   {{0x60c01ef7,0x69da0634,0x63a600c4,0x629e0381}},	//   _comm, izte, _frkn, adpo,
   {{0x6f0314e2,0x60c0538d,0x26c10146,0x6d41472a}},	//   tonc, _domm, _koho_, _stla,
   {{0x629c8bba,0x60c000a4,0x26c10350,0x69c80537}},	//   _garo, _eomm, _joho_, kyde,
   {{0x26c100d1,0xf0750018,0x60c000bd,0xfce51628}},	//   _moho_, _میاں_, _fomm, локо,
   {{0x60c08bbb,0x29090134,0x7c3b0131,0x6d4100d8}},	//   _gomm, _nkaa_, ucur, _vtla,
   {{0x7c3b0012,0x629c8bbc,0xa49b0032,0x6f031405}},	//   rcur, _yaro, _akòk, ponc,
   {{0x68e48bbd,0x2909418c,0xa3bb0006,0x66cb026a}},	//   _smid, _akaa_, _अपन_, _dükk,
   {{0xaad91827,0x59ca0d88,0x6d418bbe,0x212d0113}},	//   योगक, ानगर, _utla, _kieh_,
   {{0xf74623bf,0x6fa7049d,0xe9a60d83,0x00000000}},	//   лемо, चिपू, اگون_, --,
   {{0x6b658bbf,0x2d0f02e8,0x7b060088,0x4b7900c1}},	//   _скла, ातील_, rður, _נאַו,
   {{0x7ae3019f,0x69c802b6,0x61330090,0x5a4708a1}},	//   _umnt, byde, _eħli, _рэда,
   {{0x629c2733,0x63a600e7,0x98b900e8,0x00000000}},	//   _raro, _srkn, ūrā_, --,
   {{0x68e48bc0,0x97c61363,0x212d02e7,0x629c8bc1}},	//   _umid, _مقبو, _nieh_, _saro,
   {{0x60c08bc2,0xdd030138,0x93468bc3,0x3ce509a1}},	// [92e0] _romm, ūrėj, унзе, जोये_,
   {{0x629c8bc4,0x20f80206,0x00000000,0x00000000}},	//   _qaro, dčia_, --, --,
   {{0x629c8bc5,0x60c08bc6,0x20f80138,0x2caf3062}},	//   _varo, _pomm, ečia_, _ongd_,
   {{0xa09a0037,0x629c8bc7,0x48b20033,0xd12f450f}},	//   عضاء_, _waro, _চতুর, سمه_,
   {{0x629c1114,0x44240013,0x69c80034,0x69da034f}},	//   _taro, _àm_, zyde, zzte,
   {{0x629c81aa,0x69c800c2,0x63a48bc8,0xf8bf00fd}},	//   _uaro, yyde, mvin, mmée_,
   {{0x60c05ab2,0x57d000b6,0xf8bf014b,0x00000000}},	//   _tomm, हनुह, lmée_, --,
   {{0x7ae88bc9,0xbd873345,0x69c88bca,0x63a42427}},	//   widt, انين_, vyde, ovin,
   {{0x63a48bcb,0x66d00222,0x8fa30a71,0x4fa34dff}},	//   nvin, _räkn, _лате, _литв,
   {{0x69c809ce,0x69da02dc,0xe45f0084,0xc3330341}},	//   tyde, tzte, _ylös_, זוז_,
   {{0x26c18bcc,0xd2b700a1,0x7c860ac6,0x7ae83229}},	//   _roho_, אלית_, _буле, ridt,
   {{0x8dfb00a1,0xa3e505a7,0x69c88bcd,0x63a40407}},	//   _אהבת, _भइल_, ryde, kvin,
   {{0x69da0068,0x63a40ab2,0x81bc00c7,0xd7f81728}},	//   szte, jvin, েছি_, гур_,
   {{0x3ce6022e,0x99d60241,0x98bf00c6,0x00000000}},	//   _hmov_, _متعا, ystė_, --,
   {{0x58d50084,0x45d40ffa,0x69c500bc,0xdb2301f9}},	//   _войт, борс, _ühep, _órát,
   {{0x290f0037,0x20f80138,0x2bd100a4,0x29090350}},	//   _óga_, yčia_, दैवा, _ukaa_,
   {{0x26c10871,0x395e0b4b,0x63a48bce,0xbec701d3}},	// [92f0] _toho_, lsts_, gvin, ldīš,
   {{0x66d00212,0x212d042c,0x00000000,0x00000000}},	//   _jäkl, _sieh_, --, --,
   {{0x461500bf,0x66d00149,0xb0351339,0x7aef0143}},	//   _خودر, _mäkl, анеш, écti,
   {{0x395e8bcf,0x5f75001c,0x98bf00c6,0x00000000}},	//   ists_, لاتر, rstė_, --,
   {{0x644d8bd0,0xb4c309a0,0x926b19e8,0xda0b00aa}},	//   mbai, ्सी_, _прва_, _सुनत_,
   {{0x395e0029,0x644d8bd1,0xddc51e6d,0xa3de0096}},	//   ksts_, lbai, ибли, _थेट_,
   {{0xfc3100e3,0xbd450076,0x00000000,0x00000000}},	//   يحة_, جنبي, --, --,
   {{0xff1500c7,0x644d0a00,0x628527aa,0x999c0103}},	//   াদেশ_, nbai, lfho, _nevű_,
   {{0x395e0990,0x00000000,0x00000000,0x00000000}},	//   ests_, --, --, --,
   {{0x752f0067,0x644d0332,0x62850076,0xb4d200b7}},	//   _licz, hbai, nfho, _वत्_,
   {{0x63a48bd2,0x6ac5278e,0x395e00e8,0x00000000}},	//   zvin, _लकीर, gsts_, --,
   {{0x63a42cbf,0x752f0034,0xaad900a8,0xd8261d6f}},	//   yvin, _nicz, योजक, идни,
   {{0xb8ee000f,0xa3e5007a,0x26d88bd3,0xdcf40a39}},	//   _शक_, _भेल_, thro_, _šaći,
   {{0x63a402a1,0x20f8042d,0x6285029a,0x5f36006e}},	//   vvin, jčin_, jfho, יטשע_,
   {{0x2d53002d,0x6cec074c,0x09e20161,0x00000000}},	//   nţe_, _जगमग_, _мошн, --,
   {{0x8a1400cd,0x47c6004d,0xa4468bd4,0x628502ac}},	//   _اظها, _вбив, рнад, efho,
   {{0x68fd0103,0x00000000,0x00000000,0x00000000}},	// [9300] érde, --, --, --,
   {{0x55e643d0,0xf8bf00fd,0x0ea406eb,0x3ce90031}},	//   _вооб, rmée_, _गोंड, čavy_,
   {{0x765c8bd5,0x644d64e5,0xddc38bd6,0x00000000}},	//   mary, bbai, vanş, --,
   {{0x64a6298c,0x39a50029,0x4fc64e08,0xb3580068}},	//   _тама, _mēs_, исла, _میرا_,
   {{0x98a6020e,0x00000000,0x00000000,0x00000000}},	//   nslı_, --, --, --,
   {{0x765c48bc,0x5d665ccc,0xfaf90138,0x644c007f}},	//   nary, атиз, irūs_, śnię,
   {{0xdce101e8,0x69c7052f,0x00000000,0x00000000}},	//   _aslı, øjel, --, --,
   {{0x0ca70084,0x656e0a1b,0x765c8bd7,0xc19b0327}},	//   атьи_, irbh, hary, _בשלי,
   {{0x765c8bd8,0x225801a2,0xafe60cba,0x00000000}},	//   kary, _kerk_, _тоал, --,
   {{0x79a62156,0x0f7b0341,0x6e960037,0x765c2459}},	//   арме, _באמב, _خلطا, jary,
   {{0x765c01b3,0x22588bd9,0x20f8013f,0x00000000}},	//   dary, _merk_, nčio_, --,
   {{0x1bea456f,0x395e8bda,0x20f800c6,0x6d4a2a0d}},	//   _идеи_, rsts_, ičio_, mpfa,
   {{0x39498bdb,0xd7fb044b,0x98bf01d3,0x765c00f0}},	//   _čase_, тун_, lstī_, fary,
   {{0x7e781d66,0x20f800c6,0x00000000,0x00000000}},	//   ngvp, kčio_, --, --,
   {{0x7afd0f7d,0x6abc003e,0x00000000,0x00000000}},	//   éste, örfu, --, --,
   {{0x04c900e3,0x693a02a1,0x2ed300a4,0xb4c3206b}},	//   دوري_, _jċem, _थत्त, ्से_,
   {{0x644d8bdc,0x656e0a02,0x765c8bdd,0x94190a95}},	// [9310] rbai, arbh, bary, ужат_,
   {{0xf1a72887,0x644d0013,0xf6993db3,0x82d81894}},	//   ирен, sbai, _свој_, адус_,
   {{0x28cc045f,0x20f80995,0x3ce710e9,0x273d026e}},	//   ासचि, rčin_, _जगले_, _hìn_,
   {{0x62850037,0x273d026e,0x00000000,0x00000000}},	//   sfho, _kìn_, --, --,
   {{0xa3bb05d6,0x4fa51d62,0x273d0032,0xddc1078e}},	//   _अपि_, силв, _jìn_, _belş,
   {{0x4aa6007d,0xaaa64473,0x20180037,0x273d00fe}},	//   _कोलव, _कोलक, جتمع_, _mìn_,
   {{0xad581ad1,0xdb0200da,0x273d0032,0x2c130033}},	//   арых_, _croí, _lìn_, _হলেই_,
   {{0x84f90789,0x20f8025b,0x85f800ca,0xe5f800ca}},	//   ्किट_, nčil_, יצוע_, יזור_,
   {{0x765c620e,0x225800dc,0x6d4a0076,0x861a0154}},	//   yary, _yerk_, apfa, _rapٍ_,
   {{0x9f95007a,0x7b320034,0xbd6b00ae,0x2b5f044c}},	//   _müüa_, _słuc, _арде_, rsuc_,
   {{0x98a643cb,0x39e93126,0x765c8bde,0x2a7c00b3}},	//   бине, удно_, vary, _dcvb_,
   {{0x693a02a1,0x765c8bdf,0x00000000,0x00000000}},	//   _kċej, wary, --, --,
   {{0xfaa501b3,0xdc36006e,0xcb691372,0x20f800d4}},	//   _гало, _האנט_, _сале_, dčil_,
   {{0xe7371994,0x2cbf8be0,0x7d090150,0x3ced80e5}},	//   сер_, ljud_, loes, liev_,
   {{0x765c8be1,0x66d00302,0x2aba00ca,0xd46a2877}},	//   rary, _häkk, _תמצא, ливе_,
   {{0xb4d20d75,0x68210174,0x765c8be2,0xd3ba004d}},	//   वसे_, _ịden, sary, лузі_,
   {{0x765c0113,0x22588be3,0x273d0023,0x00000000}},	// [9320] pary, _perk_, _gìn_, --,
   {{0x66d08be4,0x05080033,0x7d093f24,0x2cbf00bc}},	//   _mäkk, লগের_, hoes, hjud_,
   {{0x22588be5,0x98b90138,0x20f81523,0x72060037}},	//   _verk_, ūrą_, učio_, حوام,
   {{0x225801aa,0x2cbf2f66,0x693a02a1,0x20f8004b}},	//   _werk_, jjud_, _bċej, rčio_,
   {{0x0eea02ec,0x7d098be6,0x20f80138,0x787b00c1}},	//   льки_, does, sčio_, אָוו,
   {{0x52753fea,0xdb020161,0x11d60b2f,0x20f800c4}},	//   _мусу, _proí, _любя, mčim_,
   {{0x2b468be7,0x644300a5,0xddc10103,0xa7fb01ff}},	//   _stoc_, śnie, _belő, mañe,
   {{0xa7fb0072,0x6d4a5530,0xdfbb0139,0x00000000}},	//   lañe, rpfa, _lóṣù_, --,
   {{0x940d01c2,0x00000000,0x00000000,0x00000000}},	//   ɓoɓi_, --, --, --,
   {{0x63ab052f,0x63a94582,0x6d4a05e8,0xfbcf00b9}},	//   ågni, _šenk, ppfa, عتي_,
   {{0x2d988be8,0x7d095441,0xddc101f9,0xb2bb2252}},	//   _ère_, boes, _felő, אמיר,
   {{0x2d9e1197,0x021703c2,0x00000000,0x00000000}},	//   _iste_, מחים_, --, --,
   {{0x61e00092,0x00000000,0x00000000,0x00000000}},	//   _əmla, --, --, --,
   {{0x81de00c7,0xf4000081,0xeaf509f6,0x2eee0063}},	//   _তখন_, ্ধার_, ीकृत_, niff_,
   {{0x2d9e000d,0x9f9500aa,0x45d5176e,0x04675be9}},	//   _jste_, _süüa_, цовс, йтам,
   {{0x2eee8be9,0x00000000,0x00000000,0x00000000}},	//   hiff_, --, --, --,
   {{0x38690044,0x20f800d8,0xe4e40120,0x66cb173c}},	// [9330] _idar_, rčil_, чірн, _süku,
   {{0x8c1b09c1,0x290b44c2,0xa49b0139,0xa7fb0143}},	//   רומי, loca_, _akòt, gañe,
   {{0x399a3df6,0xa2bf2235,0xc0cb03bf,0x00000000}},	//   _jūs_, लॉग्, луде_, --,
   {{0x7e68034f,0x399a01d3,0x301525e7,0x00000000}},	//   _addp, _mūs_, одер, --,
   {{0x491800f5,0x2d9e0a00,0x6d4801d3,0x98b40995}},	//   זקאל_, _aste_, _atda, šeći_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38690022,0x3ced0031,0xe057001c,0x2cf61073}},	//   _odar_, tiev_, _هیات_, ुकूल_,
   {{0x62978bea,0x645f0092,0xddda022b,0x3c2f00a7}},	//   lexo, naqi, _metň, _növü_,
   {{0x2d9e8beb,0x8c6400e3,0x290b0231,0x2eee1e95}},	//   _este_, سطين, doca_, biff_,
   {{0x05ba32c9,0x399a0029,0x38698bec,0xdb028bed}},	//   _उपलब, _būs_, _adar_, _croà,
   {{0xe8fa426c,0x7d098bee,0x29032a4e,0x290b0850}},	//   ило_, poes, čkan_, foca_,
   {{0x16040789,0xa3d90034,0x290b05db,0x8d741454}},	//   _शुगर_, ़ना_, goca_, _راما,
   {{0x68fd034f,0x66d028b4,0xb90209a1,0x00000000}},	//   érda, _häki, _धत_, --,
   {{0x38698bef,0xf3ff0131,0x9a2900ae,0xa8030072}},	//   _edar_, _adão_, _колб_, úñas,
   {{0x629700d8,0x845a2a3b,0xe5a308d9,0xd62a4876}},	//   dexo, ират_, мири, рове_,
   {{0x9e3c0244,0x6aa30150,0x66d0007b,0xe946001c}},	//   _maďa, _hanf, _mäki, _بروی,
   {{0xb6a60ce5,0x6aa30d2a,0x66d000b7,0xa7fb037a}},	// [9340] _дипл, _kanf, _läki, tañe,
   {{0x78a4022e,0x38690094,0x6aa38bf0,0x78a68bf1}},	//   _haiv, _zdar_, _janf, ldkv,
   {{0x6aa3048e,0x28af000d,0x78a400c2,0x9e3c0220}},	//   _manf, _जोडि, _kaiv, _naďa,
   {{0x6aa38bf2,0x78a4037a,0xfbc713c3,0xa7fb01ff}},	//   _lanf, _jaiv, _قت_, sañe,
   {{0x78a4022e,0x6d4800f9,0xdfd0001c,0x6443007f}},	//   _maiv, _stda, عيت_, śnic,
   {{0x78a48bf3,0x6aa34ee0,0x290b0169,0x00000000}},	//   _laiv, _nanf, zoca_, --,
   {{0x20d78bf4,0x628e0090,0x00000000,0x00000000}},	//   _için_, _ibbo, --, --,
   {{0x66cb0390,0x6aa30139,0xdb0b016d,0x2fcf004d}},	//   _yüks, _aanf, _urgê, bygg_,
   {{0x39492431,0xfb86013f,0x00000000,0x00000000}},	//   _časa_, цыйн, --, --,
   {{0xcb1a00c9,0x6aa30150,0x38690063,0x60c22c07}},	//   јќи_, _canf, _sdar_, ljom,
   {{0x09f80080,0x3f860bfe,0x2d9e0a00,0x7afd04d8}},	//   صفحة_, ltou_, _uste_, ésta,
   {{0x7aef0fb6,0x78a40036,0x29030335,0x60c28bf5}},	//   éctr, _caiv, čkao_, njom,
   {{0x3f868bf6,0x60350092,0x290b2364,0xa3ae00c3}},	//   ntou_, _həmç, roca_, किफ_,
   {{0xa3ae0b5f,0x387f10a4,0x3f862226,0x66d90032}},	//   किन_, żur_, itou_, _bìka,
   {{0x290b19c3,0x58d5078b,0x00000000,0x00000000}},	//   poca_, _нокт, --, --,
   {{0x628e54ae,0x38690039,0x6aa38bf7,0x78a48bf8}},	//   _abbo, _udar_, _zanf, _gaiv,
   {{0x3d0b007d,0x645f00dd,0x62970094,0xb87b0072}},	// [9350] ावते_, raqi, texo, rhíd,
   {{0x238e00d9,0x248900e7,0xb87b0072,0x66d90139}},	//   dējā_, sfam_, eníx, _fìka,
   {{0x6297002b,0x78a4024a,0x00000000,0x00000000}},	//   rexo, _yaiv, --, --,
   {{0x62978bf9,0x628e0166,0xea00020b,0x26c3010a}},	//   sexo, _ebbo, _ngậy_, ljjo_,
   {{0x68ed0857,0x645d8bfa,0xa4f9009d,0x44390239}},	//   _mmad, _iesi, ्कीच_, _igs_,
   {{0x645d8bfb,0x6da51c99,0x2fcf0d90,0x335800ae}},	//   _hesi, зика, rygg_, _фарэ_,
   {{0xb1460979,0x645d8bfc,0x6aa302f1,0x68ed00aa}},	//   _فیلم_, _kesi, _ranf, _omad,
   {{0xdd8e00e3,0x66d000c2,0x645d8bfd,0xd5fc00ca}},	//   اوي_, _väki, _jesi, יפור,
   {{0x645d1fe2,0x3f862ee8,0x6aa38bfe,0x78a48bff}},	//   _mesi, ctou_, _panf, _raiv,
   {{0x68ed8c00,0x645d8c01,0x44398c02,0x78a400c2}},	//   _amad, _lesi, _lgs_, _saiv,
   {{0x60db0407,0x4efa00c1,0xaf080037,0x3ea502b6}},	//   _klum, _פלעג, _بقلم_, _ialt_,
   {{0x645d8c03,0x44390009,0x60c9084e,0xa3ae1e93}},	//   _nesi, _ngs_, _joem, किम_,
   {{0x78a48c04,0x3ea58c05,0x6aa30103,0x60c98c06}},	//   _vaiv, _kalt_, _tanf, _moem,
   {{0x44398c07,0x60db71d2,0x68ed8c08,0x78a48c09}},	//   _ags_, _llum, _emad, _waiv,
   {{0x60db8c0a,0x645d8c0b,0x78a48956,0xceb20327}},	//   _olum, _besi, _taiv, עיל_,
   {{0x60c98c0c,0x645d0996,0x9346594b,0x274800ae}},	//   _noem, _cesi, знае, _pînă_,
   {{0x2d8700aa,0x64448c0d,0xdb0b0231,0x443904d6}},	// [9360] htne_, rcii, _argé, _dgs_,
   {{0x60db0766,0x2d878c0e,0x645d8448,0x691d020d}},	//   _alum, ktne_, _eesi, néen,
   {{0x60db8c0f,0x60c98c10,0x2a6a0103,0x68ed00f0}},	//   _blum, _boem, óbbi_, _ymad,
   {{0xe043123a,0x645d8c11,0xa7fb0072,0x55bb00ca}},	//   енци, _gesi, laña, _המטו,
   {{0x765e8c12,0x6d4524a1,0x3f86002b,0x63af05db}},	//   _kepy, íhan, utou_, _grcn,
   {{0x645d8c13,0xa3e52183,0xdee359b2,0x59cb0296}},	//   _zesi, _भेट_, ночи, ाहार,
   {{0x3f868c14,0x645d0060,0x3ea58c15,0x60db8c16}},	//   stou_, _yesi, _dalt_, _flum,
   {{0x60db02e6,0x2900068d,0x3f868c17,0x29128c18}},	//   _glum, _njia_, ptou_, _nkya_,
   {{0x613a030b,0x3ea5004d,0x00000000,0x00000000}},	//   _důle, _falt_, --, --,
   {{0x3ea55c05,0x68ed8c19,0x6da6450e,0x29000350}},	//   _galt_, _smad, _низа, _ajia_,
   {{0xdd8f0308,0x1ea91374,0xa7fb034f,0x395800fc}},	//   _مول_, _باقي_, daña, èrs_,
   {{0xfce322ff,0x00000000,0x00000000,0x00000000}},	//   _похо, --, --, --,
   {{0x645d8c1a,0x443900c6,0xcce50568,0x00000000}},	//   _resi, _rgs_, _تسلي, --,
   {{0x645d4787,0xa7fb2200,0x29120517,0x691d020d}},	//   _sesi, gaña, _ekya_, céen,
   {{0xa3e5000f,0x56780084,0x765e0154,0x4439020b}},	//   _भेज_, ября_, _depy, _pgs_,
   {{0x5fbe2cb6,0x68ed008a,0x7afc033b,0xba170327}},	//   ्हाल, _umad, črtu, _מחוץ_,
   {{0xd90f0814,0x645d8c1b,0x60c90371,0xa7fb1186}},	// [9370] _لیگ_, _vesi, _roem, baña,
   {{0x60db8c1c,0x645d0060,0x60c98c1d,0x2d870146}},	//   _slum, _wesi, _soem, ytne_,
   {{0x645d8c1e,0x60db0bb0,0x68fd8c1f,0x60c91171}},	//   _tesi, _plum, onsd, _poem,
   {{0x68fd1de4,0x3ea500d7,0x39ac00d2,0x00000000}},	//   nnsd, _salt_, _měs_, --,
   {{0x6d5a010a,0xbea52b99,0x765e0342,0x272401cd}},	//   _awta, далк, _yepy, bönd_,
   {{0x63ad8c20,0x7c390150,0x673702a1,0x2d878c21}},	//   mvan, _sgwr, _jixj, ttne_,
   {{0x3ea52701,0xa1940476,0x60db17ad,0x60c90313}},	//   _valt_, _парч, _tlum, _toem,
   {{0x2d878c22,0x63ad8c23,0x60db00dc,0x9f5f0018}},	//   rtne_, ovan, _ulum, áról_,
   {{0x63ad6bc3,0x2d87230b,0x3ea50c8a,0x661702c3}},	//   nvan, stne_, _talt_, _lyxk,
   {{0xa3ae143d,0x39450879,0xab5d0034,0x63ad19bf}},	//   कित_, мног, wyżs, ivan,
   {{0x6dd50260,0x66d00212,0x63ad0d67,0x2ca60441}},	//   _تقاض, _mäkt, hvan, _faod_,
   {{0x63ad01ab,0x39400128,0x2ca600f9,0xb4f900c3}},	//   kvan, _čist_, _gaod_, ्कोप_,
   {{0x691d0257,0x272401bf,0xe79c026a,0xa7fb0143}},	//   péen, höne_, _düğü, taña,
   {{0x63ad8c24,0x6b898c25,0x29190270,0x7e638c26}},	//   dvan, mteg, alsa_, nanp,
   {{0x6b8902a7,0x044608d8,0xaac40281,0x63ad8c27}},	//   lteg, дебн, _ستون, evan,
   {{0xf8e22dfd,0x2eda0be4,0xdb020052,0xa7fb037a}},	//   _पतिय, _भत्त, _proç, saña,
   {{0xfa8e0019,0xccf200a1,0x59cb0104,0x98b205aa}},	// [9380] _mừng_, דכן_, ाहवर, _jiyč_,
   {{0xe297002d,0x6b8901e9,0xfa8e00fe,0x00000000}},	//   мау_, iteg, _lừng_, --,
   {{0xa87a00c1,0xd62a055b,0x63a9033b,0x2c0a0034}},	//   ַאַר, _фоне_, _šent, _हुईं_,
   {{0x657c007b,0xdb028c28,0x63ad0383,0x00000000}},	//   murh, _troç, bvan, --,
   {{0x386000f3,0x6aa802ad,0x6b898c29,0x64560169}},	//   _meir_, yddf, jteg, mbyi,
   {{0x38608c2a,0x26d800c4,0x2bb107ad,0x7b14015e}},	//   _leir_, nkro_, जिना, nàut,
   {{0xc6930054,0xfa8e0023,0x657c0063,0x6b898c2b}},	//   דאו_, _bừng_, nurh, eteg,
   {{0x24804594,0xdc13008b,0x6b890ac9,0x00000000}},	//   ngim_, _ağır, fteg, --,
   {{0xfa8e00de,0x7e6302a1,0xe7ee1d72,0x63a90072}},	//   _dừng_, banp, _चेला_, _áent,
   {{0x7b3200a5,0x38600076,0xdd9213c3,0xcdd60284}},	//   _tłum, _aeir_, _لوط_, _оцењ,
   {{0x6b898c2c,0x66d013e1,0x386003ea,0xa9c325a7}},	//   ateg, _läks, _beir_, всяк,
   {{0xa3de1244,0x63ad03a3,0x38600150,0xfa8e0023}},	//   तना_, yvan, _ceir_, _gừng_,
   {{0x386000e3,0x8c432f25,0xe7842357,0x693a0090}},	//   _deir_, _рече, куро, _aċet,
   {{0x63ad11d3,0x68fd0036,0x6d47020d,0x7d0d3b84}},	//   vvan, snsd, _éjac, čase,
   {{0xb8e50081,0x944c0129,0x0907110c,0x3860009c}},	//   _এত_, _ọdịd, _очим, _feir_,
   {{0x63ad8c2d,0x38608c2e,0xadf105a7,0x44228c2f}},	//   tvan, _geir_, _अइसन_, _bzk_,
   {{0x44220146,0xa7fb0610,0x2bb10034,0x63ad8c30}},	// [9390] _czk_, maño, जिया, uvan,
   {{0x63ad1063,0x05010033,0x98bf02c6,0xa7fb034f}},	//   rvan, ্ষের_, yptě_, laño,
   {{0x63ad3bea,0x6b890a00,0x7e638c31,0x442201ff}},	//   svan, zteg, vanp, _ezk_,
   {{0x63ad01c0,0x7e6301af,0x321803a8,0xd4790142}},	//   pvan, wanp, _dyry_, _צאָל,
   {{0xfa8e0019,0x752d8c32,0x29030117,0x69ce0537}},	//   _rừng_, mmaz, čkah_, øbej,
   {{0x752d0068,0xaaad009f,0xfa8e0023,0xdb1101f9}},	//   lmaz, _झोंक, _sừng_, égün,
   {{0x3d0b07ad,0x44227a8d,0xf2350103,0x00000000}},	//   ावले_, _zzk_, _سبسک, --,
   {{0x752d020e,0x4c8576c4,0x00000000,0x00000000}},	//   nmaz, хлив, --, --,
   {{0x7e632b29,0x38608c33,0x6b890634,0xa7fb83ee}},	//   panp, _reir_, uteg, daño,
   {{0x7c2278c0,0x3860235a,0x5fbe1101,0x1eea0103}},	//   _dzor, _seir_, ्हरल, _فوقی_,
   {{0x6b898c34,0xfa8e0028,0xaca300ac,0x7c22281a}},	//   steg, _từng_, _azụm, _ezor,
   {{0xc6891723,0x7e618c35,0x6d418c36,0xf1b20089}},	//   _לא_, _help, _iula, אסט_,
   {{0xbd2c07a6,0x6d418c37,0x291e00d9,0x752d077e}},	//   _וואָ, _hula, ēta_, dmaz,
   {{0x7d1b8c38,0xa3ae023a,0xfaa2007e,0xe5a60131}},	//   llus, किस_, _башо, ниги,
   {{0x386026aa,0x6d418c39,0x44228c3a,0xa7fb0143}},	//   _teir_, _jula, _szk_, baño,
   {{0x6d418c3b,0x64a35cc8,0x657c0270,0xa7fb0143}},	//   _mula, ласа, rurh, caño,
   {{0x240709f2,0x0326249b,0x7d1b00c2,0x24800052}},	// [93a0] енти_, едан, ilus, rgim_,
   {{0xe9ff00ef,0x7d1b5a68,0x7e610194,0xdb0b034f}},	//   _giải_, hlus, _nelp, _orgí,
   {{0x7d1b8c3c,0x6d411b51,0x7f400092,0x365b00ca}},	//   klus, _nula, _sumq, _מכינ,
   {{0x442200c4,0x20f800d2,0x00000000,0x00000000}},	//   _tzk_, jčit_, --, --,
   {{0x6d418c3d,0x7d1b00aa,0xdb02020d,0xdb00224d}},	//   _aula, dlus, _croû, lvmå,
   {{0x6d418c3e,0x6e943898,0xd00f177a,0x63a600e7}},	//   _bula, тику, حله_, _iskn,
   {{0x40962223,0x6d418c3f,0xdb0b001f,0x629e5183}},	//   _прат, _cula, _orgâ, mepo,
   {{0x629e8c40,0x6d418c41,0xf8bf0018,0x61e100aa}},	//   lepo, _dula, rmék_, _ülla,
   {{0xa2c400e2,0x6d417434,0xb09b00a1,0xd10d0be4}},	//   राप्, _eula, _צימר, िकरण_,
   {{0x7c220ec8,0x6d418c42,0x629e18f0,0x7e6100f9}},	//   _vzor, _fula, nepo, _gelp,
   {{0x6d418c43,0x7c220034,0x5cd6004d,0x7d1b6609}},	//   _gula, _wzor, _підх, blus,
   {{0x66090b88,0x7d1b8c44,0x7d02019f,0x629e09a1}},	//   şekk, clus, _ujos, hepo,
   {{0x7c22084f,0x6d418c45,0x7e6104d6,0xa7fb5642}},	//   _uzor, _zula, _yelp, raño,
   {{0x629e20e4,0x66d00149,0x00000000,0x00000000}},	//   jepo, _säkr, --, --,
   {{0xa7fb0f07,0xa2c40d7e,0x65948c46,0xf527355b}},	//   paño, रान्, лару, ефан,
   {{0x57b50927,0x6aaa0596,0x752d0072,0xc9836ab4}},	//   _абит, _haff, umaz, _суши,
   {{0x752d8c47,0x6aaa2085,0xd3711f11,0x69dc00f3}},	// [93b0] rmaz, _kaff, شها_, øref,
   {{0x6aaa8c48,0x629e8c49,0x2bb105d6,0x752d8c4a}},	//   _jaff, gepo, जिता, smaz,
   {{0x073600ca,0x7d1b00f0,0x00000000,0x00000000}},	//   _שאתם_, ylus, --, --,
   {{0x6d4132d7,0x98bd022b,0x00000000,0x00000000}},	//   _rula, _ouvč_, --, --,
   {{0x6d418c4b,0xf77f026a,0x00000000,0x00000000}},	//   _sula, nuç_, --, --,
   {{0x6d4137a6,0xa3ae05a7,0x629e8c4c,0x6aaa0517}},	//   _pula, किर_, cepo, _naff,
   {{0xf2d20132,0xdcfa06d7,0x7d1b0006,0x6d416acd}},	//   _דעם_, _artı, tlus, _qula,
   {{0x7e616378,0x6d418c4d,0xb87b0076,0xdb0b0131}},	//   _welp, _vula, dhío, _orgã,
   {{0x7d1b8c4e,0x7e618c4f,0x6aaa0517,0x6d418c50}},	//   rlus, _telp, _baff, _wula,
   {{0x6d418c51,0x6aaa8c52,0x7d1b8c53,0x9e670068}},	//   _tula, _caff, slus, _سائن,
   {{0x7d1b8c54,0x6d4106a8,0x00000000,0x00000000}},	//   plus, _uula, --, --,
   {{0x9f9b007b,0xfd562252,0x629e8c55,0x00000000}},	//   päät_, _ישעי_, zepo, --,
   {{0x62951e4d,0x9cd600ca,0x629e8c56,0x6aaa8c57}},	//   _obzo, _שונה_, yepo, _faff,
   {{0x6aaa8c58,0x2cad8c59,0x00000000,0x00000000}},	//   _gaff, lded_, --, --,
   {{0xe7375fd4,0x629e2e5f,0xc44f0134,0x00000000}},	//   тер_, vepo, _ụgụr, --,
   {{0xa3ae05d4,0x6aaa2a8c,0x2cad8c5a,0x628705db}},	//   किल_, _zaff, nded_, _acjo,
   {{0x93438c5b,0xd70a0396,0x6aaa0517,0x2cad1a5b}},	// [93c0] инте, _оние_, _yaff, ided_,
   {{0xf1fa082c,0x8c3d11bc,0x69dc0b81,0x00000000}},	//   وعات_, leşd, øreg, --,
   {{0x629e8c5c,0xcb120341,0x29020188,0xa2c4121d}},	//   repo, סלב_, onka_, राब्,
   {{0xb91a0065,0xdcfa009e,0x290201cd,0x3d0b007f}},	//   _aifẹ_, _istħ, nnka_, हकों_,
   {{0x2cad8c5d,0xdb0b0428,0x29028c5e,0xf8b30089}},	//   dded_, _orgà, inka_, ישא_,
   {{0xc7d70054,0xf41300a1,0x63a44829,0x290201c2}},	//   כוני_, _כפר_, mwin, hnka_,
   {{0x6aaa8c5f,0x63a40060,0xb4db00ee,0x7d0700c6}},	//   _raff, lwin, _diàf, kūrę,
   {{0xfd0f0037,0x2cbd030a,0x3fc60103,0x00000000}},	//   يجي_, _cnwd_, _لگتی_, --,
   {{0x63a48c60,0xb91a0af0,0x248401cd,0x7d0700c6}},	//   nwin, _fifẹ_, _ömmu_, dūrę,
   {{0x63ab052f,0xb87b0037,0x29028c61,0xa3aa0e4c}},	//   ægni, thío, enka_, _खनन_,
   {{0xfbcf1e49,0x63a48c62,0xc27b0796,0x6aaa8c63}},	//   متی_, hwin, וריי, _vaff,
   {{0x6aaa8c64,0x63a48c65,0xcd3603c5,0x3eac00bd}},	//   _waff, kwin, _شراب, _hadt_,
   {{0x6aaa009e,0x64430034,0xa49b0154,0x00000000}},	//   _taff, śnik, _djòl, --,
   {{0x29028c66,0x00000000,0x00000000,0x00000000}},	//   anka_, --, --, --,
   {{0x63a48c67,0x69dc0430,0x6b80010a,0x00000000}},	//   ewin, øred, lumg, --,
   {{0xba3700ca,0x63a48c68,0x92af0033,0x272402c3}},	//   _בטוח_, fwin, _ওকে_, röna_,
   {{0x39490087,0x63a48c69,0x613a02c6,0xe5341aad}},	// [93d0] _časi_, gwin, _půln, реть,
   {{0x24730028,0x78ad1d94,0x43940ac6,0x63a20db4}},	//   ệm_, _haav, рафс, çona,
   {{0x7afd1097,0x78ad00c2,0x8c3d0233,0x75d50037}},	//   ésti, _kaav, leşe, _إيجا,
   {{0xf2df002d,0x63a40126,0xc0ab0018,0x210d2166}},	//   _atât_, bwin, بائل_, िकेश_,
   {{0x747a00a1,0x78ad00aa,0xaed5097a,0x7f19013f}},	//   _אנרג, _maav, лодш, ніку_,
   {{0x753d1feb,0x3ebe8c6a,0x78ad8c6b,0x644d8c6c}},	//   _hisz, _cntt_, _laav, lcai,
   {{0x753d0018,0xfc3f025b,0x29028c6d,0x00000000}},	//   _kisz, žím_, ynka_, --,
   {{0x644d8c6e,0x3ae001b9,0xd0d400e5,0x6f6500d1}},	//   ncai, _ròpa_, _косъ, _مهرم,
   {{0x2cad37b5,0x644d8c6f,0x753d3e15,0x2cb100d2}},	//   rded_, icai, _misz, ězd_,
   {{0x62858c70,0xfff60260,0x753d8c71,0x00000000}},	//   ngho, _حکمت_, _lisz, --,
   {{0x63a48c72,0x5dd506fa,0xa2c4034d,0x78ad083e}},	//   zwin, _حقائ, रात्, _baav,
   {{0x78ad002b,0x2902008a,0x63a4084e,0xdce701d3}},	//   _caav, unka_, ywin, ēlēj,
   {{0x8cc0007f,0x00000000,0x00000000,0x00000000}},	//   वारो, --, --, --,
   {{0x99d50182,0xa49b0139,0x8c3d020a,0xf743293e}},	//   _متبا, _ikòy, geşe, серо,
   {{0x63a425e6,0x660600e5,0x753d8c73,0x00000000}},	//   wwin, упва, _bisz, --,
   {{0x30ae0081,0x03a6101b,0x78ad06b0,0x753d6053}},	//   _কক্স, либо, _gaav, _cisz,
   {{0x68e48c74,0x63a401c0,0x7981019b,0x753d8c75}},	// [93e0] _ilid, uwin, lulw, _disz,
   {{0xa2c463e1,0x63a40b7c,0x644d09f7,0x6aa10167}},	//   राध्, rwin, acai, nelf,
   {{0x394f002d,0x63a48c76,0x68e400b6,0xccf90034}},	//   _însă_, swin, _klid, kiś_,
   {{0x74550465,0x63a40381,0x600a013f,0x6aa18c77}},	//   _върх, pwin, ннем_, helf,
   {{0xa2c4049d,0x6aa1160e,0x7981019f,0x41a42b6e}},	//   राद्, kelf, hulw, _गैरस,
   {{0xe1660037,0x71660037,0x765c8c78,0x7981019b}},	//   _مدري, _مارك, nbry, kulw,
   {{0x91e6010e,0x7d0d0ec8,0x68e48585,0x236700e7}},	//   _сове, časn, _olid, ćnje_,
   {{0x79818c79,0x673e8c7a,0x00000000,0x00000000}},	//   dulw, _lipj, --, --,
   {{0x161617e5,0x09dc00a4,0xcb670c37,0x78ad8c7b}},	//   _दुसर_, मन्य, гање_, _raav,
   {{0xbda600bf,0x78ad4207,0x68e48c7c,0x6b808c7d}},	//   _محصو, _saav, _alid, rumg,
   {{0x527b00c1,0x765c1842,0x78ad13ce,0xc27b006e}},	//   ענטא, dbry, _paav, ערטי,
   {{0x27e68c7e,0x28af099d,0x8c4609b9,0xe7878c7f}},	//   _żona_, _जोखि, _седе, луго,
   {{0x69dc0170,0x6d5818f0,0x00000000,0x00000000}},	//   øreb, lpva, --, --,
   {{0x68e4019f,0x79a600ae,0x78ad010a,0x79812712}},	//   _elid, _брие, _waav, bulw,
   {{0x753d2627,0x78ad0329,0x7afa8c80,0x63a200fd}},	//   _pisz, _taav, mitt, çonn,
   {{0x7afa8c81,0x54558c82,0x69da36bf,0x68e40133}},	//   litt, рват, myte, _glid,
   {{0x753d0068,0x644d8c83,0xe0200251,0x7afa007b}},	// [93f0] _visz, rcai, _बरगद_, oitt,
   {{0x644d8c84,0x7afa8c85,0x320b0c63,0x657a0076}},	//   scai, nitt, нхен_, áthc,
   {{0x753d0068,0x62858c86,0x69da8c87,0x2b468c88}},	//   _tisz, rgho, nyte, _luoc_,
   {{0x7afa8c89,0x6aa10ab2,0xf8bf020d,0x00000000}},	//   hitt, zelf, mmés_, --,
   {{0x2b4600de,0xddd000b6,0x087800c1,0x7afa8c8a}},	//   _nuoc_, _češt, רעדט_, kitt,
   {{0xd9f60d75,0x60c0022b,0x6e2403e3,0x7afa00ce}},	//   ुपात_, _enmm, ƙibl, jitt,
   {{0x7afa8c8b,0x24990063,0x6aa113ea,0x00000000}},	//   ditt, _kbsm_, velf, --,
   {{0x29090051,0x7d0d10e1,0x6f1a010a,0xeb992cde}},	//   _njaa_, časo, _ektc, вии_,
   {{0x2b4600de,0xa7fb8c8c,0x79814944,0x7afa0a5f}},	//   _cuoc_, bañi, wulw, fitt,
   {{0x7afa8c8d,0x2b460019,0xf8de030b,0x290900c2}},	//   gitt, _duoc_, मस्प, _ajaa_,
   {{0xdeba0341,0x8a3800c2,0x98a902a1,0x68e40154}},	//   _שמעל, ляют_, _ghaċ_, _plid,
   {{0x3c470080,0x6aa10665,0xab9500d6,0xa49b022b}},	//   _إضاف, self, _виді, _djòk,
   {{0x39491b30,0x7d048c8e,0xf746249c,0x81bd0033}},	//   _času_, čist, рего, েনি_,
   {{0x69da8c8f,0x7afa00e5,0x26d30072,0x4b7a006e}},	//   byte, citt, _coxo_, _יאנו,
   {{0x765c1564,0xa2c40469,0x69da436f,0x24f682d3}},	//   rbry, रास्, cyte, ачар,
   {{0x81bd0081,0x853e321e,0x765c8c90,0x68e48c91}},	//   েনা_, _ọgbọ_, sbry, _ulid,

   {{0x26d30042,0x2348001c,0x394700b3,0x6266001f}},	// [9400] _foxo_, اسری_, _huns_, иваа,
   {{0x42561a77,0x3947057a,0x26d301c8,0x2caf0727}},	//   ртат, _kuns_, _goxo_, _lagd_,
   {{0x506621be,0x867b00c1,0xc69300a1,0x767b00ca}},	//   атла, _בריו, _ואת_, _בטיח,
   {{0xe7b31e49,0xa2c4022d,0x7afa8c92,0xdc340031}},	//   _امید, राह्, zitt, _súči,
   {{0x39470933,0x44248c93,0x212d0188,0x00000000}},	//   _luns_, _ám_, _dheh_, --,
   {{0xa2e60084,0xdd9a5011,0x212d0036,0x394016a9}},	//   _тогд, вши_, _eheh_, _liis_,
   {{0x7afa1189,0x39478c94,0xf8bf0257,0xbd67007b}},	//   vitt, _nuns_, llée_, арые_,
   {{0x3d108c95,0xa2c400a4,0x69da022a,0x00000000}},	//   ावें_, राव्, vyte, --,
   {{0x7afa8c96,0x2b4600de,0x6440016d,0x807b00ca}},	//   titt, _quoc_, _úmid, _שנמצ,
   {{0xf2d300c1,0xf2df00de,0x69da8c97,0x6d588351}},	//   ַער_, _luân_, tyte, ppva,
   {{0x7afa1bc1,0x39470042,0x26d31097,0x6f1816aa}},	//   ritt, _cuns_, _roxo_, movc,
   {{0x7afa8c98,0x39490995,0x394708a8,0x6f180c0b}},	//   sitt, _čast_, _duns_, lovc,
   {{0xcb540241,0x7afa8c99,0x69da6c77,0x00000000}},	//   _انتظ, pitt, syte, --,
   {{0x6d488c9a,0x6f188c9b,0x3ce6023e,0xd7f80cd1}},	//   _kuda, novc, _hlov_, рую_,
   {{0x998400e3,0x69da023b,0x04670975,0xddc3020a}},	//   _العو, qyte, итам, manţ,
   {{0x6d488c9c,0x657a00e3,0xf8bf8c9d,0xdb0b01bf}},	//   _muda, átha, rmés_, _ergä,
   {{0x213f02e7,0xc2994daa,0x26d3002b,0xf8bf014b}},	// [9410] _riuh_, лках_, _toxo_, glée_,
   {{0xa2c43245,0x29198c9e,0x68fd8c9f,0xddc300d3}},	//   राष्, losa_, lisd, nanţ,
   {{0x6f1800d4,0x80cb0179,0x80c30096,0x6d488ca0}},	//   dovc, _सचदे, ळाले, _nuda,
   {{0x68fd8ca1,0x112800d6,0xf8bf00fd,0x00000000}},	//   nisd, аючи_, blée_, --,
   {{0x38693bf8,0x2d9e736e,0x2919028d,0x24890270}},	//   _mear_, _apte_, iosa_, mgam_,
   {{0x6d488ca2,0x38690037,0xef1808a1,0x3ae90031}},	//   _buda, _lear_, амі_, _kúpe_,
   {{0x2919466b,0x6d488ca3,0xa2c40a08,0x68fd0324}},	//   kosa_, _cuda, रार्, kisd,
   {{0x6d488ca4,0xf2df0019,0x24898ca5,0x38698ca6}},	//   _duda, _xuân_, ngam_, _near_,
   {{0x6d488ca7,0x39408ca8,0xde59004d,0x201f024a}},	//   _euda, _riis_, _базі_, _uyui_,
   {{0x39408ca9,0x764502ad,0xf3ff0161,0xcac90ab3}},	//   _siis_, _nghy, _leão_, угое_,
   {{0x6d488caa,0x186a079c,0x29193e56,0x38698cab}},	//   _guda, лани_, fosa_, _bear_,
   {{0xcd9600a1,0x29195c31,0x38695a2a,0x7f4101ee}},	//   _לדעת_, gosa_, _cear_, _hilq,
   {{0xe8f78cac,0x3940007a,0x69ce108e,0x38698cad}},	//   сля_, _viis_, øber, _dear_,
   {{0x7c2b03ce,0x6d481a3a,0xddc300d3,0xdc3600c1}},	//   _izgr, _yuda, canţ, _פאסט_,
   {{0x39408cae,0x38698caf,0x442b0381,0x7f41009e}},	//   _tiis_, _fear_, _azc_, _milq,
   {{0x39916224,0xf2df0028,0xa2da02d5,0x6f1800d4}},	//   más_, _quân_, पॉन्, zovc,
   {{0x399100fb,0xe29a0131,0xa3ab0179,0x2fdd01fa}},	// [9420] lás_, лаа_, _कैद_, jywg_,
   {{0x16aa17aa,0x7b1d0428,0x38690062,0xf8bf5b6a}},	//   _свои_, cèut, _zear_, rlée_,
   {{0xe2970265,0x38690054,0xf2df0023,0x39916bd1}},	//   сах_, _year_, _tuân_, nás_,
   {{0x6d488cb0,0x4fea24ec,0x3d21007f,0xddc3044c}},	//   _ruda, лмен_, मतों_, zanţ,
   {{0x6d488cb1,0x351b0054,0xdefa022a,0x64460124}},	//   _suda, _תוכנ, лык_, _igki,
   {{0x3ce6025b,0x39918cb2,0x75248cb3,0x6e218cb4}},	//   _slov_, kás_, lliz, _bylb,
   {{0xfe6f0e25,0x29198cb5,0x6f188cb6,0x629c8cb7}},	//   ردو_, yosa_, rovc, _ibro,
   {{0x39910068,0x44220665,0x3b540752,0xb87b0103}},	//   dás_, _kyk_, окир, lhív,
   {{0xddc3002d,0x644602e7,0x6f18830e,0x2ca43564}},	//   tanţ, _mgki, povc, remd_,
   {{0x6d488cb8,0x4974249c,0x386901f7,0x2ca48cb9}},	//   _tuda, олос, _sear_, semd_,
   {{0x629c01e5,0x44220665,0xddc300d3,0x399148fd}},	//   _mbro, _lyk_, ranţ, gás_,
   {{0x23c800aa,0x7aef05fe,0x3ce68cba,0x7afd037a}},	//   रमाद, èctr, _ulov_, éstr,
   {{0x7524332f,0x6c360100,0x3f860558,0x657a0037}},	//   dliz, _افشا, nuou_, áthn,
   {{0x39910018,0xddc300e7,0x7b320034,0x6f040503}},	//   bás_, lanš, _głup, éich,
   {{0x291971cc,0x1dbd2171,0xf3ff0131,0x9afb00ca}},	//   posa_, ्मयत, _peão_, _תפוח,
   {{0xddc300d9,0x44228cbb,0x24892780,0x75248cbc}},	//   nanš, _byk_, ugam_, gliz,
   {{0x629c009c,0x24898cbd,0x6d421ad8,0x7b1d015e}},	// [9430] _bbro, rgam_, _mioa, pèut,
   {{0x75248cbe,0x44228cbf,0xdb098358,0x3f860072}},	//   aliz, _dyk_, rveç, duou_,
   {{0x75248cc0,0x66d00084,0x1a9b00c1,0x96030033}},	//   bliz, _näky, ריבע, _এরকম_,
   {{0xddc30087,0x629c74df,0x63ae007b,0x7c22010a}},	//   janš, _ebro, ännä, _oyor,
   {{0x39910068,0x7c2218c7,0x7f496165,0xe0d00246}},	//   zás_, _nyor, _queq, عزم_,
   {{0x8d551cf2,0xb87b838a,0x399101f9,0x00000000}},	//   отич, chív, yás_, --,
   {{0x6d428cc1,0xc05b01ce,0xed5932e3,0x63bd0167}},	//   _bioa, _біз_, шой_, _hrsn,
   {{0x6d428cc2,0x7cfe5873,0x63bd0542,0x63bb003d}},	//   _cioa, tūra, _krsn, _ġunj,
   {{0x69dc1484,0xa91d0031,0x7c2205bd,0x78a60103}},	//   øren, tuľn, _cyor, vekv,
   {{0x39918cc3,0x7c222375,0x0b160037,0x7aa505cb}},	//   tás_, _dyor, يقية_, циоз,
   {{0x3ea704e4,0xa9690831,0x75240034,0x7c224031}},	//   ment_, јима_, yliz, _eyor,
   {{0x2d878cc4,0x3ea01419,0x3ea78cc5,0x6d428cc6}},	//   mune_, đite_, lent_, _gioa,
   {{0x7c220068,0x7d240084,0x7d098cc7,0x7c2b80e9}},	//   _gyor, _эффе, mnes, _uzgr,
   {{0x4422057a,0x7d1b8cc8,0x2d870519,0x7d098cc9}},	//   _ryk_, lous, oune_, lnes,
   {{0x3ea7025a,0x7d098cca,0x2d8732d7,0xba39006e}},	//   ient_, ones, nune_, _דײַט,
   {{0xe45a02b3,0x3ea78ccb,0x75240051,0x629c028d}},	//   ржа_, hent_, uliz, _sbro,
   {{0x3ea78ccc,0x7524444a,0x2d878ccd,0x7d098cce}},	// [9440] kent_, rliz, hune_, ines,
   {{0x3ea78ccf,0x63bd15fe,0x2d878cd0,0x75240623}},	//   jent_, _drsn, kune_, sliz,
   {{0x3ea78b49,0x2d878cd1,0x7d1b5644,0x7d098cd2}},	//   dent_, june_, kous, knes,
   {{0x4fc6055b,0x3f860bf8,0xa99a00c1,0x2d878cd3}},	//   жска, tuou_, יבער, dune_,
   {{0x7d1b03be,0xbba82231,0xddc30095,0x5e5800c2}},	//   dous, _कनेक, vanš, биля_,
   {{0x3ea709cd,0x7d098cd4,0x1c1d0006,0x2d877d91}},	//   gent_, enes, _पड़ल_, fune_,
   {{0xf9870241,0x2d878cd5,0xe8010034,0x7c22061d}},	//   _تب_, gune_, _लेना_, _syor,
   {{0x7d1b8cd6,0x61e30565,0x00000000,0x00000000}},	//   gous, ønle, --, --,
   {{0x3ea78cd7,0xe7a90034,0xcb0a017b,0x6d42020a}},	//   bent_, _चैंप, иход_, _vioa,
   {{0x3ea74cda,0x21260947,0x7d090451,0x3ae00154}},	//   cent_, lloh_, anes, _kòpi_,
   {{0x2d878cd8,0x39581215,0x6e9300cd,0x7d1b8cd9}},	//   cune_, ërs_, _آلما, bous,
   {{0xeb9a08a4,0x7d1b8cda,0x6d5a5b96,0x6ec209a1}},	//   _вид_, cous, _itta, लाकु,
   {{0x776200a7,0x5ead0033,0x7c220027,0x8c3d0233}},	//   _çoxl, চারে, _uyor, neşl,
   {{0x3f500028,0x613102fe,0x7d008cdb,0xb33b0131}},	//   _màu_, måle, lims, _opça,
   {{0xd5b81756,0xfc3f030b,0xb4db00b3,0x6aa801ee}},	//   ост_, žít_, _diàn, medf,
   {{0x3ea78cdc,0x7d0007aa,0x63bd1660,0xddc119ad}},	//   zent_, nims, _prsn, _jelš,
   {{0x964701b6,0x3ea78cdd,0x439419e8,0x00000000}},	// [9450] _мэнд, yent_, матс, --,
   {{0x7d098cde,0x6d5a5e3d,0xd25b041e,0x63bd1197}},	//   znes, _otta, рца_, _vrsn,
   {{0x3ea72198,0x7d008cdf,0x6d5a010a,0x2d8701ff}},	//   vent_, kims, _ntta, xune_,
   {{0x3ea78ce0,0x76550034,0x7d1b002b,0x7cfe00c6}},	//   went_, lczy, xous, dūro,
   {{0x6d5a4de0,0x7d09038c,0x98c60335,0x61310d78}},	//   _atta, vnes, šući_, jåle,
   {{0x63ad6708,0x643a0130,0x2d878ce1,0x059600cd}},	//   mwan, _לערנ, tune_, _بایگ,
   {{0x3ea71b14,0x63ad7769,0x7d1b8ce2,0x69dc038c}},	//   rent_, lwan, tous, ørel,
   {{0x3ea78ce3,0x2d878ce4,0x63ad8ce5,0x290b007e}},	//   sent_, rune_, owan, jnca_,
   {{0xff532296,0x7d1b8ce6,0x6d5a0283,0x63ad8ce7}},	//   _آخر_, rous, _etta, nwan,
   {{0xdd000029,0x63a00222,0x7d098ce8,0x2d878ce9}},	//   ētāj, _ämne, snes, pune_,
   {{0x63ad8cea,0x7d1b45b0,0x49900018,0x3a251aad}},	//   hwan, pous, نیور, ямог,
   {{0x63ad8ceb,0x7aea8cec,0x0d84004b,0x8c3d026a}},	//   kwan, _elft, _ілін, leşm,
   {{0x63ad8ced,0x7cee009c,0xb4db01b9,0xa3ab00a3}},	//   jwan, _dùrd, _piàn, _कैल_,
   {{0x63ad8cee,0x290b8cef,0x68ef009c,0xcc3a0142}},	//   dwan, anca_, ahcd, _פעסט,
   {{0x1dbd072d,0xd62a8cf0,0x09e501b6,0x63ad7f38}},	//   ्मित, сове_, _хойн, ewan,
   {{0x63ad0364,0xf8bf8cf1,0x00000000,0x00000000}},	//   fwan, llén_, --, --,
   {{0x63ad35e0,0x00000000,0x00000000,0x00000000}},	// [9460] gwan, --, --, --,
   {{0x29028cf2,0x78b601e8,0x1dbd2172,0xb87b0037}},	//   lika_, _hayv, ्मात, bhís,
   {{0x5ba80789,0xb87b1ea5,0x63ad0361,0x24550174}},	//   _कन्व, chís, awan, _ụme_,
   {{0x2902172a,0x63ad8cf3,0x5a0c006e,0x26da8cf4}},	//   nika_, bwan, סלאַ, _hopo_,
   {{0x6b890033,0x26da8cf5,0x21268cf6,0x63ad4944}},	//   jueg, _kopo_, rloh_, cwan,
   {{0x29028cf7,0x7cfe013f,0x26da0239,0xbd6a0012}},	//   hika_, tūro, _jopo_, брие_,
   {{0x29028cf8,0x6aa800f2,0x7d008cf9,0x26da007b}},	//   kika_, vedf, tims, _mopo_,
   {{0xe0550e8c,0x3f500019,0x29020bc4,0x0caa1bb8}},	//   _قیمت_, _tàu_, jika_, стки_,
   {{0x29028cfa,0x7f4a09b4,0x3f67013d,0x8c530037}},	//   dika_, _طلاق_, _нито_, رئيا,
   {{0x6131038c,0x26da00d1,0x59b0007f,0x00000000}},	//   råle, _nopo_, _जनदर, --,
   {{0x29028cfb,0x63ad8cfc,0x6d5a13f8,0xbc6a00cd}},	//   fika_, zwan, _utta, _همان_,
   {{0x63ad0067,0x76550034,0x00000000,0x00000000}},	//   ywan, wczy, --, --,
   {{0xb4db05fe,0x26da0113,0x612300bc,0x00000000}},	//   _diàl, _bopo_, põlv, --,
   {{0xa3c20e72,0xa3c00455,0x96d80455,0x26da0161}},	//   ्मन_, ंटन_, नॉलॉ, _copo_,
   {{0x26da0465,0xcb130130,0x29027de9,0x76550034}},	//   _dopo_, _אלס_, bika_, rczy,
   {{0xe81e0abe,0x29028cfd,0x63ad8cfe,0x6a820139}},	//   _युवा_, cika_, twan, _fífà,
   {{0xa87c0054,0x2bb1009f,0x316a029a,0x68ed041c}},	// [9470] _האחר, ड़िया, _awbz_, _ilad,
   {{0x63ad092f,0x6eef0021,0xa2c40d61,0x67460206}},	//   rwan, _købe, राग्, ľujú,
   {{0x68ed068e,0x63ad8cff,0x6b890634,0xe80108d4}},	//   _klad, swan, zueg, _लेता_,
   {{0xf1c000ef,0x6eef01df,0x63ad8d00,0x2eec037a}},	//   ương_, _møbe, pwan, _aldf_,
   {{0x68ed0206,0x6eef01c5,0x93c7044c,0x6b8901ff}},	//   _mlad, _løbe, _brăţ, xueg,
   {{0x6da58d01,0x68ed8a99,0xeae70033,0x10140504}},	//   дика, _llad, _পদ্ম, ربند,
   {{0xfe700adc,0x68ed0032,0x29028d02,0x533442c5}},	//   اده_, _olad, yika_, _черт,
   {{0x29027218,0x6b890062,0x00000000,0x00000000}},	//   xika_, tueg, --, --,
   {{0x2d8a052f,0xfd560174,0x1dbd02d5,0x394e0364}},	//   _åben_, _kabọ, ्महत, _aufs_,
   {{0x68ed8d03,0x29028d04,0xa91d0220,0xe57801d3}},	//   _alad, wika_, buľk, šķi_,
   {{0x29028d05,0x68ed0a88,0x60db0c56,0x6f03013d}},	//   tika_, _blad, _koum, minc,
   {{0x68ed8d06,0xe45f0212,0x60db0383,0x26da001c}},	//   _clad, _snön_, _joum, _sopo_,
   {{0x29028d07,0x26da8d08,0x68ed063d,0xf8bf0143}},	//   rika_, _popo_, _dlad, plén_,
   {{0x68ed8d09,0x29028d0a,0x161f009f,0x6f038d0b}},	//   _elad, sika_, _मुहर_, ninc,
   {{0xceb217f5,0xf74344bd,0x29028d0c,0x68ed8d0d}},	//   כים_, теро, pika_, _flad,
   {{0x60db8d0e,0x60c90361,0x00000000,0x00000000}},	//   _noum, _nnem, --, --,
   {{0x26da8d0f,0x6f038d10,0x291202a4,0xaac20285}},	// [9480] _topo_, kinc, _ijya_, _वोडक,
   {{0x26da0036,0x6f036fe2,0x68ed0206,0x055600e5}},	//   _uopo_, jinc, _zlad, _отмя,
   {{0x6f038d11,0x2b476bcf,0x91aa0076,0x00000000}},	//   dinc, _minc_, تهاك_, --,
   {{0x61e30c08,0x23600126,0x2b470150,0x00000000}},	//   ønla, ppij_, _linc_, --,
   {{0x4f571363,0x60db1428,0x6f038d12,0x00000000}},	//   وجود_, _doum, finc, --,
   {{0x934616dd,0x60c98d13,0x6f038d14,0xd00f00b9}},	//   _інве, _enem, ginc, جله_,
   {{0x1ea900e3,0x40968d15,0x2736052f,0x290000c2}},	//   ثاني_, _орат, mænd_, _omia_,
   {{0x629e0b8e,0x60db06a3,0x2d800220,0x395c8d16}},	//   lfpo, _goum, čie_, _rtvs_,
   {{0x6f03049e,0xd007007e,0x2aaa372a,0x2b47030a}},	//   binc, _жете_, отно_, _binc_,
   {{0x68ed3fa3,0x2b470472,0x29120193,0x1dbd02d5}},	//   _slad, _cinc_, _ajya_, ्मशत,
   {{0x6d5e8d17,0x68ed0021,0x60db066a,0x2b47013c}},	//   ípad, _plad, _youm, _dinc_,
   {{0x80e000c7,0x63a61044,0x6ba702c3,0x2a690357}},	//   পোর্, _opkn, örgå, _đabe_,
   {{0x68ed0335,0x59b034d8,0x274b004d,0x995700d8}},	//   _vlad, _जनवर, ючно_, _váše_,
   {{0x68ed8d18,0x7bc20027,0x00000000,0x00000000}},	//   _wlad, _irou, --, --,
   {{0x442d2782,0x645a00ae,0xb60413fc,0x3f8600d4}},	//   _še_, _ştia, вятк, hrou_,
   {{0x39988d19,0x6f038d1a,0x7bc200b6,0x6ab800f2}},	//   més_, zinc, _krou, _havf,
   {{0xe6670157,0x39988d1b,0x6e2801df,0x60db8d1c}},	// [9490] _отно, lés_, _lydb, _roum,
   {{0x35b55ac3,0x3f86066e,0x60db8d1d,0x39498d1e}},	//   _збор, drou_, _soum, _hias_,
   {{0x6f036df1,0x39985635,0xa2c41e9f,0x60db2676}},	//   vinc, nés_, राज्, _poum,
   {{0x4f9500d3,0x776d0372,0x00000000,0x00000000}},	//   ерку, _kwax, --, --,
   {{0x39498d1f,0x3f860bf8,0x39980257,0xdbd60673}},	//   _mias_, grou_, hés_, _jääm,
   {{0x3949022e,0x8ca100a5,0x39980103,0x60db0383}},	//   _lias_, क्नो, kés_, _woum,
   {{0x6f038d20,0x7bc28d21,0x60db8d22,0xada51605}},	//   rinc, _arou, _toum, хайл,
   {{0x62348d23,0x60c98d24,0x3949006c,0x39988d25}},	//   _ресу, _unem, _nias_, dés_,
   {{0xa2c4009d,0x7bc28d26,0x0b450dd8,0xe0d2006e}},	//   राच्, _crou, ннин, _גײן_,
   {{0xa3c20a30,0x394900bc,0x301400ae,0x8c3d0233}},	//   ्मत_, _aias_, _рдур, neşi,
   {{0x39494c9d,0x39988d27,0x2b47061c,0x09e500ba}},	//   _bias_, gés_, _vinc_, хонн,
   {{0xf8bf0074,0x7bc27eba,0x39498d28,0xa3df00c3}},	//   blém_, _frou, _cias_, तहा_,
   {{0x39498d29,0x7bc28d2a,0x2b470472,0x2cad0188}},	//   _dias_, _grou, _tinc_, meed_,
   {{0xfbd00068,0x2cad008a,0x39988d2b,0xf6260095}},	//   _ختم_, leed_, bés_, едго,
   {{0x39980990,0x18a611a1,0x64a63ba4,0x13c8045f}},	//   cés_, _займ, нава, रम्भ,
   {{0x2d870a02,0x2cad0188,0x29008d2c,0x69c30078}},	//   irne_, need_, _umia_, _irne,
   {{0x6b9b8d2d,0xccf200c1,0x81dd0033,0x78a402a4}},	// [94a0] ntug, אכן_, _তেল_, _ibiv,
   {{0x2cad8d2e,0x3949022e,0x3f860313,0x69c31271}},	//   heed_, _zias_, vrou_, _krne,
   {{0x3949022e,0x2cad74c0,0xd0120103,0x00860231}},	//   _yias_, keed_, گلش_, елео,
   {{0xa3c2009f,0x705300bf,0x3f868d2f,0x394901fa}},	//   ्मद_, هنما, trou_, _xias_,
   {{0x39980068,0x2d878d30,0x78a48d31,0x2cad5f51}},	//   zés_, erne_, _mbiv, deed_,
   {{0x39980257,0x7bc4013f,0x3f868d32,0xdd900dce}},	//   yés_, _šiuo, rrou_, لوت_,
   {{0xf9871823,0x2cad8d33,0xc69300c1,0x39987afc}},	//   _حب_, feed_, טאג_, xés_,
   {{0x2cad008a,0x61461728,0x7cee009c,0xc19b0796}},	//   geed_, _чеба, _bùra, _משלי,
   {{0xdccf0028,0x02e40ed3,0x69c38d34,0x39498d35}},	//   _tỉnh_, _गवाह_, _arne, _rias_,
   {{0x39988d36,0x7bc21db2,0x93fb0341,0x78a43e57}},	//   tés_, _vrou, פליי, _abiv,
   {{0x0d8606d5,0x39498d37,0xfaa3004b,0x6aba0124}},	//   _член, _pias_, ушын, rdtf,
   {{0x399815c9,0xa3c2277c,0xfc641e49,0x7bc2729b}},	//   rés_, ्मा_, _شخصی, _trou,
   {{0x39988d1b,0x39498d38,0x69c31e8a,0x7d0204ff}},	//   sés_, _vias_, _erne, _imos,
   {{0x39988d39,0x8c431191,0x78a4083e,0x7cfe0d7c}},	//   pés_, _сече, _ebiv, dūri,
   {{0x39490d7d,0x62830610,0x2d9c0103,0x6d5c014b}},	//   _tias_, ónom, ntve_, _érad,
   {{0x81d60033,0x612a01cd,0x61e500d4,0x3eae0571}},	//   িনা_, býli, vyhl, heft_,
   {{0x7d0200e7,0x69c30141,0x00000000,0x00000000}},	// [94b0] _mmos, _zrne, --, --,
   {{0x78bd0429,0x78a42392,0x3eae007e,0x24923d56}},	//   ldsv, _zbiv, jeft_, agym_,
   {{0x2cad025e,0x7d028d3a,0x00000000,0x00000000}},	//   yeed_, _omos, --, --,
   {{0x823416cc,0x78bd09a8,0xd47900c1,0x62950034}},	//   اركا, ndsv, _קאָל, _wczo,
   {{0x78bd0cad,0x752d60e8,0xe9ff0023,0x7d0701dc}},	//   idsv, mlaz, _khải_, _lèrè,
   {{0x7d028d3b,0x752d8d3c,0x2d871c56,0x7cee009c}},	//   _amos, llaz, trne_, _rùra,
   {{0x30a75dbe,0x62344e42,0x2cad8d3d,0x2d878d3e}},	//   _прав, _беру, teed_, urne_,
   {{0x6b9b8d3f,0x09e40081,0x7cf500e1,0xdbdf0139}},	//   ttug, _ফেভা, _márg, _fììm,
   {{0x2cad8d40,0x69dc679f,0x78af00ae,0xe8011101}},	//   reed_, ären, decv, _लेला_,
   {{0x6b9b4200,0x752d8c13,0x7d070113,0x2cad8d41}},	//   rtug, hlaz, _bèrè, seed_,
   {{0x3f8f8d42,0x6b9b8d43,0x2d9c0031,0x7bcd00c6}},	//   lugu_, stug, ctve_, _šaud,
   {{0xa3d1030b,0x69c3033b,0xf1b2006e,0x7d07001c}},	//   वमा_, _vrne, בסט_, _dèrè,
   {{0x442b8d44,0x79881cab,0x6d4b026d,0x00000000}},	//   _nyc_, ardw, _iiga, --,
   {{0x6d4b8d45,0x6b894192,0x6f0d0037,0x645d3174}},	//   _higa, mreg, éach, _afsi,
   {{0x3f8f092f,0x6d4b5fa6,0x752d3afb,0x7cf50072}},	//   hugu_, _kiga, flaz, _cárg,
   {{0x6d4b0d2a,0x3f8f3b3c,0x7cfe12b8,0x752d8d46}},	//   _jiga, kugu_, tūri, glaz,
   {{0x6d4b5c43,0x03262060,0x69c17a24,0x442b00dc}},	// [94c0] _miga, вдан, lvle, _cyc_,
   {{0x6d4b8d47,0x394a025b,0x3f8f8d48,0x6b89002b}},	//   _liga, _časy_, dugu_, ireg,
   {{0xe2973288,0x752d8d49,0x63a901d3,0x7cf50143}},	//   тах_, blaz, _ģene, _gárg,
   {{0x6b890126,0x21670ac6,0x6d4b8d4a,0x5577006e}},	//   kreg, тици_, _niga, _בעטן_,
   {{0xa85700a1,0x75248d4b,0x3f8f8d4c,0x602300c2}},	//   דינה_, moiz, gugu_, адца,
   {{0x6b890515,0x57fb00a1,0x7d020036,0x2d8e8d4d}},	//   dreg, ולנו, _smos, tufe_,
   {{0x6d4b8d4e,0xe2970e2f,0x7bc0023e,0x6b891cab}},	//   _biga, _шар_, wvmu, ereg,
   {{0x6b898d4f,0x2d8e0364,0x6d4b8d50,0x69ab0e52}},	//   freg, rufe_, _ciga, _जनजी,
   {{0x6d4b0498,0x6b898d51,0x2d9c8d52,0x28d6055c}},	//   _diga, greg, stve_, धानि,
   {{0x6131070a,0x752d51a4,0x6ef4009c,0x6d4b8d53}},	//   håll, zlaz, _bàbe, _eiga,
   {{0xa2c30c3c,0x6d4b8d54,0xddda0103,0x75240634}},	//   रयत्, _figa, _tető, koiz,
   {{0x6d4b11b9,0x92ae0081,0x7cf50487,0x3ea9042d}},	//   _giga, কায়_, _cárd, đate_,
   {{0xe9ff00ef,0x78bd0073,0x7cf50103,0xb8fb02f0}},	//   _phải_, rdsv, _sárg, _डच_,
   {{0x6d4b8d55,0x65952db3,0x2d580139,0x7d070f09}},	//   _ziga, лагу, _kée_, _tèrè,
   {{0x09e30a28,0x6d4b6947,0x35e4013f,0x6ef40065}},	//   _војн, _yiga, ацтв, _kàbb,
   {{0xc9831e9e,0x6d4b8d56,0x6d4e00fd,0x2d5102a1}},	//   _туши, _xiga, _ébau, _eġew_,
   {{0x6d400084,0xe9ff00de,0x752d01ff,0x2d580032}},	// [94d0] imma, _thải_, rlaz, _lée_,
   {{0x752d7dbc,0x7cf50018,0x8c3d00d3,0x7bdf8420}},	//   slaz, _tárg, meşt, _àque,
   {{0x22470704,0x8c3d250e,0x2d5800fd,0x2ca605db}},	//   änk_, leşt, _née_, _obod_,
   {{0xf8bf8d57,0x3f8f8d58,0x6601003e,0x6b890ac9}},	//   ndé_, tugu_, úlku, yreg,
   {{0x7084004b,0x6d4b8d59,0x8c3d42ad,0x8fa50832}},	//   ргіз, _riga, neşt, уале,
   {{0x6d4b4051,0x7e7800d9,0x539a040a,0x3f8f804c}},	//   _siga, gavp, _אישו, rugu_,
   {{0x6d4b8d5a,0x6b8901cb,0xdcef007e,0x3f8f1b9a}},	//   _piga, wreg, _žeđa, sugu_,
   {{0x6b892733,0x7cee01b9,0x7cfe00c6,0x24998d5b}},	//   treg, _dùro, kūru, _jcsm_,
   {{0x6d4b8d5c,0x74c50033,0x1b4980c5,0x7bcd00e8}},	//   _viga, _একাউ, нзии_, _šaub,
   {{0x6b898d5d,0x6d4b00cd,0xe9d91d4d,0x6d4000c2}},	//   rreg, _wiga, еко_, amma,
   {{0x6d4b8d5e,0x7c2b00a5,0x613802c6,0x394641f3}},	//   _tiga, _wygr, síle, лног,
   {{0x6b890ba0,0x69c18d5f,0x6d4b0381,0x00000000}},	//   preg, rvle, _uiga, --,
   {{0x7d098d60,0xfaa55961,0x75240ca7,0x69c1057a}},	//   mies, _бало, voiz, svle,
   {{0x24990124,0x2cbf007a,0x7cf500b6,0xf8bf014b}},	//   _acsm_, ldud_, _dáre, adé_,
   {{0x69dc13b9,0xe737008f,0x94610294,0x8c250033}},	//   øret, уер_, _ụdịd, মেশন_,
   {{0x7d098d61,0xa3c00455,0xf9920341,0x2cbf00aa}},	//   nies, ंटल_, _הרה_, ndud_,
   {{0x42ca0131,0x4ab702e8,0x7cf58d62,0x75248d63}},	// [94e0] нган_, _असाव, _kárb, roiz,
   {{0xe29700d3,0x2cbd022e,0x7d098d64,0x7bc40138}},	//   лау_, _lawd_, hies, _šiuk,
   {{0x869b0105,0xea7600c1,0x8cb80179,0xdb090072}},	//   _אייז, רגער_, ्यमो, nveñ,
   {{0x2cbd01fa,0x6ae0030b,0x50ba0604,0x3ced006c}},	//   _nawd_, _पक्र, عداد_, jkev_,
   {{0xdee64e4f,0x7d098d65,0xe6121ac9,0x3ced05db}},	//   лоди, dies, _خشک_, dkev_,
   {{0x2d800029,0x3f5900b3,0x00000000,0x00000000}},	//   ņiem_, _dèu_, --, --,
   {{0x7d098d66,0xc6930327,0xd1320037,0x63b68d67}},	//   fies, צאה_, _همس_, lwyn,
   {{0x7d098d68,0x3ced023e,0x00000000,0x00000000}},	//   gies, gkev_, --, --,
   {{0x4e96054f,0x7cf50145,0x21260085,0x6fb802d5}},	//   _مشار, _bárb, mooh_, _इनिं,
   {{0x8c3d00d3,0x21260085,0x6d4001c2,0xd00f0452}},	//   veşt, looh_, smma, _علل_,
   {{0x7d098d69,0x39151d5c,0x6eef01df,0x28f98d6a}},	//   bies, имор, _møbl, вень_,
   {{0x8c3d002d,0x3ebe00d6,0x7d098d6b,0x2ca68d6c}},	//   teşt, _hatt_, cies, _ubod_,
   {{0xead43d7b,0x3ebe8d6d,0xf8bf4468,0x6c7b006e}},	//   _воль, _katt_, rdé_, _טראד,
   {{0x8c3d002d,0x38608d6e,0xbb830037,0x387903e3}},	//   reşt, _efir_, _الوي, sasr_,
   {{0x8c3d002d,0x4a5b0341,0x7e570089,0xe801007a}},	//   seşt, _אדוו, רסלב_, _लइका_,
   {{0xdb1901bf,0x628a0610,0xa99b00ca,0xa3c20c22}},	//   _erwä, ófon, _נבחר, ्मं_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [94f0] --, --, --, --,
   {{0x7d0905ba,0x3ebe13f8,0x00000000,0x00000000}},	//   zies, _natt_, --, --,
   {{0x38600102,0xa2c9009d,0x66280094,0x611c04ad}},	//   _yfir_, _होण्, čské, zčle,
   {{0x290b161f,0x7cf50018,0x439500c6,0xb4db00b3}},	//   nica_, _márc, _камс, _ciàt,
   {{0x7d098d6f,0x3ced023e,0x248e02c6,0x69dc007b}},	//   vies, vkev_, íjmů_, ärej,
   {{0x7d098d70,0x23690284,0x2cbd01ad,0xb4db01f7}},	//   wies, mpaj_, _sawd_, _bhàg,
   {{0x7d098d71,0x1dc5049d,0x3ebe23ff,0xd2290037}},	//   ties, विधत, _datt_, _شكره_,
   {{0xa2c9009d,0x44390141,0x00000000,0x00000000}},	//   _होत्, _kzs_, --, --,
   {{0x6e95493c,0x3ebe003d,0x3ced15fe,0x69ce02b6}},	//   _визу, _fatt_, rkev_, åben,
   {{0x7d098d72,0x7cf506cb,0x3ebe00bd,0x6297019f}},	//   sies, _bárc, _gatt_, ngxo,
   {{0x290b8d73,0x7cf504d8,0x7d098d74,0x186a1121}},	//   fica_, _cárc, pies, кани_,
   {{0x61fa0006,0x6fdc0081,0x44394a93,0xdb090042}},	//   _ütle, _মেয়ে, _ozs_, rveñ,
   {{0x69dc0856,0x08363d7b,0x3ebe00dc,0x443905db}},	//   ører, рхня, _yatt_, _nzs_,
   {{0x290b020a,0xe73a129e,0x67270172,0x3ebe009e}},	//   aica_, тег_, gojj, _xatt_,
   {{0x7ae3054f,0xd62a8d75,0x649a678b,0xa5460037}},	//   _iont, тове_, ктар_, لضرو,
   {{0x05550012,0x7ae38d76,0xb4668d77,0x44661a0e}},	//   стря, _hont, ркал, рвав,
   {{0xdbd90161,0x42560832,0x7306035f,0x6ef401ec}},	// [9500] _açúc, атет, апаз, _làba,
   {{0x8ccc0067,0x68e41d2d,0x577b00c1,0x44390ebd}},	//   _दोनो, _hoid, _שטיצ, _dzs_,
   {{0x68e400bc,0x3ebe45d9,0x6ef401f7,0x98da30a8}},	//   _koid, _ratt_, _nàba, _बचाए,
   {{0x7ae38d78,0x3ebe0351,0x2bb6000d,0x68e400c2}},	//   _lont, _satt_, _अनला, _joid,
   {{0x3ebe0078,0x684a00c6,0x44390117,0x68e48d79}},	//   _patt_, būdž, _gzs_, _moid,
   {{0x290b002d,0xdfcf00e3,0x7ae38d7a,0x68e401b5}},	//   zica_, بيه_, _nont, _loid,
   {{0x6ef401ec,0xb4db009c,0x290b8d7b,0x44398d7c}},	//   _càba, _tiàt, yica_, _zzs_,
   {{0x290b0933,0x7ae30514,0x3ea0030b,0x6283035d}},	//   xica_, _aont, řit_, ónov,
   {{0x60c28d7d,0x3ebe00d6,0x7ae38d7e,0x2eb6276f}},	//   mdom, _tatt_, _bont, _всес,
   {{0x60c2013f,0x68e41ab6,0x8f9b0327,0x290b8d7f}},	//   ldom, _aoid, _בימי, wica_,
   {{0x60c00022,0x7ae38d80,0x68e401ec,0x325700ca}},	//   _kamm, _dont, _boid, יסים_,
   {{0x60c08d81,0x68e408a8,0x68f632dd,0x60c249fb}},	//   _jamm, _coid, _clyd, ndom,
   {{0xe8012f8f,0x68e40161,0x4bd7001c,0x629c020a}},	//   _लेखा_, _doid, _نبود_, _ocro,
   {{0xbb43125f,0x6b820027,0x7bdf6c99,0x7cf501f9}},	//   _дечк, _ivog, _àqua, _tárc,
   {{0xe5c4204e,0x5bb604f8,0xbbb605cd,0x60c28d82}},	//   осто, _अनुव, _अनुक, kdom,
   {{0x60c08d83,0x987507ec,0x2fc603ce,0x629c332e}},	//   _namm, _улиц, kvog_, _acro,
   {{0x56950cba,0x7cf50103,0xe8c300a4,0x335800ae}},	// [9510] _лапт, _jára, षयीच, иатэ_,
   {{0x60c0008c,0x613113c8,0x32673333,0xb4db009c}},	//   _aamm, måli, ртав, _piàs,
   {{0x60c0083e,0xb4db8d84,0x65191ac9,0xc348008f}},	//   _bamm, _diàr, _مقدس_, ряте_,
   {{0x6b8202e6,0x60c20d3e,0x60c08d85,0x629c8d86}},	//   _ovog, gdom, _camm, _ecro,
   {{0x7cf5135f,0x60c00b6a,0xf8bf8d87,0x26c18d88}},	//   _nára, _damm, llés_, _kaho_,
   {{0xaf0400d6,0x60c20034,0x629c0076,0x00000000}},	//   опіл, adom, _gcro, --,
   {{0x7ae38d89,0x6b8203be,0x29090084,0x645a00d3}},	//   _ront, _avog, _omaa_, _ştii,
   {{0xeb9915a7,0x7ae38d8a,0x7cf50d79,0x69c501cd}},	//   гии_, _sont, _bára, _áhei,
   {{0x7ae38d8b,0x69ca02ad,0xb4db01b9,0x6f0d0076}},	//   _pont, _arfe, _ghàe, éacs,
   {{0x26c1023f,0x68e48d8c,0x6b820335,0x60c08d8d}},	//   _naho_, _soid, _dvog, _zamm,
   {{0x68e48d8e,0x7ae38d8f,0x60c08d90,0x2ba9007a}},	//   _poid, _vont, _yamm, _कहवा,
   {{0x7ae3172a,0x673e00dd,0x26d303be,0x7cf54b05}},	//   _wont, _shpj, _anxo_, _fára,
   {{0x68e40084,0x6b652cd8,0x69ca1507,0x26c18d91}},	//   _void, _укла, _erfe, _baho_,
   {{0x7afa5b2f,0x60c28d92,0x61fb0022,0x628703a9}},	//   chtt, zdom, _ƙull, _ndjo,
   {{0x99853345,0xf8bf11ce,0xa2db1203,0xd9460fec}},	//   _البو, glés_, नान्, _леки,
   {{0x6ab70bd9,0xf8c60146,0xe8f60470,0xa5070c3f}},	//   _असुर, _šéfa_, _دستخ, беса_,
   {{0x60c01d46,0x7cfc0068,0x0b620174,0xb4db009c}},	// [9520] _ramm, _férf, _kụọr, _bhàb,
   {{0x60c00c2e,0x212d00bf,0xb4db01b9,0xf8bf8d93}},	//   _samm, _akeh_, _chàb, blés_,
   {{0x3940023e,0x0b620174,0xe3b2001c,0xb4db0428}},	//   _khis_, _mụọr, _کرج_, _viàr,
   {{0x60c222d4,0x03a61d3f,0x53a6311c,0x2bbc00aa}},	//   udom, _лимо, _ламб, ्टमा,
   {{0x44240028,0x81e60081,0xbbb61efb,0x213f01dc}},	//   _âm_, _বেশ_, _अनेक, _dhuh_,
   {{0x63a48d94,0x60c00517,0x2ee5028d,0x60c20429}},	//   mtin, _wamm, _colf_, sdom,
   {{0x7bcb8d95,0xa3c2000c,0x6b826a36,0x60c00fc4}},	//   _argu, ्मक_, _svog, _tamm,
   {{0xa3bc0d43,0xa1160781,0x26c302ef,0x7bcb00c4}},	//   _आना_, _اورت, zdjo_, _brgu,
   {{0xda7a8d96,0xac184171,0xbb620065,0xa2cd0096}},	//   лян_, ропу_, _bọọg, साच्,
   {{0x7cf50103,0x2ee50952,0x63a43f43,0xf2d3006e}},	//   _vára, _golf_, itin, ִער_,
   {{0x63a48d97,0x7bcb8d98,0x68fd0052,0x00000000}},	//   htin, _ergu, ërdo, --,
   {{0x63a48d99,0x6b821197,0x394001b9,0x7cfc003e}},	//   ktin, _tvog, _chis_, _sérf,
   {{0x6d5a25fa,0x7bcb0995,0xc1a53245,0x3940026d}},	//   _huta, _grgu, _गङ्ग, _dhis_,
   {{0x6d5a31ab,0xd6d70081,0x2be5030b,0x613113b9}},	//   _kuta, হস্প, टहरू_, råli,
   {{0x6d5a181b,0x3ce601fa,0x26c38d9a,0x6ef401b9}},	//   _juta, _koov_, rdjo_, _làbo,
   {{0x6d5a8d9b,0x26c10169,0xa4f1026a,0x7cf50037}},	//   _muta, _waho_, _dışı_, _lárn,
   {{0x63a48d9c,0x28d6152c,0x3ce68d9d,0x26c18d9e}},	// [9530] gtin, धारि, _moov_, _taho_,
   {{0x7cf50231,0x7cff0065,0x28a5055c,0x00000000}},	//   _nárn, _kàrù, ग्रि, --,
   {{0x7cfc00fb,0x6d5a8d9f,0x63a400ca,0x80ca04f1}},	//   _kérd, _nuta, atin, _सोहे,
   {{0xd011003f,0xb4db009c,0x63a48da0,0x2ba9417a}},	//   ولا_, _dhàc, btin, _कहला,
   {{0x6d5a8da1,0x63a48da2,0xdbf100b6,0x29192e7e}},	//   _auta, ctin, _přív, insa_,
   {{0x6d5a8da3,0x398301e8,0x7cf50328,0xe2f90565}},	//   _buta, yıs_, _cárn, _тегі_,
   {{0x78ad03ce,0x6d5a1114,0x7bc700d9,0x3f760034}},	//   _obav, _cuta, ājum, ału_,
   {{0x6d5a02a4,0xab656eb1,0x5578006e,0x98a000c4}},	//   _duta, овил, זעהן_, _ikić_,
   {{0xeab9370d,0xa3df00b6,0x9f6300ce,0x00000000}},	//   айп_, तहट_, övät_, --,
   {{0x78ad7429,0x7bdb008a,0x29198da4,0x2fcd03a9}},	//   _abav, rxuu, ensa_, _ireg_,
   {{0xd9462d06,0x6d5a66f1,0x3940006c,0x63a40827}},	//   жени, _guta, _phis_, ztin,
   {{0x63a48da5,0x28a505cd,0xb4e800b7,0x7e7a0381}},	//   ytin, ग्लि, _भवे_, _zetp,
   {{0xe73a2ea7,0x7cf50018,0xbbeb003f,0x63a48da6}},	//   ием_, _háro, _حرام_, xtin,
   {{0x7f5b0694,0x7cf50018,0x29197ea4,0x3ce6006c}},	//   _muuq, _káro, ansa_, _zoov_,
   {{0x39401723,0x7bc98da7,0x3ce601fa,0x69160087}},	//   _this_, lveu, _yoov_, jšeg,
   {{0x63a48da8,0x68fd0364,0x00000000,0x00000000}},	//   ttin, chsd, --, --,
   {{0x63a48da9,0x130a013f,0x03a323b8,0x6737003e}},	// [9540] utin, анай_, мито, ðgjö,
   {{0x63a48daa,0x78ad8dab,0x16aa21b4,0x00000000}},	//   rtin, _zbav, _твои_, --,
   {{0x7cf50074,0x5bb6000d,0x645a020a,0x7bcd00c6}},	//   _náro, _अन्व, _ştiu, _šaul,
   {{0x6d5a8dac,0x63a48dad,0x7cfc0018,0x28dd0d77}},	//   _ruta, ptin, _kére, यायि,
   {{0x6d5a8dae,0xae9a0037,0x63a401ee,0xdfa60076}},	//   _suta, لضغط_, qtin, تحضي,
   {{0x6d5a8daf,0x24808db0,0x7cfc0018,0x141b00a1}},	//   _puta, laim_, _mére, _כוכב,
   {{0x7cfc0042,0xc8ca0104,0x7e7a8db1,0x7cf50103}},	//   _lére, ियाट, _vetp, _várn,
   {{0x6d5c2bb5,0x24801ac3,0x7e7a4bdc,0x6ef4009c}},	//   _éram, naim_, _wetp, _tàbo,
   {{0xd0121850,0x6d5a006d,0x2d5100c4,0x2fcd436f}},	//   _غلط_, _wuta, _išel_, _greg_,
   {{0x6d5a8db2,0x28dd0d7a,0x78ad028d,0x3f800138}},	//   _tuta, याभि, _sbav, šius_,
   {{0xa2db152c,0x7cfc8db3,0x6d5a00f9,0xdca60396}},	//   नात्, _aére, _uuta, _мажи,
   {{0x69c80212,0x7cfc0103,0xa3ca0caf,0x2bbc023a}},	//   rvde, _bére, लटा_, ्टदा,
   {{0xd83b01b6,0x7cf50579,0x7cfc0161,0x24800076}},	//   рэн_, _záro, _cére, daim_,
   {{0x7c2200dc,0xdcf80138,0x7cf5033c,0x7cfc00fc}},	//   _ixor, tuvė, _lárl, _dére,
   {{0x6d420019,0x67f10032,0xa4d5036c,0x660203e3}},	//   _khoa, _bójú, пові, _ƙoka,
   {{0x245814fa,0x7aea00d9,0x24f81402,0x2480109d}},	//   жать_, žotā, онсы_, gaim_,
   {{0x7cfc0257,0x2bcd08d4,0xfbbc00a8,0x00000000}},	// [9550] _gére, ़िया, ्टिम, --,
   {{0x28ac009f,0x82d8002d,0x00000000,0x00000000}},	//   ट्ठि, одус_, --, --,
   {{0x7f5b008a,0x116a00cd,0x2fcd060f,0x24800037}},	//   _suuq, مللی_, _sreg_, baim_,
   {{0xfbbc00b6,0x2fcd8db4,0x6efd03a9,0x1db40096}},	//   ्टाम, _preg_, _mèbe, ंबईत,
   {{0x9f3500d6,0x7c220052,0xa2db0f8f,0x00000000}},	//   педі, _nxor, नाद्, --,
   {{0x6d4201c8,0x7cf58db5,0xed59245c,0x6916033b}},	//   _ahoa, _páro, бок_, pšeg,
   {{0x6d42009c,0x63b9071d,0x8ccc0c38,0x4087001f}},	//   _bhoa, şanı, _दोहो, _муаб,
   {{0x7cf50068,0x2fcd8db6,0x8b950d81,0x6d42020b}},	//   _váro, _treg_, проч, _choa,
   {{0x3ec40084,0x2d980149,0x6d42009c,0x7bc400c6}},	//   östä_, _åren_, _dhoa, _šiur,
   {{0x7bc90257,0x7cf50103,0x4ad20285,0x752d01c8}},	//   rveu, _táro, तागव, hoaz,
   {{0x7c2200dc,0x7cfc0301,0x7bc900e7,0x6d42009c}},	//   _exor, _sére, sveu, _fhoa,
   {{0x7cfc255c,0x69ac09d0,0x61314796,0x752d01ff}},	//   _pére, _जहरी, måls, joaz,
   {{0x7cf50103,0x6d498db7,0x69160094,0x248000bc}},	//   _járm, mmea, všed, vaim_,
   {{0xb8f304dd,0x6d498db8,0x7cfc01f9,0x00000000}},	//   _हो_, lmea, _vére, --,
   {{0x1fb8055c,0x69dc28b4,0x00000000,0x00000000}},	//   _इन्ड, äret, --, --,
   {{0x7d1b8db9,0x6d4901b5,0x77862a84,0x7cfc01f9}},	//   nnus, nmea, _елиз, _tére,
   {{0x24800a1b,0x7cfc2027,0x6d490a02,0xaad00096}},	// [9560] raim_, _hérc, imea, _थोडक,
   {{0x6d490037,0x66270103,0x00000000,0x00000000}},	//   hmea, érké, --, --,
   {{0xc219004d,0x00000000,0x00000000,0x00000000}},	//   оєї_, --, --, --,
   {{0x7cfc0933,0x7cf50018,0x00e60084,0x4fc602e3}},	//   _mérc, _bárm, яжен, зска,
   {{0xa49b0154,0x7cf50231,0x28dd1d96,0x00000000}},	//   _blòf, _cárm, याति, --,
   {{0x6daa01d4,0x7d1b00aa,0x083b006e,0x59db0213}},	//   _fəal, enus, זענל, यमार,
   {{0x43438dba,0xb4db01ec,0x1ea90568,0x0dca007e}},	//   _черв, _mhàn, تاني_, сули_,
   {{0x7cf522a4,0x7d1b4ab2,0x8fa66ab4,0x09b40033}},	//   _fárm, gnus, _набе, টিমা,
   {{0xa49b05aa,0xdd9005bc,0x00000000,0x00000000}},	//   _imòt, روک_, --, --,
   {{0x6d428dbb,0xfee900e3,0xb4db00de,0x6d49009c}},	//   _whoa, _وعلى_, _nhàn, amea,
   {{0x672e02dd,0x386d1ea5,0x6d420019,0x3f862ee8}},	//   dobj, ñero_, _thoa, lsou_,
   {{0xdca61c16,0x6d493e7c,0x7c2201e9,0xddc83ea4}},	//   _хади, cmea, _txor, _kedž,
   {{0x3f868dbc,0xddc800e7,0x7c2201ee,0x2c08001c}},	//   nsou_, _jedž, _uxor, _بعضی_,
   {{0xb4db8dbd,0xddc801b3,0xe5730cc8,0x6d550042}},	//   _chàn, _medž, فطر_, _ézar,
   {{0x28dd0553,0xa2db0d61,0xb4db01b9,0x752d8dbe}},	//   यादि, नास्, _dhàn, toaz,
   {{0x2eb905d4,0x645a00d3,0x7aea01df,0xa99b0327}},	//   _इस्त, _ştir, _hoft, _הבהר,
   {{0xddc80b14,0x3f86030b,0x6eef052f,0x69c50088}},	// [9570] _nedž, jsou_, _købt, _áher,
   {{0x7bcd0138,0xd7fc00ca,0xd25b01b3,0x81b60033}},	//   _šauk, _להחל, сца_, জিন_,
   {{0xaaae1388,0xf1c201d3,0x7aea044c,0x4aae0386}},	//   ज्यक, jušā_, _moft, ज्यव,
   {{0x291900cd,0x6ef4009c,0x7aea1556,0xa2db00b7}},	//   érah_, _hàbh, _loft, नाह्,
   {{0x3ce003a2,0x00000000,0x00000000,0x00000000}},	//   काने_, --, --, --,
   {{0xe8da00af,0x2bb60251,0xddc802ef,0x2d5100b6}},	//   _बच्च, _अनजा, _dedž, _všem_,
   {{0x7bc20154,0x6d498dbf,0x00000000,0x00000000}},	//   _asou, tmea, --, --,
   {{0xed56013d,0xddc800e7,0x6ef401b9,0x799a0079}},	//   мощ_, _fedž, _làbh, dutw,
   {{0x6d4903e9,0xddc86126,0x0b451da9,0x6aba00b3}},	//   rmea, _gedž, мнин, fetf,
   {{0xff5300e3,0x38698dc0,0x3cff02ac,0x6d490cc2}},	//   _أخر_, _afar_, shuv_, smea,
   {{0x7bc28dc1,0x7aea8dc2,0x7cee0441,0xf2df00fe}},	//   _esou, _doft, _cùrs, _quây_,
   {{0xc6890089,0x7cf50103,0x38690052,0x00000000}},	//   _כא_, _márk, _cfar_, --,
   {{0xfaa51940,0xe9db001c,0x99d5001c,0x69dc02c3}},	//   _жало, _گذشت_, ستگا, ärer,
   {{0x3cfd023e,0x2bbc030b,0x6ef4009c,0x2cad03c3}},	//   _hlwv_, ्टरा, _càbh, lfed_,
   {{0x7cfc1ee9,0x64a68dc3,0xe7371c4c,0xe5a303bf}},	//   _héra, мава, фер_, кири,
   {{0x6eef02b6,0x672e6727,0x3ce000c3,0x2cad8dc4}},	//   _købs, sobj, काये_, nfed_,
   {{0xb4db011b,0xb4be00a5,0x6ef401ec,0x72c6001f}},	// [9580] _thàn, _इसी_, _fàbh, мбаз,
   {{0x61382e64,0xb0c62fc2,0x2d87038c,0xddc80477}},	//   míli, _रोजग, ksne_, _redž,
   {{0xddd808a9,0x7cf50018,0x2d870cc9,0xddc80b14}},	//   kavš, _várj, jsne_, _sedž,
   {{0x7cf5030b,0x69c3007e,0x0cd80033,0x31be00b6}},	//   _dárk, _msne, _তত্ত, _vůz_,
   {{0xddd808a9,0x6ef405fe,0xb4db01b9,0x68fd0216}},	//   davš, _hàbi, _mhàl, ërdi,
   {{0xbd6a1031,0x6b9b34b0,0x3f863ef1,0x644302c6}},	//   орие_, duug, rsou_, řnic,
   {{0xf98700fb,0x3f868dc5,0xa2db0efb,0xa49b01ec}},	//   _جب_, ssou_, नार्, _flòd,
   {{0x7aea127d,0x672104fa,0xddc800e7,0xdb19042c}},	//   _soft, člji, _tedž, _erwü,
   {{0x7aea00d3,0x7cfc00fd,0x29020188,0x6ef400b3}},	//   _poft, _céra, dhka_, _làbi,
   {{0x7aea00dd,0x78a40042,0x7cfc00fd,0x38698dc6}},	//   _qoft, _aciv, _déra, _sfar_,
   {{0xb4db009c,0x611c033b,0xdee3008f,0x6ef401b9}},	//   _bhàl, včlj, _шофи, _ràbh,
   {{0x61e30149,0xb4db009c,0x6cd30d59,0x38690052}},	//   änli, _chàl, _لقما, _qfar_,
   {{0x628e28d9,0x69c37ceb,0x7cfc56e5,0x613848a9}},	//   _odbo, _esne, _géra, gíli,
   {{0xaff900c1,0xa3d20287,0xbbbc1178,0x7cee01ec}},	//   פּרי, विन_, ्टीक, _tùrs,
   {{0xe93b0781,0xb4db009c,0x16340110,0x7cfc0113}},	//   _وسعت_, _fhàl, веря, _zéra,
   {{0x3ea908c5,0x628e0150,0x26da05aa,0x662501d3}},	//   đati_, _adbo, _enpo_, _ārkā,
   {{0x61381f4a,0xa87c00ca,0x7cfc0072,0xa2db0469}},	// [9590] cíli, _ואחר, _xéra, नाल्,
   {{0x28dd0403,0x7cf56db0,0x31670072,0xddd80995}},	//   यावि, _párk, ínzo_, zavš,
   {{0x68ed01e9,0x2d9c8dc7,0x6ef400ee,0x6edd0096}},	//   _koad, juve_, _gàbi, पासु,
   {{0x78bd8dc8,0x628e00f9,0x00000000,0x00000000}},	//   nesv, _edbo, --, --,
   {{0x645d0009,0x68ed02c9,0x3f89014b,0xa2a742d4}},	//   _igsi, _moad, éau_, _चाप्,
   {{0x68ed8dc9,0x6efd0113,0xed590217,0xb4db009c}},	//   _load, _bèba, пок_, _mhàm,
   {{0x62858dca,0x613870f9,0xddd80995,0x78bd032e}},	//   maho, zíli, tavš, kesv,
   {{0xd658004f,0x62858dcb,0x61f8038c,0x4439603b}},	//   ויות_, laho, øvle, _kys_,
   {{0x60db8dcc,0x61381097,0xfbd104f4,0x5f950018}},	//   _inum, xíli, اتب_, _سلائ,
   {{0x62854c9c,0x7cf58dcd,0x78a400e5,0x7cfc8dce}},	//   naho, _mári, _sciv, _véra,
   {{0x44394e5f,0xc33200f5,0x7cf50037,0x68ed0575}},	//   _lys_, רוי_, _lári, _boad,
   {{0xb4be8dcf,0x7cfc8dd0,0x68ed036f,0x3ce0009d}},	//   _इसे_, _hérn, _coad, काणे_,
   {{0xb8e80067,0x62858dd1,0x68ed36a2,0x6d590bb6}},	//   _उस_, kaho, _doad, _iiwa,
   {{0x29028dd2,0x6d594ee1,0x613832c7,0x62858dd3}},	//   shka_, _hiwa, ríli, jaho,
   {{0x6d593064,0x61388dd4,0x386b00e3,0x62858dd5}},	//   _kiwa, síli, éirí_, daho,
   {{0x6d5939a0,0x07a607ec,0x44398dd6,0x60db0cea}},	//   _jiwa, _заин, _bys_, _nnum,
   {{0x44260303,0x28dd06ed,0x2bd2417a,0x7cf58dd7}},	// [95a0] ço_, यारि, तिया, _cári,
   {{0x60db8dd8,0x28ac68b9,0x6d590dcf,0xa85700a1}},	//   _anum, ट्रि, _liwa, _איפה_,
   {{0x5ec80081,0x29006e6d,0x6d59010a,0x00000000}},	//   লামে, _klia_, _oiwa, --,
   {{0x6d598dd9,0x2bd208c0,0x60c90143,0x44391a65}},	//   _niwa, तिमा, _caem, _fys_,
   {{0x62858dda,0x087700c1,0xc9530266,0x44398ddb}},	//   baho, גענט_, אמא_, _gys_,
   {{0x6d59006d,0x2d9c8ddc,0xe8020fef,0x040b0023}},	//   _aiwa, tuve_, रैया_, _lưỡn,
   {{0x6d5913d2,0x2bd20eeb,0xb87b0220,0xa2c902d5}},	//   _biwa, तिभा, rkíz, _होट्,
   {{0x6d598ddd,0xed570831,0x60c90167,0x81b60033}},	//   _ciwa, ној_, _gaem, জিদ_,
   {{0x53c90b94,0x6b890396,0xd1170089,0x68ed8dde}},	//   रिएश, gseg, _נקמה_, _road,
   {{0x29120361,0x68ed002b,0xa49b05aa,0xa3c300c3}},	//   _amya_, _soad, _klòc, ्ित_,
   {{0xf8dd0d88,0x131700a1,0x290001ec,0xa3d20861}},	//   यालय, תחיל_, _blia_, विड_,
   {{0x62858ddf,0x6b898de0,0x040b00de,0x6d598de1}},	//   zaho, bseg, _cưỡn, _giwa,
   {{0x62858de2,0x040b0019,0x7cfc8de3,0x68ed0558}},	//   yaho, _dưỡn, _héro, _voad,
   {{0x44395a58,0x6d59194b,0x443f003d,0xa2d0030b}},	//   _rys_, _ziwa, _ġu_, _डोल्,
   {{0x645d0124,0x68ed60f2,0x2900037a,0xd5b8872f}},	//   _pgsi, _toad, _flia_, нст_,
   {{0xf98f16c4,0x9a3b00a1,0x98a501d3,0x62858de4}},	//   _ابو_, _מתוק, ēlē_, waho,
   {{0x545502b3,0x62858de5,0x60c90167,0x00000000}},	// [95b0] тват, taho, _raem, --,
   {{0x2d8c8de6,0x7cf50396,0x60c98de7,0x691616ac}},	//   _ovde_, _vári, _saem, nšen,
   {{0x394926f7,0x44390665,0xa2d0009d,0x60db0072}},	//   _khas_, _wys_, _डोळ्, _pnum,
   {{0x62858de8,0x443900a5,0x00000000,0x00000000}},	//   saho, _tys_, --, --,
   {{0x6d594725,0x7cfc0257,0x2d8c00e7,0x31580037}},	//   _riwa, _aéro, _avde_, رجمة_,
   {{0x63ad11b9,0x6d598de9,0xa3c006ed,0x7cfc0113}},	//   mtan, _siwa, ूटर_, _béro,
   {{0x60c98dea,0x69160146,0xa928035d,0x6d598deb}},	//   _taem, dšen, nažé, _piwa,
   {{0x92588dec,0x7cfc8ded,0x6b898dee,0x60db52ef}},	//   _част_, _déro, tseg, _unum,
   {{0x6d590010,0x2d8c026a,0x6b8900bc,0x00000000}},	//   _viwa, _evde_, useg, --,
   {{0xdb0001cd,0x6d592d4f,0xa3d2046e,0x394906a8}},	//   ttmá, _wiwa, वित_, _ahas_,
   {{0x6b898def,0x290063b2,0x63ad8df0,0x39498df1}},	//   sseg, _plia_, htan, _bhas_,
   {{0xdb00025b,0x39498df2,0xa3c161b6,0x6b8900bc}},	//   rtmá, _chas_, ंबा_, pseg,
   {{0x63ad75ce,0x394901ec,0x7529015c,0x7cfc8df3}},	//   jtan, _dhas_, čezl, _mérl,
   {{0x2cbf50d9,0x7c2400c6,0xf8c70103,0x7cfc0113}},	//   leud_, _žirg, áért_, _yéro,
   {{0x63ad8df4,0x394901f7,0x28aa058f,0x6efd0154}},	//   etan, _fhas_, _कापि, _lèbo,
   {{0x2cbf02ad,0x3949009e,0x29000062,0x69de05db}},	//   neud_, _ghas_, _ulia_, _špeg,
   {{0x63ad8df5,0xa3d21efb,0xdcea042d,0x386003a9}},	// [95c0] gtan, विध_, žiće, _igir_,
   {{0x1303529c,0xc7d700ca,0x479b021e,0x6efd0113}},	//   азум, _יופי_, _קייס, _sèbn,
   {{0x63ad8df6,0xa50a1d7b,0x7cfc0103,0x7764037a}},	//   atan, _жена_, _bérl, _huix,
   {{0x63ad8df7,0x6f01041c,0x28aa0852,0xc4831bc1}},	//   btan, _allc, _काफि, _клюк,
   {{0x10a31a67,0x63ad226a,0xdee611db,0x7cfc2831}},	//   ричн, ctan, коди, _séro,
   {{0x7cfc8df8,0x09c80081,0xdd9002fc,0x776400ee}},	//   _péro, ষমতা, موت_, _muix,
   {{0x91e3060b,0x78b6025b,0xe29700c9,0x00000000}},	//   _коре, _obyv, _јас_, --,
   {{0x7cfc0349,0x80ca099d,0x00000000,0x00000000}},	//   _véro, _सोचे, --, --,
   {{0xfd0f00bf,0x9eaa00c9,0xf8bf0257,0x3cef00b3}},	//   تجو_, _оваа_, nnée_, _dogv_,
   {{0x38608df9,0x691600b6,0x7cfc01dc,0x3ae90206}},	//   _agir_, ušen, _téro, _kúpy_,
   {{0x692404a3,0x63ad0a00,0x7bcd6a3c,0x00000000}},	//   rđen, ztan, _šaut, --,
   {{0x63ad277e,0xd90f09b4,0x7d080065,0x776400ee}},	//   ytan, تیب_, _dèrù, _buix,
   {{0x69168dfa,0x7d028dfb,0xd83801b6,0x776400ee}},	//   pšen, _ilos, вэр_, _cuix,
   {{0xd7f852de,0x8c4307df,0xb8fa8dfc,0x6f180146}},	//   тую_, _тече, _डो_, nivc,
   {{0x3949022e,0x80d8030b,0xb9090033,0x6d4e0036}},	//   _thas_, _नोभे, _যত_, _èbas,
   {{0x69246a54,0xd49859b2,0xf8bf0072,0xc6560103}},	//   nđel, кру_, roés_, افِک,
   {{0x29198dfd,0x63ad8dfe,0xf8bf0257,0x7bcd0072}},	// [95d0] misa_, utan, gnée_, _áaut,
   {{0x29198dff,0x63ad8e00,0x64430092,0x6f180128}},	//   lisa_, rtan, ənil, jivc,
   {{0x7d028e01,0xc8aa007d,0x7cf58e02,0xf8aa0251}},	//   _olos, _कामट, _záru, _कामय,
   {{0x29197e73,0x63ad8e03,0x7cf50103,0xb4db009c}},	//   nisa_, ptan, _járt, _ohài,
   {{0x7cf50b05,0x83840109,0x6efd022b,0x1fa700d3}},	//   _márt, _высе, _fèbl, трег,
   {{0x24898e04,0x7d020383,0xdb000149,0x7cfc0072}},	//   laam_, _alos, ntmä, _dérm,
   {{0x29198e05,0x7cfc1b21,0x00000000,0x00000000}},	//   kisa_, _térl, --, --,
   {{0x7d020054,0x248903ee,0xa2db3fac,0xb4db0441}},	//   _clos, naam_, नाक्, _bhài,
   {{0x29198e06,0x7cfc8e07,0x69dc13b9,0xb4db0441}},	//   disa_, _kérj, åren, _chài,
   {{0xa3ab00c3,0x77640428,0x81b60033,0xb4db01f7}},	//   _गमन_, _ruix, জির_, _dhài,
   {{0x29191b24,0x201000c6,0x7cf58e08,0x00000000}},	//   fisa_, ėlių_, _bárt, --,
   {{0x7cf500e3,0x29190517,0xc19a006e,0x2489450d}},	//   _cárt, gisa_, עשרי, jaam_,
   {{0x3ce0007d,0x776408a8,0xb4db0049,0xe8f72390}},	//   कारे_, _quix, _ghài, уля_,
   {{0xe5a62b49,0x7d02005f,0x673503e5,0xa3d20be4}},	//   лиги, _zlos, gozj, विस_,
   {{0x29195b7d,0xd6270d5e,0x6446007f,0x24890381}},	//   bisa_, горе_, _szki, faam_,
   {{0x291934df,0x65650113,0x776400b3,0x6f1809ac}},	//   cisa_, _duhh, _tuix, zivc,
   {{0x93aa0391,0x032622cb,0x27e60052,0x7cf50e2e}},	// [95e0] عارف_, гдан, _çon_, _hárs,
   {{0xf8bf025a,0x65658e09,0x3cda009f,0x91e68e0a}},	//   rnée_, _fuhh, _खोने_, лозе,
   {{0xaaa61cff,0x691600d2,0x00000000,0x00000000}},	//   _खासक, yšel, --, --,
   {{0xbfaa1055,0x7cfc0072,0x104a00ba,0x647500ae}},	//   етке_, _pérm, няли_, _вырф,
   {{0x6f1804a3,0xb4c0245a,0x75248e0b,0xd12f0037}},	//   tivc, ंजी_, mniz, أمن_,
   {{0xa3c12235,0x2919019b,0x91860781,0x51860182}},	//   ंबर_, zisa_, _مجرم, _مشرق,
   {{0x3ce000c0,0x6d4b00e7,0x29191d60,0x7d028e0c}},	//   काले_, _bhga, yisa_, _plos,
   {{0x7cfc2c90,0xb88708a8,0x6b9b8e0d,0x3fa6097d}},	//   _térm, _muíñ, frug, _مصطف,
   {{0x29191139,0x6b9b8e0e,0x2aaa2b49,0x60c2024a}},	//   visa_, grug, нтно_, meom,
   {{0x24890126,0x29196a84,0x6d4b01ff,0x60c2313a}},	//   zaam_, wisa_, _ehga, leom,
   {{0x29198e0f,0x6916013f,0x6ef405fe,0x7cf510a8}},	//   tisa_, pšel, _fàbr, _párt,
   {{0x6b9b8e10,0x7d0200c2,0x7cf50328,0x7cfc0103}},	//   brug, _ulos, _dárs, _mérk,
   {{0x29198e11,0x68fd5b45,0x7cf501f9,0xdb000216}},	//   risa_, rksd, _várt, numë,
   {{0x29190201,0x27ff003d,0x3d1a0139,0x6d40676b}},	//   sisa_, ġun_, _fàwè_, llma,
   {{0xb887002b,0xc4720134,0x2bd20386,0xdb008e12}},	//   _cuíñ, _ọtọb, तिवा, rtmä,
   {{0x69ca003d,0x442b0428,0x6b82083e,0x752427f0}},	//   _isfe, _pxc_, _kwog, gniz,
   {{0x6d40069d,0x28aa382d,0x24892b25,0xd3710604}},	// [95f0] ilma, _काति, raam_, زها_,
   {{0x2bb70251,0x75248e13,0x24898e14,0xd34700cd}},	//   _अहसा, aniz, saam_, ایسه_,
   {{0x26c38e15,0x6d4001c2,0xf770001c,0x6b8206b0}},	//   mejo_, klma, _وای_, _lwog,
   {{0x26c38e16,0x60c202e5,0x4fd55cb1,0xe5c4004d}},	//   lejo_, geom, ижет, _усьо,
   {{0xa2d0009d,0xafe50ed4,0x00000000,0x00000000}},	//   _डोक्, ролл, --, --,
   {{0x26c38e17,0xa3d206ed,0x26d100e7,0x6d4b01c2}},	//   nejo_, विर_, ndzo_, _shga,
   {{0x6b820383,0x7cfc01f9,0x60c2010a,0x00000000}},	//   _awog, _kérh, beom, --,
   {{0x2d670995,0x6b9b7186,0x6b822cb9,0x62950357}},	//   _uđem_, trug, _bwog, _hdzo,
   {{0x69d88e18,0x28d90bf5,0x62878e19,0x2d9c19ab}},	//   _arve, _बोधि, _kejo, arve_,
   {{0x26c30b27,0x6b9b8e1a,0xe9d90b1e,0x6d408848}},	//   jejo_, rrug, вко_, alma,
   {{0x62878e1b,0x69d800e9,0x26c38e1c,0xf2d2006e}},	//   _mejo, _crve, dejo_, קעט_,
   {{0x69d800e9,0x6b9b02e6,0x69de0181,0x62878e1d}},	//   _drve, prug, _špec, _lejo,
   {{0x290c013f,0x3cff023e,0x69d88e1e,0x7d098e1f}},	//   ėda_, mkuv_, _erve, mhes,
   {{0x7cf50068,0x3ced18b4,0x6287030b,0xd6260037}},	//   _társ, ljev_, _nejo, لعزي,
   {{0x2d9820ab,0x2d51033b,0xdce105db,0x7d090350}},	//   _året_, _ušes_, _lulč, ohes,
   {{0x8883008f,0x94268e20,0x7d098e21,0x7d1b8e22}},	//   _длъж, амбе, nhes, nius,
   {{0xf7720678,0x26c38e23,0x03a615db,0x53a635c1}},	// [9600] _باب_, bejo_, ризо, разб,
   {{0x7d1b8e24,0x7cf50610,0x96964170,0x75240063}},	//   hius, _márq, _триш, sniz,
   {{0x7d1b8e25,0xa2a700c3,0x41aa30cc,0x628701d3}},	//   kius, _चार्, твен_, _dejo,
   {{0x53a6433f,0x3cff023e,0x03a61ca5,0x19b60142}},	//   _камб, jkuv_, _кимо, יפער_,
   {{0x7d098e26,0xe3b2097d,0x7d1b8e27,0x60c28e28}},	//   dhes, _برج_, dius, reom,
   {{0x98ab00a5,0x63a48e29,0x7cfc0018,0x62878e2a}},	//   mocą_, muin, _térk, _gejo,
   {{0x63a48e2b,0xb23a00e3,0x7d1b0072,0x7cfc201c}},	//   luin, _شكرا_, fius, _héri,
   {{0x6b820c56,0x92a600a5,0x7d1b00e5,0x7d0900ca}},	//   _pwog, _wyłą, gius, ghes,
   {{0x7cf506cb,0x6d40003e,0xa2db0096,0x63a43d0f}},	//   _párr, rlma, नाच्, nuin,
   {{0x7cfc5459,0x2d9c00b6,0x2fc9014b,0x00000000}},	//   _méri, prve_, çage_, --,
   {{0x63a407bc,0x7d1b2e9a,0xf2d900c1,0x3cff023e}},	//   huin, bius, אַרל, bkuv_,
   {{0x7d098e2c,0x7d1b222d,0x63a48e2d,0xb4c5034c}},	//   ches, cius, kuin, _एसे_,
   {{0x315700c1,0x8c433db3,0xe667105e,0x7cf5037a}},	//   ייטן_, _деце, итво, _tárr,
   {{0x63a48e2e,0x7cfc003e,0x46de03b3,0x98bf0233}},	//   duin, _sérh, मागह, rptı_,
   {{0x26d10067,0x62878e2f,0x26c38e30,0xfa77040a}},	//   rdzo_, _rejo, rejo_, _דעות_,
   {{0x26c38e31,0x3f8f0150,0x7cfc1561,0x62872bc7}},	//   sejo_, ysgu_, _béri, _sejo,
   {{0x63a45bdb,0x26c38e32,0x62870095,0x6e2d026a}},	// [9610] guin, pejo_, _pejo, ğabi,
   {{0x883c00a1,0x6e2d01e8,0x7cfc0257,0x7cf526aa}},	//   _בתחו, şabi, _déri, _lárp,
   {{0x75d50604,0xb4db0441,0xdce100c6,0x6efd0154}},	//   _ايجا, _bhàt, _sulč, _wèbk,
   {{0x7cfc8e33,0xb1250081,0xb4db009c,0x63a48e34}},	//   _féri, বত্ব_, _chàt, buin,
   {{0x63a400d3,0x3cff01fa,0x7f19097a,0xb4db009c}},	//   cuin, vkuv_, ліку_, _dhàt,
   {{0x1dd300aa,0x00000000,0x00000000,0x00000000}},	//   थिलत, --, --, --,
   {{0xa19455dc,0xb4db01b9,0xaca30294,0x92941fc4}},	//   _марч, _fhàt, shọn, _фасц,
   {{0x51840a71,0xd5d83845,0xb4c50dba,0x7cfc03a9}},	//   _фура, डितज, _एसो_, _yéri,
   {{0x3ced0b27,0x7d1b8e35,0x7d098778,0xdb092ee8}},	//   rjev_, rius, rhes, steí,
   {{0xfe702761,0x7d098e36,0x3cff8e37,0x78ad05b4}},	//   _قدم_, shes, skuv_, _acav,
   {{0x7d098e38,0x657701bb,0x63a401c0,0x6efd0383}},	//   phes, _ntxh, zuin, _nèbi,
   {{0x05090033,0x00000000,0x00000000,0x00000000}},	//   রচুর_, --, --, --,
   {{0xeb9900a9,0xdb0b052f,0x7bd905bd,0x00000000}},	//   _сил_, _opgø, _urwu, --,
   {{0xa3c103a2,0xda7b2917,0x00000000,0x00000000}},	//   ंबई_, _ряд_, --, --,
   {{0x7ae38e39,0x7cfc2e00,0x76071f5d,0xe8d900de}},	//   _innt, _séri, берг_, _giỏ_,
   {{0x7cfc3421,0xb466313c,0x63a48e3a,0x6efd015e}},	//   _péri, скал, tuin, _dèbi,
   {{0x68e48950,0xa49b01b9,0x044a8e3b,0x212600c4}},	// [9620] _inid, _glòm, упак_, vnoh_,
   {{0x63a4117b,0x7cfc025a,0xb4db01f7,0x290200c2}},	//   ruin, _véri, _bhàs, lkka_,
   {{0x63a48e3c,0x28dd009d,0xb4db01b9,0x68f6026a}},	//   suin, याचि, _chàs, _koyd,
   {{0xb4db01ec,0x2902007b,0x66010120,0x92e80a43}},	//   _dhàs, nkka_, ølke, বসে_,
   {{0x29020084,0x24802b9c,0x1fb600c2,0xdb008e3d}},	//   ikka_, mbim_, ссер, sumé,
   {{0x4dbe0081,0xa3bd00c3,0xb4db01f7,0x2f0b0120}},	//   ্মসূ, _आहत_, _fhàs, _nøgd_,
   {{0x68e40af0,0xa49b0032,0x7cf5034f,0xb4db009c}},	//   _onid, _amòy, _párp, _ghàs,
   {{0xbb741fdb,0x7ae30441,0x248003e3,0x644b09dc}},	//   огиј, _annt, nbim_, ügig,
   {{0xc0060686,0x61fe0565,0x30060120,0x00000000}},	//   _упак, lypl, _узаг, --,
   {{0x78ad8e3e,0x68e48e3f,0x37be0033,0x290288ab}},	//   _scav, _anid, ইটার, ekka_,
   {{0xdd9200bf,0x81b60081,0x68f68e40,0x69cf0034}},	//   _روش_, জিক_, _boyd, łcen,
   {{0xd8430094,0x00000000,0x00000000,0x00000000}},	//   _ničí_, --, --, --,
   {{0x28aa07d5,0x69dc0c89,0x61340847,0x00000000}},	//   _कारि, æreb, _gülş, --,
   {{0x98be00d9,0x7cfc0575,0xf1c809c3,0x6b5604e6}},	//   ētā_, _cérv, रबान, _утех,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x183a0134,0x68e40de9,0x00000000,0x00000000}},	//   ọmụm, _gnid, --, --,
   {{0x29090694,0x36d517e9,0xb4db01f7,0x6ea90096}},	// [9630] _ilaa_, _допр, _bhàr, _घालु,
   {{0x3267032d,0x2f0b02b6,0xb4db0441,0x44270023}},	//   став, _køge_, _chàr, ăn_,
   {{0xdb090076,0x2bcf097c,0x24808e41,0x6115004d}},	//   nteá, _तैना, bbim_, оджу,
   {{0xdb0900e3,0x00000000,0x00000000,0x00000000}},	//   iteá, --, --, --,
   {{0xcf9b0831,0xff510470,0x60c400aa,0xb4db01ec}},	//   ује_, وخت_, õima, _fhàr,
   {{0x13ba006e,0xe81c007a,0xb4db01f7,0xd2f60281}},	//   _דזשע, _पइसा_, _ghàr, _وکلا_,
   {{0xace961a9,0x28aa04f8,0x69de0094,0x29020120}},	//   имка_, _कालि, _špen, ykka_,
   {{0x28d92373,0x2fcd01bb,0x8b9522f9,0xa2d1023a}},	//   _बोलि, _tseg_, ороч, ठयक्,
   {{0x68e48e42,0xa49b0154,0x212d0113,0xeb990231}},	//   _rnid, _alòk, _ijeh_, шип_,
   {{0x69060072,0x68f60555,0x3dd2007f,0x29092098}},	//   _cóen, _soyd, ływa_, _alaa_,
   {{0x2dfa0018,0xcebb00a7,0x00000000,0x00000000}},	//   _پبلک_, şəsi_, --, --,
   {{0x8afe01c2,0x68f600a7,0x7cfc8e43,0x24990381}},	//   _riƙe, _qoyd, _sérv, _ndsm_,
   {{0x3c47003f,0x26d30188,0x290200c2,0x00000000}},	//   _اضاف, _baxo_, rkka_, --,
   {{0x2bcf10ed,0x7ae38e44,0xa49b0154,0xead4007b}},	//   _तैया, _unnt, _flòk, _ночь,
   {{0x96630ea0,0x2ee50063,0x9604099d,0xf743136e}},	//   дкре, _mnlf_, रनेट_, феро,
   {{0x68e40b0b,0xd4673968,0x212d023b,0x61fe0146}},	//   _unid, жите_, _njeh_, vypl,
   {{0x2ee5008a,0x24808e45,0xdb00004d,0xd7ef0037}},	// [9640] _onlf_, rbim_, ttmø, _لكي_,
   {{0x681c0029,0xc8aa00a3,0xe29a3898,0x6b4f052f}},	//   rādī, _काँट, раж_, bøge,
   {{0x673c8e46,0x50660131,0x7c2d0088,0xf8bf0103}},	//   morj, отла, _þarf, knél_,
   {{0x7cfc00d1,0x00000000,0x00000000,0x00000000}},	//   _yéru, --, --, --,
   {{0xa3ce0e72,0x1eca007e,0x7cfc0103,0x6f1a0172}},	//   _शनि_, илди_, _mért, _pmtc,
   {{0xdd9a29db,0xa49b0139,0x7c240128,0xda1a00aa}},	//   аши_, _alòh, _žiro, _फइलत_,
   {{0xd9a8000f,0x4c94036a,0x63b62093,0x3ea00233}},	//   _कमेट, пийс, ltyn, ğit_,
   {{0x61e10068,0x3ea05f3a,0x3940023e,0x90c37bb3}},	//   _álla, şit_, _nkis_, _обсе,
   {{0xd0071121,0x63b68e47,0x2f0b052f,0x81b60033}},	//   _дете_, ntyn, _søge_, জিও_,
   {{0x29090051,0x39400138,0x8af700a7,0x673c05db}},	//   _slaa_, _akis_, _şəri, jorj,
   {{0x26d38e48,0x7cfc0b39,0xbf131f11,0x63b6007b}},	//   _raxo_, _séru, _تولب, htyn,
   {{0x26d38e49,0x88b1015a,0x7cfc014b,0x26f5023a}},	//   _saxo_, ریخچ, _péru, ीघ्र_,
   {{0xc86400d6,0xdb090037,0xab2a05d8,0xdcf801d3}},	//   дтри, steá, _кода_, ssvē,
   {{0x3ce60197,0x39400a69,0x7c2d347f,0x3afb084e}},	//   _hnov_, _ekis_, _žarg, _dêps_,
   {{0x7cfc2027,0x2bd21c0a,0x45d48e4a,0xf8bf0c90}},	//   _fért, तिका, морс, lném_,
   {{0x92a90034,0x6b4f02b6,0x337507cb,0x00000000}},	//   kułó, røge, згар, --,
   {{0x6b4f052f,0x673c4811,0x386901ff,0xdcf3007e}},	// [9650] søge, borj, _igar_, žaće,
   {{0x26c700b6,0x00000000,0x00000000,0x00000000}},	//   _úno_, --, --, --,
   {{0x69241386,0x691602dd,0xf0780174,0xc1b900e5}},	//   rđev, ršev, _ịgụn, слех_,
   {{0x55da00c1,0x657a0182,0x24990239,0x7af80170}},	//   _פֿינ, íthe, _udsm_, _lovt,
   {{0x69de033b,0xf8bf02c6,0x7bc60216,0x00000000}},	//   _špel, jném_, çkul, --,
   {{0x644f01d3,0xf8bf00b6,0x00000000,0x00000000}},	//   _izci, dném_, --, --,
   {{0x7bc272c7,0xf8bf0103,0x3ce700b7,0x00000000}},	//   _apou, tnél_, झाले_, --,
   {{0x673c0087,0x69168e4b,0x7d760037,0x00000000}},	//   zorj, nšet, أمير_, --,
   {{0x76450084,0x395200f0,0xdb09016d,0xa49b01ec}},	//   _lyhy, _rhys_, nteç, _clòi,
   {{0x38692664,0x7cfc8e4c,0x05cb0403,0xf8bf01f9}},	//   _agar_, _sért, ाबाब, snél_,
   {{0x7bc21b59,0x673c0087,0x2fdf0090,0x7cfc0143}},	//   _epou, vorj, _hrug_, _pért,
   {{0x2fdf005f,0x69d00557,0x63b600c2,0xa3cb09a1}},	//   _krug_, धिजी, ytyn, लबा_,
   {{0x673c8e4d,0x69da023e,0x7d0b01d3,0xa49b01f7}},	//   torj, avte, _ilgs, _glòi,
   {{0x4e1f04dd,0x7bda00a1,0xbb780103,0x2cad00bc}},	//   _बधाई_, _לקנו, _بلوچ_, lged_,
   {{0x386d2f54,0x649a0077,0xb4db01b9,0x39520abf}},	//   žera_, йтар_, _phàp, _thys_,
   {{0x63b60084,0x673c8e4e,0x141a0037,0x2cad8e4f}},	//   ttyn, sorj, ميزة_, nged_,
   {{0xf42a0181,0x2fdf022e,0x776d0131,0x644f007f}},	// [9660] _opäť_, _nrug_, _guax, _czci,
   {{0x27e0663f,0x63b68e50,0x7af8006c,0xae1c007a}},	//   _irin_, rtyn, _xovt, _भइलन_,
   {{0x63b68e51,0xe57700ae,0x7bdb007b,0x764500eb}},	//   styn, _нзэ_, hvuu, _gyhy,
   {{0x2fdf0021,0x63b68e52,0x8afe03e3,0x26ca039f}},	//   _brug_, ptyn, _miƙa, lebo_,
   {{0x09a8000c,0x61e10103,0x5f430281,0x6566039f}},	//   _कम्य, _álln, کنول, _iikh,
   {{0x69c30cad,0xf67a00c1,0x290b00d9,0x63a42095}},	//   _opne, זאַמ, ībai_, mrin,
   {{0x629c8e53,0x7bc28e54,0x8afe03e3,0x26d801d3}},	//   _idro, _spou, _niƙa, idro_,
   {{0x27e00649,0x2cad8e55,0xf8bf301f,0x64460f5a}},	//   _orin_, gged_, tném_, _kyki,
   {{0x63a48e56,0x628e0484,0x7cfc0102,0x8fa30e21}},	//   nrin, _kebo, _sérs, _пате,
   {{0x63a48e57,0x628e242a,0x69060072,0x65668e58}},	//   irin, _jebo, _dóem, _likh,
   {{0x63a48e59,0x64460088,0x26ca0139,0x27e08e5a}},	//   hrin, _lyki, debo_, _arin_,
   {{0x27e08e5b,0x628e8e5c,0x65660415,0x7c2d0aa0}},	//   _brin_, _lebo, _nikh, _žare,
   {{0xd83b01b6,0x7cfc10d9,0x69160220,0x27e000ae}},	//   сэн_, _férr, všet, _crin_,
   {{0x628e10e1,0x27e0624d,0xa3e000a3,0xf8bf00fd}},	//   _nebo, _drin_, थिन_, diée_,
   {{0x27e08e5d,0x16041ae6,0xa3d20096,0x3abb00ca}},	//   _erin_, रनगर_, विझ_, _המונ,
   {{0xca470080,0x63a48933,0x629c02ad,0xf8bf0257}},	//   _عليه_, frin, _adro, fiée_,
   {{0x63a48e5e,0x24580084,0x628e8e5f,0x65660efe}},	// [9670] grin, зать_, _bebo, _dikh,
   {{0x26ca8e60,0x629c01af,0x628e2ad4,0x6d4201c2}},	//   cebo_, _cdro, _cebo, _lkoa,
   {{0x32072e16,0x65668e61,0x64460063,0x3f8000ae}},	//   ány_, _fikh, _eyki, ţiul_,
   {{0x6ebf000d,0xf42a0181,0x6d424045,0xdb0000b3}},	//   ल्नु, _späť_, _nkoa, humà,
   {{0xf8bf00fd,0x32070a7f,0x335900ae,0x3fc900d1}},	//   ciée_, šny_, _мамэ_, تدای_,
   {{0x628e0d50,0x6d420139,0x670d0557,0x4dc30081}},	//   _gebo, _akoa, हसिक_, ্মসং,
   {{0x30a722de,0x62858e62,0x22a30065,0x60dd037a}},	//   _нрав, mbho, _eékà_, _ósmo,
   {{0x629c12fb,0x26d81672,0x48e80081,0x752d8e63}},	//   _zdro, zdro_, _পত্র, nnaz,
   {{0x2fdf0167,0x69dc01df,0x2cad8e4f,0xceba03e3}},	//   _urug_, æren, rged_, siƙa_,
   {{0x7c260088,0x1a05008f,0x6d420062,0x6916007e}},	//   úkra, дпом, _ekoa, jšer,
   {{0x98a60a54,0x2bdb01e4,0x6efd022b,0x00000000}},	//   мине, बिहा, _wèbs, --,
   {{0x27e00a29,0x26c102ef,0x63a48e64,0x26ca0372}},	//   _prin_, _abho_, yrin, webo_,
   {{0xeb8e1ae2,0x6d5b02fa,0x26ca8e65,0xb8f609c3}},	//   _ши_, mmua, tebo_, _हस_,
   {{0x6d498e66,0x65660060,0x63a48e67,0xdb2300c2}},	//   llea, _sikh, vrin, äräi,
   {{0x63a4646b,0xed160018,0x24920270,0x26c10062}},	//   wrin, _رہیں_, taym_, _dbho_,
   {{0x628e8e68,0x27e08e69,0x6d498350,0x752d054d}},	//   _sebo, _trin_, nlea, gnaz,
   {{0x6d4956ed,0x59d50be4,0xc95300a1,0x224c0095}},	// [9680] ilea, धिकर, _במה_, _šdk_,
   {{0x63a48e6a,0x03a3007e,0xf8bf00fd,0x6d5b023b}},	//   rrin, тифо, riée_, hmua,
   {{0x63a43b64,0xd46a02d8,0x00000000,0x00000000}},	//   srin, _мине_, --, --,
   {{0x6d5b01fa,0x628e0363,0x8fa60476,0x4fc638bc}},	//   jmua, _webo, даде, дска,
   {{0x628e8e6b,0xb4ca0e28,0x7afd00c6,0x75240361}},	//   _tebo, लजी_, ūsty, miiz,
   {{0xf8bf0018,0xdee31a9f,0x672e3feb,0x0efa0e28}},	//   tnék_, кочи, nnbj, ्सेस_,
   {{0x62633431,0x036705e1,0x00000000,0x00000000}},	//   _авра, _цирк_, --, --,
   {{0x6d5b023e,0xe8e00023,0x6d498e6c,0x60170129}},	//   gmua, _trội_, glea, ụman,
   {{0xaf2a8e6d,0xdb090381,0x00000000,0x00000000}},	//   _джаз_, cueë, --, --,
   {{0xadba00e3,0xe457006e,0x6d4901c8,0x6d5b0113}},	//   _وهذا_, ויפט_, alea, amua,
   {{0x6d498e6e,0xf2d300a1,0x1bec5dfe,0x7524270d}},	//   blea, דעת_, जमहल_, kiiz,
   {{0xcb6a02b3,0xb4db0065,0xf7870131,0xf1d14364}},	//   _даде_, _akàn, íços_, _सनसन,
   {{0xac9700bf,0x6d40022b,0x0cbc023a,0x00000000}},	//   _آنها_, moma, ्जीम, --,
   {{0x6d4011cf,0x75e40134,0xdce200c4,0x2f0b00f2}},	//   loma, _ọzay, _mioč, _løgn_,
   {{0xdb000487,0x3d0a0139,0x00000000,0x00000000}},	//   cumá, _jùwo_, --, --,
   {{0x6d408e6f,0x66f8026a,0x657a0103,0xc8674ef9}},	//   noma, _aşkı, ítha, _отпи,
   {{0x752d8e70,0x43941486,0xf66b0037,0x69de00d8}},	// [9690] rnaz, катс, _وحده_, _špeh,
   {{0x6d408e71,0x6d4901e9,0x0cbc00b6,0x00000000}},	//   homa, zlea, ्जुम, --,
   {{0x6d408e72,0xda0e00af,0x7cf50131,0xa3ab0d75}},	//   koma, ानित_, _várz, _गमक_,
   {{0xa49b009c,0x00000000,0x00000000,0x00000000}},	//   _clòt, --, --, --,
   {{0x25750149,0x2f0b01df,0x6d5b01fa,0xa49b009c}},	//   _hål_, _døgn_, vmua, _dlòt,
   {{0x63ad5bf1,0x25750429,0xda0e00a4,0x00000000}},	//   muan, _kål_, ानात_, --,
   {{0x63ad3ad9,0x6d408e73,0x200922bb,0x69dc01df}},	//   luan, foma, šai_, ærel,
   {{0x25750501,0xdfd51ad1,0xfd640134,0x63ad0350}},	//   _mål_, _побы, _ikwụ, ouan,
   {{0x6d498e74,0x6d5b8e75,0x00000000,0x00000000}},	//   rlea, rmua, --, --,
   {{0xa3e0046e,0x6d498e76,0xfaf10037,0x6d5b8e77}},	//   थित_, slea, اثة_, smua,
   {{0x6d490ba6,0x6d408e78,0x69261c2a,0xf8bf8e79}},	//   plea, boma, емна, ffé_,
   {{0x6d408e7a,0xdb0900c9,0xe8f73ae2,0x63ad0cc4}},	//   coma, nteú, елю_, kuan,
   {{0xfaa53898,0x7d090a50,0x2ba600bc,0x00000000}},	//   _зало, mkes, _खिया, --,
   {{0x63ad005a,0x7d090f79,0xfd640174,0x257517d2}},	//   duan, lkes, _okwụ, _bål_,
   {{0xfd640294,0x00000000,0x00000000,0x00000000}},	//   _nkwụ, --, --, --,
   {{0x69a40096,0x1da70034,0x63ad0a4b,0xdef8009e}},	//   _किती, _गिनत, fuan, _viċi_,
   {{0x63ad8e7b,0xfd640857,0x03a35e66,0xa49b0383}},	// [96a0] guan, _akwụ, лито, _alòs,
   {{0x28c1074c,0x0686013f,0xdbc6007a,0x2cbf0479}},	//   ष्ठि, _ягон, _tööa, hfud_,
   {{0x6d4047cf,0x7d098e7c,0xa49b8e7d,0x00000000}},	//   yoma, kkes, _clòs, --,
   {{0x26da068d,0x397a006e,0xa2c11677,0xdfda00e5}},	//   _hapo_, לטענ, र्ब्, зък_,
   {{0xe7e38e7e,0x63ad037a,0x26da8e7f,0xd12f0cc8}},	//   खिया_, cuan, _kapo_, حمن_,
   {{0x6d408e80,0x2d8c07ac,0x8afe0022,0x26da8ada}},	//   woma, _pwde_, _riƙo, _japo_,
   {{0x2d9a0fc5,0x7d0901c2,0x5d662cc3,0x26da3f1b}},	//   épe_, fkes, нтиз, _mapo_,
   {{0xc5f300a1,0xd9e3009f,0x91bb00ca,0x8d730103}},	//   רדה_, गिनत_, _ממלי, داوا,
   {{0x6d408e81,0xef1a0f84,0x5ce300c2,0x3f8d030a}},	//   roma, _ема_, ующа, _gweu_,
   {{0x2d6e000d,0x6b4f01c5,0x26da8e82,0xb4db0139}},	//   _před_, søgn, _napo_, _akàl,
   {{0x6d408e83,0xddc8007f,0x00000000,0x00000000}},	//   poma, _wzdł, --, --,
   {{0x6d403665,0x69b100a5,0x386d01df,0x63ad37b7}},	//   qoma, _अमरी, øer_, yuan,
   {{0xb8d91fbb,0xa2c10592,0x26da0062,0xbb2b0103}},	//   _चा_, र्ड्, _bapo_, _کتنے_,
   {{0x26da8e84,0xd0400022,0xe6672cf5,0x25750120}},	//   _capo_, _hamɓ, етбо, _pål_,
   {{0x95c803fc,0x39425f73,0x26da0139,0x692b02c6}},	//   нута_, boks_, _dapo_, třed,
   {{0x290b0b4b,0x63ad8e85,0x39420063,0xa4d4004d}},	//   ības_, tuan, coks_, лосі,
   {{0x317102ac,0x02a78e86,0x799a007f,0x00000000}},	// [96b0] _suzz_, ерем, lstw, --,
   {{0x82d800d3,0x25750212,0x26da38d3,0x00000000}},	//   ндус_, _tål_, _gapo_, --,
   {{0x799a8e87,0x692b00b6,0x672702ef,0x02d10034}},	//   nstw, před, mijj, _हसीन,
   {{0x212602e5,0x68ed0090,0xdb0000bc,0x26da0062}},	//   gioh_, _jnad, lumä, _zapo_,
   {{0x63ad8e88,0x389c00c1,0x24898e89,0x26da0239}},	//   quan, ליאנ, mbam_, _yapo_,
   {{0x6da5162b,0x443901af,0x7d093aab,0xf7740341}},	//   вика, _ixs_, wkes, אקס_,
   {{0x53343051,0x68ed8159,0x7d091d94,0x799a007f}},	//   _серт, _onad, tkes, jstw,
   {{0x68ff0694,0x68ed4188,0x672700e7,0x62978e8a}},	//   _noqd, _nnad, hijj, laxo,
   {{0x7d094287,0xd9d9030b,0xa2c10403,0xdb0013ce}},	//   rkes, बट्ट, र्थ्, kumä,
   {{0x7d090f06,0x68ed1ab9,0xf8aa1fb4,0x60db024a}},	//   skes, _anad, कल्प, _haum,
   {{0x68ed009e,0x39428e8b,0x799a01cb,0x3d9500ae}},	//   _bnad, toks_, gstw, _риер,
   {{0x60db0472,0xdb2609e5,0x26da8e8c,0xa2c12f4f}},	//   _jaum, _یونی, _sapo_, र्त्,
   {{0x26da1dab,0x60db0051,0x7d060084,0x672700e7}},	//   _papo_, _maum, ökse, fijj,
   {{0x4ad700fb,0xfaa58e8d,0x60db8e8e,0x2ba60034}},	//   _ساتھ_, _рако, _laum, _खिता,
   {{0xceb27c04,0xcb1200ca,0x6b9b8e8f,0xd62a6368}},	//   יים_, _דלג_, lsug, фове_,
   {{0x26da0051,0x443900ee,0x68ed042c,0xe1f20d7f}},	//   _wapo_, _bxs_, _gnad, یسا_,
   {{0x26da013f,0xe3ba0cd1,0xb46601b6,0x6b9b8e90}},	// [96c0] _tapo_, ьба_, ткал, nsug,
   {{0x68ed04e9,0xdb0000a7,0x7d1e0103,0x290000bc}},	//   _znad, rumç, épsz, _hoia_,
   {{0x60db11fe,0xa2c15d3f,0x00000000,0x00000000}},	//   _baum, र्ध्, --, --,
   {{0x29008e91,0xdcfe00d9,0x6b9b8e92,0x60db00fc}},	//   _joia_, īvīb, ksug, _caum,
   {{0x7c2d8e93,0x087700c1,0xb4c009c3,0x60db8e94}},	//   _žarn, דענט_, ूजी_, _daum,
   {{0xa3c100a5,0x3cda0490,0x7f4301af,0xa2c117ad}},	//   ूबर_, _खोजे_, gonq, र्द्,
   {{0x291206b0,0xa3e008c0,0xf8bf0113,0x00000000}},	//   _olya_, थिव_, dién_, --,
   {{0x6d598e95,0x29008e96,0x60db8e97,0xebd8162b}},	//   _chwa, _noia_, _gaum, едиш_,
   {{0x6b9b11b9,0x50461b60,0x443912dc,0x31bc037a}},	//   gsug, _реаб, _xxs_, líz_,
   {{0x68ed030b,0x6d590332,0x2912083e,0x2f100139}},	//   _snad, _ehwa, _alya_, _fàga_,
   {{0x7c2d0088,0x672700e7,0x29004b85,0x3f860956}},	//   _þarn, vijj, _boia_, lpou_,
   {{0x0c260ed8,0xe8e00028,0x799a00a5,0x29005a44}},	//   _имен, _trời_, rstw, _coia_,
   {{0x692b000d,0x672700e7,0x290001ff,0xeb97002d}},	//   třeb, tijj, _doia_, _аич_,
   {{0xf8bf058a,0x68ed01c2,0x29120172,0x19ba0037}},	//   cién_, _wnad, _elya_, _قطعة_,
   {{0xf62800d6,0xdb000149,0x9f44023b,0x247806c0}},	//   віти_, rumä, _armë_, _ọma_,
   {{0x69d88e98,0x68ed0a3d,0x672700e7,0x2900518e}},	//   _isve, _unad, sijj, _goia_,
   {{0x54558e99,0x60db8e9a,0xe8d90019,0x248901d3}},	// [96d0] уват, _raum, _nhỉ_, rbam_,
   {{0xe3b00037,0x22955f34,0x36d5007b,0x490b00b6}},	//   ترف_, الاس, _соор, ासको_,
   {{0x26d18e9b,0x60db8e9c,0x7c36003e,0x6297041c}},	//   mezo_, _paum, _þyrf, raxo,
   {{0x26d152b4,0x301544ab,0x2600030b,0x29000042}},	//   lezo_, лдер, रहरी_, _xoia_,
   {{0xe8d900ef,0xd91c0130,0x251a00a1,0x443f0019}},	//   _chỉ_, וואל, _נושא, _âu_,
   {{0x69d81017,0xb87b124d,0x60db0051,0x26d18e9d}},	//   _osve, ndíb, _waum, nezo_,
   {{0x60db8e9e,0xf8bf0257,0x6b828b75,0x2d94013f}},	//   _taum, nnés_, _atog, арыс,
   {{0x26d130ff,0x6b9b8e9f,0x3949022e,0x3ea95e74}},	//   hezo_, tsug, _nkas_, şat_,
   {{0x26d1405e,0x0b45016d,0x69ca01bf,0xdc310233}},	//   kezo_, лнин, _apfe, _düğm,
   {{0x6b9b8ea0,0x29008ea1,0x6b820076,0x692b00d2}},	//   rsug, _soia_, _dtog, yřec,
   {{0xa2ca086d,0x2bd8009f,0x6b9b0865,0x26d10072}},	//   _सॉफ्, _बैठा, ssug, dezo_,
   {{0x69a409c3,0x62958ea2,0x61f830c1,0x6f018ea3}},	//   _किरी, _lezo, ävli, _holc,
   {{0x69d800b3,0x3cef028d,0x290000ae,0x6f01007f}},	//   _esve, _ingv_, _voia_, _kolc,
   {{0x62958ea4,0x26d135fe,0x00000000,0x00000000}},	//   _nezo, gezo_, --, --,
   {{0x64a62a04,0xf8bf00fd,0x6f014fba,0xdb260072}},	//   лава, gnés_, _molc, _ápáx,
   {{0xa3e08ea5,0xfbd8007f,0x31bc01f9,0x98a2007f}},	//   थिल_, _बैडम, víz_, ynkę_,
   {{0x62956164,0xdce101d3,0x78a40d6a,0x00000000}},	// [96e0] _bezo, _atlī, _idiv, --,
   {{0xb4635565,0xdb005aee,0xdb0902ac,0x00000000}},	//   скул, stmö, dreë, --,
   {{0x62953a05,0xd24f00e3,0x9abc03e5,0xc0e6166f}},	//   _dezo, كنك_, fiċj, ложк,
   {{0xc096071c,0x19b6006e,0x7983010a,0x31bc0072}},	//   اجات, טפער_, _mtnw, ríz_,
   {{0x316d4e99,0xdb09084e,0x00000000,0x00000000}},	//   _diez_, greë, --, --,
   {{0x62958ea6,0x6f01237a,0xa85700ca,0xf8bf3229}},	//   _gezo, _colc, ניסה_, nnér_,
   {{0x6f01013d,0x2b07030b,0xdb1b00fd,0xdcfa01d3}},	//   _dolc, ाउनु_, ctué, _attā,
   {{0xd1322761,0x386d2c0a,0x78a40051,0x62950415}},	//   _امر_, žeri_, _ndiv, _zezo,
   {{0x5b148d01,0x6f018ea7,0xa2c100a8,0xdb09029a}},	//   имит, _folc, र्व्, creë,
   {{0x78a4222b,0xfc4a0139,0x6f0109d2,0x00000000}},	//   _adiv, _akíó_, _golc, --,
   {{0x02c60287,0x00000000,0x00000000,0x00000000}},	//   र्यभ, --, --, --,
   {{0x3f840167,0x644b00aa,0x6b820361,0xdd8f01dc}},	//   _ktmu_, ügik, _ttog, _روه_,
   {{0xe8d900ef,0xed572863,0x6d44013f,0x31d100b6}},	//   _giờ_, _соц_, čiad, _सन्ध,
   {{0x7d020694,0x8c1b00a1,0xdb1e0212,0x78a48ea8}},	//   _hoos, _אודי, övän, _ediv,
   {{0x62958ea9,0x7d020837,0x26d18eaa,0x65954e6f}},	//   _rezo, _koos, rezo_, рабу,
   {{0x9983054f,0xfd4c0032,0x7d028eab,0xa7752a61}},	//   _اليو, _ailẹ, _joos, _клич,
   {{0x6295034f,0x26d10328,0x2919152f,0x24181402}},	// [96f0] _pezo, pezo_, mhsa_, готы_,
   {{0x27e98eac,0x83050081,0x7d028ead,0xb87b00b3}},	//   _iran_, োচ্চ_, _loos, bdíc,
   {{0xe8d900de,0xa2c12a09,0x802705bc,0xc1e83168}},	//   _nhị_, र्ष्, گرام, льце_,
   {{0x32640dee,0x6f018eae,0xd0110037,0x19b700c1}},	//   стув, _solc, يلا_, רפאר_,
   {{0x4ac4063c,0xe8d90134,0x35ab009f,0x656f009c}},	//   वभाव, _ahị_, _छिड़, _iich,
   {{0x656f33d3,0xaec400d6,0xde052b49,0x8afe01c2}},	//   _hich, йбіл, ипли, _fiƙi,
   {{0x6f0126e0,0x656f8eaf,0xe8d90028,0x41e4059b}},	//   _volc, _kich, _chị_, _літа,
   {{0x63ad8eb0,0x27e98eb1,0x656f0239,0x7a1300a7}},	//   oran, _oran_, _jich, qətə,
   {{0x656f4209,0x9ed9013d,0x7d020df7,0x60c904ff}},	//   _mich, _имат_, _doos, _ibem,
   {{0x656f8eb2,0x16051d96,0x4b25245c,0x644f8eb3}},	//   _lich, रहार_, рмов, _myci,
   {{0x63ad28f9,0x69de025b,0xe8d90174,0x7d020188}},	//   hran, _šper, _ghị_, _foos,
   {{0x656f3477,0xf8660070,0x7d028eb4,0xd9460394}},	//   _nich, ивно, _goos, реми,
   {{0x63ad0335,0x27e98eb5,0x6d4b00e8,0x644f0537}},	//   jran, _cran_, _ikga, _nyci,
   {{0x7d0201fa,0x656f8eb6,0x6b898eb7,0x27e901bf}},	//   _zoos, _aich, mpeg, _dran_,
   {{0x63ad8eb8,0x27e97176,0x656f0d5a,0x66033f1d}},	//   eran, _eran_, _bich, опра,
   {{0x63ad8eb9,0x69c18eba,0x7de00018,0x2a3a00ca}},	//   fran, mtle, lásá, _בעצמ,
   {{0x27e93890,0x656f8ebb,0x03265951,0x24071a19}},	// [9700] _gran_, _dich, адан, анти_,
   {{0x656f8a33,0x60c98ebc,0xa2c118ff,0x81c10033}},	//   _eich, _abem, र्ल्, ্টন_,
   {{0x63ad86ae,0x60c90172,0x69c11b6b,0xb87b0143}},	//   aran, _bbem, ntle, ldía,
   {{0x2ba610ed,0x3fe619e8,0x69c102ac,0xe1650037}},	//   _खिला, ижев, itle, مدني,
   {{0x7d025d92,0x69c100aa,0xb87b04d8,0xdb090143}},	//   _roos, htle, ndía, nteó,
   {{0x656f8ebd,0x69c117d2,0x3d110af0,0x7d028ebe}},	//   _zich, ktle, _báwo_, _soos,
   {{0x656f1a69,0x7de00018,0xdd97004b,0x7d028ebf}},	//   _yich, dásá, ашы_, _poos,
   {{0x3d110032,0x5bb87d72,0x24808ec0,0x60c90139}},	//   _dáwo_, глия_, ncim_, _gbem,
   {{0x69c10034,0x02c600b7,0x0083180b,0xa0672a59}},	//   etle, र्थभ, _флуо, _вата_,
   {{0xe8d900ef,0x5b1402fd,0x31784325,0x7bc08ec1}},	//   _thị_, смот, _kurz_, rtmu,
   {{0x257c0080,0x13cf00c7,0xbca600cd,0x7d020188}},	//   _níl_, রিয়, _نماي, _toos,
   {{0x27e914b1,0x98a200e8,0x254a00c6,0x6b89009c}},	//   _pran_, tikā_, nėlę_, bpeg,
   {{0x656f8ec2,0xd83b004b,0xdc540068,0x00000000}},	//   _rich, тэн_, _اراک, --,
   {{0x656f8ec3,0x8afe01c2,0x257c003e,0x98a200e8}},	//   _sich, _riƙw, _bíl_, rikā_,
   {{0x656f068d,0x69c1029a,0x35e404a1,0x257c02c6}},	//   _pich, ctle, оцтв, _cíl_,
   {{0x796900a5,0x257c00b6,0xf99300ca,0x3d180139}},	//   _oświ, _díl_, _ורק_, _féwe_,
   {{0x63ad8ec4,0x656f8ec5,0xd3710adb,0x24820188}},	// [9710] uran, _vich, سها_, _dfkm_,
   {{0x656f02e2,0x59da0f53,0x63ad8ec6,0x644f0e43}},	//   _wich, _बनार, rran, _vyci,
   {{0x656f083d,0x644f00a5,0x63ad85e7,0xc692028c}},	//   _tich, _wyci, sran, _מאי_,
   {{0x63ad8ec7,0x7de00018,0x7a0a00a7,0x692b00d2}},	//   pran, zásá, mətd, zřen,
   {{0x752d8ec8,0x6b5d020d,0x3ea500b3,0xe8d900fe}},	//   miaz, lège, _pdlt_, _nhọ_,
   {{0x752d7e0e,0x43940b34,0x116700d1,0x00000000}},	//   liaz, _фарс, _چلسی_, --,
   {{0x692b030b,0x816b0077,0x518443f7,0x7de00103}},	//   vřen, _араб_, _мута, vásá,
   {{0x752d8ec9,0x657a0037,0x5bc50037,0x60c961b2}},	//   niaz, íthi, مقبل, _ubem,
   {{0x7de00068,0x30151d6e,0x692b030b,0xe8d90294}},	//   tásá, _удар, třen, _chọ_,
   {{0x69c18eca,0x6b898ecb,0xe9d92917,0xdb1b00b3}},	//   ttle, rpeg, гко_, rtuï,
   {{0x6b898ecc,0x394600a9,0x7de001f9,0x6e454175}},	//   speg, йног, rásá, _انضم,
   {{0x6b89075b,0x69c18ecd,0x6d440206,0x89360076}},	//   ppeg, rtle, čiac, إعدا,
   {{0x752d8ece,0x291e013f,0x7d1b580d,0x257c8ecf}},	//   diaz, ėta_, mhus, _síl_,
   {{0x7d1b093e,0x00000000,0x00000000,0x00000000}},	//   lhus, --, --, --,
   {{0xba9a0054,0x1a65010d,0x7d1b0a4b,0x00000000}},	//   _עסקי, _دیدی_, ohus, --,
   {{0x752d4850,0x7d1b3287,0xf8dc2c82,0x257c00d8}},	//   giaz, nhus, _बसिय, _víl_,
   {{0xdb09034f,0xe45a3035,0x24808ed0,0x7d1b0350}},	// [9720] lteñ, ужа_, rcim_, ihus,
   {{0xb87b8ed1,0x57fb0327,0xd83f02c6,0x23790120}},	//   ndín, _עליו, áček_, _dusj_,
   {{0xdb0908a8,0x7d1b8ed2,0x8b5600c1,0xe61200cd}},	//   nteñ, khus, ציעס_, _رشد_,
   {{0x752d5559,0xd83f033b,0xc8b80442,0x7ae600e8}},	//   ciaz, šček_, अलिट, ēkti,
   {{0x7d1b8ed3,0xd9a41cff,0x00000000,0x00000000}},	//   dhus, _खट्ट, --, --,
   {{0x44208ed4,0xe457006e,0x6e93176e,0x201a007f}},	//   mzi_, _ליכט_, пишу, ąpi_,
   {{0xacf808d1,0x44208ed5,0xa3e03613,0x644b09a1}},	//   инку_, lzi_, थिक_, ügiv,
   {{0x629e8ed6,0x7d1b8ed7,0x44208ed8,0xa06a0a51}},	//   lapo, ghus, ozi_, _баба_,
   {{0x44204513,0x77e20285,0xfe720d59,0x660e00d4}},	//   nzi_, गटोक_, _فدا_, hybk,
   {{0xbea3355a,0x629e8ed9,0x752d8eda,0x5a3410b8}},	//   _наук, napo, ziaz, жнот,
   {{0x9cca0963,0x7d1b8edb,0xaa583c1a,0x63b6020b}},	//   _была_, bhus, рину_, huyn,
   {{0xeb9a0231,0x629e12f5,0xe8d900de,0xec7a1f75}},	//   _бид_, hapo, _thọ_, _спд_,
   {{0x629e8edc,0x6ebf000f,0x752d8edd,0xceba03e3}},	//   kapo, ल्कु, viaz, siƙu_,
   {{0x44208ede,0x1ddc1376,0x69dc13b9,0xdc3b00c1}},	//   dzi_, _मनात, æres, _געדר,
   {{0x44208edf,0x50c802d5,0x752d8ee0,0xdb0002c3}},	//   ezi_, रभाष, tiaz, rrmä,
   {{0x7a0a0092,0x2f0b00f3,0x25ac1054,0xa3e500a3}},	//   rətd, _høgt_, ádla_, पटल_,
   {{0x752d82ee,0xc2990686,0x7a0a013c,0x00000000}},	// [9730] riaz, иках_, sətd, --,
   {{0x629e8ee1,0x394b18ae,0x249900f9,0x20d300fe}},	//   gapo, locs_, _wesm_, _ải_,
   {{0xe5c72156,0x44208c18,0x752d8ee2,0xd25b00d3}},	//   _успо, azi_, piaz, уца_,
   {{0x63b62772,0xe1f00037,0x905576c4,0x00000000}},	//   buyn, عسل_, овец, --,
   {{0xb4db0139,0x7d1b1842,0x629e2c70,0x692b02c6}},	//   _ajàg, vhus, bapo, vřel,
   {{0x079c00a1,0x3f691486,0xa19501b3,0x645d6fa6}},	//   נסול, шило_, _магч, _izsi,
   {{0xe8d90028,0x6ebf16f8,0x6d49029a,0x7d1b8ee3}},	//   _nhỏ_, ल्गु, toea, thus,
   {{0x394b0428,0xdb1b0072,0x3b850360,0xdb851ac8}},	//   jocs_, rtuí, олиг, огии,
   {{0xfc31054f,0x7d1b02fe,0x98a216d7,0x7f94224a}},	//   بحث_, rhus, niką_, _натх,
   {{0x7d1b8ee4,0x212f8ee5,0x49c925d6,0x2fdf041c}},	//   shus, ligh_, алон_, _isug_,
   {{0x44208ee6,0xb87b8ee7,0x394b015e,0xe9d600ae}},	//   zzi_, rdín, focs_, окэ_,
   {{0xc6892865,0x212f00e3,0xdb090610,0x7afc0212}},	//   _יא_, nigh_, rteñ, örtr,
   {{0x81c10081,0x2f100441,0x629e8ee8,0x69dc181f}},	//   ্টি_, _bàgh_, yapo, ærer,
   {{0x212f01b5,0x9f440161,0x44208ee9,0x7bdb0350}},	//   high_, _irmã_, vzi_, mwuu,
   {{0x366a17e9,0xdb0900e1,0xe7370138,0xa50a711a}},	//   раво_, nreí, цер_, аева_,
   {{0x7ae38eea,0x442002a7,0x81c10081,0x448a2a84}},	//   _hant, tzi_, ্টা_, рбан_,
   {{0x7ae30510,0x629e03cb,0x66e60303,0x44208eeb}},	// [9740] _kant, tapo, _допа, uzi_,
   {{0x44207dc8,0x27e08eec,0x6b840037,0xdce800b6}},	//   rzi_, _isin_, _éige, _budě,
   {{0x44200068,0x68e48eed,0x7ae30133,0x8c3d0092}},	//   szi_, _kaid, _mant, laşd,
   {{0x26d88eee,0x29020660,0xa2ca0034,0x4fea667a}},	//   lero_, njka_, _सॉर्, имен_,
   {{0x795d0979,0x68e41224,0x7ae3078e,0x63630134}},	//   néwa, _maid, _oant, ọnar,
   {{0x26d88eef,0xf413004f,0x7ae35c1c,0x68e48ef0}},	//   nero_, _חפש_, _nant, _laid,
   {{0x63a48ef1,0x629c0029,0x29192224,0xdb09037a}},	//   lsin, _iero, ūrai_, greí,
   {{0x7ae30254,0x68e40049,0xf1c30363,0x26d88ef2}},	//   _aant, _naid, žší_, hero_,
   {{0x7ae31a9b,0xa2ca68b9,0x629c6c7c,0x26d88ef3}},	//   _bant, स्थ्, _kero, kero_,
   {{0x26d88ef4,0x3d18001c,0x68f61881,0xddc9020a}},	//   jero_, _déwa_, _anyd, înţe,
   {{0x7ae38ef5,0x26d88ef6,0x629c313d,0x27e08ef7}},	//   _dant, dero_, _mero, _asin_,
   {{0x7c6500cd,0x68e48ef8,0x25b80113,0x2d8e0364}},	//   _کامل, _caid, durl_, mpfe_,
   {{0x26d88ef9,0x68e41114,0x2fc68efa,0x63a4118f}},	//   fero_, _daid, ntog_, jsin,
   {{0x629c16ac,0x26d80b92,0x940b0092,0xe8d90023}},	//   _nero, gero_, _gecə_, _thỏ_,
   {{0xd49b1121,0x27e0026e,0x68e4688c,0xc1c900a5}},	//   ира_, _esin_, _faid, _रहेग,
   {{0x68e48efb,0x7ae38efc,0x25ad3c34,0x63a46448}},	//   _gaid, _zant, čel_, fsin,
   {{0x63a48efd,0x26d88efe,0x7ae38eff,0x61ee00bd}},	// [9750] gsin, bero_, _yant, _arbl,
   {{0x68e41ee3,0xa3ac000f,0x26d807a3,0x61ee0542}},	//   _zaid, _गिर_, cero_, _brbl,
   {{0x212f00e3,0x26c10294,0xdb1b8f00,0x63a48f01}},	//   tigh_, _icho_, ntuá, asin,
   {{0x6f1a00d3,0x63a48f02,0x69cd0101,0x644b00bc}},	//   _altc, bsin, _तहसी, ügis,
   {{0x629c5058,0xf48400cd,0x212f0a1b,0x2fc68f03}},	//   _fero, _تاپی, righ_, gtog_,
   {{0x629c8f04,0x212f0037,0x2d95117c,0xdb1b1f20}},	//   _gero, sigh_, прис, ktuá,
   {{0x7ae38f05,0x6d443123,0x628549e9,0x61ee007e}},	//   _rant, čian, mcho, _grbl,
   {{0x7ae30f8e,0x62854d2f,0x26d88f06,0x2fdf023e}},	//   _sant, lcho, zero_, _tsug_,
   {{0x26c10890,0x629c083e,0x26d88f07,0x2b80009c}},	//   _ocho_, _yero, yero_, _còc_,
   {{0x62850fa9,0x68e48f08,0x26c101fa,0x629c8f09}},	//   ncho, _said, _ncho_, _xero,
   {{0x26d8116a,0x68e48f0a,0x63a4758e,0x8c950565}},	//   vero_, _paid, zsin, _ерлі,
   {{0x26c18f0b,0x7c2d8831,0x63a48f0c,0x7ae38f0d}},	//   _acho_, _žaru, ysin, _want,
   {{0x26d88f0e,0x68e47293,0x62858f0f,0x2ee50a88}},	//   tero_, _vaid, kcho, _kalf_,
   {{0x7ae3022e,0x62858f10,0x25ac025b,0xbbe90260}},	//   _uant, jcho, ádlo_, _پرچم_,
   {{0x26d88f11,0x62858f12,0x68e41c11,0x629c03a9}},	//   rero_, dcho, _taid, _rero,
   {{0x63a48f13,0x629c8f14,0xb4e60592,0x26d88f15}},	//   tsin, _sero, पये_, sero_,
   {{0xa507013d,0xd4673574,0x61ee3df1,0x63a4004b}},	// [9760] чета_, зите_, _srbl, usin,
   {{0x63a409a7,0x6aa10973,0x213f0113,0x212d01dc}},	//   rsin, nalf, _ajuh_, _ameh_,
   {{0x629c8f16,0x63a43199,0xc8b50018,0x41b60450}},	//   _vero, ssin, _علیک, ясат,
   {{0x63a48f17,0x629c8f18,0x00000000,0x00000000}},	//   psin, _wero, --, --,
   {{0x28c10d88,0x629c8f19,0x4abd1c0a,0x62850146}},	//   ष्टि, _tero, ्भाव, bcho,
   {{0x657e0060,0x62850441,0xb87b0103,0xfe700470}},	//   _kuph, ccho, gdíj, نگا_,
   {{0x39818f1a,0x6f088f1b,0xe2970636,0x2b8000b3}},	//   _nós_, _vodc, _хас_, _sòc_,
   {{0xc0e33164,0xa3b300b6,0x2fc68f1c,0x657e0372}},	//   _поск, _टिम_, ptog_, _muph,
   {{0x61431807,0x657e0415,0x2ee5030a,0x00000000}},	//   _чета, _luph, _falf_, --,
   {{0xfbcf00ab,0xef170084,0x39814386,0x501b00ca}},	//   اتي_, _ему_, _bós_, _הומו,
   {{0xa2c10455,0x39815c31,0x58d91c32,0xe8d900fe}},	//   र्ट्, _cós_, одня_, _nhể_,
   {{0xdb1b2f31,0x69cd009f,0x62853a18,0x14ce1178}},	//   rtuá, _तहरी, zcho, ह्मण,
   {{0xdb1b0161,0x6aa103a8,0xc864174e,0x78bd4672}},	//   stuá, balf, етри, rgsv,
   {{0x39810080,0x6aa10428,0xf53f00f3,0x2c09030b}},	//   _fós_, calf, _sjå_, िहरू_,
   {{0x661402c6,0xe3b301f3,0x00000000,0x00000000}},	//   _čeká, کرز_, --, --,
   {{0xe94509b4,0x2a3b00ca,0x00000000,0x00000000}},	//   _ترتی, _לעומ, --, --,
   {{0x62858f1d,0x3ce6007e,0x00000000,0x00000000}},	// [9770] tcho, _maov_, --, --,
   {{0x212d8f1e,0x62851022,0xc3540284,0x00000000}},	//   _smeh_, ucho, екуј, --,
   {{0x62858f1f,0xcb130130,0x69c800ee,0x2ee51d87}},	//   rcho, עלע_, ntde, _ralf_,
   {{0x62858f20,0xf8bf8f21,0x2ee50f5a,0x9f4d0f5a}},	//   scho, ngé_, _salf_, _treë_,
   {{0xf8bf00fd,0x31640234,0xdee52a84,0x9412013c}},	//   liés_, _dhmz_, доли, kayə_,
   {{0xdb092e92,0x69c85a55,0x7777009e,0x66220233}},	//   kreá, ktde, _jixx, _öykü,
   {{0xa3e5000d,0x316400e7,0x77770090,0x692b02c6}},	//   पटक_, _fhmz_, _mixx, přeh,
   {{0x78ad05bd,0x3d180113,0xdef80090,0x777702a1}},	//   _ndav, _déwo_, _enċ_, _lixx,
   {{0x6aa14118,0x69c88f22,0x1c45004d,0x39818f23}},	//   talf, etde, ьним, _sós_,
   {{0x3981001f,0xc9a900c2,0x89a900c2,0x7777009e}},	//   _pós_, овое_, оков_, _nixx,
   {{0xd9462d06,0xa96a5bcf,0x6aa1224d,0xbbeb01f9}},	//   дени, жина_, ralf, _گرام_,
   {{0xf8bf8f24,0x39811fa4,0x657e009c,0x07a61d62}},	//   ggé_, _vós_, _ruph, мамн,
   {{0xbbeb001c,0x2cbf29fb,0x200b015e,0x657e29e4}},	//   _درام_, mgud_, _àcid_, _suph,
   {{0xdb0900e3,0xf8bf00fd,0xab64004d,0x7bc90239}},	//   breá, fiés_, _звіл, mteu,
   {{0xbb520d74,0x28c6009f,0x69c80d4d,0x77770078}},	//   _جنوب, _वापि, ctde, _dixx,
   {{0x2cbf007a,0x2919023b,0x7d0b0103,0x2d533906}},	//   ngud_, ërat_, _jogs, mães_,
   {{0x7bc98f25,0x3164007e,0x7d06007b,0x3a050103}},	// [9780] nteu, _rhmz_, öksi, _رکھی_,
   {{0xe8d9011b,0xa3cf0e4c,0x44630396,0x7bc96a46}},	//   _thể_, _शहर_, твув, iteu,
   {{0xaacf20cd,0xa50a2de0,0xf8bf6865,0x7d0b3584}},	//   त्यक, _дена_, ciés_, _oogs,
   {{0x7bc98f26,0x7d0b0a88,0xf8bf0094,0x626503c5}},	//   kteu, _nogs, liér_, رالق,
   {{0xd12f0979,0x10a360cf,0xdfd00602,0x77770063}},	//   جمن_, тичн, ايت_, _yixx,
   {{0x6d44013f,0xaacf1677,0x644601ff,0x257b0174}},	//   čiam, त्मक, _ixki, ụlee_,
   {{0x7d0b8f27,0x69c8486e,0x98a900e7,0x2d8c0131}},	//   _bogs, xtde, _smač_, _qtde_,
   {{0xfbaa007b,0x00000000,0x00000000,0x00000000}},	//   отой_, --, --, --,
   {{0x7d0b01af,0xaec61c76,0xb0180174,0x00000000}},	//   _dogs, _обал, ọọvụ_, --,
   {{0x1f631bf9,0x93fb0089,0x98a000a5,0x69c84a83}},	//   _акум, קליי, _imię_, ttde,
   {{0x1959055b,0x69350ae3,0x02b700ca,0x7bc904d1}},	//   заны_, енну, והים_, ateu,
   {{0x27f24d8f,0x7d0b0063,0xd83f0206,0x00000000}},	//   _bryn_, _gogs, áčok_, --,
   {{0x7bc97dfc,0xf8bf0257,0x69c88f28,0x272d0117}},	//   cteu, rgé_, stde, lžni_,
   {{0xf8bf020d,0x92c20033,0x00000000,0x00000000}},	//   tiés_, ্যু_, --, --,
   {{0xcad70054,0x8c3d00a7,0x94d500f6,0x7aea01d3}},	//   _חוות_, maşa, новц, ļotā,
   {{0xf8bf0257,0x78ad0201,0x63b60150,0x27f25d74}},	//   riés_, _udav, fryn, _fryn_,
   {{0x29190029,0x24580084,0x27f23dc0,0x63b68f29}},	// [9790] ūras_, дать_, _gryn_, gryn,
   {{0xd25b3a62,0x00000000,0x00000000,0x00000000}},	//   оце_, --, --, --,
   {{0x85750084,0x5184013f,0x644601ff,0x28c600aa}},	//   _плох, вуча, _exki, _वामि,
   {{0x63b65b89,0xc61b0287,0xa5d80d7f,0x22580ac9}},	//   bryn, ननीय_, _کبیر_, _dyrk_,
   {{0x24b600c1,0xf8bf0257,0x9f35004d,0x656d8f2a}},	//   _אהרן_, chée_, неді, mmah,
   {{0x656d28b8,0x2f1800c2,0xe7b2009f,0x80db00b6}},	//   lmah, мочь_, _जिसप, _नसके,
   {{0xc3320266,0xa3e76bbd,0xddc100e8,0x00000000}},	//   _עול_, भिक_, _izlū, --,
   {{0x7bc98f2b,0x656d0798,0xef190034,0xeb9936f2}},	//   tteu, nmah, _duża_, пии_,
   {{0x31340c28,0x656d01e9,0x7bc98f2c,0x6d4200c4}},	//   _ретр, imah, uteu, _djoa,
   {{0x7bc98f2d,0x656d8f2e,0x2d530231,0x00000000}},	//   rteu, hmah, tães_, --,
   {{0x656d0808,0xf2d200c1,0x7d0b1d46,0x13d80033}},	//   kmah, נעט_, _togs, সিয়,
   {{0x7bc90257,0x2d533906,0x7a0a00a7,0x656d00e7}},	//   pteu, rães_, mətl, jmah,
   {{0x395e00d9,0x7a0a00a7,0xb8d80285,0xdce100c6}},	//   ēts_, lətl, _चय_, _sulė,
   {{0x6d5b01e5,0x64460167,0xdb09015e,0x00000000}},	//   llua, _rxki, dreç, --,
   {{0xceb27c04,0xf8bf025b,0x24f6105b,0x6abd6eef}},	//   טים_, riér_, нчар, ्भीर,
   {{0x2edc000d,0x63b640f2,0x656d2783,0x6d5b8f2f}},	//   _यस्त, tryn, gmah, nlua,
   {{0x6d5b8f30,0xc2b60291,0x7a0a013c,0xdb090231}},	// [97a0] ilua, ељењ, hətl, greç,
   {{0x63b6030a,0x7a0a00a7,0x6d5b3bf8,0x656d008c}},	//   rryn, kətl, hlua, amah,
   {{0xda0f0557,0x64a65961,0x569b00ca,0xe0da0b2f}},	//   ाहित_, _пана, _מייצ, зве_,
   {{0x92c20f71,0x4fc616bd,0x98ab00ae,0xf8bf020d}},	//   ্যে_, еска, mică_, phée_,
   {{0x98ab00d3,0x6d5b8f31,0x9f4d00b3,0xdb090131}},	//   lică_, dlua, _creï_, creç,
   {{0xde580138,0x00000000,0x00000000,0x00000000}},	//   малі_, --, --, --,
   {{0xe357193b,0x78a602e6,0x4343113f,0x98ab002d}},	//   _נשלח_, kakv, _серв, nică_,
   {{0xafe65833,0x201100a7,0xdb0900c2,0x2f1000ee}},	//   _побл, _əziz_, hreä, _pàgs_,
   {{0xcf463ad2,0x60c2019f,0x8c3d6d5d,0x00000000}},	//   _знай, mgom, taşa, --,
   {{0x9ad20134,0x7a0a0092,0xef19003d,0xb87b016d}},	//   _bịag, bətl, _tuża_, ndív,
   {{0x6d5b4f69,0x673500dd,0x656d008c,0xe895186f}},	//   blua, vizj, ymah, кань,
   {{0x60c28f32,0x28c604f8,0x98ab00d3,0x67350034}},	//   ngom, _वाणि, dică_, wizj,
   {{0xac970037,0x6d4001c2,0xd7fb0284,0x291909a1}},	//   _أنها_, mnma, чун_, rksa_,
   {{0x98ab00d3,0xd763015a,0xb6e4083c,0x00000000}},	//   fică_, انسی, люск, --,
   {{0x248901af,0x6d400313,0xaa578f33,0x98ab00ae}},	//   tcam_, onma, _пишу_, gică_,
   {{0x7aea8f34,0x6d408f35,0x92bd0081,0x6b820051}},	//   _haft, nnma, _আসে_, _kuog,
   {{0x24898f36,0x7aea8f37,0x6d4005b7,0x00000000}},	// [97b0] rcam_, _kaft, inma, --,
   {{0xdbc7007a,0x656d289c,0x24892364,0xdb090161}},	//   _tööp, smah, scam_, rreç,
   {{0x6b82013d,0x2489062d,0x75240201,0x975800ca}},	//   _luog, pcam_, bhiz, _איזו_,
   {{0x75248f38,0x7aea8f39,0x41d20179,0x6d4001cb}},	//   chiz, _laft, _सहरस, jnma,
   {{0x5eaa0081,0x3d0440c1,0x6b820138,0x6d5b023e}},	//   চ্ছে, वाने_, _nuog, vlua,
   {{0x44290010,0x6d4014bd,0x141a00ca,0x63bf0036}},	//   mza_, enma, _חושב, muqn,
   {{0x1ea80037,0xe570001c,0x00000000,0x00000000}},	//   راوي_, _خطی_, --, --,
   {{0x44298f3a,0x7a0a0092,0x6d400de9,0x5ff5168c}},	//   oza_, rətl, gnma, _избу,
   {{0x6d5b06ee,0x98ab00d3,0x7aea8f3b,0x69ca0090}},	//   rlua, zică_, _baft, _aqfe,
   {{0x44298f3c,0x7aea1428,0x6d5b8f3d,0x00000000}},	//   iza_, _caft, slua, --,
   {{0x7aea1bd6,0x3ea78f3e,0x27260023,0x6d5b8f3f}},	//   _daft, mant_, _hông_, plua,
   {{0x3ea71288,0x61f519d0,0x27260023,0x2c870139}},	//   lant_, _mrzl, _kông_, _dídó_,
   {{0x7d090ea3,0x44298f40,0x88e30081,0x6b540428}},	//   mjes, jza_, যাংক, ràgr,
   {{0x3ea78f41,0x7d098f42,0x44298f43,0x98ab002d}},	//   nant_, ljes, dza_, tică_,
   {{0x44298f44,0x80d22373,0x27260019,0x75240201}},	//   eza_, ण्डे, _lông_, thiz,
   {{0x98ab00d3,0x7d098f45,0x7d1b8f46,0x3d04034c}},	//   rică_, njes, nkus, वाये_,
   {{0x27260019,0x7d1b8f47,0x98ab020a,0x03a6290e}},	// [97c0] _nông_, ikus, sică_, тизо,
   {{0x3ea78f48,0x75240193,0x7d1b13e1,0x798306a8}},	//   jant_, shiz, hkus, _kunw,
   {{0x44290012,0x3ea78f49,0x7d1b2e17,0x7d093b0b}},	//   aza_, dant_, kkus, kjes,
   {{0x6ec4245a,0x272600de,0x44296788,0xb87b8f4a}},	//   _राहु, _bông_, bza_, rdív,
   {{0x2726011b,0x44290067,0xb91d0134,0x7c298f4b}},	//   _công_, cza_, _anyụ_, jzer,
   {{0x3ea78f4c,0xef1900a5,0x272600de,0x78a48639}},	//   gant_, _dużo_, _dông_, _leiv,
   {{0x20000a29,0x7afe0428,0xf987001c,0x79830172}},	//   ţii_, _òpti, _خب_, _nunw,
   {{0x7aea0407,0x7d098f4d,0x7d1b3642,0xaacf045f}},	//   _saft, gjes, gkus, त्सक,
   {{0x3ea78f4e,0x6aa38f4f,0x6d4021ad,0xafe318c6}},	//   bant_, _benf, rnma, _котл,
   {{0x3ea78f50,0x2d6e030b,0xf8eb009f,0xa49b0139}},	//   cant_, _přes_, _जोड़ा_, _joòr,
   {{0xc333004f,0x44298f51,0x3f840051,0xdb00003e}},	//   שות_, zza_, _humu_, gsmá,
   {{0x3f848f52,0x44298f53,0x78a43c30,0x7aea0188}},	//   _kumu_, yza_, _ceiv, _waft,
   {{0xead4280f,0x99640077,0x3f8436cc,0x7c290034}},	//   _боль, ртэл, _jumu_, czer,
   {{0x7bc08f54,0x3f840283,0x07a4004b,0x6aa38f55}},	//   mumu, _mumu_, раён, _genf,
   {{0x4b7b00c1,0x3f84083e,0xd4c73da3,0x00000000}},	//   _קאוו, _lumu_, ксап, --,
   {{0x44298f56,0x3ea70ca3,0x628e36e2,0x3f84010a}},	//   tza_, zant_, _afbo, _oumu_,
   {{0x44298f57,0x3ea78f58,0xaacf030b,0x7bc01f14}},	// [97d0] uza_, yant_, त्वक, numu,
   {{0x27e90139,0x8c3d0702,0x3ea78f59,0x68ed2d01}},	//   _isan_, daşl, xant_, _haad,
   {{0x3ea757d6,0x4429221d,0x68ed8f5a,0x8af701d4}},	//   vant_, sza_, _kaad, _şəki,
   {{0x7bc08f5b,0x3f84083e,0x44290167,0x3ea700eb}},	//   kumu, _bumu_, pza_, want_,
   {{0x7bc08f5c,0x68ed8f5d,0x7d090ea3,0x14d60089}},	//   jumu, _maad, vjes, _גורל_,
   {{0x68ed2921,0x39ae0138,0x3f848f5e,0xa29400d6}},	//   _laad, kęs_, _dumu_, _варі,
   {{0x3ea729c4,0x657d8f5f,0xed592877,0x41e40138}},	//   rant_, _kish, нок_, _кіта,
   {{0x79838f60,0x3ea78f61,0x61fa0018,0x272600de}},	//   _runw, sant_, _átla, _tông_,
   {{0x657d8f62,0x7d098f63,0x3ea702cd,0x7983026e}},	//   _mish, rjes, pant_, _sunw,
   {{0x657d03e1,0x63ad8f64,0x78a48f65,0x645d8f66}},	//   _lish, isan, _seiv, _mysi,
   {{0x68ed8f67,0x7c2900fb,0x645d8f68,0x7d098f69}},	//   _baad, szer, _lysi, pjes,
   {{0x3ea516f4,0x63ad5ff3,0x8c3d07d1,0x657d8f6a}},	//   _helt_, ksan, laşm, _nish,
   {{0xb8ec412e,0x7bc08f6b,0x6d59405f,0x68ed8f6c}},	//   _ला_, cumu, _ikwa, _daad,
   {{0x2d858f6d,0x63ad49ee,0x8afc00a5,0x636b008b}},	//   _kule_, dsan, ględ, nünd,
   {{0x27e98f6e,0x1dc601e4,0x7ae17b76,0x657d8f6f}},	//   _esan_, रूपत, melt, _bish,
   {{0x28d3007d,0xaacf28fb,0x68ed0c1a,0x63ad8f70}},	//   ध्दि, त्रक, _gaad, fsan,
   {{0x69c18f71,0x63ad8f72,0x2fcd023e,0x636b4303}},	// [97e0] lule, gsan, _nqeg_, künd,
   {{0x7ae18f73,0x2900022e,0xb87b0018,0x68ed39d5}},	//   nelt, _hnia_, rdít, _zaad,
   {{0x2b8900ef,0x69c18f74,0xe8d90028,0x29120044}},	//   _lúc_, nule, _nhớ_, _koya_,
   {{0x645d17d2,0x657d8f75,0x6d5900ac,0x63ad0188}},	//   _fysi, _gish, _nkwa, bsan,
   {{0x69c10cbf,0x7ae18f76,0x63ad8f77,0x29128f78}},	//   hule, kelt, csan, _moya_,
   {{0x6d598f79,0x69c18f7a,0x657d4dae,0x291200dc}},	//   _akwa, kule, _zish, _loya_,
   {{0x657d1632,0xb87b8f7b,0x7ae17854,0x69c152f3}},	//   _yish, ndír, delt, jule,
   {{0x69c18f7c,0x7bc08f7d,0x39ae013f,0x29121f72}},	//   dule, tumu, vęs_, _noya_,
   {{0x68ed8f7e,0x7a0a0092,0x2b890023,0x636b8f7f}},	//   _raad, məti, _cúc_, bünd,
   {{0x68ed6800,0x7bc05c9e,0x29008f80,0x636b8f81}},	//   _saad, rumu, _ania_, rüng,
   {{0x69c18f82,0x29128f83,0xdd8f00bf,0x7bc08f84}},	//   gule, _boya_, _فول_, sumu,
   {{0x68ed025e,0x63ad8f85,0x92e00081,0x39ae0138}},	//   _qaad, ysan, থায়_, ręs_,
   {{0x9cd70054,0x657d8f86,0x68ed0837,0x290000a5}},	//   _תודה_, _rish, _vaad, _dnia_,
   {{0x69c18f87,0x2d850010,0x6d44013f,0x657d019f}},	//   bule, _yule_, čiau, _sish,
   {{0x69c13f8e,0xfa550018,0x645d6ccc,0x291200dc}},	//   cule, _پروگ, _sysi, _foya_,
   {{0x657d5b92,0x636b8f88,0x349501b6,0x27e90d2a}},	//   _qish, zünd, раар, _tsan_,
   {{0x2b890019,0x27e942f3,0xb97c006e,0x63ad4c3c}},	// [97f0] _xúc_, _usan_, _אנהי, usan,
   {{0x6b5d05fe,0x645d0220,0x60c90451,0x38698f89}},	//   tègi, _vysi, _scem, _izar_,
   {{0x645d8f8a,0x657d8f8b,0x7a0a00a7,0x32672db3}},	//   _wysi, _tish, fəti, утав,
   {{0x417400e3,0x645d0034,0x63ad8f8c,0x7ae18f8d}},	//   مانس, _tysi, psan, zelt,
   {{0x69c18f8e,0x2d858f8f,0x636b0511,0x63ad4828}},	//   zule, _sule_, tünd, qsan,
   {{0x2d858f90,0x6d5910a4,0x9f4d0037,0x4ea700ae}},	//   _pule_, _skwa, _breá_, урда,
   {{0x28c60557,0x636b8f91,0x7a0a0092,0xdce80138}},	//   _वालि, ründ, bəti, _judė,
   {{0x3ea502e2,0xa3b90251,0xa3e91bed,0x7ae101bf}},	//   _welt_, _घटा_, _मना_, welt,
   {{0xdcfa0029,0x7ae18f92,0x3ea53530,0xb4db0139}},	//   _attē, telt, _telt_, _ajàk,
   {{0x69c18f93,0x2d850d80,0x394900bc,0x8c3d013c}},	//   tule, _tule_, _ajas_, laşk,
   {{0x8e840080,0xa2ca0386,0x7dfc00ae,0x39461c00}},	//   _المه, स्ट्, _căsă, иног,
   {{0x69c109ad,0x7ae141dd,0x6d5926f6,0x2b8900de}},	//   rule, selt, _ukwa, _túc_,
   {{0x6d440181,0x69c18f94,0x7ae18f95,0x98ab007f}},	//   čiat, sule, pelt, nicę_,
   {{0x69c18f96,0xf7721823,0x38691d49,0x98ab00d9}},	//   pule, تاج_, _dzar_, ējās_,
   {{0xe8d90028,0x29128f97,0x7a0a0092,0xe5a618d4}},	//   _giữ_, _toya_, yəti, риби,
   {{0x778617ab,0xe8d900fe,0xb87b0143,0x29005c45}},	//   _клиз, _khờ_, seía, _unia_,

   {{0xe2ca5180,0xdb0909d3,0xd3873bba,0x00000000}},	// [9800] клад_, queó, ийте_, --,
   {{0x130300d6,0xdce20023,0xd9ec382b,0xe61a007e}},	//   озум, _khoă, _जनमत_, _адо_,
   {{0x673c04fa,0x9c820146,0x00000000,0x00000000}},	//   mirj, áčko, --, --,
   {{0x316d04ea,0xf8c6049d,0x661c8f98,0x46d202c6}},	//   _chez_, वलिय, myrk, द्रह,
   {{0xe8d90019,0xee1e045f,0x3d040d75,0x7a0a00a7}},	//   _nhờ_, बन्ध_, वासे_, rəti,
   {{0x6b8400e3,0xd83f0146,0x2f560396,0x7a0a00a7}},	//   _éigi, _účel_, штес, səti,
   {{0x32070084,0x98a005db,0xdb0034cb,0x8ee80033}},	//   änyt_, _alič_, nsmå, পালগ,
   {{0x673c023b,0x216a4a52,0x387f015c,0x715911db}},	//   hirj, _риби_, žuri_, _брус_,
   {{0x673c4207,0xe8d90028,0x6eb60037,0xeb063739}},	//   kirj, _chờ_, _نصائ, ачно,
   {{0x7dfc00ae,0x661c0ec9,0x3d040336,0xdb0029d2}},	//   _păsă, kyrk, वाहे_, ksmå,
   {{0xdb0905e6,0xd5b10023,0x3d1801dc,0xe91907bf}},	//   gueñ, ới_, _séwu_, гоні_,
   {{0x6d440774,0x661c0d2d,0xdb003813,0x00000000}},	//   čias, dyrk, dsmå, --,
   {{0x7d028f99,0xdce8013f,0xab9400e3,0x6ecd0be4}},	//   _inos, _sudė, _التغ, _सामु,
   {{0xa2c2000d,0x7bdb0341,0xadc30139,0x3d042065}},	//   _लाग्, _סקוו, _alẹm, वावे_,
   {{0xdb001d0e,0xe45f00c2,0x00000000,0x00000000}},	//   gsmå, _syö_, --, --,
   {{0x8a7b00a1,0xd4980284,0x26da010a,0x38698f9a}},	//   _באות, иру_, _ebpo_, _tzar_,
   {{0x39598f9b,0x673c01ff,0x00000000,0x00000000}},	// [9810] moss_, birj, --, --,
   {{0xd5430139,0x39590aab,0xa37b0231,0x673c05db}},	//   _bẹ́n, loss_, _opõe, cirj,
   {{0x6ecd09c3,0x7d020172,0x8c1a0033,0x6d950090}},	//   _साबु, _onos, _তেমন_, _iġag,
   {{0xe45f00c2,0xed46001c,0x39590365,0x00000000}},	//   _työ_, _رپ_, noss_, --,
   {{0x2f19004d,0x8fe71c47,0x00000000,0x00000000}},	//   лодь_, рцед, --, --,
   {{0xc69500c1,0xdee52c22,0x39598f9c,0xd5430139}},	//   זאַ_, соки, hoss_, _fẹ́n,
   {{0x8c3d6f01,0x00000000,0x00000000,0x00000000}},	//   maşi, --, --, --,
   {{0x4c690036,0x673c0117,0xece91c4c,0xdcf900d1}},	//   лийн_, zirj, удил_, افظت_,
   {{0x60db8f9d,0x3959328e,0x5f940120,0x7b16044c}},	//   _ibum, doss_, _митт, _râur,
   {{0x7d0202dd,0xb87b45f8,0x37bf0033,0x6d950090}},	//   _enos, teín, েবার, _nġag,
   {{0x5d8500e3,0x673c0087,0x6d440220,0x39594aa1}},	//   _الصل, virj, čiar, foss_,
   {{0xe8d900de,0x673c0167,0x00000000,0x00000000}},	//   _thờ_, wirj, --, --,
   {{0xed590087,0x3d040296,0xdb090487,0x673c8f9e}},	//   mož_, वारे_, sueñ, tirj,
   {{0x661c4a75,0x6370007a,0x7e6100c2,0x6b9600ca}},	//   tyrk, mäng, _kylp, _הכסף_,
   {{0xdb0909e9,0xd62708ea,0x63700f3a,0x60db4058}},	//   queñ, боре_, läng, _obum,
   {{0x6ab71362,0x8a1600a1,0x6362001f,0xdb003696}},	//   _आयुर, _לחצו_, môni, rsmå,
   {{0xd6c30018,0x673c0087,0x63620161,0x6b9b0124}},	// [9820] _کمپی, pirj, lôni, npug,
   {{0xadf904dd,0x27e00af0,0xed5900b6,0x60db2d3b}},	//   ्मान_, _ipin_, hož_, _abum,
   {{0x63706986,0xed598f9f,0x6362016d,0x644f8fa0}},	//   häng, kož_, nôni, _exci,
   {{0xa2d80455,0x60db01b9,0x6eda00b6,0x104a008d}},	//   _नॉर्, _cbum, प्नु, ляли_,
   {{0x33b50109,0x65768fa1,0x00000000,0x00000000}},	//   _мёрт, mmyh, --, --,
   {{0x26ca3228,0x65648fa2,0x7d021386,0x60db0129}},	//   ngbo_, llih, _snos, _ebum,
   {{0x3d04000c,0xe7af00a5,0x877b006e,0xe8d90023}},	//   वाले_, _जौनप, נאצי, _nhở_,
   {{0x27e08fa3,0x71260241,0x5bb82a6e,0x6370160c}},	//   _opin_, _ارسل, алия_, fäng,
   {{0x63703114,0x7d020087,0xa3cb05cd,0xa2d8030b}},	//   gäng, _vnos, रूप_, न्थ्,
   {{0x6362001f,0x7b390146,0xff24001c,0x49d80120}},	//   fôni, lňuj, _ببری, адою_,
   {{0xfbcf09b4,0xe8d900de,0x27e00139,0x63620131}},	//   وتی_, _chở_, _apin_, gôni,
   {{0xa2d8632d,0x7d020039,0x63701680,0xc27b00f5}},	//   न्त्, _unos, länd, טריי,
   {{0xdc8e0134,0x39598fa4,0x26d88fa5,0x7d1d0364}},	//   _dịtụ_, ross_, ffro_, össe,
   {{0x81df0033,0xe5c70f80,0x56940451,0x59f800d3}},	//   তিত_, йсбо, зарт, _векя_,
   {{0xa3cb40c1,0x6eda0714,0x63620231,0x00000000}},	//   रंभ_, प्यु, côni, --,
   {{0x3eae02dc,0x6aaa1a68,0x63700f3a,0x656402c9}},	//   haft_, _heff, händ, glih,
   {{0x06e40081,0x6aaa1d51,0x7b390146,0x61ee0f5a}},	// [9830] মাজি, _keff, dňuj, _asbl,
   {{0x8c1b00ca,0x7a0a00a7,0x798a0350,0x6aaa00d7}},	//   אומי, bətt, _kufw, _jeff,
   {{0x3cfe007d,0xa3a90d39,0x65648fa6,0xa2d811b5}},	//   _शोभे_, _गौर_, blih, न्ध्,
   {{0x69c00789,0x6aaa00c2,0xddd40233,0xe8d9020b}},	//   _विनी, _leff, _şaşk, _khố_,
   {{0xd0092644,0xe8d90e62,0x6362016d,0x8e8516d9}},	//   реле_, _nkọ_, zôni, огле,
   {{0xa2d8099d,0x2d9539f8,0x6aaa27a9,0xd5dd009f}},	//   न्द्, орис, _neff, _पहाड़,
   {{0x171c0130,0xe8d92caa,0x8d750037,0x9f44037a}},	//   רווע, _akọ_, يابا, _armó_,
   {{0x60db271c,0xa63c00a1,0x63700149,0x7b3900d4}},	//   _ubum, טגור, täng, cňuj,
   {{0x798a01bf,0x6aaa8fa7,0xed5960d1,0x6370208f}},	//   _aufw, _beff, rož_, bänd,
   {{0x63700704,0x63620161,0xe9d90291,0xe8d90023}},	//   räng, tôni, ако_, _phở_,
   {{0x7a691e61,0x6aaa472d,0x6b9b8fa8,0x752d019f}},	//   ринг_, _deff, spug, khaz,
   {{0x62830220,0x637009b5,0x6362016d,0x00000000}},	//   ľnoh, mäne, rôni, --,
   {{0x6d498fa9,0xbf870019,0xeaae1982,0x68e60fcf}},	//   mnea, _điển_, _ой_, rekd,
   {{0x1ddd0789,0xd5b800d9,0xe8d900de,0xdb1b8116}},	//   _महात, šām_, _thở_, rtuó,
   {{0x6b838faa,0x6d4920ac,0x798a0027,0x78af044c}},	//   _iing, onea, _gufw, bacv,
   {{0x6d494450,0x6b830c71,0x39b500d9,0x6b8b56ad}},	//   nnea, _hing, mās_, _kugg,
   {{0x6d49006b,0x39b50029,0x65642f6b,0xe8c602e8}},	// [9840] inea, lās_, rlih, वलीच,
   {{0x6b838fab,0x6b8b8fac,0x6d490091,0xf7720f36}},	//   _jing, _mugg, hnea, _تاب_,
   {{0x39b50b4b,0x63701424,0x6b838fad,0xe297055b}},	//   nās_, vänd, _ming, цах_,
   {{0x6b838fae,0x752d8faf,0x69c102bc,0x8066008f}},	//   _ling, chaz, irle, овеж,
   {{0x63706986,0x69c101bf,0x7b390146,0x48dc030b}},	//   tänd, hrle, rňuj, ग्यो_,
   {{0x6b838fb0,0x39b50029,0x44200193,0x7b390094}},	//   _ning, kās_, myi_, sňuj,
   {{0x39b50b4b,0x63704435,0x44200018,0x272f01bf}},	//   jās_, ränd, lyi_, _fünf_,
   {{0x6d4907bc,0x6b838fb1,0x39b500d9,0x63700149}},	//   gnea, _aing, dās_, sänd,
   {{0x44206d3f,0x6b838fb2,0x0ed2009d,0x6b8b0036}},	//   nyi_, _bing, _सापड, _cugg,
   {{0x37d00081,0xda7a036a,0xa3cb08d4,0xdb0000f2}},	//   িবার, иян_, रंत_, nsmø,
   {{0x39b500d9,0x28f93b2f,0x6b8317c9,0x6b5d00fd}},	//   gās_, бень_, _ding, tègr,
   {{0x394d0303,0x6b838544,0xe8d90028,0x6b8b8fb3}},	//   ões_, _eing, _phố_, _fugg,
   {{0x4420023f,0x6b8b8fb4,0x6d408fb5,0x79840188}},	//   jyi_, _gugg, mima, _diiw,
   {{0x443200a5,0x39b501d3,0xa49b00ee,0x2d8c8fb6}},	//   dzy_, bās_, _enòl, _kude_,
   {{0x752d0060,0x39b500d9,0xdce2007f,0x442006b0}},	//   thaz, cās_, _choć, eyi_,
   {{0x6d408fb7,0x6b838fb8,0x2d8c8fb9,0x79840065}},	//   nima, _zing, _mude_, _giiw,
   {{0x6b83533a,0x44200018,0x2d8c0106,0xe3b30397}},	// [9850] _ying, gyi_, _lude_, برز_,
   {{0x6d408ed7,0x2d8c0ab2,0x74150018,0x6b83656d}},	//   hima, _oude_, _ہوجا, _xing,
   {{0x6d408fba,0x69c88fbb,0x7c2002ad,0x752d0201}},	//   kima, nude, hymr, phaz,
   {{0x6d4001b3,0xdb090080,0x7c20038c,0x44200193}},	//   jima, iseá, kymr, byi_,
   {{0x44320067,0x6d406c87,0x2d8c8fbc,0x3eac01df}},	//   czy_, dima, _aude_, _bedt_,
   {{0x2d8c5753,0x78ad8fbd,0x68fa00d9,0x3cdd030b}},	//   _bude_, _leav, ētdi, क्ने_,
   {{0x6d40008a,0x6b8b0e04,0x6d490a6c,0x69c88fbe}},	//   fima, _sugg, tnea, jude,
   {{0x6b838fbf,0x39b500d9,0x6d408fc0,0xdb1b05fe}},	//   _sing, vās_, gima, truï,
   {{0x6b838fc1,0x3eac052f,0xb4e917ad,0x637000ce}},	//   _ping, _fedt_, _यसै_, säne,
   {{0x39b50029,0x6d4909f7,0x49c95ac0,0xe80f50d7}},	//   tās_, snea, блон_, ामना_,
   {{0x6b838fc2,0xc4cb00a5,0x44328fc3,0x69c88fc4}},	//   _ving, िलाओ, zzy_, gude,
   {{0x69c10f20,0x39b500d9,0xdce92461,0x4420180d}},	//   rrle, rās_, dmeć, yyi_,
   {{0x39b501d3,0x3f858fc5,0x3f8d015e,0x7bf900ae}},	//   sās_, _kilu_, _jueu_, _ындр_,
   {{0x7d195591,0x69c87ac7,0x6b830010,0xdb0905e6}},	//   _hows, bude, _uing, rreó,
   {{0xe737545a,0x8c3d020a,0x64a6141a,0xc60a0a43}},	//   чер_, raşu, заба, রন্থ_,
   {{0x3f858fc6,0x78ad01c0,0x44200311,0x1a6500cd}},	//   _lilu_, _geav, tyi_, _ویکی_,
   {{0x75248fc7,0x1aee0081,0x39428fc8,0xa49b00b3}},	// [9860] rkiz, জারে_, miks_, _gnòm,
   {{0x44321799,0x6d408fc9,0x39428fca,0x3f85283d}},	//   rzy_, zima, liks_, _nilu_,
   {{0x44320067,0x68f68fcb,0x442639c1,0x6d408fcc}},	//   szy_, _kayd, šo_, yima,
   {{0x3f8d03be,0x39428fcd,0x68f68fce,0x7d19007f}},	//   _bueu_, niks_, _jayd, _nows,
   {{0x6d408fcf,0x68f614ca,0xa3cb0378,0xf3ff016d}},	//   vima, _mayd, रूद_, _grã_,
   {{0x2d8c8fd0,0x394200aa,0x6d408fd1,0x68f6008c}},	//   _pude_, hiks_, wima, _layd,
   {{0x91e309a2,0x6d408fd2,0x7d1901af,0x63b66374}},	//   _поре, tima, _bows, lsyn,
   {{0xdb981f02,0x69c80572,0xa2aa0f35,0x2cea036c}},	//   ович_, vude, टरव्, сько_,
   {{0x7bc98fd3,0x63b60073,0x5f760018,0x7ae8160e}},	//   gueu, nsyn, _فائر, tedt,
   {{0x6d40339b,0x81df00c7,0xab970037,0x161c0179}},	//   sima, তির_, أخير_, नहार_,
   {{0x6d40504b,0x68f6008a,0x78ad007a,0x7ae825ff}},	//   pima, _bayd, _peav, redt,
   {{0x6f1a20bb,0x68f60188,0x394200aa,0x63b68fd4}},	//   _hotc, _cayd, giks_, ksyn,
   {{0x69c88fd5,0x68f60188,0x00000000,0x00000000}},	//   sude, _dayd, --, --,
   {{0x69c88fd6,0x48e900b6,0xdb09037a,0x636b0555}},	//   pude, _जसको_, breñ, günl,
   {{0x68f603a3,0x78ad87de,0xa4d5325f,0x645800a7}},	//   _fayd, _teav, мові, şvil,
   {{0x5ec50033,0x68f6041c,0x25bf0206,0xf3ff0231}},	//   ল্পে, _gayd, čul_, _prã_,
   {{0xdcfa0029,0x2909008c,0x88bc00ca,0x00000000}},	// [9870] _attī, _inaa_, _המחז, --,
   {{0x6f1a0158,0x00000000,0x00000000,0x00000000}},	//   _notc, --, --, --,
   {{0xa3b90592,0x68f61e6b,0x4ad41677,0x00000000}},	//   _घटक_, _yayd, _दानव, --,
   {{0x9c130174,0x3f85161f,0x81df0033,0x68f679af}},	//   _kọti, _silu_, তিল_, _xayd,
   {{0xe0d0046b,0x7d190365,0x7bc970d8,0xa3e10ded}},	//   ازم_, _rows, xueu, _दहि_,
   {{0xdb1b0bfe,0x05b1009d,0xdce1003d,0x82370421}},	//   truí, _जबाब, _kulħ, _فرزا,
   {{0x7d1900a5,0x272f0233,0x00000000,0x00000000}},	//   _pows, _güne_, --, --,
   {{0xe8d90019,0xa3e10096,0x2d863ab5,0x29097da1}},	//   _khổ_, _दहा_, _cioe_, _nnaa_,
   {{0x3f850fc7,0x39428fd7,0xdb09003e,0x6f1a04f8}},	//   _tilu_, viks_, freð, _fotc,
   {{0x81c200c7,0x29093b2e,0x80d9000c,0x68f68fd8}},	//   ্বর_, _anaa_, फ्रे, _sayd,
   {{0x68f68fd9,0x13e600c7,0x39428fda,0x1dc60378}},	//   _payd, নিয়, tiks_, रूआत,
   {{0x68f60092,0x63b68fdb,0xdb09334c,0x9c130af0}},	//   _qayd, ysyn, rreñ, _bọti,
   {{0x636b07aa,0x39428fdc,0x7bc900fd,0xe8d900fe}},	//   tünl, riks_, queu, _nhổ_,
   {{0x68f6008a,0x59c52918,0x39428fdd,0xa29f030b}},	//   _wayd, _विपर, siks_, खुम्,
   {{0x212d2129,0x63700212,0xd62a008f,0xd84f0174}},	//   _oleh_, jäna, цове_, wọta_,
   {{0xadf0007a,0x00000000,0x00000000,0x00000000}},	//   _अईसन_, --, --, --,
   {{0xd4672249,0x04431ab2,0x61e900cb,0xe8d90023}},	// [9880] дите_, ветн, _ćela, _chổ_,
   {{0x63b6038c,0xd7762296,0x212d0072,0x3cdd0085}},	//   rsyn, _تابع, _aleh_, क्ते_,
   {{0x212d0332,0x63b68fde,0x00000000,0x00000000}},	//   _bleh_, ssyn, --, --,
   {{0x53a90096,0xd7d200c3,0x98b9020a,0xd84f0174}},	//   _चौकश, _तमाच, misă_, pọta_,
   {{0x6f1a8fdf,0xd84f0174,0x00000000,0x00000000}},	//   _potc, lọra_, --, --,
   {{0xdd9a075f,0x212d0063,0x2d860150,0x800b0103}},	//   оши_, _eleh_, _sioe_, ترمہ_,
   {{0x66e0007a,0x3940305a,0x00000000,0x00000000}},	//   ख्यक_, _omis_, --, --,
   {{0x9c130134,0xe73f016d,0x9bf41ca5,0x00000000}},	//   _nọsi, mpõe_, езич, --,
   {{0x6143139c,0x98b900ae,0x6f1a00b3,0x7f430154}},	//   _рета, hisă_, _totc, binq,
   {{0x3940025a,0x7f430451,0xb87b037a,0x00000000}},	//   _amis_, cinq, nfíe, --,
   {{0x8e4a00e3,0x28f98fe0,0x9c130139,0x22950065}},	//   _بلاك_, пень_, _bọsi, _húkó_,
   {{0xfd4f0134,0x212d00dc,0x0c26002d,0x2d9e4c46}},	//   _mejọ, _xleh_, _омен, _itte_,
   {{0x1bf20e72,0x9c130065,0x00000000,0x00000000}},	//   _अनिल_, _dọsi, --, --,
   {{0xf53f3813,0x3993001f,0x39408fe1,0x2fc60270}},	//   _små_, _fãs_, _emis_, irog_,
   {{0x56942549,0x6d870103,0x98a90117,0xdef8009e}},	//   таст, _műan, _hlač_, _maċ_,
   {{0x7af860f5,0xe8d90019,0x636b07aa,0x765b026a}},	//   _havt, _phổ_, rünm, şuyo,
   {{0x7af8023e,0x69da8fe2,0x54551940,0x337513a4}},	// [9890] _kavt, ltte, хват, егар,
   {{0x2fc61e71,0x2d9e052f,0x38690044,0x69da373c}},	//   drog_, _otte_, _iyar_, otte,
   {{0x69da0084,0x212d0218,0x69cf0034,0x29d8020d}},	//   ntte, _pleh_, ąceg, néa_,
   {{0x69da02fd,0x3cfe0789,0xe8d900de,0x38690d2a}},	//   itte, _शोले_, _thổ_, _kyar_,
   {{0x7feb0678,0x93271dec,0x6370071b,0x7f430092}},	//   تراف_, _قرآن, männ, tinq,
   {{0x7af88fe3,0x7df30092,0x69da7c4e,0x637005f8}},	//   _navt, _həsə, ktte, länn,
   {{0x62830181,0x212d033b,0x7f4300a7,0xa3cb5685}},	//   ľnos, _tleh_, rinq, रूर_,
   {{0x628341f9,0x2fc6005f,0xa2d70081,0x98a02461}},	//   žnos, brog_, _সফটও, _ilić_,
   {{0x7df301d4,0x2d9e0006,0x3d040455,0x5e591ac9}},	//   _məsə, _ette_, वाजे_, _کلاس_,
   {{0x8c9f0789,0x3f9f0167,0x7af80234,0x00000000}},	//   _ग्रो, _ituu_, _cavt, --,
   {{0xa96a13dc,0x3869097f,0x637063bb,0xb06201a5}},	//   зина_, _ayar_, känn, _ääri,
   {{0xfe6e00cd,0xf7690266,0x386900f3,0x394002a1}},	//   _اگه_, _הק_, _byar_, _qmis_,
   {{0x7d0b001c,0x69da8fe4,0x636b758e,0xdb0b05e8}},	//   _ings, atte, günk, _avgå,
   {{0xdb1b4668,0x8c1a0327,0x273400aa,0x98a000c4}},	//   bruá, _מוני, _mäng_, _olić_,
   {{0x7bdb7c85,0x3d04009d,0xd94644f3,0x67210212}},	//   ltuu, वाचे_, _пеки, ölja,
   {{0x98b900ae,0x7df3013c,0x00000000,0x00000000}},	//   risă_, _cəsə, --, --,
   {{0x7bdb6609,0x68e489b2,0x98a01523,0x00000000}},	// [98a0] ntuu, _ibid, _alić_, --,
   {{0x3ced01fa,0x7d0b0085,0x42562fad,0x59a61980}},	//   heev_, _lngs, нтет, कीकर,
   {{0xe8d90019,0xf8bf20cc,0x7bdb00c2,0x3cf400aa}},	//   _chỗ_, chés_, htuu, ्यमे_,
   {{0x7bdb2d21,0x8c9f8fe5,0x2fc67a52,0x386903e3}},	//   ktuu, _ग्लो, trog_, _yyar_,
   {{0x68e40129,0x7f461546,0xd43600e3,0xe73f0161}},	//   _mbid, недж, _أعجب, spõe_,
   {{0x69da41b6,0xf1c300d2,0x00000000,0x00000000}},	//   ytte, ýší_, --, --,
   {{0x68e48fe6,0x63a48fe7,0x628e8fe8,0x7bdb3eb3}},	//   _obid, lpin, _igbo, etuu,
   {{0x68e48fe9,0x98a93452,0x2fc68fea,0x7ae30169}},	//   _nbid, _plač_, prog_, _abnt,
   {{0x63a48feb,0xdef8003d,0x27340212,0xcb461165}},	//   npin, _taċ_, _känd_, ехни,
   {{0x68e48fec,0x307562f9,0x7e68057a,0x7d0b304c}},	//   _abid, _русс, _tydp, _engs,
   {{0xc3338943,0x2bc20ed5,0x19590109,0x38690808}},	//   רות_, _शिवा, даны_, _syar_,
   {{0x69da8fed,0x98a90220,0x29d801dc,0x200400c4}},	//   rtte, _tlač_, réa_, _krmi_,
   {{0x629c00dd,0x7bdb0126,0x628e026e,0xd05b01c2}},	//   _ofro, ctuu, _ogbo, _dauɗ,
   {{0x68e44188,0x999e0018,0x65660167,0x628e0e62}},	//   _ebid, sztő_, _akkh, _ngbo,
   {{0x7d0b2fe3,0x63a4396c,0xf8bf02c6,0xe5c46c77}},	//   _yngs, epin, lkém_, лсто,
   {{0x59c5000c,0xc4cb06ed,0x628e1a40,0x7df300a7}},	//   _वितर, िलेख, _agbo, _qəsə,
   {{0xf2c703d9,0xf8bf009d,0x63708fee,0x63a40fa0}},	// [98b0] есен, ्लीप, ränn, gpin,
   {{0x69c80272,0xd0110260,0x27e900f9,0x68fd8fef}},	//   orde, یلا_, _ipan_, ldsd,
   {{0x20046c5f,0x7df30092,0x27340212,0x6d42020a}},	//   _armi_, _təsə, _säng_, _omoa,
   {{0x68fd4a75,0x69c80527,0x628e0129,0x629c8ff0}},	//   ndsd, irde, _egbo, _efro,
   {{0x69c88ff1,0x80090018,0x68fd1030,0xd2500018}},	//   hrde, براہ_, idsd, لنے_,
   {{0xb87b037a,0xd0060e3a,0x00000000,0x00000000}},	//   leís, теше_, --, --,
   {{0x8d552064,0xed59249c,0x7d0b00e7,0xb3540161}},	//   ктич, мок_, _pngs, _скрш,
   {{0x7bdb00c2,0x68fd21a4,0x656d8ff2,0x13d50033}},	//   ttuu, jdsd, nlah, _সৈয়,
   {{0x69c801a2,0x7f95013d,0x68e4009c,0x656d026d}},	//   erde, _разх, _rbid, ilah,
   {{0x7bdb3adb,0x656d019f,0x59c51d69,0x00000000}},	//   rtuu, hlah, _विदर, --,
   {{0x7bdb82bf,0x81df00c7,0x27e911b9,0x98a611db}},	//   stuu, তিক_, _apan_, кине,
   {{0xfeac0649,0x26c100f9,0x27e9009c,0x63a48ff3}},	//   _iṣẹ_, _adho_, _bpan_, ypin,
   {{0x69c80371,0x656d025b,0xf8bf00b6,0x2be500bc}},	//   arde, dlah, ckém_, _कहिं_,
   {{0x27e9005c,0x7bdc00ae,0xa3d402d5,0x07a327d4}},	//   _dpan_, ărut, सूफ_, рарн,
   {{0xa3d402e8,0x63bd0160,0x1659249c,0x9a690037}},	//   सून_, _avsn, ерть_, _تمثل_,
   {{0x2be51161,0x656d8ff4,0x629c0dda,0x68e401c8}},	//   _कहां_, glah, _sfro, _ubid,
   {{0x3cf42171,0xb87b6823,0x63a45b60,0x7bc98178}},	// [98c0] ्यते_, rfíc, upin, nreu,
   {{0x63a48ff5,0x657f023e,0x656d0188,0x00000000}},	//   rpin, amqh, alah, --,
   {{0x63a48ff6,0x656d6950,0xe5a602a0,0x7bc90381}},	//   spin, blah, _шини, hreu,
   {{0x63a48ff7,0xd5b80029,0x4fc62de9,0x656d008c}},	//   ppin, šās_, вска, clah,
   {{0xb4c00455,0xb4ce03a2,0xa3ba1a37,0x81e80081}},	//   ीली_, रली_, _تاجر_, বিধ_,
   {{0x6d426c0e,0x628e00ac,0xb87b0328,0x6564007b}},	//   _smoa, _ugbo, nfía, loih,
   {{0x41aa0426,0xe1f700c2,0x2eee8360,0x7bc901ce}},	//   _іван_, _игр_, reff_, ereu,
   {{0xed570cb8,0x7bc901bf,0x2fdd023e,0x7c861a19}},	//   кој_, freu, btwg_, купе,
   {{0x06b80081,0x9f4d05e6,0x7bc9020a,0x5fc91981}},	//   _জানি, _creó_, greu, _रियल,
   {{0xc1800129,0xfe422c31,0xee7a0076,0x3f990131}},	//   _ịghọ, _پکتی, _قصات_, _ésua_,
   {{0x27e90185,0x69c801a2,0x656d8fa6,0xf8bf00b6}},	//   _span_, urde, ylah, ském_,
   {{0xdca63974,0xf8bf0018,0x7bc9319e,0x3f8c0063}},	//   _ради, mkék_, breu, _hidu_,
   {{0xb8eb007d,0x7bc92f7c,0xcc1601c3,0x3f8c0113}},	//   _लय_, creu, _جذاب, _kidu_,
   {{0xcf9300c1,0x656d008a,0xbb430095,0x66050234}},	//   יטש_, wlah, _кечк, _prhk,
   {{0xd5b820a7,0x80d3000f,0xb8d90033,0xb87b0072}},	//   кст_, _डाले, _চা_, teís,
   {{0xdb1b0396,0x850d0789,0x656d409f,0x2ba9030b}},	//   truç, हाइट_, ulah, चीका,
   {{0x656d005a,0x4394036a,0xcfd70033,0x0ed200a4}},	// [98d0] rlah, иатс, _দৈনন, _सांड,
   {{0x656d8ff8,0x6fcc0096,0x2fdd023e,0x764e0103}},	//   slah, _समजू, vtwg_, ányá,
   {{0x67280212,0xb87b002b,0x656d56a1,0xe8d9020b}},	//   ödje, peís, plah, _nhừ_,
   {{0x59c51376,0x7bc902db,0x3f8c3b64,0x00000000}},	//   _विसर, yreu, _aidu_, --,
   {{0x3f8c003d,0x752d18fd,0x00000000,0x00000000}},	//   _bidu_, mkaz, --, --,
   {{0x44292bf4,0x543a00c1,0x7bc90dbb,0x3f8c01ee}},	//   mya_, _טערא, vreu, _cidu_,
   {{0x02af1ae6,0x3f8c0113,0x28d40966,0x06b80033}},	//   टरीन, _didu_, _थालि, _জামি,
   {{0x7bc98ff9,0x16b00251,0x752d019f,0x9f4d028d}},	//   treu, _जज्ब, nkaz, _creò_,
   {{0x7bc90257,0xbab5055b,0xa05501b3,0x00000000}},	//   ureu, лёны, _сваі, --,
   {{0x89a9387c,0x7bc98ffa,0xa3d40789,0x44298ffb}},	//   нков_, rreu, संत_, iya_,
   {{0x44298ffc,0x798d02e7,0x394a4abb,0x5cd500ab}},	//   hya_, _biaw, езно_, _مقاط,
   {{0x44298ffd,0x7bc9002d,0x798d0085,0x89360037}},	//   kya_, preu, _ciaw, اعدا,
   {{0x59c511c6,0x4429092f,0x798d8ffe,0x3156006e}},	//   _विवर, jya_, _diaw, רירן_,
   {{0x3cfd023e,0x7d1b8fff,0x6d499000,0xa03a006e}},	//   _hawv_, ljus, liea, געשפ,
   {{0xceb27c04,0x3cfd023e,0x62810244,0x44290188}},	//   מים_, _kawv_, _úloh, eya_,
   {{0xb4ce3873,0xb4c009f6,0x44299001,0x798d0124}},	//   रले_, ीले_, fya_, _giaw,
   {{0x7c29552a,0x7c3b9002,0x44299003,0x6b8d0080}},	// [98e0] nyer, nzur, gya_, _éags,
   {{0x57fb0054,0x3cfd0d7d,0x7d1b0006,0x78b600a7}},	//   _טלפו, _lawv_, hjus, _heyv,
   {{0xf77200d0,0xdce20213,0x442982ad,0xaca30129}},	//   _پاک_, _skoč, aya_, _asọm,
   {{0x44299004,0x3cfd006c,0x7d1b0361,0x7c29083e}},	//   bya_, _nawv_, jjus, kyer,
   {{0x7d1b9005,0x78b60511,0x44298135,0x3f8c00aa}},	//   djus, _meyv, cya_, _pidu_,
   {{0x78b6034f,0x7c292eec,0x00000000,0x00000000}},	//   _leyv, dyer, --, --,
   {{0x7afe22bf,0x3d8a00c2,0xa49b009c,0x7de60f98}},	//   _ópti, нщин_, _gnòs, استم,
   {{0x3cfd006c,0x42531850,0x867b006e,0xdb009006}},	//   _cawv_, _انفر, ערקו, nsmö,
   {{0x7c29570b,0x3cfd023e,0xdce2042d,0x00000000}},	//   gyer, _dawv_, _ukoč, --,
   {{0xef832249,0xb4db00b3,0xdfcf0076,0x629e044c}},	//   _глуп, _amàl, _ريم_, ncpo,
   {{0x6e930080,0x5e930080,0x7e569007,0xaa581803}},	//   _الما, _المط, _стац, тину_,
   {{0x4429663f,0x3cfd023e,0x7c296b87,0xe8d900de}},	//   yya_, _gawv_, byer, _khứ_,
   {{0x752d43c5,0x69c00d88,0x386d02b6,0x7c290079}},	//   vkaz, _विकी, æer_, cyer,
   {{0x7bfb00a1,0x7dea0092,0x44290051,0x3cfd023e}},	//   _נפוצ, _təsd, vya_, _zawv_,
   {{0x44290113,0xd90f001c,0x6aba4563,0x95c8247a}},	//   wya_, _فید_, matf, лута_,
   {{0x44299008,0x06c60081,0x752d0031,0x637017a5}},	//   tya_, শ্লি, ukaz, bänk,
   {{0x44290154,0x394b4a64,0x29270034,0x636b04a8}},	// [98f0] uya_, mics_, ętać_, künt,
   {{0xd25b450e,0x44299009,0x394b900a,0x752d0010}},	//   нце_, rya_, lics_, skaz,
   {{0x3207025b,0x7c3b0451,0xbbc10285,0xdce9015c}},	//   íny_, zzur, _षट्क, zmeđ,
   {{0x394b900b,0x7c3b0034,0xdce92db5,0x68ff009e}},	//   nics_, yzur, tleč, _jaqd,
   {{0xe8d90028,0x06b80081,0x3cfd022e,0xa29500d6}},	//   _chứ_, _জাতি, _rawv_, _вагі,
   {{0x3cfd01bb,0x9294004b,0x394b0158,0x7c290ac1}},	//   _sawv_, _гарц, hics_, vyer,
   {{0x3cfd023e,0xf204008f,0x6d492325,0x7d1b007b}},	//   _pawv_, _лято, tiea, tjus,
   {{0x7c29178b,0x7c3b6382,0x68ff17f4,0x7c36007f}},	//   tyer, tzur, _naqd, _żyra,
   {{0x75ec0068,0xa3cb0455,0x394b900c,0x60db0193}},	//   _közö, रंट_, dics_, _icum,
   {{0xff530080,0xef67013d,0x81e80081,0x7c290ab7}},	//   _اخر_, _събо, বির_, ryer,
   {{0x394b900d,0xb0b90557,0x3cfd0197,0x7c290d1f}},	//   fics_, _उजाग, _tawv_, syer,
   {{0x63700222,0x394b05fe,0x7c2912f5,0xb87b900e}},	//   tänk, gics_, pyer, rfín,
   {{0x6aba02b6,0x6d59063d,0x00000000,0x00000000}},	//   batf, _ijwa, --, --,
   {{0xfaa51588,0x63702104,0x2cad900f,0x2d8f009c}},	//   _тако, ränk, lbed_, _hige_,
   {{0x29560465,0x28a71b79,0x60db037a,0x63701b80}},	//   _въпр, _क्वि, _ocum, sänk,
   {{0x2d8f022b,0x637032f4,0x394b00b3,0x636b01f9}},	//   _jige_, mäni, cics_, zünt,
   {{0x29120174,0x2900312c,0x93460da5,0x00000000}},	// [9900] _inya_, _iaia_, анае, --,
   {{0x2d8f9010,0x60db7ab9,0x29129011,0x29009012}},	//   _lige_, _acum, _hnya_, _haia_,
   {{0x80a61850,0xaadd048a,0x4add1c83,0x291207ac}},	//   لمان, _मानक, _मानव, _knya_,
   {{0x3be5009f,0x290001e9,0x81e80033,0x2d8f0027}},	//   _कहूँ_, _jaia_, বিল_, _nige_,
   {{0xdefa02fd,0x31ac0154,0x636b25bb,0xa3ea00b7}},	//   вый_, _bòzò_, güns, _महि_,
   {{0x2d8f10f0,0xd00f177a,0x29009013,0xe8070557}},	//   _aige_, بله_, _laia_, शिता_,
   {{0x636b1f8a,0x2d8f9014,0x2912045d,0x60db01b9}},	//   rünt, _bige_, _onya_, _fcum,
   {{0xe8d90028,0xa3ea00a3,0x29008996,0x2d984073}},	//   _thứ_, _महा_, _naia_, _érem_,
   {{0x8fa33f98,0x61e90039,0x2d8f01c2,0x8cd70789}},	//   _мате, _ćeli, _dige_, _यारो,
   {{0x29120857,0x8ca60789,0x2902008a,0x320a0146}},	//   _anya_, _ट्रो, edka_, _krby_,
   {{0x2bc22ebd,0x29009015,0x394b3166,0x2d8f0ebd}},	//   _शिका, _baia_, tics_, _fige_,
   {{0x38c909b4,0xdd8f006f,0x29007378,0x5fba009f}},	//   دادی_, _قول_, _caia_, _उबाल,
   {{0x20069016,0x394b9017,0x29120167,0x27ed66cc}},	//   nvoi_, rics_, _dnya_, ïen_,
   {{0x28a7022d,0x29129018,0x394b9019,0x2902901a}},	//   _क्रि, _enya_, sics_, adka_,
   {{0x68ff901b,0x689300bf,0x3cdd02d5,0x29000956}},	//   _taqd, _ویدئ, क्के_, _faia_,
   {{0x29000a00,0xef190034,0x00000000,0x00000000}},	//   _gaia_, _duży_, --, --,
   {{0x394903ce,0x3cde0034,0x449800c2,0x2d84007b}},	// [9910] _imas_, _गाने_, рвую_, imme_,
   {{0x27340006,0x60db00d3,0x48e30521,0x63a20037}},	//   _täna_, _scum, ट्रो_, íona,
   {{0xa2dd19af,0xa3cb0e50,0x636b01bf,0x938858aa}},	//   _पाठ्, रूज_, wüns, рста_,
   {{0x29120167,0x212403dc,0x7bc0004b,0x30150243}},	//   _xnya_, _comh_, ksmu, йдер,
   {{0x83871119,0x2d8f901c,0x212403dc,0xbea50879}},	//   _выве, _rige_, _domh_, балк,
   {{0x2d8f901d,0x3949023e,0x2d84007b,0x7bc02e7f}},	//   _sige_, _lmas_, emme_, dsmu,
   {{0x2cad901e,0x78bd2490,0x2d8f052f,0x7bc200fd}},	//   tbed_, kasv, _pige_, _avou,
   {{0x260802e8,0x28a70861,0x78bd0220,0x067c00ca}},	//   हिती_, _क्लि, jasv, כנול,
   {{0x40342c13,0x2cad901f,0x29000010,0x7bc09020}},	//   _детс, rbed_, _raia_, gsmu,
   {{0x7de702ec,0x39499021,0x29009022,0x7bc2030b}},	//   _відд, _amas_, _saia_, _dvou,
   {{0xe8d90028,0x29009023,0x2d8f9024,0x291209a4}},	//   _chữ_, _paia_, _tige_, _pnya_,
   {{0x3cde009f,0x637009b5,0x6d950031,0x7c950037}},	//   _गाये_, räni, _všad, _الإص,
   {{0x6c8500e3,0x290003be,0x29020509,0x317f0090}},	//   _الشم, _vaia_, rdka_, _mhuz_,
   {{0x394926f7,0x6d50007f,0xdb0900ee,0x00000000}},	//   _emas_, ądał, nseü, --,
   {{0xe5a6051b,0x6f019025,0x291202e7,0x5b7a00ca}},	//   сиби, _malc, _tnya_, _גרסא,
   {{0x29129026,0x69c17f6f,0x6f0100b3,0x00000000}},	//   _unya_, msle, _lalc, --,
   {{0x69c125cc,0xf484001c,0x7dea00a7,0x212401b9}},	// [9920] lsle, زاری, _məsa, _romh_,
   {{0xa2dd194f,0x7c240013,0x5fd10096,0x00000000}},	//   _पाण्, _àire, _समजल, --,
   {{0xfe650018,0x2d8416c7,0x28be0285,0x00000000}},	//   _آگ_, ymme_, ्णपि, --,
   {{0x69c19027,0x6d9505db,0xf77f0233,0xe0030b2b}},	//   isle, _ošab, rtçe_, लिंद_,
   {{0x572509e5,0x60182b69,0x28db32c9,0x987a006e}},	//   _طریق, роля_, _भासि, װאַט,
   {{0x6f0129b0,0xe2970aa8,0x69c124b8,0xdce000d9}},	//   _calc, _гар_, ksle, domā,
   {{0xa2dd00a8,0xa3d40455,0x9c130174,0x69c100d8}},	//   _पात्, सूर_, _gọzi, jsle,
   {{0xc0e317b9,0x7bc6013f,0x69c12ca7,0xdb190154}},	//   _носк, škum, dsle, _avwà,
   {{0x6f0116ea,0x88b70033,0x2c1e0033,0x491c0c9c}},	//   _falc, _ঝালক, _বেড়ে_, यानो_,
   {{0x60230109,0x25a6033b,0x69c19028,0x78bd0313}},	//   _эдуа, _čoln_, fsle, wasv,
   {{0x69c18ae7,0x9952030b,0x78bd5f50,0x38601a4a}},	//   gsle, lář_, tasv, _axir_,
   {{0x48ab0226,0x7d1d042c,0x9c130065,0x00000000}},	//   ытом_, össt, _lọyi, --,
   {{0x672502fd,0xc8670e38,0x69c301df,0x995200b6}},	//   _pohj, стни, _evne, nář_,
   {{0xd6d81d57,0x7d026615,0x69c19029,0x2bf70142}},	//   йтс_, _haos, bsle, _למדן_,
   {{0x80d83212,0x957700cd,0x69c1119e,0x63a20076}},	//   डलाइ, مدرض, csle, íonn,
   {{0x3949001f,0xe8d90023,0x7d024880,0x7dea00a7}},	//   _umas_, _khử_, _jaos, _xəsa,
   {{0x24180ff8,0xa3d40ff9,0x7d023c0d,0x2a8e0092}},	// [9930] боты_, सूल_, _maos, ləb_,
   {{0x70d10251,0x7d02902a,0xd6db0284,0x00000000}},	//   हल्ल, _laos, _сти_, --,
   {{0xf7742252,0xd095007b,0x00000000,0x00000000}},	//   _מקץ_, ошлы, --, --,
   {{0x3f9901dc,0x00000000,0x00000000,0x00000000}},	//   _ésuk_, --, --, --,
   {{0x68ed8f57,0xe8d90134,0x675412eb,0xa0690e2c}},	//   _mbad, _ajị_, _ذخیر, јала_,
   {{0x7a3f0068,0xf6500068,0xc7d800a1,0x69c1902b}},	//   _játé, _آئی_, מודי_, ysle,
   {{0x68ed902c,0x6f01902d,0x7d02677b,0xb4db009c}},	//   _obad, _valc, _baos, _amài,
   {{0x6f010034,0xa15949f4,0xdce001d3,0x3cde0096}},	//   _walc, _табу_, tomā, _गाणे_,
   {{0x63ad902e,0x4ad402e8,0x60c90995,0xe8d92e5c}},	//   npan, _दाखव, _idem, _ejị_,
   {{0x68ed310b,0x69c10407,0x200d2226,0xb178003e}},	//   _abad, tsle, _irei_, _þórð,
   {{0x63ad0167,0xf2d20796,0x8d740421,0x7dea00a7}},	//   hpan, ועי_, _کالا, _təsa,
   {{0x63ad902f,0xa3ea0d39,0x69c10b81,0xa96a1e58}},	//   kpan, _महल_, rsle, рима_,
   {{0x3cde0789,0x6d4b02a1,0x28db2171,0xe76a0d59}},	//   _गाते_, _imga, _भारि, لحسن_,
   {{0x69c300d9,0x2cbf9030,0x2a8e0092,0x69c19031}},	//   _tvne, laud_, bəb_, psle,
   {{0x63ad028a,0x00000000,0x00000000,0x00000000}},	//   epan, --, --, --,
   {{0x959920f9,0x68ed4eac,0x2cbf17f9,0x200d00ae}},	//   стру_, _gbad, naud_, _orei_,
   {{0xccf202f8,0x63ad1098,0x0326327e,0xc3260c37}},	// [9940] וכן_, gpan, одан, омак,
   {{0x60c911c4,0xe3b704a1,0x4902030b,0x68ed47ba}},	//   _adem, юбу_, षयको_, _zbad,
   {{0x6d4b2b31,0xe1fa9032,0x63ad0037,0x48e1074c}},	//   _omga, рге_, apan, _कामो_,
   {{0xa50a13b0,0x200d5e36,0x63ad0124,0x6ed7030b}},	//   _тема_, _brei_, bpan, _ठाउँ,
   {{0x200d1b38,0x60c923b3,0x7d0200d1,0x272f013c}},	//   _crei_, _ddem, _raos, _süni_,
   {{0x60c99033,0x200d02e2,0x7d029034,0x73f9006e}},	//   _edem, _drei_, _saos, _פּרו,
   {{0x64490102,0x995202c6,0x2d9a014b,0x200d078e}},	//   _þeir, sář_, êpe_, _erei_,
   {{0x200d01bf,0x2cbf16d5,0xe0d70120,0x25370142}},	//   _frei_, gaud_, _мвс_, ַניש_,
   {{0x81bc0f71,0x200d9035,0x644007e7,0xff270103}},	//   _আমি_, _grei_, _ümid, _ڈبلی,
   {{0x6d4b87aa,0x68ed6848,0xba0a008f,0x7d029036}},	//   _emga, _sbad, ахме_, _waos,
   {{0x81e80081,0x13b30081,0xa2dd16f8,0x06e30033}},	//   বিক_, টওয়, _पास्, য়মি,
   {{0xe8d90028,0x63ad9037,0x68ed02a1,0x2cbf00fc}},	//   _thử_, ypan, _qbad, caud_,
   {{0x81b703e3,0x6370007b,0xb89a02c6,0xdd8f033c}},	//   ɓɓuk, näns, _šťáv, _شوه_,
   {{0x6d950090,0xe8d90065,0x00000000,0x00000000}},	//   _iġar, _ijọ_, --, --,
   {{0x56941bb8,0xe8d90019,0xda6f00d6,0x63ad01af}},	//   дарт, _chợ_, _ця_, wpan,
   {{0x68ed1005,0x63700212,0x290500e8,0x00000000}},	//   _ubad, käns, ēlas_, --,
   {{0x63ad9038,0x63700149,0x6d9502a1,0x00000000}},	// [9950] upan, jäns, _jġar, --,
   {{0xc7b25f61,0xd371300d,0x63ad9039,0xb2ab083c}},	//   _רבי_, رها_, rpan, ртаж_,
   {{0x637009df,0x63ad154c,0x877c006e,0x200d0113}},	//   vänt, span, _דאזי, _srei_,
   {{0x61e5627c,0x644003e5,0x2608030b,0x200d2121}},	//   rthl, _żmie, हिरी_, _prei_,
   {{0xd009002d,0x251a040a,0xe8d90129,0xb4d71fbb}},	//   селе_, _הורא, _njọ_, सली_,
   {{0x200d002d,0xe3b200c1,0xa85800ca,0xd00e15ae}},	//   _vrei_, _אױך_, חידה_, الو_,
   {{0x09af0081,0x43942223,0xe8d90129,0x31c419e8}},	//   _কিভা, _царс, _ajọ_, _оств,
   {{0x200d002d,0x64410092,0x6b88029a,0x0c2530c0}},	//   _trei_, _əlin, emdg, змин,
   {{0xdb1b016d,0x4ea700ae,0xaed500d3,0x00000000}},	//   ssuí, _дреа, _ноаш, --,
   {{0x4a455e66,0x2cbf020a,0xce6b002d,0x0b42013f}},	//   знов, saud_, _кред_, еньн,
   {{0xc86900c1,0x7a692a59,0x656d01c8,0x2cbf014b}},	//   _ען_, синг_, koah, paud_,
   {{0x7dea0092,0x6d4b903a,0x9c130134,0x00000000}},	//   _məsl, _umga, _nọgi, --,
   {{0x2c09001c,0x00000000,0x00000000,0x00000000}},	//   _دعای_, --, --, --,
   {{0x26080096,0x290400e7,0x00000000,0x00000000}},	//   हिली_, žma_, --, --,
   {{0x7dea013c,0x6d5b6138,0x00000000,0x00000000}},	//   _nəsl, onua, --, --,
   {{0xe9a8300d,0x6d5b903b,0xc4d60096,0xccf9007f}},	//   _بدون_, nnua, धलेख, neś_,
   {{0x42ca01b6,0xf99300ca,0x798407ac,0xade20096}},	// [9960] йган_, _ארה_, _ihiw, _गमभन_,
   {{0x1ddb0378,0xe8d900de,0x6d5b0037,0x637000c2}},	//   _यमंत, _thợ_, hnua, väns,
   {{0xa2dd2125,0x27340222,0xe297083c,0x2ac600b6}},	//   _पार्, _länk_, чах_, líbí_,
   {{0x236716a2,0x46dc009f,0x6d5b0216,0x00000000}},	//   čnja_, _बाँह, jnua, --,
   {{0xe47500d3,0x21671c66,0x00000000,0x00000000}},	//   _журэ, чици_, --, --,
   {{0x637012cd,0x4393013f,0x00000000,0x00000000}},	//   räns, _паўс, --, --,
   {{0xde930291,0xa3c600b6,0x4432007b,0x00000000}},	//   нашњ, ैंक_, lyy_, --,
   {{0x06c60081,0x7524903c,0xf8db007f,0x273402c3}},	//   শ্চি, njiz, _भाइय, _bänk_,
   {{0x64440517,0x4420903d,0xb4db00b3,0xe8d900fe}},	//   nzii, nxi_, _imàt, _nhỡ_,
   {{0x3cde1349,0xbec200d9,0x442005fe,0x5a3402b3}},	//   _गावे_, šība, ixi_, днот,
   {{0x7524048e,0x58d50870,0x6d9500c6,0xaadd3613}},	//   kjiz, монт, _išan, _मारक,
   {{0x60c20051,0x443200c2,0xdb190154,0x2bd41a09}},	//   naom, kyy_, _avwä, _दिपा,
   {{0xa2dd2a29,0xfc2f2c9a,0x798403a9,0x3ae5022b}},	//   _पाल्, _محو_, _dhiw, _bňpč_,
   {{0x2d9e0023,0xaae6001c,0x44200072,0x3ebe01ab}},	//   _kute_, _رستو, dxi_, _jett_,
   {{0x7afa903e,0x24990063,0x2d9e903f,0x3ebe9040}},	//   mett, _pgsm_, _jute_, _mett_,
   {{0x3ebe7d19,0x69da21e9,0xb4c9000d,0xb4d71efb}},	//   _lett_, mute, ैले_, सले_,
   {{0x69da9041,0x2d9e5bca,0xa3d4030b,0x7dea0092}},	// [9970] lute, _lute_, संग_, _səsl,
   {{0x7afa9042,0x2bd41362,0x3ebe9043,0xfbd4030b}},	//   nett, _दिना, _nett_, _दिनम,
   {{0x26c30087,0x7afa00e5,0x65150068,0x6d409044}},	//   majo_, iett, _ہوگئ, khma,
   {{0x7afa9045,0x26c30087,0xd84f0134,0x98a500c6}},	//   hett, lajo_, pọda_, ėlė_,
   {{0x4add62e4,0x7afa41dd,0xb4db0af0,0x3ebe2104}},	//   _मालव, kett, _alàg, _bett_,
   {{0x69da9046,0x2d9e9047,0x26c39048,0x7afa8c8b}},	//   kute, _bute_, najo_, jett,
   {{0x69da9049,0x4177037f,0x7afa904a,0xb4d7009f}},	//   jute, _فارس, dett, _साफ़_,
   {{0x2d9e03f3,0x69da904b,0x26c30117,0xa294004d}},	//   _dute_, dute, hajo_, _часі,
   {{0x7afa5a3d,0x6d5b0a00,0x3ebe904c,0x6f6500cd}},	//   fett, rnua, _fett_, _قهرم,
   {{0x7afa904d,0x6fd2000f,0x26c30b27,0x69da904e}},	//   gett, _सितं, jajo_, fute,
   {{0x2d9e87ea,0x26c302dd,0x69da904f,0xd6e30081}},	//   _gute_, dajo_, gute, য়ায,
   {{0x6d4002e2,0x27340149,0x7e7e0e5b,0xf1b2006e}},	//   chma, _tänk_, üppe, כסט_,
   {{0x442003e5,0x7afa9050,0x2d9e031a,0xf8bf0103}},	//   xxi_, bett, _zute_, rkép_,
   {{0x7afa6fcc,0xdb0b0149,0x26c30087,0x2d9e037a}},	//   cett, _avgö, gajo_, _yute_,
   {{0x7d093b5b,0x55e300c2,0x64a600c6,0xa50a1441}},	//   odes, корб, даба, оева_,
   {{0x44200a00,0xe3ba1a6d,0x443200c2,0x2bd414e5}},	//   txi_, жба_, tyy_, _दिमा,
   {{0x26c30eb8,0x7dea01d4,0x73060138,0xf7722259}},	// [9980] bajo_, _rəsm, мпаз, _لاد_,
   {{0x7d090084,0x753d0103,0x60c20051,0xf77202a3}},	//   hdes, _elsz, waom, _جاب_,
   {{0x00e602ec,0xf1a501ce,0x3ebe00f3,0x443200c2}},	//   джен, ерін, _rett_, syy_,
   {{0x2d9e1cb5,0x3ebe01ce,0x7d092832,0x3cf90034}},	//   _rute_, _sett_, jdes, ्यों_,
   {{0x2d9e0a34,0x69da9051,0x7afa9052,0x8fa3816c}},	//   _sute_, zute, yett, ваче,
   {{0x69da9053,0x437500d6,0x2d9e9054,0x7d099055}},	//   yute, _зуст, _pute_, edes,
   {{0x7afa9056,0x629c01ac,0x7d091507,0x68e43906}},	//   vett, _igro, fdes, _ocid,
   {{0x7afa9057,0xdc8e0134,0x7d099058,0x6440003e}},	//   wett, _dịnụ_, gdes, _ýmis,
   {{0x7afa9059,0x3ebe905a,0x63a40c7a,0x7dea00a7}},	//   tett, _tett_, nqin, _kəsk,
   {{0x60c0905b,0x48e1007d,0x6d404cd8,0x2d9e894a}},	//   _hemm, _काहो_, shma, _tute_,
   {{0x7afa905c,0x60c0009e,0x7d09905d,0x26c302dd}},	//   rett, _kemm, bdes, vajo_,
   {{0x69da905e,0x60c00078,0x7d09905f,0x67d53761}},	//   rute, _jemm, cdes, ному,
   {{0xb907320a,0x7afa9060,0x629c9061,0x60c09062}},	//   _पा_, pett, _ogro, _memm,
   {{0x69da9063,0x60c09064,0x629c42e1,0xb8d609c3}},	//   pute, _lemm, _ngro, _च्_,
   {{0xe5c426d0,0x26c39065,0x2d860019,0x60c00085}},	//   ксто, rajo_, _khoe_, _oemm,
   {{0x60c09066,0xab5d0034,0xd7fb34df,0x26c38720}},	//   _nemm, duży, _дуо_, sajo_,
   {{0xdce908a9,0x26c3033b,0x69c89067,0x21260b18}},	// [9990] sleć, pajo_, lsde, djoh_,
   {{0x32110067,0x68fd9068,0xdb090161,0x629c009c}},	//   _przy_, lesd, mpeã, _cgro,
   {{0xe8d900ef,0xe8070a30,0x7d090084,0xd25b0ad3}},	//   _chủ_, शिका_, ydes, цца_,
   {{0x60c09069,0x290b00ae,0x66053177,0x00000000}},	//   _cemm, ndca_, _ishk, --,
   {{0x60c0906a,0x6f080113,0x7d09906b,0x2fc90076}},	//   _demm, _badc, vdes, éag_,
   {{0x26c10897,0xaadd07e2,0xdc1400c7,0x32110034}},	//   _jeho_, _माइक, িহাস_, _trzy_,
   {{0x60c0906c,0x3d100251,0x7d090141,0x26c1906d}},	//   _femm, _दोहे_, tdes, _meho_,
   {{0x60c03e3e,0x69c8906e,0x7d0900c2,0x28db40ba}},	//   _gemm, dsde, udes, _भागि,
   {{0x7d09906f,0x213f0113,0x6f08033c,0x7c24009c}},	//   rdes, _iluh_, _fadc, _àirl,
   {{0x26c10220,0x3a255bc6,0x60c0014b,0x3f85019f}},	//   _neho_, емог, _zemm, _uhlu_,
   {{0x9f8a0084,0x00000000,0x00000000,0x00000000}},	//   töön_, --, --, --,
   {{0x68fd1082,0x186a1b60,0x00000000,0x00000000}},	//   gesd, зами_, --, --,
   {{0x2d8d9070,0x26c100f9,0x66058b29,0x69c88ef0}},	//   mmee_, _beho_, _ashk, asde,
   {{0x613a0428,0xa3d400b6,0xdb0900bc,0xb3ad0a43}},	//   _aïll, संघ_, tseõ, _চিংড়,
   {{0xe6172e62,0xf53f02fe,0xa3e20abe,0x26c1022b}},	//   ндр_, _blå_, नून_, _deho_,
   {{0x68e42a5c,0x6d950995,0xf1a333c5,0x2bf300aa}},	//   _ucid, _ošam, _ओढ़न, _अहां_,
   {{0x4ad30b94,0x7bc99071,0x3940019c,0xb4db01b9}},	// [99a0] _दयाव, nseu, _ilis_, _blàb,
   {{0x60c09072,0x39400197,0xe8d90019,0xd83f0579}},	//   _semm, _hlis_, _phủ_, íček_,
   {{0xda1f04f8,0x60c00167,0xf7720018,0xaadd088d}},	//   यमित_, _pemm, _لاگ_, _माईक,
   {{0x7bd50034,0x7a465635,0x0657006e,0xc1760e27}},	//   ązuj, _hété, _טייך_, ردات,
   {{0x7bcf309c,0x63a400a7,0xed5000cd,0x26c100f9}},	//   ácul, qqin, یپت_, _yeho_,
   {{0xe8d94d2a,0x629c00e9,0x9e0600d3,0x213f0113}},	//   _thủ_, _ugro, ечил, _eluh_,
   {{0x7bcb9073,0xe363251c,0x60c09074,0x7a460257}},	//   _avgu, _скри, _temm, _mété,
   {{0xe29702de,0x213f153a,0x63a90131,0x7bc9084e}},	//   _час_, _gluh_, _éenc, fseu,
   {{0x1be70291,0x216700d3,0x7dea013c,0xa2390065}},	//   едњи_, _чити_, _məsi, _lọ́d,
   {{0x39407490,0x8fa31469,0x3e8602c6,0xa3e819af}},	//   _alis_, _сафе, _cítí_, _यमन_,
   {{0x4dd66dd5,0x68fd9075,0x26c102ac,0x00000000}},	//   _ستاس, tesd, _reho_, --,
   {{0xfc66013d,0x7dea0092,0x2245026a,0x69c89076}},	//   _пълн, _nəsi, _ülke_, rsde,
   {{0xb4db00b3,0x68fd9077,0xdceb0078,0x00000000}},	//   _llàc, resd, _sigħ, --,
   {{0xb9c60080,0xf53f0501,0xa3ea0ed3,0x8c1b040a}},	//   _كتبه, _slå_, _महज_, _מודי,
   {{0xe8d90857,0xbb8300e3,0xc6680012,0x68fd0167}},	//   _ahụ_, _حلوي, еште_, pesd,
   {{0x28db009f,0x4a7b00ca,0x25ac0e43,0x26c10169}},	//   _भाटि, _מרוב, ídla_, _weho_,
   {{0x26c19078,0x28b40076,0x00000000,0x00000000}},	// [99b0] _teho_, _صحيح, --, --,
   {{0x2d53044c,0xdceb02a1,0x00000000,0x00000000}},	//   eţel_, _tigħ, --, --,
   {{0xcad700ca,0x212d01cb,0x213f00d4,0x00000000}},	//   תובת_, _poeh_, _pluh_, --,
   {{0xa2dd82eb,0x3ce601fa,0x7fd5097a,0x00000000}},	//   _पाक्, _ncov_, вікі, --,
   {{0xdee51110,0x6568109d,0xb4cd3ec9,0x260502d5}},	//   воли, édhe, रणी_, _हैती_,
   {{0xbec200d9,0x98a902ef,0x09b60033,0xb33b0131}},	//   šīna, _mlađ_, _ঝিনা, _fuça,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27340149,0x3e8602c6,0x2d992534,0xfe70450f}},	//   _hänt_, _sítí_, öse_, حده_,
   {{0x2d8d0934,0x27340212,0x6c570139,0x752f0034}},	//   rmee_, _känt_, _bálẹ, _mocz,
   {{0x7bc9561f,0x78ad05fe,0xc6bc0081,0x2d8d084e}},	//   rseu, _afav, _অঞ্চ, smee_,
   {{0xa96a1c21,0xd94622d1,0x7bc98c30,0x394014b1}},	//   дина_, вени, sseu, _plis_,
   {{0xaca30294,0x9c390291,0x00000000,0x00000000}},	//   _kpọm, _опет_, --, --,
   {{0xeb8e8dba,0x69de004d,0x00000000,0x00000000}},	//   _ви_, _åpen, --, --,
   {{0x41d11a94,0x9a15668e,0x7d0b0088,0x78ad0154}},	//   _हिंस, _афиш, _hags, _efav,
   {{0x65c39079,0xb87b05e6,0x7d0b0124,0xe5a62a84}},	//   ибра, rgía, _kags, тиби,
   {{0xe8d90028,0xb4dc3873,0x7d0b907a,0xc5631787}},	//   _phụ_, ठले_, _jags, акск,
   {{0x7d0b4c9c,0x7a46907b,0x5ed1009d,0x7dea00a7}},	// [99c0] _mags, _tété, सणाऱ, _vəsi,
   {{0x7c260222,0xfbd400a5,0x98a000e7,0x7d0b87c4}},	//   äkri, _दिसम, _boić_, _lags,
   {{0xb6d90130,0x7dea0092,0x2fcd022b,0xb87b0231}},	//   _אַרט, _təsi, _aveg_, ngín,
   {{0xa3e2018b,0x7d0b7640,0xe8d90019,0x64a643f7}},	//   नंद_, _nags, _thụ_, _шама,
   {{0xc0e30686,0x00000000,0x00000000,0x00000000}},	//   рочк, --, --, --,
   {{0x4add009d,0xdbdb003e,0x273400aa,0x3f8e00d8}},	//   _मागव, _ráðg, _tänu_, umfu_,
   {{0x7d0b857a,0x68f65b0b,0x00000000,0x00000000}},	//   _bags, _obyd, --, --,
   {{0x3d1900b7,0x6b440154,0x7d0b01ee,0x00000000}},	//   भागे_, _mòge, _cags, --,
   {{0x7d0b338b,0x8fa61906,0x6aad0233,0x00000000}},	//   _dags, _разе, _şafa, --,
   {{0x78ad1cb2,0x2019907c,0x7d0b0503,0x273402c3}},	//   _sfav, _ásia_, _eags, _mäns_,
   {{0x2bd42674,0x7d0b3fcb,0x273402c3,0x78ad020b}},	//   _दिवा, _fags, _läns_, _pfav,
   {{0xdd960241,0xa9210092,0xe9450281,0x00000000}},	//   _شجاع, _şöbə, اردی, --,
   {{0xf7731850,0xdb090080,0x1bd40ffe,0x752f0034}},	//   لاس_, speá, _соля, _rocz,
   {{0xf09300ca,0x752f007f,0x7a530a85,0x260f0d75}},	//   ינר_, _socz, اضیا, डिली_,
   {{0x752f0067,0xa4d502ec,0x7e86030b,0x6d4201df}},	//   _pocz, лові, _úspě, _kloa,
   {{0xb4cd009d,0x3544004d,0x386901c8,0x63b6084e}},	//   रणे_, ахув, _txar_, fpyn,
   {{0x659407bf,0x245802fd,0x3959907d,0x06d80033}},	// [99d0] рату, вать_, miss_, দ্ধি,
   {{0x69da3744,0x7d0002c3,0x46a7034c,0x7d1d0103}},	//   orte, hems, _खलिह, össz,
   {{0xe659002d,0x752f007f,0x6b440139,0x7d00024a}},	//   _чинч_, _tocz, _kògb, kems,
   {{0x69da0099,0x06d80081,0x7d00163c,0xdce2009e}},	//   irte, দ্দি, jems, _djoċ,
   {{0x7d0000cc,0x69da01bf,0x7dea0092,0xd2500068}},	//   dems, hrte, _məsu, منے_,
   {{0x7d0b907e,0xf77f07e7,0xdce002c6,0xaed20291}},	//   _sags, ftçi_, pomě, бољш,
   {{0x7d0b7759,0xb06200c2,0x6d9500e8,0x6d42907f}},	//   _pags, _ääni, _ušak, _bloa,
   {{0x2bd409c4,0xb33b0216,0x00000000,0x00000000}},	//   _दिशा, _kuço, --, --,
   {{0xeb992cde,0x69da9080,0xa1580284,0x313451ad}},	//   нии_, erte, _рату_, _тетр,
   {{0x4add632d,0x4b252453,0x00000000,0x00000000}},	//   _माओव, умов, --, --,
   {{0x7d0b9081,0x52d000c7,0x2bc406ed,0x7dea00a7}},	//   _tags, স্কৃ, लीबा, _səsv,
   {{0xb87b9082,0x2e3a00c1,0x6d42044c,0x4a42004d}},	//   rgín, _אגענ, _gloa, снюв,
   {{0x69da9083,0x9f59016d,0x6ee00174,0xed5900d2}},	//   arte, _ésó_, _ịbid, miž_,
   {{0xcc3a006e,0x25ac023c,0x00000000,0x00000000}},	//   _רעסט, ídlo_, --, --,
   {{0x39593441,0x2d9d1c35,0x6b445c94,0xe80000aa}},	//   biss_, _kiwe_, _fògb, _लईका_,
   {{0x2cad00a1,0xf8a80251,0x2d9d0239,0x7dea00a7}},	//   nced_, _गलिय, _jiwe_, _təsv,
   {{0xc9530054,0xf2da071c,0x00000000,0x00000000}},	// [99e0] _למה_, فظات_, --, --,
   {{0x7d001b6a,0x29026699,0x491c000d,0x7bdb0063}},	//   zems, leka_, याको_, iruu,
   {{0xe0da0cf5,0x24860220,0x26ca9084,0x7d00198d}},	//   еве_, ťom_, mabo_, yems,
   {{0x29029085,0x9fca0084,0x69ce36a2,0x26ca9086}},	//   neka_, егда_, ábei, labo_,
   {{0x65640294,0x7d000120,0x43860308,0x00000000}},	//   mnih, vems, _ملحق, --,
   {{0x26ca9087,0x643b00c1,0x29023a09,0x69da0170}},	//   nabo_, _טעכנ, heka_, yrte,
   {{0x63a602ef,0x6d4200d3,0x2902571e,0x2d9d0ab9}},	//   _hukn, _ploa, keka_, _biwe_,
   {{0x290203c6,0x26ca008a,0x69da00b6,0xae092748}},	//   jeka_, habo_, vrte, विजन_,
   {{0x26ca1081,0x7d009088,0x2902621a,0x7dea0092}},	//   kabo_, rems, deka_, _rəsu,
   {{0x69da0087,0x3d19009d,0x63a603e3,0x7d009089}},	//   trte, _मोठे_, _mukn, sems,
   {{0x63a6908a,0x037700ca,0x26ca908b,0x69da3b89}},	//   _lukn, רתית_, dabo_, urte,
   {{0x7dea01d4,0x29026708,0x637001bf,0x2d9d010a}},	//   _dəst, geka_, gänz, _giwe_,
   {{0x3f9e908c,0x63a600f9,0xb95400c2,0x00000000}},	//   _kitu_, _nukn, свящ, --,
   {{0x26ca7a5b,0x3f9e5cbf,0x2d9d908d,0x69da033b}},	//   gabo_, _jitu_, _ziwe_, prte,
   {{0x29020060,0x3f9e007a,0xa3e202d5,0x63a6003e}},	//   beka_, _mitu_, नूस_, _aukn,
   {{0x290212e6,0x99d30018,0xb33b00ee,0x7bc2022b}},	//   ceka_, _اتوا, _puço, _kwou,
   {{0x36d51ff9,0x26ca908e,0x6fc60096,0x63a605db}},	// [99f0] _копр, babo_, रीमं, _cukn,
   {{0xd4982565,0xb4db00ee,0x26ca041c,0x798d063d}},	//   урс_, _glàn, cabo_, _hhaw,
   {{0x798d908f,0x7dea0092,0x05790037,0xa3e102d5}},	//   _khaw, _xəst, _لمدة_, _धमक_,
   {{0x30150012,0xdef800bd,0x1128008f,0x63a605db}},	//   идер, _abċ_, лючи_, _fukn,
   {{0xd0090012,0x752d9090,0x2d9d0174,0xa49b00ee}},	//   теле_, mjaz, _riwe_, _caòt,
   {{0x29024958,0x3f9e00d9,0xddc80138,0x2d9d9091}},	//   zeka_, _citu_, _dydž, _siwe_,
   {{0x3f9e03f3,0xed590363,0xddc20423,0xdcfa026a}},	//   _ditu_, tiž_, общи, _attı,
   {{0xd6580054,0x7bc2022b,0x7bdb28b4,0x00000000}},	//   טיות_, _bwou, truu, --,
   {{0x44290060,0x2d53002d,0x2902096d,0x0b451141}},	//   nxa_, nţei_, veka_, инин,
   {{0x2902068d,0x3f9e2f6b,0x44292b2a,0x60cb02c9}},	//   weka_, _gitu_, ixa_, lagm,
   {{0x29029092,0x6926198a,0x65640188,0x7a692888}},	//   teka_, амна, ynih, тинг_,
   {{0x273d00ef,0x798d0197,0x5c75225a,0x60cb1331}},	//   _hình_, _chaw, _клет, nagm,
   {{0x29029093,0x798d9094,0x6d4910f0,0x26ca9095}},	//   reka_, _dhaw, mhea, tabo_,
   {{0x29022e02,0x63a69096,0x644d005c,0x6d493f35}},	//   seka_, _rukn, dzai, lhea,
   {{0x273d00ef,0x26ca9097,0x63a6182c,0xb8ec0033}},	//   _mình_, rabo_, _sukn, _লা_,
   {{0x63a61912,0x26ca0435,0x798d009e,0x59da00bc}},	//   _pukn, sabo_, _ghaw, _भितर,
   {{0x6f032832,0x7c3b84d9,0x7c29015e,0x78a921b8}},	// [9a00] kenc, nyur, nxer, ževc,
   {{0x6f039098,0x6d950138,0xdcfb0995,0x7c297c05}},	//   jenc, _išau, dluč, ixer,
   {{0x6f039099,0x6d5b1c24,0x02063c1f,0x7c3b0027}},	//   denc, kiua, рзен, hyur,
   {{0x3f9e02eb,0x60cb0124,0xc05a00f3,0xfbc70568}},	//   _situ_, gagm, кіл_, _وت_,
   {{0x6d49064b,0x273d00ef,0x3f9e2cc6,0xe8190e50}},	//   dhea, _bình_, _pitu_, दिया_,
   {{0x69c300a1,0x9f533f54,0x06d80033,0x6aa305db}},	//   _owne, овіч, দ্রি, _ngnf,
   {{0x3f9e0010,0x6fd20789,0xbd6a261f,0x69d502c6}},	//   _vitu_, _सिकं, крие_, ázel,
   {{0x6d4903e9,0xc0e322ff,0x6f0301ff,0x7bc20383}},	//   ghea, _моск, aenc, _pwou,
   {{0x3f9e909a,0x6f03909b,0xdee6336f,0x798d909c}},	//   _titu_, benc, _вози, _rhaw,
   {{0x798d1114,0x752d909d,0x63700084,0x78a4909e}},	//   _shaw, zjaz, täny, _agiv,
   {{0x6d490091,0x798d0eca,0xc9874932,0x00000000}},	//   bhea, _phaw, иуми, --,
   {{0x6d49064b,0x798d01fa,0x7bc206a3,0x7c3b0169}},	//   chea, _qhaw, _twou, byur,
   {{0x442903e5,0x588700c6,0x386d026a,0x7c3b02a4}},	//   xxa_, рына, çer_, cyur,
   {{0x6d40909f,0x79a622f6,0x78a40361,0x6b4401ec}},	//   lkma, _крие, _egiv, _fòga,
   {{0x798d01bb,0x69c302e0,0x7aef0146,0xdcfb7465}},	//   _thaw, _gwne, žitý, zluč,
   {{0x644d03f3,0x442941da,0x6f0390a0,0x6d402b34}},	//   tzai, txa_, zenc, nkma,
   {{0xf8bf90a1,0x6d4001cb,0x79460034,0x6f0390a2}},	// [9a10] mbé_, ikma, _wówc, yenc,
   {{0x442990a3,0xec710130,0x6f0308a8,0x23bd0af0}},	//   rxa_, פֿן_, xenc, _aájò_,
   {{0x555930cf,0x6d4090a4,0xd05100a7,0x273d00fe}},	//   _баня_, kkma, əfəs, _rình_,
   {{0x6d49009c,0x6d4042d8,0x44290231,0x00000000}},	//   xhea, jkma, pxa_, --,
   {{0x6b810150,0x00000000,0x00000000,0x00000000}},	//   yllg, --, --, --,
   {{0x6d401183,0x7c3b0027,0x00000000,0x00000000}},	//   ekma, vyur, --, --,
   {{0x6d49328f,0x6f0369f6,0xed598d23,0x60cb0bb6}},	//   thea, renc, лок_, pagm,
   {{0x7c29627e,0x61e50060,0x6f033d46,0x23671912}},	//   txer, muhl, senc, čnju_,
   {{0x273d00ef,0x63ad6843,0x61e5601c,0x7c2913a9}},	//   _tình_, nqan, luhl, uxer,
   {{0x6aa408bb,0x6d4990a5,0x60c986d6,0x2bdd00c3}},	//   _şifr, shea, _heem, _मिठा,
   {{0x60c990a6,0x6d4900e0,0x61e5005c,0x7c3b878a}},	//   _keem, phea, nuhl, syur,
   {{0xa3e20179,0xfc3301c3,0x00000000,0x00000000}},	//   नूँ_, _وحش_, --, --,
   {{0x8d7406f6,0x6d5990a7,0x60c943da,0x7d740037}},	//   _بالا, _imwa, _meem, _بالط,
   {{0x2cbf05a3,0x61e50060,0x60c9084e,0xf1a709c4}},	//   lbud_, kuhl, _leem, गदान,
   {{0x78a90b27,0x19b51363,0xe64300d6,0x68ed009c}},	//   ževa, _احتج, перп, _fcad,
   {{0x60c990a8,0xf9922259,0x2cbf00f3,0x68ed033c}},	//   _neem, _عبث_, nbud_, _gcad,
   {{0x44260396,0xa3e209c3,0x6d5906b0,0x66e66ab4}},	// [9a20] ão_, नूं_, _mmwa, _лопа,
   {{0x291290a9,0xd24f00cd,0xe6462240,0xe29a24e9}},	//   _haya_, کنم_, _геоп, газ_,
   {{0x291290aa,0x60c990ab,0x61e52142,0x6d590a15}},	//   _kaya_, _beem, guhl, _omwa,
   {{0xc6930054,0x29120496,0x00000000,0x00000000}},	//   _מאת_, _jaya_, --, --,
   {{0x8ff70080,0xdfcf00e3,0x69d500b6,0x9c130065}},	//   مرور_, فين_, ázej, _dọki,
   {{0x6d596875,0x291290ac,0x61e50201,0x42531aaa}},	//   _amwa, _laya_, buhl, _کنفر,
   {{0x60c9023e,0x200d31cc,0x3d1902d5,0x00000000}},	//   _feem, _esei_, _मोहे_, --,
   {{0x29120dd5,0xfc460094,0x60c90462,0x5fe000a3}},	//   _naya_, šími_, _geem, _निपल,
   {{0x6d4090ad,0x61fb007e,0x00000000,0x00000000}},	//   rkma, _ćuli, --, --,
   {{0x68ed10de,0x291290ae,0x6d4090af,0x6e93015a}},	//   _scad, _aaya_, skma, _کلما,
   {{0x29121114,0x7c24013f,0x8e8600e3,0x3f9b00fd}},	//   _baya_, _šird, _الاه, ïque_,
   {{0x60c9023e,0x291200dc,0xdd8f0037,0x00000000}},	//   _xeem, _caya_, _كول_, --,
   {{0x29120a75,0xf8bf90b0,0x25e600bc,0xead432f8}},	//   _daya_, rbé_, जूसी_, _доль,
   {{0x83030033,0xf8bf0103,0x00000000,0x00000000}},	//   _উচ্চ_, sbé_, --, --,
   {{0x2c740018,0x291290b1,0x2bc40557,0x44b60134}},	//   _دیکھ_, _faya_, लीरा, _ọsụ_,
   {{0x291290b2,0x39a501d3,0x657d90b3,0x7c2401b9}},	//   _gaya_, _cēsu_, _qksh, _àirs,
   {{0x994800ab,0x394900f9,0x2ca600fe,0xe5340120}},	// [9a30] _دليل_, _ilas_, _mgod_, четь,
   {{0x63ad90b4,0x39490146,0x60c990b5,0x21240154}},	//   rqan, _hlas_, _seem, _anmh_,
   {{0x394990b6,0x56956116,0x291290b7,0xe5350084}},	//   _klas_, _фант, _yaya_, _день,
   {{0x61e590b8,0x399b2c5a,0x0ce30033,0x2cbf02c3}},	//   ruhl, _būsi_, _মস্ত, xbud_,
   {{0xb4e510e9,0x63ad90b9,0x9f993739,0x60c90e22}},	//   नली_, qqan, авду_, _veem,
   {{0x60c9083e,0x8afc0034,0x39490143,0x439400e5}},	//   _weem, nięd, _llas_, _наяс,
   {{0x60c990ba,0x394990bb,0x260f0285,0x2cbf90bc}},	//   _teem, _olas_, डिटी_, tbud_,
   {{0x2bd410ed,0x6d9500c6,0x00000000,0x00000000}},	//   _दिखा, _ašar, --, --,
   {{0x291290bd,0x6fe0110f,0x2cbf017a,0x200d0161}},	//   _raya_, _नियं, rbud_, _usei_,
   {{0x29122129,0x6d5e025a,0x39490479,0x3d193db8}},	//   _saya_, épar, _alas_, _मोरे_,
   {{0x7cd90018,0x394990be,0x2912057c,0x2d84009c}},	//   _نواز_, _blas_, _paya_, blme_,
   {{0x78a908a9,0x6d59092f,0x394990bf,0x7c24084f}},	//   ževn, _umwa, _clas_, _šire,
   {{0x29121186,0x224d00b6,0x31c605d6,0x06ee00a4}},	//   _vaya_, _řekl_, _लब्ध, _जादव_,
   {{0x394990c0,0x291290c1,0x409a00ca,0x25a20154}},	//   _elas_, _waya_, יברס, _sikl_,
   {{0x291290c2,0x39491053,0x00000000,0x00000000}},	//   _taya_, _flas_, --, --,
   {{0x785c01d3,0x91b0020b,0x00000000,0x00000000}},	//   tāvī, _đào_, --, --,
   {{0xe577084c,0x42ca6ab4,0x5eca0033,0x00000000}},	// [9a40] ізу_, иган_, _রাসে, --,
   {{0x6fe0110f,0x7c2400e3,0x2124009c,0x00000000}},	//   _निबं, _áire, _snmh_, --,
   {{0x64a60d69,0x316d00e7,0xa49b0383,0xf74a0d5b}},	//   _мана, _bjez_, _abòd, _ملکي_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xee021c20,0x34a7004d,0x25e60034,0x00000000}},	//   लब्ध_, _євро_, जूरी_, --,
   {{0x661e020a,0x6fdb0386,0x00000000,0x00000000}},	//   _krpk, _निरू, --, --,
   {{0x79460067,0x61465e66,0x00000000,0x00000000}},	//   _równ, _дева, --, --,
   {{0x387f003d,0x91030c37,0x00000000,0x00000000}},	//   żuri_, _опсе, --, --,
   {{0xeb061476,0x46bf00b6,0x6b44009c,0xa49b0af0}},	//   очно, ्रमह, _fògl, _gbòd,
   {{0xba5419e8,0x60c290c3,0x2cb102c6,0x93fb2252}},	//   звој, lbom, ězda_, סליי,
   {{0x394990c4,0xa2ad06ec,0x777c00b3,0xb87b0131}},	//   _plas_, _जलस्, dorx, ngív,
   {{0x2ca600f9,0x00000000,0x00000000,0x00000000}},	//   _ugod_, --, --, --,
   {{0xcb6a00c9,0xc19b006e,0x8b650d5b,0x78a90357}},	//   _каде_, ישטי, _کانم, ževo,
   {{0x628e0a39,0x6cea00c3,0xdb2000ce,0x00000000}},	//   _ozbo, _टाँग_, ätäm, --,
   {{0x661e02f7,0x28c802d5,0x26da6205,0x00000000}},	//   _crpk, लरशि, _ddpo_, --,
   {{0xb4e57674,0x394990c5,0x00000000,0x00000000}},	//   नले_, _ulas_, --, --,
   {{0xe8730de1,0x628e90c6,0xb2ab3ac9,0x54551da9}},	// [9a50] _زندگ, _azbo, атеж_, чват,
   {{0x2bdd045f,0xe8d90023,0x23742ce3,0xdceb0559}},	//   _मिसा, _thỳ_, والح, _čičk,
   {{0x6cea17ff,0x26d1022b,0xdb0302ac,0x00000000}},	//   _टांग_, mazo_, _binê, --,
   {{0xdd860068,0x26d190c7,0x60c290c8,0x6b44009c}},	//   _سو_, lazo_, gbom, _sògl,
   {{0xf4841e20,0xe8d90294,0x6fc613ae,0x442d90c9}},	//   _журн, _amị_, रीलं, _çe_,
   {{0x26d190ca,0xdb0b0131,0x60c2010a,0x00000000}},	//   nazo_, _eugê, abom, --,
   {{0xc3320341,0xd04900a7,0x5eca0033,0xbea23035}},	//   _אום_, _ənən, _রাশে, нашк,
   {{0x26d10143,0xb4db01ec,0xf8b500a4,0x00000000}},	//   hazo_, _blài, ंडोप, --,
   {{0x399b0029,0x26d10811,0x69dc05f1,0xb4db01ec}},	//   _jūsu_, kazo_, áren, _clài,
   {{0x399b0029,0x26d10239,0x78a9007e,0x7c260572}},	//   _mūsu_, jazo_, ževl, åkra,
   {{0xd9100068,0x98b008c5,0x26d190cb,0x6b44749b}},	//   ہیں_, šača_, dazo_, _gògm,
   {{0xa96a4402,0xb4db01b9,0x60db00bd,0x201f3ae1}},	//   сима_, _flài, _jdum, _krui_,
   {{0x6d4b522a,0x661e2cea,0x60db60d9,0x00000000}},	//   _ilga, _srpk, _mdum, --,
   {{0x26cc88cb,0x7d0983b7,0x26d10143,0x907a0289}},	//   údo_, lees, gazo_, מטרי,
   {{0x65c6013d,0xd9462f93,0x60db14a8,0x60c200c6}},	//   ябва, _неки, _odum, ybom,
   {{0x7d0967ac,0x2a3a00a1,0xb33b016d,0x60db3fbc}},	//   nees, _לעצמ, _muçu, _ndum,
   {{0x26d190cc,0x29000174,0x656f0350,0x00000000}},	// [9a60] bazo_, _ibia_, _djch, --,
   {{0xe8190455,0x7d090084,0x8afc00a5,0x629a0146}},	//   दिरा_, hees, mięc, _útok,
   {{0x6d4b90cd,0x7d095e37,0x23660995,0x42560927}},	//   _olga, kees, đoj_, чтат,
   {{0xfaf800e8,0x39b7078e,0x00000000,0x00000000}},	//   lnīt_, _găse_, --, --,
   {{0x8afc00a5,0x98a7084f,0xb4db0032,0x60db06b0}},	//   nięc, šića_, _alàw, _ddum,
   {{0x60db90ce,0x6d4b1a5b,0xa2bb0a50,0x60c2093e}},	//   _edum, _alga, शुद्, sbom,
   {{0x7d0990cf,0x29000134,0xb4db01b5,0x00000000}},	//   fees, _obia_, _slài, --,
   {{0x7d0990d0,0x5bb84c81,0x3f870335,0x6da30b1b}},	//   gees, олия_, alnu_, нија,
   {{0x6fb604f4,0x26d112e6,0x00000000,0x00000000}},	//   _رمضا, yazo_, --, --,
   {{0x29000daf,0xff2400cd,0x49d80120,0x00000000}},	//   _abia_, _تبری, одою_, --,
   {{0xc33300a1,0x7d0990d1,0x63a90131,0xf1c300fe}},	//   תות_, bees, _éenv, _nhớ_,
   {{0x26d10010,0xdb0305aa,0x00000000,0x00000000}},	//   wazo_, _linè, --, --,
   {{0x31570341,0x26d190d2,0x7c830114,0xac9a3a89}},	//   ליטן_, tazo_, _пуше, _انشا_,
   {{0xd7f81c9b,0xe8d9026e,0x00000000,0x00000000}},	//   чую_, _imọ_, --, --,
   {{0x50cc61b6,0x8afb0054,0x26d190d3,0xb604224a}},	//   ाराष, _להגי, razo_, нятк,
   {{0xe8d900de,0x69d800bd,0x39920072,0x26d190d4}},	//   _thự_, _ivve, táse_, sazo_,
   {{0x26d10933,0xdb0390d5,0xdb0b0113,0x60db0090}},	// [9a70] pazo_, _binè, _bugè, _rdum,
   {{0x291902ef,0xe9ff0023,0xdb0300ee,0x290b7993}},	//   ldsa_, _hoại_, _cinè, leca_,
   {{0xdb0b0572,0x22470103,0x7d093634,0x00000000}},	//   _utgå, ánk_, yees, --,
   {{0x290b85d8,0x2bdd0085,0xdb0b02cd,0xe29800d6}},	//   neca_, _मिला, _eugè, чає_,
   {{0xdb1b14e2,0x29d80028,0xdb036b24,0xd2500018}},	//   spué, hĩa_, _finè, ننے_,
   {{0xe9ff00ef,0x7d0990d6,0x69d8008f,0x290b90d7}},	//   _loại_, wees, _ovve, heca_,
   {{0x7d0990d8,0x290b90d9,0xed59055b,0xe8d90065}},	//   tees, keca_, жой_, _amọ_,
   {{0x656d90da,0x63af0ca7,0x290b0480,0x0c250275}},	//   nnah, _kucn, jeca_, дмин,
   {{0x69d8294c,0x2bdd02e8,0x290b90db,0x46bf09c4}},	//   _avve, _मिळा, deca_, ्राह,
   {{0x99060775,0xe9d91312,0x7d09862c,0x4a451bec}},	//   षज्ञ_, око_, sees, днов,
   {{0x7d0990dc,0x63a70126,0xdb0300b6,0x6d4b0270}},	//   pees, _mijn, _jiné, _tlga,
   {{0xe6c60179,0x63a70126,0xdb0343f8,0xdce00138}},	//   वर्ज, _lijn, _miné, domė,
   {{0x7d5600c1,0xdb03020d,0x69d890dd,0x656d008c}},	//   _קינד_, _liné, _evve, dnah,
   {{0x63a790de,0x6fe02397,0x4c9a00ca,0x9b4500d1}},	//   _nijn, _निसं, _ובנו, _زنبو,
   {{0x8afc00a5,0x656d1c7e,0x00000000,0x00000000}},	//   sięc, fnah, --, --,
   {{0x1987013d,0x63af09ac,0x8afc0034,0x656d90df}},	//   _общи_, _bucn, pięc, gnah,
   {{0x7984068d,0x63a70ab2,0x63af00c4,0xdb0390e0}},	// [9a80] _ikiw, _bijn, _cucn, _ainé,
   {{0xdb091ea5,0x39a40032,0x656d2fbe,0x69c14fb5}},	//   mpeó, _fèsì_, anah, ople,
   {{0xdb0390e1,0x69c190e2,0x656d008a,0x5f1802d5}},	//   _ciné, nple, bnah, _योग्_,
   {{0x200490e3,0x656d0188,0x9c821054,0x6b4401f7}},	//   _ppmi_, cnah, íčko, _eògh,
   {{0x63a70126,0xb4db0428,0x79840a4b,0x6b4401f7}},	//   _fijn, _clàu, _mkiw, _fògh,
   {{0xdb036d06,0x290b0e94,0x69c190e4,0x65640350}},	//   _finé, zeca_, kple, liih,
   {{0x442269ed,0x53a70789,0x7bcb00bd,0x63af09ac}},	//   _hrk_, _कूटश, _awgu, _zucn,
   {{0x69c11cab,0x63a701c0,0x65640134,0x79840172}},	//   dple, _zijn, niih, _nkiw,
   {{0xa2a2034d,0x64440517,0x0083002d,0x1b170033}},	//   _कृत्, nyii, _алто, তানে_,
   {{0x7984417d,0x5a340d5e,0x656423de,0x69c118f0}},	//   _akiw, енот, hiih, fple,
   {{0x290b2243,0x656d0694,0x69c126d2,0xdb0300b3}},	//   teca_, ynah, gple, _xiné,
   {{0x1c461977,0x79960178,0x64440172,0x00000000}},	//   _онем, _chyw, kyii, --,
   {{0xb8d71784,0x290b90e5,0x442200d6,0x6b440428}},	//   _जल_, reca_, _nrk_, _lògi,
   {{0x290b08a9,0x63af0995,0x5ee00081,0x70ab00c3}},	//   seca_, _rucn, প্রে, _छल्ल,
   {{0xd9f2018b,0x63a701c0,0x290b90e6,0x656d1d87}},	//   _अमित_, _rijn, peca_, tnah,
   {{0x99440702,0x63af1100,0x656d90e7,0x61e50094}},	//   mış_, _pucn, unah, vrhl,
   {{0x63a76476,0xdb0301c3,0x99440491,0x78ad00aa}},	// [9a90] _pijn, _siné, lış_, _igav,
   {{0x656d90e8,0x442210ef,0x8c1b00ca,0xdb03037a}},	//   snah, _drk_, חומי, _piné,
   {{0x39920018,0x99440740,0x63a7023b,0x7d0290e9}},	//   lása_, nış_, _vijn, _obos,
   {{0x63a70126,0x7c220b7d,0x6b440154,0x44221d46}},	//   _wijn, _oror, _dògi, _frk_,
   {{0x80270080,0x5ed30081,0x69c10141,0x63a70381}},	//   برام, _সাবে, zple, _tijn,
   {{0x7d022b60,0x9944026a,0x6fe009c4,0x69c16fea}},	//   _abos, kış_, _निरं, yple,
   {{0x753d1bb3,0xc1770dd0,0x7c2241e5,0x7d020361}},	//   _kosz, _قدرت, _aror, _bbos,
   {{0x9294620c,0x7c2240d6,0x5ee00033,0x99440abd}},	//   _расц, _bror, প্লে, dış_,
   {{0x799602ad,0xdcf9010a,0x81b703e3,0x753d90ea}},	//   _rhyw, _akwă, ɓɓak, _mosz,
   {{0x39920018,0x69c12088,0x7d027eda,0xfeb815ae}},	//   dása_, tple, _ebos, _قامت_,
   {{0x7c22204c,0xdcfb02c6,0x00000000,0x00000000}},	//   _eror, louč, --, --,
   {{0x69c190eb,0xaca30129,0x7c22002b,0x753d6053}},	//   rple, _arụm, _fror, _nosz,
   {{0x69c190ec,0x291e030b,0xb4db015e,0x7c22526c}},	//   sple, ěta_, _llàs, _gror,
   {{0xcc3a07a6,0x7d1b0006,0x794600a5,0x7d19008a}},	//   _מענט, ldus, _mówi, _haws,
   {{0xd04001d4,0xd5b21d28,0x7d1901ee,0xd62700ae}},	//   _demə, افر_, _kaws, норе_,
   {{0x7d1b05a7,0xdb0904d8,0x79840051,0x7d1901c2}},	//   ndus, mpeñ, _ukiw, _jaws,
   {{0x03262b49,0x490000c3,0xb4db009c,0x753d0034}},	// [9aa0] ндан, ष्णो_, _alàs, _dosz,
   {{0xb4db009c,0x44220ae3,0x6d4913ce,0x7d1b007b}},	//   _blàs, _vrk_, hkea, hdus,
   {{0x00e610ab,0xb4db0428,0x6d49007b,0x61468842}},	//   ежен, _clàs, kkea, нежа,
   {{0x61e30068,0xe0d20dce,0x6b8190ed,0x057635bf}},	//   ánla, ازا_, holg, _ساجد,
   {{0x14d70054,0x673e90ee,0x7d1b90ef,0xd04000a7}},	//   _אוכל_, _kopj, ddus, _yemə,
   {{0x7c241a36,0x99440740,0x44200051,0x8fa300c2}},	//   _širo, yış_, mvi_, гаче,
   {{0x994401d4,0x39920018,0x6b660257,0xa2f700ca}},	//   xış_, zása_, _légè, _רמלה_,
   {{0x78a90039,0x44200f06,0x7d1b2447,0xdd9701b6}},	//   ževi, ovi_, gdus, ншы_,
   {{0x30760c0d,0x7d1990f0,0x6b8102dc,0x44200472}},	//   _чувс, _daws, folg, nvi_,
   {{0x994403a3,0x442090f1,0xf063069c,0x7d1b00aa}},	//   tış_, ivi_, _скуп, adus,
   {{0x4420454c,0x7d1901ee,0x2bc4023a,0x00000000}},	//   hvi_, _faws, लीजा, --,
   {{0x39920068,0x442002e6,0x99440f28,0x6d495a7f}},	//   tása_, kvi_, rış_, ckea,
   {{0x53b5009d,0xa49b06a3,0x7c220044,0x2d8601dc}},	//   _अंधश, _abòn, _uror, _ikoe_,
   {{0x7d1900a5,0x44200095,0x7c2d077e,0x6b81028d}},	//   _zaws, dvi_, _šarg, colg,
   {{0x6f1a90f2,0x753d472c,0x442090f3,0xe6100018}},	//   _matc, _posz, evi_, یشہ_,
   {{0x69da90f4,0x78ad198d,0x442005db,0x00000000}},	//   mste, _ugav, fvi_, --,
   {{0x97a703fc,0xb4db01ec,0x442001cd,0x69da0d4b}},	// [9ab0] _прол, _blàr, gvi_, lste,
   {{0x6f1a90f5,0x69da1f58,0xb4db90f6,0x7d1b0a39}},	//   _natc, oste, _plàs, zdus,
   {{0x644101d4,0x69da2071,0x442090f7,0x16bf439d}},	//   _əliy, nste, avi_, ्रीब,
   {{0x69da504d,0xf99f06a3,0x6b810103,0xdcfb02c6}},	//   iste, nmè_, zolg, touč,
   {{0x7d1982e8,0x4174071c,0xdbe20139,0x69da0fe8}},	//   _raws, دالس, _féég, hste,
   {{0x2d860449,0xdcfb3b92,0x7d190842,0xe8221da8}},	//   _akoe_, rouč, _saws, मिता_,
   {{0x6b812d87,0x69da90f8,0x7ed4001c,0x26d30231}},	//   volg, jste, ازها, _mexo_,
   {{0x26d300dd,0x387e0034,0x629590f9,0x7d1b743c}},	//   _lexo_, ętrz_, _izzo, udus,
   {{0x69da90fa,0x81c30081,0x6d494633,0x7d1b074c}},	//   este, _এটি_, rkea, rdus,
   {{0x26d310d9,0x69da90fb,0x6d496656,0xfaa54ce6}},	//   _nexo_, fste, skea, капо,
   {{0x2bd10b89,0x28c3009d,0x291b14d8,0x628b0034}},	//   _दौरा, _व्हि, _baqa_, ęgow,
   {{0x81c300c7,0x186a249c,0x8afc00a5,0x6b8190fc}},	//   _এটা_, дами_, wnęt, solg,
   {{0x395901e5,0x3de30081,0x2d8d061d,0x212d0113}},	//   ërsa_, _মহিল, mlee_, _mneh_,
   {{0x2d8d90fd,0x9c120174,0x44200172,0xb8e902d5}},	//   llee_, _kọnf, vvi_, _ल्_,
   {{0x26d30072,0x9a240076,0x291b90fe,0x00000000}},	//   _dexo_, _معين, _faqa_, --,
   {{0x44202904,0xa2a2277c,0x25ab0036,0xa3b6007f}},	//   tvi_, _कृष्, _cicl_, _चंद_,
   {{0xd4671b4d,0x7bdb442e,0xe5a384ad,0x62952ae2}},	// [9ac0] вите_, nsuu, рити, _azzo,
   {{0x212d0cd0,0x7bdb0084,0x3940009c,0xc7a6153d}},	//   _aneh_, isuu, _hois_, _шипк,
   {{0x26d80193,0x2d8d90ff,0x44209100,0x213f00fc}},	//   maro_, klee_, svi_, _bouh_,
   {{0x26d800a6,0x6f1a8105,0x80cc0789,0x291b0188}},	//   laro_, _satc, ारें, _xaqa_,
   {{0x394004ea,0x31662011,0x212d0087,0x6fb31487}},	//   _mois_, rioz_, _dneh_, لمنا,
   {{0x69da3bd7,0x26d8513e,0xe8d90174,0x69dc01d3}},	//   yste, naro_, _ikụ_, šrei,
   {{0x67040d7e,0x527500d3,0x2dd700e3,0x39990018}},	//   श्यक_, _буту, نبية_, lése_,
   {{0x6f1a00a1,0x39409101,0xe29713a8,0x26d801c8}},	//   _watc, _nois_, _рас_, haro_,
   {{0x69da9102,0xd17504d9,0x26d89103,0x7bdb1d05}},	//   wste, _сыры, karo_, gsuu,
   {{0x69da1936,0x3940006b,0x26d84dc8,0xdb030139}},	//   tste, _aois_, jaro_, _finí,
   {{0x3940025a,0x69da9104,0x26d89105,0x28f925a9}},	//   _bois_, uste, daro_, нень_,
   {{0x69da0cac,0x26d37e46,0x7c2d08c5,0x3940009b}},	//   rste, _sexo_, _šare, _cois_,
   {{0x39409106,0x69da1a02,0xdb030161,0x26d85d6f}},	//   _dois_, sste, _dinâ, faro_,
   {{0x26d89107,0x7bc20503,0x39990103,0x7c654345}},	//   garo_, _itou, dése_, _حامل,
   {{0x394004ea,0xe8d900ac,0x26d303be,0xa49b0139}},	//   _fois_, _akụ_, _vexo_, _ebòl,
   {{0x2d840148,0x61fe0364,0x39400231,0x02cb142e}},	//   nome_, dtpl, _gois_, िर्न,
   {{0x26d89108,0x26d3002b,0x7c240117,0xa49b0065}},	// [9ad0] baro_, _texo_, _širj, _gbòl,
   {{0x99520074,0x26d802a4,0x61e30018,0x2d8d0063}},	//   máš_, caro_, ánlo, zlee_,
   {{0x6d5c01b3,0x2d843371,0x99520146,0x02a71e20}},	//   _įran, kome_, láš_, трам,
   {{0xe5350084,0x2d840138,0x00000000,0x00000000}},	//   _семь, jome_, --, --,
   {{0xb4c13b30,0xdee57f94,0x2d842c5a,0x99520094}},	//   ुरी_, голи, dome_, náš_,
   {{0x20d100ef,0x5ed30033,0xf41200ca,0x00000000}},	//   ại_, _সাহে, _הפך_, --,
   {{0x7bc234d7,0x2d842dec,0x80d20081,0xfd110037}},	//   _atou, fome_, _হার্, مجة_,
   {{0x2d84699a,0x2ee90092,0x99520146,0x2fc6023e}},	//   gome_, şaf_, káš_, bpog_,
   {{0x39409109,0xfc3100e3,0x98a00b14,0x2d9f01df}},	//   _rois_, صحة_, _inić_, rmue_,
   {{0x7bdb28b6,0x99520146,0x394013c6,0x6440020d}},	//   rsuu, dáš_, _sois_, _àmie,
   {{0x3940910a,0xd9463a7a,0x39990018,0x7bdb6587}},	//   _pois_, гени, zése_, ssuu,
   {{0x2d8400a1,0x26d8910b,0x7f4100bd,0x7bdb007b}},	//   come_, waro_, _holq, psuu,
   {{0xeb8e910c,0x26d8910d,0x39402f7d,0x2bdd0251}},	//   _ги_, taro_, _vois_, _मिटा,
   {{0x59d0030b,0x7f41009e,0x00000000,0x00000000}},	//   थीहर, _jolq, --, --,
   {{0x26d8910e,0xa50a18e4,0x6eca4eba,0x8ed80033}},	//   raro_, нева_, _स्फु, _সামগ,
   {{0x291e0029,0x39990068,0x26d87e1b,0x995200d4}},	//   ētas_, tése_, saro_, báš_,
   {{0x2e1701d4,0x25a0910f,0xb4e40034,0xdce001d3}},	// [9ae0] _dəfə_, rmil_, _नयी_, nimā,
   {{0x46f60423,0xdcf42461,0x79869110,0x42561a57}},	//   _счит, _čačk, lokw, лтет,
   {{0x29d10660,0xdb0a0513,0x2fdf0027,0x00000000}},	//   nša_, _difè, _avug_, --,
   {{0x63140081,0x79869111,0xdb090161,0x2d840042}},	//   সাইট_, nokw, mpeõ, xome_,
   {{0xe3b20688,0x61fe9112,0x7f469113,0x2d849114}},	//   _درج_, stpl, ледж, vome_,
   {{0x9c120174,0x79863759,0x7f41009c,0xe7b700bc}},	//   _dọlf, hokw, _colq, _इंसप,
   {{0xe29703fc,0x5fe005d4,0x29d123c5,0x68e49115}},	//   _бар_, _निकल, jša_, _odid,
   {{0x68e40129,0x27e000c4,0xe6d100a4,0x00000000}},	//   _ndid, _ovin_, _तज्ज, --,
   {{0x9c120294,0x7f414d86,0x2d849116,0xdb0300b3}},	//   _gọlf, _folq, rome_, _binà,
   {{0x93fb0105,0xdd04026a,0x2d849117,0x63ae0078}},	//   עליי, ırıy, some_, _jibn,
   {{0x19590895,0xaa943bbc,0x497514fa,0xdb0305fe}},	//   ваны_, ринч, илос, _dinà,
   {{0x63ae022b,0x99520e43,0x69c3020b,0x00000000}},	//   _libn, táš_, _dtne, --,
   {{0x68e40150,0x27e00154,0xf7732ba0,0xc8675e41}},	//   _ddid, _cvin_, ماس_, утни,
   {{0x6d4200aa,0x68e43bcc,0x29d1033b,0x65660415}},	//   _hooa, _edid, bša_, _amkh,
   {{0xe5c4008f,0x628e1322,0x27e0071d,0x6b4401ec}},	//   йсто, _nybo, _evin_, _fògr,
   {{0xb4c14694,0x69c80428,0x63ae02fa,0x68e4009e}},	//   ुरे_, mpde, _aibn, _gdid,
   {{0x69c819a7,0x7afd192a,0x245800c2,0x29090139}},	// [9af0] lpde, đstv, гать_, _ibaa_,
   {{0x6e2802fe,0x2b9900fd,0x65660201,0x6fcf00a3}},	//   _ordb, pèce_, _emkh, _सौगं,
   {{0x5ed30081,0x63ae0188,0x6db101d3,0xdb0b034f}},	//   _সালে, _dibn, _jāat, _jugá,
   {{0xf8bf025a,0x7ff51a37,0xdd860037,0xdb03488f}},	//   ncé_, لستا, _ذو_, _miná,
   {{0x6e28036b,0x00000000,0x00000000,0x00000000}},	//   _ardb, --, --, --,
   {{0x79860201,0x00000000,0x00000000,0x00000000}},	//   zokw, --, --, --,
   {{0x8d550848,0x7986661c,0x93c6020a,0x628b007f}},	//   итич, yokw, rtăş, ęgos,
   {{0xf1a42a6a,0x29d10995,0x2fc401b9,0xd7b50096}},	//   _грун, vša_, _ftmg_, ंदाच,
   {{0x1c421ad1,0x6e280364,0xa1580095,0x320100ca}},	//   жным, _erdb, _сату_, lthy_,
   {{0x29095b02,0x00000000,0x00000000,0x00000000}},	//   _abaa_, --, --, --,
   {{0x4a75004b,0x5efe00a5,0x29d19118,0x27e08121}},	//   рыпт, _शॉट्_, uša_, _svin_,
   {{0xb4e42235,0xfe70048f,0xdb0304d8,0xa96a43c2}},	//   _नये_, _عدل_, _diná, тима_,
   {{0x2f240103,0x61e30103,0xd7d000a4,0x79860350}},	//   ségű_, ánlj, तींच, rokw,
   {{0xfaa5559f,0xdb03499e,0x29090174,0x442c1fff}},	//   _кало, _finá, _ebaa_, _čd_,
   {{0x59760761,0x63ae0117,0xdb030161,0x79860239}},	//   _выпу, _ribn, _giná, pokw,
   {{0x2c0900a5,0x290937dc,0x63ae9119,0x628e30e6}},	//   _वहां_, _gbaa_, _sibn, _rybo,
   {{0x5ee000c7,0x66e61994,0x00000000,0x00000000}},	// [9b00] প্টে, _копа, --, --,
   {{0x3f87911a,0xa2e6007b,0x00000000,0x00000000}},	//   jonu_, рожд, --, --,
   {{0xf8ba0789,0x8afc00a5,0x63ae023e,0x200d00d3}},	//   _इलाय, więk, _vibn, _apei_,
   {{0xb4db0028,0x4fc607cb,0x628e0146,0x65660060}},	//   _hoàn, аска, _vybo, _umkh,
   {{0x628e5345,0x63ae911b,0x96da0f77,0x00000000}},	//   _wybo, _tibn, _बजाउ, --,
   {{0x7c2400e3,0x00000000,0x00000000,0x00000000}},	//   _áiri, --, --, --,
   {{0x91e30f32,0xdbcf0094,0x399903a9,0x657600ce}},	//   _море, _džín, hésa_, onyh,
   {{0x7c2d04a3,0x22470364,0x2d9d00f0,0x6576911c}},	//   _šara, änke_, _chwe_, nnyh,
   {{0xef1a08c3,0x60cd3959,0xf8bf0257,0xdb03002b}},	//   _има_, ñame, ndée_, _siná,
   {{0x3b54455b,0xd00f00e3,0xda26004d,0xf2d3006e}},	//   скор, _تلك_, аємо, ֿער_,
   {{0xd2b700d7,0x00000000,0x00000000,0x00000000}},	//   ילית_, --, --, --,
   {{0xbc6709e5,0xed5900b6,0xb4d50378,0xdb1b020d}},	//   امین_, chž_, _सजे_, nquê,
   {{0xf8bf911d,0xdcfb07e7,0x6576298b,0xdca60284}},	//   rcé_, lluğ, dnyh, _тади,
   {{0xe7878e8d,0x6a4a013c,0x69c84893,0x00000000}},	//   румо, vəff, ppde, --,
   {{0xd5b82dd1,0xf9c40260,0xdcfb0511,0x00000000}},	//   ист_, _احتی, nluğ, --,
   {{0x4867008f,0x00000000,0x00000000,0x00000000}},	//   _въоб, --, --, --,
   {{0x9fe10081,0x798d911e,0xe7ee0251,0x3f8707aa}},	// [9b10] _মঙ্গ, _ikaw, _जिया_, yonu_,
   {{0xf2c7083c,0xdcfb026a,0x962700e8,0x00000000}},	//   рсан, kluğ, _paņē, --,
   {{0xd1b80068,0x877c006e,0x798d009e,0x6b4d033c}},	//   لانا_, _באזי, _kkaw, _dúgh,
   {{0xc10500e3,0xe6101ac9,0x65760120,0x3201911f}},	//   صوتي, _کشی_, cnyh, rthy_,
   {{0x656d0113,0x2cbf00a7,0x798d4788,0x80c600a3}},	//   miah, vcud_, _mkaw, ाड़े,
   {{0x656d3648,0x20e700de,0x6b881197,0xff0707f0}},	//   liah, ối_, jodg, рядн,
   {{0xb87b1ba8,0x798d0172,0xdce200d4,0x644d1023}},	//   laíd, _okaw, _emoč, lyai,
   {{0x798d0197,0x656d9120,0xe67800a1,0x387e00ae}},	//   _nkaw, niah, יתוח_, ştri_,
   {{0x442b02a1,0x3f879121,0x63a50076,0x601800d3}},	//   _jrc_, ponu_, omhn, _котя_,
   {{0x798d9122,0x442b9123,0xaca30174,0xdb0301ff}},	//   _akaw, _mrc_, lfịn, _minç,
   {{0x39920018,0x5e9500e3,0x442b00e7,0x63a50099}},	//   lási_, _الاط, _lrc_, imhn,
   {{0x7bc99124,0xe8f7088c,0x644d007b,0x00000000}},	//   ppeu, блю_, kyai, --,
   {{0x656d50ef,0x4ca50081,0xe81b0c8c,0x798d0113}},	//   diah, _গ্রু, _पैदा_, _dkaw,
   {{0x644d7cf1,0x798d010a,0x6d5b2e2a,0x00000000}},	//   dyai, _ekaw, lhua, --,
   {{0xceb2534e,0xa6e30088,0x442b0b87,0x00000000}},	//   לים_, íðar, _arc_, --,
   {{0x6d5b03e3,0x00000000,0x00000000,0x00000000}},	//   nhua, --, --, --,
   {{0xdcfb03e0,0x64a30138,0x6576032e,0x7c3b9125}},	// [9b20] zluğ, зата, rnyh, nxur,
   {{0x7c2b9126,0x442b9127,0x39920103,0x65760073}},	//   _mrgr, _drc_, dási_, snyh,
   {{0x442b0472,0x6d5b061d,0xdce20234,0xdcfb013c}},	//   _erc_, khua, _smoč, xluğ,
   {{0x00da003f,0x6d5b022e,0x10a62efb,0x63a50037}},	//   ابات_, jhua, биен, amhn,
   {{0xdcfb08a9,0x5ec90081,0xfecf0081,0xb87b0165}},	//   jluđ, _রয়ে, _রাজধ, caíd,
   {{0x934600ae,0x6d5b0131,0x26da0139,0x75249128}},	//   _унге, ehua, _jepo_, ldiz,
   {{0x7c2b0150,0xdb0300c2,0x442b0141,0x00000000}},	//   _argr, _minä, _zrc_, --,
   {{0x2fda0979,0x75249129,0x6fb600bf,0x26da23c5}},	//   _مورد_, ndiz, _همرا, _lepo_,
   {{0x75240051,0x3eaa0314,0xdc2a0604,0xdce20995}},	//   idiz, _ºbto_, اسبه_, _umoč,
   {{0xd00f0bf4,0x60c200a1,0xb4d5009f,0x6d5b016d}},	//   _سلم_, lcom, _सज्_, ahua,
   {{0xd9150fdf,0x6d5b10e4,0x60c20036,0x7c2b11fc}},	//   одны, bhua, ocom, _ergr,
   {{0xf53f0149,0x6d5b912a,0xd7fb00c2,0xb4c70096}},	//   _ihåg_, chua, луг_, _उभे_,
   {{0xbfb600ef,0x588701b6,0x75242a8c,0x286b2b49}},	//   _điểm_, сына, ddiz, урно_,
   {{0xac9708ba,0x26da037a,0x3c770266,0x629c02ac}},	//   _انها_, _cepo_, _פתגם_, _ozro,
   {{0x26da912b,0x656d0220,0x39920018,0x20dd00c6}},	//   _depo_, tiah, zási_, lšių_,
   {{0x6d400c56,0x6a4a0092,0xdb03255b,0x798d31ab}},	//   njma, rəfd, _pinç, _ukaw,
   {{0xb4b9000f,0x656d912c,0x629c0063,0x661e0063}},	// [9b30] _चली_, riah, _azro, _espk,
   {{0x656d0181,0xb87b2733,0x6d5b912d,0x60c20381}},	//   siah, raíd, zhua, ecom,
   {{0xfbda0775,0x644d1d49,0x821500e3,0x50b52887}},	//   _मौसम, syai, تواص, ослу,
   {{0x39920068,0x6d5b4f69,0x6d4600c2,0xdb0b01bf}},	//   tási_, xhua, ökal, _zugä,
   {{0x6d4000cc,0x442b398a,0x657d01cb,0x69d501f9}},	//   djma, _urc_, _ijsh, ázez,
   {{0x7c2d0995,0x4429271c,0xf41f00c2,0x399249d6}},	//   _šaro, mva_, _isä_, rási_,
   {{0xe81b0287,0xf1d502d5,0x60c2912e,0x59d733c5}},	//   _पैसा_, डीशन, bcom, _भौंर,
   {{0x60c2912f,0xdd9100e3,0x44299130,0xd658040a}},	//   ccom, بوع_, ova_, מיות_,
   {{0x44294003,0x764e0034,0x00000000,0x00000000}},	//   nva_, zyby, --, --,
   {{0x44299131,0x6d5b5d8b,0x60db4f6b,0x3d2900d1}},	//   iva_, shua, _heum, اتژی_,
   {{0x44291d2d,0x60db005c,0xdce90774,0x2a6001c2}},	//   hva_, _keum, lieč, _ƙiba_,
   {{0x442902e6,0xfd560134,0x6d5b023e,0xdb0300c2}},	//   kva_, _mgbọ, qhua, _sinä,
   {{0xdce99132,0x26da0239,0x442914cf,0x764e00f0}},	//   nieč, _pepo_, jva_, wyby,
   {{0x7c292134,0x60db01f7,0x7d099133,0x6d59063d}},	//   mver, _leum, lfes, _hlwa,
   {{0x44299134,0x2b47009c,0xa2d8023a,0x80d900a3}},	//   eva_, _ionc_, यरस्, _ढ़ूं,
   {{0xdce9013f,0x7c290ac9,0x9f460072,0x442915cd}},	//   kieč, over, iroá_, fva_,
   {{0x06d900c7,0xfd562caa,0x442900ea,0x2b470141}},	// [9b40] _তারি, _agbọ, gva_, _konc_,
   {{0x7524162d,0x1b170081,0x7c299135,0x636900a7}},	//   sdiz, তাকে_, iver, _yönə,
   {{0x7c298371,0x44299136,0xe82204f8,0x8afc00a5}},	//   hver, ava_, मिका_, mięt,
   {{0x60c222d4,0x7c298008,0x629c3c34,0xf1a900cd}},	//   ucom, kver, _vzro, مانه_,
   {{0xb4d611bb,0x7c299137,0x629c00a5,0x60db9138}},	//   हरी_, jver, _wzro, _deum,
   {{0x60c29139,0x8afc00a5,0x7c2923ff,0x6d59913a}},	//   scom, nięt, dver, _alwa,
   {{0x629c02e6,0x7d09913b,0x7c291c7d,0x60db0013}},	//   _uzro, ffes, ever, _feum,
   {{0x2900913c,0x7c2936e5,0x60db01b9,0x6d59030a}},	//   _ncia_, fver, _geum, _clwa,
   {{0x7c29343a,0xb0540174,0x8b660037,0x21242bc0}},	//   gver, ọọrụ_, قادم, _iamh_,
   {{0xb4d61000,0x3f7600a5,0xa3dc1b92,0xeb4a686c}},	//   हरु_, dług_, णीय_, рчик_,
   {{0x2b4704ea,0x06d90081,0x79954000,0x44290730}},	//   _donc_, _তালি, зинф, zva_,
   {{0xb4b905d4,0xa9c300d6,0x21260085,0x6b600065}},	//   _चले_, ьськ, ndoh_, _bágù,
   {{0x2006913d,0x6ec11677,0x7d7b0142,0x2b4700fc}},	//   ntoi_, रुकु, _דראג, _fonc_,
   {{0x212401f7,0xdb0300f3,0x4429913e,0x00000000}},	//   _lamh_, _pinå, vva_, --,
   {{0xb4d60961,0xc4db0831,0xf41f00c2,0x356b2825}},	//   हरू_, иђа_, _ssä_, аран_,
   {{0xb87b0161,0x20060052,0x2124009c,0x00000000}},	//   raíb, ktoi_, _namh_, --,
   {{0x29190a37,0x94ab10bb,0x4429913f,0x20060052}},	// [9b50] mesa_, ртва_, uva_, jtoi_,
   {{0x29199140,0x60db9141,0x6f18077e,0xdb1901dc}},	//   lesa_, _seum, jevc, _cuwè,
   {{0x44293b2a,0x55950396,0x8ed80033,0x92680d6f}},	//   sva_, _наоѓ, _সাংগ, орца_,
   {{0x68fd0709,0xdb1b4229,0xdb0b0212,0x2006023b}},	//   ngsd, rqué, _utgö, ftoi_,
   {{0x25a98295,0x6725007a,0x39490072,0xdb1b04c1}},	//   mmal_, _kahj, _moas_, squé,
   {{0x7c296b18,0x394904de,0x39920018,0x25a99142}},	//   vver, _loas_, lást_, lmal_,
   {{0x20069143,0x7c29029a,0x63bd9144,0x7d093106}},	//   atoi_, wver, _husn, tfes,
   {{0x25a902e2,0x29199145,0x67251f4f,0x63bd1a3a}},	//   nmal_, jesa_, _lahj, _kusn,
   {{0x29199146,0xc10400e3,0x7c290257,0x25a90364}},	//   desa_, _توقي, uver, imal_,
   {{0x63bd9147,0x25a901bf,0x67259148,0x7d09059a}},	//   _musn, hmal_, _nahj, sfes,
   {{0x29199149,0x39490bfe,0x25a9914a,0x63b519ad}},	//   fesa_, _boas_, kmal_, _mizn,
   {{0x39490933,0x7c29914b,0x29193fc8,0x6d590201}},	//   _coas_, pver, gesa_, _ulwa,
   {{0xdb03914c,0x63bd023e,0x63bb03be,0xab290636}},	//   _minú, _nusn, _éunh, _гола_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae1914d,0x2919914e,0x63bd01bf,0x8f9a00ca}},	//   malt, besa_, _ausn, מישי,
   {{0xf99200bf,0x7ae1914f,0x63bd02ad,0xb4d60101}},	//   _ثبت_, lalt, _busn, हरे_,
   {{0x29c10028,0xf484001c,0xd05403e3,0x212401ec}},	// [9b60] _hóa_, ذاری, ɗaɗi, _ramh_,
   {{0xdb0b0072,0x7ae19150,0x9479004d,0x63bd00d8}},	//   _augú, nalt, істу_, _dusn,
   {{0x63b50b18,0xb6bb00ca,0xdb1903a9,0x6360003e}},	//   _dizn, _לציי, _cuwé, _löng,
   {{0x7ae19151,0x2d800181,0x63bd2f77,0xdb0d003e}},	//   halt, čiek_, _fusn, _ákær,
   {{0x7ae126fd,0x29c19152,0xdb190113,0xf53f00f3}},	//   kalt, _lóa_, _tuwè, _tiår_,
   {{0x29190283,0x20064e63,0x7ae100c2,0x00000000}},	//   zesa_, rtoi_, jalt, --,
   {{0x7ae13d7d,0x6f180b18,0x29199153,0x03a30e05}},	//   dalt, revc, yesa_, _чиро,
   {{0x7cf607aa,0x442202a1,0x7ae1009c,0x63bd005c}},	//   dürü, _ksk_, ealt, _yusn,
   {{0x29197412,0x06e20081,0x63bd008c,0x442277fb}},	//   vesa_, _বানি, _xusn, _jsk_,
   {{0x44229154,0x7ae19155,0x39920018,0x39499156}},	//   _msk_, galt, zást_, _soas_,
   {{0xc33302f8,0x291942a3,0x44270023,0x442201ce}},	//   גות_, tesa_, ̉n_, _lsk_,
   {{0x7ae131e8,0x6360003e,0xa49b009c,0x00000000}},	//   aalt, _hönd, _mbòr, --,
   {{0x7ae19157,0x63609158,0xc7c70f94,0x7d029159}},	//   balt, _göng, ясни, _icos,
   {{0x7c22915a,0x7ae1442c,0x2919915b,0xbb433407}},	//   _isor, calt, sesa_, _печк,
   {{0x2919915c,0x39920018,0x63b50335,0x442200a1}},	//   pesa_, tást_, _rizn, _ask_,
   {{0x9cfa0033,0x3f8e198d,0x6360003e,0x629500d4}},	//   _আসুন_, hofu_, _lönd, _ryzo,
   {{0x68ed5ff6,0xa49b0065,0x25a92bd4,0x3f8e1b95}},	// [9b70] _idad, _abòr, rmal_, kofu_,
   {{0x02a708d9,0x25a901bf,0x4422915d,0x2cab00a7}},	//   прем, smal_, _dsk_, ükdə_,
   {{0x2b0e632d,0x60cd1de7,0x29c10019,0xfe1b0378}},	//   त्यु_, ñamo, _xóa_, _भैंस_,
   {{0x63bd4fcb,0x7c22915e,0x7ae1915f,0x44229160}},	//   _tusn, _osor, zalt, _fsk_,
   {{0x68ed0a4b,0x7c229161,0x63605bd0,0x65680216}},	//   _mdad, _nsor, _bönd, ëdhe,
   {{0x75260044,0x3f8e024a,0x4dfb023a,0x00000000}},	//   _zakz, gofu_, _एमआई_, --,
   {{0x7ae14361,0x68ed3264,0x63609162,0x00000000}},	//   valt, _odad, _dönd, --,
   {{0xe7ee0b89,0x27e97dec,0x7ae101bf,0x68ed3673}},	//   _जिला_, _ovan_, walt, _ndad,
   {{0x7ae19163,0x27e902ac,0x60c9850c,0x3f8e024a}},	//   talt, _nvan_, _ifem, bofu_,
   {{0x63600390,0x68ed9164,0x7cf6008e,0x98a9007f}},	//   _gönd, _adad, türü, _znać_,
   {{0x27e906a3,0x7c229165,0x98700220,0x09bd0033}},	//   _avan_, _esor, rúča_, _আবহা,
   {{0x7ae125a5,0x29e70cc9,0x7d020076,0x7cf60555}},	//   salt, rđa_, _gcos, rürü,
   {{0x7ae19166,0xeb8e00d3,0x7d1b9167,0xb8d60096}},	//   palt, _аи_, meus, _जण_,
   {{0x6d4b9168,0x7d1b9169,0x68ed384e,0x636002c3}},	//   _hoga, leus, _edad, _köne,
   {{0xab280391,0xdb1b1ba8,0x4422916a,0x995200d4}},	//   _رسول_, nquí, _ssk_, máž_,
   {{0x6d4b916b,0xe5a323a3,0x7d1b916c,0x99520094}},	//   _joga, виси, neus, láž_,
   {{0x9f5f3964,0x63600149,0x2fcd01fa,0xb87b0037}},	// [9b80] _aquí_, _löne, _nteg_, laín,
   {{0x6d4b916d,0xdcda16f8,0x4422784e,0x7d1b00fc}},	//   _loga, _यज्ञ, _vsk_, heus,
   {{0x752663f2,0xc87f02e2,0x7d1b204b,0x6d4b916e}},	//   _takz, raße_, keus, _ooga,
   {{0x6360916f,0xaca30065,0xa49b00b3,0x27e9014b}},	//   _sönd, _afọj, _icòn, _yvan_,
   {{0xd0100241,0x44229170,0x3f8e9171,0x801a35bf}},	//   الت_, _usk_, tofu_, تزاز_,
   {{0x60c99172,0x44200010,0x7d021043,0x3eba00d6}},	//   _efem, mwi_, _scos, øpt_,
   {{0x656f02ad,0x60c99173,0x44207f39,0x3f8e9174}},	//   _ymch, _ffem, lwi_, rofu_,
   {{0x63600b88,0x6d4b1519,0x7d1b9024,0xf2a300ae}},	//   _döne, _coga, geus, _рисп,
   {{0xe3bf03be,0x44200150,0x3f8e9175,0xaf06264b}},	//   _xuñ_, nwi_, pofu_, _опал,
   {{0x2912022b,0x00000000,0x00000000,0x00000000}},	//   _abya_, --, --, --,
   {{0x6d4b9176,0x7d270222,0xdd8f00d3,0xad6200de}},	//   _foga, örsä, _аш_, _đươn,
   {{0x7d1b4fe5,0x7c22006d,0x6d4b9177,0x00000000}},	//   ceus, _tsor, _goga, --,
   {{0xab2a455b,0xf7732ba0,0x7c2206c0,0x44200193}},	//   _мода_, ناس_, _usor, jwi_,
   {{0x63600b88,0x44209178,0x29120283,0xc053006e}},	//   _yöne, dwi_, _ebya_, דזש_,
   {{0xb87b222b,0x7dc7026a,0xe7eb1b11,0x56943602}},	//   caín, _kısa, _झटका_, варт,
   {{0x6d4b0933,0x06e20081,0x68ed9179,0x3ce40231}},	//   _xoga, _বাণি, _udad, namv_,
   {{0xb87b00e3,0x2d580257,0x4420917a,0x659423e3}},	// [9b90] maío, _réel_, gwi_, тату,
   {{0xb87b0080,0x250900d0,0x5f0000a5,0x39990103}},	//   laío, _کردی_, _राष्_, dési_,
   {{0x2fcd917b,0x7d1b04d1,0x44200188,0x50f51da9}},	//   _steg_, yeus, awi_, езет,
   {{0xb87b00e3,0x2b0e0ff9,0x02a4888e,0x44200027}},	//   naío, त्तु_, трум, bwi_,
   {{0x442d0af0,0x6d4b917c,0x06e20081,0x7d1b49f0}},	//   _ée_, _roga, _বাতি, veus,
   {{0x6d4b917d,0xb87b0037,0x00000000,0x00000000}},	//   _soga, haío, --, --,
   {{0xe8d90e62,0x7d1b917e,0x3eb30212,0x2c170caf}},	//   _alọ_, teus, äxt_, _बैजू_,
   {{0xdb1b04d8,0x56b800a1,0x0c2509b9,0x80d90033}},	//   rquí, ופון_, емин, _ডাক্,
   {{0x6d4b917f,0x7d1b9180,0xb87b00e3,0x27ed0087}},	//   _voga, reus, daío, šenj_,
   {{0x4a452249,0xf1b9033b,0x7d1b9024,0x6d4b65a8}},	//   енов, _hiš_, seus, _woga,
   {{0x44209181,0x6d4b0013,0xa3e608fa,0xf1b900cc}},	//   zwi_, _toga, _यौन_, _kiš_,
   {{0x9952025b,0x25b90062,0xdc330031,0x290400bc}},	//   sáž_, _nisl_, lúče, üma_,
   {{0xf1b928fc,0xb87b002b,0x995200d4,0x31560142}},	//   _miš_, saín, páž_, גירן_,
   {{0x442005aa,0x63600364,0xa92400c6,0xa8030072}},	//   vwi_, _mönc, _ąžuo, áñas,
   {{0x6996426c,0x59b9007d,0xba5200e3,0x39990018}},	//   _прих, _ईंटर, _منوع, zési_,
   {{0xb87b0080,0xa2cd0775,0xf1b90039,0x44209182}},	//   caío, दुस्, _niš_, twi_,
   {{0x248608a8,0x442006a8,0x68e60a60,0x00000000}},	// [9ba0] çom_, uwi_, makd, --,
   {{0x44200d37,0x78a4019f,0x68e69183,0x00000000}},	//   rwi_, _iziv, lakd, --,
   {{0x26d89184,0xa2a50454,0x44209185,0xb87b0076}},	//   mbro_, _करण्, swi_, haíl,
   {{0x290273ec,0x39990018,0x68e60d1f,0xdce20234}},	//   ngka_, tési_, nakd, _imoć,
   {{0x25dc00b6,0x00000000,0x00000000,0x00000000}},	//   गीरी_, --, --, --,
   {{0x80d01b11,0x672000b7,0xe5e7001c,0x26d879a9}},	//   _ड्रे, मजिक_, _تزیی, nbro_,
   {{0x6383013d,0xdb030037,0x25e302d5,0xf1b90218}},	//   _сгра, _ghné, टीपी_, _fiš_,
   {{0xd00a5601,0x79844d61,0x7dc700a7,0x1d3400e5}},	//   _небе_, _njiw, _qısa, тния,
   {{0x9f860426,0xfbcf110a,0x78a4294f,0xfd6600fe}},	//   _згад, یتی_, _nziv, _khuế,
   {{0x5a345bc8,0xdbdb0032,0x79840350,0x1ee8001c}},	//   внот, _dààt, _ajiw, _آوای_,
   {{0x28f96089,0xb87b00e3,0x78a46b52,0xd52d0065}},	//   мень_, taío, _aziv, _jọ́s,
   {{0xa3c0000d,0x7c861720,0xc27b00ca,0x00000000}},	//   ँदा_, _пуле, לריי, --,
   {{0xdd8f012b,0xb87b00e3,0xd838539a,0x656472af}},	//   _اون_, raío, нэр_, dhih,
   {{0x61fe02e6,0xb87b00e3,0x48ed000d,0x99a001d3}},	//   kupl, saío, _आएको_, āršu_,
   {{0xdb03030b,0x249f0095,0xb9070033,0x78a43944}},	//   _jiný, _šum_, _পা_, _eziv,
   {{0x656400a6,0xba9b00a1,0x1a9b00ca,0x00000000}},	//   ghih, _מסוי, _מיוע, --,
   {{0x26d8028d,0x3ebe00c4,0x24180fe9,0x94770d83}},	// [9bb0] bbro_, _ogtt_, ноты_, ردرا,
   {{0xd6db0084,0x00000000,0x00000000,0x00000000}},	//   _эти_, --, --, --,
   {{0xa4d9249c,0x40ce0134,0x81c90033,0x78a4007e}},	//   _одну_, _ịrị_, লীন_, _zziv,
   {{0x60b51363,0x00000000,0x00000000,0x00000000}},	//   نمائ, --, --, --,
   {{0xdb18016d,0x753d9186,0xf1b900c4,0x2ca00441}},	//   _vivê, _insz, _viš_, _ùidh_,
   {{0x21290117,0xc476021e,0x0eac06eb,0x00000000}},	//   žah_, _יתרו_, टइंड, --,
   {{0x61fe305a,0x6b670065,0x02dd0285,0x00000000}},	//   cupl, _légù, यरीन, --,
   {{0x752d9187,0x69c718ed,0x6a4a00a7,0xa2cd3162}},	//   ndaz, íjem, rəfl, दुर्,
   {{0x51841979,0xdb18022b,0x5f09007f,0x59c6007f}},	//   _сура, _kivè, _साप्_, _रूबर,
   {{0x799d01bf,0xf41200ca,0x999f00c6,0x162100b6}},	//   elsw, ספי_, kytų_, मबार_,
   {{0x68e67b2e,0x78a40103,0x753d029a,0xc3320796}},	//   takd, _sziv, _onsz, בוי_,
   {{0x4ad113ae,0x999f00c6,0x00000000,0x00000000}},	//   _द्रव, dytų_, --, --,
   {{0xf1b20c6a,0x3ebe01c2,0x8b25314b,0x64440072}},	//   יסט_, _ygtt_, _адле, xxii,
   {{0x06e20081,0x6d5b2050,0x29050103,0x68e606a8}},	//   _বাহি, lkua, őlap_, sakd,
   {{0x26d81842,0x66e30b99,0x660600e5,0xa5960aca}},	//   rbro_, роса, ъпва, вращ,
   {{0x7ae33f88,0x6d5b9188,0x26d89189,0x6d498c6f}},	//   _hent, nkua, sbro_, njea,
   {{0xc9530054,0x78a4042d,0x69c3918a,0xe3ba1510}},	// [9bc0] _כמה_, _uziv, _hune, дба_,
   {{0x7ae3918b,0x69c32e02,0x27e01baa,0x6564918c}},	//   _jent, _kune, _iwin_, shih,
   {{0xdb1806a3,0x2cb102c6,0x6d5b007b,0x1db35433}},	//   _divè, ězdy_, kkua, ुदात,
   {{0x7ae3918d,0x69c3918e,0x61fe918f,0x3f8500e7}},	//   _lent, _mune, rupl, _ajlu_,
   {{0x69c39190,0xdb0b9191,0x68e49192,0x61fe9193}},	//   _lune, _bugü, _meid, supl,
   {{0x68e42fa2,0x7ae39194,0x39990018,0xe3b200b9}},	//   _leid, _nent, lést_, _خرج_,
   {{0x69c39195,0x91e3333f,0x2ca00d62,0x63bc01b9}},	//   _nune, _восе, _šid_, _iirn,
   {{0x68e40150,0x39990c90,0xdce9026a,0x63bc1537}},	//   _neid, nést_, rneğ, _hirn,
   {{0x7ae30f8b,0x63bc3c0d,0x31660103,0xe7bd0033}},	//   _bent, _kirn, mhoz_, _অব্য,
   {{0x69c39196,0x3a270167,0xdb180103,0x63bc1b41}},	//   _bune, _bsnp_, _kivé, _jirn,
   {{0x68e49197,0x69c34a25,0x7ae31b9e,0x6ed80c38}},	//   _beid, _cune, _dent, _न्यु,
   {{0x7ae37d43,0x68e400f0,0x629c1e95,0xdb030131}},	//   _eent, _ceid, _myro, _binó,
   {{0x7ae39198,0x5887147c,0x68e401b5,0x60cd05e6}},	//   _fent, тына, _deid, ñami,
   {{0x7ae35a9a,0x629c00f9,0x63bc007e,0x52e10034}},	//   _gent, _oyro, _nirn, _फ़ेस,
   {{0xe5c41fbf,0x68e40080,0x31660018,0x69c39199}},	//   исто, _feid, khoz_, _gune,
   {{0x7ae3919a,0x8ab700a1,0x68e468f5,0x2bb208d4}},	//   _zent, _בלוג_, _geid, ीदवा,
   {{0x63bc0a75,0x629c0009,0x752d6d6e,0x7ae34944}},	// [9bd0] _birn, _ayro, rdaz, _yent,
   {{0x7ae30933,0x629c919b,0x68e401cb,0x7ae80034}},	//   _xent, _byro, _zeid, nadt,
   {{0x6d5b0052,0x629c0350,0xdb18015e,0x4432033c}},	//   ykua, _cyro, _vivè, avy_,
   {{0xdb180113,0xf8c100c3,0x629c03a8,0x63bc0503}},	//   _divé, _एलोप, _dyro, _eirn,
   {{0x7ae86e08,0x629c019c,0xe0d8004d,0xdcfb00e7}},	//   kadt, _eyro, тві_, unuč,
   {{0x63600088,0x63bc919c,0xdb0300b3,0x00000000}},	//   _hönn, _girn, _linò, --,
   {{0x6360919d,0xdb0f1561,0x7ae3919e,0x6d5b5bae}},	//   _könn, _àdép, _rent, tkua,
   {{0x63600103,0xde160037,0x63bc919f,0x290991a0}},	//   _jönn, اقيت_, _zirn, _ncaa_,
   {{0x7ae3016a,0x6d5b91a1,0x69c391a2,0x6360003e}},	//   _pent, rkua, _sune, _mönn,
   {{0xe9d922f9,0x69c391a3,0x69c40181,0x6d5b91a4}},	//   нко_, _pune, _čier, skua,
   {{0xc3320130,0x68e45e8b,0xdb0304d8,0x7dc701e8}},	//   זוי_, _peid, _sinó, _kısm,
   {{0x69c314f3,0xf99f06a3,0x7ae391a5,0x2909255c}},	//   _vune, glè_, _went, _ccaa_,
   {{0x68e48fda,0xe9e90220,0x399900b6,0xe81f0179}},	//   _veid, dnúť_, vést_, मौला_,
   {{0x443291a6,0x68e40cac,0xa87500c2,0x3dc50361}},	//   vvy_, _weid, рующ, _kulw_,
   {{0x68e491a7,0x39990018,0x2bdf2235,0xdb0102c3}},	//   _teid, tést_, पीरा, rmlä,
   {{0x63bc91a8,0x96d40e50,0x0906014d,0x44320a7f}},	//   _sirn, _ब्रॉ, _спин, tvy_,
   {{0x629c3a18,0xd4671e13,0x394091a9,0xdb190034}},	// [9be0] _syro, гите_, _inis_, _utwó,
   {{0x443291aa,0x87260084,0x394000d8,0xdb0300d8}},	//   rvy_, _смож, _hnis_, _ohní,
   {{0x6440007e,0x39400090,0x316601f9,0x00000000}},	//   _šmid, _knis_, thoz_, --,
   {{0x629c0618,0x98a5007f,0x6360042c,0x00000000}},	//   _vyro, ślą_, _gönn, --,
   {{0x63bc91ab,0x629c0034,0xdfcf0037,0x3940009c}},	//   _tirn, _wyro, كين_, _mnis_,
   {{0x31660018,0x96a8030b,0xe8d90174,0x8f341e61}},	//   shoz_, _गराउ, _ijụ_, рекц,
   {{0x2d9f413a,0x2ee5084e,0x316601f9,0x7ae809a1}},	//   flue_, _delf_, phoz_, vadt,
   {{0x5d54261f,0xf1aa001c,0x212d009c,0x21765a67}},	//   ркит, _سازه_, _gaeh_, _сугр,
   {{0x21670a7c,0x7ae891ac,0x29090027,0x54770142}},	//   _сити_, tadt, _rcaa_, ָגיע_,
   {{0x96d43abb,0x394091ad,0x6fdd09d0,0x25a091ae}},	//   _ब्लॉ, _anis_, _नौटं, hlil_,
   {{0xdb0300e3,0x6fb3015a,0x7ae80730,0x395291af}},	//   _ghní, _املا, radt, _boys_,
   {{0x2ee50505,0x02b7006e,0x39520027,0x2d9f18ab}},	//   _zelf_, טליך_, _coys_, clue_,
   {{0x8d930080,0x9c5700cd,0xec34015a,0x63603a68}},	//   _النش, _مجوز_, _خوشگ, _rönn,
   {{0x28e324eb,0x636001cd,0x00000000,0x00000000}},	//   परहि, _sönn, --, --,
   {{0x58d50465,0xe8d90129,0xe9e90031,0x2909024a}},	//   _койт, _ajụ_, tnúť_, _tcaa_,
   {{0x58390927,0xb4d50c79,0x636002c3,0x395201ee}},	//   _азия_, ржащ, _böno, _goys_,
   {{0x33750152,0x80cd0033,0xa9bc00ca,0xe8d800ca}},	// [9bf0] агар, ারম্, _אזהר, _עוזר_,
   {{0xe9e90206,0x00000000,0x00000000,0x00000000}},	//   snúť_, --, --, --,
   {{0x02a73bbc,0xb4db009c,0xe9e90031,0x77ba00ca}},	//   урам, _cnàc, pnúť_, _שמתח,
   {{0x27ed0106,0x2ee500a1,0x32010094,0xa49b009c}},	//   šenu_, _self_, ruhy_, _lcòi,
   {{0x504500e5,0x6360013c,0x00000000,0x00000000}},	//   релб, _könl, --, --,
   {{0xb0d50789,0x212d0113,0x3ce905db,0x44390158}},	//   _ड्रग, _waeh_, _žav_, _irs_,
   {{0xf1a70c58,0x752f3720,0x6b5f084e,0x443906f5}},	//   _бран, _kacz, _sêgo, _hrs_,
   {{0x442b91b0,0x528400e3,0x4439778c,0x491506eb}},	//   _ksc_, _الفك, _krs_, _फॉलो_,
   {{0xab655f3b,0x2ee591b1,0x69ce91b2,0x6fb90036}},	//   ивил, _telf_, íben, _агар_,
   {{0xce6b1b4d,0xd7a4000f,0x443959af,0xb92b00fe}},	//   _пред_, _खींच, _mrs_, _thuỳ_,
   {{0xa96a0114,0xfaa50e48,0x443991b3,0x7aa500ae}},	//   вина_, рано, _lrs_, ринз,
   {{0x442b00dc,0x752f0034,0x39520188,0x00000000}},	//   _osc_, _nacz, _qoys_, --,
   {{0x25e30455,0x7db40688,0x8d5a0089,0x44390381}},	//   टीसी_, _اصلا, _שכני, _nrs_,
   {{0x66e301b6,0x00000000,0x00000000,0x00000000}},	//   жора, --, --, --,
   {{0x25a091b4,0x00000000,0x00000000,0x00000000}},	//   tlil_, --, --, --,
   {{0x394091b5,0xbdfa0033,0x00000000,0x00000000}},	//   _unis_, _আহমদ_, --, --,

   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [9c00] --, --, --, --,
   {{0x443991b6,0x25a0103b,0x63600233,0x442b32e8}},	//   _drs_, slil_, _gönl, _dsc_,
   {{0x443991b7,0xb226002d,0xe5a62877,0x366a0f32}},	//   _ers_, рмел, _вини, _рано_,
   {{0x443991b8,0x00000000,0x00000000,0x00000000}},	//   _frs_, --, --, --,
   {{0x6a4a01d4,0x33d591b9,0x443991ba,0x63600367}},	//   rəfi, _гіст, _grs_, _yönl,
   {{0x752f00a5,0x25e30251,0x00000000,0x00000000}},	//   _zacz, टीवी_, --, --,
   {{0x69c1178c,0x224734fe,0x7c2d0aa8,0x7c3900eb}},	//   _रंगी, änkt_, _šarp, _arwr,
   {{0x75240143,0x2372007f,0x44390158,0x00000000}},	//   neiz, żają_, _yrs_, --,
   {{0x442b0072,0x8afe0044,0x661e00dc,0x765c03a8}},	//   _xsc_, _alƙa, _lppk, hyry,
   {{0x7c390124,0x61fe0849,0xdb0301ec,0x75240364}},	//   _drwr, orpl, _chnà, heiz,
   {{0x19591ad1,0x7c2b1c40,0x3ea90d2a,0x0ecf1cff}},	//   ганы_, _esgr, ƙata_, _स्टड,
   {{0xa2d6063a,0x00000000,0x00000000,0x00000000}},	//   मुत्, --, --, --,
   {{0xb8cf550b,0x68f602ad,0x752f00a5,0x6d4291bb}},	//   _कर_, _ddyd, _racz, _inoa,
   {{0x656691bc,0xdb0301f7,0x0b933a1d,0x00000000}},	//   _alkh, _ghnà, _وجود, --,
   {{0x752f0034,0x9942007f,0x88c802c6,0x00000000}},	//   _pacz, _dół_, _svěž, --,
   {{0x81c40f71,0x442b0472,0x7c2b02ad,0x661e005c}},	//   _এবং_, _psc_, _ysgr, _dppk,
   {{0x61fe0db1,0xf2c701a0,0x69da91bd,0x291b00bd}},	// [9c10] erpl, асен, lpte, _ibqa_,
   {{0x34a705d4,0xdb0a00e3,0x443991be,0x24181402}},	//   _खरीद, _bhfé, _vrs_, рофы_,
   {{0x5f00000f,0x6d4200ae,0x442b01ee,0x764800ce}},	//   _राज्_, _onoa, _wsc_, ädyt,
   {{0xdd860979,0x443972b8,0x91ac0023,0x7afd00c6}},	//   _رو_, _trs_, _đọc_, ėsti,
   {{0x443991bf,0xf77000cd,0xf4842cbf,0x61fe02ac}},	//   _urs_, _رای_, _дурн, arpl,
   {{0x44295fa6,0x6d4200f9,0xf8bf91c0,0xf1c90037}},	//   mwa_, _anoa, ldés_, _موسى_,
   {{0x44298e05,0xdb1803be,0x61fe0106,0x2d58020d}},	//   lwa_, _civí, crpl, _nées_,
   {{0xf8bf2c48,0x98a50034,0x44298ce5,0xcd2900c2}},	//   ndés_, ślę_, owa_, ужие_,
   {{0x442991c1,0x1c421ad1,0xdd2f00b6,0xeb992de9}},	//   nwa_, зным, _těžk, лии_,
   {{0x442991c2,0x201f0062,0x00000000,0x00000000}},	//   iwa_, _ipui_, --, --,
   {{0x442991c3,0xed3500ae,0x81c90033,0xdb0300da}},	//   hwa_, _гэлэ, লীর_, _chná,
   {{0x442991c4,0xce6821fd,0x00000000,0x00000000}},	//   kwa_, _труд_, --, --,
   {{0xa2e800c7,0x442991c5,0x7d0991c6,0x2d9d0294}},	//   _পাসও, jwa_, mges, _ikwe_,
   {{0x59cf084a,0x4429067d,0x7d0991c7,0x7c2926f3}},	//   _संपर, dwa_, lges, mwer,
   {{0x442991c8,0x7c290b7c,0xdb0300e3,0xf1b90285}},	//   ewa_, lwer, _ghná, ेदान,
   {{0x442965b7,0x16a809b0,0x9c130174,0x00000000}},	//   fwa_, _गरीब, _nọkw, --,
   {{0x44294dc7,0x7c2991c9,0x752422c9,0x7d090364}},	// [9c20] gwa_, nwer, reiz, iges,
   {{0x06e20081,0x7d090364,0x7524029a,0x7c298086}},	//   _বাকি, hges, seiz, iwer,
   {{0xe1fa108f,0x442989f4,0x7c2902e2,0xb9c107aa}},	//   уге_, awa_, hwer, _üçün,
   {{0x44295092,0x7c2991ca,0x2638025b,0x106a0b91}},	//   bwa_, kwer, _ičo_, лией_,
   {{0x7bcf1fa4,0x7d095c63,0x7c290126,0x63600149}},	//   ícul, dges, jwer, _jönk,
   {{0x69da2e6e,0x7c2991cb,0x2d9d01c2,0x8bff0033}},	//   ypte, dwer, _akwe_, ্বান_,
   {{0x7d0901bf,0x7c29112f,0x201f0154,0xdef901b3}},	//   fges, ewer, _epui_, рыі_,
   {{0x7c2991cc,0xdd900dd0,0x7d0985af,0xdb1804d8}},	//   fwer, بوب_, gges, _viví,
   {{0x80662fd4,0x7c2991cd,0xa6c00081,0xb87b0076}},	//   _уваж, gwer, ্রিয়, naít,
   {{0x261900a5,0x6e3c20fc,0x2d9d0129,0x7d0991ce}},	//   _पहली_, _árbo, _ekwe_, ages,
   {{0x4429655f,0xdc5505bc,0xdb01020d,0x7f3b00ca}},	//   zwa_, مریک, illè, _תעבו,
   {{0xd90f11a2,0x44298473,0x7c29035e,0x99677207}},	//   ریخ_, ywa_, bwer, стол,
   {{0x34a7009d,0x7c2901cb,0x00000000,0x00000000}},	//   _खरेद, cwer, --, --,
   {{0x442914b1,0xd7f800c2,0x69da91cf,0xb87b0076}},	//   vwa_, щую_, ppte, daít,
   {{0x7aea002d,0x442903e5,0x4b7b0266,0x00000000}},	//   _ieft, wwa_, _תאוו, --,
   {{0x442922b1,0x46d902d5,0x6b9a00ee,0x20ba02d5}},	//   twa_, _ब्रह, lotg, ेशाध,
   {{0xf8bf91d0,0x4429563a,0x69ca5f27,0x3f8700f0}},	// [9c30] rdés_, uwa_, _hufe, ynnu_,
   {{0x44295c19,0x7aea02e6,0x69ca91d1,0xe2f900d6}},	//   rwa_, _jeft, _kufe, режі_,
   {{0x442991d2,0x201f00d3,0x7d09057a,0xdb010ac9}},	//   swa_, _spui_, yges, rmlø,
   {{0xe70509b4,0x442991d3,0x3f9e40e8,0x69ca0baa}},	//   _اسکی, pwa_, _aktu_, _mufe,
   {{0x442991d4,0x7af80031,0xdce000c6,0x00000000}},	//   qwa_, _odvt, limė, --,
   {{0x7aea0092,0x55520103,0x00000000,0x00000000}},	//   _neft, _ٹھہر, --, --,
   {{0x7d095d73,0x7c290371,0x9c130134,0x67350381}},	//   tges, wwer, _tọkw, idzj,
   {{0x7c2991d5,0xed591773,0x78ad0117,0x798d91d6}},	//   twer, рои_, _ozav, _njaw,
   {{0x7d096378,0x69d822bb,0x7c2901c0,0x69ca5feb}},	//   rges, _atve, uwer, _aufe,
   {{0x7c290db1,0x7d09357f,0x2d830103,0x6727037a}},	//   rwer, sges, ője_, jejj,
   {{0xdce202e6,0xdd99035d,0x69264256,0x7c2991d7}},	//   _zloč, poň_, омна, swer,
   {{0x7c2991d8,0xdb010257,0x7bdb91d9,0x2d9d78cc}},	//   pwer, illé, ppuu, _ukwe_,
   {{0x656d91da,0xb87b10d9,0x798d0ece,0x6b9a0125}},	//   dhah, daís, _djaw, botg,
   {{0x78ad0a39,0xdb0a00ee,0x7bd90027,0xe73a0291}},	//   _dzav, _difó, _itwu, шег_,
   {{0x7bcb91db,0x7bc30270,0x857a0f21,0x78ad91dc}},	//   _hugu, _iinu, асат_, _ezav,
   {{0x7bc31098,0x7bcb0c50,0x656d0256,0xb0a991dd}},	//   _hinu, _kugu, ghah, _औरंग,
   {{0x7bcb91de,0x7bc391df,0xfd640129,0x64a34d93}},	// [9c40] _jugu, _kinu, _anwụ, дата,
   {{0xaac905a5,0xdb180018,0x636001bf,0x6daa0022}},	//   रशिक, _kivá, _köni, _aƙal,
   {{0x7bcb91e0,0x249600c6,0xb87b0076,0x00000000}},	//   _lugu, _žemę_, saít, --,
   {{0xdce200cb,0x02aa0f35,0x3f9e0063,0x0446002d}},	//   _ploč, _करीन, _sktu_, _демн,
   {{0x2eee91e1,0x7bcb57dd,0x644b00aa,0x7bc30062}},	//   taff_, _nugu, ägit, _oinu,
   {{0x7bc391e2,0x442209a4,0xdce20094,0x78a433b5}},	//   _ninu, _ipk_, _vloč, _myiv,
   {{0x7bcb0158,0x2eee91e3,0xdbd10161,0x7bd90027}},	//   _augu, raff_, qüên, _atwu,
   {{0x7bc30006,0x7bcb91e4,0x442200a4,0x7aea1e42}},	//   _ainu, _bugu, _kpk_, _seft,
   {{0xa06791e5,0xa2be3ec9,0x7bc38dcc,0x69ca91e6}},	//   _дата_, _वृत्, _binu, _sufe,
   {{0x7bcb0a00,0xb4db0472,0x7bc30167,0x65640063}},	//   _dugu, _anàl, _cinu, hkih,
   {{0x78ad0018,0x7bc391e7,0x7a370174,0x6b9a00ee}},	//   _szav, _dinu, _ọtu, rotg,
   {{0x7bc30088,0xdb18025b,0x3f9c7d87,0xdb03016d}},	//   _einu, _divá, lovu_, _sinô,
   {{0x64400995,0x67270078,0x69ca91e8,0x69c4009c}},	//   _šmin, tejj, _wufe, _diie,
   {{0x3f9c03ce,0x7c227d9a,0x7bc372e7,0xf1ca080f}},	//   novu_, _ipor, _ginu, िदान,
   {{0x69d82fe7,0x442291e9,0x656d001c,0x95cb2ff8}},	//   _utve, _apk_, thah, руга_,
   {{0x3f9c1197,0x656d90d7,0x3201025b,0x442291ea}},	//   hovu_, uhah, vrhy_, _bpk_,
   {{0xb87b22bf,0x78ad0363,0x2d5100e1,0x7bc30169}},	// [9c50] raís, _uzav, _páez_, _yinu,
   {{0x656d91eb,0x27e991ec,0x68ed91ed,0x44220063}},	//   shah, _iwan_, _head, _dpk_,
   {{0x68ed06ee,0xa2be08c0,0x27e91df6,0x69ce0220}},	//   _kead, _वृद्, _hwan_, íbeh,
   {{0x27e92d17,0x61e7023e,0x417400d1,0x00000000}},	//   _kwan_, _vwjl, وانس, --,
   {{0xd6bd00c7,0x44220063,0x657d91ee,0xb97c006e}},	//   _অভিয, _gpk_, _imsh, סנדי,
   {{0xdfce0080,0x68ed91ef,0x7bcb91f0,0xdb0a0037}},	//   ديو_, _lead, _rugu, _bhfí,
   {{0x7c2238c4,0x7bc391f1,0x59c617ff,0x7bcb00aa}},	//   _apor, _rinu, _रंगर, _sugu,
   {{0x7bcb0472,0x7bc391f2,0x7c2291f3,0x00000000}},	//   _pugu, _sinu, _bpor, --,
   {{0x7bc391f4,0x6ed8000d,0x9c2200c2,0x3f9c91f5}},	//   _pinu, नुहु, едыд, bovu_,
   {{0x59cf03a2,0x7c22080e,0xdcfb0880,0x7bcb7bdc}},	//   _संदर, _dpor, knuć, _vugu,
   {{0x27e991f6,0x7bc391f7,0x7c22063d,0x31ae0146}},	//   _awan_, _vinu, _epor, lýza_,
   {{0xbea800cd,0x68ed0a6c,0x50cb1376,0x7bcb91f8}},	//   _بهمن_, _cead, िशिष, _tugu,
   {{0x7bc391f9,0x8d7400bf,0x69c400aa,0xa3ab53b8}},	//   _tinu, _تالا, _viie, खता_,
   {{0x81e10f71,0x657d91fa,0x7c3b0079,0x2bc800c3}},	//   _দিন_, _amsh, mvur, रदरा,
   {{0x6d591114,0x68ed10f0,0xdcfb0ca7,0x27e90bb6}},	//   _kowa, _fead, gnuć, _ewan_,
   {{0x60c97246,0x3f9c0fbd,0x442291fb,0x68ed91fc}},	//   _ngem, zovu_, _ppk_, _gead,
   {{0x6d59083e,0x291202a4,0xa2be0469,0x27e991fd}},	// [9c60] _mowa, _icya_, वेन्, _gwan_,
   {{0x083b0054,0x442291fe,0x6d592822,0x60c991ff}},	//   _פעיל, _vpk_, _lowa, _agem,
   {{0xb6a30257,0xa75b00ca,0x00000000,0x00000000}},	//   éâtr, _הדיר, --, --,
   {{0x6d599200,0x68ed0042,0x4fc62b08,0x6b815568}},	//   _nowa, _xead, пска, hilg,
   {{0xdbd105fe,0xea000023,0x8fa62d06,0xd00700d3}},	//   qüèn, _trầy_, паде, зече_,
   {{0x60c90233,0x00000000,0x00000000,0x00000000}},	//   _egem, --, --, --,
   {{0x7d1b9201,0x2cc101d4,0x6d590172,0x644300e8}},	//   ffus, ərdə_, _bowa, ānie,
   {{0x3f9c0542,0x6b810080,0x7d7800e3,0x2fc501ec}},	//   sovu_, eilg, تمبر_, _eilg_,
   {{0x68ed0054,0x6d599202,0xdcfb02ef,0x69d502c6}},	//   _read, _dowa, znuć, ízen,
   {{0x68ed9203,0x2fc500e7,0x27e99204,0x60c902ef}},	//   _sead, _gilg_, _rwan_, _zgem,
   {{0x68ed9205,0x799d024a,0xb4db01ec,0x7edb00ca}},	//   _pead, tosw, _snàm, _הקבצ,
   {{0x7c2216a2,0x27e902f1,0x4d760e27,0x00000000}},	//   _tpor, _pwan_, _عطار, --,
   {{0x7c229206,0x6b816b1f,0x260f50da,0x68ed0131}},	//   _upor, bilg, तूनी_, _vead,
   {{0xc7c40084,0x6d599207,0xb9042fbd,0x68e0020e}},	//   есси, _zowa, _प्_, ımda,
   {{0x68ed0006,0x356b1312,0x3a3a0103,0x6d59083e}},	//   _tead, бран_, _épp_, _yowa,
   {{0x27e92c64,0xc87f042c,0x00000000,0x00000000}},	//   _twan_, faßt_, --, --,
   {{0x94ab34ca,0xdcfb1912,0x27e90d2a,0x399901f9}},	// [9c70] ства_, snuć, _uwan_, kész_,
   {{0x3dc60063,0x7d030139,0x6e2d007f,0x00000000}},	//   _liow_, _kìrà, łabi, --,
   {{0x35b5448a,0xddcb0218,0xe69500ae,0x39492059}},	//   _обор, _žiži, _цины, _knas_,
   {{0x6b819208,0x657d0201,0x2ca600d1,0x92b40076}},	//   zilg, _umsh, _oyod_, رحلا,
   {{0x6d5909f0,0x26170131,0x3ea517a5,0x00000000}},	//   _rowa, lço_, _sylt_, --,
   {{0x6d599209,0x25a9920a,0x96180018,0xbea50396}},	//   _sowa, llal_, _بغیر_, малк,
   {{0x2617920b,0x6d590034,0x6b81920c,0x7d1b920d}},	//   nço_, _powa, vilg, tfus,
   {{0x61fa0088,0x5f770018,0x60c90113,0x1c452917}},	//   _ætla, _کارر, _ugem, дним,
   {{0x6b81329c,0xd6c50081,0x2fc501b9,0x7d1b0632}},	//   tilg, ্রিয, _tilg_, rfus,
   {{0x7d030065,0x7c3b0ac9,0x2ca605aa,0x7f5a0113}},	//   _bìrà, rvur, _dyod_, _gotq,
   {{0x6d590fc9,0x7d1b05bd,0x6e6700c2,0x25a9920e}},	//   _towa, pfus, _этаж, klal_,
   {{0x37e20033,0x6b8112fa,0xf76900ca,0x3949044c}},	//   _বিবর, silg, _דק_, _cnas_,
   {{0x02aa17ff,0x59cf048a,0x2ca60270,0xb8d6009f}},	//   _कर्न, _संवर, _gyod_, _झर_,
   {{0x6b81009e,0x3ea0020a,0x48de0285,0x394907ee}},	//   qilg, şite_, _क्रो_, _enas_,
   {{0x6372052f,0xe5a6484c,0x46a300e5,0x2d8d6221}},	//   _hæng, диви, варв, onee_,
   {{0xdb1802fd,0x2d8d920f,0x66019210,0x2d9f2bc7}},	//   _eivä, nnee_, álka, noue_,
   {{0xe73a1102,0xfc4a003e,0xd6cf0018,0x00000000}},	// [9c80] _деп_, mtíð_, اقہ_, --,
   {{0x394903ce,0x6372052f,0x316d05aa,0x91e60c79}},	//   _znas_, _mæng, _alez_, доже,
   {{0x63720021,0x399901f9,0x2176037e,0xa2b30a50}},	//   _læng, vész_, мудр, _अरण्,
   {{0x6e3c1f84,0xfc4a01ab,0x290f0212,0x00000000}},	//   _árbi, ntíð_, _ögat_, --,
   {{0xdfcf0c5e,0x62950063,0x25a00036,0x92c00033}},	//   لين_, _exzo, moil_, ীরে_,
   {{0x26d89211,0x3dc60063,0x6d5d0212,0x00000000}},	//   ncro_, _siow_, ösan, --,
   {{0x63600018,0x216a085f,0x399901f9,0x00000000}},	//   _dönt, _диви_, rész_, --,
   {{0x2d8d9212,0xdb030503,0x00000000,0x00000000}},	//   gnee_, _ghnú, --, --,
   {{0x657a014b,0xae0200aa,0x00000000,0x00000000}},	//   éthy, रूजन_, --, --,
   {{0x6eb60308,0xdb0a0076,0x00000000,0x00000000}},	//   _قصائ, _bhfá, --, --,
   {{0xc3337c04,0x25a09213,0xdb180ec9,0x2d9f057a}},	//   דות_, koil_, _nivå, boue_,
   {{0x6372052f,0x63600212,0x8f0e0835,0x2d9f014b}},	//   _fæng, _köns, _साँझ_, coue_,
   {{0x63609214,0xd83800d3,0x2905008b,0xa3c03ec9}},	//   _yönt, мэр_, ğla_, ुदा_,
   {{0x2d849215,0x63600149,0x29050511,0x00000000}},	//   lime_, _möns, şla_, --,
   {{0x63600212,0x637202b6,0x00000000,0x00000000}},	//   _löns, _mænd, --, --,
   {{0x26170396,0x2d843610,0x394914e2,0x20060052}},	//   rço_, nime_, _unas_, kroi_,
   {{0x36d53164,0xc3130065,0x8afe03e3,0x8f0e0557}},	// [9c90] _попр, _ajíṣ, _alƙi, _सांझ_,
   {{0x25a9134c,0x20069216,0x316d007e,0x2d849217}},	//   slal_, droi_, _slez_, hime_,
   {{0x2d849218,0x2d8d7d23,0xe7eb02d5,0x00000000}},	//   kime_, ynee_, जीरा_, --,
   {{0x37e20081,0x2d849219,0x25a976cd,0x25a01224}},	//   _বিতর, jime_, qlal_, coil_,
   {{0x752d002d,0x2d84921a,0x63602e7e,0x6372003e}},	//   meaz, dime_, _pönt, _bænd,
   {{0x752d002d,0x2d840072,0x6360921b,0x628100d2}},	//   leaz, eime_, _döns, _žlou,
   {{0x69ca0b7f,0x6da53528,0xdb0301ec,0xbea2107a}},	//   _संगी, ника, _ghnù, лашк,
   {{0x752d002d,0x2d84921c,0x63600222,0x3dde0124}},	//   neaz, gime_, _föns, _dttw_,
   {{0xa2d605a5,0x7e9900cd,0x2d9f057a,0xb4db01ec}},	//   मुक्, _کنار_, roue_, _cnài,
   {{0xdbdc0088,0x752d00ae,0x00000000,0x00000000}},	//   ráðh, heaz, --, --,
   {{0x2d84921d,0xd910015a,0xdea10018,0x656f02cb}},	//   bime_, لیغ_, _حیثی, _olch,
   {{0x5c751312,0x752d00d3,0xbf1b02d5,0x25a00063}},	//   _плет, jeaz, प्रभ_, xoil_,
   {{0x6d4b921e,0xeb8e1a57,0xec6e1a77,0x60db0010}},	//   _inga, _би_, _сп_, _mfum,
   {{0x907a00ca,0x3f79006e,0x75dc0154,0x207a2252}},	//   לטרי, לאָס, _lčze, לארא,
   {{0x69ce46b4,0x60db0b07,0x25a0921f,0x752d020a}},	//   íbet, _ofum, toil_, feaz,
   {{0x7dc70018,0x6d4b0085,0x60db0361,0xc6c30138}},	//   _műso, _jnga, _nfum, уйск,
   {{0x2fdf006c,0x656f009c,0x6d4b101e,0x290001ff}},	// [9ca0] _ntug_, _dlch, _mnga, _idia_,
   {{0x60db9220,0x27e0013f,0x25a09221,0x79869222}},	//   _afum, _itin_, soil_, likw,
   {{0x6d4b9223,0x752d044c,0x0cac1462,0x00000000}},	//   _onga, beaz, _चर्म, --,
   {{0x2d8464dd,0x79869224,0x59b23aee,0x20069225}},	//   xime_, nikw, ीगिर, troi_,
   {{0x40340d5e,0x2d840da2,0xa0670284,0x00000000}},	//   телс, vime_, наца_, --,
   {{0x6d4b9226,0x60db2721,0x2006293c,0xa2d60b2b}},	//   _anga, _efum, rroi_, मुख्,
   {{0xe2970e2c,0x290052fa,0xa3c932ec,0x6d4b009c}},	//   _зар_, _odia_, _लूट_, _bnga,
   {{0x29000129,0x5bc80be4,0x6da31fdb,0x79860239}},	//   _ndia_, रद्व, лија, jikw,
   {{0x6d4b02e7,0x6372052f,0x79865fa7,0x44320150}},	//   _dnga, _tænd, dikw, nwy_,
   {{0x2d849227,0x5c731211,0x752d002d,0x6d4b33ba}},	//   sime_, ульт, zeaz, _enga,
   {{0x27e000a6,0x7e9a0867,0x2a6a0103,0x661c033b}},	//   _atin_, _عنصر_, ább_, jtrk,
   {{0x67d51f65,0x752d00ae,0xdb010131,0x00000000}},	//   кому, xeaz, nolê, --,
   {{0x752d00d3,0x38c90281,0xb87b1515,0x48ab3c75}},	//   veaz, بادی_, mbík, ятом_,
   {{0x443202ad,0x66010018,0xb1130134,0x69ce002b}},	//   dwy_, álko, pụgh, íbes,
   {{0x79a786dc,0x752d45c0,0x79865f28,0xb8d70033}},	//   _прие, teaz, bikw, _জল_,
   {{0x5558008f,0x7bca0079,0xa3c902d5,0xe53404d9}},	//   нася_, _hifu, _लूज_, лесь,
   {{0x752d0012,0x7bca9228,0x6aaa02ad,0xa2be0592}},	// [9cb0] reaz, _kifu, _hyff, वेस्,
   {{0x752d002d,0x60db9229,0x7bca0051,0x00000000}},	//   seaz, _sfum, _jifu, --,
   {{0x752d00ac,0x7bca0010,0x61fc0a39,0x61ee00f0}},	//   peaz, _mifu, _cvrl, _cwbl,
   {{0x7ff50177,0xb4db015e,0x25870139,0x7bca922a}},	//   نستا, _anàv, _dìlè_, _lifu,
   {{0xc4280002,0xfbe700fe,0xd5640152,0x6aaa03a8}},	//   _пюре_, _chế_, _стэп, _lyff,
   {{0x6d4b005c,0x7986922b,0x7bca6939,0x15e80285}},	//   _snga, zikw, _nifu, टीकर_,
   {{0x6d4b005c,0xed59922c,0x61ee00f0,0x00000000}},	//   _pnga, дой_, _gwbl, --,
   {{0x92e900c7,0x60db0051,0xf1a47ba6,0x7bca0350}},	//   _যায়_, _ufum, _брун, _aifu,
   {{0x7bca0198,0x5bb528f1,0x69cb3344,0x7dd500bd}},	//   _bifu, ксоф, _संजी, _iġsm,
   {{0x4a4509fe,0x200f922d,0x0b4201b3,0xdcf10233}},	//   внов, mugi_, аньн, ıgın,
   {{0x3f87922e,0x200f2e9b,0x6aaa02ad,0x7986922f}},	//   minu_, lugi_, _cyff, tikw,
   {{0x3f877925,0x6d4b211a,0x212f00e7,0x69dc0076}},	//   linu_, _unga, negh_, írea,
   {{0x8d7433ce,0x79862073,0x8afe0044,0xdb010076}},	//   _حالا, rikw, _alƙu, allá,
   {{0x79869230,0x7bca012d,0x6aaa01b9,0x59cf00c3}},	//   sikw, _gifu, _fyff, _सूअर,
   {{0x6aaa0150,0x200f2e17,0x79860a4b,0x3ea903e3}},	//   _gyff, hugi_, pikw, ƙatu_,
   {{0x1614000f,0x7bca2824,0x44320034,0x29000174}},	//   तंबर_, _zifu, twy_, _udia_,
   {{0xccf20105,0xf77300cd,0x3f879231,0x7bca2767}},	// [9cc0] יכן_, _چاپ_, kinu_, _yifu,
   {{0x443221a6,0x200f007a,0xc88701bf,0x31ca1da8}},	//   rwy_, dugi_, ößer_, िद्ध,
   {{0x3f870335,0xf50603fc,0x7ae5007a,0x00000000}},	//   dinu_, _изно, _õhtu, --,
   {{0xcfe600c7,0xb816382d,0x4a5a00a1,0x200f2f73}},	//   _নিবন, _तमाम_, ודעו, fugi_,
   {{0x69cb030b,0x3f87003e,0x200f00bc,0x6b83039f}},	//   _संघी, finu_, gugi_, _omng,
   {{0x3f870088,0x6e940d62,0xa2e3037e,0xa0670284}},	//   ginu_, лилу, _ворд, ђаја_,
   {{0x6e280abd,0x7bca0faf,0xa2be1e05,0xdb0100b3}},	//   _qpdb, _rifu, वेश्, molè,
   {{0x7bca9232,0xfbe70023,0xc5f300ca,0x6b83063d}},	//   _sifu, _thế_, בדה_, _amng,
   {{0x3f870039,0x10a614fb,0x711b00ca,0x00000000}},	//   binu_, _риан, _קומפ, --,
   {{0x3f8700cc,0x64460095,0x3d140d75,0xdb0100b3}},	//   cinu_, _mrki, _धावे_, nolè,
   {{0x7bca0051,0x00000000,0x00000000,0x00000000}},	//   _vifu, --, --, --,
   {{0xfce68561,0x64467694,0x79840167,0x6b830372}},	//   _родо, _orki, _cmiw, _emng,
   {{0x7d029233,0xb4db01b9,0xdb0101dc,0x00000000}},	//   _idos, _mnàt, kolè, --,
   {{0x257501df,0x79840361,0xc3080033,0x00000000}},	//   _måle_, _emiw, র্তি_, --,
   {{0x64469234,0xfbb700ca,0xdb0100b3,0x200f0079}},	//   _arki, _שפות_, dolè, zugi_,
   {{0x6446015c,0x39152ff8,0x81e10081,0x69cb1677}},	//   _brki, _смир, _দিল_, _सूची,
   {{0x95c81dc6,0xb1130129,0x4993001c,0xf8bf014b}},	// [9cd0] тура_, hụch, _میگر, ffée_,
   {{0xdb019235,0x47350a99,0x64460357,0x2575320e}},	//   golè, _снос, _drki, _såld_,
   {{0x3f8700e9,0x64469236,0x7d020181,0x3eac0537}},	//   vinu_, _erki, _odos, _nydt_,
   {{0x7d0200dd,0x644600e7,0x200f9237,0x78ad083e}},	//   _ndos, _frki, tugi_, _kyav,
   {{0x3f879238,0x25750149,0xdce200cb,0x6446007e}},	//   tinu_, _våld_, _zloć, _grki,
   {{0x753d00fb,0xa2be0789,0x7d029239,0xe816074c}},	//   _hasz, _वृक्, _ados, _तमसा_,
   {{0x4439923a,0x753d2214,0x200f923b,0x78ad0172}},	//   _hss_, _kasz, sugi_, _lyav,
   {{0x3f877925,0x229400d6,0x644601ab,0xdb01923c}},	//   sinu_, _тися, _yrki, molé,
   {{0x51841b4b,0xcfab0068,0x753d472c,0x69dc0220}},	//   _тура, _قائم_, _masz, íren,
   {{0x44393acc,0x753d2bd6,0x7d02923d,0x75dc0154}},	//   _mss_, _lasz, _edos, _lčza,
   {{0x443912d2,0x198a30cc,0x656d030c,0x78ad1c64}},	//   _lss_, ебни_, kkah, _ayav,
   {{0x753d0d1b,0x44390572,0x78ad8b97,0x00000000}},	//   _nasz, _oss_, _byav, --,
   {{0x291e0034,0x63a509a4,0xa2aa0096,0x78ad05bd}},	//   ęta_, kohn, _जुन्, _cyav,
   {{0x6b830201,0xdce20357,0x00000000,0x00000000}},	//   _umng, _ploć, --, --,
   {{0x63a5923e,0x656d02e7,0x4439923f,0x7bc101bf}},	//   dohn, fkah, _ass_, mmlu,
   {{0x6d5b06ee,0x656d2846,0x442b44c4,0x79849240}},	//   njua, gkah, _bpc_, _umiw,
   {{0x44399241,0x032600ae,0xe3ba33a2,0x9f4f0088}},	// [9ce0] _css_, лдан, еба_, yrgð_,
   {{0x68f60092,0x442b9242,0x644600c4,0xb4db01ec}},	//   _heyd, _dpc_, _vrki, _snàt,
   {{0x61463a60,0x471b00c1,0x68f60188,0x753d9243}},	//   лежа, _אויג, _keyd, _fasz,
   {{0x44399244,0x673e627d,0xdb011b59,0x7c2b724b}},	//   _fss_, _hapj, solè, _opgr,
   {{0x68f617bd,0x6d5b302f,0x64466510,0x673e9245}},	//   _meyd, djua, _urki, _kapj,
   {{0x27f202ad,0x8fa361f2,0x753d007f,0x7d1900eb}},	//   _mwyn_, баче, _zasz, _acws,
   {{0x09cf00af,0x7c2b00d9,0x6b889246,0x64440f06}},	//   _संगठ, _apgr, vidg, lvii,
   {{0x44209247,0x6d5b023b,0x75249248,0x6b88033c}},	//   oti_, gjua, nfiz, widg,
   {{0x44209249,0x61fe924a,0x25db00c3,0x0b8a1a6d}},	//   nti_, lspl, _खूनी_, есни_,
   {{0x4420924b,0x673e0018,0xf0630291,0xb1130134}},	//   iti_, _napj, _укуп, pụch,
   {{0x442008a3,0xdd8f1e49,0x8afe01c2,0xa2aa030b}},	//   hti_, _کون_, _noƙe, _जुम्,
   {{0x7d0200a5,0xddb60018,0x61fe09ec,0x68f68643}},	//   _udos, _صحاب, ispl, _ceyd,
   {{0x4420924c,0x68f6612f,0x27f20178,0x67d51cf2}},	//   jti_, _deyd, _cwyn_, рогу,
   {{0x4439924d,0x78ad0169,0xdceb01d3,0x27f200f0}},	//   _rss_, _vyav, _ilgā, _dwyn_,
   {{0x4420924e,0x7afa02fd,0xd5bb14fb,0xaadb00ca}},	//   eti_, matt, еса_, _אחור,
   {{0x44207001,0x61fe17d2,0x63a501bf,0xb4db00b3}},	//   fti_, dspl, wohn, _anàr,
   {{0x656d42b2,0x44208215,0x442b03be,0xdb030037}},	// [9cf0] rkah, gti_, _qpc_, _ghnó,
   {{0x443908a9,0x2d810018,0x7afa924f,0x753d0034}},	//   _vss_, éhez_, natt, _wasz,
   {{0x44209250,0x7afa028d,0x44390381,0x64446656}},	//   ati_, iatt, _wss_, avii,
   {{0x7afa9251,0x673e053f,0x44209252,0xdb0100d8}},	//   hatt, _zapj, bti_, rolé,
   {{0x44209253,0xb97c0130,0x442b9254,0x7afa3caa}},	//   cti_, ענדי, _upc_, katt,
   {{0x6d470029,0xa06616a1,0x7afa9255,0xdb0106ad}},	//   ējam, раша_, jatt, polé,
   {{0x7afa6b74,0xff040bd5,0x539a0796,0xb87b0072}},	//   datt, сячн, _יישו, ncíb,
   {{0x63bc0206,0x5187038f,0x00000000,0x00000000}},	//   _zhrn, _суга, --, --,
   {{0x6d5b10dd,0x2363023e,0x28c70179,0x2d860383}},	//   rjua, _kojj_, रेमि, _dmoe_,
   {{0x7afa9256,0xf53f1842,0x5ec70033,0x2d8602ac}},	//   gatt, _skål_, রুষে, _emoe_,
   {{0x44209257,0xd5b506eb,0x491a00aa,0x7bc1093e}},	//   zti_, ंताज, _भादो_, rmlu,
   {{0x44209258,0x213f06ee,0x68f60253,0x186a249c}},	//   yti_, _jauh_, _qeyd, вами_,
   {{0x7afa17d2,0x290c0491,0x44202ce7,0x7c2b62f4}},	//   batt, ğda_, xti_, _upgr,
   {{0xcb66327e,0x68f60694,0x7afa008f,0x213f005c}},	//   _ваше_, _weyd, catt, _lauh_,
   {{0x24f61a57,0x671702d5,0x96631824,0x68f6363c}},	//   ичар, _तारक_, окре, _teyd,
   {{0x44208b3f,0xdb03009c,0x63bc02c6,0x00000000}},	//   tti_, _ghnò, _shrn, --,
   {{0x442087c6,0x6386016d,0x31bc030b,0x691e033b}},	// [9d00] uti_, агаа, níze_, _všeč,
   {{0x44200213,0x39400d7d,0x61fe17a5,0x64445460}},	//   rti_, _hais_, tspl, rvii,
   {{0x201f9259,0x4aab007d,0x3940925a,0x64440329}},	//   _aqui_, _घुमव, _kais_, svii,
   {{0x61fe0bad,0x39403b62,0xf1a9001c,0x50660231}},	//   rspl, _jais_, هانه_, итла,
   {{0x394014b8,0x61fe925b,0x44200188,0x7afa026a}},	//   _mais_, sspl, qti_, yatt,
   {{0x3940925c,0x9e065912,0x42e70396,0x26cc0e51}},	//   _lais_, ачил, _вмро_, ždou_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5d542de0,0x3940925d,0x644300a5,0xe297007e}},	//   скит, _nais_, łnie, _тас_,
   {{0x7afa925e,0x6d405d6e,0xc8a50285,0x00000000}},	//   tatt, rdma, _गुंट, --,
   {{0x395216c8,0x7b6626be,0x81c40129,0x25752452}},	//   _anys_, ртие, _ịchọ_, _måla_,
   {{0x7afa925f,0x39406b6a,0x28f93c91,0xb87b02c6}},	//   ratt, _bais_, лень_, kcíc,
   {{0x644901b3,0x7afa0e9f,0x39409260,0xcc87001c}},	//   _šeim, satt, _cais_, انیه_,
   {{0x39409261,0x7afa60a4,0xc8649262,0x7bdb008c}},	//   _dais_, patt, отри, cquu,
   {{0x7afa00bd,0x3ea900ae,0xd7f80ab3,0x05db0285}},	//   qatt, şate_, шую_, _मंदब,
   {{0x3940025a,0xe8d90129,0xf1bf0031,0x31ae0094}},	//   _fais_, _amụ_, žšia_, lýzu_,
   {{0xda5b0054,0x69d88315,0x39409263,0x224d14f3}},	//   _יכול, _iuve, _gais_, _ček_,
   {{0x68fd9264,0x54b9055b,0x7af8023e,0xd83b00d3}},	// [9d10] masd, угая_, _kevt, _рэй_,
   {{0x69d89265,0x28c700a5,0x68fd9266,0xddce0220}},	//   _kuve, रेणि, lasd, ždňo,
   {{0x213f061d,0x39520150,0x3940023e,0x637b020a}},	//   _pauh_, _ynys_, _yais_, _lîng,
   {{0x29191084,0x69d81474,0x68fd9267,0x3940006c}},	//   ngsa_, _muve, nasd, _xais_,
   {{0xdee501a0,0x69d89268,0x5045001f,0x66150062}},	//   боли, _luve, селб, luzk,
   {{0x69d8025a,0x543a00c1,0x7af89269,0x00000000}},	//   _ouve, _געשא, _nevt, --,
   {{0x69d809ea,0x81e10033,0x92582503,0x3e330103}},	//   _nuve, _দিক_, _карт_, تہار,
   {{0x069800ca,0x00000000,0x00000000,0x00000000}},	//   ידום_, --, --, --,
   {{0x39401ee3,0x69d800fd,0x68fd926a,0x201f0072}},	//   _rais_, _auve, dasd, _uqui_,
   {{0x4ea70f30,0x3940926b,0xa2be0469,0x69d8926c}},	//   _креа, _sais_, वेक्, _buve,
   {{0x3940768c,0xa96a188d,0xd9460e1b,0xfaa51cbb}},	//   _pais_, гина_, бени, сано,
   {{0x3940005c,0xdd8f0281,0x200f0036,0x7f41926d}},	//   _qais_, _کوچ_, orgi_, _halq,
   {{0x3940926e,0xab290d62,0xb900045f,0x9cda00c1}},	//   _vais_, _бола_, _तल_, _עקספ,
   {{0x7777002b,0x394000f9,0x66e34ef9,0xdb180131}},	//   _clxx, _wais_, зора, _divó,
   {{0x394001bb,0x69d839ab,0xa50a463e,0x26182235}},	//   _tais_, _guve, лева_, बंधी_,
   {{0x7bd91a05,0x25a90036,0x68fd59f8,0x394001ec}},	//   _kuwu, goal_, casd, _uais_,
   {{0xb87b926f,0x69d801bf,0x7bd901c2,0xdb01037a}},	// [9d20] rcíc, _zuve, _juwu, holí,
   {{0x26180455,0x46f61165,0x8afe01c2,0x7bd9083e}},	//   बंदी_, _учит, _koƙa, _muwu,
   {{0x69d80933,0x7bd99270,0x86c600d1,0x00000000}},	//   _xuve, _luwu, _ديدن, --,
   {{0xdb015009,0xb87b0072,0x25a97676,0x00000000}},	//   dolí, lcía, coal_, --,
   {{0x7bd900cd,0x7f419271,0x68e40239,0x2d8d084e}},	//   _nuwu, _balq, _mfid, diee_,
   {{0x7f410933,0xb87b0610,0xb7db0142,0x637b078e}},	//   _calq, ncía, אקסי, _cînd,
   {{0x41b600cd,0x6146534d,0x63ae0063,0x24800052}},	//   _همسر, _лева, _ikbn, lzim_,
   {{0x656601c2,0x7bd910df,0x69d89272,0x7cd802a0}},	//   _jokh, _buwu, _ruve, шмир_,
   {{0x69d89273,0x26180251,0x656600dc,0x205619e8}},	//   _suve, बूती_, _mokh, _утвр,
   {{0x4f650080,0x6566067d,0x68e49274,0x7bd900d1}},	//   _والف, _lokh, _afid, _duwu,
   {{0x68e924c7,0x99990396,0xdb010072,0x2d8d0350}},	//   ñedo, икот_, colí, biee_,
   {{0x3f8e0010,0x65660060,0x61fa003e,0x5e57006e}},	//   lifu_, _nokh, _ætlu, _ליבע_,
   {{0x68fd9275,0xdb180383,0x7bd906b0,0x7af80141}},	//   rasd, _divò, _guwu, _tevt,
   {{0x7f4101d4,0x3f8e0010,0x661501e9,0x248000b6}},	//   _xalq, nifu_, tuzk, dzim_,
   {{0x65669276,0x68e400eb,0x00000000,0x00000000}},	//   _bokh, _ffid, --, --,
   {{0x661502a7,0x569442c7,0x59dd0096,0xdb08023b}},	//   ruzk, част, _नंतर, kodë,
   {{0xdd1c0146,0x98170fba,0xf99400ca,0x3f8e024a}},	// [9d30] kážk, _ابعا, _מרק_, kifu_,
   {{0x63600068,0x661502a7,0x27e90d79,0x25a9061d}},	//   _köny, puzk, _itan_, soal_,
   {{0xd2510037,0xa4d5004d,0xd9f80285,0x656601f9}},	//   بنا_, _моні, ंठित_, _fokh,
   {{0x798f0027,0xdb011f1d,0x3d14136b,0x00000000}},	//   nicw, volí, _धागे_, --,
   {{0x27e900ec,0x3e470023,0x1ee70470,0x3f8e0a4b}},	//   _jtan_, _sđt_, موشی_, fifu_,
   {{0x2d9a0018,0xdb0167e0,0x7bd90027,0x7f41026d}},	//   épen_, tolí, _ruwu, _qalq,
   {{0xdb18025b,0x7bd9001c,0x6d429277,0x171c006e}},	//   _chví, _suwu, _baoa, אווע,
   {{0xdb019278,0x637b00fd,0xcfe9001c,0x27e97c5f}},	//   rolí, _dîne, _نفره_, _otan_,
   {{0x1c421ad1,0x7f4100dc,0x3f8e0051,0x0b5904d9}},	//   дным, _talq, bifu_, арны_,
   {{0x68e49279,0x2909008c,0x31bc00d4,0x3d1b00a4}},	//   _sfid, _adaa_, míza_, _यावे_,
   {{0xeab100e3,0x6fe10081,0x27e9927a,0x31bc0094}},	//   بعة_, _নিয়ে, _atan_, líza_,
   {{0x3a980084,0x7bd9927b,0x38c40113,0x00000000}},	//   стью_, _tuwu, jèré_, --,
   {{0x65660449,0x2d9d0027,0xeb8e927c,0x7d1b0a4b}},	//   _rokh, _ijwe_, _жи_, mgus,
   {{0x7d1b007a,0x257c0037,0x7c3b0027,0x27e90154}},	//   lgus, _míle_, mwur, _dtan_,
   {{0x27e9927d,0x212d6fe4,0x7c3b10ef,0xb87b0143}},	//   _etan_, _obeh_, lwur, rcía,
   {{0x290c00c6,0x00000000,0x00000000,0x00000000}},	//   ėdas_, --, --, --,
   {{0xf74630fa,0x61e9033b,0x336602b7,0x7d1b743c}},	// [9d40] _депо, _čela, оваг, igus,
   {{0x25750149,0xb7d70260,0x3cff022e,0x212d0113}},	//   _håll_, _گویا_, hauv_, _abeh_,
   {{0xe0da72bd,0x052a00d3,0x656625d9,0x2b1c00b6}},	//   аве_, _конк_, _tokh, _मासु_,
   {{0x64430034,0x27e90212,0x66e00139,0x7c3b0294}},	//   łnia, _ytan_, _fàkó, kwur,
   {{0x3f8e927e,0x4fc60c2b,0xaaab009f,0x44243177}},	//   tifu_, оска, _घुसक, _ëm_,
   {{0x7d1b5da0,0x7c3b084e,0xb87b0094,0xdb0800b3}},	//   egus, dwur, kcín, codè,
   {{0xe2975f56,0xdd1c0146,0x3f8e927f,0x00000000}},	//   _дар_, rážk, rifu_, --,
   {{0x3f8e9280,0x7d1b9281,0x7176001c,0xdb08014b}},	//   sifu_, ggus, _بهرا, modé,
   {{0x7c3b0294,0xe8160336,0x3d1b00a3,0x00000000}},	//   gwur, _तमगा_, _यारे_, --,
   {{0xe4570130,0xee0a00ae,0x8afc007f,0x7d1b2f27}},	//   קייט_, _вежл_, djęc, agus,
   {{0x798f7a56,0x1f5900d3,0x27e90133,0x7a3700d3}},	//   ticw, _ушть_, _stan_, опэр_,
   {{0x637202b6,0xed57061b,0x7c3b0027,0x00000000}},	//   _bænk, _мох_, bwur, --,
   {{0x7dd5013f,0x798f9282,0x00000000,0x00000000}},	//   _išsa, ricw, --, --,
   {{0x7d009283,0x28c70469,0x798f039f,0xdb0100b3}},	//   lams, रेषि, sicw, colà,
   {{0xb7bb016d,0x555900e5,0x5bc30076,0xfb870d83}},	//   stão, бавя_, _تقول, _بدنی,
   {{0x7d009284,0x27e90062,0x00000000,0x00000000}},	//   nams, _ttan_, --, --,
   {{0x27e91e81,0x43070076,0x00000000,0x00000000}},	// [9d50] _utan_, قذاف, --, --,
   {{0x97150ae3,0xa49b01b9,0x7d1b5d47,0x6b9a042c}},	//   _эмоц, _leòg, zgus, nntg,
   {{0x28c70354,0x7d009285,0x7d1b026a,0x257c9286}},	//   रेरि, kams, ygus, _síle_,
   {{0xf55900e3,0x7bc8005c,0x7d0009ac,0x36340421}},	//   _الحب_, hmdu, jams, _کریس,
   {{0xdee50ebf,0xdb010076,0xdbd600ce,0x00000000}},	//   поли, holá, nään, --,
   {{0xdb0110a8,0xd7ab049d,0xd0060636,0xa5d800d1}},	//   kolá, चकिच, чеше_, _دبیر_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c3b9287,0x7d1b0138,0x7d00070e,0xdbd64638}},	//   twur, ugus, gams, kään,
   {{0x7d1b9288,0xdbd600aa,0xa49b009c,0xd01113c3}},	//   rgus, jään, _deòg, _سلا_,
   {{0x798d0283,0x547c00a1,0x3cff023e,0x644f1fce}},	//   _amaw, יטחו, sauv_, _mrci,
   {{0x2b1c04a9,0xd9469289,0x637202b6,0xdb010103}},	//   _मारु_, пени, _sænk, golá,
   {{0xac190963,0xaca30294,0xdb0a00e3,0xfd640174}},	//   _году_, _ahụk, _bhfó, _mawụ,
   {{0x5ed00081,0xdce20095,0xf2b800b6,0x02b80d61}},	//   _স্পে, _glođ, _अर्घ, _अर्न,
   {{0xc3110033,0x798d395b,0xa2cc0285,0x8c421e11}},	//   স্তি_, _emaw, थेड्, _чеше,
   {{0xdb014c36,0xa49b01b5,0x2d7f007f,0xfbd00113}},	//   colá, _leòd, ałeś_, _شته_,
   {{0x637201c5,0x18a6097a,0x06ab0081,0x644f00e7}},	//   _tænk, _найм, _গৃহি, _brci,
   {{0x29025298,0xd5af04f4,0x9f5f00b3,0x38c80281}},	// [9d60] maka_, افق_, _avuí_, _باغی_,
   {{0x29023eb4,0x04fc0081,0x6e2d0034,0xdb08014b}},	//   laka_, ইলের_, łaby, todé,
   {{0x7dc50610,0xdce2033b,0x7d000601,0x11d6001c}},	//   mósf, _sooč, yams, ستاد,
   {{0xe5a608d8,0x69d605e3,0xa3e40789,0xe7c00096}},	//   _хими, _jiye, _पंप_, _शीतप,
   {{0x69d67685,0x26180251,0x644f14f3,0xdb010103}},	//   _miye, बूरी_, _grci, zolá,
   {{0x29023223,0x8afe0022,0x69d6928a,0x78b600ce}},	//   haka_, _roƙo, _liye, _myyv,
   {{0x2902928b,0x7d005ee1,0x69c401c8,0x6fb60103}},	//   kaka_, tams, _ohie, _ہمرا,
   {{0x290228be,0x69c40019,0xdb010579,0x7bc37dae}},	//   jaka_, _nhie, volá, _ahnu,
   {{0x321a0146,0x5ea60281,0xa49b009c,0x00000000}},	//   lupy_, _کمال, _geòd, --,
   {{0xfc2f33c6,0x69d60af0,0x7d00928c,0xd9b73ec9}},	//   احي_, _aiye, sams, ृष्ट,
   {{0x2902555a,0x69d68709,0xdb180146,0x69c4009c}},	//   faka_, _biye, _chvá, _bhie,
   {{0x644a00d9,0x69c4188c,0xdc2a00cd,0x0dca00d3}},	//   āfij, _chie, _هسته_, _улей_,
   {{0x69d6928d,0x6c34015a,0x69c40167,0xdb010103}},	//   _diye, _آفتا, _dhie, solá,
   {{0x321a1799,0x69d60139,0xb87b0037,0xdb012e16}},	//   kupy_, _eiye, scío, polá,
   {{0x2902928e,0xc6a40dc9,0x644f015c,0x69d60135}},	//   baka_, ерти, _srci, _fiye,
   {{0x798d928f,0xdbd60084,0x20069290,0x69c49143}},	//   _umaw, sään, ksoi_, _ghie,
   {{0x245800c2,0x2bdf00c3,0x03d507bf,0x3f9c010a}},	// [9d70] пать_, नदया, джаю, knvu_,
   {{0xa87c00a1,0x6443007f,0xd25b01b3,0xa49b01b9}},	//   _לאחר, łnio, йце_, _reòd,
   {{0x32070068,0x69d68151,0x799d281c,0x00000000}},	//   ény_, _yiye, onsw, --,
   {{0x63730b88,0x3f9c010a,0x637b00fc,0x00000000}},	//   _sını, envu_, _dîna, --,
   {{0xb4d940c1,0x644f0244,0x3dde009c,0xd00900d3}},	//   ाशी_, _urci, _autw_, целе_,
   {{0x44299291,0x644d50cd,0x00000000,0x00000000}},	//   mta_, mvai, --, --,
   {{0x29027429,0xc33200c1,0xee3900d6,0x644d9292}},	//   yaka_, _שול_, іни_, lvai,
   {{0x44299293,0xd65800a1,0xdea4010d,0x29023c7f}},	//   ota_, ליות_, رینی, xaka_,
   {{0x2d83013f,0x644d1c14,0x69c40150,0x60db2885}},	//   ėje_, nvai, _rhie, _igum,
   {{0x44290e1d,0x29022bf4,0x69d69294,0x69c40158}},	//   ita_, waka_, _siye, _shie,
   {{0x29029295,0x44299296,0x62851d51,0x69d63d4a}},	//   taka_, hta_, nzho, _piye,
   {{0x44290b6a,0x2cae0174,0xdde900d1,0x00000000}},	//   kta_, ịmị_, _هرچه_, --,
   {{0x29029297,0x3b095fdd,0x60db0239,0x8c4503f2}},	//   raka_, _дело_, _mgum, _целе,
   {{0x44299298,0x6f039299,0x6d4902a7,0x657d0188}},	//   dta_, nanc, ldea, _alsh,
   {{0x2902929a,0x60db083e,0x2fdf0124,0x69d60c23}},	//   paka_, _ogum, _luug_, _tiye,
   {{0x6d49929b,0x60db0ad9,0x44290902,0x78a4022e}},	//   ndea, _ngum, fta_, _txiv,
   {{0x4429929c,0x6d49003b,0x65640808,0xf9c712eb}},	// [9d80] gta_, idea, rjih, _تحوی,
   {{0x7c29091f,0x6d4982ca,0x60db26d3,0x321a0146}},	//   iter, hdea, _agum, tupy_,
   {{0x4429929d,0x7c29929e,0x673c1898,0xa6ca110a}},	//   ata_, hter, merj, _گوگل_,
   {{0x27e00d64,0x4429929f,0x661c92a0,0x673c92a1}},	//   _kuin_, bta_, murk, lerj,
   {{0x44291c40,0x27e004ea,0x661c0991,0x2900001f}},	//   cta_, _juin_, lurk, _meia_,
   {{0x6d5992a2,0x6f0392a3,0x673c92a4,0x290092a5}},	//   _anwa, ganc, nerj, _leia_,
   {{0x7c297980,0x2006028d,0x27e0007b,0xda0906e4}},	//   eter, ssoi_, _luin_, _विगत_,
   {{0x7c2992a6,0x27ed00ae,0x60db06b0,0x673c56b2}},	//   fter, ţeni_, _ggum, herj,
   {{0x673c2c09,0x7c2992a7,0x2b4792a8,0x6f0343ad}},	//   kerj, gter, _banc_, banc,
   {{0x6f032d5d,0x2d980018,0x661c92a9,0x2b476496}},	//   canc, őre_, kurk, _canc_,
   {{0x442992aa,0xaa58108f,0x661c92ab,0x7f5a02a1}},	//   zta_, чину_, jurk, _intq,
   {{0xaca40129,0x6d600146,0x661c92ac,0x27e092ad}},	//   _akụz, ávač, durk, _buin_,
   {{0x44297148,0x2900627e,0xdb080610,0x27e001f7}},	//   xta_, _deia_, lodí, _cuin_,
   {{0x27e092ae,0x673c92af,0xe8e00023,0x3f89014b}},	//   _duin_, gerj, _muội_, éaux_,
   {{0x67d416fa,0x79a72dd1,0x29004d6e,0x356b03b0}},	//   тору, _орие, _feia_, оран_,
   {{0x29ee01c2,0x62850117,0xb4d900a4,0x257c1137}},	//   mƙa_, vzho, ाशे_, _píla_,
   {{0x673c92b0,0x442992b1,0x6f0392b2,0x7bd86586}},	// [9d90] berj, uta_, yanc, _kivu,
   {{0x661c50ef,0x752d92b3,0x644d92b4,0xdce20090}},	//   burk, sfaz, rvai, _fmoħ,
   {{0x7c2936f6,0x644d92b5,0x39497a7b,0x6d4901af}},	//   zter, svai, _kaas_, ydea,
   {{0x442992b6,0x6f0392b7,0x7645023f,0xf9d900c1}},	//   pta_, wanc, _ishy, פֿעל,
   {{0x394992b8,0x06f30bd9,0x442992b9,0x7c29201a}},	//   _maas_, _अभाव_, qta_, xter,
   {{0xa3e40789,0x70520f43,0x39493cbc,0x7bd87d71}},	//   _पंत_, انوا, _laas_, _nivu,
   {{0x6d4962b9,0xa49b01b9,0x2b47009c,0x7f48041c}},	//   tdea, _feòc, _ranc_, _dadq,
   {{0x6f0392ba,0x7c290dfc,0x1c4592bb,0x394992bc}},	//   sanc, tter, еним, _naas_,
   {{0x7c2992bd,0xfc480019,0x3dc6008a,0x7bd80193}},	//   uter, _cử_, _dhow_, _bivu,
   {{0x6d490441,0x61e90660,0x290000f3,0x3dc692be}},	//   sdea, _čelj, _seia_, _ehow_,
   {{0x673c92bf,0x7bd892c0,0x39493beb,0x76450193}},	//   verj, _divu, _baas_, _nshy,
   {{0x6d590150,0xf99f894a,0x27e018f0,0x67256f06}},	//   _unwa, gnè_, _puin_, _achj,
   {{0x673c92c1,0xa3db000f,0x27e00472,0x29000dd3}},	//   terj, _ढंग_, _quin_, _veia_,
   {{0xfaa5457f,0x201d00f9,0x29ee01c2,0x7bd806b0}},	//   _пало, iuwi_, bƙa_, _givu,
   {{0x6f0192c2,0x29000db4,0xcb1200ca,0xdb0102c3}},	//   _melc, _teia_, _עלה_, rolä,
   {{0x27e0043e,0x673c033b,0x2d9f0257,0x7bd84dce}},	//   _tuin_, serj, nnue_, _zivu,
   {{0x673c003d,0xfc480028,0x66e60870,0x212f00c4}},	// [9da0] perj, _xử_, _попа, dfgh_,
   {{0x317f0113,0xe3b70f5e,0x74130037,0x661c92c3}},	//   _aluz_, ебу_, اولا, purk,
   {{0x317f115f,0x00000000,0x00000000,0x00000000}},	//   _bluz_, --, --, --,
   {{0xdb080094,0x3949008c,0xc0e60110,0x10a60036}},	//   vodí, _xaas_, ходк, ниен,
   {{0x6f0102e5,0x26180034,0x201d0270,0x26c700b6}},	//   _belc, बंकी_, guwi_, _únor_,
   {{0x3dc692c4,0xdfcf5e51,0x25a039a2,0x6f010ff6}},	//   _show_, مين_, lnil_, _celc,
   {{0xfc4800ef,0x03a31a18,0x6f0192c5,0x53a378ee}},	//   _sử_, _сиро, _delc, _сарб,
   {{0x7bd830ec,0x8c6623c3,0x5d540c59,0x25a092c6}},	//   _sivu, етод, ткит, nnil_,
   {{0x10a30859,0x394992c7,0x6f0192c8,0x257c0af0}},	//   _битн, _raas_, _felc, _lílo_,
   {{0xf8bf00fd,0x64460167,0x25a00117,0x53b00179}},	//   ngée_, _mski, hnil_, जकिश,
   {{0xc3337c04,0x7bd892c9,0x25a0033b,0x39492481}},	//   אות_, _vivu, knil_, _paas_,
   {{0xfc4800ef,0x4c86013d,0xbfa50023,0x25a00094}},	//   _tử_, _плев, hiệ, jnil_,
   {{0xb90904dd,0xdb08001f,0x7a3600a7,0x7bd80036}},	//   _बल_, godã, _bütö, _tivu,
   {{0x39496b1a,0x00000000,0x00000000,0x00000000}},	//   _waas_, --, --, --,
   {{0x394992ca,0x644692cb,0x6a86014b,0x00000000}},	//   _taas_, _aski, _défé, --,
   {{0xd5b8197f,0x25a0033b,0x257c02c6,0x00000000}},	//   есу_, gnil_, _dílo_, --,
   {{0x68ed08bb,0x00000000,0x00000000,0x00000000}},	// [9db0] _ifad, --, --, --,
   {{0x889c00a1,0x7bcd0036,0x2c1800b7,0x316d037a}},	//   _מבחי, _èaut, _दिनं_, _soez_,
   {{0x644692cc,0x22590037,0x764502a4,0xd6d800ae}},	//   _eski, بلاد_, _ushy, _птю_,
   {{0x25a01e4d,0x00000000,0x00000000,0x00000000}},	//   cnil_, --, --, --,
   {{0x2d8492cd,0x6f012a3e,0x644601c2,0x05b6001c}},	//   dhme_, _pelc, _gski, _شگفت_,
   {{0x7bdf04ea,0x656f02dc,0x3b0501d4,0x248943b5}},	//   _équi, _hoch, xalq_, mzam_,
   {{0x6372003e,0x61dc0789,0xb87b0103,0x248992ce}},	//   _vænt, यदृष, gbíz, lzam_,
   {{0x7dd5013f,0x6f010413,0x11d40037,0x656f281c}},	//   _išsk, _welc, _متقد, _joch,
   {{0x656f92cf,0x7d02002d,0x6f014dc8,0x443900dc}},	//   _moch, _deos, _telc, _jps_,
   {{0x656f0091,0x24891197,0x67200034,0x69cf01fa}},	//   _loch, izam_, _बाइक_, emce,
   {{0xfaa521b6,0x6a86025a,0x371b00aa,0x257c01cd}},	//   тано, _réfé, _बाड़ी_, _bíll_,
   {{0x656f92d0,0x7d0292d1,0x853003e3,0x2d9f0036}},	//   _noch, _geos, kiɗa, qnue_,
   {{0x8ccd0034,0x6d4b009c,0xec6e1a1b,0xa9a30036}},	//   देशो, _iaga, _тп_, рияд,
   {{0x6d4b92d2,0x24891511,0x1ae21720,0xfc4602c6}},	//   _haga, dzam_, _кошм, řích_,
   {{0x6d4b92d3,0x656f5190,0xa2d3030b,0x66033c1a}},	//   _kaga, _boch, भेम्, ипра,
   {{0x656f92d4,0x6d4b37ec,0x443992d5,0x00000000}},	//   _coch, _jaga, _bps_, --,
   {{0x6d4b1dbd,0x25a092d6,0xa3d60096,0x442b02a0}},	// [9dc0] _maga, rnil_, _हळद_, _cqc_,
   {{0x6d4b3bd7,0x656f00e3,0x25a092d7,0xb38300ae}},	//   _laga, _eoch, snil_, алул,
   {{0x656f92d8,0xf8bf00fd,0x25a0138c,0x6372003e}},	//   _foch, rgée_, pnil_, _sæns,
   {{0x6d4b92d9,0x656f92da,0xa1132b38,0xd1300076}},	//   _naga, _goch, لومت, صمت_,
   {{0xdb080094,0x29120113,0x7d0200bc,0x2489007f}},	//   hodá, _mdya_, _reos, czam_,
   {{0x442092db,0x7d02773b,0x6d4b883a,0x656f92dc}},	//   mui_, _seos, _aaga, _zoch,
   {{0x442092dd,0x6d4b92de,0x26dc025b,0x2d840257}},	//   lui_, _baga, _úvod_, thme_,
   {{0x75241a0f,0x6d4b7cab,0x656f554a,0x44200668}},	//   ngiz, _caga, _xoch, oui_,
   {{0x6d4b92df,0x442092e0,0x61e900cc,0x98be030b}},	//   _daga, nui_, _čeli, ětě_,
   {{0x2d84074a,0x6d4b0099,0x4420009c,0x2912010a}},	//   shme_, _eaga, iui_, _adya_,
   {{0x442006ee,0xdee30231,0x7d0232d2,0x3f9b0257}},	//   hui_, _тохи, _teos, èque_,
   {{0x6d4b92e1,0x7dc50cb6,0x00000000,0x00000000}},	//   _gaga, rósc, --, --,
   {{0x656f92e2,0x442033be,0x257501df,0xdd8f13c3}},	//   _roch, jui_, _målt_, _بون_,
   {{0x6d4092e3,0x6d4b92e4,0x442092e5,0x656f7e4a}},	//   lema, _zaga, dui_, _soch,
   {{0x35e402ec,0xda6f0465,0x44390284,0x6d4b01a6}},	//   ицтв, _тя_, _sps_, _yaga,
   {{0x6d400fda,0x88c800b6,0x68ed92e6,0xa49b0441}},	//   nema, _stěž, _ufad, _deòn,
   {{0x442092e7,0x54550963,0x656f92e8,0xb87b016d}},	// [9dd0] gui_, ыват, _voch, ecív,
   {{0x6d400006,0x656f02dc,0x1b1400c7,0x248940e8}},	//   hema, _woch, ত্রে_, rzam_,
   {{0x6d4092e9,0x656f92ea,0x24890034,0x31ae0146}},	//   kema, _toch, szam_, lýzy_,
   {{0x6d4092eb,0x442092ec,0xf67a00c1,0x44397c5f}},	//   jema, bui_, _נארמ, _tps_,
   {{0x6d4b92ed,0x44200f2c,0x9487002d,0x6d4092ee}},	//   _raga, cui_, _рынд, dema,
   {{0x7dd501b3,0xe8d90174,0xdb010031,0xff250120}},	//   _išsi, _nnọ_, solú, умко,
   {{0x6d4b92ef,0x43941d57,0x16c10285,0x00000000}},	//   _paga, _тарс, _एरोब, --,
   {{0xe8d900ac,0x26dc0089,0x00000000,0x00000000}},	//   _anọ_, וקומ, --, --,
   {{0x7bca16cc,0xc6bf00c7,0x6d4b92f0,0x00000000}},	//   _bhfu, _আলোচ, _vaga, --,
   {{0x9ee900e3,0x6d4b5478,0x200900d9,0xc0c84d3e}},	//   _أفضل_, _waga, šais_, _русе_,
   {{0x6d4b92f1,0x6d4092f2,0xadf52a6e,0x7dc70018}},	//   _taga, bema, _спеш, _műsz,
   {{0xdb080fc5,0x290492f3,0x8ed50033,0x00000000}},	//   rodá, úma_, _স্থগ, --,
   {{0xd9100018,0x7c640018,0xdb23001c,0xdb080103}},	//   میں_, _ناول, _نوشی, sodá,
   {{0x3ced02dd,0x442092f4,0x7d0945f9,0xf1c70094}},	//   lcev_, vui_, laes, _šály_,
   {{0x98a403a3,0x69c400a5,0xdbd1007a,0xf8bf014b}},	//   ımı_, रतदी, _müüj, ffés_,
   {{0x7d0903ce,0x44200c5f,0x3ced02dd,0x00000000}},	//   naes, tui_, ncev_, --,
   {{0x7524006d,0x2618007a,0x79840051,0x394292f5}},	// [9de0] rgiz, बूजी_, _iliw, meks_,
   {{0x394292f6,0x442092f7,0x6d4092f8,0x6444008c}},	//   leks_, rui_, zema, rwii,
   {{0xeb9607a6,0x6d4000ac,0x442092f9,0x7984684d}},	//   נדער_, yema, sui_, _kliw,
   {{0x673b005f,0x394213e1,0x442092fa,0x6d400062}},	//   đuje, neks_, pui_, xema,
   {{0x442092fb,0x6d405d6e,0xe3b10018,0x7dc70103}},	//   qui_, vema, صرے_, _fűsz,
   {{0xa2e31312,0x3942007a,0x6d4092fc,0x798400f0}},	//   _горд, heks_, wema, _lliw,
   {{0x6d4092fd,0x798492fe,0x39427aa0,0x63ab01f9}},	//   tema, _oliw, keks_, égne,
   {{0xf6570341,0xdd9000e3,0x6b830113,0x644d00aa}},	//   רסקי_, توب_, _alng, _üliõ,
   {{0x6d4092ff,0x39429300,0xd1b300bf,0xa49b009c}},	//   rema, deks_, _اینک, _neòl,
   {{0x6d409301,0x6d8703cc,0x79849302,0xff240068}},	//   sema, _añad, _aliw, _خبری,
   {{0xa49b009c,0xfca9001c,0x4e1a001c,0x6d408d42}},	//   _aeòl, _یاهو_, _ستاد_, pema,
   {{0xfce61ca5,0x394200bc,0x798403a8,0x00000000}},	//   _содо, geks_, _cliw, --,
   {{0xa3e40455,0xe81c0006,0xa49b0441,0x7984039f}},	//   _पूल_, भंगा_, _ceòl, _dliw,
   {{0xead4333f,0x60dd0031,0x79840415,0x31bc00d4}},	//   _коль, _úsme, _eliw, mízu_,
   {{0x5b7b00c1,0x6b9a11fe,0xb4db0139,0x387f0433}},	//   _ארגא, mitg, _laàt, šur_,
   {{0xa49b01ec,0x7984007f,0x6b9a00b3,0x00000000}},	//   _feòl, _gliw, litg, --,
   {{0x33f400e3,0x3ebe004d,0x24181402,0xa49b8ca7}},	// [9df0] مسلس, _lytt_, лоты_, _geòl,
   {{0x290b9303,0x69df023b,0x98b901d3,0x7996007f}},	//   laca_, _hiqe, cesā_, _zmyw,
   {{0x3ebe866f,0xdb080088,0xd6db004d,0x00000000}},	//   _nytt_, lldó, _яти_, --,
   {{0x290b32f0,0x3547224a,0x3135004d,0x00000000}},	//   naca_, _схов, редр, --,
   {{0x3ced0087,0xada50031,0x69df0052,0x7d090e22}},	//   vcev_, nkúš, _miqe, vaes,
   {{0x88c700c7,0x3ebe0e3e,0x69df5887,0x290b9304}},	//   _এলাক, _bytt_, _liqe, haca_,
   {{0xd5ae00fb,0x277800a1,0x7d09007b,0xa49b01ec}},	//   _رہے_, רגון_, taes, _meòm,
   {{0x290b042d,0xa49b01ec,0x463c006e,0x69df039f}},	//   jaca_, _leòm, געהע, _niqe,
   {{0xe7e105d4,0x0d8200f7,0xdca51312,0x290b1ee5}},	//   _गंगा_, ільн, рапи, daca_,
   {{0x30840037,0x60c96b52,0x00000000,0x00000000}},	//   _الكف, _izem, --, --,
   {{0x39420006,0x69cd009c,0x49ca0cc6,0x290b9305}},	//   teks_, _bhae, клон_, faca_,
   {{0x69cd0150,0x290b9306,0x7f430393,0xe9d70a29}},	//   _chae, gaca_, lenq, икэ_,
   {{0x7dc510d9,0x6b65249c,0xc8d002d5,0x69cd001c}},	//   lóso, _вкла, सेंट, _dhae,
   {{0x87b90562,0x394205a7,0x60c90350,0x7cdb00e8}},	//   густ_, seks_, _mzem, _vārī,
   {{0x290b5607,0x63b70094,0x00000000,0x00000000}},	//   baca_, doxn, --, --,
   {{0x290b75bc,0x69cd0080,0xdb180154,0x79840051}},	//   caca_, _ghae, _akvè, _uliw,
   {{0x3f858821,0x9f440036,0x13062b16,0x60c918fe}},	// [9e00] _ollu_, _fumè_, изам, _nzem,
   {{0x7bc102e0,0x42561fdb,0x69df5cda,0x6e23722b}},	//   nllu, итет, _éper, kunb,
   {{0x00e61588,0x171b00c1,0x7bc19307,0x60c99308}},	//   ажен, _בויע, illu, _azem,
   {{0x3f858877,0x31600328,0x7ae30062,0x6e239309}},	//   _allu_, ñiz_, _lgnt, dunb,
   {{0x60c90034,0x2f180829,0x33d6004d,0x3f6a0fe3}},	//   _czem, голь_, _вівт, кидо_,
   {{0x60c9930a,0x7ae30113,0x8fa3002d,0x4432010a}},	//   _dzem, _ngnt, оаче, mty_,
   {{0xe8e000de,0x4432930b,0x1c18007a,0x6f0a00e7}},	//   _muối_, lty_, _दिहल_, rafc,
   {{0xe817009d,0xad6600e3,0x290b0a43,0x68e428f0}},	//   _तिला_, شابه, xaca_, _ngid,
   {{0x290b02e6,0x4432262a,0x61e0009c,0x6f662cf1}},	//   vaca_, nty_, _iiml, _кваз,
   {{0x4432930c,0x61e00fbc,0x68e4930d,0xe8e000fe}},	//   ity_, _himl, _agid, _nuối_,
   {{0x3f9c63c1,0x4432930e,0x61e003a3,0xa3d70be4}},	//   mivu_, hty_, _kiml, ागत_,
   {{0x443212fb,0x60c00084,0x3f9c930f,0x7bc1581e}},	//   kty_, _kymm, livu_, allu,
   {{0xdbdc00b6,0x63a5003e,0x61e00078,0x63bc0141}},	//   lšíh, ynhn, _miml, _okrn,
   {{0xe8e00028,0x61e0765d,0x68e49310,0x6f0805db}},	//   _cuối_, _liml, _egid, _jedc,
   {{0x290b0039,0xada50220,0x7bdf028d,0x44329311}},	//   paca_, skúš, _èqua, ety_,
   {{0x443257bf,0x261809a1,0x69cd0231,0x61e09312}},	//   fty_, _फिरी_, _uhae, _niml,
   {{0x4432084e,0x656d062b,0x799d0201,0x7f439313}},	// [9e10] gty_, rjah, misw, yenq,
   {{0x799d0060,0x8c1b00a1,0x656d9314,0x9f44020d}},	//   lisw, כומי, sjah, _fumé_,
   {{0x60c900fb,0x27e99315,0x61e90307,0xd8b800cd}},	//   _szem, _huan_, _čels, _مدیا_,
   {{0x799d0060,0x27e91c3d,0x3f850085,0xdceb0078}},	//   nisw, _kuan_, _sllu_, _imgħ,
   {{0x27e901ff,0x7bc19316,0x3e470103,0x6f080167}},	//   _juan_, yllu, _sőt_, _bedc,
   {{0x2d865675,0x60c9033b,0x799d6b52,0x7dc501f9}},	//   _aloe_, _vzem, hisw, tóso,
   {{0x6fcd0181,0x27e99317,0x799d0201,0x7f43015e}},	//   júce, _luan_, kisw, renq,
   {{0x6fcd9318,0x6e230a00,0x386b0063,0x51879319}},	//   dúce, runb, kxcr_, _туга,
   {{0x60c0931a,0x60c9931b,0x799d063d,0x27e93c21}},	//   _gymm, _uzem, disw, _nuan_,
   {{0x5f740080,0x61e04d41,0x2d860167,0xdce7028e}},	//   _والر, _ziml, _eloe_, ılıl,
   {{0xe9da0020,0x26c1023e,0x2ca900e7,0xdce904e9}},	//   лко_, _nyho_, _žadd_, lječ,
   {{0x27e92ae3,0x186a2da1,0x4432931c,0xe8e00023}},	//   _buan_, гами_, yty_, _suối_,
   {{0x4432931d,0x27e9931e,0x3bd51689,0xb608007e}},	//   xty_, _cuan_, _люкс, _mišš,
   {{0x27e9931f,0x291e026a,0xcc5600ca,0xa8030072}},	//   _duan_, şta_, _לבני_, íñas,
   {{0xc9f50391,0xfaa22df8,0x6456006c,0x27e9009c}},	//   _استع, _нашо, wvyi, _euan_,
   {{0x44327032,0x63bc9320,0xb6a30aad,0x27e900f0}},	//   tty_, _skrn, числ, _fuan_,
   {{0x1ddf000f,0xd4670b70,0x27e900dc,0x61e09321}},	// [9e20] _पूछत, бите_, _guan_, _riml,
   {{0x443210d2,0x212d0cd0,0x1dce0179,0x60c00212}},	//   rty_, _aceh_, _हीनत, _rymm,
   {{0x4432262a,0xdb010072,0x06d60033,0x3f8201d3}},	//   sty_, loló, _ত্রি, _ēku_,
   {{0x44321106,0x2c180096,0x3aba006e,0x64a64187}},	//   pty_, _दिलं_, אמענ, _гама,
   {{0xdb019322,0x3a250cad,0xb87b9323,0xc01300d6}},	//   noló, hulp_, ncíp, зміщ,
   {{0xe82000af,0x44209324,0x799d0201,0xa2c10096}},	//   _बिना_, mri_, zisw, _वरच्,
   {{0x528600e3,0xa2480f03,0x44209325,0x3f9c0283}},	//   _الأك, _خیال_, lri_, rivu_,
   {{0x44209326,0x3f9c9327,0xdb010224,0xafe600ae}},	//   ori_, sivu_, koló, _гоал,
   {{0x44209328,0x3f9c00c4,0x40960076,0x00000000}},	//   nri_, pivu_, _الذر, --,
   {{0x44209329,0xdb010a90,0x799d00f0,0x27e9932a}},	//   iri_, doló, wisw, _ruan_,
   {{0x4420932b,0xed0600cd,0x7dea0034,0x2ca90206}},	//   hri_, _هواپ, _męsk, _ľade_,
   {{0x27e9576f,0x8afc0034,0x6fcd0206,0x00000000}},	//   _puan_, ejęt, rúce, --,
   {{0x27e9932c,0x395200a1,0x8c43384f,0xcc332259}},	//   _quan_, _days_, _неце, _فروع,
   {{0x799d4c9b,0x27e90052,0x00000000,0x00000000}},	//   sisw, _vuan_, --, --,
   {{0x4420932d,0x7d2501cd,0xaa9400ae,0x799d4835}},	//   eri_, _útsý, _фийч, pisw,
   {{0x27e9932e,0xe8d90294,0xb8cf0081,0xe9a41fdb}},	//   _tuan_, _alụ_, _কর_, _најп,
   {{0x4420932f,0xe8200006,0xdb019330,0x5399055b}},	// [9e30] gri_, _बिया_, coló, авая_,
   {{0xdce90268,0xdb013195,0xdceb044c,0x00000000}},	//   vječ, lolò, _kogă, --,
   {{0x26c70181,0xd17500c6,0xa49b01ec,0x00000000}},	//   _áno_, жылы, _meòi, --,
   {{0xdce937f6,0x59c90775,0xa49b01f7,0xdb016430}},	//   tječ, रतिर, _leòi, nolò,
   {{0xa06903fc,0xa3d50fa5,0x25a981c2,0x777702a1}},	//   рала_, _момч, mnal_, _koxx,
   {{0x66fb05a5,0xaded17ff,0xdce90268,0xfe70001c}},	//   ्रिक_, _चंदन_, rječ, کده_,
   {{0x3cdb007d,0xdce90ea3,0x25a99331,0x877c22fe}},	//   खेने_, sječ, onal_, ראוי,
   {{0x25a99332,0x4c8502ec,0x31340b1b,0x5bb39333}},	//   nnal_, жлив, _неср, ुत्व,
   {{0xa49b01ec,0xdb01015e,0x50670138,0x39521dbd}},	//   _beòi, dolò, _утва, _rays_,
   {{0x39529334,0x645d1912,0xeb9904c9,0x25a90094}},	//   _says_, _mrsi, рио_, hnal_,
   {{0x395204ea,0x89aa02fd,0x44209335,0x753d00a5}},	//   _pays_, иков_, zri_, _obsz,
   {{0x44209336,0xdb019337,0xb4db026e,0x68e900d4}},	//   yri_, toló, _gbàg, žedn,
   {{0x777702a1,0xcb6902a0,0xe8e00023,0x25a90094}},	//   _boxx, _вале_, _ruồi_, dnal_,
   {{0x44209338,0x661a035d,0x5ed00081,0xc31f0081}},	//   vri_, átko, _স্টে, ন্তি_,
   {{0xb87b2733,0x645d9339,0xdb01933a,0x644f933b}},	//   scíp, _arsi, soló, _asci,
   {{0x4420933c,0x2d8d933d,0xdb010428,0x25a906f5}},	//   tri_, nhee_, colò, gnal_,
   {{0x4420933e,0x7d0b0068,0x377600d3,0x00000000}},	// [9e40] uri_, _megs, _дынс, --,
   {{0x4420933f,0x2bcf000c,0x7d0b0103,0x645d05db}},	//   rri_, _सीमा, _legs, _drsi,
   {{0x644f6df6,0x44200255,0x98b90138,0x645d0684}},	//   _esci, sri_, resą_, _ersi,
   {{0x44209340,0xaca30134,0x637b044c,0x00000000}},	//   pri_, _atọm, _sînt, --,
   {{0x2d8d026d,0x6566039f,0x00000000,0x00000000}},	//   dhee_, _inkh, --, --,
   {{0xdfcf0080,0xceb40092,0x25a00188,0x2b800383}},	//   نين_, şəm_, liil_, _gòch_,
   {{0xa3d713ae,0xed500103,0xa49b01ec,0x7d0b041c}},	//   ागर_, ٹھا_, _reòi, _begs,
   {{0x25a09341,0x2d8d0134,0x61fe0f5a,0xc31f0033}},	//   niil_, ghee_, mppl, ন্দি_,
   {{0xb4db0032,0x7d0b9342,0x7d19030a,0x9b6a03fc}},	//   _gbàd, _degs, _ddws, ашна_,
   {{0x25a915fe,0x25a0008c,0x61fe0120,0x23789343}},	//   znal_, hiil_, oppl, _jorj_,
   {{0xa2a0110f,0x1959022a,0x25a00188,0xdb010428}},	//   _गेम्, баны_, kiil_, tolò,
   {{0x6fc400b3,0x00000000,0x00000000,0x00000000}},	//   dòci, --, --, --,
   {{0xb8f302e8,0xdb010428,0x2480006c,0x7dd50138}},	//   _वर_, rolò, jyim_, _išsp,
   {{0x5fca00b6,0x2902008c,0x69c62275,0x7d0b0381}},	//   ितिल, abka_, alke, _zegs,
   {{0x6933030b,0xdb230088,0x68f600f0,0x25a000bc}},	//   _přeč, _þrát, _ffyd, fiil_,
   {{0x4815121c,0x645d0fee,0x00000000,0x00000000}},	//   _емис, _prsi, --, --,
   {{0x25a9451f,0xe8e00019,0x6fca0096,0x2b800383}},	// [9e50] rnal_, _buổi_, ितां, _pòch_,
   {{0xd25b225d,0x645d1197,0xed5904e9,0x6566029a}},	//   ице_, _vrsi, može_, _enkh,
   {{0x25a0024b,0xed59042d,0x6fc40428,0x765e0113}},	//   biil_, lože_, còci, _grpy,
   {{0x2b8006a3,0x25a0008a,0x60400134,0x6d870062}},	//   _wòch_, ciil_, _ịmag, _añan,
   {{0x644f9344,0x7d0b0185,0x645d135c,0x61fe1030}},	//   _usci, _regs, _ursi, appl,
   {{0x44294497,0xd34300d0,0x752d7f18,0x237881c2}},	//   mua_, _تفسی, lgaz, _gorj_,
   {{0x44299345,0x2d8d18f0,0xdce90031,0xed590094}},	//   lua_, thee_, rieľ, hože_,
   {{0x752d4753,0x3cf700a5,0xed596b2f,0x44292074}},	//   ngaz, ीरें_, kože_, oua_,
   {{0x1c420fe9,0x5e590281,0x7d0b3200,0x00000000}},	//   еным, _گلاس_, _vegs, --,
   {{0x2d8d008a,0x7d0b35a5,0x5f9500d1,0x68e900d2}},	//   shee_, _wegs, _علائ, žedl,
   {{0x44290d7d,0x644d9346,0x00000000,0x00000000}},	//   hua_, hwai, --, --,
   {{0x44299347,0x2480017d,0x66150034,0x290202c6}},	//   kua_, yyim_, dszk, ubka_,
   {{0x44299348,0x2d9d0193,0xeb8e0731,0x213f00d1}},	//   jua_, _imwe_, _зи_, _mbuh_,
   {{0x442982a2,0x752d00e5,0x7c29034f,0x644d0150}},	//   dua_, egaz, muer, dwai,
   {{0x9663246b,0x7c2901be,0x1c2102d5,0xdb1a0052}},	//   нкре, luer, _मिडल_, zotë,
   {{0x752d18cb,0x44290051,0x2bcf13ae,0x250800cd}},	//   ggaz, fua_, _सीता, ترسی_,
   {{0x44299349,0x7c292850,0xd4670114,0x2d9d0283}},	// [9e60] gua_, nuer, пите_, _mmwe_,
   {{0x213f01dc,0x752d934a,0x3860041c,0x00000000}},	//   _abuh_, agaz, _irir_, --,
   {{0x24920067,0x442900d3,0x24860206,0xb77b00a1}},	//   szym_, aua_, šom_, _האיש,
   {{0x4429934b,0x7c290407,0x3cf70034,0x7dc50072}},	//   bua_, kuer, ीरों_, bósi,
   {{0xe8e00028,0x7dc5002b,0xf993006e,0xdb1801cd}},	//   _tuổi_, cósi, ערד_, _skví,
   {{0xfbc70602,0x7c2944eb,0xb4d81a09,0x2d9d02a4}},	//   _ست_, duer, ाधी_, _amwe_,
   {{0xb4db0065,0x67eb003d,0x00000000,0x00000000}},	//   _gbàb, _iżje, --, --,
   {{0x7c2909b3,0x2ca900c6,0xdb1a00d4,0x3218014b}},	//   fuer, _žada_, moté, _ivry_,
   {{0x7c292243,0x2c1c0096,0xdb1a014b,0x00000000}},	//   guer, _मिळू_, loté, --,
   {{0x5ede00c7,0x394029dd,0x53be000c,0x63be30e6}},	//   নুষে, _abis_, ्तिश, nopn,
   {{0x4429934c,0xa3e40ed3,0x61ee0429,0x3940009c}},	//   zua_, _पूछ_, _jubl, _bbis_,
   {{0xed590074,0x7c290407,0x63be0618,0x9f4405fe}},	//   tože_, buer, hopn, _humà_,
   {{0x7c2914e2,0xc8641e33,0x61ee3720,0x442901e9}},	//   cuer, нтри, _lubl, xua_,
   {{0x61ee04ea,0x4429934d,0x386609ac,0xed590218}},	//   _oubl, vua_, _šorc_, rože_,
   {{0x7bda0088,0x61ee22a8,0x8b3b00ca,0x44290174}},	//   mmtu, _nubl, _התוצ, wua_,
   {{0x4429934e,0x67eb02a1,0x5574934f,0x7bc801ab}},	//   tua_, _ażje, нгст, lldu,
   {{0x09c90e72,0x3f8c0390,0x752d9350,0x798d828a}},	// [9e70] रतीय, _oldu_, rgaz, _ilaw,
   {{0x44299351,0x798d022e,0x61ee0146,0xe9730018}},	//   rua_, _hlaw, _bubl, _آنکھ,
   {{0x44299352,0x213f00dc,0x61ee00d1,0x7c295817}},	//   sua_, _pbuh_, _cubl, zuer,
   {{0x15f204a9,0xdd86003f,0x7dc50b0b,0x44297104}},	//   _आंतर_, _شو_, pósi, pua_,
   {{0x4429013d,0x321889c0,0xe0d00037,0xe8e000fe}},	//   qua_, _evry_, هزه_, _duỗi_,
   {{0x798d02ad,0x3f9e0063,0x6f03023e,0x394b020d}},	//   _llaw, _cmtu_, ubnc, hecs_,
   {{0x7c290365,0x61ee08a9,0x798d427d,0x6442020d}},	//   wuer, _gubl, _olaw, çoiv,
   {{0x7c2972c0,0x3f8c0062,0xe46a0233,0x7bc81a7a}},	//   tuer, _eldu_, ıköğ, eldu,
   {{0x32010270,0x3940002b,0x61ee05db,0x00000000}},	//   lphy_, _rbis_, _zubl, --,
   {{0x798d9353,0x7c299354,0xaca30174,0x7986366c}},	//   _alaw, ruer, _nkụk, wkkw,
   {{0x7c2924da,0x394a09f2,0x3201023e,0xddc80103}},	//   suer, озно_, nphy_, _erdő,
   {{0x7c290314,0xaca306c0,0x2d9d023f,0x798d8933}},	//   puer, _akụk, _umwe_, _claw,
   {{0x798d9355,0xd6fb0285,0xd9100103,0x00000000}},	//   _dlaw, ्रंथ_, نیں_, --,
   {{0x8c42185c,0x61fb0e94,0xa49b01b9,0x798d0372}},	//   _реше, _čuln, _leòs, _elaw,
   {{0x4ad10e52,0xe737007b,0x798d16ea,0x00000000}},	//   _हरिव, ьер_, _flaw, --,
   {{0x9952013f,0x61ee9356,0xe817009d,0xed59007e}},	//   ršų_, _rubl, _तिचा_, ndž_,
   {{0x63be0087,0x6fcd0220,0x69c40239,0x61fc05db}},	// [9e80] topn, júco, _ikie, _strl,
   {{0x387f0364,0x7dea00c6,0x6fcd0031,0xa49b01ec}},	//   äure_, _kęst, dúco, _reòt,
   {{0xa49b01b9,0x7dc501f9,0x00000000,0x00000000}},	//   _beòs, lósu, --, --,
   {{0x2f0a0034,0xed59007e,0xdce902c6,0x00000000}},	//   _mógł_, jdž_, ěněn, --,
   {{0x7bc80088,0x7bc300a4,0x9f4502f1,0x69c49357}},	//   yldu, _oknu, _kilè_, _mkie,
   {{0xdb1a025b,0x61ee00aa,0x9f450154,0xe29a3c1f}},	//   poté, _tubl, _jilè_, _даг_,
   {{0x69c43f8a,0x61fc042d,0x00000000,0x00000000}},	//   _okie, _utrl, --, --,
   {{0x29c40072,0x2dd70037,0xdb01041b,0x6e2a042c}},	//   iñas_, وبية_, nnlæ, rufb,
   {{0x7e87013f,0x20c301b6,0xdb184e96,0xa49b009c}},	//   _įspū, _айтм, _akvá, _heòr,
   {{0x798d9358,0x69c489ed,0x69d6361e,0x7bc8013c}},	//   _slaw, _akie, _ahye, uldu,
   {{0xd01300c7,0x798d01bb,0x394b9359,0xe814009f}},	//   _সময়_, _plaw, tecs_, _तौबा_,
   {{0x69d60383,0xbc6a001c,0xa49b01ec,0x644601d0}},	//   _chye, _ومان_, _meòr, _opki,
   {{0xd7f83283,0x02ee0285,0x6d97020a,0xa2a00386}},	//   дус_, जशाह_, rţat, _गेस्,
   {{0x394b00ee,0x00000000,0x00000000,0x00000000}},	//   secs_, --, --, --,
   {{0x9f4510fe,0x69c40090,0x52bf09c3,0x386d020a}},	//   _dilè_, _fkie, _्रेस, ţer_,
   {{0x58d5007b,0x9999007f,0x798d60d9,0x00000000}},	//   _пойт, żyła_, _ulaw, --,
   {{0xb7d50065,0x9f4505aa,0xed5900c4,0xdb015d61}},	// [9e90] _aṣen, _filè_, noža_, rolö,
   {{0x6d9700d3,0x69dd935a,0xdb0102b6,0x00000000}},	//   nţar, lmse, anlæ, --,
   {{0xe1f05f34,0xe7e8007f,0x00000000,0x00000000}},	//   لسن_, _टूटा_, --, --,
   {{0x32016b15,0x7dc5935b,0xa49b01ec,0xe5070452}},	//   rphy_, nóst, _deòr, _تبدي,
   {{0xd0094460,0x69dd1ac3,0x3f69121c,0x600802b7}},	//   челе_, imse, зило_, днім_,
   {{0x657d5b4b,0xa49b01f7,0x443900ee,0x7e550e06}},	//   _hosh, _feòr, _iqs_, етиц,
   {{0xee390a8d,0x657d935c,0x68ed008a,0x23be0c3c}},	//   їни_, _kosh, _ogad, ्तरद,
   {{0x68ed935d,0x63a50991,0x657d935e,0x6d8701e9}},	//   _ngad, lihn, _josh, _iñak,
   {{0x657d935f,0xed59077e,0xdb012722,0x6fc40428}},	//   _mosh, rdž_, lilé, tòct,
   {{0x69c49360,0x61e99361,0xa3bf0490,0x63a5005c}},	//   _skie, _hiel, ँकि_, nihn,
   {{0x61e99362,0xa2d3009d,0x60c90085,0x00000000}},	//   _kiel, भेच्, _hyem, --,
   {{0x657d7727,0x60c90361,0x61e9024a,0x63a59363}},	//   _nosh, _kyem, _jiel, hihn,
   {{0x61e99364,0xdb080610,0x8c457748,0x4439023b}},	//   _miel, godó, _челе, _nqs_,
   {{0x61e90b4b,0x7c3b9365,0x60c902c9,0x6d59756f}},	//   _liel, mtur, _myem, _hawa,
   {{0x6d599366,0x657d9367,0x63a510d3,0x69d6023b}},	//   _kawa, _bosh, dihn, _thye,
   {{0x6d5b9368,0x61e99369,0x7bc1936a,0xaca30134}},	//   ndua, _niel, lolu, _nhịk,
   {{0x6d599302,0x809f06ed,0x657d936b,0xa49b0013}},	// [9ea0] _mawa, _खेले, _dosh, _seòr,
   {{0x6d594930,0xaca30174,0x63a5005c,0x7c3b0062}},	//   _lawa, _ahịk, gihn, itur,
   {{0x61e9936c,0x657d023b,0x62851384,0x60c940f5}},	//   _biel, _fosh, gyho, _ayem,
   {{0x6d59726d,0x61e9936d,0x657d936e,0xaca30294}},	//   _nawa, _ciel, _gosh, _chịk,
   {{0x4fc621bf,0x61e90758,0x63a5063f,0x7bc1936f}},	//   нска, _diel, bihn, kolu,
   {{0xa49b8d84,0x2d8f9370,0x60c9022b,0x7c3b9371}},	//   _teòr, _alge_, _dyem, dtur,
   {{0x6d599372,0x657d9373,0x61e900a1,0xd04e0092}},	//   _bawa, _yosh, _fiel, _ədəb,
   {{0x61e90090,0x6d599374,0xdd9724d3,0x7c3b9375}},	//   _giel, _cawa, ешь_, ftur,
   {{0x7c3b2783,0x60c95445,0x3cdb00aa,0x00000000}},	//   gtur, _gyem, खेले_, --,
   {{0x09c90961,0xa0a31c0f,0x61e99376,0x1e96121c}},	//   रत्य, _сауд, _ziel, _прер,
   {{0x200d02dc,0x0c730177,0xdb080034,0x61e99377}},	//   _zwei_, ندید, wodó, _čelz,
   {{0x6d599378,0x67eb00bd,0xec7a00d3,0xdb1a430e}},	//   _gawa, _ażja, _нпе_, motí,
   {{0x7c3b504e,0x69dd9379,0x7bc18ff4,0x62850167}},	//   ctur, rmse, bolu, zyho,
   {{0x7bc1002d,0x657d937a,0x6d59937b,0x29120065}},	//   colu, _sosh, _zawa, _eeya_,
   {{0xdb1a0990,0x6d595d1d,0xa2a0009d,0x657d5a11}},	//   notí, _yawa, _गेल्, _posh,
   {{0xdb01937c,0x62850146,0x6d590188,0xb4db009c}},	//   vilé, vyho, _xawa, _dbàn,
   {{0x61e9937d,0x63a509a4,0x9327001c,0xf994006e}},	// [9eb0] _riel, tihn, فران, _תרפ_,
   {{0x61e9937e,0x628500d4,0x60c905bd,0xe9df01f9}},	//   _siel, tyho, _ryem, lmú_,
   {{0x61e9937f,0x60c91281,0x7c3b22c9,0x06df0081}},	//   _piel, _syem, ztur, _ব্রি,
   {{0x63a5063f,0x1c2105a7,0x61e9023b,0x62859380}},	//   sihn, _मिलल_, _qiel, ryho,
   {{0x61e99381,0x6d599382,0x29d900e3,0xdce90dd9}},	//   _viel, _rawa, méad_, mjeć,
   {{0x61e99383,0x6d590706,0xdce90ea3,0x60c90051}},	//   _wiel, _sawa, ljeć, _vyem,
   {{0x44299384,0x61e99385,0x6d599386,0x6d409387}},	//   lra_, _tiel, _pawa, ffma,
   {{0x7c3b3543,0x44299388,0x8d6508d8,0xf8bf416f}},	//   ttur, ora_, твие, ngés_,
   {{0x44299389,0x7bc17f66,0x6d5b8045,0x200d0063}},	//   nra_, tolu, rdua, _uwei_,
   {{0x442913a3,0x6d5955e6,0x3d270139,0xdb23001c}},	//   ira_, _wawa, _bìwà_, دودی,
   {{0x09d60f71,0x6d59295f,0x7bc1938a,0x7c3b551a}},	//   _সংবা, _tawa, rolu, stur,
   {{0x4429938b,0x7bc1938c,0x7c3b39bc,0x6d4b0094}},	//   kra_, solu, ptur, ínač,
   {{0x2912074e,0x4429938d,0x7bc1938e,0x395b003d}},	//   _veya_, jra_, polu, _daqs_,
   {{0x4429938f,0x70130081,0x7c2917d2,0x3d270139}},	//   dra_, _সমাজ_, mrer, _fìwà_,
   {{0x44299390,0x65b304f9,0x316d01c8,0x395b9391}},	//   era_, għho, _onez_, _faqs_,
   {{0x7d096382,0x89361b49,0xf8661a57,0x7c29209a}},	//   nbes, _شعبا, _авио, orer,
   {{0x44299392,0x28de0455,0xd706013d,0x5fc102f0}},	// [9ec0] gra_, नेशि, _изпи, शकाल,
   {{0x8cd602d5,0x13be0285,0x06866236,0x78ad02c6}},	//   मेटो, ्तेभ, _агон, šová,
   {{0x44299393,0x7c2902e2,0xdce90268,0x7d091507}},	//   ara_, hrer, bjeć, kbes,
   {{0x29d900e3,0x6fcd0076,0x7c290d2d,0x7f5a00a7}},	//   céad_, lúch, krer, _satq,
   {{0x7d099394,0x317f02f1,0x00000000,0x00000000}},	//   dbes, _douz_, --, --,
   {{0x5ead00c7,0x7c293f25,0xaca30129,0x7d095b8c}},	//   য়েছে, drer, _chọk, ebes,
   {{0x7c299395,0xf3f40081,0x7d0983d5,0x00000000}},	//   erer, _ছবির_, fbes, --,
   {{0x7d099396,0x6ce6116d,0x7c290131,0x6fcd0076}},	//   gbes, кіпе, frer, húch,
   {{0xc0450241,0x7c299397,0x00000000,0x00000000}},	//   _مخلو, grer, --, --,
   {{0xf4130054,0x20069398,0xd00700ae,0x4a540ed4}},	//   ספת_, mpoi_, _рефе_, гкос,
   {{0xc3337c04,0x44299399,0x7d09939a,0x7c290565}},	//   בות_, zra_, bbes, arer,
   {{0x7c29939b,0x6f1802dd,0x442932a7,0xac73001c}},	//   brer, lavc, yra_, _چاوش,
   {{0xb7d50065,0x6d950af0,0xe9df002b,0x7c29145c}},	//   _aṣan, _dáad, rmú_, crer,
   {{0x4429939c,0x60180076,0xe9df0206,0x00000000}},	//   vra_, _zúmá, smú_, --,
   {{0xb8ca048a,0x442914d8,0x2bb1009d,0x2b920281}},	//   _गे_, wra_, ीकरा, _میکس,
   {{0xdcfb0995,0x2b5c00c4,0x00000000,0x00000000}},	//   rkuć, _havc_, --, --,
   {{0x2919939d,0x6f180ca7,0xdcfb0335,0xe8d90134}},	// [9ed0] masa_, kavc, skuć, _maị_,
   {{0xdce90ea3,0x1755008f,0x6f180660,0x6fcd037a}},	//   sjeć, _своя, javc, cúch,
   {{0x4429939e,0x6f18042d,0x2919020a,0x29d90076}},	//   sra_, davc, oasa_, péad_,
   {{0x4429939f,0x291993a0,0x673b0106,0x326436c5}},	//   pra_, nasa_, đuju, штув,
   {{0x6fcd93a1,0x4429003d,0x656f3ed6,0x7d09093e}},	//   lúci, qra_, _inch, vbes,
   {{0x2919117e,0x2489022e,0x2d8293a2,0xee391469}},	//   hasa_, myam_, öken_, енк_,
   {{0x6da5139c,0x291993a3,0x24890103,0x290b0167}},	//   лика, kasa_, lyam_, kbca_,
   {{0x7c2993a4,0xf8d300b7,0x69cf05db,0x00000000}},	//   trer, _सरूप, jlce, --,
   {{0x291993a5,0x6f1800cc,0x6d950103,0x7c292ca7}},	//   dasa_, bavc, _ráad, urer,
   {{0x7c29627e,0x6fcd0031,0x61f505db,0x00000000}},	//   rrer, kúci, _kuzl, --,
   {{0x6fcd0181,0x25a91515,0x7d0901d0,0x8e9906cf}},	//   júci, kial_, pbes, _ثناء_,
   {{0x291993a6,0xb4db0032,0x2489010a,0x7c2993a7}},	//   gasa_, _abàm, kyam_, prer,
   {{0x9b452c66,0x2489022e,0x3156006e,0xbb4593a8}},	//   _منشو, jyam_, נישן_, _белк,
   {{0x656f0dfc,0x291900f9,0x2d8d659a,0x2b5c0381}},	//   _anch, aasa_, lkee_, _gavc_,
   {{0x29190e55,0x6fcd0076,0x00000000,0x00000000}},	//   basa_, rúch, --, --,
   {{0x6f18042d,0x25a993a9,0x6fc50096,0xdb1a00d4}},	//   zavc, gial_, ाकडू, motá,
   {{0x2bf600c1,0x69c693aa,0x9f45033c,0x446604d9}},	// [9ee0] ָמען_, moke, _ailí_, ывав,
   {{0x69c62c6f,0x69df028d,0x6fcd93ab,0x161d00b6}},	//   loke, _èper, búci, _फिचर_,
   {{0x201f0990,0x35a64ce6,0xb2260138,0x673b14f3}},	//   _avui_, _банг, умел, đujt,
   {{0x25a928ab,0x05560f00,0x2489022e,0xf67b006e}},	//   cial_, _стоя, byam_, _נאכמ,
   {{0xdefa0d64,0x6f18739c,0xa0678a30,0xe475539a}},	//   ный_, tavc, лаца_, _курэ,
   {{0x69c6219c,0x443201af,0xdb1a0103,0xcf260037}},	//   hoke, muy_, kotá, ارشي,
   {{0x291993ac,0x443212f5,0x69c693ad,0x6f180e43}},	//   yasa_, luy_, koke, ravc,
   {{0x69c62b29,0xdb08016d,0x6f1893ae,0x9942007f}},	//   joke, cidê, savc, _cóż_,
   {{0x6f1893af,0x69c693b0,0x443200b3,0x61e23852}},	//   pavc, doke, nuy_, mmol,
   {{0x40930080,0x25a993b1,0xc43b00ca,0xdb015c31}},	//   _الكر, zial_, עתיי, bilí,
   {{0x291993b2,0x443293b3,0xc33300ca,0x69c693b4}},	//   tasa_, huy_, זות_, foke,
   {{0xdb01016d,0x61e293b5,0x69c61a11,0x24890e26}},	//   gilâ, nmol, goke, yyam_,
   {{0x291993b6,0x44320de3,0xdca326d0,0xdb1a00ee}},	//   rasa_, juy_, _лаци, potà,
   {{0x2919555a,0x6fcd0220,0x443293b7,0x61e2322f}},	//   sasa_, túci, duy_, hmol,
   {{0x69c61e95,0x25a993b8,0x6d870062,0x4993001c}},	//   boke, tial_, _eñau, _هیدر,
   {{0x5558013a,0x248904a6,0xdb0300b3,0x69c666ea}},	//   лася_, tyam_, _amnè, coke,
   {{0xdb080161,0x3949037a,0xe3150859,0x00000000}},	// [9ef0] vidê, _ibas_, имањ, --,
   {{0x25a993b9,0x248904b7,0x4ad8009f,0x38690022}},	//   sial_, ryam_, _डराव, _irar_,
   {{0x7ceb0018,0xd2510c5e,0x2489658c,0x200400dc}},	//   _körü, تنا_, syam_, _atmi_,
   {{0x3d0e00a5,0xdb01034f,0xf43500d3,0x25f200a3}},	//   सरों_, vilí, _кемэ, ंआरी_,
   {{0x65360130,0xf3ff0161,0x3949023b,0x4432037a}},	//   _דארף_, _irão_, _mbas_, cuy_,
   {{0x61f593ba,0xdb08001f,0xdb0193bb,0x61e23ac9}},	//   _tuzl, sidê, tilí, amol,
   {{0xed59922c,0x09d60033,0x6d871a86,0xc695006e}},	//   вой_, _সংসা, _oñat, יאַ_,
   {{0x0d851a9c,0x0c25044c,0x38695768,0x9f4c02f1}},	//   рлин, амин, _orar_, _lidè_,
   {{0x69c693bc,0xff25001c,0xdb0193bd,0x2d8d28ef}},	//   voke, _نبای, silí, rkee_,
   {{0x4a45251e,0xb4db0139,0x257c00b6,0x394940fd}},	//   анов, _abàk, _díly_, _abas_,
   {{0xa2cb3abb,0x69c6068d,0x2fc793be,0x386993bf}},	//   _तुम्, toke, mong_, _arar_,
   {{0x3949009c,0x2fc793c0,0x4e940076,0x00000000}},	//   _cbas_, long_, _اشكر, --,
   {{0x69c693c1,0xa2a753b8,0xeb8e5f33,0x7d1b93c2}},	//   roke, _टेस्, _ди_, maus,
   {{0x7d1b93c3,0x2fc734e1,0x38690ec9,0x69c693c4}},	//   laus, nong_, _drar_, soke,
   {{0x66e648ad,0x69c60010,0x6b834cde,0x61e293c5}},	//   рова, poke, _iong, ymol,
   {{0x7ceb08fd,0x2fc77e69,0x7d1b93c6,0x3869003d}},	//   _görü, hong_, naus, _frar_,
   {{0x2fc73367,0x75364bdc,0xd6d90034,0x4432037a}},	// [9f00] kong_, rgyz, ęła_, uuy_,
   {{0x6b8393c7,0x2fc793c8,0xb6a61012,0xdb0893c9}},	//   _jong, jong_, _виол, vidë,
   {{0x6b8393ca,0x2fc70256,0x7d1b93cb,0xf3c9177a}},	//   _mong, dong_, kaus, ابقه_,
   {{0x7d1b1736,0x614623cb,0x6b830b87,0x443293cc}},	//   jaus, реда, _long, puy_,
   {{0x61e2003d,0x2056028d,0x7d1b6b26,0x443293cd}},	//   rmol, ртер, daus, quy_,
   {{0x2fc73103,0x799602ad,0x442093ce,0x6b8393cf}},	//   gong_, _llyw, msi_, _nong,
   {{0xf8d316f8,0x91e6001f,0x257c02c6,0x6d47007e}},	//   _सर्प, _вове, _síly_, đjan,
   {{0x44200fe9,0x6b8344ee,0xdb0893d0,0x442293d1}},	//   osi_, _aong, midé, _kvk_,
   {{0x6b834545,0x2fc70f4f,0x9f4c030b,0x4fea2249}},	//   _bong, bong_, _lidé_, _аман_,
   {{0x442093d2,0x2fc763ac,0x23c60abe,0xbea60426}},	//   isi_, cong_, वविद, _казк,
   {{0x6b8393d3,0x7d1b4848,0xdd8f007e,0x79960313}},	//   _dong, baus, _дш_, _blyw,
   {{0x442093d4,0x8c46062c,0x7d1b0054,0x442293d5}},	//   ksi_, _веде, caus, _ovk_,
   {{0xfce608c3,0x442093d6,0x6b8302cd,0x23c602d5}},	//   _тодо, jsi_, _fong, ववाद,
   {{0x8c1b0341,0x6b8300f3,0x442093d7,0x395f2224}},	//   _יודי, _gong, dsi_, žus_,
   {{0x7c222eb8,0x7bc831d4,0x61410018,0x442093d8}},	//   _hvor, modu, náló, esi_,
   {{0x4420068d,0x44f56752,0x39151693,0x2fc703e3}},	//   fsi_, спас, _умир, zong_,
   {{0x2fc734e1,0xe4e702ec,0x6b8393d9,0x442093da}},	// [9f10] yong_, рівн, _yong, gsi_,
   {{0x7bc893db,0x7d1b1056,0x473572bd,0xdb08014b}},	//   nodu, zaus, _унос, fidé,
   {{0x442093dc,0x7d1b0d2a,0xdb010ac9,0x00000000}},	//   asi_, yaus, rnlø, --,
   {{0x2fc702c9,0x442093dd,0xdb0805fe,0xf6500068}},	//   wong_, bsi_, sidè, _کئی_,
   {{0x442093de,0x2fc71c04,0x557600c1,0xe820009f}},	//   csi_, tong_, _הערן_, _बिछा_,
   {{0x645d93df,0x7d0293e0,0x7c2005db,0x7d1b0350}},	//   _issi, _afos, dsmr, waus,
   {{0x2fc712f5,0x22950080,0x7c2293e1,0x1ec90084}},	//   rong_, _الأس, _avor, ылки_,
   {{0x6b8393e2,0x56b800a1,0x2fc793e3,0xfe700286}},	//   _song, יפון_, song_, بده_,
   {{0x2fc793e4,0x6b8393e5,0x7d1b10a5,0x09d60033}},	//   pong_, _pong, raus, _সংলা,
   {{0x7c2245ca,0x6b9a02f1,0x61415944,0x7d1b93c6}},	//   _dvor, ghtg, báló, saus,
   {{0x6b8393e6,0x645d037a,0x44200103,0xb5170285}},	//   _vong, _lssi, zsi_, तराय_,
   {{0x442093e7,0x645d6c5f,0x6b831f06,0x2cbd023e}},	//   ysi_, _ossi, _wong, _txwd_,
   {{0x8d5a00a1,0x44200092,0x6b834ca9,0x3156006e}},	//   _תכני, xsi_, _tong, זירן_,
   {{0x6b830010,0x6b9a5abe,0x60db0a4b,0x442293e8}},	//   _uong, chtg, _mzum, _rvk_,
   {{0x645d1a91,0x7c222cea,0xdb1a0037,0x644f01d3}},	//   _assi, _zvor, altó, _apci,
   {{0x44201dd0,0x3f850201,0x7d190154,0x44220027}},	//   tsi_, _lolu_, _jews, _pvk_,
   {{0x7b060068,0x442093e9,0x60db0294,0x0326097a}},	// [9f20] _érté, usi_, _nzum, йдан,
   {{0x44209249,0x442228b6,0xdb08020d,0x3f850233}},	//   rsi_, _vvk_, tidé, _nolu_,
   {{0x645d93ea,0x60db93eb,0x644f037a,0x442202ac}},	//   _essi, _azum, _epci, _wvk_,
   {{0xf1a502ec,0x7d19128b,0x7bc83748,0x44204ca9}},	//   орін, _news, zodu, psi_,
   {{0x4420635c,0x3f8593ec,0x7bc893ed,0x629e3e15}},	//   qsi_, _bolu_, yodu, szpo,
   {{0x60db02ef,0xd8d700c1,0x6d4b6dd0,0x8b070d2a}},	//   _dzum, זונט_, _abga, _haƙƙ,
   {{0x3f850342,0x7c2293ee,0x60db00ac,0x644400c2}},	//   _dolu_, _svor, _ezum, ltii,
   {{0x656493ef,0x8afe03e3,0x7bc893f0,0xdd970138}},	//   ndih, _maƙe, wodu, йшы_,
   {{0x91e3062a,0x64446259,0x3f8500e7,0x5577006e}},	//   _хоте, ntii, _folu_, מעקן_,
   {{0x69df00dd,0x290200a5,0x3f85031a,0x29d91f11}},	//   _shqe, ecka_, _golu_, géan_,
   {{0x64d5009f,0x644400c2,0x1e9600d3,0x6d9c014b}},	//   _दर्श, htii, _урар, _réaf,
   {{0x7c220094,0x64441d2d,0x7bc893f1,0xb4db0065}},	//   _tvor, ktii, sodu, _gbàw,
   {{0x399b01e5,0xa3d81784,0x3f85008e,0xb901397e}},	//   _nëse_, ाता_, _yolu_, _थर_,
   {{0x0a94116d,0x68f61474,0x645d0036,0xdb010094}},	//   _малю, _egyd, _rssi, pilá,
   {{0x56944d40,0xa14300d9,0xd6d9007f,0x60cd00e8}},	//   парт, šķir, ęło_, ļami,
   {{0x64440188,0x69cd93f2,0x6d9c0076,0x00000000}},	//   ftii, _ukae, _déag, --,
   {{0x5fba2dfd,0x765e05aa,0x644483b8,0x49b83a1d}},	// [9f30] ेवाल, _espy, gtii, _داود_,
   {{0x6f1a93f3,0xed590141,0x2d86009c,0x6d9c00da}},	//   _netc, roži_, _looe_, _héad,
   {{0xd6d900cd,0x72b90037,0x644493f4,0xdb0102b6}},	//   _خودش_, جهاز_, atii, bilæ,
   {{0x644493f5,0x8f6a0103,0x00000000,0x00000000}},	//   btii, یلنے_, --, --,
   {{0x6d9c00e3,0x644400d3,0xaacf045f,0x4acf0c8c}},	//   _méad, ctii, _सुनक, _सुनव,
   {{0x6d4b02e7,0x8afe01c2,0x3f692bcf,0x7a0100e8}},	//   _sbga, _yaƙe, рико_, _lēta,
   {{0xfebb110a,0x29020149,0x623416dd,0xdee200ae}},	//   داشت_, ycka_, _неру, моши,
   {{0x7dc50018,0x23632230,0xfd650af0,0x6f1a01cb}},	//   lósz, _hajj_, _hotẹ, _eetc,
   {{0xa2b9018b,0x60db93f6,0xb4db009c,0x6d4b022b}},	//   ्थव्, _uzum, _ucàd, _vbga,
   {{0xb4db009c,0x3a250d66,0x09d200a4,0x6f1a93f7}},	//   _gcàe, омог, सत्य, _getc,
   {{0x2fc00076,0x291b063d,0x00000000,0x00000000}},	//   éige_, _beqa_, --, --,
   {{0x6d9c34cc,0x644400c2,0xbc750286,0xdb030503}},	//   _réag, ytii, _وهاب, _imní,
   {{0xe45f0d64,0x65642516,0x6d9c033c,0x00000000}},	//   _myös_, vdih, _déad, --,
   {{0x1af30033,0x6d490076,0x6d9c020d,0x7dde0216}},	//   _আজকে_, lfea, _péag, rëse,
   {{0xba7700bf,0xb8d1072d,0x6d9c00e3,0x28aa102d}},	//   _داشت, _टे_, _féad, _चेरि,
   {{0x644402fd,0xf50a439e,0x29d90037,0x6d491c5d}},	//   ttii, рнал_, néal_, nfea,
   {{0x92d600c7,0xd4672de0,0x2eb615e4,0x6d49152f}},	// [9f40] _হলে_, оите_, _अख्त, ifea,
   {{0x32d62da1,0x644493f5,0x213f005c,0x38602062}},	//   оцес, rtii, _acuh_, _isir_,
   {{0x64446e59,0x8b0703e3,0x66e610e0,0xe45f00ce}},	//   stii, _taƙƙ, _фона, _syöt_,
   {{0x6f1a027e,0x644493f8,0x38600090,0xdb0128b4}},	//   _setc, ptii, _ksir_, lilä,
   {{0xe0560241,0x29d90037,0x3860003d,0x6f1a93f9}},	//   تخاب, déal_, _jsir_, _petc,
   {{0x44320150,0x9e06100c,0x3940009c,0x6d4905db}},	//   mry_, очил, _lcis_, efea,
   {{0xdd9a11cc,0x44321890,0x38600090,0x59bc6dc1}},	//   иши_, lry_, _lsir_, ोकार,
   {{0x443293fa,0xed5912e8,0x127b006e,0xe45f007b}},	//   ory_, kožu_, _דאלע, _työt_,
   {{0x6d9c0037,0x61fc93fb,0x443293fc,0x386002a1}},	//   _réad, _hurl, nry_, _nsir_,
   {{0x4432061d,0x0b8a0c79,0x394001d3,0xdee623b9}},	//   iry_, рсии_, _acis_, _дози,
   {{0x9d46453b,0x44320146,0x61fc00c4,0xed5a00d3}},	//   _межд, hry_, _jurl, _вое_,
   {{0x44320185,0x61fc93fd,0x29d90076,0x6d490076}},	//   kry_, _murl, céal_, cfea,
   {{0x92d600c7,0x9f4c030b,0xdce90dd9,0x09bb023a}},	//   _হলো_, _lidí_, bjeđ, _उदीय,
   {{0x44320ed9,0xb4db01b9,0x61fc1d23,0xdceb00e8}},	//   dry_, _mbàt, _ourl, _ungā,
   {{0x61fc4881,0x99d70308,0x675700d1,0x386004d6}},	//   _nurl, _وتعا, میکس_, _esir_,
   {{0x443216e2,0x628309ab,0xa2cb87bf,0x00000000}},	//   fry_, änom, _तुष्, --,
   {{0xb9c40080,0x6fca0455,0x395993fe,0x94740037}},	// [9f50] _تقيي, ाकां, mess_, ودكا,
   {{0x395993ff,0x26c1023e,0xef1f0034,0x67e0007b}},	//   less_, _txho_, ążka_, töje,
   {{0xe7f9009d,0x443213e2,0x46d20aa1,0x415525e7}},	//   ंदवा_, ary_, _दुपह, звес,
   {{0x39595839,0xe1f8013f,0x44321670,0x6fd6020d}},	//   ness_, ігі_, bry_, lâch,
   {{0xa2cb1e18,0xf9940327,0x8caa0179,0x6d950139}},	//   _तुर्, ורף_, _जेलो, _dáal,
   {{0x23fa00a1,0xa3d30096,0xf8380796,0x00000000}},	//   _להשא, _हीच_, קנות_, --,
   {{0x61fc1081,0xc7b400a1,0xa3d80789,0xfe570018}},	//   _gurl, ובס_, ातर_, تیاب_,
   {{0x4c8505c7,0x673c0357,0xc17701f9,0x00000000}},	//   злив, zgrj, _بدست, --,
   {{0x29d90257,0x6d490037,0x2bc732c9,0xb7d50065}},	//   réal_, rfea, रकला, _eṣin,
   {{0x290d0634,0xeb990284,0x61fc0381,0x00000000}},	//   ñean_, сио_, _yurl, --,
   {{0xdb081f72,0x8a05013f,0xa96a1a0c,0x3860003d}},	//   cidí, язне, бина_, _ssir_,
   {{0x764702b6,0xc7a900ca,0x29d90113,0x499a14fb}},	//   dtjy, _גב_, béam_, стоя_,
   {{0xdb01007b,0x1a65001c,0x2d9f020b,0x00000000}},	//   tilä, زیکی_, mhue_, --,
   {{0xfaa55db8,0x44329400,0xed596a6a,0xceba01c2}},	//   _нало, vry_, lež_, laƙa_,
   {{0x70b8121d,0xa2cb00b6,0xa596008f,0xe3c30033}},	//   _अश्ल, _तुल्, пращ, ্গাব,
   {{0xf99f9401,0x39599402,0x44329403,0x394000ae}},	//   chè_, cess_, try_, _ucis_,
   {{0x8afe0022,0x386066ea,0x5fcb08c0,0xb6020072}},	// [9f60] _haƙa, _usir_, िवाल, ñába,
   {{0x44324827,0x8afe01c2,0xe7f93aee,0x61fc9404}},	//   rry_, _kaƙa, ंदरा_, _purl,
   {{0xe7170054,0xf8a900cd,0xdb08016d,0xaf6400d3}},	//   _מחיר_, _هدیه_, lidã, _хеyд,
   {{0xc69307a6,0xdb082f31,0x9f4c0146,0x8afe0022}},	//   _נאר_, vidí, _vidí_, _maƙa,
   {{0xed594f2f,0x8afe0022,0x6d9c0076,0x65665704}},	//   dež_, _laƙa, _léac, _iakh,
   {{0xa2a76bbd,0x8fa3470d,0xae0024cf,0x61fc9405}},	//   _टेक्, наче, _लंदन_, _turl,
   {{0x6566067d,0x8afe0022,0x9f4400e1,0x6d9c0037}},	//   _kakh, _naƙa, _sumó_, _réab,
   {{0x2d9f7fce,0x7a0101d3,0x25a00167,0x656602ac}},	//   ghue_, _pētn, nhil_, _jakh,
   {{0xf0440470,0x63ae0113,0xdb0824c7,0x00000000}},	//   _تعزی, _kmbn, sidí, --,
   {{0x65660060,0x8afe0022,0x25bf1206,0x0ea700c3}},	//   _lakh, _baƙa, čuli_, _केकड,
   {{0x395903e5,0x25a037e5,0xfbab0034,0xa9351acf}},	//   tess_, khil_, टोधम, менш,
   {{0x65669406,0x6d9c0503,0x2d9f9407,0x00000000}},	//   _nakh, _déac, chue_, --,
   {{0x39599408,0x25a09409,0x6d4200ae,0xf3ff0023}},	//   ress_, dhil_, _icoa, _trãi_,
   {{0x6d9c0080,0x395970ba,0x65660188,0xe7840392}},	//   _féac, sess_, _aakh, нусо,
   {{0x65660060,0x1db00980,0x45d5136e,0x00000000}},	//   _bakh, _जगात, довс, --,
   {{0xdb080428,0x98b901d3,0xcad700ca,0x00000000}},	//   lidà, nesī_, _מוות_, --,
   {{0x69cf0146,0x7a0800b6,0x764702b6,0x65660188}},	// [9f70] moce, _děte, stjy, _dakh,
   {{0x8afe0022,0x889c00ca,0xceba03e3,0x00000000}},	//   _yaƙa, _לבחי, zaƙa_, --,
   {{0xceba01c2,0xdb1a0052,0x6b8a009c,0x00000000}},	//   yaƙa_, entë, _mofg, --,
   {{0x25a00126,0x69cf3d46,0xc2c40076,0x00000000}},	//   chil_, noce, ريني, --,
   {{0x1b220081,0x237814f3,0x00000000,0x00000000}},	//   _মানে_, _fnrj_, --, --,
   {{0x65660060,0xceba03e3,0x69cf00d8,0x443b11bc}},	//   _zakh, waƙa_, hoce, muq_,
   {{0x6566067d,0x443b4c7c,0xed590128,0xb4db0032}},	//   _yakh, luq_, tež_, _gbàr,
   {{0x6d9c0257,0x962701d3,0xaad000c3,0x6d420169}},	//   _réac, _ieņē, _हड़क, _ccoa,
   {{0xcc89001c,0x8afe01c2,0x1c42007b,0x160400a4}},	//   زنده_, _saƙa, вным, _शंभर_,
   {{0x7d030103,0xdb080131,0x200d009c,0x6b8a030a}},	//   _bíró, vidã, _itei_, _cofg,
   {{0x52db30c3,0x7e7e0149,0xed592449,0xa3b502d5}},	//   _भरोस, äppt, pež_, _जगन_,
   {{0x69cf940a,0xdb08016d,0x2d828776,0x7c2e00e8}},	//   goce, tidã, öket_, ņbra,
   {{0x65664d8e,0xa3bf1fe6,0x8afe0022,0x6d5b0239}},	//   _rakh, ुका_, _waƙa, meua,
   {{0x6d9c00e3,0x6566211a,0x2480023e,0x8afe0d2a}},	//   _téac, _sakh, vxim_, _taƙa,
   {{0x25a00533,0xd5b20037,0x656627ae,0x63230033}},	//   thil_, نفس_, _pakh, মলায়_,
   {{0xdb1a00fd,0xdb080231,0x00000000,0x00000000}},	//   entè, pidã, --, --,
   {{0xdb08940b,0x656601af,0xb9b30037,0x70dc0034}},	// [9f80] lidá, _vakh, _جميع, _बरेल,
   {{0x61b81117,0x6566940c,0x212d0063,0x25a009f3}},	//   ेक्ष, _wakh, _adeh_, shil_,
   {{0x35a60077,0x6566940d,0x7c3b940e,0x2d9d0361}},	//   _жанг, _takh, huur, _olwe_,
   {{0xe0da8d75,0x7c3b0302,0x00000000,0x00000000}},	//   ове_, kuur, --, --,
   {{0x4fc62ca3,0x9fca00c2,0x7c3b31e8,0x7524940f}},	//   мска, огда_, juur, maiz,
   {{0x09bb1fb4,0x6d42002d,0x7c3b9410,0x69cf6c23}},	//   _उद्य, _scoa, duur, zoce,
   {{0x9f4c0072,0xa3da00c3,0x224700d3,0x00000000}},	//   _cidá_, _डीए_, _опри_, --,
   {{0x71760979,0x75249411,0x661a0031,0x7c3b041c}},	//   _تهرا, naiz, átky, fuur,
   {{0xe0435cac,0x69cf9412,0x00000000,0x00000000}},	//   _инти, voce, --, --,
   {{0x547b006e,0x75249413,0x2d9d02ac,0x7e7e02c3}},	//   קטיו, haiz, _elwe_, äpps,
   {{0x69cf8e0c,0xa3e606ed,0xd33700a1,0x75249414}},	//   toce, _पठन_, וריה_, kaiz,
   {{0x7c3b2de7,0x38720e3e,0x443b00a7,0x752400e7}},	//   buur, _bryr_, yuq_, jaiz,
   {{0x3f8c909f,0xc3240081,0x7dde023b,0x1b220033}},	//   _kodu_, _পানি_, lëso, _মাঠে_,
   {{0xeaaf037f,0xac9700bf,0xd90f110a,0x36d52436}},	//   اعی_, _تنها_, دیک_, еогр,
   {{0x3f8c9415,0xdce2050d,0x8afe03e3,0x9f450072}},	//   _modu_, _maoč, _haƙo, _pilú_,
   {{0x7bda9416,0x693600b6,0x75240062,0x00000000}},	//   lltu, _přež, gaiz, --,
   {{0x33752155,0xdb1a020d,0x7dde0052,0x3f9e5123}},	// [9f90] нгар, enté, hëso, _oltu_,
   {{0xdce204eb,0x7dde023b,0x8afe03e3,0x443b12d4}},	//   _naoč, këso, _maƙo, ruq_,
   {{0xaad4009f,0xe3c30081,0x443b17f4,0x6d5b9417}},	//   _ठुमक, ্গলব, suq_, yeua,
   {{0x59f907a6,0x3f9e20a3,0x7c3b008c,0x00000000}},	//   פּעד, _altu_, yuur, --,
   {{0x443b0092,0x3f8c0146,0x00000000,0x00000000}},	//   quq_, _bodu_, --, --,
   {{0x28b20179,0xdee52383,0x6d4001d0,0x63b102c6}},	//   ीपति, ноли, egma, édně,
   {{0xdb080161,0x53340291,0x6d8701ff,0x442b0381}},	//   xidá, _јест, _iñaz, _hvc_,
   {{0x8afe03e3,0x6d4072d4,0x7bda029a,0x212d0085}},	//   _baƙo, ggma, eltu, _udeh_,
   {{0x44290652,0x00000000,0x00000000,0x00000000}},	//   nsa_, --, --, --,
   {{0x44299418,0x2d820222,0x7c3b008a,0xdaa924f7}},	//   isa_, öker_, ruur, звод_,
   {{0xd94633a0,0x44299419,0x752f0034,0x7c3b442e}},	//   нени, hsa_, _odcz, suur,
   {{0x3f870039,0xaca30134,0xa96a0291,0x442b05db}},	//   ljnu_, _ajụk, чима_, _ovc_,
   {{0xaacf06e4,0x44291135,0xb9081024,0x7524013f}},	//   _सुरक, jsa_, _भर_, vaiz,
   {{0x7d092f48,0x4429941a,0x660800d2,0x57da00a4}},	//   lces, dsa_, ídko, णतेह,
   {{0x44292555,0x7c29941b,0x959a00ae,0x7c260146}},	//   esa_, lser, птау_, škrt,
   {{0x6d9c1872,0xe7e000aa,0x442b941c,0x79e80103}},	//   _léan, _खीरा_, _bvc_, _توبہ_,
   {{0x7c29395a,0x4429941d,0x64a3115e,0xb4ea009d}},	// [9fa0] nser, gsa_, гата, मधे_,
   {{0x68e4941e,0x6d9c00fd,0x00000000,0x00000000}},	//   _izid, _néan, --, --,
   {{0x4429941f,0x7d090034,0x442b01cb,0x7c290365}},	//   asa_, kces, _evc_, hser,
   {{0x7d0900cc,0x44295837,0xf1a91f11,0x3f8c9420}},	//   jces, bsa_, وانه_, _sodu_,
   {{0x44299421,0xe814009d,0x3f9e0085,0x7c2902b6}},	//   csa_, तीचा_, _pltu_, jser,
   {{0x6d9c00e3,0x7c299422,0x7dde00dd,0xa2cb09c3}},	//   _céan, dser, tëso, _तुक्,
   {{0x6d9c054f,0xa3b5087c,0xa3bf3db8,0xa2e32569}},	//   _déan, _जगत_, ुकर_, _борд,
   {{0x7dde00dd,0x7bc39423,0x7c290364,0x69d6010a}},	//   rëso, _ajnu, fser, _nkye,
   {{0x7c299424,0x68e4009c,0xdb0302c3,0x00000000}},	//   gser, _nzid, _omnä, --,
   {{0x6d9c07d4,0x1fb5016c,0x69d69425,0x8c530037}},	//   _géan, _исхр, _akye, ائيا,
   {{0x7c29010a,0x7dde023b,0x533700c1,0x68e49426}},	//   aser, qëso, ענטן_, _azid,
   {{0x44299427,0x7d098c44,0x23a40149,0x00000000}},	//   ysa_, cces, _höjd_, --,
   {{0xa3d0149b,0x44290092,0x7c290103,0xc17300ca}},	//   शवा_, xsa_, cser, אחר_,
   {{0x4429052f,0x69d60517,0x5c9708a1,0x49930103}},	//   vsa_, _ekye, _якія_, ئیکر,
   {{0x68e4019f,0x6be30037,0x67e00212,0x36d50859}},	//   _ezid, _حكوم, möjl, товр,
   {{0x44299428,0xd0080033,0xa3b30179,0xa2d40296}},	//   tsa_, রীয়_, जोन_, _बुध्,
   {{0x24580084,0x442b4d4b,0x98b90138,0xf3f90396}},	// [9fb0] нать_, _qvc_, mesį_, днаш_,
   {{0x69dd0013,0x23a40149,0x236a037a,0xf11900c3}},	//   llse, _nöjd_, _cabj_, दर्द_,
   {{0x44299429,0xa2d404f8,0x3a3e0085,0x290b0036}},	//   ssa_, _बुद्, nutp_, occa_,
   {{0x4429942a,0x5184942b,0x7c29942c,0x442b05fe}},	//   psa_, луча, yser, _tvc_,
   {{0x657d942d,0x349400c6,0x44294ea2,0x3f692813}},	//   _insh, _баяр, qsa_, дило_,
   {{0x656d942e,0x7c29942f,0x644d9430,0x67279431}},	//   ldah, vser, mtai, najj,
   {{0x644d9432,0x7c299433,0x8fa200c2,0x92580424}},	//   ltai, wser, раще, _парт_,
   {{0x7c299434,0x67279435,0x644d9436,0xdb1a3e15}},	//   tser, hajj, otai, kotó,
   {{0x644d9437,0xa3b56c66,0xdd8e0037,0x6d9c0037}},	//   ntai, _जगा_, توي_, _téan,
   {{0x7d090451,0x09ca0965,0x69dd7a1a,0x67278f15}},	//   sces, रव्य, else, jajj,
   {{0x644d9438,0x7c2932e8,0x34de04f8,0x61fb024a}},	//   htai, sser, _मर्द, _kiul,
   {{0x644d6b22,0x60db9439,0x61fb13eb,0x61e90113}},	//   ktai, _kyum, _jiul, _jhel,
   {{0x656d0188,0x8c451111,0x60db0027,0x201f0154}},	//   ddah, _реле, _jyum, _jwui_,
   {{0x644d943a,0x2d8f0ab2,0x69dd007a,0x290b0451}},	//   dtai, _hoge_, alse, acca_,
   {{0x644d0138,0x9f450037,0xe50f0129,0x61fb0172}},	//   etai, _chlé_, _ụmụn, _oiul,
   {{0x656d943b,0x2d8f943c,0x61e90090,0x61fb024a}},	//   gdah, _joge_, _nhel, _niul,
   {{0x60db54f0,0x2d8f943d,0xdb1a0143,0x6727083e}},	// [9fc0] _nyum, _moge_, cotó, bajj,
   {{0x657d083e,0x22ba02a3,0x61e956e2,0xf53f02b6}},	//   _ensh, وداع_, _ahel, _småt_,
   {{0x23a40222,0x644d02bc,0x179b00ca,0x61e94699}},	//   _nöje_, atai, _חייב, _bhel,
   {{0x61e9943e,0xc05a0565,0x644d943f,0x60db392d}},	//   _chel, дік_, btai, _byum,
   {{0xd0070465,0x61fb0918,0x644d9109,0x70542c66}},	//   вече_, _diul, ctai, انتا,
   {{0xdefa5c95,0x61e90188,0x2b4701c2,0x629702c3}},	//   мый_, _ehel, _ncnc_, byxo,
   {{0x764e16cf,0x61fb00ae,0xdb019440,0x29000634}},	//   ntby, _fiul, chlé, _ogia_,
   {{0x61fb9441,0x2d8f9442,0x61e99443,0x91e60582}},	//   _giul, _coge_, _ghel, _робе,
   {{0x9f4c00c2,0x00000000,0x00000000,0x00000000}},	//   _pidä_, --, --, --,
   {{0x5fb6007a,0x61380139,0x2b4703a8,0x02e600c3}},	//   _अगिल, _fúlà, _ccnc_, _कराह_,
   {{0x46d24422,0x2d8f016d,0x644d9444,0xdd920421}},	//   _दुलह, _foge_, ztai, _پوش_,
   {{0x2004466b,0x61e900dd,0xf2d303c2,0x2d8f38fa}},	//   _kumi_, _xhel, יעת_, _goge_,
   {{0x8c431300,0x1d072f93,0x69dd01df,0x656d3675}},	//   _вече, _речи_, rlse, vdah,
   {{0xa2cb009d,0x20049445,0xc7c400c2,0x29000a00}},	//   _तुझ्, _mumi_, асси, _egia_,
   {{0x6d9c00e3,0x20045a98,0xb9090033,0x98b204a8}},	//   _léam, _lumi_, _বল_, _dayı_,
   {{0xa2b80be4,0x644d02fd,0xa3b50b89,0x67270a15}},	//   ्पन्, ttai, _जगह_, sajj,
   {{0x6d9c10d1,0x656d9446,0x644d0441,0x2004020a}},	// [9fd0] _réal, rdah, utai, _numi_,
   {{0x644d4d01,0x61fb2e67,0x38699447,0xa49b022b}},	//   rtai, _siul, _isar_, _agòc,
   {{0x61e99448,0x644d9449,0x61fb7142,0x60db00dc}},	//   _phel, stai, _piul, _syum,
   {{0x656d01ee,0x200426f7,0x657d944a,0x386901c2}},	//   qdah, _bumi_, _unsh, _ksar_,
   {{0x20040193,0x7dde023b,0x628a00f2,0x443f020b}},	//   _cumi_, mësh, øfor, _êu_,
   {{0x2004944b,0x60db0239,0x720535bf,0x889c00ca}},	//   _dumi_, _vyum, _موسم, ובדי,
   {{0x61e9944c,0x28da0d88,0x6d9c0037,0x29d90076}},	//   _thel, _युनि, _téal, néas_,
   {{0x394901fa,0x61e9944d,0x20040451,0xdcfb042d}},	//   _ncas_, _uhel, _fumi_, njuć,
   {{0xa3d8009d,0x60db8151,0x66050113,0x2004944e}},	//   ातच_, _uyum, _luhk, _gumi_,
   {{0xceeb0f36,0x3949944f,0x799d0381,0x7dde0216}},	//   _قران_, _acas_, eksw, hësh,
   {{0x38699450,0x2004850e,0x2d8f0f8e,0x7dde023b}},	//   _asar_, _zumi_, _toge_, kësh,
   {{0x98b201d4,0xcd2b1ac9,0xa3b30179,0x7dde0216}},	//   _sayı_, _آسان_, जोत_, jësh,
   {{0x7d1b9451,0xc8b61855,0x98b2071d,0x672517d2}},	//   mbus, усны, _payı_, _behj,
   {{0x6a770134,0x394900b3,0x6c320103,0x399b0052}},	//   _ụfo, _ecas_, _افوا, _lësh_,
   {{0x386900f9,0x7d1b0098,0xf1d30296,0x857a00d3}},	//   _esar_, obus, तवान, нсат_,
   {{0xceb20341,0x29000072,0x7c3b0b8e,0x7dde0216}},	//   צין_, _ugia_, orur, gësh,
   {{0x69db0130,0x29d9020d,0x7c3b002b,0x764e9452}},	// [9fe0] _אַזו, réat_, nrur, stby,
   {{0x6d9c00e3,0x1c1b0f73,0xaca30174,0x7d1b00a7}},	//   _réam, पीएल_, _nkọk, hbus,
   {{0x77f700a1,0x20049453,0xdb9a00c1,0x399b0052}},	//   _תמיד_, _sumi_, עסער, _bësh_,
   {{0xaca3026e,0x7d1b6615,0x6288020d,0x20040090}},	//   _akọk, jbus, _àdom, _pumi_,
   {{0x25d700a1,0xdfda008f,0xa2d4142e,0x9f4500b3}},	//   _תוכן_, нък_, _बुर्, _niló_,
   {{0x7dde0052,0x7c3b01ff,0x7d1b09a1,0x00000000}},	//   mësi, drur, ebus, --,
   {{0x7dde023b,0x316d0063,0x44229454,0x75260154}},	//   lësi, _faez_, _hwk_, _kekz,
   {{0x6d9c00e3,0x7d1b9455,0x62810095,0xcbc00033}},	//   _téam, gbus, _šlog, _উঠেছ,
   {{0x5b262371,0x7dde023b,0x8afe0d2a,0x7c3b07ac}},	//   льна, nësi, _haƙi, grur,
   {{0x7fd600c6,0x752640cf,0x4a541828,0x44220350}},	//   _сібі, _lekz, акос, _mwk_,
   {{0x7dde023b,0x7d1b0653,0xd357021e,0xdee60a3a}},	//   hësi, bbus, ניטי_, _сожи,
   {{0xdb019456,0x7dde023b,0x8afe0022,0x6d950139}},	//   filó, kësi, _maƙi, _dáas,
   {{0x7c3b002d,0x7d020129,0xe9df0037,0x660500aa}},	//   crur, _igos, rlú_, _suhk,
   {{0x660532d2,0xb8fd4422,0xb8dd0336,0xa49b00fe}},	//   _puhk, _तँ_, _आध_, _ngòa,
   {{0x44224d87,0x7dde023b,0x39490063,0x8af600a7}},	//   _awk_, tësh, _tcas_, şəbb,
   {{0x442202fa,0x7c229457,0x39499458,0xdb010143}},	//   _bwk_, _kwor, _ucas_, biló,
   {{0x38697e46,0xfd4c0065,0x7dde0052,0x7d020a4b}},	// [9ff0] _usar_, _balẹ, rësh, _mgos,
   {{0x7c229459,0x660531e8,0x44f41b4b,0x1755008f}},	//   _mwor, _tuhk, спус, _твоя,
   {{0x8afe0d2a,0x316d037a,0x7c22010a,0x7d1b0565}},	//   _baƙi, _paez_, _lwor, ybus,
   {{0x7d02945a,0xd5671d7b,0x71270246,0x7dde0052}},	//   _ngos, _стоп, ارال, bësi,
   {{0xa0694a53,0xc3240081,0x8afe0022,0x656f945b}},	//   тала_, _পারি_, _daƙi, _iach,
   {{0x656f945c,0x645d024a,0x25a9945d,0xad9c0031}},	//   _hach, _ipsi, lhal_, _stĺp,
   {{0x656f65a1,0x244f0587,0x7c22026e,0xdce9033b}},	//   _kach, lüm_, _awor, rdeč,
   {{0x7c2205bd,0x7d1b822d,0x56b800ca,0x00000000}},	//   _bwor, ubus, טפון_, --,
   {{0x656f945e,0x7a0800b6,0x244f0367,0x23a40212}},	//   _mach, _dětm, nüm_, _höja_,
   {{0x656f945f,0x7d0200ac,0xe0d01915,0x7c3b9460}},	//   _lach, _egos, _رزق_, rrur,
   {{0x26e4000d,0xf98618c6,0x4acf149b,0x244f00a7}},	//   _गरेर_, агно, _सुखव, hüm_,
   {{0x656f374e,0x645d9461,0xa2b806ae,0xdb0100e3}},	//   _nach, _opsi, ्पत्, mhlí,
   {{0x25a9049b,0x6d5905bd,0x2d8d024a,0x00000000}},	//   dhal_, _ibwa, mjee_, --,
   {{0x656f9462,0xdca242b9,0x2d8d3cd7,0x2bdd00bc}},	//   _aach, _фаши, ljee_, _नीचा,
   {{0xb8fd03a2,0x645d013f,0xf50619cb,0xa3d90101}},	//   _तु_, _apsi, изво, ावन_,
   {{0x7dde01e5,0x25a901b5,0x6d9c00d1,0x44220167}},	//   tësi, ghal_, _réak, _pwk_,

   {{0x656f9463,0x044600d6,0x6fdf0257,0xf507002d}},	// [a000] _dach, резн, pêch, рнул_,
   {{0x7dde01e5,0x656f10f0,0xd76412eb,0x764f0103}},	//   rësi, _each, _اندی, önyö,
   {{0x656f9464,0x25a909f7,0x7afc02ef,0x6d590283}},	//   _fach, bhal_, žrtv, _obwa,
   {{0x656f9465,0x25a90d46,0xd2e60c8c,0x7dde023b}},	//   _gach, chal_, _करीब_, pësi,
   {{0x7dde00dd,0x2bc800b6,0x244f00ad,0x4422084e}},	//   qësi, िचमा, cüm_, _uwk_,
   {{0x656f0c6f,0x6d599466,0x087700c1,0x65649467}},	//   _zach, _abwa, יענט_, leih,
   {{0x8afe01c2,0x7c222bd4,0x69c6010a,0x00000000}},	//   _taƙi, _swor, knke, --,
   {{0x645d028d,0x25a07015,0x6d4b00b3,0xdceb026a}},	//   _ypsi, nkil_, _ccga, _algı,
   {{0xdb1a1e80,0xef863031,0x7f8631bb,0xa0671b29}},	//   entá, _клап, _پلان, _ката_,
   {{0x29120010,0x321a0451,0xbbd0030b,0x61e24d69}},	//   _afya_, oppy_, सकेक, llol,
   {{0xc33317f5,0x7ac630fd,0x244f008b,0x337700ca}},	//   חות_, рспе, züm_, בעים_,
   {{0x7d0203ce,0x7c2200a5,0x61e29468,0x244f04a8}},	//   _ugos, _twor, nlol, yüm_,
   {{0xa49b00b3,0xf99f028d,0xd8cb00d3,0xdd8f450f}},	//   _agòn, rkè_, тынд_, _تون_,
   {{0x656f9469,0x61e20201,0xb4db0065,0x69c6946a}},	//   _sach, hlol, _gbày, anke,
   {{0x656f825b,0x25f3009d,0x6d590063,0x00000000}},	//   _pach, ंगली_, _ybwa, --,
   {{0x656f11bc,0x8afe01c2,0x244f806d,0xf53f02c3}},	//   _qach, _saƙw, tüm_, _blåa_,
   {{0x656f8f2c,0x25a94d7a,0x61e20124,0xa5f8021c}},	// [a010] _vach, rhal_, dlol, рету_,
   {{0x656f946b,0x9f5e01e5,0x25a987fd,0x0a510068}},	//   _wach, _ditë_, shal_, _بھیج,
   {{0x656f6e3c,0xed592617,0x7dde0052,0x32552657}},	//   _tach, liže_, lësu, свер,
   {{0x656f1519,0x61e20270,0x2cad0167,0x5f1400b6}},	//   _uach, glol, yzed_, नुस्_,
   {{0xed590095,0x7dde0052,0x20670284,0x752d0172}},	//   niže_, nësu, рђев, maaz,
   {{0x8afe0022,0xa3b30034,0x28c800b6,0x94f600ca}},	//   _haƙu, जोश_, रपति, _לצרף_,
   {{0xed590ae3,0x61e20342,0x9f4502c6,0x69c6946c}},	//   гой_, blol, _uhlí_, ynke,
   {{0xa3b304dd,0x752d3eb7,0xdb1a946d,0x0d852135}},	//   जोर_, naaz, litè, слин,
   {{0x8afe03e3,0x00000000,0x00000000,0x00000000}},	//   _maƙu, --, --, --,
   {{0xed590106,0x4a450f50,0xdb1a00b3,0x2cad007f}},	//   diže_, бнов, nitè, rzed_,
   {{0x752d43e1,0x2cad0103,0x5f742519,0xc8691777}},	//   kaaz, szed_, _باقر, _רן_,
   {{0x6d59023f,0x6d4b0072,0xfe7000d1,0x752d010a}},	//   _ubwa, _ucga, _زدم_, jaaz,
   {{0xf1b2006e,0x63a7033b,0xb8860031,0x69c6946e}},	//   לסט_, _oljn, _opíš, rnke,
   {{0x6d49946f,0x6564042c,0x00000000,0x00000000}},	//   lgea, weih, --, --,
   {{0x78c10253,0x66e63f37,0xdb1a7a93,0x6b837376}},	//   _əvvə, сова, zitë, _inng,
   {{0x6d49107d,0x752d2721,0x7dde0216,0x00000000}},	//   ngea, gaaz, bësu, --,
   {{0x6d4902bc,0x79840bb6,0x656457f2,0x16041c83}},	// [a020] igea, _iniw, reih, _शंकर_,
   {{0x25a09470,0x65643661,0x799600eb,0x7dde0216}},	//   skil_, seih, _hoyw, qësv,
   {{0x61e21f91,0xb5ca1f11,0x752d083e,0x00000000}},	//   tlol, _مودم_, baaz, --,
   {{0x6146455b,0xd764110a,0x7a13044c,0xdb1a0216}},	//   седа, _انگی, _găte, titë,
   {{0x205639f5,0xe3b10068,0x61e20270,0xb033004d}},	//   стер, سرے_, rlol, зніш,
   {{0xfbc71673,0xdb1a023b,0x8afe03e3,0xe0850037}},	//   _رت_, ritë, _zaƙu, تجمي,
   {{0x44321081,0xe2970095,0x8afe01c2,0x00000000}},	//   lsy_, _лар_, _yaƙu, --,
   {{0x15fa099d,0xb8000081,0xdb1a9471,0x32180270}},	//   ्दिर_, ্ঠিত_, mité, _itry_,
   {{0xdb1a9472,0x44329473,0xfd0f33c6,0x6ab20b42}},	//   lité, nsy_, رجي_, ुप्र,
   {{0x320a9474,0x6d4901b9,0x7984039f,0x443200fc}},	//   _kuby_, agea, _aniw, isy_,
   {{0xa3d90c13,0xdd8f00ae,0x15f80e50,0x38600270}},	//   ावत_, _еш_, ंगार_, _apir_,
   {{0x394d9475,0x7dde023b,0xc27b006e,0x4432931c}},	//   ües_, tësu, ארטי, ksy_,
   {{0x8afe0022,0x80da0033,0xac9400e5,0x661701ff}},	//   _raƙu, _বৃত্, _фалш, _stxk,
   {{0x7dde00dd,0x44320185,0x81c00033,0x25750174}},	//   rësu, dsy_, ুতি_, _ụl_,
   {{0x9f5e0257,0x7bda9476,0x7a0201d3,0x2b4e039f}},	//   _cité_, motu, _vētr, _icfc_,
   {{0x7bda8149,0xb88600b6,0xdb1a014b,0x00000000}},	//   lotu, _spíš, dité, --,
   {{0x6eda007d,0x7dde00dd,0xe4500cd2,0xdb010037}},	// [a030] _पुसु, qësu, فضل_, mhlá,
   {{0xa3b300a5,0x68ed9477,0x7bda198b,0x9f5e00ee}},	//   जों_, _izad, notu, _fité_,
   {{0x7bc89478,0x3e4e00a7,0x752d9479,0x00000000}},	//   indu, _xətt_, paaz, --,
   {{0xa159947a,0x6b8401c2,0x764702a4,0x7bda00ce}},	//   раду_, _ɗiga, mujy, hotu,
   {{0x7bda11cf,0x7bc80113,0x00000000,0x00000000}},	//   kotu, kndu, --, --,
   {{0x8cdc000f,0xa2b80557,0x65aa0146,0xd9cf0081}},	//   _पड़ो, ्पश्, _výhe, রতিম,
   {{0x35f80979,0xdb1a0257,0x7bda163d,0x80da0081}},	//   _خرید_, cité, dotu, _বৃদ্,
   {{0xa2b80f77,0xd0d5013d,0x68ed033b,0x7bc800bc}},	//   ्पर्, _добъ, _ozad, endu,
   {{0x6d49006b,0x320a0146,0x6aad01c2,0x77ab00a7}},	//   rgea, _zuby_, _ƙafo, _müxb,
   {{0x6d49947b,0x212f01f7,0xdfdb008f,0xa49b010a}},	//   sgea, lagh_, _съб_, _ngòm,
   {{0x68ed01d4,0x198a013d,0x386011d3,0x68000065}},	//   _azad, абни_, _spir_, _lájì,
   {{0x7bc8947c,0x00000000,0x00000000,0x00000000}},	//   andu, --, --, --,
   {{0xa3d91fbb,0x629e00a5,0xa2e65620,0x7bda947d}},	//   ावा_, zypo, _कर्ज_, botu,
   {{0x6b8300d6,0x212f009c,0x6aa401c2,0x7c24947e}},	//   _unng, hagh_, _ƙift, _çira,
   {{0xa50a48bd,0x68ed083e,0x4432007f,0x672e947f}},	//   иева_, _ezad, wsy_, rabj,
   {{0x44329480,0xdb1a025a,0x38600193,0xdb010037}},	//   tsy_, vité, _tpir_, chlá,
   {{0x212f01b9,0x290500b6,0x32180313,0x7ae30216}},	// [a040] dagh_, ělat_, _stry_, _hynt,
   {{0x44329481,0x212200c0,0x629e08b6,0xdb1a014b}},	//   rsy_, मर्श_, typo, tité,
   {{0x7a0802c6,0x82660037,0x68ed0361,0x00000000}},	//   _pěti, تهان, _zzad, --,
   {{0x00e62d06,0xdb1a6772,0x7bda0239,0x7ae32fe3}},	//   ожен, rité, zotu, _mynt,
   {{0x7bda0051,0x7bc8003e,0xdb1a9482,0x629e00d8}},	//   yotu, yndu, sité, sypo,
   {{0x2d994437,0x8fa32b79,0xdb1a033c,0x63be0052}},	//   ösen_, маче, pité, qipn,
   {{0x59ca00a8,0xf8bf020d,0x24540324,0x7bda9483}},	//   ाचार, mbée_, läm_, votu,
   {{0xdc1e0081,0x68e40372,0x6ebe0285,0xb4db00b3}},	//   _দিবস_, _oyid, _वेणु, _icàr,
   {{0xc5f317f5,0x7bda9484,0x2717030b,0x0b8a1510}},	//   ודה_, totu, nění_, асни_,
   {{0xa3ea00c0,0x68ed0034,0xdfa60076,0x00000000}},	//   मति_, _rzad, _بحري, --,
   {{0x7ae302ad,0x7bda9485,0xddc800e7,0x6d9c020d}},	//   _cynt, rotu, _irdž, _béat,
   {{0x7bda45e6,0x6d9c0076,0x00000000,0x00000000}},	//   sotu, _céat, --, --,
   {{0x7bda9486,0xa3ea0176,0x76470169,0x00000000}},	//   potu, मता_, wujy, --,
   {{0x271700b6,0x68ed0146,0xc6a740c9,0xdb010037}},	//   dění_, _vzad, орби, shlá,
   {{0x7ae30150,0xb5c90037,0x387e01d3,0xa3d900bc}},	//   _gynt, موسم_, ātra_, ावस_,
   {{0x76470169,0xdb0109a1,0x00000000,0x00000000}},	//   rujy, gilõ, --, --,
   {{0x5fbc030b,0x68ed9487,0x6d9c0037,0xcb0e0096}},	// [a050] ्चाल, _uzad, _héas, _सलाड_,
   {{0x69dd9488,0xd3710037,0x7a350174,0x9f4c00b3}},	//   lose, عها_, _ẹtit, _midó_,
   {{0xe8d900ac,0xdb0101a5,0x21180134,0xc3240033}},	//   _mbọ_, silö, _ịtụl, _পাখি_,
   {{0xe0d30979,0x6b980c08,0x45d50077,0x661a2fd3}},	//   وزش_, _lovg, _хомс, ítke,
   {{0x29090124,0x951600a1,0x212f2bc0,0x65a300aa}},	//   _mgaa_, _מקרא_, ragh_, _lõhk,
   {{0x1b220081,0x69dd9489,0x62351fc4,0xed5905db}},	//   _মাঝে_, hose, _негу, diža_,
   {{0x69dd948a,0x2909008c,0x3ce90357,0xc2250103}},	//   kose, _ogaa_, _šav_, _رکاو,
   {{0xdceb03e5,0xe8d90032,0x2909948b,0x69dd7b12}},	//   _jogħ, _abọ_, _ngaa_, jose,
   {{0x65a30006,0xdceb122d,0xcc3500e3,0x7ae33611}},	//   _põhj, _bagā, أربع, _synt,
   {{0x5ba902aa,0x29090134,0xdceb03e5,0x7ae321ad}},	//   ском_, _agaa_, _logħ, _pynt,
   {{0xe9da0dde,0x7a1300ae,0x539c006e,0x0dcb004d}},	//   йко_, _băta, ייזו, _куди_,
   {{0x2005068d,0x69dd023b,0x186a00a9,0x200d0113}},	//   _hili_, gose, бами_, _kuei_,
   {{0xda0b0034,0x6d5b0239,0xa3db0966,0x7ae314bd}},	//   _सूरत_, mfua, डका_, _wynt,
   {{0x8c1a0327,0x2005948c,0xa2d400b6,0xe8d90af0}},	//   _הוסי, _jili_, _बुझ्, _gbọ_,
   {{0x20053045,0xcb1200a1,0x69dd948d,0xdceb0078}},	//   _mili_, _אלו_, bose, _bogħ,
   {{0xf992003f,0x2005948e,0x7bc1948f,0x271700b6}},	//   _سبب_, _lili_, lilu, tění_,
   {{0x02c4009d,0x68e40372,0xddc101d3,0xb4db009c}},	// [a060] वप्न, _uyid, _aplū, _scàr,
   {{0x287b00ca,0x20050027,0x6b8401c2,0x7a0802c6}},	//   _פנימ, _nili_, _ɗigo, _větv,
   {{0x479b0130,0x179b00c1,0x6d9c0076,0x51860d86}},	//   _הייס, _הייב, _méar, зула,
   {{0x7bc19490,0x6d9c00e3,0x80da0081,0xddc8050d}},	//   hilu, _léar, _বৃষ্, _srdž,
   {{0xd12f0adc,0x752477c2,0x7bc19491,0x212d0167}},	//   امه_, mbiz, kilu, _deeh_,
   {{0x20059492,0x46db0fef,0xb60200b6,0x69dd2395}},	//   _cili_, _मुँह, žáda, zose,
   {{0xa3d988ba,0x20052a78,0x44209493,0x9f4c0139}},	//   ावर_, _dili_, lpi_, _bidò_,
   {{0xdceb9494,0x6606882f,0x77ab0092,0x6d9c0037}},	//   _xogħ, _jikk, _müxa, _réas,
   {{0x20059495,0x6d9c0037,0x4420464d,0x6606242f}},	//   _fili_, _béar, npi_, _mikk,
   {{0x0b8a02fd,0x6d9c0037,0x66069496,0x7bc19497}},	//   ссии_, _céar, _likk, gilu,
   {{0x46db0251,0x6d9c0037,0x64440188,0x200d0634}},	//   _मुंह, _déar, hrii, _zuei_,
   {{0xdb1a9498,0x6d9c0314,0x7524009e,0x644422b0}},	//   mití, _véas, jbiz, krii,
   {{0x7bc19499,0xdb1a46b5,0x200504d6,0x80a20096}},	//   bilu, lití, _yili_, _कॅमे,
   {{0xe8d90174,0x20050188,0x6d9c0076,0x69dd949a}},	//   _nnụ_, _xili_, _géar, sose,
   {{0x6a1300e3,0xe3c40081,0x6606949b,0x69dd04e4}},	//   _كبير, ্তাব, _bikk, pose,
   {{0x66060068,0xe8d900ac,0x1c1102d5,0x64440d67}},	//   _cikk, _anụ_, _डूडल_, frii,
   {{0x6606949c,0x53992787,0xa3d90006,0x442007ac}},	// [a070] _dikk, овая_, ावल_, gpi_,
   {{0x25ef04a9,0x3374002d,0x9f5e949d,0x212d0483}},	//   _आठवी_, нгур, _bití_, _seeh_,
   {{0x35f50097,0xdb0101bf,0x4420949e,0x41557b27}},	//   _опор, chlä, api_, двес,
   {{0x64444d4e,0x7bc1949f,0x9f5e0139,0x77770090}},	//   brii, zilu, _dití_, _haxx,
   {{0x2005068d,0x200d008f,0x3ce6023e,0x77770078}},	//   _pili_, _quei_, _nyov_, _kaxx,
   {{0xdee519d4,0xedf71432,0xdb1a0037,0x1fa900ae}},	//   моли, ुद्ध_, antú, юкли_,
   {{0x7bc103e5,0x44394ba8,0x6d5b0063,0xdb030094}},	//   vilu, _hvs_, tfua, _plní,
   {{0x200594a0,0x6d9c0076,0x4439058f,0x6d5b0350}},	//   _wili_, _séar, _kvs_, ufua,
   {{0x7bc194a1,0x752f0034,0x200594a2,0xdce001d3}},	//   tilu, _mecz, _tili_, temā,
   {{0x752f00a5,0x44391a4a,0x7777009e,0xdb1a00d4}},	//   _lecz, _mvs_, _naxx, bití,
   {{0xd9461cfe,0x7bc194a3,0x44200a00,0x69030092}},	//   мени, rilu, zpi_, ətdə,
   {{0x7bc194a4,0x442094a5,0x442b0113,0x1eea00d1}},	//   silu, ypi_, _owc_, _بومی_,
   {{0x660694a6,0x7bc1002d,0x6d9c00e3,0x77770078}},	//   _rikk, pilu, _téar, _baxx,
   {{0x660605a3,0x7777028d,0x752494a7,0x80da0033}},	//   _sikk, _caxx, wbiz, বেক্,
   {{0x66060d80,0x7a08000d,0x66e3550a,0x1db10557}},	//   _pikk, _děts, вора, _जतात,
   {{0x3dcd0078,0x644431e8,0x443994a8,0x442b94a9}},	//   nnew_, trii, _bvs_, _bwc_,
   {{0xdb1a0447,0xa3d9009d,0x3ce6006c,0x75241415}},	// [a080] zití, ावं_, _xyov_, rbiz,
   {{0x443994aa,0x644418c1,0x66068d81,0xf7720281}},	//   _dvs_, rrii, _wikk, _شاخ_,
   {{0x660694ab,0xb4db0139,0x6444007a,0x27ed0044}},	//   _tikk, _adàd, srii, ɓen_,
   {{0x64a60077,0x644494ac,0x290400e7,0x6d9c0113}},	//   _жама, prii, žmau_, _néap,
   {{0xdb1a0131,0xd4360076,0x3ddf100d,0x00000000}},	//   nitã, _تعجب, douw_, --,
   {{0x43757491,0xa3d90374,0x2ab40139,0x28c5023a}},	//   _пуст, ावः_, _jùbé_, _लेफि,
   {{0x7c2b0150,0xa3db0592,0x63a394ad,0x00000000}},	//   _awgr, डकर_, önne, --,
   {{0x5c743407,0x65a30006,0xbdf70037,0xdd900037}},	//   елит, _põhi, وريا_, اوة_,
   {{0xfc3f0094,0x212637e5,0x9b6a075f,0x00000000}},	//   šín_, mboh_, ошна_, --,
   {{0x7d0b01ce,0x7ac60097,0xdb1a0565,0x00000000}},	//   _eggs, дсме, nntø, --,
   {{0xa3b61349,0x3ddf0ab2,0x2d9a020d,0xf0d20294}},	//   _जतन_, bouw_, êpes_, tịwọ,
   {{0x9e650068,0x2378022b,0x00000000,0x00000000}},	//   _سامن, _larj_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xead401ef,0x2cb00511,0xf0d20174,0x65a300bc}},	//   _поль, ıldı_, sịwọ, _jõhv,
   {{0xbd050257,0xf8ae0260,0x443901ce,0xb9060469}},	//   _théâ, لکی_, _svs_, _बु_,
   {{0xfaa700cd,0xdb1a312c,0x96f81107,0x65aa00d4}},	//   _تجهی, lità, фест_, _dýho,
   {{0xdce900cc,0x94ab059b,0x7777003d,0x245800c2}},	// [a090] rdeć, цтва_, _taxx, мать_,
   {{0x44393502,0xdb1a94ae,0x08f80037,0x7c2d0342}},	//   _vvs_, nità, _غريب_, _çare,
   {{0x69cf0036,0x00000000,0x00000000,0x00000000}},	//   once, --, --, --,
   {{0x77b00222,0x442b016d,0x67354eb8,0x34954cc3}},	//   _växe, _twc_, lazj, _замр,
   {{0x251a0266,0x6d9c020d,0x656d0a4b,0xe7050281}},	//   _מורא, _réap, meah, _تسکی,
   {{0x644d5cbf,0x673510a4,0xf41f007b,0x25a900f9}},	//   muai, nazj, _itä_, lkal_,
   {{0x644d9432,0x9ea92766,0xdb1a00b3,0x00000000}},	//   luai, явка_, dità, --,
   {{0x69cf94af,0xf41f0212,0x25a95ff7,0xdcfb0206}},	//   jnce, _träd_, nkal_, rhuľ,
   {{0x644d095a,0x3ddf01c0,0xcc89001c,0x25a901ff}},	//   nuai, rouw_, سنده_, ikal_,
   {{0x3dcd03a9,0x69cf2198,0x656d0ab4,0x00000000}},	//   snew_, ence, heah, --,
   {{0x25a90068,0xfaa503a0,0x644d0037,0x39ea0aca}},	//   kkal_, хано, huai, здно_,
   {{0x9f470146,0x6dc70f36,0x65a300aa,0x186a1b60}},	//   dlné_, _غزال, _kõhu, пами_,
   {{0x290432ee,0x00000000,0x00000000,0x00000000}},	//   äma_, --, --, --,
   {{0x644d94b0,0xdb1a015e,0x2d9d94b1,0xd7f20037}},	//   duai, cità, _howe_, اكس_,
   {{0x2d9d1a7b,0x7a0900b6,0x8b560142,0x25b200d7}},	//   _kowe_, _větr, _ניקס_, thyl_,
   {{0x65aa0074,0xdb1a016d,0x644d0037,0x060794b2}},	//   _výho, pitã, fuai, енск_,
   {{0xd46711b7,0x04430ba4,0xb4db0139,0xdb1a8652}},	// [a0a0] ните_, летн, _adàb, litá,
   {{0x69c694b3,0x213f113a,0x32d61102,0xdb010076}},	//   like, _aduh_, нцес, dhlú,
   {{0xdb1a2257,0x814600e3,0xb1468d01,0x69c6007b}},	//   nitá, فنان, енел, oike,
   {{0x69c694b4,0x2d9d00a5,0x764e09b7,0x644d94b5}},	//   nike, _nowe_, muby, buai,
   {{0x764e0735,0x644d061d,0x765c0f05,0x00000000}},	//   luby, cuai, ltry, --,
   {{0x69c694b6,0x7bcf020d,0x75364881,0x00000000}},	//   hike, écul, layz, --,
   {{0x201f94b7,0x412a08c3,0xda0b00a3,0x765c94b8}},	//   _etui_, _ново_, _संगत_, ntry,
   {{0xc69302f8,0x2c2600d6,0x7c240491,0x69c6019f}},	//   ראה_, ньог, _çirk, jike,
   {{0x2d9d498a,0x61e21f98,0x764e0124,0x9f5e00b3}},	//   _dowe_, mool, huby, _tità_,
   {{0x61e294b9,0x765c00a5,0x394094ba,0x161600c3}},	//   lool, ktry, _adis_, _दूभर_,
   {{0x69c694bb,0xdb1a94bc,0x3f8c94bd,0x656d0350}},	//   fike, gitá, _indu_, yeah,
   {{0x248000cb,0x765c017a,0x69c64006,0xed5a11ba}},	//   kvim_, dtry, gike, _ход_,
   {{0x3f9e006d,0xfbcf12eb,0x644d137f,0x65aa00b6}},	//   _kotu_, شتی_, xuai, _výhl,
   {{0x8c1b07a6,0x3940705f,0x61e294be,0x36d594bf}},	//   _צווי, _edis_, hool, вогр,
   {{0x61e294c0,0x69c694c1,0x61eb12ba,0xc987004d}},	//   kool, bike, ylgl, _зупи,
   {{0x644d94c2,0x3f9e94c3,0xf0a600de,0x61e20172}},	//   tuai, _lotu_, _đành_, jool,
   {{0x798d94c4,0x321194c5,0x656d01af,0x61e20f23}},	// [a0b0] _inaw, _suzy_, reah, dool,
   {{0x25a994c6,0x644d02bc,0x38691415,0x65a300aa}},	//   skal_, ruai, _ipar_, _rõhu,
   {{0x644d3cb8,0x325508d1,0x68070139,0x9f45009c}},	//   suai, твер, _eéjì, _ghlù_,
   {{0x7aea0052,0x27e34b03,0x2472022b,0x00000000}},	//   _myft, lojn_, _fņm_, --,
   {{0x7aea0ce7,0x3f9e7dd6,0x798d0239,0x75360142}},	//   _lyft, _botu_, _mnaw, _בארד_,
   {{0x69c694c7,0x10a20284,0xdb1a7f1d,0x27e3801a}},	//   zike, ришн, litæ, nojn_,
   {{0x69c694c8,0x61e294c9,0xdb1a0072,0x798d94ca}},	//   yike, bool, xitá, _onaw,
   {{0xfc3f025b,0x61e294cb,0x68fb0138,0xdb1a94cc}},	//   ším_, cool, žudy, vitá,
   {{0x69c694cd,0x2a6700dc,0x27e30216,0x39400231}},	//   vike, _spnb_, kojn_, _rdis_,
   {{0x09ca0454,0x798d94ce,0x2d9d0193,0x69c605bd}},	//   ाच्य, _anaw, _wowe_, wike,
   {{0x69c694cf,0x2fc794d0,0x386900d3,0x799f02ac}},	//   tike, ming_, _apar_, _boqw,
   {{0xaca30174,0x765c25e5,0xf8bf002b,0x798d00eb}},	//   _amụk, vtry, rbén_, _cnaw,
   {{0x69c6154c,0x2fc7014b,0x764e0169,0xddc701f9}},	//   rike, oing_, wuby, _élőb,
   {{0x69c694d1,0x7c3b005c,0x764e0ff4,0x765c40d6}},	//   sike, msur, tuby, ttry,
   {{0x66e6534f,0x2c1900c7,0x7bc379f8,0xcf920341}},	//   това, _দিয়ে_, _imnu, סטל_,
   {{0x2fc794d2,0x7d1b0335,0xceb2040a,0x765c0429}},	//   hing_, ncus, ביל_, rtry,
   {{0x2fc77f31,0xe8fa0465,0x69c40034,0x7c3b0707}},	// [a0c0] king_, _юли_, _imie, nsur,
   {{0x2fc756ba,0x7c3b94d3,0x69c40090,0x2480078e}},	//   jing_, isur, _hmie, rvim_,
   {{0x2fc794d4,0x248003ce,0x61e294d5,0x69c40078}},	//   ding_, svim_, tool, _kmie,
   {{0x3ea702ad,0x7c3b78bc,0x248d09ac,0x2fc70133}},	//   dynt_, ksur, _šeme_, eing_,
   {{0x61e27c19,0x20564c46,0xdfda008f,0x7c3b007e}},	//   rool, ттер, мък_, jsur,
   {{0x2fc794d6,0x61e2424e,0x35c8009f,0xa3b6030b}},	//   ging_, sool, _रगड़, _जति_,
   {{0x61e2520d,0x69c494d7,0x3ea7004d,0x8fa30284}},	//   pool, _omie, gynt_, раје,
   {{0x442294d8,0x2b4903e3,0x69d605bd,0x27e31175}},	//   _ktk_, _ɓace_, _njye, zojn_,
   {{0x2fc71336,0xe817000f,0x7aea0149,0x7c3b94d9}},	//   bing_, _धंधा_, _syft, gsur,
   {{0x2fc77100,0x69c472b8,0x69d60027,0x7d1b0036}},	//   cing_, _amie, _ajye, acus,
   {{0x38698599,0x19590109,0x7c3b00ca,0x23a402c3}},	//   _spar_, наны_, asur, _höjs_,
   {{0x200c0051,0x9f450383,0x79a72fd4,0x7aea0313}},	//   _hidi_, _aklè_, трое, _vyft,
   {{0xa3e2034c,0x200c03e3,0x27e3801a,0x6d4201ff}},	//   दवा_, _kidi_, tojn_, _idoa,
   {{0x7c2294da,0x656629bb,0x7c2d3177,0x69c4354c}},	//   _itor, _abkh, _çara, _emie,
   {{0xf8bf0303,0xc6a40f94,0x200c94db,0xda7a008f}},	//   mbém_, арти, _midi_, _цял_,
   {{0x7c226a90,0x798d94dc,0x200c00b6,0x2fc70bcc}},	//   _ktor, _unaw, _lidi_, zing_,
   {{0x2fc70054,0x7bc80023,0x80a20096,0x38690131}},	// [a0d0] ying_, oidu, _कॅले, _upar_,
   {{0x69c417b5,0x68ed025e,0x02a700d6,0x200c4d09}},	//   _zmie, _iyad, крем, _nidi_,
   {{0x9f5e02fd,0x2fc794dd,0x75d50c5e,0xf53f0537}},	//   _mitä_, ving_, _ميدا, _blåt_,
   {{0xc6920132,0x7bc806ee,0x7c2294de,0xdb1a0924}},	//   _האט_, hidu, _otor, litä,
   {{0x2fc794df,0x200c8795,0x7bc894e0,0x7c2294e1}},	//   ting_, _bidi_, kidu, _ntor,
   {{0x657d94e2,0xfc3f0074,0xdb1a32f4,0x2fc70313}},	//   _hash, šík_, nitä, uing_,
   {{0x657d449d,0x7c2294e3,0x7bc81a2a,0x6e951487}},	//   _kash, _ator, didu, العا,
   {{0x657d01e5,0x7c3b620e,0xec793c14,0x3ea73918}},	//   _jash, tsur, епи_, rynt_,
   {{0x2fc794e4,0x657d94e5,0x61e994e6,0x7c3b3f3d}},	//   ping_, _mash, _ikel, usur,
   {{0x657d94e7,0x7c3b94e8,0x69c494e9,0x7d1b0e04}},	//   _lash, rsur, _smie, scus,
   {{0x7c2202a7,0xdb1a94ea,0x68ed0188,0x7c3b8ce3}},	//   _etor, entó, _ayad, ssur,
   {{0xdea30068,0xaca300ac,0x68ed0512,0x7c3b020a}},	//   _میڈی, _atụm, _byad, psur,
   {{0x7bc894eb,0x8c450950,0x2d8f071e,0x68ed0169}},	//   bidu, _селе, _inge_, _cyad,
   {{0x657d0188,0x7bc30201,0x442294ec,0x00000000}},	//   _aash, _umnu, _rtk_, --,
   {{0x657d94ed,0x442208ca,0x69c4003d,0x61e994ee}},	//   _bash, _stk_, _tmie, _okel,
   {{0x657d94ef,0x69c42ac2,0xaca30174,0x60db0092}},	//   _cash, _umie, _njịk, _oxum,
   {{0x657d2db0,0x68ed0022,0x81cc0033,0xa49b01ec}},	// [a0e0] _dash, _gyad, রকম_, _sgòr,
   {{0x55033b4f,0x61e994f0,0x61fb0634,0x00000000}},	//   спуб, _akel, _ahul, --,
   {{0x657d94f1,0xf53f02c3,0x200c94f2,0x61fb94f3}},	//   _fash, _plåt_, _ridi_, _bhul,
   {{0x61fb94f4,0x657d94f5,0x22470146,0x200c94f6}},	//   _chul, _gash, ánka_, _sidi_,
   {{0x442206ee,0x261a000f,0x61fb0694,0x8fa6385a}},	//   _utk_, _मंडी_, _dhul, ладе,
   {{0x61e90129,0x2d8f94f7,0x61fb0134,0x7bc815d3}},	//   _ekel, _ange_, _ehul, xidu,
   {{0x200c02e6,0x657d66ba,0x61fb0527,0x29120172}},	//   _vidi_, _yash, _fhul, _ogya_,
   {{0x9f5e02fd,0x7bc800a5,0x200c060f,0xdb1a0364}},	//   _sitä_, widu, _widi_, zitä,
   {{0x161600aa,0x00000000,0x00000000,0x00000000}},	//   _दूसर_, --, --, --,
   {{0x291294f8,0x99860138,0x2d8f94f9,0xc01700ca}},	//   _agya_, kslų_, _enge_, _עקבו_,
   {{0x7bc894fa,0xdb1a0868,0x68ed02e7,0x7c220034}},	//   ridu, vitä, _syad, _wtor,
   {{0x2eb0099d,0x6d590372,0x764100c6,0x00000000}},	//   जनीत, _gcwa, šlyk, --,
   {{0x657d1114,0x7bc894fb,0x8c430cb0,0x3dc6041c}},	//   _rash, pidu, _гече, _imow_,
   {{0x657d1114,0x2912083e,0x68ed0350,0x00000000}},	//   _sash, _egya_, _vyad, --,
   {{0x657d94fc,0xdb1a94fd,0x8b65001c,0x163500e5}},	//   _pash, ritä, _خانم, ребя,
   {{0x657d94fe,0xca470037,0x2912010a,0xdb1a3c00}},	//   _qash, _إليه_, _ggya_, sitä,
   {{0x657d94ff,0xdb1a473d,0xf53f5e11,0xdce20094}},	// [a0f0] _vash, pitä, _slås_, _oboč,
   {{0x61fb068d,0x657d6288,0x61e99500,0x7e7a13c5}},	//   _shul, _wash, _skel, _ostp,
   {{0x657d23a9,0x92590084,0x56952972,0x61fb9501}},	//   _tash, тает_, _тант, _phul,
   {{0x657d6108,0x00000000,0x00000000,0x00000000}},	//   _uash, --, --, --,
   {{0x752d60fe,0xdcf902a1,0x00000000,0x00000000}},	//   mbaz, _vawċ, --, --,
   {{0x44299502,0x3f691012,0x644d01b5,0x61fb0085}},	//   mpa_, тико_, mrai, _whul,
   {{0xfd1100e3,0xf774006e,0x644d03dc,0x660f9503}},	//   يجة_, מקס_, lrai, _kick,
   {{0x1c450feb,0x644d009b,0x44299504,0xada500c2}},	//   аним, orai, opa_, раил,
   {{0x44294263,0x644d0514,0xdb180149,0xdb0a00ee}},	//   npa_, nrai, _omvä, _alfà,
   {{0x5ba91229,0x44299505,0x7ff70037,0x644d014b}},	//   тком_, ipa_, _إسرا, irai,
   {{0x644d71e0,0xaa4900e5,0x44293678,0x00000000}},	//   hrai, ъпна_, hpa_, --,
   {{0x2d8f1484,0x44290294,0x660f9506,0x644d1e06}},	//   _unge_, kpa_, _nick, krai,
   {{0xac2700ae,0x00000000,0x00000000,0x00000000}},	//   _сфек, --, --, --,
   {{0x644d17fa,0x7c2914a5,0xdcfb2461,0x317f01ff}},	//   drai, mper, nduč, _lauz_,
   {{0xe73708a4,0x62850094,0x644d9507,0x44290325}},	//   рес_, jvho, erai, epa_,
   {{0x644d700a,0xf53f0501,0x248d9508,0xa52600c6}},	//   frai, _slår_, _šema_, рмад,
   {{0x644d9509,0x660f950a,0x7c29950b,0xb4250b05}},	// [a100] grai, _dick, nper, معلو,
   {{0xdb0101df,0xdcfb7a52,0x7c29950c,0xcb1200c1}},	//   rklæ, jduč, iper, ַלד_,
   {{0x673c1253,0x644d0a02,0x660f950d,0x4429950e}},	//   marj, arai, _fick, apa_,
   {{0x7c29950f,0x673c9510,0x442900f9,0x644b237a}},	//   kper, larj, bpa_, ágic,
   {{0x6604198c,0x644d0a6c,0x261c002b,0xc05a00ae}},	//   mmik, crai, _hío_, трец_,
   {{0x673c9511,0x7c297706,0x66041b65,0xa3ca34d8}},	//   narj, dper, lmik, _ऋषि_,
   {{0x2eb000c3,0x7c299512,0xe2979513,0x00000000}},	//   जनेत, eper, _кар_, --,
   {{0x91e31b4d,0xef1800d9,0x261c058a,0x127b0142}},	//   _досе, _daļa_, _mío_, _באלע,
   {{0x673c53d4,0x7c299514,0x261c00e1,0x0cb40033}},	//   karj, gper, _lío_, ঞপ্ত,
   {{0x673c668c,0xeb064e66,0xed59042d,0x2d991489}},	//   jarj, ично, dižu_, öser_,
   {{0x673c9515,0xdb0101bf,0x77b00212,0x3218172e}},	//   darj, chlü, _växl, _jury_,
   {{0x44299516,0x644d00f0,0xdb0102c3,0x6e2a042c}},	//   ypa_, yrai, dklä, mpfb,
   {{0x660f9517,0x98b20154,0xf7730037,0x00000000}},	//   _rick, _feyč_, ياس_, --,
   {{0x644d04ea,0x673c9518,0x261c034f,0xdb010364}},	//   vrai, garj, _bío_, fklä,
   {{0x7a1300ae,0x660f9519,0x6b9c003e,0x321800b3}},	//   _bătu, _pick, örgu, _nury_,
   {{0x644d951a,0xd5b8438d,0x48ab3283,0x38600078}},	//   trai, асу_, _атом_, _fqir_,
   {{0x644d951b,0x752d789a,0x673c951c,0xdb010037}},	// [a110] urai, rbaz, barj, bhló,
   {{0x644d951d,0x4429951e,0x261c03be,0x673c8318}},	//   rrai, rpa_, _fío_, carj,
   {{0x4429951f,0x644d9520,0x7c299521,0x660f4d02}},	//   spa_, srai, zper, _tick,
   {{0xf5950cd2,0x48fe030b,0x2eb0099d,0x9f470094}},	//   _الحج, रेको_, जनैत, dlná_,
   {{0x702200c7,0xe0d000b9,0xf8bf00fc,0x7655007f}},	//   _নিউজ_, وزه_, nzé_, luzy,
   {{0x9f4700dd,0xa29502b7,0x32180133,0x00000000}},	//   monë_, _лагі, _fury_, --,
   {{0x7c29029a,0x98ab007f,0x9f470216,0x00000000}},	//   wper, racę_, lonë_, --,
   {{0x7c290331,0x673c9522,0x9f4501b5,0x98b202f1}},	//   tper, zarj, _chlò_, _seyč_,
   {{0xb4f52918,0x7c2900b3,0x00000000,0x00000000}},	//   _आरोप_, uper, --, --,
   {{0x7c299523,0xe4fa045f,0x451d0033,0x66049524}},	//   rper, ्धति_, তরিক_, zmik,
   {{0x673c9525,0x23b6003e,0x9f470216,0x00000000}},	//   varj, _jæja_, honë_, --,
   {{0x261c0fb6,0x3e613e43,0x7c299526,0x00000000}},	//   _río_, mót_, pper, --,
   {{0x673c9527,0x3e610103,0xd2f4030b,0xa2f40096}},	//   tarj, lót_, _अर्ब_, _अर्ज_,
   {{0xab260aec,0x261c167e,0xdca2025d,0x7a13020a}},	//   _лоша_, _pío_, _хаши, _sătu,
   {{0x66049528,0x673c7eee,0x7a13044c,0x00000000}},	//   tmik, rarj, _pătu, --,
   {{0x673c9529,0xd01f0081,0xdb011683,0x09e300e5}},	//   sarj, নীয়_, rklä, _нощн,
   {{0x6604952a,0x673c4811,0xdb0117a5,0x2cad01f9}},	// [a120] rmik, parj, sklä, nyed_,
   {{0x261c7176,0x2a6e037a,0xe29a1a0c,0xccf2021e}},	//   _tío_, _ypfb_, лаз_, לכן_,
   {{0xdb1a08a8,0x9f4c0019,0xdd110090,0x3e610155}},	//   titú, _đoàn_, _ażżm, jót_,
   {{0xdcff02c6,0x3e617d11,0x00000000,0x00000000}},	//   ávěr, dót_, --, --,
   {{0x2eb002c6,0x00000000,0x00000000,0x00000000}},	//   जन्त, --, --, --,
   {{0xc05902ec,0xd9a5009d,0xdefa0084,0x25b267cc}},	//   рії_, _ऑक्ट, лый_, lkyl_,
   {{0x877b006e,0xf77300ca,0xf8bf01f9,0x645655a3}},	//   ראצי, פקה_, zzé_, luyi,
   {{0x25a0952b,0x6576952c,0x00000000,0x00000000}},	//   njil_, neyh, --, --,
   {{0x77b00149,0x5bb82a6e,0xe0da0291,0xdb030154}},	//   _växj, илия_, _сва_, _honè,
   {{0xf8bf0257,0xdb030c45,0x7f43007b,0x00000000}},	//   ncée_, _konè, _неуж, --,
   {{0x77ab0092,0xc3330796,0x25a00167,0x139b006e}},	//   _müxt, הות_, kjil_, אביע,
   {{0xdb037a93,0x6456952d,0xadfa0281,0xada31a1b}},	//   _zonë, kuyi, _صراط_, _нахл,
   {{0xacf61ac9,0x5c0607bf,0xdb030154,0x99920154}},	//   _اسات, _ляка, _lonè, _miyň_,
   {{0x7bcf0257,0xda34002d,0x00000000,0x00000000}},	//   écut, _декы, --, --,
   {{0x7bca5e0a,0x28c500aa,0x00000000,0x00000000}},	//   _imfu, _लइकि, --, --,
   {{0xa2b10134,0x2d84952e,0xf9930568,0x645601b2}},	//   _dọ́l, ndme_, _ربع_, fuyi,
   {{0x64a40303,0x69cf952f,0x34949530,0x3e610103}},	// [a130] паѓа, mice, патр, zót_,
   {{0x261a00a5,0xdb03022b,0x00000000,0x00000000}},	//   _मूवी_, _bonè, --, --,
   {{0xdb030472,0x02d90bf4,0xa5f913a4,0x00000000}},	//   _conè, جواب_, _вену_, --,
   {{0x9f4c0019,0x64563944,0x00000000,0x00000000}},	//   _đoán_, buyi, --, --,
   {{0x3dcd9531,0x8fa51612,0xa6bb0033,0x7bca0372}},	//   view_, жале, _উখিয়, _omfu,
   {{0xb4b500df,0x3e610018,0x62350131,0x320607ac}},	//   जनी_, tót_, _мегу, amoy_,
   {{0x69cf9532,0x998900a5,0x82a40095,0x24891800}},	//   kice, _miał_, _еште, lvam_,
   {{0x0c257f94,0x63a730e6,0xec4911b4,0x3e619533}},	//   омин, _hojn, азил_, rót_,
   {{0x9f473d7f,0x00000000,0x00000000,0x00000000}},	//   yonè_, --, --, --,
   {{0x4a454cb0,0x39498cf4,0x61eb9534,0xfbc5004d}},	//   онов, _adas_, logl, ібно,
   {{0xe9da17e9,0x69cf9535,0x63a79536,0x30240065}},	//   ико_, fice, _mojn, _iṣọp,
   {{0x61eb9537,0x69cf26a1,0x7a1300ae,0x3949037a}},	//   nogl, gice, _bătr, _cdas_,
   {{0x7a13002d,0x3e4501d3,0xdb0300fd,0x3079006e}},	//   _cătr, lēt_, _moné, באָנ,
   {{0x63a7023e,0xe7371728,0x25b90124,0xab291896}},	//   _nojn, жер_, _alsl_, _тока_,
   {{0x320600f9,0x6b833e2c,0x3e4501d3,0x316d2af9}},	//   ymoy_, _iang, nēt_, _obez_,
   {{0x28c50b5f,0x6d5b6f6e,0x6b831bf5,0x452a235c}},	//   _लेकि, ngua, _hang, ржан_,
   {{0x6b839538,0x61eb9539,0x63a745ca,0x6d5b0072}},	// [a140] _kang, dogl, _bojn, igua,
   {{0x6b834263,0x79844584,0x7c2400e3,0x7986029a}},	//   _jang, _haiw, _éire, ldkw,
   {{0x6b83953a,0x79840044,0xe5a6268e,0x61eb037c}},	//   _mang, _kaiw, _дини, fogl,
   {{0x61eb953b,0xdb03953c,0x3e4501d3,0x216a1412}},	//   gogl, _coné, dēt_, риди_,
   {{0x63a71197,0x79840bb6,0x00da0e00,0x6d5b01af}},	//   _fojn, _maiw, جبات_, dgua,
   {{0x6b83953d,0x69cf9159,0x5f9363a7,0x6d4f2e9a}},	//   _nang, zice, дишт, ócan,
   {{0x179b0054,0xdb1a00dd,0xdb035b86,0x4420953e}},	//   ייסב, shtë, _foné, lqi_,
   {{0x6b8301aa,0x7984953f,0x61eb008f,0x6d5b028d}},	//   _aang, _naiw, cogl, ggua,
   {{0x64446d14,0x69cf9540,0x442000a7,0x2d820031}},	//   nsii, vice, nqi_, ľke_,
   {{0x6b830706,0x705300bf,0x64442a8b,0x628e0146}},	//   _cang, _آنلا, isii, _krbo,
   {{0x7984006d,0x3e4500d9,0x6b839541,0x261a00aa}},	//   _baiw, cēt_, _dang, _मूली_,
   {{0x64442a3c,0x6b839542,0x798401cb,0x7bcf014b}},	//   ksii, _eang, _caiw, écur,
   {{0x6d409543,0xdd8f1850,0x6b837b5f,0x28c50efb}},	//   mama, _جون_, _fang, _लेखि,
   {{0x6d409544,0x69cf9545,0x7bca0201,0xcb670291}},	//   lama, sice, _umfu, _даље_,
   {{0x69cf9546,0xb5a71aad,0x00000000,0x00000000}},	//   pice, орай, --, --,
   {{0x6d409547,0x6b839548,0x9f47001c,0x63a7023e}},	//   nama, _zang, roné_, _sojn,
   {{0x6b835eea,0xb4b53029,0x63a7006c,0x5455013d}},	// [a150] _yang, जने_, _pojn, яват,
   {{0x6d407441,0x6b839549,0xc2e90081,0x7bda0088}},	//   hama, _xang, _কৃষি_, nntu,
   {{0x6d40954a,0x250909e5,0x65aa0579,0x64441f98}},	//   kama, _گردی_, _výhr, asii,
   {{0xf67a0130,0x1a9b00c1,0x05b90068,0x63a70034}},	//   _פארמ, ייבע, _اگست_, _wojn,
   {{0x6d40954b,0x859a00a1,0x61eb954c,0x628e4f43}},	//   dama, _השרו, rogl, _erbo,
   {{0x3e4501d3,0xf8bf002b,0x61eb954d,0x4439030a}},	//   tēt_, lbés_, sogl, _iws_,
   {{0x4439954e,0x3135188d,0x628e0542,0x69cd31e8}},	//   _hws_, _невр, _grbo, _omae,
   {{0x6d406299,0x753d0067,0x44390197,0x7bda954f}},	//   gama, _jesz, _kws_, entu,
   {{0x6b836c54,0x6d5b2928,0xe80000b6,0x3e4500e8}},	//   _pang, rgua, ोगमा_, sēt_,
   {{0x69dd04ea,0x753d3c90,0x6d5b2df7,0x69cd00f0}},	//   éren, _lesz, sgua, _amae,
   {{0x656f272c,0x44399550,0xddc800d9,0x9ee90b05}},	//   _obch, _lws_, žoša, _افضل_,
   {{0x6d400ca9,0x6b839551,0x7bda0084,0x6444008a}},	//   cama, _wang, antu, ysii,
   {{0x6b830498,0x44391071,0x3f859552,0x442b9553}},	//   _tang, _nws_, _kalu_, _ntc_,
   {{0x61a8055e,0x79840d2a,0x6b839554,0x3f859555}},	//   _कक्ष, _waiw, _uang, _jalu_,
   {{0x753d0068,0x79849556,0x44399557,0xcf9200c1}},	//   _besz, _taiw, _aws_, עטל_,
   {{0x3f852129,0x741600e3,0x644432d2,0xe5a31e00}},	//   _lalu_, كورا, tsii, ниси,
   {{0x39420006,0x75243ab5,0xa5070a18,0x753d9558}},	// [a160] maks_, rciz, зета_, _desz,
   {{0x6d409559,0x6444008a,0xb903955a,0x4420955b}},	//   zama, rsii, _язык, rqi_,
   {{0x442b919e,0x753d0018,0x64441d94,0x681200b6}},	//   _etc_, _fesz, ssii, _vědě,
   {{0x628e037d,0x443905dd,0x80cd0d75,0x6d408d56}},	//   _vrbo, _fws_, _देहे, xama,
   {{0x6d40273b,0x3f85955c,0x4420955d,0x9f450206}},	//   vama, _balu_, qqi_, _sklá_,
   {{0x6d4b955e,0x6d40955f,0x661e0218,0x68f600c2}},	//   _adga, wama, _kupk, _myyd,
   {{0x6d4092e9,0x7c2b00d9,0x3f8509eb,0x59dc01e4}},	//   tama, _atgr, _dalu_, मचार,
   {{0x80cd10e9,0x3942007a,0x661e00e7,0x4439022e}},	//   _देवे, jaks_, _mupk, _yws_,
   {{0x6d409560,0x661e00cc,0x44390197,0x6f020139}},	//   rama, _lupk, _xws_, _bíbí,
   {{0x6d402ce8,0x3f8519db,0x7bda484c,0xdb1a00d4}},	//   sama, _galu_, untu, bitý,
   {{0x21fc030b,0x39429561,0x6d463640,0x29009562}},	//   ního_, faks_, ókas, _azia_,
   {{0x6d409563,0x629a00fd,0x4efb0089,0x3f850381}},	//   qama, _àtou, _פלאג, _zalu_,
   {{0x2ac2025a,0x753d2214,0x3a204582,0x6f0238e9}},	//   _bébé_, _resz, _čipu_, _fíbí,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x248200dc,0x39429564,0x21fc02c6,0xf1bf0206}},	//   _askm_, baks_, jího_, úška_,
   {{0x4439030a,0x3ea1007b,0x69cd0350,0x00000000}},	//   _pws_, ähti_, _umae, --,
   {{0x753d0068,0xf8bf0921,0x44397a17,0x2d8603a9}},	// [a170] _vesz, rbés_, _qws_, _maoe_,
   {{0x6ad00081,0x442b00de,0x051d0033,0x443901cb}},	//   _সুযো, _vtc_, তরের_, _vws_,
   {{0x753d0068,0x22470103,0x69dd9565,0x27e40031}},	//   _tesz, énk_, onse, émne_,
   {{0x69dd9566,0x31354441,0x3f859567,0x442b0257}},	//   nnse, федр, _salu_, _ttc_,
   {{0xc5fb055e,0x3f859568,0x656d9462,0xa2d900c3}},	//   ्षीय_, _palu_, mfah, _मशक्,
   {{0x1408009d,0xdfd10037,0x6f1a00ee,0x69dd9569}},	//   वगृह_, ضيع_, _cgtc, hnse,
   {{0x21fc030b,0x63a30088,0x3f85956a,0x3f870559}},	//   cího_, önnu, _valu_, rdnu_,
   {{0x69dd01c0,0x656d0364,0x629a1912,0xa4c0020e}},	//   jnse, nfah, _štog, nüşü_,
   {{0xfc050752,0x3f855e8b,0x3942007a,0x9f470428}},	//   мпио, _talu_, vaks_, loní_,
   {{0x765500a5,0xdb1a956b,0x6d460e2e,0x656d956c}},	//   krzy, ditó, ókar, hfah,
   {{0xf1c4030b,0x39420d2f,0x29000018,0x8eb51ac9}},	//   लोकन, taks_, _szia_, _تماش,
   {{0x6d4b01c5,0xbcb508d8,0x7f430188,0x68f600c2}},	//   _udga, _обещ, lanq, _pyyd,
   {{0xe87c0390,0x21fc00b6,0x656d0364,0x76550034}},	//   _düşü, zího_, dfah, erzy,
   {{0x39420006,0xa84d00d2,0x00000000,0x00000000}},	//   saks_, énář_, --, --,
   {{0xdb03025b,0xe9d20037,0x7bc1956d,0x7a4202c6}},	//   _koní, _لغة_, mhlu, _vítá,
   {{0x68f6007b,0x656d042c,0x29000062,0x9f4700b3}},	//   _tyyd, gfah, _tzia_, doní_,
   {{0xd4670f86,0x600405fe,0x0443430b,0x261a0442}},	// [a180] мите_, lòme, кетн, _मंकी_,
   {{0x7bc1956e,0x67220f35,0x21fc02c6,0x7655007f}},	//   nhlu, _मलिक_, tího_, brzy,
   {{0x38cb00bf,0xa3af05a7,0x213f1ae5,0xf8bf300f}},	//   _هایی_, _ओकर_, _beuh_, ncén_,
   {{0x20052cb2,0xbbaa143d,0x765c0193,0x60430129}},	//   _ahli_, _चक्क, mury, _ọmar,
   {{0x7bc126f7,0x3940956f,0x98b9044c,0x00000000}},	//   khlu, _meis_, masă_, --,
   {{0x39401884,0x443212fb,0xdce001d3,0x7bc115c0}},	//   _leis_, mpy_, zemē, jhlu,
   {{0x9e061b42,0xdb03015e,0x2e4a008f,0x69dd9570}},	//   мчил, _boní, цяло_, ynse,
   {{0xdb0303a4,0x39409571,0x248d0a39,0x9f5e015e}},	//   _coní, _neis_, _šemi_, _pitó_,
   {{0xa06a2c52,0xf1bd0034,0xdb030032,0x9f5e0154}},	//   _фаза_, ्फरन, _doní, _ditò_,
   {{0x765c9572,0x0a6a14f8,0x7bc19573,0x5f46001c}},	//   kury, орми_, ghlu, _آنال,
   {{0x6fb3001c,0xdb030032,0x8aa3004d,0x68fa00a7}},	//   _جملا, _foní, вряд, ətdi,
   {{0x2480061d,0x8d930037,0x2b490022,0x81b00033}},	//   kwim_, _للمش, _ɓaci_, টোর_,
   {{0x69dd9574,0x394000e3,0xc8644785,0x7bc101fa}},	//   rnse, _deis_, ктри, bhlu,
   {{0x765500a5,0x7bc13cd9,0x60040428,0xdb1a3210}},	//   trzy, chlu, lòmb, ritó,
   {{0xc1ee0789,0x39400cc2,0xdb1a11e9,0x656d0364}},	//   जवाब_, _feis_, sitó, tfah,
   {{0x69d60103,0xdb1a00b3,0x656d0350,0x00000000}},	//   ézet, pitó, ufah, --,
   {{0x656d9575,0xe9df0220,0xa4c007e7,0x439500c6}},	// [a190] rfah, mnú_, rüşü_, наас,
   {{0x765c0193,0xe9df0220,0x63a5023e,0x76550034}},	//   bury, lnú_, ujhn, przy,
   {{0x77b00149,0x33f40212,0xe9df0076,0xd5bc0032}},	//   _växt, växt_, onú_, _kọ́_,
   {{0xe9df9576,0x9f470428,0x397c006e,0x7d020415}},	//   nnú_, roní_, ַטונ, _ozos,
   {{0x660d2bc5,0xe4e700d6,0x7f43016f,0xd46b0037}},	//   mmak, _цінн, tanq, _بحجم_,
   {{0x660d9577,0xe9df00e3,0x01c90018,0x409208ba}},	//   lmak, hnú_, _کورٹ_, الور,
   {{0xfe710814,0x7f430165,0x7bc1022e,0xd346001c}},	//   ادت_, ranq, vhlu, _سینه_,
   {{0x660d9578,0x22470618,0x4c850b31,0xe9df0031}},	//   nmak, ánku_, елив, jnú_,
   {{0xe9df0181,0x7c2d003d,0xcc880023,0x7d02007f}},	//   dnú_, _ħars, _cớ_, _czos,
   {{0x3940132d,0x660d9579,0x5ac90ed7,0xdd1d078e}},	//   _seis_, hmak, злом_, _fâşi,
   {{0xa3b705a7,0xd5bc0032,0x660d957a,0x777c002b}},	//   _जवन_, _bọ́_, kmak, verx,
   {{0x3ce003ce,0x29d200cc,0x7bc1957b,0x6004015e}},	//   _žive_, ršao_, shlu, ròme,
   {{0x777c002b,0x6e210063,0xdd1c02c6,0xb4ae0d75}},	//   terx, _hulb, ušťk, _कथे_,
   {{0x39400364,0x29d200e7,0x660d6473,0x387f0131}},	//   _weis_, pšao_, emak, çura_,
   {{0x3940957c,0xe9df0220,0xd5bc0032,0x6e2102c3}},	//   _teis_, bnú_, _fọ́_, _julb,
   {{0x660d4327,0x6e2112dc,0x3869009e,0x64a6004b}},	//   gmak, _mulb, _fqar_, наба,
   {{0x765c957d,0x98b9020a,0xe4062d06,0xe45a32f8}},	// [a1a0] sury, rasă_, езап, яжа_,
   {{0x26cc538a,0xb4e00096,0x43860cd2,0x6456930b}},	//   údos_, _तशी_, علاق, rryi,
   {{0x27ff01c2,0x00000000,0x00000000,0x00000000}},	//   ɓun_, --, --, --,
   {{0x64a611fb,0xe0462249,0x5066433f,0x4432957e}},	//   _зама, енди, етка, ppy_,
   {{0x248000dc,0x351b00ca,0x00000000,0x00000000}},	//   qwim_, _מוכנ, --, --,
   {{0xe9df2e92,0x8fa3290e,0xf41f007b,0x442201ff}},	//   znú_, лаче, _eräs_, _iuk_,
   {{0x539b0054,0x44223d79,0xa3dd00aa,0x6e21483a}},	//   _צילו, _huk_, तचर_, _culb,
   {{0x4422957f,0xf41f0212,0xa7fb037a,0x6e21773e}},	//   _kuk_, _gräs_, muñe, _dulb,
   {{0x4422013f,0xe9df0220,0x63ae0106,0xfc2f010d}},	//   _juk_, vnú_, _kobn, یحی_,
   {{0x7ac61af2,0x660d00d9,0x4f840018,0xcc880023}},	//   есме, zmak, _جارہ, _vớ_,
   {{0x19590109,0x2ec616c4,0xe9df0220,0x6e219580}},	//   маны_, _ثقاف, tnú_, _gulb,
   {{0xcc880019,0x3ce601fa,0xdb0300b3,0x44220154}},	//   _tớ_, _txov_, _donà, _ouk_,
   {{0x44220910,0xe9df0220,0x98b8008f,0x00000000}},	//   _nuk_, rnú_, елят_, --,
   {{0xc5fb04dd,0x8c1b00ca,0xe9df4205,0xaa5800d3}},	//   ्ष्य_, _זוגי, snú_, _жику_,
   {{0x44229581,0x660d9582,0xd5bb43cb,0x2bf70327}},	//   _auk_, tmak, пса_, _רמון_,
   {{0x7c220084,0x6b8a5a43,0x00000000,0x00000000}},	//   _kuor, _hafg, --, --,
   {{0x660d32b0,0x442214cb,0x63ae0117,0x6d4f0076}},	// [a1b0] rmak, _cuk_, _bobn, ócai,
   {{0x44220a75,0x7c22008f,0x660d8614,0x9f470094}},	//   _duk_, _muor, smak, koná_,
   {{0xdb030146,0x660d1c18,0xdb18034f,0xd25b0792}},	//   _koná, pmak, _olví, яца_,
   {{0xa2d50454,0x3e4c000d,0x248d09ac,0xdb03421d}},	//   _येण्, dět_, _šemu_, _joná,
   {{0x7c220ff8,0xf8b30f42,0x7f4100dd,0xdb03002b}},	//   _nuor, ुनिय, _pelq, _moná,
   {{0x25a99583,0x6e219584,0x7f410216,0xdb0a022b}},	//   ljal_, _pulb, _qelq, _tofè,
   {{0x44220a00,0x00000000,0x00000000,0x00000000}},	//   _zuk_, --, --, --,
   {{0x25a99585,0x44220194,0xc6940341,0x63ae0087}},	//   njal_, _yuk_, ראק_, _zobn,
   {{0x7c22013d,0x6d42002d,0x1c420138,0xdb0100a7}},	//   _cuor, _deoa, аным, sklü,
   {{0x8b952383,0x7c22010a,0x6e219586,0x629500e7}},	//   трич, _duor, _tulb, _krzo,
   {{0x25a92e17,0x00000000,0x00000000,0x00000000}},	//   kjal_, --, --, --,
   {{0x7c22013d,0x645f0201,0x62950a39,0x3eba004d}},	//   _fuor, kuqi, _mrzo, øpte_,
   {{0xef1800d9,0x2d9d00ac,0xbb850037,0xdb0354fc}},	//   _daļu_, _inwe_, _للشي, _doná,
   {{0x4422057a,0x00000000,0x00000000,0x00000000}},	//   _ruk_, --, --, --,
   {{0xf7430cf5,0x44229587,0x7c22042c,0xdceb00c6}},	//   ресо, _suk_, _zuor, _pagė,
   {{0x63ae9588,0x645f0052,0xef1800e8,0x00000000}},	//   _sobn, fuqi, _gaļu_, --,
   {{0x62950328,0x63ae023e,0xa5239589,0x00000000}},	// [a1c0] _arzo, _pobn, рмуд, --,
   {{0x44220039,0x35c60034,0x25a900bc,0x00000000}},	//   _vuk_, रोज़, ajal_, --,
   {{0x2002013f,0xdb030018,0x2d9d06c0,0xb9930504}},	//   _ūkio_, _elnö, _onwe_, _صلیب,
   {{0xa7fb03be,0x25a94695,0x2c6b02b6,0x3e4c02c6}},	//   ruñe, cjal_, kød_, vět_,
   {{0xf99300f5,0x6443084f,0xf1a90037,0x4153036c}},	//   ירא_, ćnic, عامه_, рвіс,
   {{0x60040c56,0x6d420042,0x6564003e,0x9f8a00bc}},	//   fòma, _seoa, lgih, _lööb_,
   {{0x7c2202fd,0xe1262b49,0xd1b20260,0x29d22f54}},	//   _suor, _амби, _پیشک, ršaj_,
   {{0x6564958a,0x00000000,0x00000000,0x00000000}},	//   ngih, --, --, --,
   {{0x6d4200bc,0x7dde00e8,0xdb1a958b,0x00000000}},	//   _veoa, nīsi, nitö, --,
   {{0x7c220084,0x2d9d00ac,0x61e225e2,0x3e4c00d2}},	//   _vuor, _enwe_, lnol, pět_,
   {{0xdea30260,0xa5b300c3,0x3f9e958c,0x5ea60192}},	//   _نیوی, _इकलौ, _intu_, _جمال,
   {{0x61e2958d,0x7c220084,0x3f8c4191,0x3ed9006e}},	//   nnol, _tuor, _hadu_, _אַנא,
   {{0x7c2d0587,0x3f8c958e,0x61e20630,0x00000000}},	//   _çarp, _kadu_, inol, --,
   {{0xb8cb17e5,0x7dde01d3,0x6b8a02b6,0x3f8c958f}},	//   _गप_, dīsi, _uafg, _jadu_,
   {{0x8c1b00f5,0x3f8c0918,0xf1b902dd,0xb4db0139}},	//   _קווי, _madu_, _hiše_, _adàp,
   {{0x69c602dc,0xdb1a4d23,0xf1b908c5,0xb4db009c}},	//   chke, chtá, _kiše_, _deàn,
   {{0x33750020,0x25a99590,0xa5f84064,0x61e262d2}},	// [a1d0] лгар, rjal_, тету_, dnol,
   {{0x65640124,0x248d00e7,0x62950034,0x61e20072}},	//   agih, _šems_, _przo, enol,
   {{0x798d9591,0x2d8d9592,0x00000000,0x00000000}},	//   _kaaw, ydee_, --, --,
   {{0x61e29593,0x3f9e0044,0xfb1500c1,0x3f8c194a}},	//   gnol, _antu_, אַנט_, _aadu_,
   {{0x80cd0067,0x3f8c0a00,0x518401b6,0x661d0270}},	//   _देखे, _badu_, руха, _iisk,
   {{0xa5bb266c,0x644d9594,0xae1b1b11,0x661d02ac}},	//   _bióg, msai, _पूजन_, _hisk,
   {{0x44295837,0xf1b902ef,0x661d9595,0x3f8c0706}},	//   lqa_, _aiše_, _kisk, _dadu_,
   {{0x661d9596,0x644d9597,0x752d77fe,0x8cd40852}},	//   _jisk, osai, ncaz, _बेहो,
   {{0xa3b7007d,0x644d9598,0x44299599,0x53b71fb4}},	//   _जवा_, nsai, nqa_, _आकाश,
   {{0x3f8c959a,0x09dc02e8,0x2c6b0c08,0xdaa90ac6}},	//   _gadu_, मच्य, rød_, евод_,
   {{0xd9460b40,0xa96a0a3a,0x752d039f,0x798d0517}},	//   лени, нина_, kcaz, _baaw,
   {{0x7c95048f,0x798d008a,0x644d959b,0xaca30294}},	//   _مشتا, _caaw, ksai, _alụk,
   {{0xeb8e5be6,0x798d32bd,0x3f8c959c,0x644d00e8}},	//   _ли_, _daaw, _yadu_, jsai,
   {{0x69c600dd,0x661d3b62,0xe8040336,0x6c520291}},	//   shke, _aisk, _शीशा_, _укљу,
   {{0x661d959d,0x6b817eba,0x959a00ae,0xfbd000d1}},	//   _bisk, melg, нтау_, _بتن_,
   {{0x61e20092,0x88861087,0x798d68f7,0x661d959e}},	//   xnol, _ближ, _gaaw, _cisk,
   {{0xb0d200a5,0x69c4959f,0x7c292c1a,0x69d602a4}},	// [a1e0] _देंग, _ilie, nqer, _imye,
   {{0xb6a61b77,0xdb030257,0x69c495a0,0x798d92fe}},	//   _биол, _conç, _hlie, _zaaw,
   {{0x661d1139,0x644d151d,0x50d600cd,0xdb1a1c23}},	//   _fisk, asai, گزار, sitö,
   {{0x3f8c8b40,0x249f0039,0x14d5009d,0xd5b100de}},	//   _sadu_, _šume_, _ठेवण, ết_,
   {{0x7bc30006,0x644d1ff5,0x69c40181,0x61e295a1}},	//   _olnu, csai, _mlie, rnol,
   {{0x61e21b36,0x661d0146,0xbe8a40c9,0xdb032a41}},	//   snol, _zisk, есие_, _gonç,
   {{0x69c45c09,0x764e0a1f,0x3f8c53f3,0xf1b900c4}},	//   _olie, nsby, _vadu_, _siše_,
   {{0x764e02ac,0x00000000,0x00000000,0x00000000}},	//   isby, --, --, --,
   {{0x7bc624e5,0x6b8195a2,0x9b6a00e5,0x00000000}},	//   ūkum, felg, ншна_, --,
   {{0xf1b902e6,0xef9100bf,0x6b813525,0x3f9e34ac}},	//   _više_, _ویند, gelg, _untu_,
   {{0x69c495a3,0x798d0270,0x8cd40179,0x65b80065}},	//   _blie, _paaw, _बेरो, _híhu,
   {{0x8c460221,0x316695a4,0x201e95a5,0x7bc395a6}},	//   _беде, ngoz_, _hiti_, _elnu,
   {{0x201e95a7,0x6fb80096,0x69c401ec,0x798d0172}},	//   _kiti_, _अवां, _dlie, _vaaw,
   {{0x69c495a8,0x798d008a,0xdb180103,0x661d95a9}},	//   _elie, _waaw, _elvá, _sisk,
   {{0x7bda02fd,0x201e1dc3,0xdb0300ee,0x69c42071}},	//   mitu, _miti_, _ronç, _flie,
   {{0x69c495aa,0xb0c41362,0xa8a70a7c,0x644d95ab}},	//   _glie, वनाग, _брок, tsai,
   {{0x661d7293,0x245500cd,0x24580084,0x752d1ec8}},	// [a1f0] _visk, شناس, лать_, rcaz,
   {{0x644d95ac,0x4429003d,0x661d31c4,0x81e20033}},	//   rsai, rqa_, _wisk, _নীল_,
   {{0x644d4caa,0x661d95ad,0x442995ae,0x7afd00b6}},	//   ssai, _tisk, sqa_, řstv,
   {{0x7bda95af,0xa11900e3,0x50b51da3,0x394b0428}},	//   hitu, نقاط_, ислу, nacs_,
   {{0x201e04a3,0xa0a51e33,0x7bda95b0,0x44293b3b}},	//   _biti_, ралд, kitu, qqa_,
   {{0x201e95b1,0x7bda95b2,0x3c29003e,0x7e552549}},	//   _citi_, jitu, _rúv_, атиц,
   {{0x74d90be4,0xda05009d,0x8c0a0081,0x6b8195b3}},	//   _नेतृ, रतात_, রদান_, velg,
   {{0xf2d2040a,0x201e0138,0x225c0031,0x6b8100f9}},	//   _ועל_, _eiti_, ávke_, welg,
   {{0xe1340012,0x61fb5289,0x6b8195b4,0x201e95b5}},	//   _ынты, _ikul, telg, _fiti_,
   {{0x69c495b6,0x7bda95b7,0x61e900f3,0x201e0193}},	//   _slie, gitu, _hjel, _giti_,
   {{0x69c495b8,0x61e902ec,0x29090174,0x8d771629}},	//   _plie, _kjel, _azaa_, _ماشا,
   {{0x6b8195b9,0x7cd60103,0x201e95ba,0x69c400bd}},	//   selg, اویز_, _ziti_, _qlie,
   {{0x69c40934,0x61fb0051,0xaca30134,0x6b816727}},	//   _vlie, _mkul, _mmịk, pelg,
   {{0x7bda481f,0x7bc895bb,0x2d8f2452,0x61e9007e}},	//   citu, chdu, _hage_, _ljel,
   {{0x61fb95bc,0x69c4003d,0x2d8f95bd,0x7e630270}},	//   _okul, _tlie, _kage_, nunp,
   {{0xceb200a1,0x61e995be,0x09e30423,0x69c495bf}},	//   חיל_, _njel, _мощн, _ulie,
   {{0x9f5e0084,0x6fc5009d,0x9346349e,0x764e059a}},	// [a200] _yhtä_, वसां, инае, ssby,
   {{0x2d8f95c0,0x61fb4606,0xe29a2c49,0xaca30134}},	//   _lage_, _akul, каз_, _amịk,
   {{0x61e9053f,0x27f86425,0xa75b00d7,0x00000000}},	//   _bjel, morn_, _בדיר, --,
   {{0x201e95c1,0x61e90ea3,0xea760130,0xc05a116d}},	//   _siti_, _cjel, יגער_, вік_,
   {{0x61e9029b,0x201e95c2,0x25a21a02,0x24990124}},	//   _djel, _piti_, _inkl_, _grsm_,
   {{0x7c2400e3,0x3ce00660,0xdfcf00ab,0xdb0a0610}},	//   _éiri, _živo_, وين_, _sofí,
   {{0x7bda95c3,0x201e95c4,0x61e902ec,0x7e98001c}},	//   vitu, _viti_, _fjel, انبر_,
   {{0x61e984e9,0xdd9700d3,0xdcea141f,0xdd900103}},	//   _gjel, ашь_, šiče, سوخ_,
   {{0x2d8f95c5,0x201e95c6,0xbc6700e3,0x7bda4de0}},	//   _dage_, _titi_, لمين_, titu,
   {{0x90e500cd,0xc5e3439d,0x201e00ae,0x00000000}},	//   _اسفن, _गद्य_, _uiti_, --,
   {{0xbeaa00bf,0xf1b902dd,0x2d8f0044,0xfbcf0190}},	//   _جهان_, _hiša_, _fage_, بتي_,
   {{0x7bda95c7,0x6da33967,0xdebb0105,0xf1b90039}},	//   situ, _миха, _שמאל, _kiša_,
   {{0x6e280618,0x6c34001c,0x2d8495c8,0x394b3572}},	//   _hudb, _افتا, meme_, racs_,
   {{0x2d8495c9,0xf1b9031a,0x7bda023b,0xdcfb008b}},	//   leme_, _miša_, qitu, lduğ,
   {{0x69dd95ca,0x7bd84dae,0x394b95cb,0xadc30af0}},	//   éres, _imvu, pacs_, _atẹl,
   {{0xdcfb03a3,0xf99f15c9,0x2d8495cc,0xfa330190}},	//   nduğ, rmès_, neme_, _برود,
   {{0x69dd7730,0xf1b995cd,0x6e28080e,0x600d05e6}},	// [a210] mise, _niša_, _ludb, lúme,
   {{0x61fb682e,0x69dd0fda,0x61e94f65,0xa3b7009d}},	//   _skul, lise, _sjel, _जवळ_,
   {{0xe6950080,0xf1b90b14,0x2d840201,0xdb030212}},	//   _الجد, _aiša_, keme_, _tonå,
   {{0x69dd95ce,0xa5bb0328,0xb7e90033,0xa84805bc}},	//   nise, _dióc, _গঠিত_, _حلیم_,
   {{0x2d8f006d,0x2d840074,0x3949009b,0xd479006e}},	//   _rage_, deme_, _meas_, _גאָל,
   {{0x69dd6d03,0x39490a1b,0x7dde00d9,0x490a0caf}},	//   hise, _leas_, zīst, _सरसो_,
   {{0x2d8f2c8b,0x320d004f,0x69dd6cd3,0x61e90ea3}},	//   _page_, _they_, kise, _tjel,
   {{0x61fb0060,0x2d8465ee,0x61e9033b,0x69dd95cf}},	//   _ukul, geme_, _ujel, jise,
   {{0x69dd0006,0x63b509ac,0x61f90034,0xab29037e}},	//   dise, _kozn, mowl, лопа_,
   {{0x6e2802ea,0x39490072,0x78bd00c2,0x7e6300cd}},	//   _fudb, _aeas_, dysv, punp,
   {{0x2d8f95d0,0x69dd95d1,0x7dde0029,0x63b54c8d}},	//   _tage_, fise, tīst, _mozn,
   {{0x69dd95d2,0x2d84896d,0x63b5077e,0x394900d3}},	//   gise, ceme_, _lozn, _ceas_,
   {{0x27f895d3,0x39490091,0xec3500c1,0xe3bf0143}},	//   torn_, _deas_, _פאַר_, _nuño_,
   {{0x7c3b2d96,0x69dd95d4,0xdc3600c1,0x30da00c1}},	//   mpur, aise, _האסט_, אַלע,
   {{0x9695016d,0x7c3b01cd,0x394900e1,0x00000000}},	//   ортш, lpur, _feas_, --,
   {{0x249f01ac,0xe3bf0042,0xd5b10023,0x7bc1093e}},	//   _šuma_, _buño_, ếp_, lklu,
   {{0x61f900a5,0x798695d5,0x63b50154,0xe3bf0143}},	// [a220] dowl, mekw, _bozn, _cuño_,
   {{0x7bc195d6,0xd8d700c1,0x798677c2,0xd7640504}},	//   nklu, _לופט_, lekw, _بندی,
   {{0x63b595d7,0xdceb00d9,0xce9501d3,0xdcfb008b}},	//   _dozn, _angļ, šējā_, yduğ,
   {{0x629a2297,0xf0d20129,0x79860415,0x6e280324}},	//   _átom, bịlọ, nekw, _rudb,
   {{0x6e2803ce,0x660495d8,0x7c3b20bb,0xdb0a0072}},	//   _sudb, mlik, jpur, _mofá,
   {{0x824a3862,0x660495d9,0xdfd000e3,0x7986945a}},	//   _مشرف_, llik, بيت_, hekw,
   {{0x69dd533a,0x6f010150,0x2d8495da,0xddcb00e7}},	//   yise, _cylc, teme_, _šiši,
   {{0x63b50038,0x660495db,0x629c95dc,0x628e008c}},	//   _zozn, nlik, _irro, _isbo,
   {{0xe3bf22e7,0xdcfb03a3,0x6604057a,0x69dd0d4b}},	//   _xuño_, rduğ, ilik, vise,
   {{0xdee61fdb,0x7bc195dd,0xa4b700a1,0x2d8495de}},	//   _лози, gklu, צליה_, seme_,
   {{0x69dd6a47,0x660495df,0x93fb00c1,0x394995e0}},	//   tise, klik, רליי, _peas_,
   {{0x78bd007b,0x2489007f,0x798695e1,0x629c1175}},	//   tysv, ywam_, gekw, _mrro,
   {{0x660495e2,0x39490610,0x600d05e6,0x7d2300d1}},	//   dlik, _veas_, súme, _عفون,
   {{0x69dd95e3,0x7bc102e2,0xcc5700f5,0x629c411e}},	//   sise, cklu, _פסוק_, _orro,
   {{0x98a50dea,0x7bdb00a1,0x660495e4,0x63b595e5}},	//   ğlı_, _תקוו, flik, _rozn,
   {{0x98a507d1,0x660495e6,0x7d020172,0xe3bf0328}},	//   şlı_, glik, _kyos, _puño_,
   {{0x545500d6,0xe9df0037,0x93270103,0x629c95e7}},	// [a230] юват, miú_, مران, _arro,
   {{0xe9df0037,0x6e221ac3,0x660495e8,0xe4d40076}},	//   liú_, _liob, alik, ستقب,
   {{0x63b515f4,0x7d02010a,0xb4db009c,0x00000000}},	//   _vozn, _lyos, _meài, --,
   {{0xdb030038,0xe9df00e3,0x6e2295e9,0x225c025b}},	//   _ponú, niú_, _niob, ávka_,
   {{0x628e95ea,0x629c95eb,0x1be80096,0x7bc15264}},	//   _esbo, _erro, टचाल_, yklu,
   {{0x443995ec,0x7bc1201a,0x629c0216,0x00000000}},	//   _its_, xklu, _frro, --,
   {{0x798695ed,0x442b0227,0x7d0295ee,0xb4db009c}},	//   yekw, _huc_, _ayos, _seàh,
   {{0x442326f1,0xf8bf92d4,0x7d02023f,0x6e225d94}},	//   _hij_, ncés_, _byos, _ciob,
   {{0xdb1a00e3,0xa3b00455,0x6e2295ef,0xe9df0037}},	//   chtú, टॉक_, _diob, diú_,
   {{0x798695f0,0x442395f1,0x7d02058b,0x69dd00fd}},	//   wekw, _jij_, _dyos, èren,
   {{0x44230505,0x798695f2,0x656f013d,0xf9860467}},	//   _mij_, tekw, _occh, огно,
   {{0x7c3b95f3,0x4423006c,0x6e2295f4,0x644301ac}},	//   ppur, _lij_, _giob, ćnij,
   {{0x79864e39,0x44397c4a,0xb4db01b9,0x7d020172}},	//   rekw, _nts_, _feài, _gyos,
   {{0x442301fa,0xaa451bf9,0x61b618ff,0x657d5895}},	//   _nij_, _декл, _अक्ष, _absh,
   {{0x6d4b048e,0x660495f5,0xf1b90141,0xdb11042c}},	//   _kega, tlik, _nišo_, ßgän,
   {{0xe5a30cd7,0x660495f6,0x442b95f7,0x6d4b95f8}},	//   миси, ulik, _buc_, _jega,
   {{0x44234ff3,0x660469f7,0x442b95f9,0x26d1028d}},	// [a240] _bij_, rlik, _cuc_, azzo_,
   {{0x660495fa,0x3f870fa3,0x6d4b95fb,0x644000dd}},	//   slik, jenu_, _lega, _çmim,
   {{0x660495fc,0x3f8795fd,0x443905fe,0x7c230085}},	//   plik, denu_, _ets_, _minr,
   {{0x64a62a04,0xf65300a1,0x6d590198,0xf8bf18ae}},	//   _дама, _קצר_, _ndwa, ccés_,
   {{0x44237a17,0x6e221032,0x7c2b305c,0xecd902d5}},	//   _fij_, _riob, _nugr, _बेलफ,
   {{0xc05900d6,0x6e2295fe,0x442301c0,0x3cfd034c}},	//   сії_, _siob, _gij_, _लड़े_,
   {{0x60040990,0x628e0bb6,0x7c2b084e,0x7c3900eb}},	//   nòmi, _usbo, _augr, _atwr,
   {{0x44230505,0x6d4b0da3,0x5d54016e,0x7c231909}},	//   _zij_, _cega, чкит, _ainr,
   {{0x6d4b95ff,0x442301fa,0x7c230af0,0x6d590517}},	//   _dega, _yij_, _binr, _ddwa,
   {{0x6d599600,0x3f870542,0x4423006c,0x6d4b0188}},	//   _edwa, cenu_, _xij_, _eega,
   {{0x6d4b4168,0xc333028c,0xe9df00e3,0xa3dc009d}},	//   _fega, וות_, tiú_, तोय_,
   {{0x7c232305,0x6e2200e7,0x78a201d3,0x2cbf0113}},	//   _einr, _uiob, _šova, byud_,
   {{0xe9df0080,0x6443005f,0xa5bb037a,0x7c230324}},	//   riú_, ćnik, _bión, _finr,
   {{0xd7fb1e54,0x29050029,0xe9df00e3,0x442b9601}},	//   рум_, āla_, siú_, _ruc_,
   {{0x44230126,0x7c2b031f,0xa3ae2ebd,0xf8ae015a}},	//   _rij_, _zugr, कान_, نکی_,
   {{0x44230197,0x442b05fe,0x7dce01f7,0xa4d5004d}},	//   _sij_, _puc_, _dùsg, побі,
   {{0x4423022e,0x92e700c7,0xf8bf49f0,0x44390231}},	// [a250] _pij_, _পরে_, rcés_, _qts_,
   {{0x44235d91,0x442b9602,0x2915007f,0x6b889603}},	//   _qij_, _vuc_, ądać_, nedg,
   {{0x44232189,0x3f879604,0x44390085,0x1b1c0081}},	//   _vij_, venu_, _wts_, পুরে_,
   {{0x44230505,0x442b00de,0x657d0027,0xd1b80076}},	//   _wij_, _tuc_, _ubsh, يانا_,
   {{0x44239605,0x8fa5116d,0x3f879606,0x44390167}},	//   _tij_, зале, tenu_, _uts_,
   {{0x6d4b113a,0x94ba00a1,0x9f470257,0x656d9607}},	//   _sega, _המשת, onné_, lgah,
   {{0x92580318,0x3f870335,0x6d4b1e77,0xed595309}},	//   _март_, renu_, _pega, бой_,
   {{0x656d6a21,0x7bca1175,0x00000000,0x00000000}},	//   ngah, _alfu, --, --,
   {{0x6d4b9608,0x205424d3,0x3f8703da,0x7c235916}},	//   _vega, _октя, penu_, _pinr,
   {{0x6d4b6946,0xa3ae382b,0xf1b900e7,0x7c2b00c4}},	//   _wega, काय_, _hoš_, _vugr,
   {{0x76550034,0xf1b96de8,0x61eb9609,0x7c95001c}},	//   jszy, _koš_, ongl, زشکا,
   {{0xf1b902e6,0x22470c01,0x9f5e02f1,0x7c2b960a}},	//   _još_, ánky_, _aktè_, _tugr,
   {{0xa3dc04a9,0xa3ae03a2,0xf1b9960b,0xdca50d57}},	//   तोड_, काम_, _moš_, _хали,
   {{0xf1b9005f,0x9d1a00a1,0x4c9a0796,0x61eb0009}},	//   _loš_, _פוסט, _לבנו, hngl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a611ce,0x69cf025b,0x656d960c,0xb0bd0096}},	//   ñol_, chce, ggah, ्नाग,
   {{0x2ea830a8,0x600400ee,0x00000000,0x00000000}},	// [a260] _कप्त, sòmi, --, --,
   {{0xdb0304ea,0x389b00f5,0x317f00d3,0x187700ca}},	//   _anné, _פיינ, _abuz_, _צעיר_,
   {{0xf1b902dd,0xd36f012b,0x91e60e2d,0x67bb1777}},	//   _boš_, اهم_, поже, _המיק,
   {{0x69c61189,0x00000000,0x00000000,0x00000000}},	//   nkke, --, --, --,
   {{0xd00a0156,0x69c65f36,0xe0430a54,0x92bc0a43}},	//   беде_, ikke, енчи, ইছে_,
   {{0x64560035,0xdb030103,0x61eb960d,0x613101f9}},	//   msyi, _enné, angl, _póló,
   {{0x09cc02e8,0x59cc009d,0x8cd40179,0x6b8800f2}},	//   ासाठ, ासार, _बेजो, vedg,
   {{0x799602ac,0x2bd90eeb,0x00000000,0x00000000}},	//   _nayw, योसा, --, --,
   {{0x69dd025a,0x64566ac0,0x48ce0033,0x7dce009c}},	//   èrem, nsyi, রপুর, _rùsd,
   {{0x5a340478,0x6f660396,0x7996010a,0x61e2960e}},	//   мнот, _ѕвез, _aayw, liol,
   {{0xa5bb10d9,0x7f3b00a1,0x79960270,0x60c25445}},	//   _biól, _העבו, _bayw, lyom,
   {{0x61e2960f,0xdd8f2ce3,0x2fcc54a0,0x9f5c0216}},	//   niol, _موم_, _hldg_, kovë_,
   {{0x60c29610,0xdca3188d,0x2bd900a5,0x76550034}},	//   nyom, _паци, योहा, wszy,
   {{0x6fbe0789,0x61e249ae,0xfbcf0037,0xa49b0154}},	//   ्सिं, hiol, _متى_, _dyòl,
   {{0x61e29611,0x4b7b0796,0xdb7b00ca,0x25b97306}},	//   kiol, _האוו, _הנוכ, _posl_,
   {{0xb8e30f71,0x76550034,0x69c60364,0x799602ac}},	//   _এই_, rszy, ckke, _gayw,
   {{0x57f50ea0,0x69df0090,0xb0db0285,0x2bd9023a}},	// [a270] _опит, _imqe, _मेंग, योवा,
   {{0xa3d7000f,0x76550034,0x656d12f5,0xf1b900d4}},	//   ़ों_, pszy, sgah, _soš_,
   {{0x27e33e38,0x69cd1aab,0xf1b90141,0xdb1802ac}},	//   mijn_, _klae, _poš_, _sovê,
   {{0xe8d938cd,0x61e200e5,0x27e301c0,0x68e200c6}},	//   _ndị_, giol, lijn_, _žodi,
   {{0x60c20018,0xf1b905db,0x69cd00f0,0x00000000}},	//   gyom, _hišk_, _mlae, --,
   {{0xe8d900ac,0x27e301c0,0x8b0702c6,0x69cd00f0}},	//   _adị_, nijn_, _jiří, _llae,
   {{0xdd9100fb,0x69c60939,0x629a4e00,0x69cd0062}},	//   ہوں_, ykke, _štov, _olae,
   {{0xf1942082,0x27e3029a,0x60c20512,0x00000000}},	//   _пись, hijn_, byom, --,
   {{0x225803ab,0x799603e3,0x3a3c0141,0x52dd1462}},	//   _zvrk_, _rayw, _atvp_, _मधुस,
   {{0x69cd0ae8,0x3e5700ae,0x0ae900c2,0xdb180154}},	//   _alae, păt_, ждой_, _kovè,
   {{0xa3ae0f42,0x69cd02ad,0x198a09b9,0x5f7400d1}},	//   कात_, _blae, обни_, _سالر,
   {{0x69cd9612,0x88e64e42,0xdb1805aa,0x4efa00ca}},	//   _clae, джме, _movè, _והעו,
   {{0x69c600c2,0x3156006e,0x27e30381,0x00000000}},	//   rkke, וירן_, fijn_, --,
   {{0x69cd00f9,0x8b0300b6,0x81e30033,0x799603a8}},	//   _elae, ářsk, নকি_, _wayw,
   {{0xf7720814,0x2bda00bf,0x69cd0150,0xdb181cb0}},	//   _یاد_, _بانک_, _flae, _novè,
   {{0x9f5c0052,0x64565a0d,0x69cd030a,0x64a6007e}},	//   tovë_, tsyi, _glae, маба,
   {{0xe3ba816c,0x27e301cb,0x2fc70113,0x00000000}},	// [a280] оба_, bijn_, kkng_, --,
   {{0x64562fc5,0x60c20239,0x27e301c0,0x00000000}},	//   rsyi, vyom, cijn_, --,
   {{0x9f5c00dd,0x75490103,0x61e23786,0x00000000}},	//   sovë_, észü, tiol, --,
   {{0x9f5c033d,0x25ff0096,0x4915030b,0xdb03033c}},	//   mové_, लवणी_, नेको_, _honó,
   {{0x9f5c0074,0x205622fb,0x00000000,0x00000000}},	//   lové_, фтер, --, --,
   {{0x8fa32383,0xd8d70142,0x00000000,0x00000000}},	//   каче, וונט_, --, --,
   {{0x9f5c0618,0xdb031f84,0xc246224a,0xda0e0096}},	//   nové_, _monó, _інак, सतात_,
   {{0x27e301c0,0x68f6014b,0x2fc70113,0x644d014b}},	//   zijn_, _oxyd, akng_, _éniè,
   {{0x9f5c025b,0xf41f02c3,0x0b8a04e6,0x00000000}},	//   hové_, _isär_, осни_, --,
   {{0x63bc38b8,0x9f5c0343,0xdfa62296,0x00000000}},	//   _jorn, kové_, _تحري, --,
   {{0x9f5c025b,0x2fd700cd,0x69cd9613,0x63bc00ca}},	//   jové_, _تولد_, _plae, _morn,
   {{0x9f5c0363,0x3ce00335,0x8c460231,0xceb3006e}},	//   dové_, _živu_, _жеде, _שיף_,
   {{0xdb18002b,0x63bc057a,0x27e3029a,0xae1b006e}},	//   _mové, _oorn, tijn_, _וואכ,
   {{0xdb030314,0xe78428dc,0x63bc9614,0x00000000}},	//   _conó, кусо, _norn, --,
   {{0xd5bb5e0c,0xdb030072,0x9f5c0579,0x27e39615}},	//   оса_, _donó, gové_, rijn_,
   {{0xdb180618,0xca2900c1,0xa3dc00a4,0x999f00c6}},	//   _nové, _צופֿ, तोस_, rstų_,
   {{0x63bc69d8,0x27e301c0,0x6b98026a,0x8415008f}},	// [a290] _born, pijn_, _kavg, емах,
   {{0x9f5c025b,0x63bc29b0,0x29092609,0xb4db0441}},	//   bové_, _corn, _iyaa_, _beàr,
   {{0x3d05033a,0x63bc9616,0xddc300d3,0xf1b90087}},	//   _हुने_, _dorn, nunţ, _hiši_,
   {{0x29090167,0xf1b900cb,0xb4db01ec,0x471a00ca}},	//   _kyaa_, _kiši_, _deàr, _מותג,
   {{0x63bc06ab,0x25ab6b54,0xd1b80246,0x6b9802c3}},	//   _forn, _incl_, بالا_, _oavg,
   {{0xe8d90174,0xb4db01ec,0x1e9521fd,0xdb03015e}},	//   _ndọ_, _feàr, ерир, _monò,
   {{0xb4db0441,0x6f0803a8,0xed594778,0xa28205bc}},	//   _geàr, _cydc, пой_, _میلو,
   {{0xdcf314f3,0xdceb04f9,0xe8d90134,0xe0bd0081}},	//   šače, _jagħ, _adọ_, _অধীন,
   {{0xdceb04f9,0x9f5c025b,0x29096d00,0x00000000}},	//   _magħ, zové_, _nyaa_, --,
   {{0x63bc4ce0,0x9f47034f,0xdceb009e,0x00000000}},	//   _xorn, ronó_, _lagħ, --,
   {{0x29090fdc,0x2bb100a5,0x5fac2183,0x20050270}},	//   _ayaa_, जाबा, चारल, _ikli_,
   {{0x9f5c025b,0xf99f0c56,0x9f470037,0xdceb003d}},	//   vové_, blèm_, inní_, _nagħ,
   {{0x1c4404a1,0x48ce0033,0x00000000,0x00000000}},	//   _анім, রপ্র, --, --,
   {{0x9f5c0074,0x6aae0037,0x3d050034,0xf1b90117}},	//   tové_, óifí, _हुये_, _diši_,
   {{0xa3ae0852,0xb9072fbd,0xdceb009e,0x28e00e52}},	//   कास_, _ये_, _bagħ, _पेरि,
   {{0x9f5c0074,0x212d0da3,0x98ac0092,0xdceb0090}},	//   rové_, _ngeh_, şdı_, _cagħ,
   {{0x9f5c0074,0x7de8030b,0x628700d9,0xa80603e0}},	// [a2a0] sové_, měst, _apjo, _atış,
   {{0xdcea0106,0x9f5c0146,0xdb1a0037,0x78a40169}},	//   šiće, pové_, chtó, _iriv,
   {{0xa3dc048a,0x63bc01bf,0x39524e3f,0x78a41b13}},	//   तोष_, _vorn, _keys_, _hriv,
   {{0xfb16006e,0x629a00c4,0x00000000,0x00000000}},	//   ײַבט_, _štos, --, --,
   {{0x63bc9617,0xd00a1cb1,0x673102c6,0x79849618}},	//   _torn, педе_, řejň, _mbiw,
   {{0xdb030428,0x6444862e,0x3952041c,0x74160452}},	//   _anní, mpii, _leys_, _سوزا,
   {{0xaade0251,0x442a041c,0x8e2642c5,0x7dd50103}},	//   _फेंक, _iib_, нфид, _másf,
   {{0x442a0294,0xa3ae0e50,0xd84f0134,0x20054fd5}},	//   _hib_, काव_, _bọlb_, _ekli_,
   {{0x442a9619,0xd1750138,0x28e00179,0xef8600d3}},	//   _kib_, _шыры, _पेलि, _плап,
   {{0x3a290496,0x442a04de,0x798475ee,0xcbce0033}},	//   _siap_, _jib_, _abiw, িচ্ছ,
   {{0x78a4961a,0x6da60f32,0x00000000,0x00000000}},	//   _ariv, _пижа, --, --,
   {{0x442a961b,0x78a4961c,0x3e7a023b,0xf1b90660}},	//   _lib_, _briv, mët_, _piši_,
   {{0x3e7a01e5,0xdd8f00e3,0x442a961d,0x2617016d}},	//   lët_, _دون_, _oib_, nçoe_,
   {{0x442a961e,0x78a4961f,0xf1b90039,0x79840517}},	//   _nib_, _driv, _viši_, _ebiw,
   {{0x3a29005a,0x3e7a00dd,0x98a900e7,0x78a49620}},	//   _tiap_, nët_, _igač_, _eriv,
   {{0x78a402fe,0x65943a33,0x3f8e405f,0x497400e5}},	//   _friv, ласу, hefu_, _блъс,
   {{0xf367062a,0x442a02f1,0x3e7a00dd,0x24f832e3}},	// [a2b0] етен, _bib_, hët_, енты_,
   {{0x442a9621,0x3e7a01e5,0x6672001c,0x7c2a00bd}},	//   _cib_, kët_, دگیر, _jifr,
   {{0x442a0694,0xdceb2751,0x3e7a00dd,0x629a0141}},	//   _dib_, _tagħ, jët_, _štor,
   {{0x799d9622,0x7de70113,0x3e7a0052,0x66ee01f9}},	//   ndsw, _mèsè, dët_, sőké,
   {{0x660d9623,0x249f001f,0x799d1570,0x3e7a02ac}},	//   mlak, _éum_, idsw, eët_,
   {{0x660d9624,0xdee50831,0x442a9625,0x7c2a00a7}},	//   llak, коли, _gib_, _nifr,
   {{0xa3ae0fef,0x3e7a023b,0xddd40095,0x660d0634}},	//   कार_, gët_, _šaši, olak,
   {{0x442a022e,0x4ce20081,0x660d9626,0x4c855e04}},	//   _zib_, _পড়ু, nlak, влив,
   {{0x442a01fa,0xc8e00455,0x7c2a003e,0x7de802c6}},	//   _yib_, _पेंट, _bifr, věst,
   {{0x660d0060,0x442a0197,0x28d00789,0x3e7a023b}},	//   hlak, _xib_, हनसि, bët_,
   {{0x7c2a2425,0xa96a6321,0x78a49627,0x660d9628}},	//   _difr, мина_, _sriv, klak,
   {{0x660d0039,0x6016016d,0x8d74001c,0x2ba62f74}},	//   jlak, râme, _ماها, _कोठा,
   {{0xeb8e4070,0x660d52dd,0x1a650177,0x7c2a0090}},	//   _ки_, dlak, ریکی_, _fifr,
   {{0x77770042,0x6a853d6e,0x290c01d3,0x7c2a9629}},	//   _ccxx, _алка, āda_, _gifr,
   {{0x07a307ed,0x660d962a,0xe73735c1,0x7de701dc}},	//   јасн, flak, тес_, _gèsè,
   {{0x442a0d7d,0x660d1ba1,0xf1b900cb,0x78a4676b}},	//   _sib_, glak, _kišu_, _triv,
   {{0xa3ae0e72,0x442a0197,0x3e7a023b,0xdb0a0383}},	// [a2c0] काल_, _pib_, zët_, _anfè,
   {{0x442a006c,0xa3dc0067,0x7c2a05fe,0x98a002ef}},	//   _qib_, तों_, _xifr, _agić_,
   {{0x442a022e,0x644431e8,0xa68300d3,0x00000000}},	//   _vib_, spii, _клэд, --,
   {{0x442a1f12,0x6e2b0649,0x3aba006e,0x644400c2}},	//   _wib_, _nigb, ומענ, ppii,
   {{0x442a01bb,0xf1b91cae,0x6d493aab,0xdb0a022b}},	//   _tib_, _nišu_, dbea, _enfè,
   {{0x3e7a00dd,0x6e2b0af0,0xa3ae0096,0x14d700ca}},	//   tët_, _aigb, काळ_, _יוכל_,
   {{0xf1b900e7,0x539b00ca,0x3f8e94ce,0x7c2a962b}},	//   _aišu_, _קילו, refu_, _rifr,
   {{0x3e7a074a,0x7c2a962c,0x2bca1117,0x3f8e0051}},	//   rët_, _sifr, िस्थ, sefu_,
   {{0xdb0a00fd,0x6e2b962d,0x3e7a0052,0x9f5c0094}},	//   _infé, _digb, sët_, loví_,
   {{0xf1b90580,0x660d962e,0x3e7a0216,0x00000000}},	//   _dišu_, zlak, pët_, --,
   {{0x6d49962f,0x2ba6009d,0x9e65110a,0x6fd400ee}},	//   bbea, _कोणा, _مانن, _càce,
   {{0x6e2b0f20,0x7dd5033c,0x6d4901b9,0x00000000}},	//   _gigb, _cásd, cbea, --,
   {{0x2d860113,0xdb1a0844,0x7c2a00bd,0x00000000}},	//   _iboe_, nktú, _tifr, --,
   {{0x5ba30465,0x2ca69630,0x00000000,0x00000000}},	//   _връз, _irod_, --, --,
   {{0x27ed00e9,0x660d9631,0x8c1b00ca,0x45d583dc}},	//   đen_, tlak, _חוגי, говс,
   {{0x5967008f,0x2ba609c3,0x27ed0103,0x660401c8}},	//   _ръка, _कोता, ően_, goik,
   {{0x660d3ad9,0xa3ae0789,0x24580084,0x39599632}},	// [a2d0] rlak, कां_, кать_, mass_,
   {{0x395905c4,0x9327001c,0xf2c7007e,0x3d0500bc}},	//   lass_, نران, ксен, _हँसे_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf99f06a3,0x249f14f3,0xa1150037,0xf1b9080e}},	//   ndè_, _šumu_, هوات, _ništ_,
   {{0x07f8110a,0xa0690219,0xe0d00190,0x7a2601b9}},	//   _سریع_, хала_, يزه_, _dųth,
   {{0xa3ae080f,0x9f47023b,0x6e2b9633,0x248400b7}},	//   काः_, minë_, _sigb, _ämma_,
   {{0x2bb1007d,0xc29300cd,0x7dd59634,0x9f47023b}},	//   जासा, _خیاب, _láse, linë_,
   {{0x2ca60995,0xf1b90039,0xf1a463a7,0x00000000}},	//   _brod_, _pišu_, _крун, --,
   {{0x6d499635,0x9f47023b,0x39598604,0xcc89001c}},	//   rbea, ninë_, dass_, رنده_,
   {{0x6d4901b5,0xf1b900cb,0x60c400c2,0x249900dc}},	//   sbea, _višu_, äime, _mssm_,
   {{0x39ea1121,0x44211519,0x6e2b019c,0x9f470052}},	//   едно_, imh_, _tigb, hinë_,
   {{0x186a08d1,0xceb200c1,0x9f47023b,0x2ca6022b}},	//   нами_, _ליב_, kinë_, _frod_,
   {{0xed598e15,0x9f470052,0x8d5a00ca,0x2ca6036b}},	//   maž_, jinë_, _נכסי, _grod_,
   {{0xaae400cd,0x66e63fe2,0x2d9d057a,0x9f470052}},	//   اسیو, гога, _hawe_, dinë_,
   {{0x2d9d9636,0xf743013d,0x66046510,0xcb5600ca}},	//   _kawe_, сесо, toik, _עסקה_,
   {{0x2d9f9637,0x2956008f,0x9f470052,0xed590095}},	//   ndue_, _съкр, finë_, naž_,
   {{0xd4671c47,0xb3860231,0x2d9d0051,0x08e20033}},	// [a2e0] лите_, ллал, _mawe_, _গুরু_,
   {{0x66043655,0x3ce60006,0x248b0036,0x9f5c00d4}},	//   soik, _जइसे_, _dpcm_, toví_,
   {{0x8b5600c1,0x6604007b,0xa9050103,0xb14600ae}},	//   ריעס_, poik, _مبین, гнел,
   {{0xc69307a6,0x44210514,0x2d9d3f68,0x2e3800fd}},	//   _פאר_, amh_, _nawe_, _réf_,
   {{0x183600c1,0x9f47023b,0x39400090,0xea01020b}},	//   נאַל_, cinë_, _mfis_, _quẩy_,
   {{0x2d9d0065,0x25a000aa,0xa5bb9638,0x00000000}},	//   _aawe_, ldil_, _chóf, --,
   {{0x24809639,0xe8d90134,0x74130260,0xdb1800b6}},	//   ltim_, _ibụ_, _طوفا, _poví,
   {{0x225c025b,0x25a0963a,0x2d9d4ed7,0x38600117}},	//   ávku_, ndil_, _cawe_, _ovir_,
   {{0x2480963b,0x25a0963c,0x2d9d963d,0x7f462b99}},	//   ntim_, idil_, _dawe_, _безж,
   {{0x320613d9,0x24800270,0x21200179,0x3940044c}},	//   looy_, itim_, यधीश_, _afis_,
   {{0xe8d900ac,0x8d86249b,0x3f9e0063,0x7ac612d3}},	//   _mbụ_, _булд, _iatu_, успе,
   {{0x2480963e,0x2d9d963f,0x2e1600e3,0x3d05034c}},	//   ktim_, _gawe_, _صباح, _हुवे_,
   {{0x3f9e809f,0x24809640,0x2ca69641,0x9f900032}},	//   _katu_, jtim_, _urod_, _kàà_,
   {{0x394000e7,0x3f9e9642,0x7d0600bc,0x39599643}},	//   _efis_, _jatu_, üksu, sass_,
   {{0x2d9d3223,0xa3ae049d,0x39592452,0x3f9e9644}},	//   _yawe_, काई_, pass_, _matu_,
   {{0xf9931e53,0x3f9e00d9,0xe8d900ac,0x9f4700dd}},	//   _طبع_, _latu_, _abụ_, tinë_,
   {{0x44210167,0xdce90206,0x9f4705aa,0x00000000}},	// [a2f0] tmh_, zdeľ, binè_, --,
   {{0x9f4701e5,0x3f9e3254,0x25a038d2,0x00000000}},	//   rinë_, _natu_, adil_, --,
   {{0x06bf00c7,0x9f4700dd,0xa5bb266c,0x25a0003d}},	//   _উইকি, sinë_, _biót, bdil_,
   {{0x7dd51f97,0x9f479645,0xe45f0088,0x9f900139}},	//   _másc, pinë_, _tvö_, _aàà_,
   {{0x3f9e3edf,0x9f4795be,0x2d9d03a9,0x9f900139}},	//   _batu_, liné_, _rawe_, _bàà_,
   {{0x764500dd,0xfe453a69,0x3f9e0483,0x2d9d0350}},	//   _kthy, анко, _catu_, _sawe_,
   {{0x3f9e22c9,0x2d9d3620,0xa5bb00da,0xe7f81115}},	//   _datu_, _pawe_, _chóg, ूकता_,
   {{0x3d19007f,0x69cf01cb,0x00000000,0x00000000}},	//   _परदे_, jkce, --, --,
   {{0x61eb013d,0xed590786,0x3f9e9646,0x9f900065}},	//   migl, raž_, _fatu_, _fàà_,
   {{0x2d9d3223,0xa5bb00e3,0xa3ae0557,0x61eb9647}},	//   _wawe_, _fhóg, काए_, ligl,
   {{0x7dd59648,0xed59007e,0xa3ad00c3,0x799f039f}},	//   _cásc, paž_, _कफन_, _baqw,
   {{0x9f479649,0x61eb964a,0x9f5c0146,0x82760142}},	//   diné_, nigl, mová_, סערע_,
   {{0x9f5c0074,0x20070006,0xc2ec0081,0x6d5b00a4}},	//   lová_, ooni_, _করছি_, maua,
   {{0x2007964b,0x6d5b71b9,0x61eb028d,0xfaa5964c}},	//   noni_, laua, higl, _вако,
   {{0x9f5c0074,0x9f47964d,0x7bc32b5c,0x61eb0009}},	//   nová_, giné_, _ionu, kigl,
   {{0x7bc30102,0x200747cf,0x2480026a,0x6d5b1049}},	//   _honu, honi_, ttim_, naua,
   {{0x7bc3964e,0x2007964f,0x69d60068,0x9f5c6c39}},	// [a300] _konu, koni_, _ilye, hová_,
   {{0x200763ca,0x69aa04a9,0x9f5c0618,0x24809650}},	//   joni_, _जोती, ková_, rtim_,
   {{0x3f9e2cc6,0x24809651,0x20071cc9,0x6d5b0a25}},	//   _ratu_, stim_, doni_, kaua,
   {{0x3f9e2129,0x6d5b048e,0xdb1a0170,0x69c401cf}},	//   _satu_, jaua, rktø, _joie,
   {{0x81cd0081,0xe8e100fe,0x6d5b01ff,0x9f990139}},	//   ষোভ_, _địu_, daua, _kèè_,
   {{0x261700fd,0x9f900032,0xbf210096,0x69c40036}},	//   nçon_, _bàá_, मधून_, _loie,
   {{0x61eb9652,0xd17600c2,0x69c40a88,0x9f5c9653}},	//   bigl, _вызы, _ooie, gová_,
   {{0x3f9e1ee3,0xa3ae007d,0x69c452c4,0xdb18033d}},	//   _watu_, काक_, _noie, _nová,
   {{0x3f9e0ade,0x200745f3,0xdb0a042c,0xa2cf0139}},	//   _tatu_, boni_, _wofü, _lọ́j,
   {{0x9f5c025b,0xa5bb00e3,0x20073c59,0x7dd50161}},	//   bová_, _thóg, coni_, _pásc,
   {{0x1fb523a3,0x7bc39654,0x98a20092,0x195903a7}},	//   _устр, _donu, dakı_, ланы_,
   {{0x6d5b9398,0x644601ac,0x00000000,0x00000000}},	//   caua, _otki, --, --,
   {{0xa3e7000f,0x2b064153,0x69cf026a,0x7bc30907}},	//   _बगल_, _सुरु_, rkce, _fonu,
   {{0x9f47001c,0x628e0cad,0x7dd50037,0x69d66113}},	//   tiné_, _opbo, _tásc, _elye,
   {{0xc6a42887,0x69d62e5f,0x799f38ad,0xd7f81cb1}},	//   орти, _flye, _taqw, руя_,
   {{0x69c40a00,0x9f4700d1,0x69d602ac,0x00000000}},	//   _goie, riné_, _glye, --,
   {{0xf94a0130,0x2007628a,0x61eb008f,0x9f47001c}},	// [a310] _געפֿ, yoni_, vigl, siné_,
   {{0xd79500e3,0x69c40126,0xdb0a0161,0x2007023b}},	//   _الدخ, _zoie, _infâ, xoni_,
   {{0x64460b88,0x61eb5dab,0xa3bb0260,0x76450212}},	//   _etki, tigl, _یاسر_, _uthy,
   {{0x9f5c0146,0x69c4002b,0x201e0f06,0x6fd4009c}},	//   vová_, _xoie, _ahti_, _ràca,
   {{0xf99f0472,0x61eb9655,0x9f4700c2,0x10a51907}},	//   llès_, rigl, ynnä_, силн,
   {{0x61eb9656,0x9f5c0244,0x6aaa00f0,0xfba60469}},	//   sigl, tová_, _orff, _कोलम,
   {{0x443909ce,0x20079657,0x6d5b9658,0xe61f0019}},	//   _hus_, roni_, taua, _khô_,
   {{0x7bc39659,0x44397988,0x2007965a,0xa3b534d8}},	//   _sonu, _kus_, soni_, झाव_,
   {{0x7bc3965b,0x61e9965c,0x4439965d,0x2007965e}},	//   _ponu, _imel, _jus_, poni_,
   {{0x44391071,0x7bc34307,0x61fb02fe,0x69c40257}},	//   _mus_, _qonu, _hjul, _soie,
   {{0x44390d7d,0x4431965f,0x7bc39660,0x69c49661}},	//   _lus_, _miz_, _vonu, _poie,
   {{0x44390428,0x3cfd0197,0x61fb0172,0xe61f00fe}},	//   _ous_, _txwv_, _jjul, _nhô_,
   {{0x4439006c,0x61e90294,0x69c401e6,0x44310062}},	//   _nus_, _mmel, _voie, _oiz_,
   {{0x7bda2b89,0x6d590096,0x61fb0335,0x61c45d3f}},	//   chtu, _hewa, _ljul, _वक्ष,
   {{0x44399662,0xdb1800fb,0x7dd50074,0x6d599663}},	//   _aus_, _tová, _zása, _kewa,
   {{0x443100d9,0x44399664,0x61fb47fd,0x00000000}},	//   _aiz_, _bus_, _njul, --,
   {{0x443129e4,0x6d5975d6,0x44399665,0x3a2007ac}},	// [a320] _biz_, _mewa, _cus_, _ihip_,
   {{0x44399666,0x61e99667,0x6d590710,0xf1a900cd}},	//   _dus_, _amel, _lewa, یانه_,
   {{0x443938ff,0x44310396,0x479b0341,0x630607e8}},	//   _eus_, _diz_, _גייס, حوال,
   {{0x26176e38,0xa3a80eeb,0x201e0216,0x6d596193}},	//   nçol_, _खोर_, _shti_, _newa,
   {{0x4fc63c97,0x44399668,0x44319669,0x61fb8090}},	//   йска, _gus_, _fiz_, _djul,
   {{0x161c05d4,0x61e9966a,0x437508f9,0x6d590172}},	//   _भीतर_, _emel, _муст, _aewa,
   {{0x4439966b,0x6d592ba3,0x2fc5033b,0x7dd50076}},	//   _zus_, _bewa, _dolg_, _sása,
   {{0x443901bb,0x6d591114,0x7dd50328,0x44310117}},	//   _yus_, _cewa, _pása, _ziz_,
   {{0x443901bb,0x6d591bd6,0xea010023,0xbda60103}},	//   _xus_, _dewa, _quậy_, لحکو,
   {{0x9b580396,0x4431430c,0xa3dc0096,0x61e90141}},	//   шиот_, _xiz_, तोच_, _zmel,
   {{0xfba7007b,0x00000000,0x00000000,0x00000000}},	//   стый_, --, --, --,
   {{0x6d596898,0x7bda5a11,0xf2d300c1,0x3a2051e4}},	//   _gewa, shtu, פער_, _chip_,
   {{0x6e3a4305,0xb4db0032,0xb87b0031,0xae1b00ca}},	//   _hutb, _afàn, dzíc, _עודכ,
   {{0xa3a80e72,0x00000000,0x00000000,0x00000000}},	//   _खोल_, --, --, --,
   {{0x4439966c,0x443117f9,0x48e9007a,0xe61f0023}},	//   _sus_, _riz_, _चेरो_, _phô_,
   {{0x443107d1,0x4439966d,0xdb0a0428,0xca470037}},	//   _siz_, _pus_, _infà, _اليه_,
   {{0x4439006c,0x798d966e,0x69dd009b,0x9f470036}},	// [a330] _qus_, _ibaw, mhse, finì_,
   {{0x44393c08,0x443100a7,0x7df300ae,0x78ad05bd}},	//   _vus_, _qiz_, răsi, _irav,
   {{0x443100b6,0xe53563f8,0x443900cd,0xe61f0023}},	//   _viz_, _мень, _wus_, _thô_,
   {{0x44391071,0x3f8c24ae,0xb8840018,0xa5bb0503}},	//   _tus_, _abdu_, _بلیٹ, _dhóc,
   {{0x44390006,0x2ed1030b,0x7dd50146,0x798d966f}},	//   _uus_, तन्त, _básn, _mbaw,
   {{0x644d0ab5,0x6d594a02,0x6e3a0124,0xdb1a2fcc}},	//   mpai, _sewa, _butb, nktó,
   {{0x2fc50934,0x6d5932c3,0x644d9670,0x321f0023}},	//   _volg_, _pewa, lpai, _thuy_,
   {{0x61e99671,0x1c450d06,0x2d8a0018,0x78ad9672}},	//   _umel, оним, őben_, _orav,
   {{0x644d6bb4,0xc3250033,0x68200c19,0x69dd01ec}},	//   npai, মুখি_, löde, dhse,
   {{0x7ff70241,0x6d5900bf,0x798d9673,0xdb030072}},	//   _اسرا, _wewa, _abaw, _innú,
   {{0x62859674,0x6d597ef8,0x78ad9675,0x3a200063}},	//   ntho, _tewa, _arav, _phip_,
   {{0x628500f0,0xee2e004d,0x69aa201e,0xdb1a007f}},	//   itho, _ін_, _जोशी, ektó,
   {{0x394d46b4,0x6285009c,0x261700ee,0x00000000}},	//   ñesa_, htho, rçol_, --,
   {{0x78ad0128,0xdbf10092,0xab29249b,0x798d06b0}},	//   _drav, dəçi, _кола_, _ebaw,
   {{0x62859676,0x78ad6bf9,0xb6a30131,0x26170072}},	//   jtho, _erav, мирл, açom_,
   {{0x69dd02dc,0x7dd50068,0x798d2caa,0x660f171d}},	//   chse, _máso, _gbaw, _ckck,
   {{0x628502ad,0x13ea004b,0x644d0fa0,0x26170072}},	// [a340] etho, амай_, gpai, cçom_,
   {{0x63bb01c2,0xe3b709e4,0xa5bb0076,0xa3e50442}},	//   _ɗung, обу_, _phóc, बोल_,
   {{0xe29a19e0,0x78ad0087,0x7dd50094,0x00000000}},	//   рае_, _zrav, _náso, --,
   {{0x63a50013,0x6e3a0350,0x7ddc01f9,0x00000000}},	//   adhn, _rutb, _kése, --,
   {{0x92bc0f71,0xaca30174,0x62850503,0x00000000}},	//   েছে_, _blọk, atho, --,
   {{0x66169677,0x62859119,0x6e3a00f9,0x5fa400a4}},	//   llyk, btho, _putb, _गोखल,
   {{0x628557b0,0x7d1500a7,0x00000000,0x00000000}},	//   ctho, əzsi, --, --,
   {{0x85480138,0x00000000,0x00000000,0x00000000}},	//   brėž, --, --, --,
   {{0x6ea80103,0x00000000,0x00000000,0x00000000}},	//   _گناہ_, --, --, --,
   {{0x8bd81d08,0x00000000,0x00000000,0x00000000}},	//   смос_, --, --, --,
   {{0x1fb59678,0x69dd023b,0x290507aa,0xed4632f8}},	//   _эстр, thse, ğlam_, _днеп,
   {{0x78ad574a,0x00000000,0x00000000,0x00000000}},	//   _prav, --, --, --,
   {{0x7dd50244,0x6e2247e4,0x00000000,0x00000000}},	//   _záso, _ihob, --, --,
   {{0x7ddc0257,0x78ad6bd4,0x62850178,0xdb0a2bb5}},	//   _dése, _vrav, ytho, _enfá,
   {{0x66169679,0x06e10033,0x00000000,0x00000000}},	//   flyk, _মুজি, --, --,
   {{0x7dd50074,0x78ad4589,0xd9ff3d34,0x2b490542}},	//   _násl, _trav, _उदित_, _đaci_,
   {{0x78ad967a,0x045900e3,0xe9df0037,0x6e2200eb}},	// [a350] _urav, صلاة_, mhú_, _mhob,
   {{0x644d82ca,0x57f400c2,0x6285967b,0xa3e50034}},	//   rpai, _опыт, ttho, बों_,
   {{0x644d967c,0x66160313,0x64404466,0x079a0266}},	//   spai, blyk, _émin, _הסתל,
   {{0x628502d3,0x7ddc967d,0x7df300d3,0x644d5063}},	//   rtho, _lésb, năst, ppai,
   {{0x6285967e,0x660d03a9,0x224a0062,0xc5f900b6}},	//   stho, moak, _etbk_, ्कीय_,
   {{0x1da3121d,0x9405001c,0x7dd50146,0x6e2241e5}},	//   _खोजत, _روزه, _páso, _ahob,
   {{0x6e2201b9,0x7d020372,0xc695006e,0x00000000}},	//   _bhob, _axos, לאַ_, --,
   {{0xbca500e3,0x317f0511,0xb222003e,0x660d967f}},	//   كمبي, _ucuz_, áætl, noak,
   {{0x6e229680,0x2bb90037,0x2b5c05db,0x962700e8}},	//   _dhob, مادة_, _bevc_, _izņē,
   {{0x7ddc04ea,0x7dd50094,0x9c22013f,0x00000000}},	//   _rése, _zásl, ндыд, --,
   {{0xe8e10028,0x660d9681,0x3b092ca4,0xea0000fe}},	//   _đều_, koak, сено_, _ngải_,
   {{0x6e22151d,0x3ce600c3,0xf2d2006e,0x23610113}},	//   _ghob, _जेके_, געט_, hahj_,
   {{0x660d02e7,0x6e29038c,0x2d8f016d,0xdd991515}},	//   doak, mmeb, _ibge_, meň_,
   {{0x2bbb054f,0xdd992347,0x59c80096,0x6e2909af}},	//   _خاصة_, leň_, _लवकर, lmeb,
   {{0xa3b532c9,0xe9df0037,0xf6262b16,0x290c007f}},	//   झाई_, bhú_, здво, łda_,
   {{0x6e299682,0xe9df3c09,0xb9020033,0x661600f2}},	//   nmeb, chú_, _দশ_, ulyk,
   {{0x75d30037,0xa3e802d5,0x999200c6,0x66160795}},	// [a360] ريكا, यफल_, ūzų_, rlyk,
   {{0x66162084,0x764e5da3,0x442300fe,0x6e2902db}},	//   slyk, ppby, _chj_, hmeb,
   {{0x8c1a00a1,0xe2972fad,0xb87b0146,0xa5bb0065}},	//   צועי, зах_, nzín, _ihón,
   {{0x236a0124,0x216719e8,0xf41f0364,0xd5e0030b}},	//   _wdbj_, зици_, _spät_, _नतिज,
   {{0xf5370054,0x6e2900aa,0x60161789,0xdd99023c}},	//   _מרכז_, dmeb, lâmi, deň_,
   {{0x6e941728,0x9f5c0031,0x22c50134,0x9f4700b3}},	//   дику, lovú_, ịkal_, ginà_,
   {{0xcf260080,0x6e2250dc,0x60160161,0xc7b300ca}},	//   أرشي, _phob, nâmi, תבו_,
   {{0x21a33574,0xade300d6,0x9f5c0031,0x00000000}},	//   _писм, ецьк, novú_, --,
   {{0xdceb0b12,0x00000000,0x00000000,0x00000000}},	//   _bagı, --, --, --,
   {{0xdb03022b,0x9f5c0206,0x00000000,0x00000000}},	//   _kanè, hovú_, --, --,
   {{0xe9df0080,0x6e228085,0x9f5c0031,0xbeaa001c}},	//   thú_, _thob, kovú_, _دهان_,
   {{0xdb0300cd,0x261701e8,0x7d020a00,0x3ddf01c0}},	//   _manè, rçok_, _txos, chuw_,
   {{0x9ac4003d,0x05000081,0x7de50037,0x9f5c0031}},	//   _suċċ, ্ধুর_, _تسلم, dovú_,
   {{0xdc370130,0xa5bb9683,0xaa665e16,0x7d1d9684}},	//   _זאגט_, _chón, _етик, üsse,
   {{0x660d9685,0xeaaf0037,0x356b0036,0x9ac40078}},	//   toak, _معي_, йран_, _quċċ,
   {{0x44230332,0x41ab009f,0xe1ab09c3,0x6b9a20a8}},	//   _shj_, _घोंस, _घोंघ, letg,
   {{0x660d9686,0x39499687,0x7bca4132,0x200e0a3d}},	// [a370] roak, _ifas_, _kofu, kofi_,
   {{0xdd990579,0x38699688,0x660d0634,0xd3710076}},	//   zeň_, _ivar_, soak, ئها_,
   {{0xaadc04a9,0x38699689,0x75480103,0x9f5c0206}},	//   मनिक, _hvar_, észí, bovú_,
   {{0xd1310e5a,0x38692452,0x7dd50146,0x9f470146}},	//   نما_, _kvar_, _pásm, diná_,
   {{0xdd990074,0x8fa513a7,0x92bd0081,0x200e0044}},	//   veň_, дале, ইনে_, fofi_,
   {{0x25a97d19,0xb4d9034c,0x7bca2e74,0x00000000}},	//   ldal_, ़नी_, _nofu, --,
   {{0x24890068,0x9f47034f,0x929419d4,0x6fd4009c}},	//   ltam_, giná_, _парц, _màch,
   {{0x96270b4b,0x53341d7b,0x25a9968a,0x56b800a1}},	//   _uzņē, _чест, ndal_, לפון_,
   {{0x2489968b,0x7dd50088,0xea0000de,0xdd990220}},	//   ntam_, _hásk, _ngại_, reň_,
   {{0x320f0054,0x63a72533,0xdd99025b,0x39496a8c}},	//   logy_, _jajn, seň_, _afas_,
   {{0x25a9968c,0xdd990146,0x3ed50cd2,0x7bca3b42}},	//   kdal_, peň_, _تقار, _dofu,
   {{0x2489968d,0x7dd50103,0x00000000,0x00000000}},	//   ktam_, _másk, --, --,
   {{0x7dd50074,0xb87b0018,0xa5bb0019,0xdb0a01bf}},	//   _lásk, szín, _phón, _anfä,
   {{0x63a7968e,0x0c2402ec,0x24890018,0x629501c0}},	//   _najn, _змін, dtam_, _opzo,
   {{0x16a707f3,0xe7371102,0x3869058f,0x25a9968f}},	//   мври_, дер_, _evar_, fdal_,
   {{0x200e766d,0xcb1200a1,0x6016001f,0x6fd4009c}},	//   zofi_, _שלה_, râmi, _eàch,
   {{0x224d00e9,0x63a70018,0xdb0300bf,0x79840027}},	// [a380] _čeka_, _bajn, _sanè, _iciw,
   {{0x78a49690,0x25a60660,0xdb03098c,0x9f5c0206}},	//   _isiv, žol_, _panè, sovú_,
   {{0xe72a6804,0xea010023,0x7ddc0113,0x9f900139}},	//   _фонд_, _quầy_, _lésa, _gàù_,
   {{0xdb0300fc,0x00000000,0x00000000,0x00000000}},	//   _cané, --, --, --,
   {{0x63a700a5,0x24899691,0xa067174e,0xdb031405}},	//   _fajn, ctam_, дача_, _dané,
   {{0xb03300d6,0x2cad9692,0x63a7393f,0x5f930da5}},	//   вніш, dved_, _gajn, вишт,
   {{0x316d0143,0x2d8d9693,0x2cad9694,0xc243180b}},	//   _fdez_, ffee_, eved_, _анск,
   {{0x44389695,0x200e5fe7,0x7bca9696,0xec6a2064}},	//   _hir_, sofi_, _sofu, орок_,
   {{0x61e29697,0x6f0d03e0,0x6fd400ee,0x7dd59698}},	//   mhol, ğaca, _làci, _másh,
   {{0x5f760391,0x61e2085d,0x7ddc0257,0x4438008a}},	//   _زائر, lhol, _désa, _jir_,
   {{0x38690501,0x44389699,0x337700a1,0x6b9a8116}},	//   _svar_, _mir_, ועים_, retg,
   {{0xc33317f5,0x61e202ec,0x4438969a,0xdd8f00e3}},	//   כות_, nhol, _lir_, _نوم_,
   {{0xdd8f1e49,0x443801b5,0x7bca88ab,0x290c00a7}},	//   _خون_, _oir_, _tofu, şdan_,
   {{0x44380090,0x61e2969b,0x6fdd0113,0x3f9c969c}},	//   _nir_, hhol, _kèca, nevu_,
   {{0x38c501e5,0x61e20060,0xe61300e3,0x63a7969d}},	//   _bërë_, khol, نشر_, _rajn,
   {{0xe81f048a,0x4438378d,0x24890018,0x63a70018}},	//   _मीरा_, _air_, ttam_, _sajn,
   {{0x44385425,0x61e201c5,0xb4d900a5,0xd7e700d6}},	// [a390] _bir_, dhol, ़ने_, _жіно,
   {{0x3f9c26dd,0x7dd5969e,0x6fd40472,0x2489969f}},	//   jevu_, _pásk, _fàci, rtam_,
   {{0x443896a0,0x248996a1,0x65640bb6,0x63a796a2}},	//   _dir_, stam_, baih, _vajn,
   {{0x7c3896a3,0x443896a4,0x248996a5,0x61e2526d}},	//   _livr, _eir_, ptam_, ghol,
   {{0x63a702e6,0x44383763,0x244496a6,0x5184061b}},	//   _tajn, _fir_, _göm_, туха,
   {{0x187c00a1,0x443802ec,0x7c3800e7,0x7dd50103}},	//   קטוב, _gir_, _nivr, _tásk,
   {{0x61e24dac,0xa3a80d75,0x7ddc014b,0x682001f9}},	//   bhol, _खोट_, _sésa, ködn,
   {{0x61e25ae0,0x6fdd05fe,0x6e920037,0xdb180c45}},	//   chol, _dèca, اليا, _invè,
   {{0x603905aa,0x3f8901c2,0x8b0702c6,0x3f9c010a}},	//   _fňma, ƙau_, _ohří, bevu_,
   {{0x7dd50018,0x2cad00a1,0x3f9c0580,0xddc801d3}},	//   _mási, rved_, cevu_, ļoša,
   {{0x656f1af5,0x80a70096,0x7c3800e8,0x291e007f}},	//   _odch, चिके, _divr, ętam_,
   {{0x69c601fa,0x799d084e,0x644f04e9,0x7ddc01dc}},	//   ujke, gesw, _otci, _tésa,
   {{0x7dd50146,0x65640084,0x26170161,0x9f47026a}},	//   _nási, vaih, nçou_, ginç_,
   {{0x6d4996a7,0x60c401a5,0x38c50052,0x656401c2}},	//   lcea, äimi, _sërë_, waih,
   {{0x66e61c00,0x443896a8,0x6d490036,0xd62a1a17}},	//   хова, _rir_, ocea, зове_,
   {{0x7dd5132d,0xa3a8417a,0x78a400aa,0x61e296a9}},	//   _bási, _खोज_, _tsiv, xhol,
   {{0x656496aa,0x443896ab,0x6d49009b,0x67e20220}},	// [a3a0] raih, _pir_, icea, _pôjd,
   {{0x0857040a,0x6fd400b3,0x645d00eb,0x65643661}},	//   _רבים_, _tàci, _dwsi, saih,
   {{0x44381f30,0x38c5023b,0x61e22b3b,0xe7320076}},	//   _vir_, _tërë_, thol, _حصة_,
   {{0x443896ac,0x3f8596ad,0x2a6a0018,0x7dd543db}},	//   _wir_, _aclu_, ábbi_, _fási,
   {{0x44382fb1,0x61e20170,0xdb1805aa,0x3f9c96ae}},	//   _tir_, rhol, _envè, tevu_,
   {{0x442c06a3,0x61e296af,0x4ea6166f,0x443852bd}},	//   _òd_, shol, ериа, _uir_,
   {{0x7dd5025b,0x3f9c96b0,0xe2971824,0x61e296b1}},	//   _zási, revu_, _пар_, phol,
   {{0x291e00a5,0x7dce01b9,0x3f9c02ef,0xbef70037}},	//   ętaj_, _cùsp, sevu_, عروض_,
   {{0xdb180161,0x32070103,0x98ab008b,0x2bdc00b6}},	//   _invé, énye_, yacı_, यसला,
   {{0x8afe0022,0x3ea9007f,0xdb5796b2,0x261700b3}},	//   _leƙe, łata_, нюю_, lçot_,
   {{0x7c380257,0x799d4204,0x2f260065,0x63bc084e}},	//   _vivr, tesw, _dígí_, _mnrn,
   {{0x225c0074,0x613607aa,0x6e39030a,0x00000000}},	//   ávky_, _gülü, _giwb, --,
   {{0x799d1868,0x441000c3,0x00000000,0x00000000}},	//   resw, ़काऊ_, --, --,
   {{0xb8c90d1b,0x2ca60150,0x799d96b3,0x9f470233}},	//   _गई_, _isod_, sesw, rinç_,
   {{0x7a3e0138,0x9c1700ca,0xab270284,0x98ab0345}},	//   _būte, _רחוק_, _поља_, racı_,
   {{0x3495922c,0x7ddc96b4,0x236500e7,0x7dd537c3}},	//   кабр, _méso, _žlj_, _pási,
   {{0x3a2902c9,0x00000000,0x00000000,0x00000000}},	// [a3b0] _ihap_, --, --, --,
   {{0xdce074b4,0xdb0300b3,0xdd0c007f,0x00000000}},	//   jamč, _innò, _kółk, --,
   {{0xc87f0364,0xfe1000b6,0x3a29020b,0x79ea0103}},	//   luß_, ावास_, _khap_, _رویہ_,
   {{0xcb1300c1,0x7ae500aa,0x2ca600f0,0x45d53a1f}},	//   אלע_, _ühte, _osod_, _ромс,
   {{0xf99400a1,0x10a51510,0x6f1a0154,0xa0a5028d}},	//   טרף_, тилн, _aytc, талд,
   {{0x61e000a7,0xdb182ef5,0x3a290113,0x26170131}},	//   _elml, _envé, _lhap_, rçou_,
   {{0x628b020a,0x5f0500e5,0x9f47007b,0x31660027}},	//   ăgos, ъзка, vinä_, baoz_,
   {{0x7ddc025a,0x9f5c0146,0x7767023e,0x3a2900de}},	//   _déso, mový_, hajx, _nhap_,
   {{0x9f5c025b,0xa5bb2027,0x6d4996b5,0x261725a5}},	//   lový_, _dióx, rcea, lços_,
   {{0x6d4900e3,0x1a65110a,0xe5020557,0x6fd400b3}},	//   scea, نیتی_, लपति_, _bàcu,
   {{0x9f5c025b,0x26171f8d,0xdb030154,0x91d50179}},	//   nový_, nços_, _annò, _दवाई,
   {{0x3a2996b6,0x186a2a61,0x9f47007b,0x7bda3ffc}},	//   _chap_, мами_, sinä_, aktu,
   {{0x9f5c0146,0x00000000,0x00000000,0x00000000}},	//   hový_, --, --, --,
   {{0x9f5c0363,0x00000000,0x00000000,0x00000000}},	//   kový_, --, --, --,
   {{0xfaa596b7,0x9f5c0146,0x96631278,0xdb031bb9}},	//   _райо, jový_, икре, _kaní,
   {{0x9f5c025b,0x98be01e8,0x63bc47a6,0xdb0300d4}},	//   dový_, ştı_, _snrn, _janí,
   {{0xd46707f3,0x741600b9,0xb3868bbf,0x25ab03a8}},	// [a3c0] ките_, نورا, клал, _dacl_,
   {{0x2d9f0313,0x00000000,0x00000000,0x00000000}},	//   heue_, --, --, --,
   {{0x66e6425b,0x9f5c0094,0x277700ca,0x78b60350}},	//   _рона, gový_, _בגין_, _hryv,
   {{0x7ddc96b8,0xdb180074,0x6fd4015e,0x20050350}},	//   _réso, _nový, _làct, _ajli_,
   {{0x80be0455,0xe0e00081,0xf8c20285,0x7bda01cd}},	//   ्हें, বপ্ন, शमिय, yktu,
   {{0xdfcf3345,0x9f5c135f,0x25a096b9,0xb4de0034}},	//   يين_, bový_, leil_, तनी_,
   {{0x6fdd0472,0x24800441,0xdb030094,0x9f5c0094}},	//   _tècn, luim_, _baní, cový_,
   {{0x5f16007d,0x7526023e,0x25a00441,0x442a0167}},	//   _पुण्_, _kzkz, neil_, _hhb_,
   {{0xc5f30054,0xdb011050,0x3a2900f9,0xdb0396ba}},	//   ידה_, ndlæ, _rhap_, _daní,
   {{0x25a096bb,0x9f5e0154,0xdd0c0034,0x442a0f5a}},	//   heil_, _ektò_, _półk, _jhb_,
   {{0xe9f93006,0x5a353407,0x0d86246d,0x37ba0081}},	//   енні_, лнот, _ален, ুসার,
   {{0x39400027,0x5a3400d3,0x248002ac,0x00000000}},	//   _cgis_, инэт, kuim_, --,
   {{0x386d67d2,0x9f5c0146,0xc8641165,0x6fd400ee}},	//   éer_, zový_, итри, _fàct,
   {{0x248096bc,0xd7c9001c,0x481400ae,0x00000000}},	//   duim_, روزه_, имяс, --,
   {{0x88cb0081,0x1af00081,0x3a2996bd,0x25a00120}},	//   _লেখক, _ঘুরে_, _thap_, feil_,
   {{0x9f5c025b,0x25a001b5,0x7c2d028d,0x1dc50469}},	//   vový_, geil_, _èarr, वायत,
   {{0x80be0067,0x386000f0,0x442a2e35,0x24800428}},	// [a3d0] ्हों, _gwir_, _bhb_, guim_,
   {{0x9f5c0074,0x6fdd05fe,0x442a007e,0xa5bb0076}},	//   tový_, _rèco, _chb_, _mhói,
   {{0x7dd50146,0x59d732f6,0x938800e5,0x96f900ae}},	//   _zásu, _डकार, ъста_, _чент_,
   {{0x261725da,0x9f5c025b,0xdd0100cb,0x66dc00c2}},	//   rços_, rový_, _žučn, säkö,
   {{0x7dd596be,0x9f5c025b,0xdfd50ae3,0x2480044c}},	//   _mást, sový_, лоды, cuim_,
   {{0x7dd50487,0x9f5c0094,0x224305db,0x00000000}},	//   _lást, pový_, _tujk_, --,
   {{0x4e9500e3,0xf1a703fc,0x76450167,0x69dd4a7e}},	//   اشتر, _иран, _juhy, kkse,
   {{0x7dd50074,0x7645061d,0xa2a80557,0x7c2a0090}},	//   _nást, _muhy, _घनत्, _ahfr,
   {{0xa5bb0080,0x31340c2b,0x7c2a0037,0x0cb30033}},	//   _chói, _ветр, _bhfr, য়ন্ত,
   {{0x7aa51720,0x69dd96bf,0xa5bb0076,0x5ac9290e}},	//   гиоз, ekse, _dhói, елом_,
   {{0x160316e2,0xdb0306f0,0x764501ff,0x00000000}},	//   रचार_, _taní, _nuhy, --,
   {{0x2b4e01c2,0x61f900f9,0x6016016d,0xa5bb0076}},	//   _effc_, niwl, lâmp, _fhói,
   {{0x6d5b2c09,0x25a087af,0x6fd40428,0xfd44013f}},	//   mbua, veil_, _tàct, _тэхн,
   {{0x291e00d9,0x69dd00c2,0x2a6c00ec,0xaae509f4}},	//   āta_, akse, bsdb_, _مسعو,
   {{0x66e334fc,0x25a096c0,0x7dd50037,0x65ba0831}},	//   бора, teil_, _fást, нуар_,
   {{0x64a65d76,0x7dd510d9,0x2905008b,0x248004f2}},	//   лаба, _gást, ğlar_, tuim_,
   {{0x29050390,0x25a096c1,0xb4de32ec,0x00000000}},	// [a3e0] şlar_, reil_, तने_, --,
   {{0x7dd50579,0x25a001b5,0x248096c2,0x934600ae}},	//   _zást, seil_, ruim_, унже,
   {{0xdb0a015e,0x764503a9,0x1bf6006e,0x574300ae}},	//   _cafè, _guhy, נצער_, _ынэб,
   {{0x00e63407,0x067b006e,0x798625e4,0x7a3e01d3}},	//   лжен, _אנטל, ngkw, _jūta,
   {{0x660496c3,0x24801f8d,0xdce001d3,0x8a1700ca}},	//   mnik, quim_, kamā, נחנו_,
   {{0x66046b4f,0xeeaa12e7,0x656600f9,0xdce001d3}},	//   lnik, етик_, _hekh, jamā,
   {{0x69dd0084,0x6566117e,0xdb010149,0xa5bb0037}},	//   ykse, _kekh, ndlä, _shói,
   {{0x5c744d79,0x660496c4,0x644696c5,0x7c2a023b}},	//   алит, nnik, _kuki, _shfr,
   {{0xa3e805d4,0x600a1121,0x63ae023e,0x660413e1}},	//   _बता_, _знам_, _kabn, inik,
   {{0xda7a96c6,0x644601a6,0x7dd500e3,0x65660372}},	//   ням_, _muki, _sást, _lekh,
   {{0xd00f003f,0x660496c7,0x64464146,0xb87b662a}},	//   _علم_, knik, _luki, nzív,
   {{0x69dd02fd,0x6566019f,0xa5bb0076,0x644602ac}},	//   ukse, _nekh, _thói, _ouki,
   {{0x6446006d,0x5c5642d1,0x69dd00d6,0x7dd50487}},	//   _nuki, _стеф, rkse, _vást,
   {{0xdce001d3,0xdb0300ee,0x5fc70096,0x69dd00bc}},	//   camā, _fanà, लायल, skse,
   {{0xd5bb66e1,0x644696c8,0x7dd500e3,0xaab708ba}},	//   нса_, _auki, _tást, _مدير_,
   {{0x66047fc1,0x6aaa03a8,0x00000000,0x00000000}},	//   gnik, _isff, --, --,
   {{0xd37b139c,0xf99000e3,0x64462693,0x63ae0141}},	// [a3f0] ече_, _ربي_, _cuki, _babn,
   {{0x6446006d,0x926b1acf,0x65661183,0x5eea0033}},	//   _duki, ерда_, _eekh, _কখনও_,
   {{0x66040b27,0xdb03499e,0x63ae022e,0x64460634}},	//   bnik, _kaná, _dabn, _euki,
   {{0xdb0a0583,0x6d420019,0x629c00ed,0x644613d0}},	//   _café, _ngoa, _dpro, _fuki,
   {{0x601600d3,0x601f0161,0x64460193,0xdceb003d}},	//   tâmp, lêmi, _guki, _ibgħ,
   {{0x3d18000f,0x629c002b,0xd47a006e,0x6d4201ff}},	//   _पड़े_, _fpro, _באשל, _agoa,
   {{0x6d5b01d4,0x644602ef,0xd3440018,0xd00e1f11}},	//   tbua, _zuki, _اہمی, بلو_,
   {{0xdb030094,0x6039022b,0xbca50076,0xdb018bf1}},	//   _naná, _kňmk, لمبي, ndlå,
   {{0x6d5b6ec5,0xdb010161,0x629c00b6,0xcd29008f}},	//   rbua, celê, _zpro, ъжие_,
   {{0x66043151,0xdb1811ce,0x7dd50161,0xabd51009}},	//   znik, _enví, _páss, рциј,
   {{0x4fc4426c,0xdb031e6f,0x3b091121,0xdce00877}},	//   _уста, _baná, тено_, ramā,
   {{0x66040092,0x601f0161,0xdb031bf7,0xdce00325}},	//   xnik, dêmi, _caná, samā,
   {{0x7dd50503,0x00000000,0x00000000,0x00000000}},	//   _fásr, --, --, --,
   {{0x66040067,0x64463223,0xdb0300e3,0x65660415}},	//   wnik, _ruki, _eaná, _sekh,
   {{0x09e691e5,0x644613ff,0xdb030cb6,0x65660063}},	//   _войн, _suki, _faná, _pekh,
   {{0xe9df0181,0x06072251,0x644696c9,0x395f003e}},	//   ckú_, анск_, _puki, ðust_,

   {{0x629c96ca,0x7ddc07d4,0xddd800cc,0x00000000}},	// [a400] _spro, _désh, nuvš, --,
   {{0x660408c5,0x629c003d,0x68200018,0x644696cb}},	//   snik, _ppro, ködi, _vuki,
   {{0x66040c7e,0xb1460b2e,0x656600ec,0x877b0327}},	//   pnik, анел, _tekh, _באיי,
   {{0x64461c24,0xfc480019,0xe0da0831,0x00000000}},	//   _tuki, _lửa_, кве_, --,
   {{0x4fc6455b,0x629c00a5,0x67450155,0x644600f9}},	//   иска, _wpro, _átjá, _uuki,
   {{0xfc480019,0x63bb03e3,0x442101b9,0x00000000}},	//   _nửa_, _ɗunk, clh_, --,
   {{0x7ddc0257,0x539b00ca,0x6fdd020d,0x6b8a009c}},	//   _hési, _שילו, _mèch, _rcfg,
   {{0x9fa3003e,0x7dd50328,0x6fdd020d,0xf65700d7}},	//   síðu_, _básq, _lèch, בסקי_,
   {{0x64400257,0x5f1605fa,0xdb010216,0x00000000}},	//   _émis, _पुर्_, belë, --,
   {{0xfc480028,0x6609005f,0x60e807aa,0x23c90179}},	//   _cửa_, čeki, ırmı, रायद,
   {{0xb4db0028,0x6253003d,0x7ddc269b,0xdb0396cc}},	//   _ngàn, _għod, _lési, _paná,
   {{0x245d0065,0xdd900286,0x00000000,0x00000000}},	//   _jámò_, _روت_, --, --,
   {{0xfbcf0688,0x6fdd05aa,0xdb030231,0x53c90285}},	//   ستی_, _bèch, _vaná, रामश,
   {{0xd7fb0215,0xe9df0031,0x24920e4b,0x245d0139}},	//   тум_, skú_, dtym_, _lámò_,
   {{0xdb030018,0x66ca0139,0x395203a8,0xf1c700aa}},	//   _taná, _kàṣà_, _ffys_, _रचलन,
   {{0x3c2b01df,0xdb1800b3,0x00000000,0x00000000}},	//   røve_, _invà, --, --,
   {{0x22a801e8,0x44210062,0xb87b0103,0xdef80090}},	// [a410] _aşk_, tlh_, gzít, _deċi_,
   {{0x7ddc025a,0x78ad755b,0xd68719c3,0x6fdd05aa}},	//   _dési, _isav, _кумп, _gèch,
   {{0xa5bb0037,0xdb0a96cd,0x00000000,0x00000000}},	//   _bhót, _infó, --, --,
   {{0xf54f0174,0xe1f00214,0xa5bb0503,0xc244021a}},	//   _rụwa_, وسن_, _chót, інік,
   {{0xdce20095,0x245d0139,0xc1040037,0xe80e0336}},	//   _beoč, _dámò_, يومي, _सदमा_,
   {{0x656d96ce,0xdce0020a,0x335800ae,0xa2e00af0}},	//   laah, zamă, _варэ_, _kọ́k,
   {{0x21290181,0xfc4800de,0x3f8700e7,0xa49b015e}},	//   ťah_, _rửa_, rgnu_, _exòt,
   {{0xfc480028,0x798d006c,0x63a502db,0x78ad0f06}},	//   _sửa_, _ncaw, lehn, _osav,
   {{0x628596cf,0xdb0101f9,0xa2e00139,0x00000000}},	//   luho, melé, _lọ́k, --,
   {{0x63a5033b,0x656d96d0,0x7dd5034f,0x6253009e}},	//   nehn, haah, _vásq, _iħob,
   {{0xa96a0114,0xae7800d6,0x656d96d1,0x78ad010a}},	//   лина_, _всіх_, kaah, _asav,
   {{0xdb030396,0x656d008a,0x6fdd00fd,0x98a600e5}},	//   _lanç, jaah, _sèch, биме,
   {{0xeb992de0,0x91ba00ca,0xdb18015e,0x78ad0103}},	//   _бил_, אמרי, _envà, _csav,
   {{0x7ddc025a,0x628596d2,0x661d02ac,0x00000000}},	//   _rési, kuho, _aksk, --,
   {{0x6729000d,0xdb010018,0x32064b94,0x66e30f30}},	//   řejn, kelé, ynoy_, пора,
   {{0xbb3a00c1,0x7ddc7176,0x6fdd015e,0xdb0a022b}},	//   _געצי, _pési, _dèci, _enfó,
   {{0xfd640134,0xdb1896d3,0x625300bd,0xf9930a41}},	// [a420] _agwụ, _invá, _nħob, _זרח_,
   {{0xdb0368a4,0x6039022b,0x29ef01c2,0xdb0a022b}},	//   _canç, _fňmi, nƙan_, _infò,
   {{0xb87b0068,0xe5a636c9,0x69c40a2c,0xdb03001f}},	//   szít, _лини, _knie, _danç,
   {{0x69d696d4,0xc8b50068,0x765c0124,0x3d185c52}},	//   _joye, _الیک, mpry, _पडले_,
   {{0x69d6025a,0x7bc30172,0x69c400a5,0xa5bb003e}},	//   _moye, _onnu, _mnie, _skóg,
   {{0x628596d5,0x69d600fd,0x7a0b007f,0xdb03042c}},	//   buho, _loye, jętn, _kanä,
   {{0x7ddc00ee,0x61eb009c,0xf1c300d2,0x00000000}},	//   _mésv, bhgl, áší_, --,
   {{0x7bc396d6,0x69d696d7,0x200796d8,0x61eb02db}},	//   _annu, _noye, anni_, chgl,
   {{0xf1c3030b,0x61e23b0d,0xdce202ef,0x8afc0034}},	//   šší_, mkol, _teoč, zbęd,
   {{0x24800037,0xf54f0134,0xdce000c6,0x765c2566}},	//   irim_, _hụta_, jamą, kpry,
   {{0x441b00c1,0x69d696d9,0x69c403e5,0x248096da}},	//   רויס, _boye, _bnie, hrim_,
   {{0x14c80f02,0x7bc396db,0x61e296dc,0xf4000081}},	//   रमाण, _ennu, nkol, ্তির_,
   {{0xdca3176b,0xf54f0129,0x1dc50285,0x69d696dd}},	//   _наци, _mụta_, वारत, _doye,
   {{0xdb010018,0x656d00ac,0xd7f83cf9,0xb8d12a29}},	//   zelé, waah, бус_, _ऐन_,
   {{0x61e296de,0xdb0a0c56,0xf4000081,0x69d696df}},	//   kkol, _enfò, ্তার_, _foye,
   {{0x9f470146,0x78ad7417,0xa5bb037a,0xdb0350d5}},	//   diný_, _tsav, _ahór, _sanç,
   {{0x63a52191,0x656d0694,0xdb010018,0x61e230e6}},	// [a430] tehn, raah, velé, dkol,
   {{0xa5bb0037,0x628596e0,0x61e22ea3,0x7d1d01bf}},	//   _chór, tuho, ekol, üssi,
   {{0xa6ab2761,0xdb010018,0x45d54a09,0x69d601ff}},	//   _صادق_, telé, _донс, _yoye,
   {{0x201e96e1,0x61e296e2,0x63a56850,0x00000000}},	//   _akti_, gkol, sehn, --,
   {{0xdb010018,0xb97c0341,0xa5bb0037,0x7ddc926e}},	//   relé, רנדי, _fhór, _jésu,
   {{0xf2e75e3d,0x66090335,0x7e5513c0,0x61e2083e}},	//   _любо, čeku, отиц, akol,
   {{0xb7dc00c1,0xdb010677,0x7ddc0113,0x61e2010a}},	//   רקוי, pelé, _lésu, bkol,
   {{0xec791c0e,0xa194007b,0x68400139,0x6253009e}},	//   апи_, _насч, _kádì, _tħob,
   {{0x61fb96e3,0x69d62722,0x61e9405f,0x7aed01c2}},	//   _imul, _roye, _ilel, _ƙato,
   {{0x69c44290,0x69d60257,0xf54f0294,0x29ef01c2}},	//   _snie, _soye, _zụta_, uƙan_,
   {{0xab2903a0,0x69c410a4,0x61e903a9,0xdb013229}},	//   рона_, _pnie, _klel, ndlø,
   {{0x5ed200c7,0x27fa00ec,0x7ddc03a9,0x63800139}},	//   _থেকে, _smpn_, _bésu, _kánà,
   {{0x69d696e4,0x9f4596e5,0x776e00a7,0x61fb0361}},	//   _voye, _allé_, tabx, _mmul,
   {{0x61e296e6,0x61e9002b,0x7bc301cd,0x24800233}},	//   zkol, _llel, _unnu, vrim_,
   {{0x61fb0a15,0xe73a385a,0x61e93c06,0x69d659e1}},	//   _omul, рев_, _olel, _toye,
   {{0x69c4802c,0xceb20089,0xa5bb15b8,0x24800216}},	//   _unie, ויל_, _akób, trim_,
   {{0xb87b0068,0x3a200449,0x765c5783,0x7ddc03a9}},	// [a440] szír, _ikip_, spry, _gésu,
   {{0x61fb96e7,0x2480023b,0xf772262f,0x00000000}},	//   _amul, rrim_, _کاک_, --,
   {{0xf54f0129,0x75ea0094,0x2d9d06b0,0x61e296e8}},	//   _pụta_, _výzb, _obwe_, tkol,
   {{0x24808495,0x61e90036,0xea8c006e,0x443101c8}},	//   prim_, _clel, רנאָ, _ehz_,
   {{0x61e296e9,0x9f5c00d4,0x75fa02c6,0x00000000}},	//   rkol, livé_, hůzk, --,
   {{0x61e90129,0x2d9d0172,0x88bb006e,0x443170a9}},	//   _elel, _abwe_, יזני, _ghz_,
   {{0xfe6f0568,0x9f5c0094,0x6d460094,0x6536001c}},	//   ندي_, nivé_, žkam, _درگذ,
   {{0x934302ec,0xdd971cb1,0x61fb0124,0x7ddc0ba6}},	//   _інте, ошь_, _gmul, _nést,
   {{0x9f47034f,0x00000000,0x00000000,0x00000000}},	//   ginó_, --, --, --,
   {{0x7ddc04ea,0xbea64ead,0x00000000,0x00000000}},	//   _résu, _мазк, --, --,
   {{0x3eb80103,0x9f5c00d4,0x224405db,0x7ddc0113}},	//   _ért_, jivé_, _kimk_, _sésu,
   {{0x201c113c,0x9f5c0437,0xec350103,0x6ce6018a}},	//   lovi_, divé_, _ہونگ, _міле,
   {{0xa92b0565,0xc17300ca,0x9f47425a,0x7ddc020d}},	//   ріне_, וחר_, minò_, _dést,
   {{0xbebc0b4b,0x3a203b10,0x36d511cc,0x00000000}},	//   _dzīv, _ekip_, погр, --,
   {{0x3dc60054,0x23c902d5,0x356b08c3,0x3a200085}},	//   _know_, रासद, иран_, _fkip_,
   {{0x7a120029,0x7bd800f3,0x54550d9b,0x6fdd00b3}},	//   tāte, _hovu, зват, _hèct,
   {{0x34940084,0x394900aa,0x94ab0291,0x7bd896ea}},	// [a450] матр, _igas_, штва_, _kovu,
   {{0x61fb96eb,0x7bd80090,0x61e90113,0x9f5c00d4}},	//   _smul, _jovu, _slel, bivé_,
   {{0x201c02e6,0x7afc00e3,0x7ddc0131,0x00000000}},	//   dovi_, úrth, _jéss, --,
   {{0x7bd873cc,0x386903e3,0xdb180212,0x00000000}},	//   _lovu, _kwar_, _invä, --,
   {{0x201c031a,0xf7f400cd,0x3ebe00e5,0xf8cb00c3}},	//   fovi_, _رسید, _artt_, ामिय,
   {{0x201c0106,0xa2a6000f,0x44254232,0x6fdd00b3}},	//   govi_, _टैक्, _ól_, _nèct,
   {{0x248959a1,0x61e996ec,0x394996ed,0x00000000}},	//   luam_, _tlel, _ogas_, --,
   {{0x25a90013,0x63b5062d,0x394996ee,0x61fb96ef}},	//   neal_, _hazn, _ngas_, _umul,
   {{0x201c0039,0x248996f0,0x321d0034,0x212d0a39}},	//   bovi_, nuam_, mowy_, _uzeh_,
   {{0x25a9151d,0x321d0034,0x201c96f1,0x394996f2}},	//   heal_, lowy_, covi_, _agas_,
   {{0x7bd896f3,0x316d96f4,0x63b596f5,0x3869006d}},	//   _dovu, _keez_, _mazn, _awar_,
   {{0x63b500cc,0x3d953715,0x321d0034,0x38696eb5}},	//   _lazn, _хидр, nowy_, _bwar_,
   {{0xdb181424,0x25a996f6,0xdb030102,0x00000000}},	//   _anvä, deal_, _janú, --,
   {{0x386904f9,0x9f5c96f7,0x2a67016d,0x7ddc00ee}},	//   _dwar_, tivé_, _twnb_, _féss,
   {{0xfaa20465,0x321d0034,0x6297023e,0xdb0317d5}},	//   _защо, kowy_, jtxo, _lanú,
   {{0x201c0039,0x25a97aaa,0xceb2028c,0x9f5c96f8}},	//   zovi_, geal_, עין_, rivé_,
   {{0x321d00a5,0x64a35ac3,0x24890332,0x63b500d9}},	// [a460] dowy_, ната, guam_, _bazn,
   {{0x613501f9,0x63b5078e,0x00000000,0x00000000}},	//   zülé, _cazn, --, --,
   {{0x201c04a3,0x386902e2,0xdce00335,0x25a90611}},	//   vovi_, _zwar_, pamć, beal_,
   {{0x04460084,0x25a95ab6,0xdb0300b3,0x321d007f}},	//   _немн, ceal_, _banú, gowy_,
   {{0x25d707a6,0x656406a8,0x63b56ed0,0x55bb00ca}},	//   _זוכן_, mbih, _fazn, _המכו,
   {{0xdb0a0222,0x63b51b36,0x7416110a,0x6297023e}},	//   _infö, _gazn, _روزا, btxo,
   {{0x7646083e,0x316d01ff,0x321d007f,0x9f4702c6}},	//   _kiky, _feez_, bowy_, chní_,
   {{0xdb030220,0x76460167,0x2d8d96f9,0x7bd896fa}},	//   _fanú, _jiky, ggee_, _sovu,
   {{0x7bd800e9,0x201c00e9,0xdb080161,0x7646010a}},	//   _povu, povi_, cedê, _miky,
   {{0x9f470451,0x7ddc0161,0x25a9044c,0x7bd800a7}},	//   sinò_, _péss, zeal_, _qovu,
   {{0x61350018,0xc4c80be4,0xdb030032,0x38694d16}},	//   pülé, रमुख, _kanù, _swar_,
   {{0x80b30034,0x2489023e,0x764606b0,0x7bd896fb}},	//   _इनमे, yuam_, _niky, _wovu,
   {{0x7bd896fc,0x6e2285f2,0x39490231,0x25a900d7}},	//   _tovu, _ikob, _vgas_, veal_,
   {{0x3f8e37bd,0xd7f800d3,0xead00065,0x8c431372}},	//   ngfu_, пус_, _dẹri_, _зече,
   {{0x752f0d1b,0x25a90a02,0x76460361,0x78a405aa}},	//   _szcz, teal_, _biky, _epiv,
   {{0x63b500e9,0x65640d1f,0x7c2896fd,0x24898e8c}},	//   _sazn, gbih, lldr, tuam_,
   {{0xb4e733d9,0x76460270,0x73d9530e,0x38690d2a}},	// [a470] बने_, _diky, одар_, _uwar_,
   {{0x25a996fe,0x67250084,0x4ab00efb,0xaab0030b}},	//   seal_, _tyhj, _जनाव, _जनाक,
   {{0x98b90390,0x25a996ff,0x2489006c,0x63b500cc}},	//   ması_, peal_, suam_, _vazn,
   {{0x7a3f5873,0x62970a00,0x22952452,0x98b90491}},	//   _būti, rtxo, råk_, lası_,
   {{0x656f02ad,0x24890231,0x321d69d1,0x7a1200d9}},	//   _iech, quam_, rowy_, nāta,
   {{0x656f9700,0x98b907aa,0x645d02a4,0x6e228702}},	//   _hech, nası_, _itsi, _akob,
   {{0x656f9701,0x60c05dcf,0x660d84eb,0x442303a9}},	//   _kech, _ermm, onak, _ikj_,
   {{0x644f0484,0x660d75f7,0x64479702,0xb4db009c}},	//   _kuci, nnak, _hiji, _agài,
   {{0x98b907d1,0x64479703,0x656f9704,0x660d9705}},	//   kası_, _kiji, _mech, inak,
   {{0x656f9706,0x64479707,0x644f6c5b,0x7a1200e8}},	//   _lech, _jiji, _muci, dāta,
   {{0x64477bb8,0xdb0805fe,0x26c10197,0x98b9008b}},	//   _miji, nedè, _nrho_, dası_,
   {{0x656f0897,0x645d4207,0xf2d200c1,0x7dd50103}},	//   _nech, _otsi, דעט_, _lász,
   {{0x660d00cb,0x645d0d7d,0xe8f72284,0x6d590350}},	//   dnak, _ntsi, для_, _ifwa,
   {{0xa3ac034c,0xdca20d86,0x64474204,0xa6ca5e66}},	//   कड़ा_, _раши, _niji, олга_,
   {{0x645d08a1,0x656f9708,0x764600f9,0x00000000}},	//   _atsi, _bech, _piky, --,
   {{0x660d9709,0x644730ef,0x656f3751,0xdb0a0037}},	//   gnak, _aiji, _cech, _uafá,
   {{0x644f0465,0x656f970a,0x6447970b,0x25fd0635}},	// [a480] _cuci, _dech, _biji, रोधी_,
   {{0x644f970c,0x9f4518d8,0x6564970d,0x6e2967c5}},	//   _duci, _allí_, sbih, hleb,
   {{0x6d5903a8,0xe2973288,0x656f7e46,0x6447970e}},	//   _ofwa, дах_, _fech, _diji,
   {{0x6d4b06dd,0x644f00e5,0xda0e009d,0x656f970f}},	//   _ngga, _fuci, ाचित_, _gech,
   {{0x66044986,0x64479710,0x644f02a4,0x6e290415}},	//   miik, _fiji, _guci, dleb,
   {{0x66040c1e,0x6d4b9711,0x6d599712,0x44239713}},	//   liik, _agga, _afwa, _gkj_,
   {{0x644f006d,0x656f9714,0xdb08015e,0x00000000}},	//   _zuci, _yech, cedè, --,
   {{0x98b9008e,0x1dc51e05,0x6e299715,0xb4db9716}},	//   zası_, वागत, gleb, _afày,
   {{0x98b901d4,0x64470169,0x3166024a,0x00000000}},	//   yası_, _yiji, mboz_, --,
   {{0x6d4b9717,0xc0a903c5,0x7a1201d3,0x6e290172}},	//   _egga, _عاقل_, vāta, aleb,
   {{0xddcb02e6,0xdd8f007e,0x660d01e8,0x66040283}},	//   žišt, _иш_, ynak, kiik,
   {{0x7c661a37,0x6e223759,0x799d042c,0x38af02a1}},	//   _قاتل, _ukob, ufsw, _pżr_,
   {{0x656f9718,0x64c8000f,0x660d0181,0x98b903a3}},	//   _rech, रमोश, vnak, tası_,
   {{0x656f9719,0xdce002c6,0x645d0113,0x26c10141}},	//   _sech, zamě, _rtsi, _prho_,
   {{0x656f971a,0xa3d21784,0x75ea0074,0x98b908bb}},	//   _pech, वान_, _význ, rası_,
   {{0x6e20971b,0x6447971c,0x62850146,0x660d0798}},	//   nomb, _siji, vrho, unak,
   {{0x656f971d,0x660d8e19,0x25a2061d,0x64470085}},	// [a490] _vech, rnak, _dbkl_, _piji,
   {{0x656f02e2,0x7a1200d9,0x644f09ac,0x6e201621}},	//   _wech, nātn, _vuci, homb,
   {{0x6e206696,0x6447971e,0x625303e5,0xe0d0001c}},	//   komb, _viji, _għol, یزه_,
   {{0x3e7a0029,0xdb080018,0xd1310037,0xdb010146}},	//   dīt_, gedé, هما_, nelá,
   {{0xa06921f4,0x645d971f,0x6e297c75,0x7bca9720}},	//   чала_, _utsi, vleb, _onfu,
   {{0x7bca0090,0x7a3600d2,0x6e200350,0x00000000}},	//   _nnfu, máte, eomb, --,
   {{0xfc4800ef,0x44219721,0x6e200610,0x2bd20096}},	//   _gửi_, moh_, fomb, ताना,
   {{0x6e205fa6,0x4421033b,0x24860138,0x7bca47dc}},	//   gomb, loh_, šome_, _anfu,
   {{0x6e292cc4,0xdb01135f,0x442101af,0x7ddc0558}},	//   rleb, delá, ooh_, _vésp,
   {{0xa3d21fbb,0x35d1009f,0x2e4b008f,0x6e294192}},	//   वाय_, हाड़, _дядо_, sleb,
   {{0x6e207f0d,0xf99f008f,0x6e299722,0x2ca60270}},	//   bomb, ffè_, pleb, _epod_,
   {{0x61f9210e,0x7bca0517,0x6d4b8c9f,0xe9d7512a}},	//   _çalı, _enfu, _ugga, екю_,
   {{0x4421159d,0x660400c2,0xf1b933ab,0x1c390109}},	//   koh_, viik, _maš_, _езды_,
   {{0xcc7600f5,0xf1b9007e,0x7bca0172,0x00000000}},	//   _טענה_, _laš_, _gnfu, --,
   {{0x4421005a,0x66045638,0xdb010094,0xe737171c}},	//   doh_, tiik, belá, еер_,
   {{0x7bca007e,0xb9210294,0x7a3f004b,0x00000000}},	//   _znfu, ụrịt, _būtu, --,
   {{0x660428a3,0x3e7a01d3,0xa5bb0065,0xdb0801f9}},	// [a4a0] riik, zīt_, _ikól, vedé,
   {{0x660444d7,0x2bd20640,0x4421134a,0x2617003d}},	//   siik, ताया, goh_, għob_,
   {{0xf1b902e6,0x2bb7007d,0xa3d20251,0x6e2053dd}},	//   _baš_, _असना, वाब_, yomb,
   {{0x625300bd,0x9f5c0072,0xf8a40285,0x00000000}},	//   _għom, riví_, _ओहाय, --,
   {{0xf1230978,0x44210d17,0x9f4505fe,0xf1b90128}},	//   льшо, boh_, _allà_, _daš_,
   {{0x3e7a0029,0x44219723,0x6576008c,0xc059004d}},	//   tīt_, coh_, layh, фії_,
   {{0x443802dc,0x6e209724,0xdb0101df,0x180e18ff}},	//   _ihr_, tomb, lelæ, _सदैव_,
   {{0x3e7a00d9,0x32070103,0x65769725,0xe2a6003e}},	//   rīt_, ényt_, nayh, öðum_,
   {{0x3e7a0029,0x81b60a43,0x00000000,0x00000000}},	//   sīt_, জাদ_, --, --,
   {{0xa5bb0065,0x23c900c3,0x96e002d5,0xf1b900c4}},	//   _akól, राएद, नहाउ, _zaš_,
   {{0x443801b9,0xda771703,0x6e206ad2,0x2bd20966}},	//   _mhr_, няя_, pomb, ताबा,
   {{0xddea00cd,0xf8bf0146,0xa3d21d69,0x00000000}},	//   _عرضه_, tvé_, वाड_, --,
   {{0xebe6942b,0xf8bf025a,0x442103a9,0x2ca602c9}},	//   _подп, uvé_, yoh_, _upod_,
   {{0xf8bf0257,0xdb18023b,0x44380294,0xa5bb0139}},	//   rvé_, _javë, _nhr_, _ekól,
   {{0x25a000f0,0x38609726,0x00000000,0x00000000}},	//   ffil_, _etir_, --, --,
   {{0xd2db0096,0xd5b80c1d,0x00000000,0x00000000}},	//   _मॅगझ, нсу_, --, --,
   {{0x69cd0051,0xe45302a3,0x2bb70287,0xfbb7023a}},	// [a4b0] _inae, اضر_, _असमा, _असमम,
   {{0x7a369727,0x1602009d,0x68470065,0x67e20206}},	//   ráte, रोबर_, _dédì, _dôjs,
   {{0xa5f99728,0x44389729,0x8c1b00ca,0x69cd084e}},	//   _жену_, _dhr_, לומי, _knae,
   {{0x44215fb1,0x225c0a7f,0x443802db,0x69df0216}},	//   soh_, ívka_, _ehr_, _joqe,
   {{0x44210da3,0xed590106,0x44380234,0x7c3800aa}},	//   poh_, ndže_, _fhr_, _ohvr,
   {{0x9f450890,0x442146d8,0xc0e204fd,0x4fa547c4}},	//   _allá_, qoh_, рошк, тикв,
   {{0xf1a7972a,0x5334972b,0xf1b90218,0x00000000}},	//   _пран, _берт, _taš_, --,
   {{0xa3d2023a,0x69df0415,0x69cd010a,0x2cbf007e}},	//   वाथ_, _noqe, _nnae, tvud_,
   {{0x00db0781,0xdb030094,0x00000000,0x00000000}},	//   _عبرت_, _daný, --, --,
   {{0xa5bb0102,0x69cd972c,0x24890161,0x7c3800c4}},	//   _skól, _anae, iram_, _chvr,
   {{0xa3d202e8,0x248996da,0x05e10034,0x0dcb1009}},	//   वात_, hram_, _नवंब, _нуди_,
   {{0x24890c86,0xdd1d00ae,0x9f5c0e4b,0x00000000}},	//   kram_, _câţi, mivá_, --,
   {{0x24895a7b,0x7c2100a4,0xeb99972d,0x9f5c0094}},	//   jram_, polr, _жил_, livá_,
   {{0x2007628a,0x69cd010a,0x2489972e,0x6d5b037a}},	//   nini_, _enae, dram_, lcua,
   {{0xd62a63f1,0xa5961681,0xfc480023,0x68e60120}},	//   дове_, кращ, _cửu_, sykd,
   {{0x20071ee3,0x6d5b972f,0x24899730,0x38600090}},	//   hini_, ncua, fram_, _ttir_,
   {{0x20071ee3,0xb9070f71,0x25a05cd8,0xa5070b99}},	// [a4c0] kini_, _যে_, rfil_, вета_,
   {{0x20079731,0x64a3061b,0x7ae500bc,0xdb0102b6}},	//   jini_, рафа, _ühts, relæ,
   {{0x24890161,0xd259224a,0xb4db0441,0x9f5c0e43}},	//   aram_, еці_, _sgàt, jivá_,
   {{0x24890131,0x6d5b023e,0x9f5c0094,0x00000000}},	//   bram_, jcua, divá_, --,
   {{0xa3d21179,0x20079732,0xf99300a1,0x409600c2}},	//   वाद_, fini_, שרד_, трет,
   {{0x20079733,0x443802dc,0xdb1800b3,0x78fb00ca}},	//   gini_, _uhr_, _favè, ופנו,
   {{0x63bc8fa9,0xe7a40c3c,0x0eec0409,0xdb0116f9}},	//   _iarn, ख्यप, जनेस_, nelä,
   {{0x531b00ca,0x6e390178,0x229c00d4,0x00000000}},	//   _חולצ, _chwb, mík_, --,
   {{0x61e0006b,0x229c025b,0x629e2ee9,0xdb180052}},	//   _ioml, lík_, ltpo, _tavë,
   {{0x2bb7009d,0x63bc5db2,0x61e001f9,0xdb0100ce}},	//   _असणा, _jarn, _homl, kelä,
   {{0x63bc9734,0x229c0343,0xd00f1850,0x61e09735}},	//   _marn, ník_, _ظلم_, _koml,
   {{0x24890511,0x8b0700b6,0x61e00063,0x2d920120}},	//   yram_, _skří, _joml, _øye_,
   {{0xcdf700ca,0x63bc0063,0x6ba70212,0xdb030503}},	//   _במאי_, _oarn, ärgå, _banó,
   {{0xdb039736,0x69cd0150,0x61e09737,0x7aed01c2}},	//   _canó, _wnae, _loml, _ƙatt,
   {{0x2bb702e8,0xdceb00d9,0x5c370089,0xdb0111d0}},	//   _असता, _iegā, _שטוב_, gelä,
   {{0x24891be3,0x61e00415,0x229c0146,0x69cd0051}},	//   tram_, _noml, dík_, _unae,
   {{0x20079738,0x63bc9739,0x7bda01fa,0x0495015a}},	// [a4d0] yini_, _barn, ojtu, طلاح,
   {{0x2489973a,0x442700de,0x60c2033b,0x7a36221e}},	//   rram_, ôn_, dvom, máta,
   {{0x61e020a8,0x46150037,0x00000000,0x00000000}},	//   _boml, _مودر, --, --,
   {{0xf65000fb,0xa5f90277,0x20070201,0x63bc973b}},	//   _گئی_, _чему_, wini_, _earn,
   {{0x3c3900fd,0x61e000b6,0x248900a7,0x1fa90c3f}},	//   lève_, _doml, qram_, екли_,
   {{0xb4df009d,0x1e951360,0x229c0094,0x9f5c00d8}},	//   तही_, грир, bík_, tivá_,
   {{0x20076fca,0xed59280f,0x3a29973c,0x3c3900fd}},	//   rini_, ной_, _okap_, nève_,
   {{0x2007973d,0xe8d906c0,0x63bc973e,0x61e00a60}},	//   sini_, _afọ_, _zarn, _goml,
   {{0xdd1107d1,0x20072a39,0xdd910068,0xa5bb0139}},	//   _düşm, pini_, لوں_, _akók,
   {{0x3a2990e3,0x2007973f,0x61430139,0x63bc9740}},	//   _akap_, qini_, _ẹlò, _xarn,
   {{0x81b60f71,0x224d01b3,0xba75001c,0xaa463bbc}},	//   জার_, _kiek_, داخت, леол,
   {{0x6ec0063c,0x3a290063,0xdb080328,0x75ea00b6}},	//   विरु, _ckap_, cedí, _výzk,
   {{0x22470368,0x229c0146,0xdb0300ee,0xdb0125e5}},	//   ínky_, zík_, _canò, delå,
   {{0x224d37e6,0x6fb302d5,0xdb013f9b,0x00000000}},	//   _liek_, ंजिं, telä, --,
   {{0x98a50029,0xd7570260,0xfb240281,0x224d0062}},	//   ālā_, الفت_, _پروپ, _oiek_,
   {{0x229c0102,0x63bc007a,0xdb010149,0x224d112f}},	//   vík_, _sarn, relä, _niek_,
   {{0xfbb7072d,0x61e04d8e,0x63bc75eb,0xd57504a1}},	// [a4e0] _असाम, _roml, _parn, русь,
   {{0x229c9741,0x61e05d6f,0x69a02f74,0x63bc9742}},	//   tík_, _soml, ग्री, _qarn,
   {{0x63bc9743,0x5186139c,0x179b00c1,0x66e60881}},	//   _varn, гула, _אייב, _сона,
   {{0xa3d204f8,0x63bc9744,0x229c7c4d,0xd24f0f98}},	//   वाह_, _warn, rík_, سنه_,
   {{0x63bc9745,0x81b60a43,0x00000000,0x00000000}},	//   _tarn, জাল_, --, --,
   {{0xb4c2022d,0xb4c069d9,0x229c0094,0xceba0284}},	//   ्मी_, ंटी_, pík_, ељи_,
   {{0x61e09746,0x224d0063,0x644e4efd,0x4ea60036}},	//   _toml, _fiek_, _iibi, урла,
   {{0x79843663,0x5d540832,0xa3d23e2a,0x11da0037}},	//   _ndiw, шкит, वाव_, _ثورة_,
   {{0x7ddc00fb,0x644e9747,0x25d700c1,0x98a90234}},	//   _kész, _kibi, רופן_, _izać_,
   {{0x644e1b63,0x224d01c0,0x3a29611c,0x92d60033}},	//   _jibi, _ziek_, _skap_, িনী_,
   {{0x9e663035,0xc3fb00c1,0x442a8d46,0x38720150}},	//   _свед, גליש, _mkb_, _awyr_,
   {{0xf2d30130,0x75f8030b,0x27e101bf,0xadb70037}},	//   צער_, _jízd, _sohn_, _مهما_,
   {{0x798402ad,0x7d7b006e,0x442a023b,0x3872030a}},	//   _ddiw, _טראג, _okb_, _cwyr_,
   {{0x644e9748,0xf41f0149,0x7a369749,0x442a0027}},	//   _nibi, _iväg_, ráta, _nkb_,
   {{0xd90f00cd,0x7a3600d2,0x00000000,0x00000000}},	//   تیک_, mátn, --, --,
   {{0x2bd20d88,0xb4c239d4,0x442a974a,0xb4c06c66}},	//   तावा, ्मू_, _akb_, ंटू_,
   {{0x337530c0,0x7b0400c6,0x34953097,0x38720178}},	// [a4f0] игар, žutė, разр, _gwyr_,
   {{0x644e974b,0x224d6ae7,0x442a1355,0x9f45007b}},	//   _cibi, _siek_, _ckb_, _yllä_,
   {{0x644e974c,0xe45f0212,0x415509ba,0x224d000b}},	//   _dibi, _grön_, авес, _piek_,
   {{0x25b20188,0x69d80eeb,0x00000000,0x00000000}},	//   ceyl_, यायी, --, --,
   {{0x656d159d,0x7a36033d,0xed5902ef,0x3afb0139}},	//   mbah, kátn, jdža_, _kápé_,
   {{0xdceb00d3,0x656d974d,0x9f510092,0x644e974e}},	//   _legă, lbah, _özü_, _gibi,
   {{0x224d3df6,0xb3d202e8,0x7777003d,0x0eb913a4}},	//   _tiek_, सारख, _mexx, тулы_,
   {{0x656d974f,0xfbb70067,0x644e9750,0x78ad00b6}},	//   nbah, _असहम, _zibi, _opav,
   {{0x20ce003e,0xec760109,0x764f0169,0x644e6900}},	//   rðið_, апы_, _micy, _yibi,
   {{0xa3ab018b,0x60c99751,0x7a1200d9,0x656d005c}},	//   _कॉम_, _irem, māti, hbah,
   {{0x78ad01d3,0x34d10acc,0xa3bd1073,0xfaa52813}},	//   _apav, समुद, _आसन_, шано,
   {{0xcfaa0081,0xd94623e9,0x80b80033,0x3f850234}},	//   _গোপন, иени, _আপত্, _hdlu_,
   {{0x69d810e9,0x7a1200d9,0x77770085,0xed4e3e28}},	//   याबी, nāti, _bexx, _фо_,
   {{0x60c90051,0x9f470037,0x29ef01c2,0x205600ca}},	//   _mrem, dhnú_, uƙar_, יישל_,
   {{0x7ddc00fb,0xf74614fa,0x2bd21efb,0xdb080131}},	//   _rész, рево, तारा, redã,
   {{0x644e9752,0x656d0d3d,0x7a360146,0x0566515d}},	//   _sibi, gbah, máto, рван,
   {{0x7a3610a8,0x9f4700e3,0xa3d202d5,0x273c0139}},	// [a500] láto, ghnú_, वाल_, _bání_,
   {{0x7bc19753,0x187b00c1,0x656d0188,0x7a1201d3}},	//   ndlu, _שטיב, abah, dāti,
   {{0x7a361e6f,0x60c99754,0xe29a022c,0x237700cd}},	//   náto, _arem, тае_, شمند_,
   {{0x60c91a02,0x50663aa7,0x644e9755,0xf1c60d43}},	//   _brem, атка, _wibi, _रोशन,
   {{0xe04642c7,0x76440044,0xf8b8007a,0x7ddc0103}},	//   анди, mmiy, ेटिय, _tész,
   {{0x76443327,0x24809756,0x7a361e6f,0x7a3d0018}},	//   lmiy, msim_, káto, méte,
   {{0x44449757,0x76440694,0x60c99758,0x7a3d20cc}},	//   mm_, omiy, _erem, léte,
   {{0x60c908ca,0x806600d6,0x661600c2,0x7a360094}},	//   _frem, _вваж, nnyk, dáto,
   {{0x2bd2000d,0x44449759,0x2617003d,0x1fb61b60}},	//   ताला, om_, dħol_, _всер,
   {{0x4444975a,0x2258975b,0xed59730a,0x00000000}},	//   nm_, _kurk_, rdža_, --,
   {{0x44441d13,0x78ad02e6,0x7a36975c,0x225801c0}},	//   im_, _spav, gáto, _jurk_,
   {{0x261703e5,0xdca62d70,0xa3d2007a,0x2480975d}},	//   għol_, _вади, वाँ_, ksim_,
   {{0xb4c2009f,0x98b80f5f,0xfd120103,0xb4c01c05}},	//   ्मो_, алят_, _بجا_, ंटो_,
   {{0x4444975e,0xb4c20d7a,0xdb18975f,0x8c43002d}},	//   jm_, ्मै_, _haví, _дече,
   {{0xc9870ed4,0x0cb6320a,0x7c289760,0x89d909b4}},	//   _купи, _अनुम, modr, _موثر_,
   {{0x44449761,0x81ab0f71,0x80ad00c7,0xdb180018}},	//   em_, _কোন_, চিত্, _javí,
   {{0xa3d20006,0x78ad00e7,0x44443f45,0xb3d20179}},	// [a510] वां_, _upav, fm_, सांख,
   {{0x6380030b,0x656d2952,0xf3674d40,0x4444010a}},	//   vání, sbah, ртан, gm_,
   {{0x60c92c57,0x752f0034,0x00000000,0x00000000}},	//   _srem, _wycz, --, --,
   {{0x44448a7b,0xb5a764ba,0xdb18030b,0x5187711a}},	//   am_, _трой, _naví, ружа,
   {{0x69d8009d,0x7c2800dd,0x7a362299,0x660d9762}},	//   याती, kodr, záto, miak,
   {{0xa3d20d7a,0xafe200c2,0x289a006e,0x638002c6}},	//   वाः_, зошл, ריװא, rání,
   {{0x75ea025b,0x7c28836f,0xe7ff278e,0xdb182ce2}},	//   _výzv, dodr, _उतना_, _baví,
   {{0x660d9763,0x7a3615bf,0xd087007b,0xc33200ca}},	//   niak, váto, _выжи, _זול_,
   {{0x60c94686,0xd0e90018,0xdb18003e,0xdb080031}},	//   _urem, _حکام_, _daví, vedá,
   {{0x660d0a00,0x6445152f,0xdb039764,0xa1f800e8}},	//   hiak, nmhi, _manö, _cīņā_,
   {{0x7bc100aa,0x660d9765,0x62530078,0x764485aa}},	//   rdlu, kiak, _għot, ymiy,
   {{0x7a36128f,0x186a249c,0x69d8000c,0x444483a7}},	//   ráto, лами_, याधी, zm_,
   {{0x660d9766,0x6e290072,0xfd5600a1,0xdb080220}},	//   diak, moeb, _השני_, redá,
   {{0x7a3d0018,0x7c282df7,0xdb181054,0x76440188}},	//   véte, codr, _zaví, wmiy,
   {{0xe45f0212,0x660d0062,0x7644020e,0xb4c000c3}},	//   _dröm_, fiak, tmiy, ंट्_,
   {{0x44441071,0x660d91fb,0x6a6400e3,0x7a3d0103}},	//   wm_, giak, _بطول, téte,
   {{0x7644026a,0x44441206,0x777c9767,0x00000000}},	// [a520] rmiy, tm_, parx, --,
   {{0x44440d7d,0x76449768,0x24809769,0x3ea90034}},	//   um_, smiy, rsim_, łaty_,
   {{0x2480976a,0x4444089a,0x660d12c3,0x833a0478}},	//   ssim_, rm_, biak, учат_,
   {{0x4444976b,0xb17d0031,0x7a3d8dce,0x635502c6}},	//   sm_, _poťa, péte, třní,
   {{0x444400fc,0x6e2902ac,0x00000000,0x00000000}},	//   pm_, doeb, --, --,
   {{0x2258976c,0xf3e600d6,0xdb0101df,0x7a120877}},	//   _turk_, _ужго, belø, mātu,
   {{0xdb182ebe,0x00000000,0x00000000,0x00000000}},	//   _paví, --, --, --,
   {{0x7c280150,0x9f5c0206,0x21a30284,0x6e2902ac}},	//   wodr, nivú_, _нисм, goeb,
   {{0xb87b0018,0x9bc6007b,0x225f05db,0x00000000}},	//   nyít, бёнк, _čuki_, --,
   {{0x660d2962,0x2cbd0270,0x62530090,0x00000000}},	//   ziak, _dswd_, _għos, --,
   {{0x91bc023a,0x3f9e033c,0x00000000,0x00000000}},	//   _ईसाई, _ictu_, --, --,
   {{0x7f3b0130,0x200e00a7,0x1e5700ca,0x22460063}},	//   _געבו, lifi_, _השאר_, nmok_,
   {{0xe9df0103,0x81ab0033,0x660d976d,0x2743001c}},	//   rjú_, _কোড_, viak, kéné_,
   {{0x7bcd006d,0xe8d906c0,0x27430113,0x00000000}},	//   _ɗauk, _ndụ_, jéné_, --,
   {{0xa3cc267b,0x6b7b0341,0x4b7b00f5,0xa3d204f8}},	//   _शोध_, _גרונ, _גאוו, वाई_,
   {{0xe8d90134,0xa3ab030b,0x59d00096,0x200e2ef7}},	//   _adụ_, क्न_, _तोपर, hifi_,
   {{0x660d057c,0x045b001c,0xb87b01f9,0x2eee02ac}},	// [a530] riak, اجرت_, gyít, hyff_,
   {{0x660d976e,0xdddd007f,0x386911bc,0x4433014b}},	//   siak, _łyżk, _itar_, ulx_,
   {{0x660d3127,0x26c70131,0x31690328,0x3d0f00b7}},	//   piak, _éno_, ñazo_, _तेने_,
   {{0x3f9e0257,0xdb0101df,0x22461ef8,0x38690090}},	//   _actu_, relø, gmok_, _ktar_,
   {{0x200e23f0,0x661d029a,0xf8c933c5,0x00000000}},	//   fifi_, _ijsk, िटिय, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e29976f,0xf1b900c4,0x518701ce,0xdb18015e}},	//   toeb, _ajše_, _гуза, _navà,
   {{0xdb0a02e2,0x25a99770,0x63b7025b,0xee3907ed}},	//   _dafü, nfal_, lexn, јни_,
   {{0x38690096,0xa3bd0e1f,0x1fa73283,0x00000000}},	//   _ntar_, _आसा_, _грег, --,
   {{0x320f0094,0x625300bd,0xdaa903a0,0x4aa90b9e}},	//   ligy_, _għor, авод_, акон_,
   {{0xbf1500e3,0xa3ab034d,0x3ebe0063,0x62970094}},	//   _بواب, क्य_, _gstt_, nuxo,
   {{0x7a3600b6,0x98a6129c,0xa6cf0033,0x394a26d0}},	//   mátk, оиме, রহাট, изно_,
   {{0x7a36025b,0x89360602,0x91bf0023,0xfce50012}},	//   látk, تعدا, _chủ_, _фоло,
   {{0xcb6900d6,0x7a1201d3,0xf77214ea,0x9f450231}},	//   _таке_, vātu, باح_, _rolê_,
   {{0x26cc132d,0x7bc3002d,0x65c6008f,0x7a360094}},	//   ído_, _ianu, обва, nátk,
   {{0x200e50cb,0x00000000,0x00000000,0x00000000}},	//   zifi_, --, --, --,
   {{0x69d69771,0x7bc39772,0x7a360146,0x64a33c85}},	// [a540] _inye, _kanu, hátk, мата,
   {{0x69c40a00,0x38a49773,0xdb182e19,0x69c69774}},	//   _haie, mör_, _havá, ldke,
   {{0x7bc30158,0x05765e51,0xf746249b,0x69c49775}},	//   _manu, _واحد, _фено, _kaie,
   {{0x7bc39776,0x69c401e9,0x69c69777,0x7a360094}},	//   _lanu, _jaie, ndke, dátk,
   {{0x69c49778,0x7a3d00fd,0x3ebe9779,0x38a4293d}},	//   _maie, néta, _sstt_, nör_,
   {{0x7bc3977a,0x629703be,0x69c4977b,0xbe8a2a6e}},	//   _nanu, buxo, _laie, асие_,
   {{0x81e60f71,0x69d63aca,0x38a43114,0x59ca099d}},	//   যোগ_, _onye, hör_, ियार,
   {{0x85f70130,0x69d60134,0xdb1802c6,0x38a4977c}},	//   ַציע_, _nnye, _navá, kör_,
   {{0x6283025b,0x1da61a94,0x7bc3977d,0xa06700d3}},	//   ánov, क्षत, _banu, _мата_,
   {{0x7a360080,0x69d60c56,0x60c003e3,0x290256ff}},	//   láth, _anye, _ismm, dzka_,
   {{0x69c40a10,0x3869977e,0xada600c6,0x80c20096}},	//   _baie, _star_, _мажл, लिके,
   {{0x38a4977f,0x61e29780,0x7a360037,0x69c48968}},	//   för_, njol, náth, _caie,
   {{0xa3ab0789,0x7a3d0257,0x38a40149,0x99a50103}},	//   क्ड_, géta, gör_, ítők_,
   {{0x69d606c0,0x7bc39781,0x9f450139,0xf8ae0113}},	//   _enye, _ganu, _bolè_, اکي_,
   {{0x98ac00d9,0x61e201df,0xadee14e5,0x45d5129e}},	//   ādā_, kjol, _जवान_, повс,
   {{0xa5bb0139,0x69c401e9,0x2c6006a3,0xf54f0174}},	//   _akór, _gaie, _kòd_, _rụba_,
   {{0x290200a5,0x80ba0ff9,0x8ccd00a5,0x7bc355c8}},	// [a550] czka_, _शैले, तियो, _yanu,
   {{0x69a71362,0x7bc3008a,0xdb180146,0x69c401e9}},	//   ट्री, _xanu, _zavá, _zaie,
   {{0x2c600c56,0x77ba00ca,0x67ba00ca,0x00000000}},	//   _lòd_, _המתח, _המתק, --,
   {{0x5bb7034d,0x2bb71e9f,0x799d1c81,0x245f0150}},	//   _अस्व, _अस्थ, ngsw, _tîm_,
   {{0x3f692cf1,0xead00139,0x3cf4007f,0x00000000}},	//   било_, _jẹbi_, इनों_, --,
   {{0x657d1627,0x645d0124,0x9f4500d4,0x00000000}},	//   _hesh, _iusi, _holé_, --,
   {{0x657d8474,0xfd4c0028,0x53342b94,0x645d0010}},	//   _kesh, _triể, _жерт, _husi,
   {{0x645d1fde,0x657d9782,0x7bc30a40,0xf0760068}},	//   _kusi, _jesh, _sanu, _کیوں_,
   {{0x7bc39783,0x64555092,0x657d9784,0x61fb9785}},	//   _panu, _kizi, _mesh, _ilul,
   {{0x7a36132d,0x7bc301d4,0x1c42163d,0x657d9786}},	//   máti, _qanu, нным, _lesh,
   {{0x69c49787,0x64559788,0x7bc33e0f,0x645d9789}},	//   _paie, _mizi, _vanu, _lusi,
   {{0x38a4978a,0x61e9773c,0x3d0f0096,0xfe70001c}},	//   tör_, _joel, _तेथे_, _شدم_,
   {{0x645d01b3,0x7bc3978b,0x7a36222b,0x6d59978c}},	//   _nusi, _tanu, náti, _igwa,
   {{0x64554970,0x7a3d978d,0x61fb015e,0x657d0154}},	//   _nizi, réta, _llul, _aesh,
   {{0x61fb978e,0x657d978f,0x645d87c6,0x29022627}},	//   _olul, _besh, _ausi, szka_,
   {{0xd90d0979,0x645d9790,0xe8860950,0xa5bb1799}},	//   ایی_, _busi, _егип, _skór,
   {{0x64559791,0x657d9792,0xdb0a0102,0xd5af00e3}},	// [a560] _bizi, _desh, _hafð, طفل_,
   {{0xf74633ed,0x6b812b83,0x7a36016d,0x645500b6}},	//   _непо, nalg, dáti, _cizi,
   {{0x1dbd3ec9,0x64559793,0x62853d9e,0x61e99794}},	//   ्यात, _dizi, gsho, _boel,
   {{0x6d5906c0,0xa3cc0251,0x61e99795,0x4431022b}},	//   _ngwa, _शोर_, _coel, _ekz_,
   {{0x61e90934,0x6b819796,0x645d9797,0x61e29798}},	//   _doel, kalg, _gusi, rjol,
   {{0x62859799,0x6d59979a,0x4adb05fa,0x657d023b}},	//   bsho, _agwa, यमाव, _zesh,
   {{0x04433d7c,0xe2970f5f,0x657d979b,0x61e91849}},	//   _черн, _нар_, _yesh, _foel,
   {{0x64550584,0x61e9030a,0x645d00a7,0x7a361206}},	//   _zizi, _goel, _yusi, báti,
   {{0x64550201,0x645d0188,0xb0f60129,0xa3c20861}},	//   _yizi, _xusi, ụọgụ_, ्यप_,
   {{0xe7d70081,0xcfaa00cd,0x7e6d0307,0xa3d20569}},	//   _হত্য, _دارم_, ćapr, वाट_,
   {{0x39401a3a,0xdfa51487,0x61e9024a,0x5b1300ae}},	//   _azis_, _تحقي, _yoel, емэт,
   {{0x61e90072,0x6d590517,0x00000000,0x00000000}},	//   _xoel, _ggwa, --, --,
   {{0x657d979c,0x6b815642,0xc8672766,0x00000000}},	//   _resh, balg, ятни, --,
   {{0x645d979d,0x657d979e,0x765e06b0,0x3a200383}},	//   _rusi, _sesh, _bupy, _ejip_,
   {{0x645d6c87,0xa3e01981,0x657d979f,0xa3c20e5e}},	//   _susi, थान_, _pesh, ्यन_,
   {{0x645533bb,0x645d97a0,0xa4d500d6,0x657d023b}},	//   _sizi, _pusi, мобі, _qesh,
   {{0x657d00dd,0x61e90db1,0x628597a1,0x9f45020d}},	// [a570] _vesh, _roel, wsho, _volé_,
   {{0x62851833,0x6455013c,0x78fc00a1,0x26c1006c}},	//   tsho, _qizi, _לפחו, _tsho_,
   {{0x645597a2,0x2bae009d,0xfbae0469,0x645d8acf}},	//   _vizi, ज्या, ज्यम, _wusi,
   {{0x2fc51484,0x628597a3,0x645d97a4,0x64554829}},	//   _salg_, rsho, _tusi, _wizi,
   {{0x645d02fd,0x61e916b4,0x64550451,0xf3f300e3}},	//   _uusi, _voel, _tizi, _كأس_,
   {{0x7a360146,0x61e924a9,0x80c200c3,0x9f45003e}},	//   ráti, _woel, लिजे, _ellý_,
   {{0x61e90305,0x6b8197a5,0x2fc50856,0x3e7a00d9}},	//   _toel, valg, _valg_, gūt_,
   {{0x61fb89af,0x798d0201,0x7bd80cfd,0xf1a400ae}},	//   _ulul, _ndaw, _anvu, _прун,
   {{0x6b8197a6,0xed599536,0xdb082e92,0xa3d200a4}},	//   talg, ndži_, cedú, वाच_,
   {{0x9f630084,0x798d1114,0x3e7a00d9,0xa3c218ff}},	//   ävät_, _adaw, būt_, ्यय_,
   {{0x7a3d025b,0x6b813155,0xad270504,0xfc4600b6}},	//   rétn, ralg, _کراو, _říct_,
   {{0x7bd897a7,0x6b81145b,0x7bc86a8d,0x6d5997a8}},	//   _envu, salg, addu, _ugwa,
   {{0xb4bc00a5,0xa3c222a3,0x1dda06eb,0x6b8100bc}},	//   _आने_, ्यम_, भारत, palg,
   {{0xfd100602,0x2d9f016d,0x1c44004d,0x765e00c6}},	//   _حجم_, lgue_, _знім, _pupy,
   {{0xa3d1045f,0x798d02a1,0x46a300e5,0x9f5c00d4}},	//   वयन_, _fdaw, карв, jivý_,
   {{0xa3ab097c,0x2d9f15bc,0x9f5c00d4,0x75f805f1}},	//   क्स_, ngue_, divý_, _vízo,
   {{0xd04001d4,0x69c0020d,0xdb01037a,0x7a0b007f}},	// [a580] _ermə, ômeu, peló, jęty,
   {{0xaca30294,0xe3b70cf5,0x00000000,0x00000000}},	//   _nnọk, мбу_, --, --,
   {{0x91e661f5,0x23e00096,0x38600487,0x03a30eaf}},	//   може, नाबद, _huir_, тихо,
   {{0xaca30294,0xe80a32c9,0x00000000,0x00000000}},	//   _anọk, होरा_, --, --,
   {{0x7bc83c5e,0x50ba2827,0xdb180206,0x00000000}},	//   yddu, تداد_, _zavä, --,
   {{0x3860151d,0x7a3697a9,0x2d9f0143,0x00000000}},	//   _muir_, mátu, egue_, --,
   {{0x7a360301,0x4ea60161,0x00000000,0x00000000}},	//   látu, фрла, --, --,
   {{0x25a0630c,0xef1801d3,0x9f4500ee,0xd6c00033}},	//   ngil_, _ceļa_, _alló_, _উপায,
   {{0x80a61e49,0x0637006e,0xa3ab142e,0x7a1200e8}},	//   _زمان, ונקט_, क्व_, vātp,
   {{0x2d9f0158,0x00000000,0x00000000,0x00000000}},	//   ague_, --, --, --,
   {{0x59d0007a,0x7bc88184,0x78b600c6,0xdb1a0216}},	//   _तोहर, rddu, _apyv, metë,
   {{0xdde300ae,0xdb1a0216,0x00000000,0x00000000}},	//   ărţi, letë, --, --,
   {{0x3860107f,0x6e220d79,0xd90f03ed,0x386d1570}},	//   _cuir_, _ijob, شید_, ëer_,
   {{0x2d8497aa,0x59dd030b,0x0cbc097c,0xdd3b00ca}},	//   lame_, याहर, ्टीम, _ועדכ,
   {{0x156c0174,0xdcc800fe,0x00000000,0x00000000}},	//   _ọmịm, _hỉ_, --, --,
   {{0x7c3a97ab,0x4d7b00c1,0xdcc800de,0x69c0016d}},	//   lltr, ַרבע, _kỉ_, ômet,
   {{0x386001b9,0xd3a7002d,0xb955004d,0xdb1a0216}},	// [a590] _guir_, дреп, _явищ, ketë,
   {{0x2d8497ac,0x59dd009d,0xeddb397e,0xdb1a023b}},	//   hame_, यावर, _मच्छ, jetë,
   {{0xa3ab06ae,0x6fdd02e8,0x2d8497ad,0x92590084}},	//   क्ष_, पासू, kame_, чает_,
   {{0x2d84013f,0x6e2297ae,0xe45f0212,0x7a364cf5}},	//   jame_, _njob, _bröt_, bátu,
   {{0xdcc80023,0x764d2d9d,0xb0680037,0x2d8497af}},	//   _nỉ_, mmay, وصول_, dame_,
   {{0x764d17bd,0x248997b0,0x6e220172,0x7a360301}},	//   lmay, msam_, _ajob, látt,
   {{0x9f4505fe,0x82a4007e,0xf1a74d70,0x2d847252}},	//   _allò_, _иште, _оран, fame_,
   {{0x2d8497b1,0xa3ab0e72,0x764d03a3,0xada54abb}},	//   game_, क्र_, nmay, хаил,
   {{0x2d9f97b2,0x248997b3,0xed590268,0x6e2297b4}},	//   rgue_, nsam_, ježe_, _djob,
   {{0x3ec402fd,0x6e2288f8,0x5ba9136c,0xed590117}},	//   ästä_, _ejob, чком_, deže_,
   {{0x3d0f0034,0x764d026a,0xdbda0139,0xe7e33f50}},	//   _तेरे_, kmay, _dààb, खाना_,
   {{0xc7a909c1,0x6e22023b,0x248997b5,0x2d8497b6}},	//   _לב_, _gjob, ksam_, came_,
   {{0x7e610305,0x9f450428,0x2489023e,0x39350152}},	//   _hulp, _molí_, jsam_, вэрс,
   {{0xb8e8030b,0x6e3b1552,0x7e6197b7,0x291e00ae}},	//   _ईन_, llub, _kulp, ăta_,
   {{0x1da6009f,0xf6261009,0x45d622f6,0xb87b03be}},	//   क्कत, едво, нцат, rxía,
   {{0xa2c300c0,0x44230167,0xdb1a023b,0x7a36016d}},	//   रबन्, _ajj_, zetë, tátu,
   {{0x798697b8,0x248908bc,0xf50a261f,0xdcc80023}},	// [a5a0] makw, gsam_, чнал_, _xỉ_,
   {{0x2d8497b9,0x6e3b7de1,0xa3ab14e5,0x764d0188}},	//   zame_, hlub, क्ल_, amay,
   {{0x6e3b97ba,0xeac90649,0x2bf60130,0x248906a8}},	//   klub, _jẹ_, עמען_, asam_,
   {{0xeac90028,0x798697bb,0x7a3632c7,0xa5bb003e}},	//   _mẹ_, nakw, pátu, _hjón,
   {{0x2d8497bc,0xdb1a00dd,0x24890150,0x7bcd0d2a}},	//   vame_, tetë, csam_, _ɗaur,
   {{0xe7e30034,0xdcc80023,0x66040270,0x6e940396}},	//   खाया_, _rỉ_, lhik, вику,
   {{0x75f8025b,0x2d8497bd,0xdb1a023b,0xdcc800de}},	//   _nízk, tame_, retë, _sỉ_,
   {{0x63be6b5e,0x433b0130,0x629e23b6,0xb1480018}},	//   lepn, _זעלב, mupo, _قیام_,
   {{0x2d8497be,0x798697bf,0x1aed0081,0xf54f0174}},	//   rame_, dakw, _ছেলে_, _nụla_,
   {{0xdee61a18,0xdb1a49b4,0xeac90af0,0x7c3a51a0}},	//   _пози, leté, _bẹ_, ultr,
   {{0x629e0f83,0x59dd030b,0x7a360103,0x79864944}},	//   nupo, यालर, játs, fakw,
   {{0xdb1a0018,0xf54f0857,0xaca40294,0xdcc80019}},	//   neté, _bụla_, _abụz, _tỉ_,
   {{0xa3c297c0,0x66040a8f,0xed590995,0x629e02b1}},	//   ्या_, dhik, teže_, hupo,
   {{0x2bd705d4,0x629e8e68,0xdb1a00fd,0xeac90d79}},	//   _भोपा, kupo, heté, _fẹ_,
   {{0x798665a6,0x764d03a3,0xed590141,0xf64711a0}},	//   bakw, tmay, reže_, ехан,
   {{0x7bca97c1,0xed590117,0x660497c2,0xdb1a020d}},	//   _hafu, seže_, ghik, jeté,
   {{0xdbf90067,0x764d97c3,0x7bca97c4,0x7a360088}},	// [a5b0] _głów, rmay, _kafu, rátt,
   {{0x7bca79f8,0xdd860103,0x764d97c5,0x248997c6}},	//   _jafu, _ھو_, smay, rsam_,
   {{0x7bca068d,0x248997c7,0x764d0367,0x9f450094}},	//   _mafu, ssam_, pmay, _polí_,
   {{0x660497c8,0x7bca97c9,0xf770001c,0xdb1a0103}},	//   chik, _lafu, _پای_, geté,
   {{0x8fa50f2e,0xa3cc33dc,0x9f4500d4,0x91bf00fe}},	//   вале, _शोक_, _volí_, _chú_,
   {{0x7bca0175,0xe8d900fe,0xae0e00c3,0x2446014b}},	//   _nafu, _ngọ_, ़ोसन_, tôme_,
   {{0xd00e2259,0x7986533a,0x00000000,0x00000000}},	//   تلو_, yakw, --, --,
   {{0x53340508,0xeac90649,0xed592787,0xe8d90032}},	//   _сест, _rẹ_, мой_, _agọ_,
   {{0x6e3b97ca,0x7bca19f2,0x9f5c0451,0x9f4c0154}},	//   rlub, _bafu, rivò_, _lodè_,
   {{0x798697cb,0x6e3b97cc,0x7bca0231,0x7a3d05ef}},	//   wakw, slub, _cafu, léth,
   {{0x91f510e9,0x798697cd,0xcd2b51d7,0x7bca97ce}},	//   _आवाज_, takw, _کسان_, _dafu,
   {{0xa5bb0088,0x3f8797cf,0xe8d90174,0x7bca010a}},	//   _sjón, lanu_, _egọ_, _eafu,
   {{0x79867d0a,0x7bca38d7,0x63b5053f,0xdb010103}},	//   rakw, _fafu, _obzn, jelö,
   {{0xdb1a0068,0x3dcd97d0,0x7bca97d1,0x9f4c0139}},	//   zeté, ldew_, _gafu, _bodè_,
   {{0x443322e5,0x66044bdb,0x7d09020a,0x2ba61ab1}},	//   dox_, thik, lzes, _खाता,
   {{0x6b838614,0xdb0101bf,0x3f8797d2,0x66040167}},	//   _heng, rflä, hanu_, uhik,
   {{0x2cad4c9d,0x443397d3,0x7bca5092,0x6b8397d4}},	// [a5c0] nted_, fox_, _yafu, _keng,
   {{0x6604628b,0x389b0130,0x6b834d61,0x629e97d5}},	//   shik, _קיינ, _jeng, tupo,
   {{0x6b8317fb,0x3f8797d6,0x8c3d0092,0x66040201}},	//   _meng, danu_, muşd, phik,
   {{0x629e97d7,0x63be0085,0x44210023,0x9f470052}},	//   rupo, sepn, anh_, ajnë_,
   {{0x629e97d8,0x2cad2b0a,0xa06764a7,0xa5bb003e}},	//   supo, jted_, вача_, _mjól,
   {{0x9346433f,0x3f8797d9,0x6b832428,0x7984028d}},	//   _анге, ganu_, _neng, _leiw,
   {{0xa2e397da,0x5299008f,0x7bca97db,0xb5fb0143}},	//   _корд, _пътя_, _rafu, _diáf,
   {{0x645c02a7,0x9f450154,0x7bca97dc,0x2cad00d7}},	//   _hiri, _dolà_, _safu, fted_,
   {{0x6b8397dd,0x443897de,0x7bca0052,0xf0630396}},	//   _beng, _kkr_, _pafu, _вкуп,
   {{0x69a502e8,0x645c97df,0x6ebd0789,0x44385bae}},	//   _काही, _jiri, _वैकु, _jkr_,
   {{0x6b8343b4,0xcfa933c6,0x2cad97e0,0x2fde0042}},	//   _deng, _سالم_, ated_, _intg_,
   {{0xc3331723,0x645c97e1,0x7bca1fde,0x6b83783b}},	//   יות_, _liri, _wafu, _eeng,
   {{0x6b832e6f,0x2cad0054,0x7bca52e2,0x7d0900a5}},	//   _feng, cted_, _tafu, czes,
   {{0x6b8397e2,0x44330090,0x645c97e3,0xf77025a1}},	//   _geng, xox_, _niri, قاف_,
   {{0x7a3d00fd,0x659597e4,0xb5a71e9b,0xb59530c0}},	//   héti, лаву, край, ливш,
   {{0x645c97e5,0x3f870039,0x6b8397e6,0x6b8819e5}},	//   _airi, zanu_, _zeng, ladg,
   {{0x645c97e7,0x73d9415c,0x6b830adf,0x443897e8}},	// [a5d0] _biri, ндар_, _yeng, _bkr_,
   {{0x337422d1,0x46ac009f,0x6b8897e9,0x93940308}},	//   игур, _चहचह, nadg, لجما,
   {{0x3f87730a,0x7d0900e5,0x893409e5,0xf364002d}},	//   vanu_, zzes, _معیا, ртун,
   {{0x645c97ea,0xa2940c10,0x3f8797eb,0x320607ac}},	//   _eiri, раці, wanu_, ghoy_,
   {{0x3f873ccf,0x30a723e9,0xe134013f,0x656d008c}},	//   tanu_, трев, анцы, mcah,
   {{0x645c97ec,0x13a7110a,0x2fde0072,0x765d02fa}},	//   _giri, _جنسی_, _cntg_, _hisy,
   {{0x6b8397ed,0x6b88037a,0xed59228d,0x765d010a}},	//   _reng, dadg, deža_, _kisy,
   {{0x6b833946,0x656d2d96,0x645c7d5e,0x2cad97ee}},	//   _seng, ncah, _ziri, tted_,
   {{0x6b830496,0x765d232e,0x645c97ef,0x3f8797f0}},	//   _peng, _misy, _yiri, panu_,
   {{0x60c997f1,0x645c0694,0x2cad97f2,0x765d2621}},	//   _isem, _xiri, rted_, _lisy,
   {{0x2cad8096,0x6b8397f3,0x7d093c90,0x3872017a}},	//   sted_, _veng, szes, _styr_,
   {{0x6b8397f4,0x3f8597f5,0x2cad00ca,0xdb0197f6}},	//   _weng, _helu_, pted_, nglé,
   {{0x6b88008a,0xdb011c9d,0x60c95dd4,0x3c1502c6}},	//   badg, nflú, _jsem, těvě_,
   {{0x9d1a0130,0x60c997f7,0x765d0991,0xab290848}},	//   _אונט, _msem, _aisy, _пола_,
   {{0x7bc10bca,0x3f8597f8,0x645c97f9,0x765d3107}},	//   melu, _melu_, _riri, _bisy,
   {{0x645c82b6,0x60c997fa,0x765d0113,0xa3cc09c3}},	//   _siri, _osem, _cisy, _शोज_,
   {{0x765d97fb,0x645c727a,0x44380332,0x7a3d002b}},	// [a5e0] _disy, _piri, _pkr_, xéti,
   {{0xdb0897fc,0x2007033b,0x3f85020a,0x645c97fd}},	//   yedü, jhni_, _nelu_, _qiri,
   {{0x645c97fe,0x60c997ff,0x20070052,0x765d7fa5}},	//   _viri, _asem, dhni_, _fisy,
   {{0x645c9800,0x7a3d0d9f,0xd259004d,0x7bc16c9a}},	//   _wiri, téti, вці_, helu,
   {{0x645c61ca,0x7bc13cb8,0x3f859801,0x44389802}},	//   _tiri, kelu, _belu_, _tkr_,
   {{0x3f859803,0x7a3d020d,0x645c0441,0xccf90034}},	//   _celu_, réti, _uiri, dyś_,
   {{0x60c99804,0x7bc19805,0x3f8523c5,0x69a59806}},	//   _esem, delu, _delu_, _काली,
   {{0x7a3d00fd,0x7c3802c6,0xeda616e6,0x3df400d3}},	//   péti, _skvr, ушко, рзис,
   {{0x2fde005c,0xed590106,0x2dd70037,0x32040063}},	//   _tntg_, teža_, طبية_, _ilmy_,
   {{0x7bc10b7c,0x200708fa,0xd7040521,0x670424eb}},	//   gelu, chni_, रनाथ_, रनाक_,
   {{0xd43700c1,0xa5bb003e,0xa3ac00c0,0xed5900e7}},	//   רטיי_, _sjóm, _गान_, reža_,
   {{0x5fe23ec9,0xccf9007f,0x80bb00aa,0x00000000}},	//   पावल, byś_, _एहमे, --,
   {{0x7bc19807,0x765d0063,0x69cf0212,0x60c90063}},	//   belu, _risy, rdce, _xsem,
   {{0xdb1a4280,0xb8ed30a8,0xed570fe3,0x69cd0350}},	//   letí, _रन_, _соч_, _waae,
   {{0xf3f900d3,0xdb080328,0x7a280233,0x00000000}},	//   _îţi_, redó, sıta, --,
   {{0xe66410f7,0xe4e7084c,0xd4e70686,0x99800555}},	//   стро, лізн, люзи, _imiş_,
   {{0x26162337,0x656d113a,0xa3c20296,0x7afa9808}},	// [a5f0] _नगरी_, rcah, ्यं_, lytt,
   {{0x59dd009d,0x32040113,0x765d00f9,0x00000000}},	//   याकर, _almy_, _wisy, --,
   {{0x753d0067,0x7afa0c2e,0x63a50037,0x765d8a45}},	//   _wysz, nytt, rghn, _tisy,
   {{0x3f851419,0x2614009d,0x7bc19809,0x9564008f}},	//   _selu_, नोदी_, zelu, _гърд,
   {{0x3f850d79,0x7afa4e21,0x00000000,0x00000000}},	//   _pelu_, hytt, --, --,
   {{0xb4c1110f,0xa3ac018b,0xa3c21dae,0x60c90087}},	//   ंबी_, _गाय_, ्यः_, _vsem,
   {{0x7bc1002d,0x2c690220,0x3f850090,0x00000000}},	//   velu, _súd_, _velu_, --,
   {{0x200778d2,0x7bc116e8,0x2d861d9f,0xb5fb0103}},	//   shni_, welu, _ceoe_, _hiáb,
   {{0x7bc1980a,0xb882000d,0x3f85980b,0x60c98f6d}},	//   telu, říze, _telu_, _usem,
   {{0x1da710e9,0x5e8701b3,0x00000000,0x00000000}},	//   _गावत, _будз, --, --,
   {{0x2005003d,0xa7200081,0x7bc100d3,0x39490967}},	//   _illi_, _ধর্ম_, relu, _azas_,
   {{0x186a3e04,0x7bc14a02,0x224d0113,0x09e40033}},	//   ками_, selu, _jhek_, মস্থ,
   {{0x39490067,0x2b15007a,0xdb0a042c,0x00000000}},	//   _czas_, _फेरु_, _abfä, --,
   {{0x68e203e5,0x7afa0073,0x225f096f,0x67230234}},	//   _ġodd, bytt, _liuk_, _žnja,
   {{0xe73a0cba,0x9f450428,0x00000000,0x00000000}},	//   тев_, _dolç_, --, --,
   {{0xb4c10714,0x00000000,0x00000000,0x00000000}},	//   ंबू_, --, --, --,
   {{0xd4672de0,0xa3d110cf,0x64a60c2d,0xb38600d3}},	// [a600] иите_, वयं_, раза, илал,
   {{0x25ab0090,0xd9e40ff9,0x78fb2252,0x00000000}},	//   _eccl_, गावत_, _סליפ, --,
   {{0x213f061d,0x179b0327,0x66e65a5c,0x00000000}},	//   _ayuh_, _בייב, _тона, --,
   {{0x64a66236,0x2005980c,0x213f03a9,0xdb180094}},	//   _кама, _alli_, _byuh_, _navý,
   {{0xb5fb0072,0x5fe2030b,0x224d00d1,0x6606007b}},	//   _fiáb, पालल, _dhek_, _ilkk,
   {{0x7afa00c2,0x224d01c8,0x26da0141,0xd0370120}},	//   yytt, _ehek_, _krpo_, азії_,
   {{0x9e062aae,0x42d504a1,0x644e0090,0x00000000}},	//   ичил, _літу, _ihbi, --,
   {{0xdef70fe9,0xa2c30557,0x7afa007b,0x442a02ac}},	//   рыш_, रबर्, vytt, _hjb_,
   {{0xafe6980d,0xa06a00c2,0x4fa60120,0x00000000}},	//   _коал, _раза_, _визв, --,
   {{0x34b70054,0x7afa00c2,0x9f4c0146,0x26da356b}},	//   ספים_, tytt, _hodí_, _orpo_,
   {{0xa3ab0fdd,0x8aa30938,0x03d70089,0x201c033b}},	//   क्ट_, оряд, בוים_, mivi_,
   {{0xf2d30130,0x201c980e,0x13cf0033,0x3949037a}},	//   קער_, livi_, রায়, _pzas_,
   {{0x1bd40465,0xc31a00c7,0x7afa0084,0xe9471612}},	//   _голя, _তুমি_, sytt, рхно,
   {{0x9f4c0146,0x25ab015e,0x00000000,0x00000000}},	//   _lodí_, _sccl_, --, --,
   {{0xf8ae010d,0xc66807ed,0xa3e00751,0xdb1a042c}},	//   وکی_, иште_, थाई_, ndtü,
   {{0x442a980f,0x7a280367,0x8c3d680c,0xe9df002b}},	//   _ajb_, nıtl, muşa, flúe_,
   {{0xf36701c9,0x39490335,0x201c55ae,0x442a9810}},	// [a610] атен, _uzas_, kivi_, _bjb_,
   {{0x442a0a39,0x224d023b,0x644e009c,0x7e680313}},	//   _cjb_, _shek_, _chbi, _oudp,
   {{0x93190037,0xb5fb0072,0x8c3d026a,0x96f94c88}},	//   دقاء_, _viáb, nuşa, _сент_,
   {{0x3869061d,0x644e0062,0xdb0100f2,0xb5fb0a61}},	//   _kuar_, _ehbi, rflø, _diác,
   {{0xe9df08a8,0x442a171d,0x80e10789,0x83870ae3}},	//   clúe_, _fjb_, पमें, _выбе,
   {{0x25a99811,0x38699812,0x7e680113,0xdb1a0e2e}},	//   lgal_, _muar_, _budp, ndtó,
   {{0x386910f3,0x22942872,0x92942529,0xa294004d}},	//   _luar_, _миря, _марц, _марі,
   {{0x25a99813,0xf1cf0251,0x7d1d003e,0xf2d2006e}},	//   ngal_, _सोचन, ússo, _צען_,
   {{0x201c0995,0x2024003e,0x38690063,0x213f01dc}},	//   bivi_, ðrið_, _nuar_, _uyuh_,
   {{0x20056b3c,0x201c0036,0x2a6700dc,0x60db41e5}},	//   _ulli_, civi_, _punb_, _irum,
   {{0x394601d3,0x00000000,0x00000000,0x00000000}},	//   _šos_, --, --, --,
   {{0xa3de02e8,0xf76900ca,0xfbd709a1,0x00000000}},	//   _दोन_, _טק_, _भोरम, --,
   {{0xed4e3c12,0xa3e8034c,0x2a6000aa,0xeaae0018}},	//   _хо_, _मचल_, _viib_, وٹی_,
   {{0x6d4b9814,0x18672b16,0x38690052,0x59aa0e1f}},	//   _izga, сари_, _duar_, _कावर,
   {{0xa3ab0640,0x7a3d0301,0x00000000,0x00000000}},	//   क्छ_, tétt, --, --,
   {{0x25a9110a,0x60db9815,0x38699816,0x0566008f}},	//   ggal_, _orum, _fuar_, сван,
   {{0xe3ba524d,0x7a3d0088,0x38690131,0xdb18037a}},	// [a620] лба_, rétt, _guar_, _favó,
   {{0x69c6635e,0x25a900e3,0x657f023e,0x201c00a7}},	//   leke, agal_, abqh, xivi_,
   {{0xa3b93b30,0x60db1eb3,0x7a2801e8,0x59dd00bc}},	//   _अउर_, _arum, yıtl, याचर,
   {{0xdb1a7fbc,0x7a3d9817,0x998200c6,0x75f801f9}},	//   netá, létr, mokų_, _vízs,
   {{0x201c9818,0x10a34d0e,0xa5bb0139,0x76449819}},	//   tivi_, зичн, _ajów, mliy,
   {{0x60db981a,0x7644981b,0x7a3d39f4,0x69c660d9}},	//   _drum, lliy, nétr, heke,
   {{0x69c6981c,0x201c785e,0x443a981d,0x6d4b5bca}},	//   keke, rivi_, mop_, _azga,
   {{0x4444981e,0x60db981f,0x5c744a4e,0xa3c2007d}},	//   ll_, _frum, олит, ्यक_,
   {{0x69c60068,0x60db235b,0x44449820,0x78a602c3}},	//   deke, _grum, ol_, jukv,
   {{0xda7a2976,0x44449821,0x443a9822,0x7a280233}},	//   лям_, nl_, nop_, sıtl,
   {{0x44448e6e,0x76449823,0x63ae0113,0x6d4b0634}},	//   il_, kliy, _mcbn, _ezga,
   {{0x69c69824,0x44440fe8,0x3f8e0010,0x38618c2f}},	//   geke, hl_, lafu_, _sihr_,
   {{0x443a9825,0x63bc0117,0x44440d94,0x764400a7}},	//   kop_, _obrn, kl_, dliy,
   {{0x44449826,0x321d007f,0x7e62033c,0x3f8e9827}},	//   jl_, ziwy_, _hiop, nafu_,
   {{0xd5bb1a9c,0x69c69828,0x7644324e,0x44449829}},	//   лса_, beke, fliy, dl_,
   {{0x4444019e,0x7c3a59b6,0x69c6982a,0x3f8e982b}},	//   el_, lotr, ceke, hafu_,
   {{0x6fa9009d,0x3f8e63c1,0x60c4008b,0x25a9982c}},	// [a630] _घालू, kafu_, çiml, rgal_,
   {{0xf367982d,0x4444982e,0x7c28982f,0x76440188}},	//   стан, gl_, nndr, aliy,
   {{0x76447079,0x23670087,0x7c289830,0x3f8e024a}},	//   bliy, žnjo_, indr, dafu_,
   {{0xddc1002d,0x7a2800a7,0x60db9831,0xdb0802c3}},	//   _mulţ, yıtm, _prum, bedö,
   {{0x444402ad,0x3f8e0022,0xdceb0090,0x660d024a}},	//   bl_, fafu_, _idgħ, mhak,
   {{0x69c69832,0x7c3a1711,0x4444018f,0x63bc0167}},	//   zeke, jotr, cl_, _gbrn,
   {{0x1dda0251,0x6d424031,0x69c69833,0x798f06b0}},	//   _मोहत, _ayoa, yeke, kacw,
   {{0xa3e7007d,0xd34600cd,0x64459834,0xa3d102d5}},	//   भाव_, _بیمه_, llhi, वयक_,
   {{0x7c3a9835,0x60db5f7f,0x69c67d1c,0x3f8e563a}},	//   fotr, _urum, veke, bafu_,
   {{0x69c69836,0x76440092,0x6d4b0117,0x50f400ae}},	//   weke, zliy, _vzga, _эзут,
   {{0x69c69837,0x2fc763e3,0x5fae009d,0x26c1023e}},	//   teke, meng_, _घातल, _npho_,
   {{0x2fc79838,0x3ea705fe,0xf1bb0789,0xef1800d9}},	//   leng_, munt_, ोजिन, _ceļu_,
   {{0x6e3b0039,0x443a1d11,0x290407e8,0x660d00cd}},	//   moub, yop_, áma_, dhak,
   {{0x69c69839,0x2fc70979,0x78a60335,0x290c00a5}},	//   seke, neng_, rukv, ąda_,
   {{0x4444052f,0xdb1a983a,0x69c6983b,0x76440491}},	//   vl_, petá, peke, tliy,
   {{0x2fc7983c,0x660d3642,0xe57a4ab5,0x62980206}},	//   heng_, ghak, рза_, ávom,
   {{0x764401d4,0x2fc7983d,0x444426e2,0xdceb0090}},	// [a640] rliy, keng_, tl_, _ddgħ,
   {{0x4444983e,0x2fc700bf,0x76449819,0x7656007b}},	//   ul_, jeng_, sliy, smyy,
   {{0x443a5982,0x42ca0077,0x2fc7983f,0x660d019f}},	//   rop_, рген_, deng_, bhak,
   {{0xe0da61af,0x660d9840,0x3ea700b7,0xb5fb0018}},	//   иве_, chak, dunt_, _hián,
   {{0x7e620072,0x7c2801ce,0x998900d4,0x66040350}},	//   _riop, yndr, _dlaň_, mkik,
   {{0x2bae0f62,0x7e629841,0x2fc79842,0xdc390491}},	//   ज्ञा, _siop, geng_, kçıl,
   {{0x2327013d,0xe2973097,0x3ea78611,0x3f8e0051}},	//   _дори_, _мар_, gunt_, rafu_,
   {{0xb5fb2ebe,0xdcba008f,0x6e2900f2,0x66049843}},	//   _lián, ащо_, gneb, nkik,
   {{0x3f8e03fa,0xf65300a1,0x2fc79844,0x9f4c0146}},	//   pafu_, וצה_, beng_, _dodá_,
   {{0x3ea70154,0x2246003d,0x60cd44c3,0x2fc72d96}},	//   bunt_, llok_, çame, ceng_,
   {{0xdd8f0307,0x66045e37,0x7c289845,0x8c3d0555}},	//   _ош_, kkik, rndr, muşl,
   {{0x7c3a9846,0x8c3d0367,0x22460167,0x5ce60037}},	//   sotr, luşl, nlok_, _وكال,
   {{0x7c3a9847,0xfbcf0688,0x3f8c00ac,0xed5a02a0}},	//   potr, رتی_, _kedu_, _тод_,
   {{0x6e209848,0x39450029,0xd83b0204,0x7d0c0555}},	//   limb, āls_, рэм_, ılsı,
   {{0x22464e0f,0x660d2cff,0x4b7b006e,0x7bc89849}},	//   klok_, thak, _דאוו, medu,
   {{0x6e201084,0x2246984a,0xa5bb003e,0x1dbc0f8f}},	//   nimb, jlok_, _njót, ्जित,
   {{0x660d984b,0x2fc7984c,0x224602c9,0xe9df0042}},	// [a650] rhak, yeng_, dlok_, clúa_,
   {{0x660d092f,0x6e20984d,0xd37b7712,0xd7b2009d}},	//   shak, himb, рча_, _जायच,
   {{0x6e203193,0x660d0060,0xc7b2040a,0x798d0167}},	//   kimb, phak, _אבי_, _keaw,
   {{0xdce90284,0x2fc7984e,0x6e200051,0x7bc8984f}},	//   zbeđ, weng_, jimb, hedu,
   {{0x2fc70979,0x3f8c4aad,0x6e2900f2,0xdb1a0233}},	//   teng_, _bedu_, vneb, betç,
   {{0x7bc802f7,0x224607ac,0x3ea701cb,0x3f8c0036}},	//   jedu, alok_, tunt_, _cedu_,
   {{0x2fc734ac,0x44210117,0x22469850,0x63b40579}},	//   reng_, mih_, blok_, žený,
   {{0x3ea76e85,0x2fc79851,0xed592102,0x4c851628}},	//   runt_, seng_, leži_, плив,
   {{0x2fc72aea,0x6e2956fa,0x99ca0081,0xdb010364}},	//   peng_, rneb, ষাৎক, sflü,
   {{0x3ea79852,0xdc3907aa,0x7bc89853,0xa5bb003e}},	//   punt_, tçıl, gedu, _kjós,
   {{0xf8a900f5,0x6e209854,0x661d286f,0x44219855}},	//   _תש_, bimb, _omsk, iih_,
   {{0xdeba00a1,0x44216a64,0x6e20019f,0xdb1a00c2}},	//   _למעל, hih_, cimb, detä,
   {{0xfce56353,0x44219856,0x3e719857,0xa5bb0102}},	//   _холо, kih_, _hát_, _ljós,
   {{0x44210085,0xed594e00,0x913a00c1,0x7bc89858}},	//   jih_, ježi_, מערק, cedu,
   {{0xa3c104f8,0x26de03be,0x8c3d01e8,0x66e31eca}},	//   ्जन_, íto_, nuşm, нора,
   {{0x3e710019,0x8afa00ca,0x7afc9859,0x9663985a}},	//   _mát_, _להצי, ärte, ексе,
   {{0x3e71985b,0x66044633,0x98ac01d3,0x00000000}},	// [a660] _lát_, rkik, ādē_, --,
   {{0x6604985c,0x6e2038fd,0x69d60188,0x0446385a}},	//   skik, zimb, _haye, чезн,
   {{0x3f8c011d,0xe6460848,0x38b64012,0x6e203e6b}},	//   _redu_, _неоп, lær_, yimb,
   {{0x23720029,0x3f8c985d,0x69d60113,0x7bc801e9}},	//   _šajā_, _sedu_, _jaye, zedu,
   {{0x44212129,0x69d68f87,0x38b600bb,0x6e200201}},	//   bih_, _maye, nær_, vimb,
   {{0x442115f4,0x3e71985e,0x6e201c35,0x3f8c0231}},	//   cih_, _bát_, wimb, _qedu_,
   {{0xc0590a8d,0x7bc8985f,0x3e7100de,0x22462f91}},	//   ції_, vedu, _cát_, plok_,
   {{0x3e71025b,0x69d665de,0x64670103,0x23ac1e93}},	//   _dát_, _naye, _óriá, _चाँद,
   {{0x6e209860,0x38b600f2,0x00000000,0x00000000}},	//   rimb, jær_, --, --,
   {{0x6e2001a6,0x798d5675,0x69d6595a,0x307b00ca}},	//   simb, _seaw, _aaye, _לאמנ,
   {{0x69d69861,0x200c9862,0x7c2f014b,0x9f7b00ca}},	//   _baye, _ildi_, écra, _הנבח,
   {{0x69d69863,0x38b61d46,0xa2c400b6,0xa3de0dba}},	//   _caye, fær_, _रहन्, _दोस_,
   {{0xb5fb22bf,0x5c06013d,0x7bc89864,0x23ac0bb5}},	//   _diál, _няка, pedu, _चांद,
   {{0xdb1a0084,0xba7300cd,0x9605397e,0xc6050085}},	//   tetä, بایت, रस्ट_, रस्य_,
   {{0x98be00d9,0x3bbb0796,0xed599865,0x3e7100fe}},	//   ātā_, _המוד, veži_, _xát_,
   {{0x44210979,0x38b6254e,0xa5bb0032,0x69d69866}},	//   wih_, bær_, _ajór, _gaye,
   {{0x200c00b7,0xed5914f3,0x80cc030b,0xdb1a0f06}},	// [a670] _oldi_, teži_, _दैले, setä,
   {{0xb88300b6,0x7d1d9867,0xb4bd0ff9,0x00000000}},	//   říst, ússi, _आही_, --,
   {{0x44219868,0x8c4101bf,0x99900220,0x38660036}},	//   rih_, äßig, ťaťa_, _èora_,
   {{0x44214b82,0x200c9869,0x661d986a,0x98b1049d}},	//   sih_, _aldi_, _umsk, _जमाए,
   {{0x3e710028,0xa5bb0088,0x92ad0081,0x00000000}},	//   _sát_, _fjór, কবে_, --,
   {{0x4421017d,0x3e7100b6,0xc4d200ca,0x9ac5010a}},	//   qih_, _pát_, _שגם_, loŋŋ,
   {{0x29021799,0x69ce009f,0x74db097c,0x7c2102db}},	//   zyka_, _तसली, निवृ, vilr,
   {{0xcfcd0081,0xec791f3e,0x8c3d03e0,0x3e71020b}},	//   লাইন, опи_, ruşm, _vát_,
   {{0x61e9986b,0x4c350138,0xb87b002b,0x3e7102ac}},	//   _inel, дэнт, nvíd, _wát_,
   {{0x69d6986c,0x38b601df,0x3e710023,0xa3d00285}},	//   _saye, vær_, _tát_, वजय_,
   {{0x61fb986d,0x69d62db2,0x61e96bab,0xe7ec0469}},	//   _koul, _paye, _knel, ञासा_,
   {{0xa3c1007d,0x29020067,0x61fb0084,0x38b6038c}},	//   ्जड_, tyka_, _joul, tær_,
   {{0xaca30134,0x9f580103,0x61fb0632,0x2c7203a8}},	//   _maịk, özök_, _moul, _gâd_,
   {{0xb8f642c3,0x61fb986e,0x69d6067d,0xb5fb04d8}},	//   _सन_, _loul, _waye, _diám,
   {{0xf7430636,0x61e983a4,0x320600f9,0xa3e70bf5}},	//   веро, _onel, ykoy_, भाई_,
   {{0x237801ac,0x61fb986f,0x24990063,0x00000000}},	//   _sfrj_, _noul, _bvsm_, --,
   {{0x44310381,0xdb18058f,0x00000000,0x00000000}},	// [a680] _bjz_, _davõ, --, --,
   {{0x2d8f4673,0x61e92f0e,0x4ad117ad,0x64a300c6}},	//   _lege_, _anel, _तनाव, тафа,
   {{0x61fb9870,0x320d7de9,0x316a5bc6,0xdb011410}},	//   _boul, _bley_, ошло_, sglæ,
   {{0x61fb5c79,0x2d8f9871,0x6f030034,0xe8d900fe}},	//   _coul, _nege_, dync, _ngớ_,
   {{0x61fb9872,0xe7e3009d,0x00000000,0x00000000}},	//   _doul, खाचा_, --, --,
   {{0xd12f177a,0x23780131,0xdbcc003e,0x60cd00f4}},	//   جمه_, _ufrj_, jóðu, çama,
   {{0x61fb9873,0x2d8f9874,0xdb0117a5,0xe3630e3f}},	//   _foul, _bege_, nglä, _акри,
   {{0x3ea0030b,0x00000000,0x00000000,0x00000000}},	//   čit_, --, --, --,
   {{0x2d8f9875,0x00000000,0x00000000,0x00000000}},	//   _dege_, --, --, --,
   {{0x61fb1428,0xed59053f,0x2b4703a8,0x9f4500d4}},	//   _zoul, ježu_, _bync_, _holý_,
   {{0xa3c1074c,0xed59033b,0xa3ac24f3,0xfff50421}},	//   ्जत_, dežu_, _गाई_, _سکوت_,
   {{0x2d8f0d79,0x2d99037a,0xf99f03a9,0x00000000}},	//   _gege_, óset_, akèn_, --,
   {{0xb4bd13b4,0x9cb30037,0x6ba70537,0xf99f03a9}},	//   _आहे_, _لمنت, ærgå, dhèt_,
   {{0x36d52cd8,0x2d8f9876,0x00000000,0x00000000}},	//   ногр, _zege_, --, --,
   {{0x80d5000f,0x683f00b6,0xc5fb0396,0x501b00ca}},	//   _मैने, vádě, оѓа_, קולו,
   {{0x7bd88151,0x7bda92a7,0xf4871055,0x99670d86}},	//   _havu, ldtu, дужн, _отпл,
   {{0x61fb17f9,0x7bd89877,0x545516bd,0x78a6007e}},	// [a690] _roul, _kavu, еват, crkv,
   {{0x61e99878,0x61fb9879,0x2a6901fa,0xaca30294}},	//   _snel, _soul, _hiab_, _saịk,
   {{0x61fb987a,0x2a69006c,0x08f8010d,0x7bd82bff}},	//   _poul, _kiab_, _فریب_, _mavu,
   {{0x7bd8987b,0xe4a700d3,0x50b52914,0xe3cf0033}},	//   _lavu, _орго, еску, রাইব,
   {{0x61fb025a,0x2d8f987c,0x64550095,0xa5bb2e92}},	//   _voul, _rege_, _thzi, _emóc,
   {{0x61fb7009,0x2a690197,0x7bd8699a,0xb4cb0d75}},	//   _woul, _liab_, _navu, लबी_,
   {{0x61fb987d,0x20073b83,0x2d8f987e,0x61e90090}},	//   _toul, rkni_, _pege_, _tnel,
   {{0x61e9987f,0x2a6901fa,0x63ad00ae,0x2007142e}},	//   _unel, _niab_, şină, skni_,
   {{0xdd9100fb,0x7bd80ba2,0x394901fa,0xc0350284}},	//   نوں_, _bavu, _nyas_, _знај,
   {{0xaf071fdb,0x2d8f0364,0x7bd80027,0x00000000}},	//   _очек, _wege_, _cavu, --,
   {{0x7bd89880,0xdbcc01ab,0x2d8f0381,0x660f02ac}},	//   _davu, róðu, _tege_, _olck,
   {{0x2a6901fa,0xaca30129,0x7afc0149,0xb5fb0103}},	//   _ciab_, _abụk, ärta, _diák,
   {{0xa3c106ae,0x7bd80078,0xed590106,0x2a690154}},	//   ्जा_, _favu, težu_, _diab_,
   {{0x7bd89881,0x39490124,0x3d180034,0x660f016d}},	//   _gavu, _dyas_, _बेटे_, _alck,
   {{0x7bc302fa,0x2a690036,0xed590357,0x2cad0158}},	//   _ibnu, _fiab_, režu_, lued_,
   {{0x7bd81596,0xdb019882,0xed5914f3,0x00000000}},	//   _zavu, rglä, sežu_, --,
   {{0x7bd8023f,0x64a344aa,0x69c4009e,0x2cad00ca}},	// [a6a0] _yavu, лата, _ibie, nued_,
   {{0xa3e705cd,0x68e49883,0x2a6901fa,0x93c80018}},	//   भाग_, _irid, _ziab_, بارہ_,
   {{0x68e40357,0x786b00bd,0xa2a50096,0x6b260139}},	//   _hrid, _iżva, _चटण्, _kòmẹ,
   {{0xa2d50354,0x68e49884,0x2a69022e,0xda10030b}},	//   णिज्, _krid, _xiab_, ासित_,
   {{0x3949023e,0x69c49885,0x68e40078,0x63ab4691}},	//   _xyas_, _mbie, _jrid, álné,
   {{0x2ab80068,0xe8d90019,0xb3cf0081,0x27170033}},	//   yéb_, _ngờ_, রাউজ, _দুটো_,
   {{0x69c49886,0xa3e70219,0xdc1200a7,0xa2e335c8}},	//   _obie, _ядра_, xşıl, _йорд,
   {{0x6ed30253,0x7bd89887,0x68e400e7,0x387f00ae}},	//   _xəbə, _savu, _orid, ţuri_,
   {{0x2cad0133,0x7ae301ce,0x00000000,0x00000000}},	//   gued_, _arnt, --, --,
   {{0x2a690d7d,0x69c49888,0x9f45037a,0x00000000}},	//   _siab_, _abie, _coló_, --,
   {{0x68e49889,0x2a69023e,0x62580037,0x7ae3009c}},	//   _arid, _piab_, ríof, _crnt,
   {{0xdc1208bb,0xc33300a1,0x7bd86973,0xb87b00b6}},	//   rşıl, טות_, _wavu, jvíc,
   {{0x6e22988a,0x68e4988b,0x3d18121d,0x7bd8988c}},	//   _imob, _crid, _बेचे_, _tavu,
   {{0x6ed301d4,0xd7f816bd,0x69c4010a,0x68e44528}},	//   _səbə, нус_, _ebie, _drid,
   {{0x68e42c58,0x2a69022e,0x05870284,0x2c0d00a4}},	//   _erid, _tiab_, еузм, ाघरं_,
   {{0x68e4695e,0x45d4004d,0x44d2022b,0x6ed300a7}},	//   _frid, лосс, _bņ_, _qəbə,
   {{0x629c01d4,0x68e4988d,0x69cf988e,0x93a70a29}},	// [a6b0] _avro, _grid, mece, ешед,
   {{0x69cf074e,0x69c417b5,0xdb014313,0xd6870c37}},	//   lece, _zbie, rflö, _пумп,
   {{0xdb1a052f,0x81da0081,0x78bd988f,0x6ed300a7}},	//   getø, ়ান_, ltsv, _təbə,
   {{0x69cf9890,0x645e9891,0x60cd016d,0x44d2022b}},	//   nece, ampi, çamo, _fņ_,
   {{0x629c57f8,0x69dd9892,0x764d008b,0xd3a7001f}},	//   _evro, idse, mlay, _првп,
   {{0x63550236,0x44251680,0x764d9893,0x6e229894}},	//   _авгу, _öl_, llay, _amob,
   {{0x69cf9895,0x853003e3,0x877c0266,0x6e22033c}},	//   kece, maɗa, לאגי, _bmob,
   {{0x62859896,0x764d9897,0x69cf1f63,0x44230113}},	//   mpho, nlay, jece, _hmj_,
   {{0x44230063,0x4ec30033,0xe7b20179,0x764d008c}},	//   _kmj_, ্মেল, _जालप, ilay,
   {{0x236700e9,0x62859898,0x764d9899,0x68e44e75}},	//   žnju_, opho, hlay, _rrid,
   {{0x764d0b88,0x68e40357,0x62850988,0x9f45037a}},	//   klay, _srid, npho, _voló_,
   {{0x68e4989a,0xa2c40bd9,0xf2d200c1,0x6285989b}},	//   _prid, _रहस्, בעט_, ipho,
   {{0x764d3cc5,0xa3c109c3,0xe8f70243,0x62850503}},	//   dlay, ंभा_, вля_, hpho,
   {{0x60c90294,0x7e6b07ac,0x68e40973,0x3d0d00b7}},	//   _mpem, _higp, _vrid, िनीं_,
   {{0x69cf10d9,0x80b302d5,0x78bd2ba3,0x186735c1}},	//   bece, उंडे, atsv, тари_,
   {{0x764d60ba,0x940c01d4,0x69cf989c,0x7bc11f53}},	//   glay, ələr_, cece, lflu,
   {{0x05661d62,0x6fe10096,0x6285066a,0x44233763}},	// [a6c0] тван, पयां, epho, _bmj_,
   {{0x7bc1989d,0x6d4b0441,0x764d3634,0xf41f0031}},	//   nflu, _myga, alay, _zväz_,
   {{0xe2971dc6,0x764d989e,0xa3b30179,0x442300c4}},	//   вах_, blay, _टार_, _dmj_,
   {{0xaca30af0,0x764d0188,0xdb1a3229,0xb87b1de1}},	//   _apọj, clay, retø, lvía,
   {{0x8c3d75d1,0x216708c3,0x853003e3,0x6d4b1842}},	//   luşu, вици_, baɗa, _nyga,
   {{0x9f650220,0x63830cba,0x442300dc,0x69cf989f}},	//   _štát_, _вгра, _gmj_, zece,
   {{0x69cf0b88,0x8c3d026a,0xf77300ca,0x62858adc}},	//   yece, nuşu, סקה_, cpho,
   {{0x444498a0,0xade3004d,0xe6bb013c,0xd1ca0d59}},	//   lo_, ацьк, şaçı, _تبسم_,
   {{0x625834f3,0x7ceb0088,0xa3e709c4,0x1fb600ae}},	//   ríod, vörð, _मोड_, _асер,
   {{0x444498a1,0x7afc0212,0x1dae0096,0x8af800b4}},	//   no_, ärto, _टाकत, енос_,
   {{0x44446381,0x6e2201af,0x601405fe,0x69cf98a2}},	//   io_, _tmob, _càme, tece,
   {{0x444498a3,0x7e6b0124,0xa5bb0139,0x764d0092}},	//   ho_, _gigp, _amón, xlay,
   {{0x44447620,0x3e7898a4,0x69dd98a5,0xa3b3009f}},	//   ko_, _hét_, rdse, _टाल_,
   {{0x444498a6,0x3e780068,0x69cf98a7,0x78bd093e}},	//   jo_, _két_, sece, rtsv,
   {{0x4444406b,0x7c2898a8,0xa3ac02d5,0x764d0367}},	//   do_, midr, _गाज_, tlay,
   {{0x4444524f,0x3ce6005f,0x58d51d64,0x3e7898a9}},	//   eo_, _krov_, _боит, _mét_,
   {{0x4444010a,0x764d008e,0x9f5e00dd,0x3e7844ff}},	// [a6d0] fo_, rlay, _botë_, _lét_,
   {{0x764d9768,0xf8bf00fd,0x5fc40d7e,0x4ab6087c}},	//   slay, mté_, ल्मल, _अमाव,
   {{0x764d55ac,0xf8bf0257,0x3e780019,0x8c3d026a}},	//   play, lté_, _nét_, muşt,
   {{0x68e20029,0x764d448b,0x8c3d0233,0x628598aa}},	//   _šodi, qlay, luşt, rpho,
   {{0x444498ab,0xf8bf98ac,0x3ce6006c,0x8fa513a5}},	//   bo_, nté_, _nrov_, гале,
   {{0xf8bf0257,0x8c3d026a,0x660d98ad,0x628500f3}},	//   ité_, nuşt, lkak, ppho,
   {{0x997600a7,0xdbe40065,0x2294534b,0x7afc02c3}},	//   _nəşr_, _gèés, _вися, ärtl,
   {{0x53341369,0x6445152a,0xa3c1382d,0x3e78181f}},	//   _тест, lohi, ंभव_, _dét_,
   {{0xc104262f,0x660d98ae,0x626c00ae,0x60c90a4b}},	//   _پولي, ikak, _uşoa, _upem,
   {{0xabd519e8,0xe8d90023,0x3e780154,0x998202c6}},	//   уциј, _ngố_, _fét_, tiků_,
   {{0x7bc198af,0x660d98b0,0xdd9100cd,0x7e6b02c9}},	//   rflu, kkak, _هوا_, _tigp,
   {{0x6445006d,0x9d192ca4,0x62580037,0x7bc15ac6}},	//   hohi, _поет_, míoc, sflu,
   {{0x625800e3,0x6445059f,0x3ce60bc6,0x7c28040f}},	//   líoc, kohi, _grov_, bidr,
   {{0x444498b1,0x3e710038,0x31560130,0x6e297746}},	//   xo_, _ešte_, טירן_, lieb,
   {{0x3e780019,0x8c1a00a1,0x7d0998b2,0xe5a64c89}},	//   _xét_, _רוצי, lyes, ливи,
   {{0x44443fba,0x660d34e1,0x6e2998b3,0x8c3d0491}},	//   wo_, gkak, nieb, ruşu,
   {{0x44440cba,0x7d0946b6,0xf8bf025a,0xe45a08c3}},	// [a6e0] to_, nyes, cté_, ежа_,
   {{0x78a9077e,0x44448677,0x6e290364,0x62880216}},	//   ševc, uo_, hieb, _çdok,
   {{0x91e6448a,0x2cbf007a,0x6e290126,0x41aa02b3}},	//   ложе, htud_, kieb, евен_,
   {{0x444498b4,0x2cbf0124,0x3e78424d,0x80c80033}},	//   so_, ktud_, _rét_, লিস্,
   {{0x859b0054,0x8cd302d5,0x3e780023,0x673601d3}},	//   _אשכו, _बैलो, _sét_, šajā,
   {{0x44443cc5,0xa0672b79,0xddcb2224,0x00000000}},	//   qo_, гача_, _figū, --,
   {{0x62580080,0x7c288116,0x645c0220,0x2cbf98b5}},	//   ríob, vidr, _ihri, etud_,
   {{0x3ce64062,0xf8bf0094,0x7c28042c,0x7d1b042c}},	//   _prov_, yté_, widr, fzus,
   {{0x7c2898b6,0x2472022b,0x4fb60c5e,0x7d0998b7}},	//   tidr, _fņme_, _مصار, gyes,
   {{0xd12f0678,0x610a00d9,0x660d1415,0xdd8f0103}},	//   _عمل_, _vēlā, zkak, _ہوم_,
   {{0x629e6fe9,0x23c6201e,0x62580037,0x5a35001f}},	//   nspo, र्यद, cíoc, инот,
   {{0xf8bf5635,0x9f5e87ec,0x7c280ad8,0x644598b8}},	//   tté_, _noté_, sidr, zohi,
   {{0xf8bf025a,0x02d10d77,0x645c98b9,0xe9df98ba}},	//   uté_, _सन्न, _ohri, rdú_,
   {{0xf8bf025a,0x9f5e0036,0x6281014b,0xd7fb0077}},	//   rté_, _potè_, _élog, хум_,
   {{0xf8bf98bb,0x6b7b0105,0xdce003a3,0x2fde0124}},	//   sté_, _ארונ, mamı, _matg_,
   {{0xdce003a3,0x629e6073,0xf8bf0257,0x6b9a98bc}},	//   lamı, dspo, pté_, latg,
   {{0x6445022f,0x660d98bd,0x645c0091,0x94770f36}},	// [a6f0] tohi, rkak, _bhri, ادرا,
   {{0x6b9a0472,0x645c98be,0x44380085,0x64400653}},	//   natg, _chri, _cjr_, _ímil,
   {{0x644598bf,0x629e98c0,0x645c1909,0xdb1a0072}},	//   rohi, gspo, _dhri, metó,
   {{0xb5fb2bb5,0x6445330c,0x645c009c,0xdb1a98c1}},	//   _ciát, sohi, _ehri, letó,
   {{0x69df00dd,0x645c0527,0xdce0008b,0x64450a4b}},	//   _maqe, _fhri, kamı, pohi,
   {{0x645c02bc,0x625800e3,0x3ddd005c,0x7d1b0092}},	//   _ghri, tíoc, _saww_, vzus,
   {{0x6e295362,0x80d50789,0x629e0095,0x6b9a76f5}},	//   tieb, _मैरे, cspo, datg,
   {{0x82370080,0x62580080,0x7d1b042c,0x7d093661}},	//   _إرسا, ríoc, tzus, tyes,
   {{0x6e2998c2,0x1fa71510,0xdd990146,0x62580076}},	//   rieb, _брег, raň_, síoc,
   {{0x60db5110,0x6e2998c3,0x2cbf7da6,0xb5fb0037}},	//   _isum, sieb, rtud_, _fhág,
   {{0xa5bb0139,0x2cbf98c4,0x7d1b0364,0x7d0938ea}},	//   _amóm, stud_, szus, syes,
   {{0xaab600aa,0xdce600e8,0x00000000,0x00000000}},	//   _अमरक, šmāj, --, --,
   {{0x2d8d98c5,0xc9560ae3,0xdce00342,0x229c0139}},	//   mbee_, ртны, bamı, _káká_,
   {{0xb8ee05d4,0x6b9a00ee,0x60db0239,0x7d0600c2}},	//   _रह_, catg, _msum, äkse,
   {{0x69df00dd,0x9f5e00b6,0xd62a0fd5,0xa596008f}},	//   _faqe, _poté_, вове_, иращ,
   {{0x78a90b27,0x629e052f,0x645c4f2d,0x229c98c6}},	//   ševa, vspo, _shri, _láká_,
   {{0x629e98c7,0x645c7fd6,0x142698c8,0x24890124}},	// [a700] wspo, _phri, адам, gpam_,
   {{0x389b00c1,0x224698c9,0x03a600d3,0x6d5998ca}},	//   _שיינ, wook_, рижо, _mzwa,
   {{0x60db2b29,0x81df0081,0xb5fb0503,0x00000000}},	//   _asum, তান_, _bhád, --,
   {{0x00e60e3f,0xb5fb7ddd,0x55e60b3b,0x600f01df}},	//   ижен, _diás, _томб, _dømm,
   {{0x2246591f,0xdce003e0,0x228c05aa,0xe0d200b9}},	//   rook_, yamı, _bòkò_, تزا_,
   {{0xa2e602fd,0x2cad9687,0x629e8027,0x22462153}},	//   _когд, dred_, pspo, sook_,
   {{0xe2973f37,0x99990181,0x82a300d3,0xdce00587}},	//   _вас_, losť_, _марж, vamı,
   {{0x6014048b,0xb4db0065,0x2cad98cb,0xadf41d54}},	//   _dàma, _iyàr, fred_, спиш,
   {{0x6b9a0472,0x99990181,0x6d590034,0xeb0e0c9c}},	//   tatg, nosť_, _czwa, ान्त_,
   {{0x60c298cc,0xbea600d6,0x46c70ee0,0x61e20103}},	//   mtom, _важк, _लहलह, ldol,
   {{0x6b9a05fe,0x337700a1,0x61e003a9,0x3f9c0051}},	//   ratg, יעים_, _kaml, mavu_,
   {{0x61e298cd,0x2cad4520,0x6ab60ed3,0x6b9a05fe}},	//   ndol, bred_, _अमीर, satg,
   {{0x61e00010,0x3e712392,0x63bc00cc,0x6b9a98ce}},	//   _maml, _išta_, _ocrn, patg,
   {{0x61e202fd,0x6b9a02a1,0x99990220,0x3f9c98cf}},	//   hdol, qatg, dosť_, navu_,
   {{0xd5bb3097,0xdb1a98d0,0x60c2007b,0x07080036}},	//   кса_, retó, htom, ахти_,
   {{0x24890194,0x600f0120,0xdb1a0072,0x61e098d1}},	//   tpam_, _rømm, setó, _naml,
   {{0x3f9c98d2,0x61e20150,0x799d02a4,0x81df0033}},	// [a710] kavu_, ddol, masw, তাম_,
   {{0x4ada0006,0x3f9c1206,0xaada0cce,0x799d6aa7}},	//   _बनाव, javu_, _बनाक, lasw,
   {{0xb5fb5f4f,0x61e00372,0x60db010a,0x00000000}},	//   _diár, _baml, _ssum, --,
   {{0xa3e704f1,0x799d98d3,0x61e2610d,0x60c20052}},	//   _मोर_, nasw, gdol, ftom,
   {{0x69bc009d,0x95080068,0x8467013d,0x320412fb}},	//   ष्टी, _پہلے_, _въве, _domy_,
   {{0x600f01df,0x3f9c98d4,0x27e198d5,0x3a290503}},	//   _tømm, gavu_, _jahn_, _lmap_,
   {{0x61e004de,0x60c24031,0x61e2028d,0x799d98d6}},	//   _faml, atom, bdol, kasw,
   {{0x61e001ce,0x625800e3,0xed59922c,0x60db98d7}},	//   _gaml, líon, лой_, _tsum,
   {{0xa3ab0d1b,0x60db360f,0xdceb009e,0x00000000}},	//   _गया_, _usum, _megħ, --,
   {{0x2cad00a1,0x62580037,0x40590192,0x61e04136}},	//   rred_, níon, _صلاح_, _zaml,
   {{0x9cf90f71,0x81da00c7,0x26c1023e,0x2cad00cb}},	//   েছেন_, ়ার_, _nqho_, sred_,
   {{0x200500f0,0xf53f0212,0xc3320796,0xdceb02a1}},	//   _holi_, _oxå_, לוי_, _negħ,
   {{0xeb8e00b8,0x200598d8,0x6c8500e3,0x78a90a87}},	//   _ни_, _koli_, _التم, ševn,
   {{0x99990181,0x200598d9,0x6b9800e7,0xa3e709b0}},	//   vosť_, _joli_, _gevg, _मोल_,
   {{0x200508c5,0xdceb0090,0x61e298da,0x60c20094}},	//   _moli_, _begħ, ydol, ztom,
   {{0x3f9c0b18,0x99990220,0x60c22c94,0x9f4c0139}},	//   zavu_, tosť_, ytom, _kodò_,
   {{0x2aa301d4,0x61e06e6d,0x2bbd0789,0x79840af0}},	// [a720] lıb_, _raml, ्भपा, _ifiw,
   {{0x61e002fe,0x25e80cce,0x68fb00ca,0x2005312a}},	//   _saml, _चोरी_, _עליה, _noli_,
   {{0xe80d0067,0x2aa301d4,0x2a60022e,0x518613c9}},	//   _सकता_, nıb_, _khib_, була,
   {{0x60c298db,0xdceb0090,0x7afc2104,0x225f0169}},	//   ttom, _gegħ, ärti, _chuk_,
   {{0x200598dc,0x81da0081,0x225f0113,0x62876eb5}},	//   _boli_, ়াল_, _dhuk_, _etjo,
   {{0x60c298dd,0x66061888,0xa5bb0065,0xdb010076}},	//   rtom, _hokk, _amóh, ngló,
   {{0x66064174,0x60c22042,0x442a98de,0x200598df}},	//   _kokk, stom, _imb_, _doli_,
   {{0x6b980dea,0x6b8303a9,0x60c298e0,0x2aa300a7}},	//   _sevg, _afng, ptom, dıb_,
   {{0x8fa61caf,0x200598e1,0x660698e2,0x3f9c1cd1}},	//   _газе, _foli_, _mokk, pavu_,
   {{0xb5fb00ef,0xdbf0030b,0x442a02ef,0x66062084}},	//   _khác, _tříd, _jmb_, _lokk,
   {{0xe9f9013a,0x0dca00d6,0x9b582105,0x394000d7}},	//   анні_, _були_, ринт_, _axis_,
   {{0x66060102,0x2a60023e,0xaaa91488,0x9e667ce1}},	//   _nokk, _chib_, _किरक, _увед,
   {{0xa3b805d4,0x442a01af,0x799d98e3,0x2a600188}},	//   छला_, _omb_, rasw, _dhib_,
   {{0xa3e7009f,0x442a4d61,0x3d2b0103,0x78a4004b}},	//   _मों_, _nmb_, _حتمی_, _dviv,
   {{0x660698e4,0x799d0010,0xdb1e00c2,0xab68003d}},	//   _bokk, pasw, ävän, _biżż,
   {{0x442a429b,0xb5fb0037,0xdceb003d,0x9f5e00b3}},	//   _amb_, _sháb, _qegħ, _notí_,
   {{0x628701ab,0x26c302dd,0x442a36da,0xb87b0146}},	// [a730] _stjo, stjo_, _bmb_, zvíj,
   {{0x68ed55b0,0x7e7a624a,0x7a2f05aa,0xb367007b}},	//   _irad, _outp, _fòtè, бъек,
   {{0x68ed0363,0x625800e3,0x200598e5,0x6606645f}},	//   _hrad, ríon, _roli_, _fokk,
   {{0x09ab00c7,0x41550f80,0x660698e6,0x3abb00c1}},	//   গ্রা, овес, _gokk, רמאנ,
   {{0xed4607d9,0x09e300c7,0x2aa30092,0x7c2a01ce}},	//   _آپ_, যাপা, zıb_, _omfr,
   {{0x2aa301d4,0x68ed0010,0xa295059b,0xaaa902d5}},	//   yıb_, _mrad, _магі, _किलक,
   {{0x66067a44,0x2aa300a7,0x69cd010a,0x59a90096}},	//   _yokk, xıb_, _obae, कणार,
   {{0xf2d207a6,0x68ed98e7,0x99806559,0x660615b0}},	//   _קען_, _orad, _omiš_, _xokk,
   {{0x2a60023e,0x2eec7e62,0x442a0063,0x200598e8}},	//   _rhib_, _erdf_, _ymb_, _toli_,
   {{0x5ac94941,0x2aa30092,0x2a60041c,0x69cd083e}},	//   алом_, tıb_, _shib_, _abae,
   {{0x68ed681e,0x78a9005f,0x786098e9,0x09e30033}},	//   _arad, ševl, növe, যানা,
   {{0x2a600197,0x2aa30092,0xdd1e02c6,0xba3d00c6}},	//   _qhib_, rıb_, _síťo, drįs,
   {{0x7860070a,0x6e2b0139,0x7e7a029a,0x00000000}},	//   höve, _imgb, _zutp, --,
   {{0x660698ea,0x68ed4e4c,0x78600103,0xcb6919c3}},	//   _sokk, _drad, köve, _кале_,
   {{0x442a581c,0x66e398eb,0x2a60006c,0x66060e22}},	//   _rmb_, мора, _thib_, _pokk,
   {{0x68ed38bf,0x78a4422e,0x39408913,0x2d9f98ec}},	//   _frad, _tviv, _txis_, naue_,
   {{0x644302dd,0xe4062fad,0x78a44100,0x660698ed}},	// [a740] čnin, озап, _uviv, _vokk,
   {{0x660698ee,0xb5fb0023,0x853001c2,0x2d9f0364}},	//   _wokk, _phác, naɗi, haue_,
   {{0x59c11677,0x8646169f,0x68ed0094,0x62580231}},	//   ष्कर, _множ, _zrad, bíol,
   {{0x3f8500ae,0x62580072,0x4b4c006e,0x00000000}},	//   _aflu_, cíol, נגאַ, --,
   {{0x25a098ef,0x10a32c3b,0x442a98f0,0x76410018}},	//   mail_, дичн, _tmb_, élye,
   {{0x4aa90454,0xeeaa7480,0xb5fb00de,0x28b2007a}},	//   _किंव, атик_, _thác, _जिनि,
   {{0x09b20033,0x2480150c,0x00000000,0x00000000}},	//   ট্যা, lqim_, --, --,
   {{0x25a098f1,0x6146075f,0x6ca62917,0x2dd3008f}},	//   nail_, _деба, орож, джър,
   {{0x625800e3,0xb87b003e,0x09e30033,0x00000000}},	//   níom, rvík, যামা, --,
   {{0x25a003e9,0x9b6a0cba,0x68ed023b,0x8c430291}},	//   hail_, ишна_, _rrad, мење,
   {{0xa5bb0396,0x68ed98f2,0x25a03d10,0x24800052}},	//   _imóv, _srad, kail_, hqim_,
   {{0x68ed01b3,0xba2b00d6,0xa2cd0b76,0x6d5c00a7}},	//   _prad, ріод_, _सहस्, əran,
   {{0x25a0117b,0xcd3609f4,0x0e691f11,0x7e621e8f}},	//   dail_, _براب, _اصلي_, _ihop,
   {{0x7c2a2305,0x00000000,0x00000000,0x00000000}},	//   _umfr, --, --, --,
   {{0x09d000c7,0x25a098f3,0xdb4f00d6,0x68ed0113}},	//   িয়া, fail_, _цю_, _wrad,
   {{0x25a00013,0x7afc007a,0x3ce9007e,0xddc2007f}},	//   gail_, ärtu, _šavi_, _ukoń,
   {{0x68ed1027,0xd37b1c66,0xb4e5074c,0x7c3a0503}},	// [a750] _urad, аче_, पटे_, ontr,
   {{0x7c3a98f4,0x7860679d,0x00000000,0x00000000}},	//   nntr, töve, --, --,
   {{0x25a00080,0x926b0b9e,0x4cd30081,0x7c3a98f5}},	//   bail_, арда_, তিযু, intr,
   {{0x25a00099,0x7c3a98f6,0x925900c2,0x2bca007f}},	//   cail_, hntr, щает_, ़्ता,
   {{0xc5fa00a1,0x00000000,0x00000000,0x00000000}},	//   _הפרט, --, --, --,
   {{0xe8d90294,0x7e6201ff,0xdb1a00bc,0x7c3a18f0}},	//   _nzọ_, _ahop, letõ, jntr,
   {{0xa19502ec,0x7e620849,0x160f0751,0x82a40b1b}},	//   _навч, _bhop, _सवार_, _оште,
   {{0xe8d90134,0x7c3a98f7,0x7e625606,0x09e30033}},	//   _azọ_, entr, _chop, যাডা,
   {{0x81190915,0x7a363b1a,0x261c00da,0x00000000}},	//   _ужас_, nšte, _híoc_, --,
   {{0x4b250426,0x3e7100e7,0x00000000,0x00000000}},	//   змов, _tšto_, --, --,
   {{0xb17d0031,0x85300d2a,0xc9490eda,0x00000000}},	//   _zaťa, raɗi, _עמ_, --,
   {{0x7a36522a,0x6eca00a7,0x25a0013c,0x2d840113}},	//   kšte, _məbl, xail_, ccme_,
   {{0x25a0025a,0x7e690c8a,0x00000000,0x00000000}},	//   vail_, mmep, --, --,
   {{0x7c9400cd,0x601d06a3,0x25a007ac,0x628909ac}},	//   _آشنا, _fème, wail_, _čeon,
   {{0x81b30081,0x4e1f0251,0x25a0461e,0x64430094}},	//   জ্য_, _बताई_, tail_, čnil,
   {{0x6e3b98f8,0xe73700ae,0xe7ec00b6,0x2d9d0169}},	//   nnub, чес_, _छोरा_, _jewe_,
   {{0x25a098f9,0x2d9d0174,0x601d03a9,0xa9240094}},	// [a760] rail_, _mewe_, _mèmb, áždi,
   {{0x2d9d0665,0x25a08350,0x62580037,0x601d0113}},	//   _lewe_, sail_, ríom, _lèmb,
   {{0x877b00a1,0x518633d4,0xa5bb0065,0x248b0063}},	//   _לאיי, пула, _amóu, _etcm_,
   {{0xdb1a00bc,0x2d9d0f5a,0x443a0231,0x00000000}},	//   petö, _newe_, snp_, --,
   {{0x3dc300c7,0xb5fb0019,0xf772001c,0x6e3b007e}},	//   ্যাল, _khán, _تاک_, dnub,
   {{0x7e6206ce,0x9326110a,0x66046a6a,0x9f4c037a}},	//   _shop, _فرزن, ljik, _andá_,
   {{0xeab60081,0x2bc204f1,0x877b00c1,0x2d9d0f5a}},	//   _জন্ম, _शाबा, זאצי, _bewe_,
   {{0x91e3562f,0x2d9d00a4,0x660498fa,0xb2266089}},	//   _посе, _cewe_, njik, _эмбл,
   {{0x2ba6033a,0x2d9d98fb,0x75243304,0x00000000}},	//   jící_, _dewe_, nziz, --,
   {{0xb5fb00de,0x2ba600b6,0x7c3a044c,0x601d05aa}},	//   _nhán, dící_, untr, _pème,
   {{0x81df00c7,0xeee400cd,0xfbcf0018,0xb87b0131}},	//   তার_, _تغذی, ھتی_, nvív,
   {{0xddc802ef,0x601d60e7,0x752400dc,0xa5bb037a}},	//   _hudž, _gèmb, kziz, _ilóg,
   {{0x3f9e00dd,0x78a632fa,0x5e250018,0x66040154}},	//   _ketu_, gskv, _تعلق, djik,
   {{0x7a36135f,0x36d500be,0x7afc00a2,0xb5fb1d53}},	//   všte, могр, ärts, _chán,
   {{0x3f9e98fc,0x7bda98fd,0xddc802ef,0x2d9d02a4}},	//   _metu_, metu, _mudž, _yewe_,
   {{0x7bda98fe,0x3f9e154e,0x660400dd,0xe8d90134}},	//   letu, _letu_, gjik, _afụ_,
   {{0xb5fb0503,0x656001ec,0xd8bb00d1,0x0ef90285}},	// [a770] _fhán, _ùmhl, _ادعا_, _ऍप्स_,
   {{0x7bda66da,0xb5fb5956,0x7e69037a,0xdb1a00bc}},	//   netu, _ghán, zmep, setõ,
   {{0x61c800c3,0x7bda98ff,0x75249900,0x00000000}},	//   रभूष, ietu, aziz, --,
   {{0x7bda87de,0x7a36175b,0xe8d92e5c,0xdcfb00c4}},	//   hetu, pšte, _efụ_, zbuđ,
   {{0xddc89901,0x81df0081,0x3f9e00c4,0x661d0212}},	//   _budž, তাল_, _betu_, _ilsk,
   {{0x2d9d057a,0x7bda9902,0x6eca00a7,0x00000000}},	//   _sewe_, jetu, _təbl, --,
   {{0x7bda9903,0x6e3b0bb6,0x4421010a,0x00000000}},	//   detu, tnub, mhh_, --,
   {{0x44339904,0x2bcf0096,0x60140441,0x00000000}},	//   lix_, त्ना, _làmh, --,
   {{0x7e693813,0x3f9e0090,0x9f5e034f,0x6e3b9905}},	//   rmep, _fetu_, _votá_, rnub,
   {{0x2d9d068d,0x7bda9906,0x7e64003d,0x78a61842}},	//   _wewe_, getu, ċipa, vskv,
   {{0x2d9d02ac,0x00000000,0x00000000,0x00000000}},	//   _tewe_, --, --, --,
   {{0x3f9e0010,0xdcf90470,0xb5fb02c6,0xce35001c}},	//   _zetu_, _وفات_, _shán, _کوچک,
   {{0x3f9e068d,0x7bda2c5c,0x644302e6,0x3ea02cea}},	//   _yetu_, betu, čnij, ćite_,
   {{0x7bda135c,0x601401b9,0xdb1a0131,0x78a69907}},	//   cetu, _càmh, tetô, rskv,
   {{0x59c602e8,0x8c420307,0x44339908,0x60140441}},	//   _वापर, _шеше, dix_, _dàmh,
   {{0x44330428,0x2b0a030b,0x752401e9,0x2ba602c6}},	//   eix_, ाहरु_, tziz, pící_,
   {{0xb5fb00ef,0x64a33ae2,0xa5bb0042,0xc7960450}},	// [a780] _thán, ката, _amós, _орны,
   {{0x661d5ec1,0x68e49909,0x4421005c,0x6616007b}},	//   _elsk, _isid, ghh_, skyk,
   {{0x2bcf0c3c,0x9f45023b,0xfbcf02c6,0xf7462e0f}},	//   त्या, _dalë_, त्यम, _цено,
   {{0x44212ce8,0x224000aa,0xc69300ca,0xe1fa0077}},	//   ahh_, õik_, _שאר_, юге_,
   {{0x7bda0051,0x9f45023b,0xb5fb00da,0x00000000}},	//   yetu, _falë_, _mhál, --,
   {{0xd0100c5e,0x2bcf1678,0x3c2005aa,0x68e4990a}},	//   طلب_, त्मा, _kòve_, _msid,
   {{0x7bda990b,0xa3e71101,0xc334006e,0x69c4007f}},	//   vetu, _मोट_, _װוּ_, _ocie,
   {{0x78a900e9,0x3f9e068d,0x9f4502f1,0x3c200154}},	//   ševi, _wetu_, _malè_, _mòve_,
   {{0x7bda990c,0x7bc3990d,0x3f9e00c4,0xed570291}},	//   tetu, _bcnu, _tetu_, моћ_,
   {{0x69c4990e,0xf0630138,0xa3de074c,0xb4fb00ca}},	//   _acie, _акуп, ढ़ि_, קפיי,
   {{0x83b700ca,0xaa59290e,0x68e4990f,0x00000000}},	//   ופיע_, зину_, _asid, --,
   {{0x7bda9910,0xdd905e51,0x200c9911,0x32060350}},	//   setu, _صوت_, _hodi_, njoy_,
   {{0x200c9912,0xb4bd00aa,0xa3de0251,0x22950065}},	//   _kodi_, _इमे_, ढ़ा_, _kúkò_,
   {{0x200c06a3,0x443391b1,0xb8f709c4,0x9f450af0}},	//   _jodi_, xix_, _सह_, _balè_,
   {{0x200c9913,0x45d51e9e,0x68e40201,0xf6530103}},	//   _modi_, новс, _esid, نئر_,
   {{0x200c9914,0x59c604dd,0xa5bb0139,0x9f450139}},	//   _lodi_, _वायर, _amór, _dalè_,
   {{0x69dd9915,0x44339916,0x601d03a9,0x9f450052}},	// [a790] mese, tix_, _lèma, _palë_,
   {{0x69dd9917,0x200c0150,0xc86700e3,0x9f450139}},	//   lese, _nodi_, _تطبي, _falè_,
   {{0x44339918,0x7a363360,0x81e80081,0x68e40103}},	//   rix_, lšta, বান_, _zsid,
   {{0x201e1031,0x44210967,0xa29400d6,0x5ef4142e}},	//   _alti_, shh_, таці, ्मन्_,
   {{0x629c801d,0x200c9919,0x7a360f72,0x78bd04c3}},	//   _ewro, _bodi_, nšta, nusv,
   {{0x649a0054,0x8574116d,0x200c8a99,0x69dd4f3f}},	//   _מישה, _шлях, _codi_, hese,
   {{0x69dd991a,0x63a5991b,0x44260022,0x9f450065}},	//   kese, mahn, ɗo_, _kalé_,
   {{0x63a53edf,0x261c00e3,0x7a36013f,0x601d0154}},	//   lahn, _líon_, kšta, _dèma,
   {{0x9f45025b,0x61fb991c,0x3dcd01af,0x629c0034}},	//   _malé_, _inul, rfew_, _zwro,
   {{0x63a5331c,0x69c4991d,0x200c0150,0x61e9991e}},	//   nahn, _scie, _godi_, _hael,
   {{0x61fb3bdc,0x69dd3759,0x61e9991f,0x7a360138}},	//   _knul, fese, _kael, ešta,
   {{0x69dd7ffe,0x61e99920,0x200c705f,0xdb0100d4}},	//   gese, _jael, _zodi_, nalé,
   {{0x61e9068d,0x63a50808,0xb5fb03be,0xdb0106a3}},	//   _mael, kahn, _chám, zalè,
   {{0xfaa5197a,0x63a5561b,0x61e95d90,0xa3cf0789}},	//   _зако, jahn, _lael, _वॉल_,
   {{0x63a54727,0x8c1a00a1,0x69dd9921,0x9f459922}},	//   dahn, _מוסי, bese, _balé_,
   {{0x69dd9923,0x61e99924,0x9f459925,0x69c40034}},	//   cese, _nael, _valè_, _ucie,
   {{0x2edc000d,0xd54700ae,0x63a59926,0xb46630cf}},	// [a7a0] _मन्त, епте_, fahn, екал,
   {{0x61fb9927,0x6fd30b88,0x63a59928,0x7bc19929}},	//   _anul, nıcı, gahn, nglu,
   {{0x23c61efb,0xa79b0089,0x61e900b3,0x35a6002d}},	//   र्गद, _משיח, _bael, _панг,
   {{0x6455832d,0x2bcf1efb,0xdb010181,0xfbcf0285}},	//   _ekzi, त्ता, galé, त्तम,
   {{0x63a5992a,0x6d5940ab,0x6b800134,0x200c992b}},	//   bahn, _nywa, ịgid, _podi_,
   {{0x69dd992c,0x9f3436bf,0x7bc100cb,0x63a50ddc}},	//   zese, келі, jglu, cahn,
   {{0x69dd992d,0x6d5900f9,0x24820063,0x6fd30092}},	//   yese, _aywa, _hukm_, dıcı,
   {{0x61e9003b,0x2bc20006,0x61fb00b3,0x200c0a4b}},	//   _gael, _शाहा, _gnul, _wodi_,
   {{0x59a70067,0x69dd992e,0x200c06f8,0x6d59992f}},	//   _ख़बर, vese, _todi_, _cywa,
   {{0x320d5c3d,0x69dd9930,0x3a20519c,0x09a90096}},	//   _zoey_, wese, _alip_, कण्य,
   {{0x69dd9931,0x600f01df,0x61e920e3,0xb4bd0285}},	//   tese, _tømr, _yael, _इम्_,
   {{0xf2d30130,0x3a200028,0x78bd03cf,0x63a50f22}},	//   נער_, _clip_, tusv, zahn,
   {{0x63a50b08,0x09e30081,0x48bf0033,0x786002c3}},	//   yahn, যালা, ইব্র, rövn,
   {{0x69dd43fe,0x7a360138,0x9f45020d,0x9f4c00f3}},	//   sese, ršta, _salé_, _endå_,
   {{0xc2210c8c,0x387a00e7,0x63a50128,0x69dd9932}},	//   _मतलब_, _dipr_, vahn, pese,
   {{0x63a5063f,0x7a36366a,0x3a209933,0x44310239}},	//   wahn, pšta, _glip_, _smz_,
   {{0xb87b01cd,0xa5bb0072,0x64550124,0xdb011054}},	// [a7b0] rvís, _alóc, _pkzi, valé,
   {{0xf8bf037a,0x00000000,0x00000000,0x00000000}},	//   mué_, --, --, --,
   {{0xa8580054,0x63a57d24,0x61e941f4,0x2a69022e}},	//   _איזה_, rahn, _pael, _khab_,
   {{0x63a50b08,0x92b40037,0x798d02a1,0x7bc19934}},	//   sahn, احلا, _jfaw, zglu,
   {{0x91bf0134,0x6fd3008b,0xf8bf020d,0xc0e52cde}},	//   _ahụ_, yıcı, nué_, толк,
   {{0xe05700d0,0xdb01222b,0x61e99935,0x63a50063}},	//   ریات_, salé, _wael, qahn,
   {{0x61fb010a,0x6d59084e,0x26180285,0x61e90653}},	//   _tnul, _sywa, _नवमी_, _tael,
   {{0xe8d90019,0x660f06c5,0x7bc1023e,0x6288002b}},	//   _ngữ_, _jock, wglu, _édoa,
   {{0x6fd30367,0x00000000,0x00000000,0x00000000}},	//   tıcı, --, --, --,
   {{0x2a690270,0x660f9936,0xb05b0174,0xea890da5}},	//   _ahab_, _lock, ịịrị_, мбол_,
   {{0xab2910f7,0x7bc19937,0x6fd307e7,0xbb451628}},	//   фона_, rglu, rıcı, тенк,
   {{0x8d87008f,0x2a69009c,0x660f9938,0xdd9501b3}},	//   _чужд, _chab_, _nock, _рады,
   {{0xf8bf5af8,0x261c0037,0x2a690188,0x3e4500e8}},	//   gué_, _díol_, _dhab_, cēta_,
   {{0x2cbf008a,0x6eca013c,0x00000000,0x00000000}},	//   muud_, _səbi, --, --,
   {{0x07a35153,0x317f23ad,0xc7a3016c,0x660f9939}},	//   расн, _oguz_, риск, _bock,
   {{0xf8bf00fd,0x6eca00a7,0x660f993a,0x00000000}},	//   bué_, _qəbi, _cock, --,
   {{0x69d6993b,0x2cbf11b9,0xb87b0094,0x387a0027}},	// [a7c0] _ibye, nuud_, rvír, _tipr_,
   {{0xe29a2f1f,0x7d060f06,0x00000000,0x00000000}},	//   даж_, äksi, --, --,
   {{0x6eca0092,0x437600d3,0xa766084c,0x3e4500e8}},	//   _təbi, туат, _шкод, zēta_,
   {{0x6fc40096,0x3eb80537,0x00000000,0x00000000}},	//   _राहू, _årti_, --, --,
   {{0x0cbc0081,0x2bc202d5,0xa3cf0096,0x69d67541}},	//   _অন্ত, _शाला, व्ह_, _mbye,
   {{0x09d600c7,0x7a360138,0x2cbf0188,0x905308a1}},	//   _তোমা, kšto, duud_, авіц,
   {{0x69d6993c,0x9e3400e5,0x00000000,0x00000000}},	//   _obye, лекч, --, --,
   {{0x2bcf16e2,0x3ce60211,0x6ced0592,0x0367036a}},	//   त्सा, _psov_, जिंग_, _риск_,
   {{0x81e80f71,0x2486054f,0xdb2002b4,0x62830146}},	//   বাদ_, íomh_, _àtún, ínov,
   {{0x3e4501d3,0x69d60b58,0x261c0076,0x2a690364}},	//   rēta_, _abye, _síol_, _shab_,
   {{0x6d440038,0x0c7300e3,0x2a69022e,0x78ad2e0e}},	//   _žiad, جديد, _phab_, _svav,
   {{0x68f658e7,0xf8bf0257,0x2a6901fa,0x3ce6006c}},	//   _bryd, tué_, _qhab_, _tsov_,
   {{0xac0a0291,0xbb470018,0x660f49fb,0x26da0085}},	//   _онда_, فلین_, _rock, _appo_,
   {{0x660f993d,0xd9180084,0x69d60283,0x68f600f0}},	//   _sock, тью_, _ebye, _dryd,
   {{0x6e224c54,0x2a69022e,0x660f993e,0xe7d2077d}},	//   _klob, _thab_, _pock, द्धप,
   {{0xd5b83947,0x628100fd,0x68f651b8,0xc60b0033}},	//   ксу_, _éloi, _fryd, রসভা_,
   {{0x2bcf02e8,0xf8bf993f,0xfbcf00b6,0x68f602b6}},	// [a7d0] त्वा, qué_, त्वम, _gryd,
   {{0x6e2205fe,0xb5fb0037,0x601d00b3,0x78a90ad1}},	//   _llob, _mhái, _rèmo, ševs,
   {{0xe7ec0789,0x660f0995,0xe29800d6,0xe8d90174}},	//   _छोटा_, _tock, ває_, _oyị_,
   {{0x645e9940,0x9f450036,0x00000000,0x00000000}},	//   alpi, _dalì_, --, --,
   {{0x25a99941,0x6d4e01bf,0x29190124,0x9f4c0036}},	//   maal_, ßbal, nysa_, _indù_,
   {{0xe8d90174,0x25a9008a,0x1ec91773,0x6e224950}},	//   _ayị_, laal_, елки_, _alob,
   {{0x7a26003e,0x2cbf6221,0x00000000,0x00000000}},	//   _hóte, wuud_, --, --,
   {{0x25a9686b,0xdb030257,0xa3cf05a5,0x6e2201b9}},	//   naal_, _fenê, व्र_, _clob,
   {{0xb5fb0037,0xacf5001c,0x44230381,0xa31c0d79}},	//   _chái, اسبت, _klj_, _lọ́w,
   {{0x25a91f49,0xb5fb0037,0x6e229942,0x2cbf008c}},	//   haal_, _dhái, _elob, ruud_,
   {{0xe807000f,0x25a941cb,0xa9a6185c,0xc4d000b6}},	//   शाना_, kaal_, линд, _सङ्ख,
   {{0xb5fb0080,0x68f602ad,0x6e229943,0x7a360d7c}},	//   _fhái, _pryd, _glob, ršto,
   {{0x25a95596,0x4423033b,0x7a260143,0xa3c30096}},	//   daal_, _olj_, _nóte, ःला_,
   {{0x68f60185,0x013600c1,0x395e00d9,0x59c6009d}},	//   _vryd, אָלט_, āts_, _वावर,
   {{0x18676ab3,0xa3aa000f,0x2cad00aa,0x3e4501d3}},	//   уари_, _गजब_, lsed_, nēto_,
   {{0x2bcf0714,0x25a90694,0xfbcf67d0,0x68f60150}},	//   त्रा, gaal_, त्रम, _tryd,
   {{0x05669944,0xfbb70557,0x30be0033,0x9f4c016d}},	// [a7e0] уван, _आयाम, _ইন্স, _cadê_,
   {{0x389b00f5,0xb97b006e,0x889b0266,0x99e40094}},	//   _ריינ, _אנפי, _רביי, čňuj,
   {{0x3ce50067,0x81e80081,0x25a99945,0xe2972246}},	//   _जैसे_, বাস_, baal_, гах_,
   {{0x69c664ea,0x2cad00aa,0x25a986d6,0x6447083e}},	//   ngke, ksed_, caal_, _ejji,
   {{0x9f450575,0xa3cf02d5,0x3e4c00b6,0xc05a01b3}},	//   _dalí_, _वॉक_, něte_, нік_,
   {{0x6e220206,0x2d8f02ac,0xd0070c59,0x7d0401f7}},	//   _slob, _afge_, лече_, _àisi,
   {{0x444474e6,0x94230950,0x64435c56,0x201c1c56}},	//   mn_, _умре, čnit, rkvi_,
   {{0x443a9946,0x44443514,0xb5fb00e3,0x201c077e}},	//   lip_, ln_, _phái, skvi_,
   {{0x44449947,0x7e6b0023,0xdb080131,0xa9240094}},	//   on_, _dhgp, cadê, ážli,
   {{0x44446966,0x443a9948,0x60c22361,0x76448643}},	//   nn_, nip_, muom, hniy,
   {{0x44449949,0x25a90694,0xe45700c1,0x2cad00a1}},	//   in_, yaal_, רייט_, ased_,
   {{0xc33317f5,0x6eca01d4,0xb5fb0080,0x443a994a}},	//   מות_, _qəbu, _thái, hip_,
   {{0x443a994b,0xdddb07aa,0x25a9994c,0xddc9026a}},	//   kip_, lmuş, vaal_, lleş,
   {{0x4444994d,0x443a06a3,0x8c4310f7,0x9f4700b6}},	//   jn_, jip_, _лече, zdní_,
   {{0x25a91f49,0x7c3a091c,0xdddb0740,0x443a994e}},	//   taal_, mitr, nmuş, dip_,
   {{0x5eb90081,0x6eca0092,0x60c2994f,0x49560129}},	//   _আহমে, _həbs, kuom, ọtụ_,
   {{0x61e26351,0x25a958a6,0x7a26003e,0x44440d98}},	// [a7f0] deol, raal_, _fótb, fn_,
   {{0x7c3a1064,0xddc901e8,0x443a9950,0x25a96840}},	//   nitr, kleş, gip_, saal_,
   {{0x45d522d5,0x25a9159f,0x60db060b,0xf367100c}},	//   _конс, paal_, _spum, утан,
   {{0x7c3a0128,0x09e30081,0x61e29951,0x25a90188}},	//   hitr, যাকা, geol, qaal_,
   {{0x44445925,0x9f4700b6,0x26d10634,0x9f4500d4}},	//   bn_, rdní_, ltzo_, _valí_,
   {{0x660d257f,0xb5fb3072,0x62830146,0xdb03766d}},	//   ljak, _cháv, ínos, _fenè,
   {{0xdb0336e7,0x7c3a9952,0xdb017851,0x26d10634}},	//   _genè, ditr, talí, ntzo_,
   {{0xed59942b,0x645708a8,0xc33200a1,0x0d851cb1}},	//   кой_, loxi, _וול_, шлин,
   {{0x0c25450e,0xac850396,0x10d80602,0x60db024a}},	//   имин, јгол, _مبلغ_, _upum,
   {{0x2cad9953,0xdb019954,0x660d032c,0x62879955}},	//   rsed_, salí, hjak, _kujo,
   {{0x7f8416cc,0x81e80f71,0x2cad00a1,0x63a70087}},	//   _المن, বার_, ssed_, _mejn,
   {{0xc869040a,0x26c332e4,0x63a79956,0x62870052}},	//   _חן_, dujo_, _lejn, _mujo,
   {{0xeb8e192f,0x4444025e,0x443a01e8,0x62879957}},	//   _ми_, yn_, yip_, _lujo,
   {{0x7c280013,0x7c3a9958,0x63a7030b,0x9f4c022b}},	//   chdr, citr, _nejn, _badè_,
   {{0x44440939,0x81ab0081,0xcc3a00c1,0x28b2007a}},	//   vn_, _খান_, _בעסט, _जिकि,
   {{0x44449959,0xe8fa15de,0x64453dd1,0x6abc003e}},	//   wn_, _али_, enhi, árfe,

   {{0x6287025a,0x443a6994,0xddc901e8,0x63a7995a}},	// [a800] _aujo, tip_, zleş, _bejn,
   {{0x4444995b,0x6457002b,0x26c30a43,0xdddb03e0}},	//   un_, goxi, bujo_, ymuş,
   {{0x4444995c,0x63a7023e,0x67bb00a1,0x443a995d}},	//   rn_, _dejn, _במיק, rip_,
   {{0xe7d210e9,0x7d1b0517,0xdb03995e,0x4444995f}},	//   द्रप, kyus, _venè, sn_,
   {{0x61e29960,0x4444533d,0x859b00ca,0x272c0139}},	//   reol, pn_, _בשכו, _fóné_,
   {{0x443a00dd,0x20560c39,0x61e29961,0x60c2013f}},	//   qip_, штер, seol, ruom,
   {{0x212015f4,0x60c2022c,0x6e292819,0x62870027}},	//   ših_, suom, fheb, _gujo,
   {{0xfe6f00ab,0xddc901e8,0xdb0322bf,0xdddb071d}},	//   ودي_, rleş, _gené, rmuş,
   {{0x394d0067,0x9c4622f9,0x7c289962,0x44382fc6}},	//   żesz_, ихол, thdr, _kmr_,
   {{0x7ed600d6,0xdb030103,0x62809963,0x79840361}},	//   _відч, _zené, _himo, _agiw,
   {{0x752d3543,0x62809964,0x6bd800cd,0x645c0239}},	//   zzaz, _kimo, نوکس_, _mkri,
   {{0xdd8f0018,0xdb0308a8,0x7c3a0138,0x6cd60018}},	//   _قوم_, _xené, sitr, _نقصا,
   {{0x7c940080,0x62801b32,0x6fcd0557,0x3ea90039}},	//   _التص, _mimo, _सामू, ćate_,
   {{0xd83b00d3,0x79840361,0xdb08300f,0x44389965}},	//   тэм_, _egiw, hadé, _nmr_,
   {{0x63a70087,0xb5a7008f,0x660d9966,0x00000000}},	//   _rejn, ирай, tjak, --,
   {{0x4b7b0105,0x628011b9,0x6d5c0587,0x26d1016d}},	//   _באוו, _nimo, ğraf, rtzo_,
   {{0x9f45025b,0x69cd00b3,0xdb039967,0x62872c2a}},	// [a810] _malá_, _icae, _rené, _sujo,
   {{0x62809968,0x62879969,0x6e29996a,0x22460220}},	//   _aimo, _pujo, zheb, enok_,
   {{0x2d820220,0x2bd80403,0x6280996b,0x6672001c}},	//   ľkej_, ब्या, _bimo, تگیر,
   {{0x62870307,0x645c02f1,0xf8bf020d,0x9f4c0154}},	//   _vujo, _ekri, oré_, _gadé_,
   {{0x6280996c,0xb5fb0037,0x601400b3,0x68ed0090}},	//   _dimo, _dhát, _pàmp, _jsad,
   {{0x09e30081,0x7a262728,0xa3cf02d5,0xb97c0266}},	//   যাটা, _móta, _वॉच_, דנדי,
   {{0xdb03058a,0xdb01045e,0x31690031,0xb5fb0503}},	//   _tené, kalá, ťaz_, _fhát,
   {{0xf2d2040a,0x62801958,0xf8bf0094,0x2246037a}},	//   _מעל_, _gimo, kré_, cnok_,
   {{0x6e298cf6,0xbc19004b,0x7a260037,0x2bc20be4}},	//   rheb, гіні_, _nóta, _शाखा,
   {{0x40841440,0x628064e6,0x6e29996d,0x69cd0143}},	//   _футб, _zimo, sheb, _acae,
   {{0xdce707d1,0x4421996e,0x682b01d4,0x68ed996f}},	//   ımız, ikh_, _müdd, _asad,
   {{0xdb010018,0x6eca0092,0xf8bf0428,0xa5bb003e}},	//   galá, _təbr, fré_, _blóm,
   {{0xc9560084,0xf8bf0257,0x2d9f0239,0x7a3601d9}},	//   стны, gré_, mbue_, nšti,
   {{0x765d7447,0x2cbf2d96,0xd26400e8,0x00000000}},	//   _aksy, mrud_, miņš_, --,
   {{0xdb01026e,0xd62a1e58,0xf99f0451,0xdb0a02b6}},	//   balá, гове_, bbè_, _adfæ,
   {{0x645c0bc6,0xf8bf0074,0x44210694,0x7a360138}},	//   _skri, bré_, ekh_, kšti,
   {{0xcc8800ef,0x62809970,0x44389971,0xf8bf0257}},	// [a820] _lớn_, _rimo, _pmr_, cré_,
   {{0x9f470094,0x4adb262c,0x601d09c2,0xb5fb00da}},	//   zdná_, _बहाव, _fèmi, _bhás,
   {{0x2cbf01c2,0x2246497a,0x644b0349,0xb5fb00da}},	//   hrud_, tnok_, égia, _chás,
   {{0xd2590c10,0x44384567,0x00000000,0x00000000}},	//   аці_, _wmr_, --, --,
   {{0x25a003b4,0x62801f84,0x44380503,0xdb080103}},	//   mbil_, _vimo, _tmr_, radé,
   {{0x645c9972,0x25a02303,0x44389973,0x98a2007f}},	//   _ukri, lbil_, _umr_, czką_,
   {{0x62809974,0x09b20081,0x62980094,0xdb0101f9}},	//   _timo, য়্যা, ívod, yalá,
   {{0xa5bb0139,0x25a0040f,0x3f8501ff,0x62805ab2}},	//   _alój, nbil_, _eglu_, _uimo,
   {{0xc5f300ca,0x53cf02d5,0x65bf0065,0x9f470206}},	//   לדה_, स्कश, _hàhà, rdná_,
   {{0xf8bf0257,0x20d2020a,0xc04602d1,0x00000000}},	//   vré_, mâi_, _اخرو, --,
   {{0xdb019975,0x7a263912,0x5f760037,0xddc94056}},	//   talá, _sóta, _طائر, smeš,
   {{0x5d860080,0xf8bf9976,0x2cbf7d57,0xd37b021e}},	//   _الإل, tré_, brud_, טריט,
   {{0xfdf700a1,0x44219977,0xf8bf3ece,0xdb010103}},	//   _לצאת_, ykh_, uré_, ralá,
   {{0xf8bf9978,0x7a269979,0x96eb5566,0x68ed1b32}},	//   rré_, _vóta, льба_, _vsad,
   {{0x6fda000f,0x501b00a1,0xdc3b00c1,0x35960134}},	//   प्यू, נולו, _געגר, _ọbụ_,
   {{0xe8d90028,0x68ed0044,0x7e9101d3,0x682b2f2b}},	//   _ngủ_, _tsad, _jāpa, _südd,
   {{0x68ed0b0b,0x2bcf0635,0x3a2900f9,0xb5fb00da}},	// [a830] _usad, त्का, _ilap_, _shás,
   {{0x44276ba1,0x3ce0000f,0x97a700d3,0xb4e91b11}},	//   ón_, _कहने_, _урил, _मनी_,
   {{0x3a297540,0xfa8900de,0x648905db,0xb5fb033c}},	//   _klap_, _lẫn_, _ožig, _dhár,
   {{0xa5f92e91,0x925900c2,0x1fb3023a,0x98a2007f}},	//   _тему_, шает_, ील्ड, szką_,
   {{0x7a360106,0x00000000,0x00000000,0x00000000}},	//   ušti, --, --, --,
   {{0xd5bf01d3,0x7a360138,0x1e950582,0x9f5e034f}},	//   žādu_, ršti, орир, _notó_,
   {{0xa49b01ec,0xb4e933dc,0x2ca601ee,0x3e4500e8}},	//   _bròg, _मनु_, _awod_, lēti_,
   {{0x7a3600e9,0x82340246,0xd26400e8,0xfe6e0d83}},	//   pšti, _فرقا, tiņš_, نگن_,
   {{0x9f5e0428,0x64890a39,0x224d03a9,0x81450103}},	//   _botó_, _džig, _ijek_, _بچان,
   {{0xfa8900ef,0x2ca9003d,0x5ba93a69,0x9f5e015e}},	//   _dẫn_, _ħadd_, шком_, _cotó_,
   {{0xcb697d1d,0x2cbf00f3,0x9ac5010a,0xbfb40076}},	//   ране_, srud_, kiŋŋ, _رحلت,
   {{0x2483029a,0x2ca605aa,0x6b9c0233,0x00000000}},	//   _lijm_, _fwod_, ırga, --,
   {{0xa3aa1fe6,0x9f5e0103,0x9f4500b3,0x224d0052}},	//   _गजल_, _fotó_, _balç_, _mjek_,
   {{0x307900c1,0x9f4500ee,0xeb99182e,0x224d0357}},	//   יאָנ, _calç_, _тик_, _ljek_,
   {{0x224d0194,0x98ab01d3,0x4b79006e,0x68e1020a}},	//   _ojek_, ājās_, _דאַו, ălda,
   {{0xb5fb0037,0x682b042c,0x6d4a00c4,0x63700139}},	//   _shár, _rüde, šmaš, _lóní,
   {{0x3ea0005f,0x25a077b9,0x94050789,0xa70a0033}},	// [a840] ćiti_, rbil_, रांच_, রনেম_,
   {{0x25a077b9,0x224d0113,0x7d040037,0xa6e61cf2}},	//   sbil_, _ajek_, _áise, _джол,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20057149,0x20d200ae,0x25ab009c,0x7a26003e}},	//   _anli_, tâi_, _gecl_, _móto,
   {{0x63700065,0xa49b01b9,0x9f5e0036,0x601d00b3}},	//   _bóní, _cròd, _notò_, _lèmu,
   {{0x224d005c,0x6489015c,0xdb01016d,0x443e0103}},	//   _ejek_, _džid, calç, _öt_,
   {{0xdb032df7,0x9f4c3411,0x09b00033,0x73f9006e}},	//   _bení, _andò_, _কানা, _פּשו,
   {{0xdb0300b6,0x629e80b5,0x00000000,0x00000000}},	//   _cení, mppo, --, --,
   {{0xdb03030b,0x629e00c2,0xecfa0033,0x6489033b}},	//   _dení, lppo, েন্স_, _vžig,
   {{0xfa890028,0x69c0997a,0x60c2997b,0xbfc30b1b}},	//   _vẫn_, ómen, mrom, _обук,
   {{0x7e9100d9,0xdb0300b3,0x9f5e034f,0x37d00033}},	//   _tāpa, _fení, _votó_, াজার,
   {{0x2d920b88,0xed5a0245,0x0dc70752,0xbf16009f}},	//   _üye_, _кое_, _души_, तहीन_,
   {{0x9f5e997c,0xb4e934fd,0xc9840c5b,0xe80709c4}},	//   _totó_, _मने_, дури, शाला_,
   {{0xe8d9997d,0x442a35b0,0x2a60010a,0x601d00b3}},	//   _ngụ_, _nlb_, _ekib_, _fèmu,
   {{0x261c054f,0x5694313c,0x60c2997e,0x24830381}},	//   _níos_, даст, hrom, _rijm_,
   {{0x60c20074,0x442a997f,0xe8d90129,0xb5fb0146}},	//   krom, _alb_, _agụ_, _cháp,
   {{0x98be002d,0x60c209ac,0x6b8d00a7,0x057705bc}},	// [a850] ătă_, jrom, _şagi, زارد,
   {{0x60c28e81,0x442a0019,0xf36763df,0x3e4501d3}},	//   drom, _clb_, отен, rēti_,
   {{0x261c0037,0x442a058f,0x00000000,0x00000000}},	//   _cíos_, _dlb_, --, --,
   {{0x9f4c015e,0xcb130266,0xa49b00b3,0x249905db}},	//   _cadí_, ולע_, _pròd, _ttsm_,
   {{0x26080e72,0x09b00033,0x248301cb,0xae091358}},	//   हारी_, _কামা, _tijm_, वासन_,
   {{0x442a0134,0xd3e300d0,0x261c0042,0xf8bf0103}},	//   _glb_, _تقسی, _fíos_, lzés_,
   {{0xd00e00e3,0x224d01c5,0xdb03030b,0x44ed6559}},	//   الى_, _tjek_, _pení, _hž_,
   {{0xdb081e0a,0x3e61003e,0x44ed7b43,0x9258007b}},	//   gadí, jótt_, _kž_, _даст_,
   {{0xdb033539,0xa5bb0076,0x44ed74b7,0xb4e90374}},	//   _vení, _clói, _jž_, _मनो_,
   {{0x1fa70f80,0x20050270,0x98a20034,0x2a6002b6}},	//   _фраг, _unli_, czkę_, _skib_,
   {{0xa3dd68b9,0xdb036117,0x98b01419,0xab65457f}},	//   थ्य_, _tení, đača_, явол,
   {{0x9f5e0451,0x7c2a225b,0xbef7023a,0x00000000}},	//   _totò_, _elfr, ंटीन_, --,
   {{0x787202b6,0x601d022b,0xdb0a0383,0x9aa50d7f}},	//   hæve, _fèmt, _lefè, _کمبو,
   {{0x3ce000a5,0x261c00e3,0xfe7900b6,0xdb030231}},	//   _कहते_, _níor_, lmů_, _venâ,
   {{0x44ed0871,0x91cc030b,0x09b00033,0x26081ae6}},	//   _až_, _हालै, _কাঠা, हाली_,
   {{0x261c9954,0x00000000,0x00000000,0x00000000}},	//   _ríos_, --, --, --,
   {{0x261c0080,0x6adb1cd4,0x9f4c0146,0xdb1805aa}},	// [a860] _síos_, _बहुर, _radí_, _advè,
   {{0x44ed4121,0x29009980,0xb46328ce,0x7a26003e}},	//   _dž_, _iria_, екул, _mótm,
   {{0xa49b009c,0xf8bf0103,0x38c201cd,0x00000000}},	//   _cròb, szét_, _færð_, --,
   {{0x7aba00a1,0xcc880019,0x64893df1,0xfe7900b6}},	//   מצעו, _sớm_, _džib, jmů_,
   {{0x26d89981,0x261c00e3,0x442a0270,0xa5bb0065}},	//   ltro_, _fíor_, _tlb_, _alów,
   {{0x261c5bef,0xd7dc1462,0x442a00fc,0x00000000}},	//   _tíos_, यभिच, _ulb_, --,
   {{0xdb0804d3,0x26ca06a8,0x60c29982,0x626602a3}},	//   tadí, nubo_, srom, _فارق,
   {{0x60c29983,0x682b0f28,0x29009984,0x26c50039}},	//   prom, _müda, _oria_, šlog_,
   {{0xdb089653,0x628e9985,0x80a61f11,0xb1260294}},	//   radí, _hubo, _رمان, ọọdụ_,
   {{0x628e3f68,0x26ca5784,0xdb0800d8,0x8cbd0085}},	//   _kubo, kubo_, sadí, _शिरो,
   {{0x28af000f,0x29009986,0xdb081097,0xfd0f00cd}},	//   जीनि, _aria_, dadã, نجی_,
   {{0x645e3315,0x628e2d3b,0xdb030161,0x29000154}},	//   hopi, _mubo, _senã, _bria_,
   {{0x628e9987,0x29006e38,0x7e629988,0x26d8028d}},	//   _lubo, _cria_, _ikop, etro_,
   {{0xb8f59989,0x629c998a,0x645e02f7,0x63ae01b9}},	//   _हम_, _otro, jopi, _nebn,
   {{0x628e1741,0x26ca998b,0x44ed033b,0x45d50497}},	//   _nubo, gubo_, _sž_, мовс,
   {{0xade20789,0x2900998c,0x3e4501d3,0xee4900fe}},	//   _कॉमन_, _fria_, bētu_, hẽn_,
   {{0x629c282c,0x68300149,0x7e620239,0xf8bf0103}},	// [a870] _atro, _bädd, _mkop, rzés_,
   {{0x628e28e6,0x26ca07ac,0x44ed3ead,0xdb180131}},	//   _bubo, bubo_, _vž_, _advé,
   {{0x41d100a5,0x26ca0451,0x628e3536,0xf8bf0103}},	//   _हादस, cubo_, _cubo, pzés_,
   {{0x628e02e6,0x69cf019f,0x23740103,0x6fda02d5}},	//   _dubo, ngce, رالح, प्सू,
   {{0x44ed998d,0xdb0a0072,0x629c7f90,0x99890a39}},	//   _už_, _defé, _etro, _omaž_,
   {{0x442502e0,0x23c304ea,0x9f4718ed,0x7a360181}},	//   _ôl_, _déjà_, lené_, nštr,
   {{0x764d0188,0x628e250c,0x3e4500e8,0x00000000}},	//   onay, _gubo, zētu_, --,
   {{0xdb03998e,0x764d998f,0x9f470220,0x69dd01c0}},	//   _nená, nnay, nené_, jfse,
   {{0xdb0130ca,0x9f5e00b3,0x764d0188,0x628e45ca}},	//   mblé, _entà_, inay, _zubo,
   {{0x09c6009d,0x4b2500d6,0x683000c2,0x60cb06a8}},	//   वल्य, дмов, _käde, mugm,
   {{0x69dd03bd,0xdb030146,0x60cb9990,0x68e44a62}},	//   ffse, _bená, lugm, _spid,
   {{0x2900009d,0x25740102,0x9f47025b,0xdb030f3f}},	//   _pria_, _júlí_, jené_, _cená,
   {{0x9f470038,0x645e0010,0x682b9991,0x683000a2}},	//   dené_, yopi, _süda, _läde,
   {{0x3e450029,0xaac507e2,0x26d8013d,0x7e697a1a}},	//   rētu_, _विपक, ttro_, llep,
   {{0x68300222,0x2ba30179,0x25b200f9,0x27e10062}},	//   _rädd, _ख्या, tayl_, _dbhn_,
   {{0x290005fe,0x764d4ea7,0x628e9992,0x26d80ac9}},	//   _tria_, gnay, _rubo, rtro_,
   {{0x629c9993,0x628e00e9,0x2bd40251,0x29008045}},	// [a880] _stro, _subo, _दामा, _uria_,
   {{0xd7ca00cd,0x6d440220,0x764d0188,0x60cb0124}},	//   _بوده_, _žiak, anay, dugm,
   {{0x645e9994,0x9f470074,0x26ca019f,0x7e695de7}},	//   ropi, bené_, qubo_, klep,
   {{0x7e692f29,0x63ae9995,0x9f4700b6,0x61eb9996}},	//   jlep, _webn, cené_, gegl,
   {{0x5fc904a9,0x63ae023e,0x60cb02c9,0x645e0171}},	//   _राखल, _tebn, gugm, popi,
   {{0x7e629997,0x628e9751,0x7e6918ef,0x7524715a}},	//   _skop, _tubo, elep, myiz,
   {{0x44449998,0x629c69a4,0x61eb46a1,0x6383677f}},	//   mi_, _utro, begl, _агра,
   {{0x64892461,0x7e699999,0x61eb0234,0x4e770037}},	//   _užic, glep, cegl, وحيد_,
   {{0xdb080933,0x75240283,0x01d7029e,0x016313f5}},	//   dadá, nyiz, _توقع_, _акто,
   {{0x4444999a,0x9f470618,0xdb030146,0x5b140a54}},	//   ni_, zené_, _sená, емот,
   {{0xcc88011b,0x4444999b,0x764d0694,0xdb0300d4}},	//   _mới_, ii_, ynay, _pená,
   {{0x7e6234d9,0xb5fb0065,0xdb080103,0x27e100f9}},	//   _ukop, _akán, gadá, _sbhn_,
   {{0x9f47135f,0x69dd0088,0x7e60999c,0x69cf01cb}},	//   vené_, rfse, momp, rgce,
   {{0x61eb0067,0x7e601bd6,0x601d03a9,0x68fd0537}},	//   zegl, lomp, _jèmp, rvsd,
   {{0x290d002d,0x2bf3009d,0x9f47768a,0x3e4501d3}},	//   ţea_, _असतं_, tené_, cēts_,
   {{0x4444999d,0xf1b90146,0x66160052,0x7e60673f}},	//   ei_, _koše_, gjyk, nomp,
   {{0x4444999e,0x9f470181,0x764d0188,0x96010033}},	// [a890] fi_, rené_, rnay, _একদম_,
   {{0x7e690094,0x9f472347,0x683000aa,0xcc8800fe}},	//   zlep, sené_, _päde, _bới_,
   {{0xf1b902e6,0x6489013f,0x9f470244,0xf367007e}},	//   _loše_, _džia, pené_, фтан,
   {{0x4444999f,0x7d0299a0,0x68300149,0x60cb2783}},	//   ai_, _oros, _väde, tugm,
   {{0x0ef700a5,0x798d0239,0x0ef902d5,0xd009636a}},	//   ंट्स_, _mgaw, ्म्स_, зеле_,
   {{0x61eb02dd,0x160d009d,0x661d02ac,0x78ad0453}},	//   segl, हावर_, _hosk, _mwav,
   {{0x661d02fd,0x644594a0,0x7e692a2a,0x61eb99a1}},	//   _kosk, mihi, tlep, pegl,
   {{0x7d0299a2,0x64455c5e,0x798d09e7,0x661d0084}},	//   _bros, lihi, _ngaw, _josk,
   {{0x661d5a72,0x7e69063f,0xdfdb013d,0x7d020fa7}},	//   _mosk, rlep, _мъж_, _cros,
   {{0xa2c402e8,0x7d0299a3,0x644599a4,0x7e6999a5}},	//   ांच्, _dros, nihi, slep,
   {{0x7d026510,0xdb031794,0xdb08109d,0x7e693500}},	//   _eros, _menç, tadá, plep,
   {{0x444499a6,0x644599a7,0xb87b0e4d,0x661d22c9}},	//   zi_, hihi, ntíf, _nosk,
   {{0xdb0899a8,0xfce502ec,0x644599a9,0xad2715f8}},	//   radá, _чоло, kihi, _تراو,
   {{0x6e29038c,0x644508cc,0x798d039f,0x444499aa}},	//   lkeb, jihi, _egaw, xi_,
   {{0x44440213,0x2edd04f8,0x6445008a,0x66e38d01}},	//   vi_, _महोत, dihi, лора,
   {{0x4444971c,0x62890034,0x2b1c030b,0x6e290407}},	//   wi_, _nieo, महरु_, nkeb,
   {{0x661d2ac2,0x69d60193,0xdb03016d,0x78ad520f}},	// [a8a0] _dosk, _icye, _benç, _gwav,
   {{0x44442421,0x7644399b,0x644599ab,0x394d0042}},	//   ui_, siiy, gihi, úese_,
   {{0xa68605e1,0x6e292b31,0x7e60628e,0xf2a699ac}},	//   _плод, kkeb, yomp, хиеп,
   {{0xcc88011b,0x09c70081,0x3ce00006,0x63a311bc}},	//   _với_, ষ্ঠা, _कहले_, ınna,
   {{0x44440479,0x47b300c7,0x644599ad,0xa06a0326}},	//   pi_, _জাতী, bihi, пада_,
   {{0xcc8800ef,0x444499ae,0xdb0301e8,0xf1b900e7}},	//   _tới_, qi_, _genç, _roše_,
   {{0x7e60001c,0xdb0a052f,0x27fa020a,0x2bb600b6}},	//   tomp, _udfø, _mapn_, _आजबा,
   {{0x6fd22235,0x5fd20096,0xb87b5593,0x00000000}},	//   _सावं, _सावल, ctíf, --,
   {{0x02e0030b,0xfd1204f4,0x2bd40296,0xa49b009c}},	//   _नहुन, اجع_, _दादा, _lròn,
   {{0x69d60169,0xf1b9007e,0x7d1d0212,0x78ad0079}},	//   _acye, _voše_, ässa, _rwav,
   {{0x200c99af,0xaa591229,0x3a752cbf,0x7c2801cb}},	//   _indi_, дину_, клор, rkdr,
   {{0x7d0299b0,0xfe7212eb,0x200c06a8,0x644587cb}},	//   _tros, _صدا_, _hndi_, zihi,
   {{0x661d99b1,0x64450694,0xdca300d6,0x201e6c9a}},	//   _rosk, yihi, _бачи, _koti_,
   {{0xf9f10081,0xa49b01f7,0x201e99b2,0xdb030212}},	//   টাইল_, _bròn, _joti_, _benä,
   {{0x661d0ec8,0xadf405d4,0x201e99b3,0xa49b99b4}},	//   _posk, _आसान_, _moti_, _cròn,
   {{0xa5bb0065,0x27fa002b,0x201e99b5,0x78ad2cd0}},	//   _alór, _eapn_, _loti_, _twav,
   {{0x644599b6,0x78ad6afd,0x200c05db,0x22460062}},	// [a8b0] tihi, _uwav, _ondi_, diok_,
   {{0x201e2340,0xb4e10693,0xd37b261f,0xa5bb033c}},	//   _noti_, _दही_, пче_, _clór,
   {{0x644599b7,0xdb0319c7,0xdb180094,0x00000000}},	//   rihi, _venç, _odví, --,
   {{0x200c84d9,0x644599b8,0xb6ba00ca,0x787202b6}},	//   _andi_, sihi, _קצרי, nævn,
   {{0x25a911b9,0xa5bb99b9,0x683000aa,0x201e3f9d}},	//   mbal_, _flór, _häda, _boti_,
   {{0x289800a1,0xdb18002b,0xa5bb99ba,0x6aba01df}},	//   עדון_, _adví, _glór, kstf,
   {{0xf4560089,0xe45479a6,0x201e119f,0x4ac51b11}},	//   _יישר_, _скры, _doti_, _विधव,
   {{0x60c401b3,0x200c99bb,0x7e9101d3,0x682b3c84}},	//   šima, _endi_, _jāpi, _südl,
   {{0x320d008a,0x9f477a48,0xdb0a0042,0x201e0036}},	//   _iney_, mení_, _defí, _foti_,
   {{0x9f47000d,0xb5fb8110,0x6e290073,0x61fb99bc}},	//   lení_, _skál, skeb, _haul,
   {{0x68300006,0x61fb99bd,0xbf150177,0xb5fb0139}},	//   _näda, _kaul, _جواب, _akám,
   {{0x201e00dd,0x61fb99be,0x9f470220,0x25a90094}},	//   _zoti_, _jaul, není_, jbal_,
   {{0x25a92b15,0x29040e2e,0x91ba00ca,0x9f5e00c2}},	//   dbal_, íma_, ומרי, _entä_,
   {{0x61fb99bf,0x69a2332a,0x6d59063d,0xdb180206}},	//   _laul, _क्री, _ixwa, _zdví,
   {{0xf1b304f1,0x52d000bc,0x25a902ac,0xdb0320ab}},	//   ुणान, _हमेस, fbal_, _benå,
   {{0x9f470363,0xcfca0081,0xdb030084,0x61fb99c0}},	//   jení_, ল্পন, _venä, _naul,
   {{0x9f470074,0x443199c1,0xf8bf0103,0x60db99c2}},	// [a8c0] dení_, _blz_, lyén_, _nqum,
   {{0x03a60231,0x64890138,0x232a0d62,0xa49b99c3}},	//   тижо, _džio, мози_, _tròn,
   {{0x2bd4007d,0x61fb99c4,0x321f0139,0x160002d5}},	//   _दासा, _baul, _bouy_, _लोअर_,
   {{0x201e14b1,0x64890542,0xfb1a00c1,0x7229004d}},	//   _soti_, _užin, וועמ, нців_,
   {{0x201e99c5,0x61fb006d,0xdb0a03be,0x3a20016d}},	//   _poti_, _daul, _refí, _moip_,
   {{0x03a302ec,0x61fb01ff,0x2d8f02ac,0x6aba2405}},	//   _виро, _eaul, _agge_, ystf,
   {{0x201e3af8,0x04431c17,0xb87b99c6,0x9f47033d}},	//   _voti_, _терн, stíg, bení_,
   {{0x9f47000d,0x61fb99c7,0x2bd4030b,0x69a21179}},	//   cení_, _gaul, _दाहा, _क्ली,
   {{0x201e002d,0x9f490146,0x71660037,0x61e20e68}},	//   _toti_, čkám_, _شارك, mfol,
   {{0xfa8a0028,0x200c99c8,0xe9df0037,0x61e23b69}},	//   _mẫu_, _undi_, giún_, lfol,
   {{0x61fb024a,0x6ec507e8,0x25a90b8e,0x6d590372}},	//   _yaul, _متنق, ybal_, _exwa,
   {{0xf2d30130,0x61e27a5f,0x6d4400c6,0xda3500c2}},	//   סער_, nfol, _žiau, уемы,
   {{0x9f45025b,0xcc8800de,0x2e370327,0x2ba30409}},	//   _malý_, _bớt_, _בראש_, _ख्वा,
   {{0x9f47000d,0x36d533d0,0xf1b9007e,0x683041ba}},	//   zení_, логр, _moša_, _päda,
   {{0x25a999c9,0xf1b9005f,0x44310231,0x80cc0e4c}},	//   tbal_, _loša_, _rlz_, _समझे,
   {{0x61e299ca,0xe654004d,0xdb012ce2,0xb5a4007b}},	//   jfol, авсь, nalý, ируй,
   {{0x9f47000d,0x25a611ce,0x3ea902e6,0x44311aee}},	// [a8d0] vení_, ñola_, ćati_, _plz_,
   {{0x61fb359d,0x25a92b75,0x57f511f7,0xfa8a0023}},	//   _saul, sbal_, _спот, _dẫu_,
   {{0x61fb99cb,0x61e299cc,0x9f47035d,0xa3c40861}},	//   _paul, ffol, tení_, _एयर_,
   {{0x61fb005c,0x26d10415,0x61e201df,0x2c7948ae}},	//   _qaul, muzo_, gfol, mède_,
   {{0xdca600e3,0x9f470220,0x660f0a39,0xfa8a0023}},	//   _دى_, rení_, _inck, _gẫu_,
   {{0x9f47033d,0xf1b90234,0x61fb4788,0x2a6902c3}},	//   sení_, _doša_, _waul, _lkab_,
   {{0x61fb99cd,0x9f470363,0x2297023b,0x2bb60034}},	//   _taul, pení_, _uçk_, _आज़ा,
   {{0xc69400c1,0xd1bb03c5,0x78bd0b6a,0x00000000}},	//   סאפ_, _زارا_, kssv, --,
   {{0x7aea01b9,0x7a2601cd,0xf1b90aa8,0x4bd901b3}},	//   _apft, _mótt, _goša_, ньня_,
   {{0x6295641f,0x2a690383,0x6e9530cf,0x26d10b2a}},	//   _kuzo, _akab_, _бижу, kuzo_,
   {{0x2bd41e5e,0xcc880023,0xab290095,0xeab9147c}},	//   _दारा, _rớt_, хона_, эйн_,
   {{0xe9df00e3,0x629599ce,0x8bf30033,0xa14201d3}},	//   siún_, _muzo, জাইন_, _šķid,
   {{0xfd10012b,0x62950415,0xec6e0ef1,0x9f4c02c3}},	//   _وجه_, _luzo, _гп_, _vadå_,
   {{0xdb033890,0x7a261f1f,0x26d11937,0x6295014b}},	//   _menú, _rótu, fuzo_, _ouzo,
   {{0xae171860,0x61e299cf,0xcc880023,0xe9df003e}},	//   थापन_, yfol, _vớt_, gnús_,
   {{0x80c40fdd,0x67210486,0xe6436c6e,0x9f4500d8}},	//   _रिले, älja, бесп, _haló_,
   {{0x62950a00,0x7a26003e,0x316d0154,0x00000000}},	// [a8e0] _auzo, _dótt, _nyez_, --,
   {{0x26d10201,0x63b5031a,0x5fd2049d,0x41d10e52}},	//   buzo_, _cezn, _साइल, _हाउस,
   {{0xd62a3621,0x61e2004d,0x2c79020d,0x316d020d}},	//   _зоне_, tfol, cède_, _ayez_,
   {{0x78a4258e,0x7afc108e,0x9f4700b3,0xb87b00b3}},	//   _ktiv, ærti, denà_, rtíe,
   {{0xdb010146,0x7d1d042c,0xddc90031,0x9f470031}},	//   valý, ässl, mieň, rdný_,
   {{0xdb0325da,0x61e259c1,0xf1b90095,0x00000000}},	//   _denú, sfol, _voša_, --,
   {{0x629599d0,0xdb180146,0x9e14004d,0x316d0350}},	//   _guzo, _odvá, идкі, _eyez_,
   {{0x69c4023b,0x69d63542,0x7a2601cd,0x00000000}},	//   _ndie, _भाषी, _móts, --,
   {{0x2fd60080,0x8fa60f30,0x7c9e0134,0xd83f0087}},	//   _متاح, _базе, _bọọl_, ščih_,
   {{0x69c402a7,0x62820188,0x09bf034d,0x5ec30033}},	//   _adie, lmoo, ्ल्य, _শহরে,
   {{0x78a40396,0x2f5620da,0x6f930037,0x28b70006}},	//   _ativ, _стас, _المض, _अबहि,
   {{0xa2cc417a,0x00000000,0x00000000,0x00000000}},	//   _हिन्, --, --, --,
   {{0x9f470074,0xd90f12eb,0x69c40178,0x7a2601cd}},	//   mená_, سید_, _ddie, _rótt,
   {{0x9f470074,0x6282022e,0x69c499d1,0x6e2299d2}},	//   lená_, hmoo, _edie, _hoob,
   {{0x6e2299d3,0xae093b08,0xa3ca66d3,0x63b57306}},	//   _koob, वाचन_, ोलन_, _rezn,
   {{0x63b599d4,0xadf9099d,0x9f470220,0x69c02a10}},	//   _sezn, ्ययन_, nená_, ómet,
   {{0x6e2207b4,0xd3a70131,0x628299d5,0x26d10350}},	// [a8f0] _moob, греп, dmoo, suzo_,
   {{0x68ed99d6,0x69c40181,0xdb032f0b,0x290900e7}},	//   _ipad, _zdie, _renú, _iraa_,
   {{0xe29800d6,0x64890138,0xf8bf00fd,0xb87b002b}},	//   гає_, _užim, lsé_, ptíb,
   {{0x6e2299d7,0xa4d516dd,0x68ed005c,0x9f470146}},	//   _noob, _комі, _kpad, jená_,
   {{0x90e4012b,0x9f47135f,0xf8bf99d8,0x629a0257}},	//   مسون, dená_, nsé_, _éton,
   {{0x4394376f,0x41260084,0x1aeb0081,0xf8bf00fd}},	//   _гарс, рошо_, টিতে_, isé_,
   {{0x6e2299d9,0x59c5009d,0xc7d80089,0x64470113}},	//   _boob, वणार, אווי_, _imji,
   {{0x6e2235a1,0x9f450428,0x44230410,0x00000000}},	//   _coob, _saló_, _hoj_, --,
   {{0x44231071,0x61e999da,0x6d440220,0x6e2299db}},	//   _koj_, _ibel, _žiar, _doob,
   {{0x442302e6,0x3ce50d0b,0xa0c400e3,0x1c4524e9}},	//   _joj_, _कहीं_, _ديكو, рном,
   {{0x44238cb6,0x68ed99dc,0x6e2299dd,0x9f4599de}},	//   _moj_, _apad, _foob, _való_,
   {{0x442301bb,0x6e220694,0xa2d6245a,0xfe9a00a1}},	//   _loj_, _goob, मंत्, _סינמ,
   {{0x61e999df,0xdb0199e0,0x67210149,0xe8f721b9}},	//   _mbel, taló, äljn, аля_,
   {{0x80cd0e72,0x442301bb,0xc052006e,0xcb6900ae}},	//   _सिने, _noj_, ַזן_, _иале_,
   {{0x61e999e1,0xbb427db1,0x7c231ac3,0x2cbf0036}},	//   _obel, _мешк, _ionr, lsud_,
   {{0x7c2308ec,0x69c499e2,0x656f9829,0x61e90134}},	//   _honr, _udie, _bych, _nbel,
   {{0xa4465781,0x656f0150,0x78a40027,0x00000000}},	// [a900] анад, _cych, _utiv, --,
   {{0x61e999e3,0x442301bb,0x656f4a73,0x9f47033d}},	//   _abel, _coj_, _dych, zená_,
   {{0xb87b99e4,0x2bdd1e9f,0x62823bea,0x442379c6}},	//   stíc, _माना, tmoo, _doj_,
   {{0x27ed02e6,0x2cbf7076,0xcc880028,0x91e62f11}},	//   đene_, ksud_, _lớp_, роде,
   {{0x628299e5,0x9f47025b,0x6f08135f,0x6e220188}},	//   rmoo, vená_, _srdc, _roob,
   {{0x61e999e6,0x6e2299e7,0x3ec60084,0x4423011e}},	//   _ebel, _soob, асиб, _goj_,
   {{0x6e2299e8,0xb87b04d8,0x9f45028d,0x9f472347}},	//   _poob, ntía, _salò_, tená_,
   {{0x4423022e,0x2fc5002b,0x81e40081,0x25a099e9}},	//   _zoj_, _edlg_, _ভোর_, ncil_,
   {{0x80a609b4,0x442301fa,0x10a318fa,0x9f470220}},	//   _ضمان, _yoj_, _митн, rená_,
   {{0x7c2399ea,0x9f470e43,0x2eec0350,0x6e2200fc}},	//   _conr, sená_, _tpdf_, _woob,
   {{0x64890580,0xdfcf0037,0x290501d3,0x9f470094}},	//   _džih, _زين_, ālam_, pená_,
   {{0xfce6014d,0xade22918,0x26c5838a,0x80cd231a}},	//   _водо, क्शन_, álom_, _सिमे,
   {{0xf99f05fe,0x984b008f,0xf8bf014b,0x00000000}},	//   rcè_, вява_, usé_, --,
   {{0x656f000d,0x2bdd046e,0x26c50335,0xf8bf99eb}},	//   _rych, _माया, šlom_, rsé_,
   {{0x44230197,0xf8bf87e1,0x87041612,0x656f99ec}},	//   _roj_, ssé_, ояте, _sych,
   {{0x4423022e,0x7a360138,0x9f5e0231,0x290913ea}},	//   _soj_, kšty, _patê_, _traa_,
   {{0x44230197,0xdb1a023b,0xd4981603,0xf4850018}},	// [a910] _poj_, katë, арх_, مائی,
   {{0x656f0618,0x442399ed,0x61e909a4,0x7c3a0023}},	//   _vych, _qoj_, _sbel, nhtr,
   {{0xd7dc05d4,0x44230531,0xed5902e6,0x656f00a5}},	//   _बातच, _voj_, maže_, _wych,
   {{0xed59042d,0x44230034,0x67280212,0x656f99ee}},	//   laže_, _woj_, ädje, _tych,
   {{0x442399ef,0x3ce50251,0x181a04c6,0x91050d9b}},	//   _toj_, _कहें_, _شریک_, спле,
   {{0x73c50037,0xdb1a0216,0x3dc601ee,0x64470372}},	//   _ديسم, gatë, _adow_, _umji,
   {{0x752d2ea0,0x249900dc,0xbf0100c3,0xf8380327}},	//   lyaz, _husm_, लटेन_, שנות_,
   {{0x7c2399f0,0x764d0da3,0x61e9339e,0xdb1a99f1}},	//   _sonr, niay, _ubel, patê,
   {{0xdd9100fb,0xeb991b4d,0x9f5e06a3,0x752d39af}},	//   _ہوا_, лип_, _latè_, nyaz,
   {{0x7c3a33aa,0x6a7622a4,0x4ee700d6,0xa49b01ec}},	//   ghtr, táfo, _відз, _cròi,
   {{0x26c508a9,0x9f5e0113,0x7ded00c6,0xf8bf0113}},	//   šloj_, _natè_, _pėsč, byék_,
   {{0x8d9500e3,0x764d1b63,0xf1b90e9e,0x752d0361}},	//   _الإش, jiay, _ješ_, kyaz,
   {{0xbca500cd,0x764d8e40,0x00000000,0x00000000}},	//   _امتي, diay, --, --,
   {{0x7c3a99f2,0xf1b901ac,0x07a3766f,0x7d1b01fa}},	//   chtr, _leš_, зарн, mxus,
   {{0xe737139c,0x2ca60124,0xf1d8750e,0x752d010a}},	//   бер_, _ztod_, _डालन, eyaz,
   {{0xf1b999f3,0xb87b1d32,0x9f5e0154,0xe9da3715}},	//   _neš_, rtía, _datè_, _ски_,
   {{0xe57a1a77,0x25a01428,0xb87b0610,0x15b900c6}},	// [a920] уза_, rcil_, stía, рысы_,
   {{0x8ccf00a5,0x9f471b27,0x09b00033,0xdce901d3}},	//   _दिनो, cenç_, _কাটা, dceļ,
   {{0xfdf907ad,0xdb0a02e2,0xadf9000c,0x764d02e7}},	//   ्यास_, _gefä, ्यान_, biay,
   {{0xd5b90084,0xd186307f,0xf1b90357,0x3e7a0052}},	//   _всё_, блей, _ceš_, këta_,
   {{0x69db00c1,0x9c820087,0x6e3b0239,0x51185e6f}},	//   אַוו, ščil, dhub, ролю_,
   {{0x64a31af8,0x33d502ec,0x660499f4,0xdfcf0080}},	//   _хара, _міст, ldik, فيه_,
   {{0x2ca60501,0xe8193245,0x28d80179,0x81c20081}},	//   _stod_, दाता_, भूति, ্ভব_,
   {{0x660499f5,0x91e330cc,0x6e3b259e,0xdddb11bc}},	//   ndik, _носе, ghub, rluş,
   {{0xe1230231,0x09df0033,0xbd440037,0xa49b01b5}},	//   _емти, _বোঝা, تنظي, _pròi,
   {{0x60c299f6,0x44380167,0xdb1a0052,0xa3ca058f}},	//   msom, _jlr_, qatë, ोलि_,
   {{0x6e961823,0x60c20407,0x7d0b1044,0x2c1a2171}},	//   _الصا, lsom, _ergs, बाबू_,
   {{0x7c3a00dd,0xc333028c,0x60c299f7,0x63be005c}},	//   shtr, פור_, osom, hapn,
   {{0x63be2f6b,0x60c248ae,0x9e6500e3,0xa3ca7674}},	//   kapn, nsom, _بالن, ोला_,
   {{0x60c21019,0x9f5e0036,0xdb1a00d4,0xddc90234}},	//   isom, _patè_, haté, mleš,
   {{0x63be0808,0x9f4799f8,0x9f5e0139,0x2bdd142e}},	//   dapn, renç_, _baté_, _माता,
   {{0xed591d67,0x4438009c,0x66041ef8,0x60c299f9}},	//   saže_, _alr_, gdik, ksom,
   {{0x5fc82fc2,0x44380063,0x6fc80096,0x6d4099fa}},	// [a930] रणाल, _blr_, रणां, nzma,
   {{0x7bda99fb,0x443899fc,0xaca40134,0x63be0808}},	//   ngtu, _clr_, _adịz, gapn,
   {{0x628002ef,0xd37b4a54,0x319e0294,0x645c00b3}},	//   _bhmo, уча_, _ịza_, _djri,
   {{0x62801528,0x9f5e0154,0xdb1a03a9,0x443807ee}},	//   _chmo, _gaté_, gaté, _elr_,
   {{0xf1b960d1,0x60c2093e,0x22a100c6,0xd14b0286}},	//   _veš_, gsom, _dėka_, دشان_,
   {{0xc60100c7,0x9ea90870,0xd0090183,0xdb1a00bf}},	//   _একটা_, авка_, реке_, patè,
   {{0x62350084,0x6e3b4b62,0x7e69084e,0xd24e0103}},	//   _деву, thub, toep, رچہ_,
   {{0x8237212c,0x7bda0305,0xdb1a037a,0x4e290b21}},	//   _ارسا, egtu, caté, роин_,
   {{0x6e3b06ee,0x7e69043e,0xddc90087,0xee36036c}},	//   rhub, roep, gleš, інь_,
   {{0x6e3b99fd,0x7e690085,0x9f47007b,0x660499fe}},	//   shub, soep, tenä_, zdik,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3cfd0d7d,0xa2cc1784,0x6e3b0060,0x7bda022e}},	//   _tswv_, _हिस्, qhub, agtu,
   {{0xb87b0af3,0x9f470084,0x63be02e7,0xcd2b0bf4}},	//   rtín, senä_, yapn, _حسان_,
   {{0x6e39023e,0x6288028d,0xdb1a0103,0x9f5e00d1}},	//   _hlwb, _èdov, zaté, _saté_,
   {{0x7d0999ff,0x96955bee,0x660400a7,0x2cad00d7}},	//   lves, зруш, tdik, lped_,
   {{0x27ed02e6,0x85054ff1,0x60c47d2b,0x63be0063}},	//   đena_, रिंट_, šimi, wapn,
   {{0x6604783e,0x63be9a00,0x142619cb,0x3d0c00a3}},	// [a940] rdik, tapn, одам, ़िये_,
   {{0x2aed00af,0xf202009f,0xf7720281,0xb5fb0139}},	//   _जहाँ_, _रोज़_, _ياد_, _ajád,
   {{0x6d4026a1,0xf1b904e9,0xdb1a5635,0x4438014b}},	//   zzma, _gošk_, taté, _vlr_,
   {{0xe4da00cd,0x60c2348f,0x26d805bd,0x27f84a83}},	//   _پوست_, tsom, muro_, lern_,
   {{0xdb1a9a01,0x208a01ce,0x60c2013f,0x26d800f0}},	//   raté, айди_, usom, luro_,
   {{0x60c234cb,0x2900061d,0x27f8160c,0x7d099a02}},	//   rsom, _msia_, nern_, dves,
   {{0x71a605e1,0x26d89a03,0x62a22347,0x63bc00ae}},	//   _мавз, nuro_, útoč, _iern,
   {{0x27f89a04,0x69d62ebd,0x629c00f9,0x64890138}},	//   hern_, _भागी, _iuro, _džiu,
   {{0x629c9a05,0x27f89a06,0x80c40789,0x7d09905a}},	//   _huro, kern_, _रिटे, gves,
   {{0x629c9a07,0x26d89a08,0x63bc0170,0x27f89a09}},	//   _kuro, kuro_, _jern, jern_,
   {{0x629c00c9,0xa3e204dd,0x63bc9a0a,0x68e446c3}},	//   _juro, _धान_, _mern, _aqid,
   {{0x26d89a0b,0x629c9a0c,0x64899a0d,0x63bc02e2}},	//   duro_, _muro, _uživ, _lern,
   {{0x320400a5,0x27f89a0e,0x8b0700b6,0xa5bb0072}},	//   _mamy_, fern_, _poří, _ilóx,
   {{0x27f83224,0xb87b0037,0xdb189a0f,0xeb4a0103}},	//   gern_, rtío, _levé, _پشتو_,
   {{0xd5bb7ce1,0x629c013f,0x29005266,0x26c59a10}},	//   иса_, _nuro, _esia_, élo_,
   {{0x26cd02e6,0xed590d5d,0xdb1855a8,0xb5fb06f0}},	//   čeo_, laža_, _nevé, _akár,
   {{0x63bc9766,0xdb0304d8,0x629c9a11,0x98a200a5}},	// [a950] _bern, _fenó, _auro, tyką_,
   {{0xf1d868b9,0x63bc9a12,0x26d89a13,0x80c42397}},	//   _डाउन, _cern, buro_, _रिजे,
   {{0x63bc9a14,0xb87b7ddd,0x26d89a15,0x7d0913e8}},	//   _dern, ntím, curo_, zves,
   {{0x629c9a16,0xf1b9010f,0x3206019c,0xb5fb0139}},	//   _duro, _koši_, gdoy_, _ekár,
   {{0x361a040a,0xddc800a5,0xdb180072,0xed59007e}},	//   _הורד, łośc, _devé, kaža_,
   {{0x63bc9a17,0x629c7cc3,0x7bce10d9,0xdb089a18}},	//   _gern, _furo, óbul, nadó,
   {{0x629c9a19,0xf1b90106,0x9f470031,0xa49b015e}},	//   _guro, _loši_, lenú_, _eròt,
   {{0xf1bf0682,0x63bc059f,0x27f855f5,0x2bdd1d96}},	//   _þá_, _zern, zern_, _माहा,
   {{0x63bc9a1a,0x27f8844f,0x7bca002b,0x225f1a3a}},	//   _yern, yern_, _bdfu, _ijuk_,
   {{0x69dd9a1b,0x29000167,0x63a555f5,0x7d099a1c}},	//   egse, _rsia_, nchn, rves,
   {{0x63a502e2,0xdb030072,0x629c9a1d,0xcb698d75}},	//   ichn, _renó, _xuro, сане_,
   {{0x200554e5,0xdb030933,0x6aaa0081,0x2cad9a1e}},	//   _hali_, _senó, _কিশো, pped_,
   {{0x200506e1,0x27f89a1f,0xdb080037,0x225f05e8}},	//   _kali_, tern_, fadó, _mjuk_,
   {{0x26d89a20,0x27f801bf,0xfbd3110a,0x9f470031}},	//   turo_, uern_, _آتش_, denú_,
   {{0xe737487f,0x7bc19a21,0x63bc1386,0x4e1f00c3}},	//   пер_, malu, _rern, _मचाई_,
   {{0x7bc12c09,0x2005001c,0x629a0257,0x26d80193}},	//   lalu, _lali_, _étoi, ruro_,
   {{0x63bc03b4,0x2900005a,0xdb180e4d,0x27f89a22}},	// [a960] _pern, _usia_, _revé, pern_,
   {{0x7bc19a23,0x26d8195f,0x20059a24,0x32041177}},	//   nalu, puro_, _nali_, _samy_,
   {{0x179b00f5,0xe7b700a1,0x682b007a,0x979b00ca}},	//   _לייב, _מהיר_, _tüdr, _לשיק,
   {{0x63bc00bf,0xd36f0adb,0x28d308c0,0xa49b00ee}},	//   _wern, دهم_, _तिमि, _pròt,
   {{0xe5721dec,0x63bc9a25,0x20059a26,0x26c50220}},	//   _سطح_, _tern, _bali_, álov_,
   {{0x66069a27,0x20050694,0x7bc19a28,0x80cd0179}},	//   _hakk, _cali_, jalu, _सिरे,
   {{0x20059a29,0x09c70081,0x66069a2a,0xdb180018}},	//   _dali_, ষ্টা, _kakk, _tevé,
   {{0x225a0080,0x442a9a2b,0x7e640095,0x6aaa0033}},	//   _الرد_, _hob_, čipo, _কিলো,
   {{0x442a9a2c,0x7bc19a2d,0xdb080491,0xf8bf0103}},	//   _kob_, falu, sadü, nyét_,
   {{0x200508a1,0x64891999,0x09c5009d,0x442a85b6}},	//   _gali_, _užit, वण्य, _job_,
   {{0x442a3595,0x2bdd1fbb,0xe9f9004d,0x3b5300d3}},	//   _mob_, _मारा, онні_, екэр,
   {{0x442a9a2e,0x1e861119,0x0e9b00a1,0xed599588}},	//   _lob_, _элем, _השאל, saža_,
   {{0x58870ff8,0x7bc11d60,0x9f5e0472,0x20050a15}},	//   зыва, balu, _matí_, _yali_,
   {{0x27ed00e9,0x442a9a2f,0x7d029a30,0xb5fb0139}},	//   đeno_, _nob_, _isos, _akáp,
   {{0x3ce6023e,0x66069a31,0x12d70033,0x7dd604a8}},	//   _hqov_, _bakk, _সন্দ, cüsü,
   {{0xf4a800c7,0xa2d30251,0x80cd0f35,0x66069a32}},	//   _ওয়েব, _डिब्, _सिले, _cakk,
   {{0x81c20f71,0x6a7d11ce,0xdb089a33,0x66069a34}},	// [a970] ংলা_, léfo, padó, _dakk,
   {{0x442a006c,0x225f0160,0x78ad65f6,0x7c2a00ee}},	//   _cob_, _sjuk_, _itav, _jofr,
   {{0x63a50150,0x66068e1a,0x442a9a35,0x20053572}},	//   rchn, _fakk, _dob_, _rali_,
   {{0x63a502e2,0xe9df9a36,0x20059a37,0x644e0283}},	//   schn, ngú_, _sali_, _embi,
   {{0x3ce601fa,0x2bdd16f8,0x7bc19a38,0xfbdd0096}},	//   _nqov_, _माला, yalu, _मालम,
   {{0x6a76124d,0x66069a39,0x7c2a3b3f,0xfc070033}},	//   ráfi, _zakk, _nofr, _লক্ষ_,
   {{0x7bc13c99,0x7d029a3a,0x20059a3b,0x6606083e}},	//   valu, _asos, _vali_, _yakk,
   {{0x20058b5f,0x2d99038c,0x442a1c7f,0x78ad9a3c}},	//   _wali_, øse_, _zob_, _otav,
   {{0x7bc19a3d,0x442a022e,0xd0d4008f,0x51870565}},	//   talu, _yob_, _потъ, _хува,
   {{0x7c2a02ad,0x442a006c,0x69cd00f0,0x5ac93739}},	//   _cofr, _xob_, _adae, олом_,
   {{0x37e300c7,0x7bc19a3e,0x60c4013f,0x78ad1bbd}},	//   য়ার, ralu, šimt, _atav,
   {{0x7bc19a3f,0xdb1a0131,0x00000000,0x00000000}},	//   salu, catí, --, --,
   {{0xed4e0bd0,0x7bc19a40,0x66069a41,0x69cd0150}},	//   _ро_, palu, _rakk, _ddae,
   {{0xb8f61376,0x66069a42,0x7c2a0150,0x7bc70088}},	//   _हि_, _sakk, _gofr, ðjud,
   {{0xe73a0084,0x66e32eb1,0xc7a3881d,0xe5a61e11}},	//   цев_, кора, тиск, диби,
   {{0x442a9a43,0x644e005c,0xb9040033,0x3d020096}},	//   _sob_, _smbi, _নন_, वटचे_,
   {{0x442a9a44,0x66069a45,0x15fd0034,0xa49b015e}},	// [a980] _pob_, _vakk, उज़र_, _bròq,
   {{0x66069a46,0x6e2b9a47,0x7c2a0042,0x291205bd}},	//   _wakk, _logb, _xofr, _irya_,
   {{0x660670a8,0x60c90172,0xf1b90106,0x02a50565}},	//   _takk, _avem, _lošu_, ерім,
   {{0x7df9000c,0x442a18ef,0xda2100c3,0x44e60231}},	//   ्योग_, _wob_, यायत_, pô_,
   {{0x442a022e,0x10a3075f,0x98a20034,0xdb1a0224}},	//   _tob_, вичн, tykę_, vatí,
   {{0x644e0c47,0x60c90087,0xeeaa07ce,0x00000000}},	//   _umbi, _dvem, отик_, --,
   {{0xe80f68b9,0xd372300d,0xdb1a4777,0xda0e1fbb}},	//   ायता_, _شهر_, tatí, ियात_,
   {{0x7c2a9a48,0x249800bc,0x00000000,0x00000000}},	//   _sofr, _hirm_, --, --,
   {{0x6e2b0139,0xdb1a9a49,0xab5c00d9,0xed500018}},	//   _dogb, ratí, daļa, دھا_,
   {{0x3eac0023,0xb87b1405,0x00000000,0x00000000}},	//   _ttdt_, rtík, --, --,
   {{0xda1a0455,0x2912845c,0xdb1a0610,0xd00f02a3}},	//   धांत_, _arya_, patí, _خلل_,
   {{0x629a020d,0x7d0259c0,0x00000000,0x00000000}},	//   _étou, _tsos, --, --,
   {{0xf8ae110a,0x3e6b0018,0x6da337f2,0xcd362eb5}},	//   یکی_, _بجلی_, _рича, _تراب,
   {{0x59db0096,0xe9df0076,0xddc900d4,0x00000000}},	//   _भाकर, giúr_, rleť, --,
   {{0x7641013f,0x779300cd,0x2912083e,0xfa8a0023}},	//   ūlym, ضیحا, _erya_, _lẫy_,
   {{0x249802bc,0x6a840396,0x9f5e01b9,0xf1b938a4}},	//   _airm_, _илја, _matà_, _jošt_,
   {{0x3d11007d,0xe80f0789,0x290501d3,0x6a76003e}},	// [a990] तिये_, ायदा_, ālas_, gáfu,
   {{0xd37b5334,0xc6a700ae,0x00000000,0x00000000}},	//   оче_, _орми, --, --,
   {{0x60c902e6,0x6489809e,0x7d0001fa,0x926b037e}},	//   _svem, _džip, hwms, орда_,
   {{0xdb18030b,0xfa8a0023,0xdb010ac9,0x00000000}},	//   _neví, _bẫy_, rblø, --,
   {{0x249800ca,0x25d600ca,0x00000000,0x00000000}},	//   _firm_, _אורן_, --, --,
   {{0x75160130,0x9f0500e3,0xfd660174,0xf0750103}},	//   _אַלע_, فوتو, sspọ, ریاں_,
   {{0x20d50088,0x9f5e00b3,0xfe7900d2,0x00000000}},	//   _búið_, _catà_, tlů_, --,
   {{0xb87b9a4a,0xfde600e5,0x04060033,0x9f5e0231}},	//   luíd, едък_, রাণী_, _satã_,
   {{0xdb180146,0x6e2b02ac,0xe82207ad,0xfa8a020b}},	//   _deví, _vogb, मामा_, _gẫy_,
   {{0x518412d1,0xed594b63,0xf1b9007e,0x998974b7}},	//   _руса, sažo_, _vošu_, _blaž_,
   {{0x6e2b9a4b,0xeaae0018,0x629a0131,0xab5c01d3}},	//   _togb, یٹی_, _étot, taļa,
   {{0xade9001c,0xa96a0284,0x65c10206,0x00000000}},	//   _رفتم_, зима_, náhľ, --,
   {{0x2d9d06c0,0x644900c6,0x00000000,0x00000000}},	//   _igwe_, _įein, --, --,
   {{0xe3d50081,0x7e7b6cdd,0x68300212,0xdb1a00b3}},	//   স্তব, llup, _räds, batà,
   {{0xdb1a00ee,0x2c790113,0x00000000,0x00000000}},	//   catà, jèdi_, --, --,
   {{0xa49b0472,0xdb0301bf,0x7e7b0ce9,0xd6270284}},	//   _pròp, _benö, nlup, носе_,
   {{0x2c140096,0xdb1a9a4c,0x29120079,0x9f5e0131}},	// [a9a0] _थोडं_, patã, _urya_, _matá_,
   {{0x69c622e9,0xdb1a0018,0x7e7b0201,0xfa8a00fe}},	//   lake, latá, hlup, _rẫy_,
   {{0xe1fa0b0a,0x645e8578,0x673500a5,0x2d9d0294}},	//   зге_, rnpi, cyzj, _ogwe_,
   {{0xe64608d1,0x69c69a4d,0xdb1a956b,0x51862e9e}},	//   _чемп, nake, natá, нула,
   {{0x765609bf,0xb87b137f,0xe61f00de,0xdb1809fd}},	//   miyy, buíd, _khôn_, _reví,
   {{0x69c69a4e,0x76560253,0x2d9d5148,0x38a60150}},	//   hake, liyy, _agwe_, _môr_,
   {{0x44441884,0x69c60979,0xf1b900d8,0xd9e600a4}},	//   mh_, kake, _pošt_, _काढत_,
   {{0x765609bf,0x7e7b9a4f,0x69c69a50,0x798458da}},	//   niyy, glup, jake, _oziw,
   {{0xd25700f5,0x69c69a51,0x40a80068,0x9f470094}},	//   _נשמה_, dake, _آخری_, mený_,
   {{0x4444011b,0x9f47025b,0x76560092,0x61e29a52}},	//   nh_, lený_, hiyy, lgol,
   {{0x3fc900bf,0x44449a53,0x69c69a54,0x76560d2a}},	//   _آگهی_, ih_, fake, kiyy,
   {{0x61e22a81,0xb5fb0068,0xa2d30c16,0xdb1a349c}},	//   ngol, _aján, _डिस्, gatá,
   {{0x76569a55,0x76449a56,0x44446747,0x2ac60139}},	//   diyy, dhiy, kh_, _bíbá_,
   {{0x44445b92,0x2c1600a5,0x798400a5,0xe61f0023}},	//   jh_, ताओं_, _dziw, _chôn_,
   {{0x44448e66,0xb87b6cf4,0x78ad8979,0x61e205c2}},	//   dh_, ktív, _živč, kgol,
   {{0x44449a57,0xb8f70081,0x9f470146,0xdb1a6a26}},	//   eh_, _সহ_, jený_, catá,
   {{0x25a99a58,0x9f47135f,0xb87b137f,0x68300212}},	// [a9b0] rcal_, dený_, tuíd, _vädr,
   {{0x44445d5b,0x25a99a59,0x61e21d61,0xf367174e}},	//   gh_, scal_, egol, нтен,
   {{0xa3e20006,0xb3e237b3,0xb87b1fa4,0x76569a5a}},	//   _धार_, _पारख, ruíd, biyy,
   {{0x44449a5b,0x61e2178b,0xd6d8004d,0x80cd0096}},	//   ah_, ggol, _ять_, सळले,
   {{0x4444445f,0x661d9a5c,0xd0090f7e,0x3f9e0085}},	//   bh_, _insk, деле_, _bgtu_,
   {{0x4444507d,0x69c69a5d,0xb87b0fd9,0x660d9a5e}},	//   ch_, zake, quíd, ldak,
   {{0xe822152c,0xd9d900c7,0x9f47025b,0x69c69a5f}},	//   माता_, ধ্যম, bený_, yake,
   {{0x660d9a60,0x645708a8,0x290200a5,0x9f479a61}},	//   ndak, lixi, ywka_, menü_,
   {{0x7e7b063f,0x69c69910,0x202404c8,0xdb1a01f9}},	//   rlup, vake, ýrið_, vatá,
   {{0x765601d4,0x69c69a62,0x7e7b9a63,0xddc9007f}},	//   ziyy, wake, slup, wień,
   {{0xdb1a0068,0x2fc79a64,0x69c69a65,0xdb0a02e2}},	//   tatá, mang_, take, _gefü,
   {{0x2fc790aa,0x444400dd,0x3eaa0074,0x38a60161}},	//   lang_, zh_, žité_, _pôr_,
   {{0x69c69a66,0x1d090c0d,0x76560092,0x6e3b0255}},	//   rake, _цели_, viyy, mkub,
   {{0x2fc7914a,0x69c69a67,0x6d450092,0x765631fb}},	//   nang_, sake, _əhal, wiyy,
   {{0x64572dd9,0x76449a68,0x765600a7,0x6d49044c}},	//   dixi, thiy, tiyy, lzea,
   {{0xadf90fdd,0x2fc727e5,0x49730857,0x6e3b4ec6}},	//   ्यटन_, hang_, ụtụ_, nkub,
   {{0x44449a69,0x9f47025b,0x03a60752,0x76569a6a}},	// [a9c0] th_, vený_, визо, riyy,
   {{0x661d9a6b,0x7bc39a6c,0xb5fb0088,0x76449a6d}},	//   _ensk, _jenu, _hjál, shiy,
   {{0x7bc31268,0x2fc70d17,0x3ced9a6e,0x69c40381}},	//   _menu, dang_, htev_, _keie,
   {{0x44449a6f,0x62899a70,0x78a40d80,0x7644005c}},	//   sh_, _cheo, _kuiv, qhiy,
   {{0x2fc71a02,0x9f470220,0x69c49a71,0x62650182}},	//   fang_, rený_, _meie, دالق,
   {{0x2fc79a72,0x69c49a73,0x7bc345b5,0xb87b001f}},	//   gang_, _leie, _nenu, stív,
   {{0x2d8024e5,0x9f472883,0x661d00f3,0x6aa303e3}},	//   _šie_, pený_, _ynsk, _nunf,
   {{0x27ed03ce,0x62899a74,0x69c400d9,0xdb18025b}},	//   đeni_, _gheo, _neie, _nevá,
   {{0x2fc72447,0x7bc3357f,0xa0a6499a,0xf6530054}},	//   bang_, _benu, _разд, יצה_,
   {{0x2fc762af,0x7bc39a75,0xdb1a026a,0x660d9a76}},	//   cang_, _cenu, natç, zdak,
   {{0x201e04f9,0xdb180103,0xdb0a1b27,0x6aa301ee}},	//   _inti_, _bevá, _refó, _cunf,
   {{0x200c9a77,0x05e10557,0xdb1a0345,0x224601cb}},	//   _hadi_, _फाइब, hatç, nhok_,
   {{0xe80f02e8,0x6a7d025a,0x7bc30f20,0x200c9a78}},	//   ायला_, néfi, _fenu, _kadi_,
   {{0x200c2129,0x6aa3026e,0x78a401c0,0xd7f82b99}},	//   _jadi_, _funf, _duiv, кус_,
   {{0x45d54564,0x7bc86844,0x200c02f1,0x69c49a79}},	//   ловс, madu, _madi_, _feie,
   {{0x200c9a7a,0x7bc89a7b,0x7bc359a5,0x20d2086d}},	//   _ladi_, ladu, _zenu, _सिंध,
   {{0x2fc790aa,0x628902e0,0x660d0847,0x645716e7}},	// [a9d0] yang_, _rheo, rdak, tixi,
   {{0xda2104a9,0x200c1523,0x62899a7c,0x7bc89a7d}},	//   यावत_, _nadi_, _sheo, nadu,
   {{0x64579a7e,0x2fc7000b,0x62890441,0x78a401c0}},	//   rixi, vang_, _pheo, _zuiv,
   {{0x2fc790aa,0x661d1528,0x7bc874c7,0x64570188}},	//   wang_, _unsk, hadu, sixi,
   {{0x2fc712ff,0x200c9a7f,0x7bc89a80,0xb87b0e4d}},	//   tang_, _badi_, kadu, btít,
   {{0x7bc8007a,0xa2cc9a81,0x200c9a82,0x2fc7023e}},	//   jadu, _हिच्, _cadi_, uang_,
   {{0x2fc71bd6,0x7bc355a7,0x200c0979,0xb87b0428}},	//   rang_, _renu, _dadi_, ltís,
   {{0xc3321541,0x2fc733bf,0x6d4902a7,0x201e008f}},	//   _פון_, sang_, tzea, _enti_,
   {{0x7bc310dd,0x2fc7840e,0x6e290808,0x443102f1}},	//   _penu, pang_, rjeb, _koz_,
   {{0xb5fb0102,0x7bc89a83,0x69c49a84,0x200c9a85}},	//   _sjál, gadu, _seie, _gadi_,
   {{0x78a404ea,0x7bc39a86,0x290900ac,0xb5fb0065}},	//   _suiv, _venu, _asaa_, _ajám,
   {{0x2fc50ec9,0xcf560327,0x8c4300a7,0x200c9a87}},	//   _helg_, _גבעת_, _əşya, _zadi_,
   {{0x7bc3452b,0xfe700391,0x7bc89a88,0x69c49a89}},	//   _tenu, _بدل_, badu, _veie,
   {{0x6cd21850,0x66e60a8e,0x7bc81ce2,0x69c4057a}},	//   _اقوا, лога, cadu, _weie,
   {{0xe8190ed3,0x61e99a8a,0x69c44fc7,0x657d9a8b}},	//   दाजा_, _ocel, _teie, _aysh,
   {{0x28dc1e5e,0x3ea50a29,0xdb180f04,0x9f4e014b}},	//   _बिपि, _mult_, _bevæ, uffé_,
   {{0xdb0a0102,0x3a202b20,0x44319a8c,0x45863f1a}},	// [a9e0] _hefð, _inip_, _boz_, угав,
   {{0x61e95cac,0x657d00dd,0xa3e90b3f,0xe5776c35}},	//   _acel, _dysh, _याण_, узу_,
   {{0x200c03ce,0x59b8007d,0x7ae19a8d,0xddc903ce}},	//   _radi_, _आभार, nult, dlež,
   {{0x64558e38,0x7bc809d8,0x2fc50042,0xb87b0146}},	//   _emzi, zadu, _aelg_, stít,
   {{0x7ae19a8e,0x4431137f,0x2fc59a8f,0x7bc89a90}},	//   hult, _foz_, _belg_, yadu,
   {{0x648b2a96,0x3ea547f5,0x61e9019f,0x53a302b7}},	//   güid, _bult_, _ecel, _гарб,
   {{0xa3e9009d,0xe8d90134,0x7bc89a91,0x7ae19a92}},	//   _यात_, _izụ_, vadu, jult,
   {{0xe29707ce,0xb5fb0065,0x200c9a93,0x7bc7003e}},	//   _бас_, _ajáj, _wadi_, ðjun,
   {{0x200c06ee,0x7bc89a94,0x21670831,0x516601b3}},	//   _tadi_, tadu, _бити_, _сваб,
   {{0xcb1f0789,0x201e00a6,0x61e9030b,0xf1b900e7}},	//   यमंड_, _unti_, _zcel, _inša_,
   {{0x3ea52e7f,0x450a0033,0x6d4f0623,0xa3f700ca}},	//   _gult_, রমিক_, úcar, נמטק_,
   {{0xd915004b,0x80c102d5,0xdb0301cd,0x00000000}},	//   адмы, रीवे, _ofnæ, --,
   {{0x7bc824cb,0x3ea50126,0xd7fb0243,0x00000000}},	//   padu, _zult_, нув_, --,
   {{0xb5fb0363,0xe7e30081,0x7ae19a95,0xb8fd0d61}},	//   _ukáz, য়্য, bult, _डि_,
   {{0x81dc00c7,0x7ae11173,0x44319a96,0xb87b0610}},	//   ত্য_, cult, _roz_, guía,
   {{0xe8d900ac,0x29092a0b,0x4431173c,0x68ed0090}},	//   _azụ_, _tsaa_, _soz_, _tqad,
   {{0x545513b0,0xe822007d,0xa3e90b89,0x29090124}},	// [a9f0] ават, माशा_, _याद_, _usaa_,
   {{0x61e9013d,0xb87b9a97,0x3dc60063,0xb4d5074c}},	//   _scel, dríg, _leow_, _सटी_,
   {{0x44311f84,0xed590783,0x61e90fa3,0x657d057a}},	//   _voz_, raži_, _pcel, _wysh,
   {{0x27ed005f,0x44319a98,0xb6ba00ca,0xd378037e}},	//   đenu_, _woz_, _שצרי, учу_,
   {{0x25ea143d,0x91bf0174,0x3ea59a99,0x61e90094}},	//   _छाती_, _ajụ_, _sult_, _vcel,
   {{0xdb180084,0x64550201,0xc4f6006e,0x00000000}},	//   _kevä, _umzi, _דזשי_, --,
   {{0x2fc59a9a,0x44ef0233,0x28dc00b6,0xa5bb0503}},	//   _velg_, lü_, _बिभि, _gnóc,
   {{0x81dc0081,0xd1bb0260,0xa2a21efb,0x61e95496}},	//   ত্ব_, _سارا_, गदर्, _ucel,
   {{0x1c4533fd,0x2d999a9b,0x9fe70037,0x2fc59a9c}},	//   иним, äse_, _مساه, _telg_,
   {{0x1c1f0b61,0x28dc32c9,0x3a20033c,0x2a6900aa}},	//   बाइल_, _बिबि, _snip_, _ajab_,
   {{0x3f6720f9,0xcb690114,0xff5300b1,0xda210096}},	//   _стаб, тане_, _اخذ_, यांत_,
   {{0x660f0003,0x7ae19a9d,0x00000000,0x00000000}},	//   _nack, rult, --, --,
   {{0xfe7054c8,0xe8222172,0x64890a39,0x2a69022b}},	//   _عدم_, माला_, _džiz, _djab_,
   {{0x7ae19a9e,0x5d840037,0xb87b002b,0x2be2007f}},	//   pult, _الهل, tuía, _खाएं_,
   {{0x660f9a9f,0x4b7900c1,0x3dc60063,0x66d9205c}},	//   _back, _באַו, _yeow_, льтр_,
   {{0x7aee025b,0x660f0a39,0xdb180031,0xe5a33f98}},	//   žití, _cack, _devä, жити,
   {{0x69d60009,0x13ea00d3,0x290c01d3,0xb87b002b}},	// [aa00] _idye, кмай_, ādas_, suía,
   {{0x7d0b00bf,0xb87b9aa0,0x61fd0233,0x2937006e}},	//   _msgs, luín, _ısla, _כאפן_,
   {{0x660f9aa1,0x0ef40096,0x28dc5fc7,0xb87b0143}},	//   _fack, _आहेस_, _बिडि, quía,
   {{0x660f08a9,0xed590039,0xb87b13a9,0xd9e60469}},	//   _gack, lažu_, nuín, कलित_,
   {{0x03a64d1b,0x0594001c,0x7e6d00e7,0x3eb900ae}},	//   _виго, _دادگ, čapl, _ăsta_,
   {{0x66041b5b,0xc483008f,0xc0760831,0x76410138}},	//   leik, _мляк, шћењ, ūlyt,
   {{0xe7ee05d4,0x1c1f07ad,0x23270e21,0x7e4600ae}},	//   _जाना_, बाईल_, _кори_, ихие,
   {{0x7d0b0154,0x0367004d,0xddc90034,0x69d6378a}},	//   _bsgs, _тиск_, mieś, _ndye,
   {{0x614323b1,0xed590335,0x673c023b,0xd7c6009d}},	//   _дета, kažu_, hyrj, वराच,
   {{0x62829aa2,0x69d69aa3,0x660480b5,0x7d1900eb}},	//   lloo, _adye, heik, _drws,
   {{0x66049aa4,0x3dc600dc,0x62829aa5,0xdb1a317d}},	//   keik, _teow_, oloo, latú,
   {{0x62821f4c,0x62510181,0x2efe00e7,0x2ca60eac}},	//   nloo, sťov, _iptf_, _tuod_,
   {{0x6e229aa6,0x99890095,0x29870cbe,0xdb1802c3}},	//   _inob, _boaš_, рынг, _sevä,
   {{0x69d607ac,0xd7c901c3,0x76460d4b,0x00000000}},	//   _edye, طوره_, _alky, --,
   {{0x660f9aa7,0x62823fdf,0x6e229aa8,0xb87b03be}},	//   _pack, kloo, _knob, buín,
   {{0xe61f00de,0xb87b0428,0x9f5c00b6,0x81dc0033}},	//   _khôi_, dríe, jeví_, ত্ত_,
   {{0x660f0222,0x95c85ac0,0x62828a90,0x26160096}},	// [aa10] _vack, руса_, dloo, _पोळी_,
   {{0x660f9aa9,0xe7ee9aaa,0x673c4410,0x3cee9aab}},	//   _wack, _जाया_, byrj, _आमने_,
   {{0xa2f59aac,0x62821a7a,0x660f9aad,0x6e2236d8}},	//   спеч, floo, _tack, _onob,
   {{0x80db000f,0xb9100129,0x628218f0,0x9e3c00d8}},	//   _निदे, _nanị_, gloo, _buďm,
   {{0xe7ee0378,0xe3e9110a,0xdb0a0364,0x80ca0285}},	//   _जामा_, _مکان_, _gefö, _सौदे,
   {{0x6e229aae,0x3f691146,0x00000000,0x00000000}},	//   _anob, лило_, --, --,
   {{0x62828447,0x644702a1,0x41e704a1,0x4423041c}},	//   bloo, _ilji, _віза, _inj_,
   {{0x7d0b0124,0xf99f0428,0x11d40037,0x62829aaf}},	//   _psgs, ndès_, _وتقد, cloo,
   {{0x61fb9ab0,0x00000000,0x00000000,0x00000000}},	//   _ibul, --, --, --,
   {{0x308500e3,0x60cd00e7,0x61fb0090,0x6e221f91}},	//   _الطف, šams, _hbul, _enob,
   {{0xb87b03be,0x442303e3,0x78b6298b,0xed592f54}},	//   tuín, _mnj_, _styv, važu_,
   {{0x61fb0113,0xd35600d7,0x00000000,0x00000000}},	//   _jbul, מיתי_, --, --,
   {{0x66049ab1,0x61fb9ab2,0x8e7400e3,0x38789ab3}},	//   veik, _mbul, _بالض, torr_,
   {{0x66040174,0x673c691e,0xb87b0956,0x7d09083e}},	//   weik, tyrj, suín, mwes,
   {{0x6604784c,0xa2d3152c,0x7d0981d6,0x61fb9ab4}},	//   teik, _डिग्, lwes, _obul,
   {{0x64470d2a,0xed592f54,0xb87b016d,0x4423022b}},	//   _alji, sažu_, quín, _anj_,
   {{0x66049ab5,0xddc90034,0xab5c01d3,0x644705db}},	// [aa20] reik, wieś, vaļi, _blji,
   {{0x61fb9ab6,0xaca30294,0x628201af,0x232a1693}},	//   _abul, _adịk, wloo, лози_,
   {{0x7d099ab7,0xe73a5896,0x6a68026a,0xa3e913cc}},	//   hwes, _сен_, yıfl, _यार_,
   {{0x7d090060,0xb87b9ab8,0x6b7a00c1,0x8cd80557}},	//   kwes, críb, ארענ, _मिलो,
   {{0xc05a0c10,0x6282501b,0x6e22009c,0x00000000}},	//   лік_, rloo, _rnob, --,
   {{0x61fb9ab9,0x6447005f,0xdb1a9aba,0x6282715f}},	//   _ebul, _glji, ratú, sloo,
   {{0x62829abb,0x645e6da1,0x7ff300e3,0xd01103e3}},	//   ploo, mipi, سسوا, _dā_,
   {{0x6f1a0087,0x7c239abc,0x645e5f35,0xe61f0023}},	//   _vrtc, _annr, lipi, _phôi_,
   {{0xa49b05fe,0x68e605e8,0x611e020a,0x00000000}},	//   _pròx, jukd, _bălţ, --,
   {{0x61fb00dd,0x645e9abd,0x94110092,0xbbe20285}},	//   _zbul, nipi, _bizə_, पलेक,
   {{0x7f86054f,0x547b00a1,0x29009abe,0xa49b00b3}},	//   _الان, רטיו, _apia_, _isòt,
   {{0xc3337c04,0x7a3f01e5,0xe61f0028,0xa5bb2f7b}},	//   לות_, _këti, _thôi_, _anón,
   {{0x6da30a09,0x645e9abf,0xb87b0072,0x7d960076}},	//   _عموم, kipi, buíl, _الشؤ,
   {{0x69c001ab,0x4d7b00c1,0x645e0239,0x24440212}},	//   ðmer, _ערגע, jipi, _sömn_,
   {{0x466b0606,0x2bf7040a,0x644b023b,0x44230090}},	//   грам_, _המון_, ëgim, _rnj_,
   {{0x7bca0682,0x64470542,0x68e600f9,0x3f8c0094}},	//   _hefu, _slji, bukd, _mzdu_,
   {{0x69cf0328,0x7bca0063,0xdb0389c4,0xb87b0072}},	// [aa30] mace, _kefu, _agnè, quío,
   {{0x69cf59d4,0x6aaa9ac0,0x645e9ac1,0x7bca020a}},	//   lace, _kuff, gipi, _jefu,
   {{0xe7ee1085,0xe9f90028,0x6aaa1507,0x1635008f}},	//   _जाता_, _giả_, _juff, _деня,
   {{0xa49b0154,0xb87b1789,0x38af9ac2,0x04060033}},	//   _asòt, bríc, _kür_, রাগী_,
   {{0x61fb2fc8,0x7bd800cc,0x00000000,0x00000000}},	//   _vbul, _odvu, --, --,
   {{0x02a708a1,0x7bca2614,0x44230085,0x69cf9ac3}},	//   _грам, _nefu, _unj_, hace,
   {{0x80db2918,0x69cf9ac4,0xd1bb0037,0x00000000}},	//   _निवे, kace, _ماذا_, --,
   {{0xee3908c3,0x764d7225,0x7d099ac5,0x68e6235a}},	//   рни_, nhay, twes, yukd,
   {{0x82341dec,0x7bca9ac6,0x6aaa01bf,0x94110092}},	//   _عرفا, _befu, _auff, _sizə_,
   {{0x7d099ac7,0x6aaa5410,0xdfd10d7f,0x00000000}},	//   rwes, _buff, _آيا_, --,
   {{0x20079ac8,0x69cf667e,0x764d0060,0x6aaa9ac9}},	//   meni_, face, khay, _cuff,
   {{0x2007067d,0x7d096ef3,0x61eb4179,0x645e9aca}},	//   leni_, pwes, nggl, zipi,
   {{0x7e7b04a3,0xe7ee007a,0x764d517d,0xfe4200d6}},	//   moup, _जादा_, dhay, _іншо,
   {{0x7bca8544,0x20070060,0x7e7b9acb,0xbb450ae3}},	//   _gefu, neni_, loup, _мелк,
   {{0x2bbf1ab1,0x07a30c06,0x7bc19acc,0x68e65a28}},	//   _श्या, дарн, mblu, sukd,
   {{0x38af3477,0xb87b5b59,0x20079acd,0x7e699ace}},	//   _für_, tríc, heni_, nnep,
   {{0x645e9acf,0x20079ad0,0xe45a1167,0x75d300e3}},	// [aa40] tipi, keni_, ажа_, بيقا,
   {{0x7bc102db,0xe45f003e,0x764d008c,0xdb180031}},	//   nblu, _svör_, ahay, _revú,
   {{0xe5a60562,0x41aa01c9,0x7e7b030b,0x764d0060}},	//   _мини, авен_, koup, bhay,
   {{0x764d9ad1,0x645e0948,0xb5fb003e,0xdb1a13b9}},	//   chay, sipi, _sjáv, ratø,
   {{0xe80f009d,0xaca30134,0x645e9ad2,0x6b8308ca}},	//   ायचा_, _adọk, pipi, _lyng,
   {{0x20079ad3,0xdfd000e3,0x7644981b,0x69cf9ad4}},	//   geni_, ريب_, lkiy, zace,
   {{0x44f402fd,0x44449ad5,0x645c9ad6,0x60cd0095}},	//   lä_, mk_, _imri, šamp,
   {{0x44389ad7,0x3ea20149,0x66169ad8,0x7bca9ad9}},	//   _hor_, ökt_, ndyk, _sefu,
   {{0x44f402fd,0xc69309c1,0x20079ada,0x44383bd7}},	//   nä_, ואה_, beni_, _kor_,
   {{0x44449adb,0x69cf9adc,0x6616007b,0xb87b0072}},	//   nk_, wace, hdyk, tuím,
   {{0x444404e2,0x4438944f,0x6b8302e0,0x76440044}},	//   ik_, _mor_, _cyng, kkiy,
   {{0x81dc0f71,0x4438883c,0xb5fb0081,0xb87b0890}},	//   ত্র_, _lor_, _imág, dría,
   {{0x4438040c,0x44449add,0x44f402fd,0x7e601bd6}},	//   _oor_, kk_, jä_, mimp,
   {{0x444426f1,0x44f40084,0x6aaa9ade,0x7d029adf}},	//   jk_, dä_, _tuff, _ipos,
   {{0x69cf06fc,0x764d9ae0,0x6b830150,0x6d409ae1}},	//   pace, thay, _gyng, lyma,
   {{0x7e6034ac,0x44449ae2,0x38af0eef,0x7c380212}},	//   nimp, ek_, _tür_, _hovr,
   {{0x443809ce,0xd7fb13a4,0x20070201,0x7c380106}},	// [aa50] _bor_, _кун_, yeni_, _kovr,
   {{0x44389ae3,0x764d9ae4,0xf8bf2bb7,0xb87b0610}},	//   _cor_, shay, mpé_, bría,
   {{0x44381c07,0xf8bf45b0,0x6d409ae5,0x7ae80124}},	//   _dor_, lpé_, hyma, nudt,
   {{0x20077246,0x4444040d,0x6d40013f,0x645c2832}},	//   weni_, ak_, kyma, _emri,
   {{0x44381723,0x20079ae6,0x444401af,0x61eb02c3}},	//   _for_, teni_, bk_, rggl,
   {{0x44389ae7,0x6d40013f,0xf8bf00fd,0x7c3800a7}},	//   _gor_, dyma, ipé_, _novr,
   {{0x20070106,0x7e7b00b6,0x8fa21a9f,0x00000000}},	//   reni_, toup, наше, --,
   {{0x20079301,0x44383a7d,0x28dc074c,0x7d020037}},	//   seni_, _zor_, _बिलि, _bpos,
   {{0x6b837b5f,0x7e6901df,0xb5fb0103,0xc212006e}},	//   _syng, rnep, _imád, _אהן_,
   {{0x200788a5,0xbebc00d9,0x76449ae8,0x69cd009c}},	//   qeni_, _brīd, zkiy, _aeae,
   {{0x7c38013d,0x7d029ae9,0x3b091e70,0xa5bb0328}},	//   _dovr, _epos, щено_, _anóm,
   {{0x60c91f6e,0x7e6002e7,0x6d402522,0x7d020090}},	//   _kwem, cimp, byma, _fpos,
   {{0x69cd00c4,0x6b831c72,0xc8b6022a,0x00000000}},	//   _deae, _wyng, ясны, --,
   {{0x44f40084,0x6b8345a5,0x60c935f5,0x6aa451ab}},	//   vä_, _tyng, _mwem, _wiif,
   {{0xcb660cf5,0xaa465bea,0xbebc01d3,0x7d1b56a1}},	//   _наше_, _некл, _grīd, lvus,
   {{0x44f40d64,0x44389aea,0xb87b0328,0xdb1a00d4}},	//   tä_, _sor_, rría, natý,
   {{0x76449aeb,0x6e390078,0xe51c0179,0x66165f4e}},	// [aa60] rkiy, _mowb, निधि_, rdyk,
   {{0x444485f9,0x76441114,0x2912048e,0xd91b00c1}},	//   uk_, skiy, _isya_, _פויל,
   {{0x44389aec,0xf62601c9,0x6d4000a5,0x7d1b007a}},	//   _vor_, _едно, zyma, hvus,
   {{0x44440073,0x64a610fb,0x645c01c0,0x78ad022e}},	//   sk_, _нама, _wmri, _yuav,
   {{0x44385165,0xf1a900cd,0xa1330452,0x44449aed}},	//   _tor_, زانه_, فروش, pk_,
   {{0x645c24b5,0x2cbf00f9,0x629905c2,0xb4ca0096}},	//   _umri, dpud_, amwo, ोळी_,
   {{0x7d029aee,0x7e6080e5,0x60c958da,0x425637fa}},	//   _spos, timp, _ewem, _етат,
   {{0x7c389aef,0x6d4016e0,0x7ae80e3e,0x6b550090}},	//   _sovr, tyma, vudt, _mżgħ,
   {{0x7c380941,0xe29736bf,0xdd90010d,0xc0e30859}},	//   _povr, _хат_, کوک_, _потк,
   {{0x7e6037be,0x6d405dcd,0x5fd0030b,0x09b50096}},	//   simp, ryma, _सजिल, ंड्य,
   {{0x29129af0,0x60c90ab2,0x7e600759,0x6d405dcd}},	//   _asya_, _zwem, pimp, syma,
   {{0x78ad023e,0x224601f9,0xdb1a3ad7,0xdb0300eb}},	//   _puav, nkok_, matü, _egnï,
   {{0xdcf70979,0x7d02050d,0x7c380087,0x2e3700ca}},	//   _فروش_, _upos, _tovr, _מראש_,
   {{0xb905048a,0xa8a4124c,0xdca34d18,0xac9801f9}},	//   _पट_, ерск, _зачи, _بنتا_,
   {{0xabfb00ca,0xf1cc1b79,0xb87b0072,0x00000000}},	//   _ההור, ारान, brín, --,
   {{0xf8bf0257,0xa49b0139,0x80d20033,0x26df0580}},	//   ppé_, _asòp, _সমন্, čuo_,
   {{0x59c300a3,0x3a2902e7,0x3ea6193c,0x9f5c007b}},	// [aa70] _व्यर, _inap_, _miot_, levä_,
   {{0xb4cd2397,0xdb1a0233,0x60c905bd,0xe61f030a}},	//   _रबी_, katü, _rwem, _chôr_,
   {{0x75290106,0x644529cb,0x3a2920f6,0x3d0e17ff}},	//   _šezd, rkhi, _knap_, _तैसे_,
   {{0xdb1a9af1,0x3cdd0251,0x60c90383,0x224603a9}},	//   lató, _खिले_, _pwem, gkok_,
   {{0xe1f01857,0xb5fb0102,0xe8220096,0x62991881}},	//   اسم_, _fjár, माचा_, rmwo,
   {{0xdb1a9af2,0x417400cd,0xfaf801d3,0xe7bf0be4}},	//   nató, رانس, ktī_, ्रिप,
   {{0xae1e24eb,0x3a290027,0x00000000,0x00000000}},	//   _मोहन_, _onap_, --, --,
   {{0xda1d1e5e,0x7d1b007a,0xdb1a6a51,0xada5061b}},	//   _बोलत_, tvus, ható, майл,
   {{0xd7bf2183,0xe7ee05a7,0x3ea601e9,0xe7bf09a0}},	//   ्राच, _जाला_, _diot_, ्राप,
   {{0x5ee50034,0xbb45117a,0x7d1b2ba2,0x394200c6}},	//   _टिप्_, деок, rvus, vyks_,
   {{0x3ea60072,0x7d1b31e8,0x6e399af3,0xdb1a0231}},	//   _fiot_, svus, _towb, dató,
   {{0xb87b0037,0x3a2901f7,0x19b900d3,0x00000000}},	//   frío, _cnap_, зурь_, --,
   {{0xdb0a0222,0xee780781,0xdb03037a,0x80cf0033}},	//   _affä, _عصمت_, _igní, হূর্,
   {{0xdb1a9af4,0x3a299af5,0xe3e30033,0x6b6530fd}},	//   gató, _enap_, ন্তব, _окла,
   {{0x81e50f71,0x224d00a3,0x27e5153c,0x225f06b0}},	//   ব্য_, _olek_, ólna_, _omuk_,
   {{0x2ca70006,0xb87b00e3,0xb5fb0072,0x3eb80103}},	//   _hind_, brío, _amáb, _érte_,
   {{0x1be1007a,0x2ca706e5,0xb87b0076,0x7ea70233}},	// [aa80] _खयाल_, _kind_, crío, _yıpr,
   {{0x225f0533,0xdb1a9af6,0x9f5e00ee,0x22a80847}},	//   _amuk_, cató, _xató_, _aşka_,
   {{0x38b41424,0x65c654a7,0x2ca797ee,0xdb1a00ee}},	//   _här_, _обна, _mind_, latò,
   {{0x2ca79af7,0xdb180146,0xdb030037,0x38b40212}},	//   _lind_, _nevý, _ngní, _kär_,
   {{0xdb1a015e,0xa2aa1c05,0xe3e30a43,0x00000000}},	//   natò, _जंक्, ন্ধব, --,
   {{0x224d231d,0x46d20251,0x38b431da,0x22460e1e}},	//   _elek_, _तबाह, _mär_, skok_,
   {{0x38b40222,0x224d063a,0x644e9af8,0x3ea60027}},	//   _lär_, _flek_, _ilbi, _piot_,
   {{0x442a2d5a,0xae1e02d5,0x224d1a3a,0x7c2d01c2}},	//   _hnb_, _मोशन_, _glek_, _ɗare,
   {{0x38b41424,0x2ca7526d,0x2167004d,0x442a9af9}},	//   _när_, _bind_, _жити_, _knb_,
   {{0x2ca700d3,0x9f5c007b,0x3a29535f,0x69c600d8}},	//   _cind_, tevä_, _snap_, ebke,
   {{0x9e3c025b,0x60c20ae3,0x9f5e0428,0xdb1a4d05}},	//   _buďt, lpom, _obté_, vató,
   {{0x2ca70126,0x38b40704,0x60c20034,0xb87b0037}},	//   _eind_, _bär_, opom, trío,
   {{0x2ca79afa,0xa3c002d5,0xdb1a369c,0x644e00e5}},	//   _find_, ीरा_, tató, _olbi,
   {{0x38b41424,0x9c570037,0x0ec500a4,0x2ca7078e}},	//   _där_, _يجوز_, ळीकड, _gind_,
   {{0xdb1a983a,0x442d9afb,0x00000000,0x00000000}},	//   rató, _đe_, --, --,
   {{0x644e02a7,0x56949afc,0xdb1a00b3,0xf8b10421}},	//   _albi, васт, batò, _مکس_,
   {{0xdb1a9afd,0x60c24289,0xc7c70291,0x442a066a}},	// [aa90] catò, jpom, _осни, _bnb_,
   {{0x225f052f,0xe8d800ca,0x2ca70381,0x60c20141}},	//   _smuk_, _חוזר_, _xind_, dpom,
   {{0x224d5268,0x60c20381,0x00000000,0x00000000}},	//   _plek_, epom, --, --,
   {{0x644e06a7,0x442a6cae,0xd7bf0034,0x81cf0033}},	//   _elbi, _enb_, ्रवच, _শাহ_,
   {{0x442a057a,0x38580470,0x6dc10134,0x660d356b}},	//   _fnb_, _رشید_, ịakw, meak,
   {{0x649000c2,0x442a7637,0x3af80103,0x41740037}},	//   läin, _gnb_, kép_, خامس,
   {{0x2ca79afe,0x00000000,0x00000000,0x00000000}},	//   _rind_, --, --, --,
   {{0x2ca702d6,0x43940ff8,0x7c2a01bf,0x660d12c3}},	//   _sind_, _расс, _anfr, neak,
   {{0x2ca73c28,0x11670103,0xb87b0231,0x00000000}},	//   _pind_, _غلطی_, tríl, --,
   {{0x660d7a99,0xfc31054f,0x2ca700dd,0x628b1dcb}},	//   heak, احة_, _qind_, llgo,
   {{0x2ca70371,0xda661940,0x65690146,0x3af80018}},	//   _vind_, евни, _žehl, gép_,
   {{0x2bbf0efd,0xfbbf06ae,0xee2e08a1,0x2ca7019e}},	//   _श्रा, _श्रम, _ён_, _wind_,
   {{0xed4e9aff,0x6e2b0f20,0x660d0a00,0xa49b0065}},	//   _со_, _ingb, deak, _apòm,
   {{0x26de0039,0x60db1801,0xccf20327,0xdb1a015e}},	//   štom_, _mvum, _עכו_, ratò,
   {{0xe73a1d62,0xdb18002b,0x38b40364,0x96960a95}},	//   чев_, _devó, _wär_, ераш,
   {{0x660d0113,0x442a1177,0x60db6ecd,0x00000000}},	//   geak, _snb_, _ovum, --,
   {{0x142630fa,0xa5070114,0x660301b6,0x999e00c6}},	// [aaa0] ндам, нета_, ыпта, ėtų_,
   {{0x78fb0054,0x3957040a,0x628b0cad,0x4ad3063e}},	//   _צפיו, _נשים_, elgo, _दबाव,
   {{0x64e20096,0x60db4970,0x660d01ff,0xb87b0131}},	//   _पिवळ, _avum, beak, tuív,
   {{0xdb012027,0x60c20559,0x23771aaa,0xdb0a020d}},	//   lcló, tpom, رمند_, _affû,
   {{0xa3e9009d,0x442a9b00,0x3af80103,0x00000000}},	//   _याच_, _tnb_, zép_, --,
   {{0x6e2b0139,0x10a30a51,0x60c29b01,0x442a0131}},	//   _angb, гичн, rpom, _unb_,
   {{0x91e60aec,0x60c29b02,0xc6130033,0x60db36d8}},	//   _пове, spom, হারা_, _evum,
   {{0xb87b5d30,0xa3f02337,0x60c29b03,0x00000000}},	//   quív, _चाँप_, ppom, --,
   {{0x6ecc0251,0x00000000,0x00000000,0x00000000}},	//   _सबकु, --, --, --,
   {{0x8fa6044b,0x46e108d4,0x6e2b2059,0x00000000}},	//   _зазе, _फिलह, _engb, --,
   {{0xdee3007e,0xdb18065b,0xe457021e,0x660d0294}},	//   _бохи, _revó, גייט_, yeak,
   {{0xdc3c1197,0x200e9b04,0x00000000,0x00000000}},	//   _išču, lefi_, --, --,
   {{0x8c4633d4,0x7e621497,0x649000ce,0x00000000}},	//   _педе, _imop, väin, --,
   {{0xa3490065,0x7c2a9b05,0xb87b002b,0x22a70032}},	//   _bọ́t, _unfr, prím, _kìkì_,
   {{0x45d51d3f,0x660d9b06,0xb6e4022a,0x61e000d4}},	//   ковс, teak, лютк, _odml,
   {{0x63ae0174,0xe9df01cd,0xe3cd0033,0x161b023a}},	//   _agbn, rhús_, _লাইব, _पोखर_,
   {{0xa8a73c1a,0xb87b003e,0x649000c2,0x22a70065}},	// [aab0] _прок, nrík, räin, _lìkì_,
   {{0xd131015a,0x200e01c2,0xb87b002b,0x660d1305}},	//   یما_, jefi_, tuíu, seak,
   {{0x28b70101,0xf6991d2e,0x660d9b07,0x57bf030b}},	//   _इंडि, _овој_, peak, ्रीह,
   {{0x29090134,0xb9260174,0x24980381,0x2eee0abd}},	//   _kpaa_, _nkwọ_, _ehrm_, duff_,
   {{0xdb0100ee,0x00000000,0x00000000,0x00000000}},	//   nclò, --, --, --,
   {{0xb9260134,0x2909010a,0x7e620154,0x68fd11fc}},	//   _akwọ_, _mpaa_, _amop, itsd,
   {{0x43941102,0x1394007b,0x00000000,0x00000000}},	//   _барс, _бирю, --, --,
   {{0x9f4c00b3,0x4ada0980,0xdb030076,0x68fd7604}},	//   _abdó_, _भिजव, _ngná, ktsd,
   {{0x60db52cd,0x320f01f9,0x7c9513a4,0xb87b0956}},	//   _uvum, megy_, кроц, nuís,
   {{0x26de0103,0x1c451aad,0x51849589,0x2eee01ab}},	//   átok_, тном, _суса, buff_,
   {{0x9f040f43,0x26c1023e,0xa49b0139,0x29090167}},	//   _مولو, _ntho_, _apòk, _apaa_,
   {{0xa96a2156,0xb6c80103,0xb87b0206,0x68fd0aab}},	//   дима_, ہارے_, brík, ftsd,
   {{0xf4cc0033,0x2d8201f9,0x7ae88426,0xb8660286}},	//   _লম্ব, üket_, ardt, ناسو,
   {{0x66e600c9,0xed560831,0x1d0609b9,0xfd5600ca}},	//   кога, _још_, _реши_, _בשני_,
   {{0xb5fb003e,0x177900c2,0x68fd1aab,0x00000000}},	//   _smáa, есть_, atsd, --,
   {{0x80d200c7,0xe5f3002d,0xa89801d3,0x602801d3}},	//   _সমস্, văţă, _šķēr, _zīmē,
   {{0xb87b08a8,0x28dc0fef,0x26c19b08,0xc4860b36}},	// [aac0] tuít, _बिटि, _etho_, влак,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3e7a00e8,0x00000000,0x00000000,0x00000000}},	//   līte_, --, --, --,
   {{0x2005019c,0xbebc01d3,0x91e6020a,0xb87b9b09}},	//   _abli_, _brīn, тоде, buís,
   {{0x24440088,0x6f080072,0x3e7a00e8,0x9f45033c}},	//   _sömu_, _spdc, nīte_, _gclú_,
   {{0x75360abd,0xe9f90d79,0xdcf500b6,0xb87b13a9}},	//   mxyz, _diẹ_, ůběh, luír,
   {{0xe8e00019,0x200e0150,0xe80422a3,0xdb1a9b0a}},	//   _ước_, refi_, श्या_, latö,
   {{0x200500e7,0xf77300ca,0xe126007b,0x527600ae}},	//   _ebli_, יקו_, _имби, _ругу,
   {{0x5ea30037,0xdb1a9b0b,0x527502e1,0x00000000}},	//   جميل, natö, _суру, --,
   {{0xe7ee009d,0x515b0089,0x28dc0096,0xb87b003e}},	//   _जागा_, _חכמו, _बिजि, rrík,
   {{0x3d170034,0x8fa600ae,0xdc3c00c4,0x00000000}},	//   _बैठे_, _раже, _ušču, --,
   {{0x28b70455,0xb87b0181,0x68fd3d97,0x81c20033}},	//   _इंदि, prík, ttsd, ূলক_,
   {{0xb87b0143,0x00000000,0x00000000,0x00000000}},	//   nsíg, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44d00067,0x386d0292,0x9c130134,0x6490007b}},	//   eń_, đer_, _kọnv, räil,
   {{0x649000c2,0xb87b0072,0xf1b91b32,0x69e72458}},	//   säil, guír, _kaše_, _рюкз,
   {{0x35b42c49,0xf1b91197,0x9a6800e3,0xdb0a0537}},	// [aad0] рбур, _jaše_, _جميل_, _affø,
   {{0xa5bb9b0c,0x7bc500aa,0xb4e302d5,0x545402b7}},	//   _anót, _õhut, _नटी_, авут,
   {{0x6aad0051,0xd3a70c10,0xb87b13a9,0x320f9b0d}},	//   _kiaf, трап, buír, tegy_,
   {{0xe45f0222,0x798d295a,0x00000000,0x00000000}},	//   _stöd_, _kyaw, --, --,
   {{0xc7b80335,0x91050ab3,0x6aad024a,0x61f800d8}},	//   žđe_, упле, _miaf, _žalá,
   {{0x661d006d,0x764d3d8e,0x24440212,0x6aad3d2a}},	//   _hask, lkay, _döms_, _liaf,
   {{0x9388002d,0x02a7302e,0x44fd0036,0x798d26e3}},	//   _аста_, _арам, lì_, _lyaw,
   {{0x765801b3,0x80d20081,0x764d9b0e,0x661d1518}},	//   _įvyk, _সমর্, nkay, _jask,
   {{0x798d1084,0xdbcd037a,0x764d0172,0xbebc00e8}},	//   _nyaw, _añád, ikay, _urīn,
   {{0x661d9b0f,0xec7611cf,0x9098002d,0x98a00141}},	//   _lask, лпы_, _авут_, _prič_,
   {{0x6aad9b10,0x798d2df0,0x15e30096,0x629b00fe}},	//   _biaf, _ayaw, गणार_, _khuo,
   {{0xceb2004f,0x1cb90080,0x661d3466,0x798d2622}},	//   _היא_, _كاتب_, _nask, _byaw,
   {{0xfce504fd,0x798d0193,0x764d31ed,0x8276006e}},	//   _соло, _cyaw, dkay, רערע_,
   {{0x44fd9b11,0x7e69013f,0x764d0188,0xe7a50966}},	//   dì_, liep, ekay, _गृहप,
   {{0xcfd800c7,0xb87b0f61,0x69bc02d5,0x661d9b12}},	//   _সামন, tuír, _एलपी, _bask,
   {{0x661d37fe,0x6e3b0517,0xe3cd0081,0x62890294}},	//   _cask, njub, _লাগব, _nkeo,
   {{0x6d5b9b13,0xe3b20781,0x798d06b0,0xb87b2ee8}},	// [aae0] nzua, مرا_, _gyaw, ruír,
   {{0xc1cc1a09,0xdb1a9b14,0x69d69b15,0xf8bf0257}},	//   ार्ग, ratö, _heye, uvée_,
   {{0x6e3b7d24,0x661d9b16,0x91d0009f,0xf8bf00fd}},	//   kjub, _fask, दरलै, rvée_,
   {{0x661d1114,0x629b9b17,0xe6120246,0x7e695fe6}},	//   _gask, _chuo, _اشد_, jiep,
   {{0x91e35fa3,0xa06a0a51,0x7e692b31,0x798d022e}},	//   соче, нада_, diep, _xyaw,
   {{0x69d69b18,0x6d5b061d,0x661d7d12,0xdfcf0037}},	//   _leye, dzua, _zask, كيه_,
   {{0xf1b90095,0x09da0033,0x66040a4b,0xe296001f}},	//   _saše_, _থানা, ofik, _браќ,
   {{0x66040284,0xf1b974b4,0x798910a4,0xe8040101}},	//   nfik, _paše_, żewi, श्ता_,
   {{0x6aad55b6,0xacb40291,0x75249b19,0xa49b01b9}},	//   _riaf, јбољ, nviz, _spòi,
   {{0xf1b918f9,0x4cc30081,0x798d05bd,0xa0a6232c}},	//   _vaše_, _শিশু, _ryaw, _сазд,
   {{0xaa591803,0x798d1a27,0x9b94002d,0x69d629e4}},	//   вину_, _syaw, ринц, _beye,
   {{0x201e5bf1,0xc33300a1,0x6f1a041c,0x00000000}},	//   _hati_, צור_, _istc, --,
   {{0x201e87cc,0x661d9b1a,0x69d69b1b,0x00000000}},	//   _kati_, _rask, _deye, --,
   {{0x661d9b1c,0x201e1084,0x3cf10146,0x44fd028d}},	//   _sask, _jati_, ňový_, vì_,
   {{0x7bda9b1d,0x661d9b1e,0x201e113a,0x6604003d}},	//   matu, _pask, _mati_, ffik,
   {{0x201e02b4,0x69d60ea4,0xdb180364,0x764d01c2}},	//   _lati_, _geye, _bevö, ukay,
   {{0x764d9b1f,0xdddb00b6,0x27ff01c2,0xb17d0206}},	// [aaf0] rkay, nouš, ƙun_, _odťa,
   {{0x201e9b20,0x44fd9b21,0x661d9b22,0x36d51a54}},	//   _nati_, rì_, _wask, _коор,
   {{0x44fd9b23,0xd5b106fa,0x629b00de,0x69d60172}},	//   sì_, _وفد_, _phuo, _yeye,
   {{0x7bda3c5b,0xdddb02c6,0x1af7006e,0x661d024a}},	//   hatu, kouš, רמאל_, _uask,
   {{0x7bda9b24,0x201e9b25,0x26de0031,0x7e690365}},	//   katu, _bati_, átov_, viep,
   {{0xd2d71e56,0xd009231c,0x201e020a,0x760d0174}},	//   _مغرب, теке_, _cati_, _ịrịọ,
   {{0x201e9b26,0x7bda9b27,0x629b0019,0x7e690629}},	//   _dati_, datu, _thuo, tiep,
   {{0xddc200a5,0xb87b02a8,0xa267013d,0x6d5b0a00}},	//   _iloś, crív, _съгл, tzua,
   {{0x7bda9b28,0x69d69b29,0xee36022c,0x44210013}},	//   fatu, _reye, рны_, odh_,
   {{0x6e3b9b2a,0x201e00dd,0x7e6968c4,0x408700c2}},	//   sjub, _gati_, siep, _субб,
   {{0x44218e66,0x69d60f8e,0x66040034,0xbf1512eb}},	//   idh_, _peye, yfik, _خواب,
   {{0x201e01e9,0x3cee0096,0x2cae009c,0x00000000}},	//   _zati_, _आमचे_, _eifd_, --,
   {{0x7bda452d,0x44319b2b,0x8e8400e3,0x201e005c}},	//   batu, _onz_, _النه, _yati_,
   {{0x7bda9b2c,0x6c7900c1,0x69d6010a,0x31d10294}},	//   catu, _שאַפ, _weye, ịrịọ_,
   {{0x07a604c9,0x45d60fa5,0x627c0a7f,0x69d6083e}},	//   равн, ицат, nčoc, _teye,
   {{0x645563bf,0xc87f042c,0x66040350,0x00000000}},	//   _alzi, wußt_, ufik, --,
   {{0x660446c3,0xb4663d6e,0x248a0167,0x44660138}},	// [ab00] rfik, акал, _pkbm_, авав,
   {{0x75249b2d,0x3eaf0ab2,0xe4570dfb,0x61fb7fb1}},	//   rviz, _ligt_, ажу_, _acul,
   {{0x3a2008a1,0x201e9b2e,0xe28600ae,0x443102ef}},	//   _kaip_, _rati_, алжи, _dnz_,
   {{0x201e00e9,0x4421328f,0x7bda9b2f,0x44310126}},	//   _sati_, adh_, zatu, _enz_,
   {{0x201e9b30,0x7bda3128,0xb87b0161,0x648b1e3b}},	//   _pati_, yatu, rrív, güis,
   {{0x7ee67f94,0x26de0146,0x3e7a01d3,0x7bda0062}},	//   ацие, štou_, dīta_, xatu,
   {{0x7bda9b31,0xa2e32458,0x00000000,0x00000000}},	//   vatu, _морд, --, --,
   {{0x7bda9b32,0xf53f9b33,0xd252001c,0x99500031}},	//   watu, _igår_, _بنر_, pĺňa_,
   {{0x7bda9b34,0xdd9716fa,0x777e02a0,0x3eaf0537}},	//   tatu, ишь_, _lxpx, _digt_,
   {{0x28b50285,0x00000000,0x00000000,0x00000000}},	//   ंदसि, --, --, --,
   {{0xa3d704f1,0xfee90037,0x29021206,0xdddb00d2}},	//   सरत_, _معنى_, etka_, souš,
   {{0x7bda9b35,0x3ced0501,0xaa677913,0xdddb00b6}},	//   satu, brev_, рток, pouš,
   {{0x7bda9b36,0x4421008c,0xf1b905db,0x00000000}},	//   patu, ydh_, _jaša_, --,
   {{0x27ed02dc,0xf1b94056,0xdca30291,0x588701b3}},	//   ßen_, _maša_, _дачи, рыма,
   {{0x80d80ed3,0x27ed026a,0x29029b37,0x00000000}},	//   _नौसे, ğen_, atka_, --,
   {{0x27ed01e8,0xe65400d6,0x645500d8,0x00000000}},	//   şen_, овсь, _slzi, --,
   {{0xf1b9488c,0x69dd9b38,0xc7b80335,0x26c50138}},	// [ab10] _naša_, mase, žđa_, ūlo_,
   {{0x69dd9b39,0x57f504e6,0x2a69022e,0x03c72178}},	//   lase, _упот, _hmab_, рсам,
   {{0x94a8001f,0xbebc01d3,0x44210052,0xa6ab06cf}},	//   ртта_, _drīk, rdh_, _لاحق_,
   {{0x69dd4586,0x7bd8014b,0x00000000,0x00000000}},	//   nase, _levu, --, --,
   {{0xe4a7001f,0x69dd01ff,0x3eaf26d2,0x271805aa}},	//   _врво, iase, _rigt_, _zōn_,
   {{0x69dd9b3a,0xe2d90068,0xb87b1d32,0x2d8f02b6}},	//   hase, _مارچ_, crít, _ryge_,
   {{0x69dd1dcd,0x2d8f02b6,0x2a6900bc,0x2f1800fe}},	//   kase, _syge_, _omab_, _cũg_,
   {{0x69dd9b3b,0xa49b0154,0x3e7a01d3,0x61fb6204}},	//   jase, _epòt, tīta_, _ucul,
   {{0x69dd9b3c,0x7bd89b3d,0x4bd902b7,0x2d991842}},	//   dase, _bevu, льня_, åse_,
   {{0xa3d700b7,0x3e7a00e8,0x00000000,0x00000000}},	//   सरि_, rīta_, --, --,
   {{0x3a200332,0x5f950dce,0x7bd89b3e,0xaca30134}},	//   _paip_, _الائ, _devu, _nfụk,
   {{0x69dd9b3f,0x7a3f00dd,0x7bce003e,0x3ced0231}},	//   gase, _këty, ðbur, prev_,
   {{0xa3d72999,0x2f019b40,0x7e7e0103,0x68e9042d}},	//   सरा_, lóg_, éppe, šedn,
   {{0x29021c71,0x7bd80db1,0x2a690154,0xf7461061}},	//   rtka_, _gevu, _emab_, бего,
   {{0x3a2008a1,0xdddb003d,0xaa4601b6,0xfaa62e0f}},	//   _taip_, kluż, _гейл, _лако,
   {{0x7bc19b41,0x69c100b6,0xaac40286,0xa3ca00a4}},	//   lclu, ělec, _بتون, ळुन_,
   {{0xe5a31da3,0x3ae3026a,0xb87b0220,0x291e01d3}},	// [ab20] зити, lıp_, trít, ātas_,
   {{0xb87b0623,0x28b502d5,0x68e40372,0xf1b90218}},	//   rsíc, ंदरि, _ivid, _raša_,
   {{0x68e401c5,0xf1b91813,0xe29a0b31,0x3ae3026a}},	//   _hvid, _saša_, гаж_, nıp_,
   {{0xe8040251,0xf1b91be3,0x69c402a1,0x2f010076}},	//   श्रा_, _paša_, _jfie, dóg_,
   {{0xcfcf00c7,0x7bc1422e,0xb87b2c85,0x1fcf0033}},	//   _রাজন, kclu, prít, _রাজস,
   {{0xf1b95716,0x3ae3026a,0xfc220033,0x66169b42}},	//   _vaša_, kıp_, _পক্ষ_, leyk,
   {{0x7646013f,0x7bd89b43,0x69dd9b44,0x2bdb0034}},	//   _koky, _revu, yase, _मज़ा,
   {{0x68e49b45,0x7646010a,0x69dd8e48,0x6a6f022b}},	//   _ovid, _joky, xase, _mòfè,
   {{0x764601b3,0x69dd09a1,0x7bd8007e,0x41270497}},	//   _moky, vase, _pevu, _лото_,
   {{0xb4d6000d,0x409600e3,0x69dd9b46,0x69c40178}},	//   _सबै_, _الطر, wase, _afie,
   {{0x69dd9b47,0x68e40bc3,0x6a159b48,0x6441009c}},	//   tase, _avid, омну, _òlie,
   {{0x764626a1,0x7bd8010a,0x7bc301cd,0x00000000}},	//   _noky, _wevu, _efnu, --,
   {{0xd90f00bf,0x64430149,0x69dd60c8,0x68e400c4}},	//   رید_, önik, rase, _cvid,
   {{0x69dd9b49,0x69c400b3,0x68e400c6,0x9f450076}},	//   sase, _efie, _dvid, _gcló_,
   {{0xf7730e11,0x69dd9b4a,0x764600f9,0x7ac60291}},	//   ساس_, pase, _boky, _усле,
   {{0x8afc00a5,0x00000000,0x00000000,0x00000000}},	//   rzęd, --, --, --,
   {{0x76467686,0x68e40325,0x26de10a8,0x00000000}},	// [ab30] _doky, _gvid, átor_, --,
   {{0xf8b502d5,0xa3a70da5,0xe8b500a4,0x00000000}},	//   ंदीप, бјек, ंदीच, --,
   {{0xb87b002b,0x68e40094,0x59c300b6,0x26de007e}},	//   brír, _zvid, वुअर, štor_,
   {{0x09ad00c7,0x998902e6,0x200c9b4b,0xa3c90378}},	//   _ক্যা, _znaš_, _abdi_, ैरह_,
   {{0x68e49b4c,0x7bc101cb,0x3ae30233,0x00000000}},	//   _xvid, yclu, zıp_, --,
   {{0x3ae301e8,0x7ff500cd,0x1ec92383,0xd8dc0266}},	//   yıp_, زستا, алки_, נקור,
   {{0x8fa2162b,0xaad7009f,0x7d02063d,0xb87b037a}},	//   маше, _भौंक, _aqos, nríq,
   {{0x44239b4d,0x6e229b4e,0x2f019b4f,0x64479b50}},	//   _haj_, _caob, róg_, _hoji,
   {{0x44239b51,0x644703ce,0x628b89fc,0x6e22010b}},	//   _kaj_, _koji, mogo, _daob,
   {{0x628b9b52,0x3d0902b0,0x60c92d19,0x3ae30233}},	//   logo, _वहीं_, _item, tıp_,
   {{0x68e40995,0xeb9944c5,0x649002fd,0x3b091994}},	//   _svid, рин_, päiv, шено_,
   {{0x44239b53,0x64479b54,0x60c90085,0x21290031}},	//   _laj_, _loji, _ktem, ťahu_,
   {{0x229c0146,0xa3a905fa,0xe8f705af,0x7bc101cb}},	//   níka_, खेत_, оля_, pclu,
   {{0x442399e8,0x6e22419a,0x628b2bff,0x649000aa}},	//   _naj_, _zaob, hogo, näit,
   {{0x61e90f5e,0xa7aa55cf,0xf1b902dd,0x764616d4}},	//   _odel, рква_, _našo_, _poky,
   {{0x61e900cd,0x628b9b55,0x3d1d00b6,0x60c9520f}},	//   _ndel, jogo, _भनाइ_, _otem,
   {{0x64470542,0x628b9b56,0x68e47202,0x6616008a}},	// [ab40] _boji, dogo, _uvid, reyk,
   {{0x61e99b57,0x44239b58,0x64479b59,0x7c239b5a}},	//   _adel, _caj_, _coji, _janr,
   {{0xb72400bf,0x7c2305fe,0xe73a08f9,0x260505cd}},	//   _عکسه, _manr, _тен_, _हॉकी_,
   {{0x7afd0067,0x6b7a00c1,0x442301e9,0xd62a0291}},	//   ństw, ברענ, _eaj_, _томе_,
   {{0x44239b5b,0x64a60265,0x61e90150,0xfe7900b6}},	//   _faj_, _мама, _ddel, dnů_,
   {{0x6e22215e,0x61e99b5c,0x2912068d,0xe9f90019}},	//   _saob, _edel, _mpya_, _khả_,
   {{0x60c947fd,0xcf260037,0xddc2078e,0x00000000}},	//   _etem, ترشي, _cloş, --,
   {{0x442301bb,0x7c2303ee,0x628b9b5d,0x00ca00e5}},	//   _zaj_, _aanr, cogo, _влак_,
   {{0x7c239b5e,0x44230197,0x212d2174,0x998002c6}},	//   _banr, _yaj_, _greh_, _aniž_,
   {{0x4423006c,0x61e9033b,0x4cc30033,0x7c2300f0}},	//   _xaj_, _zdel, _শিখু, _canr,
   {{0x6e2210f0,0x64900084,0x61e9052f,0x7c239b5f}},	//   _taob, läis, _ydel, _danr,
   {{0xbebc0029,0xf1b10251,0x7c2d0022,0x7c2301ec}},	//   _brīv, ुँचन, _ɗari, _eanr,
   {{0x649000c2,0xddc200ae,0xd9100018,0x7eb50138}},	//   näis, _emoţ, نیٹ_, _išpa,
   {{0x7c230150,0x8afc007f,0x00000000,0x00000000}},	//   _ganr, rzęb, --, --,
   {{0xe9f90019,0x64472df7,0x628b5478,0x466b9b60}},	//   _chả_, _roji, yogo, арам_,
   {{0x44239b61,0x6447006d,0x64900084,0xf1b90138}},	//   _saj_, _soji, käis, _rašo_,
   {{0x44239b62,0x6447030b,0x628b042d,0xf1b90117}},	// [ab50] _paj_, _poji, vogo, _sašo_,
   {{0xf1b96ed0,0x8afc0034,0xb87b0076,0x44230052}},	//   _pašo_, częc, msío, _qaj_,
   {{0x442301bb,0x628b042d,0x60c97fb8,0x6447077e}},	//   _vaj_, togo, _stem, _voji,
   {{0xf1b90087,0xb87b0161,0xb5fb0131,0x171a021e}},	//   _vašo_, juíz, _amáv, _פורע,
   {{0x442303ce,0xd65600ca,0x649000aa,0xe13500c6}},	//   _taj_, _זירת_, täit, янды,
   {{0x44b4013d,0x94ba00a1,0x4423023e,0x628b149c}},	//   _обяс, _למשת, _uaj_, sogo,
   {{0xa2ab049d,0x2904028e,0x13590076,0x00000000}},	//   जगद्, çmaz_, _الأخ_, --,
   {{0xee3928b9,0x61e99b63,0x7c239b64,0x212d0087}},	//   сни_, _udel, _sanr, _treh_,
   {{0x7c23604e,0x61e4003e,0x28b70557,0x5fcf0861}},	//   _panr, ðile, _इंगि, _स्थल,
   {{0x98a90234,0x00000000,0x00000000,0x00000000}},	//   _brač_, --, --, --,
   {{0xf9890132,0x7c239b65,0x260c0e50,0x69c1030b}},	//   _ער_, _vanr, ड्डी_, ělen,
   {{0xc869040a,0xdce701e8,0x98a90307,0x69c10034}},	//   _גן_, şlık, _drač_, ślen,
   {{0x7c230511,0x00000000,0x00000000,0x00000000}},	//   _tanr, --, --, --,
   {{0x649013ce,0xe9f900fe,0xccf9007f,0xb87b0231}},	//   häir, _phả_, muś_, ssín,
   {{0x2bd102e8,0x81e10033,0x18670b1b,0xf74613a2}},	//   _द्या, _দান_, чари_, чево,
   {{0x98a00b14,0x6b9c0364,0x7e7b9b66,0x00000000}},	//   _orić_, ürge, nnup, --,
   {{0x959a02aa,0x05662e5a,0x29120051,0xcaa50adb}},	// [ab60] ству_, чван, _upya_, _تصوي,
   {{0x1423162c,0x69c601dc,0xe9f900de,0xb87b0a5a}},	//   ндум, lcke, _thả_, nsíl,
   {{0xdc9a00c1,0x69450470,0x67bb00d7,0x00000000}},	//   ציעל, _فضیل, _למיק, --,
   {{0x649002fd,0x645e9b67,0xb87b03be,0xb5fb8d62}},	//   täis, shpi, xuíz, _aláf,
   {{0xc5f30105,0x68e69b68,0x00000000,0x00000000}},	//   _אדר_, nskd, --, --,
   {{0x64900084,0xc0aa02a3,0x859b00ca,0x5f9435c1}},	//   räis, حاصل_, _לשכו, милт,
   {{0x64a3596a,0x638319e8,0x98a00a39,0x649000c2}},	//   _чара, _згра, _erić_, säis,
   {{0x44449b69,0x64909b6a,0x2bd10557,0x76449b6b}},	//   lj_, päis, _द्बा, njiy,
   {{0x444401bb,0x62800381,0x00000000,0x00000000}},	//   oj_, _ijmo, --, --,
   {{0x44445007,0xfd0f0037,0x6aa4010a,0x443802ac}},	//   nj_, اجي_, _ahif, _jnr_,
   {{0x44440197,0x44380185,0xcf8d001c,0x4f6600b9}},	//   ij_, _mnr_, _پژو_, _عاطف,
   {{0x6aa49b6c,0x7f3b00a1,0x61e29b6d,0x764401c2}},	//   _chif, _לעבו, naol, jjiy,
   {{0x3ebe030a,0x444400dc,0x81e10081,0x6aa49b6e}},	//   _hutt_, kj_, _দাম_, _dhif,
   {{0x8c430752,0x7b0500c2,0x98a92a4e,0x61e2033c}},	//   _пече, öttö, _trač_, haol,
   {{0x3ebe00aa,0x7c389b6f,0x6aa4009c,0x6d40013c}},	//   _jutt_, _invr, _fhif, lxma,
   {{0x44449b70,0x7afa9b71,0x6aa437e5,0x61e200aa}},	//   ej_, mutt, _ghif, jaol,
   {{0x7afa3903,0x28b70789,0x44389b72,0x61e200bc}},	// [ab70] lutt, _इंटि, _bnr_, daol,
   {{0x7c2810ad,0x44380036,0x62800218,0xd49b0fe9}},	//   nddr, _cnr_, _ajmo, ёра_,
   {{0x7afa9b73,0x2c0e0096,0x69df0052,0x44389b74}},	//   nutt, त्यू_, _keqe, _dnr_,
   {{0x44440d7d,0x27e39b75,0x645c8116,0x2fde002b}},	//   aj_, lajn_, _elri, _aetg_,
   {{0x92b40e25,0xb5fb026e,0x7afa2349,0x7c381570}},	//   رحما, _alág, hutt, _onvr,
   {{0x7afa9b76,0xe0d02c66,0x69df0372,0x27e30216}},	//   kutt, ازن_, _leqe, najn_,
   {{0x9ea91cf2,0x69c60222,0x752d51a4,0x7afa9b77}},	//   овка_, ycke, lvaz, jutt,
   {{0x7afa8b3f,0xa29400d6,0x7c281044,0x69df0415}},	//   dutt, _засі, eddr, _neqe,
   {{0x3e6a00cd,0xa3a9030b,0x6aa400f0,0xc21200ca}},	//   تجوی_, खेर_, _rhif, _בהן_,
   {{0x6aa4377b,0x8b0702c6,0x7afa3e99,0x60db0372}},	//   _shif, _naří, futt, _iwum,
   {{0x28b7086d,0x3ebe004d,0x7afa00f3,0x69df0372}},	//   _इंजि, _gutt_, gutt, _beqe,
   {{0x60db05bd,0x2d8e0129,0x00000000,0x00000000}},	//   _kwum, ịlị_, --, --,
   {{0x660d66a7,0x752d08a9,0xb5fb0579,0xdbdb0139}},	//   dfak, jvaz, _mlád, _háíd,
   {{0x6e2914ef,0x7afa344b,0xed160018,0xb90602d5}},	//   ldeb, butt, _کہیں_, _पब_,
   {{0x4438009c,0x6aa40167,0xb87b0072,0x7afa9b78}},	//   _rnr_, _thif, csím, cutt,
   {{0x444401bb,0x96950b0a,0x6aa40239,0x60db570a}},	//   wj_, еруш, _uhif, _owum,
   {{0x7d099b79,0xa5070feb,0xfaa704c6,0xc9860037}},	// [ab80] ntes, мета_, _تجوی, _تشغي,
   {{0x44440d7d,0xb5fb5aeb,0xa3ba0037,0x660d02fa}},	//   uj_, _alád, زائر_, afak,
   {{0x7d099b7a,0xf2c501ce,0xdb030072,0x60db4a16}},	//   htes, есін, _ignó, _awum,
   {{0x8b07030b,0x7d0936df,0x60db05bd,0xdb240103}},	//   _zaří, ktes, _bwum, ésév,
   {{0x61e29b7b,0x7d09023b,0x51830291,0x6e299a31}},	//   raol, jtes, куша, ddeb,
   {{0xdfcf00ab,0x645c227a,0xf1a91f11,0x41ce5d46}},	//   ليه_, _ulri, سانه_, _ह्रस,
   {{0x61e2028d,0x63bc007e,0x60db2673,0xdde10218}},	//   paol, _igrn, _ewum, _šuša,
   {{0x27e32179,0x7afa00c2,0x6e299b7c,0x7d099b7d}},	//   zajn_, vutt, gdeb, ftes,
   {{0x7eb50138,0xc0060f0c,0x7c3801c8,0x7d099b7e}},	//   _išpl, _опак, _pnvr, gtes,
   {{0x7afa9b7f,0x61e00149,0x3ebe00e5,0x6e39010a}},	//   tutt, _heml, _tutt_, _enwb,
   {{0x61e09b80,0x93f70327,0x7d099b81,0x2c60022b}},	//   _keml, וציא_, ates, _nòde_,
   {{0x60c09b82,0x7afa5a3d,0xd9ad0081,0x201c9b83}},	//   _kumm, rutt, _ক্ষম, levi_,
   {{0x27e30106,0x60c09b84,0x7d099b85,0x61e01172}},	//   tajn_, _jumm, ctes, _meml,
   {{0x60c09b86,0x7afa4bea,0x3e7a01d3,0xddc96b91}},	//   _mumm, putt, dīti_, mieš,
   {{0x27e303e5,0x7bca009e,0x660d9b87,0xddc900e8}},	//   rajn_, _iffu, tfak, lieš,
   {{0x61e09b88,0xfe140789,0xb5fb0076,0x32d50065}},	//   _neml, _थॉमस_, _amár, _lúyò_,
   {{0x60c044cb,0xd7d0110f,0x1fab06ed,0xddc900d9}},	// [ab90] _numm, _त्वच, _चण्ड, nieš,
   {{0x201c02e6,0x752d9b89,0x2c6023c0,0xb5fb0094}},	//   jevi_, rvaz, _fòde_, _slád,
   {{0xa3a90d1b,0xc7d60054,0xd3711857,0x3a290185}},	//   खें_, _אותי_, دها_, _kaap_,
   {{0xa4d500d6,0x3a2924e7,0x7d099b8a,0xd3a410b8}},	//   _помі, _jaap_, ytes, труп,
   {{0xb5fb0074,0x3a293c1c,0x7bca9b8b,0x61e4003e}},	//   _vlád, _maap_, _offu, ðila,
   {{0x8fa506d5,0x78fc00ca,0x26c10141,0xf1b90141}},	//   нале, קלופ, _kuho_, _maši_,
   {{0x26c19b8c,0x2eb59b8d,0x3ea601b9,0xd00e0076}},	//   _juho_, нсис, _bhot_, صلي_,
   {{0x6d252440,0x7bca9b8e,0x26c19b8f,0x60db02a4}},	//   едиз, _affu, _muho_, _twum,
   {{0x6fca0851,0x26c19b90,0x200903e3,0x60db460c}},	//   _स्कू, _luho_, ƙai_, _uwum,
   {{0xf1b913e8,0x201c3d37,0x224d03ee,0x68fd9b91}},	//   _naši_, cevi_, _hoek_, dusd,
   {{0x09ad0081,0xdbdc01cd,0x224d9b92,0x7d090fda}},	//   _ক্লা, ráði, _koek_, stes,
   {{0x7bca083e,0x60c071f7,0xc3320089,0x00000000}},	//   _effu, _yumm, אוט_, --,
   {{0x3ead0c2e,0xddc90029,0x19b900d3,0x68fd8504}},	//   mmet_, cieš, дурь_, gusd,
   {{0x3ead9b93,0x26c19b94,0x224d01cb,0x00000000}},	//   lmet_, _buho_, _loek_, --,
   {{0x4ac60442,0x60130491,0x6a9600d6,0x5a960396}},	//   _रूपव, mımı, _приє, _приф,
   {{0x09da0081,0xb5fb9b95,0xe61f0220,0x3e7a01d3}},	//   _থাকা, _aláb, _skôr_, tīti_,
   {{0x33f603f2,0xdbe20139,0x3ead0311,0x61e001cb}},	// [aba0] ечес, _béèd, imet_, _reml,
   {{0x60c09b96,0x3ead9b97,0x601303a3,0x8726097a}},	//   _rumm, hmet_, nımı, _змож,
   {{0x224d0934,0xaca30129,0x60c09b98,0x7794110a}},	//   _boek_, _ahịh, _summ, _شیرا,
   {{0x3ead00dd,0x224d02ef,0x27e101bf,0x20051e3f}},	//   jmet_, _coek_, _zehn_, _acli_,
   {{0x645b0068,0x3ead5be4,0x201c7bcc,0x6013026a}},	//   áció, dmet_, tevi_, kımı,
   {{0xddc939c1,0x3ea69b99,0x260c02d5,0xe4d70037}},	//   vieš, _shot_, ड्री_, _سوفت_,
   {{0x442a022e,0x03a31f46,0xda200251,0x53a31111}},	//   _iab_, _биро, _बसंत_, _барб,
   {{0x442a9b9a,0x60c09b9b,0xddc901d3,0x200500bd}},	//   _hab_, _tumm, tieš, _ecli_,
   {{0x644e0067,0x442a9b9c,0x60c00270,0x201c038f}},	//   _kobi, _kab_, _uumm, pevi_,
   {{0x224d0505,0xddc97031,0x2cb80149,0x3ead0f06}},	//   _zoek_, rieš, örd_, amet_,
   {{0x442a9b9d,0x3ea6023b,0x1eda13c3,0x59f99b9e}},	//   _mab_, _thot_, _رباب_, меня_,
   {{0x24560088,0x69c08802,0xf1b9007e,0x26c10559}},	//   _dæmi_, žmen, _saši_, _ruho_,
   {{0x2bd1278e,0x26c12ee0,0x442a0161,0xf1b901d3}},	//   _द्वा, _suho_, _oab_, _paši_,
   {{0x442a006c,0x7bca0036,0x6013020e,0x1fde00b6}},	//   _nab_, _uffu, cımı, _नजोड,
   {{0xf1b99b9f,0x443f0023,0x7c2a084e,0x6b66014b}},	//   _vaši_, _đu_, _iafr, _dégé,
   {{0x3a2933aa,0x442a9ba0,0x7c2a9ba1,0x4b3700ca}},	//   _uaap_, _aab_, _hafr, _טרול_,
   {{0x442a34ac,0x59d400e3,0x947500d1,0x00000000}},	// [abb0] _bab_, _صغير, نگسا, --,
   {{0x442a9ba2,0x224d0665,0xaaa52a24,0x3ead01e8}},	//   _cab_, _soek_, _गीतक, zmet_,
   {{0x442a01bb,0x7c2a00b6,0x225f0abf,0xb1ce0174}},	//   _dab_, _mafr, _pluk_, _ịrịa_,
   {{0x7c2a02f1,0xdbe20032,0x442a01c8,0x6013071d}},	//   _lafr, _dééd, _eab_, zımı,
   {{0x442a37fe,0x85b82fd4,0x99800095,0x60130555}},	//   _fab_, _плюс_, _kaiš_, yımı,
   {{0x644e42be,0x442a9ba3,0x80d30081,0x601300a7}},	//   _gobi, _gab_, _সিদ্, xımı,
   {{0x3ead1e4f,0x26c500d4,0xf83800ca,0xb87b00d4}},	//   tmet_, íloh_, תנות_, rsíh,
   {{0x3eb99ba4,0x68ed9ba5,0x442a9ba6,0x7c2a00bc}},	//   öst_, _ovad, _zab_, _aafr,
   {{0x3ead9ba7,0x442a9ba8,0x51873574,0x22842c49}},	//   rmet_, _yab_, _чува, _сург,
   {{0x09e10081,0x3ead9ba9,0x442a006c,0x3e7a01d3}},	//   _ভাষা, smet_, _xab_, dītu_,
   {{0x6fca000f,0x764f9baa,0x60130702,0x68ed9bab}},	//   _स्टू, _oocy, rımı, _avad,
   {{0x1611245a,0x7c2a02a1,0x2bd100a4,0x2a6002a1}},	//   _डॉलर_, _eafr, _द्रा, _qlib_,
   {{0xed4e2f03,0x260c007f,0x60130342,0x8d920d5b}},	//   _то_, _डॉगी_, pımı, _پلوش,
   {{0xfaf800d9,0x38a40149,0x3156006e,0xeaf902a3}},	//   brī_, föra_, דישן_, _قربت_,
   {{0x644e3239,0x442a9bac,0x6b668d39,0x6e2b0e62}},	//   _robi, _rab_, _végé, _kagb,
   {{0x442a01bb,0x644e9bad,0xdbe200fd,0x69bc02d5}},	//   _sab_, _sobi, _rééd, _एलटी,
   {{0xd0400253,0x442a0d7d,0x6e2b4c9c,0x644e2652}},	// [abc0] _etmə, _pab_, _magb, _pobi,
   {{0x442a01bb,0x6e2b026e,0x644e0085,0x446300c9}},	//   _qab_, _lagb, _qobi, авув,
   {{0x2c130ff9,0x442a9bae,0xf1b9015c,0x68ed00d8}},	//   त्यं_, _vab_, _mašu_, _zvad,
   {{0x6e2b4c9c,0x90e600cd,0xd25900d6,0x627c0094}},	//   _nagb, نستن, нці_, hčov,
   {{0x442a01bb,0xa06a16e6,0x644e9baf,0x81e10a43}},	//   _tab_, мада_, _tobi, _দাশ_,
   {{0x442a9bb0,0x644e005f,0x660478c2,0x627c00b6}},	//   _uab_, _uobi, lgik, jčov,
   {{0x7c2a9bb1,0x6e2b9bb2,0xe9f900fe,0x00000000}},	//   _rafr, _bagb, _chẻ_, --,
   {{0x66047693,0xdceb026a,0x3878573b,0x00000000}},	//   ngik, _azgı, hirr_, --,
   {{0xa3d600af,0x628204de,0xdbdc01cd,0xd02600e5}},	//   _सभा_, mnoo, _báðu, _имай,
   {{0x628201cb,0x3fcb0281,0x00000000,0x00000000}},	//   lnoo, _قدمی_, --, --,
   {{0x6fd805cd,0x68ed0941,0x6e2b9bb3,0xb87b2351}},	//   _न्यू, _svad, _fagb, príz,
   {{0x6f790130,0x62829bb4,0xb87b0161,0x752402a4}},	//   _אָנג, nnoo, nsív, kwiz,
   {{0x94030251,0x6e209bb5,0xd87700e3,0x7c2a024a}},	//   _लालच_, memb, ناسب, _tafr,
   {{0x6e202ea0,0x58d4246b,0x7d0025cc,0x3e7a01d3}},	//   lemb, рорт, mums, rītu_,
   {{0x7e629bb6,0x8c1b00a1,0x62823337,0x3e7a00e8}},	//   _klop, _חווי, knoo, sītu_,
   {{0x6e209bb7,0x80d30081,0x6604019c,0xb595007b}},	//   nemb, _সিস্, ggik, гибш,
   {{0xa5070084,0x7d009bb8,0x39440149,0x75249bb9}},	// [abd0] ъявл, nums, ämst_, gwiz,
   {{0x6e201658,0xd37b0476,0x648b01d3,0x07eb0018}},	//   hemb, мче_, kļie, _کرکٹ_,
   {{0x764f00f0,0x6235001f,0x7d000095,0x3e7a01d3}},	//   _tocy, лежу, hums, nīts_,
   {{0x6e209bba,0x62820673,0x62531275,0xcb13006e}},	//   jemb, gnoo, _açor, ילע_,
   {{0x6e200517,0x7d009bbb,0xed460018,0x6f1a0072}},	//   demb, jums, _اپ_, _aptc,
   {{0x6e2b9bbc,0x62820188,0xaa201bc3,0x7eb500c6}},	//   _sagb, anoo, _बस्छ_, _išpi,
   {{0x6e2b7759,0x44211458,0x62829bbd,0x9f47023b}},	//   _pagb, meh_, bnoo, manë_,
   {{0x442148d4,0x3e7a00d9,0x05a72373,0x7e629bbe}},	//   leh_, dīts_, _खराब, _clop,
   {{0xf1b900d9,0x7d009bbf,0x5184297a,0x00000000}},	//   _pašu_, gums, _куфа, --,
   {{0x44219bc0,0xe9f90019,0x399d01f9,0x00000000}},	//   neh_, _thẻ_, zású_, --,
   {{0x6e2b9bc1,0xf1b9161f,0x6e205a33,0x09e647ff}},	//   _tagb, _vašu_, bemb, лонн,
   {{0x44219bc2,0xcd35037f,0x7d0064fd,0x7e62004d}},	//   heh_, _مرتب, bums, _glop,
   {{0x4421113a,0x9f47023b,0x7ea5037a,0x9403007f}},	//   keh_, kanë_, cópa, _लांच_,
   {{0x44210ea3,0x7e621912,0x8c42020f,0x80d80285}},	//   jeh_, _zlop, _геше, नीटे,
   {{0x91e3007a,0x399d0103,0x7c210abf,0xf1b900c4}},	//   खराज_, tású_, melr, _zašt_,
   {{0x75249bc3,0x787400a7,0x44210113,0x00000000}},	//   twiz, _müvə, eeh_, --,
   {{0x96b90805,0xe9f90019,0xc224001c,0x85060037}},	// [abe0] туру_, _nhẹ_, یکرو, طوان,
   {{0x6e209bc4,0x290275e8,0x44219bc5,0x75240027}},	//   zemb, muka_, geh_, rwiz,
   {{0x6e203107,0x7d009bc6,0xb17d0220,0xe1fa9bc7}},	//   yemb, zums, _reťa, еге_,
   {{0x26d89bc8,0x1c130557,0x2c130167,0x51860360}},	//   mpro_, त्तल_, त्तं_, лула,
   {{0x29029bc9,0x62829bca,0x442100bf,0xb87b016d}},	//   nuka_, rnoo, beh_, rsív,
   {{0x3cf90067,0xb87b00c9,0xb4c00490,0x6e2065de}},	//   ोंने_, ssív, ँदी_, wemb,
   {{0x6e20015e,0xe816014e,0x29020193,0x7e629bcb}},	//   temb, द्या_, huka_, _plop,
   {{0xe3c107aa,0x29029bcc,0x7d0005b5,0x9d1800ae}},	//   ğış_, kuka_, tums, воит_,
   {{0x6e2026d9,0x127b0130,0x29029bcd,0x425303c5}},	//   remb, _נאמע, juka_, _انقر,
   {{0x7ea50018,0x3e7a00d9,0x7c219bce,0x13e80033}},	//   rópa, tīts_, gelr, _পাড়,
   {{0x6e204a0e,0x7d009bcf,0x8fa6193d,0x7d090052}},	//   pemb, sums, _саже, _përç,
   {{0xfce60da5,0x29029bd0,0xb5fb5956,0x320612ff}},	//   _бодо, fuka_, _alán, ngoy_,
   {{0x6e933345,0x44219bd1,0xf1b900e7,0x29025c3e}},	//   _النا, yeh_, _hašr_, guka_,
   {{0x36d50291,0x6d4600c2,0x27ea03e3,0xf7730411}},	//   иогр, äkau, gabn_, ماز_,
   {{0x395f39c1,0x2bda030b,0x44210141,0x81ea0033}},	//   šus_, _म्या, veh_, _মান_,
   {{0x44217186,0xf8bf00fd,0x45d5002d,0x9f450313}},	//   weh_, uvés_, роас, _belê_,
   {{0xf8bf025a,0x44219bd2,0x62830257,0x229c00b6}},	// [abf0] rvés_, teh_, énom, níku_,
   {{0x225d0510,0xb5fb0610,0x35b4376f,0xf36726d0}},	//   wkwk_, _glán, сбур, лтен,
   {{0x9f4700dd,0x44219bd3,0x69dd00f9,0x6aad041c}},	//   ranë_, reh_, obse, _khaf,
   {{0x44219bd4,0x60cd22a4,0x644806a3,0xeb9700c1}},	//   seh_, íamo, _òdin, נדאר_,
   {{0x44219bd5,0x61451491,0x9f4700cd,0x2d800220}},	//   peh_, рела, mané_, _žien_,
   {{0x3f9e025b,0x5fcf06ed,0x9f4700cd,0x008400d6}},	//   _bytu_, _स्खल, lané_, бліо,
   {{0xe7e6009d,0x29029bd6,0x7c2180b5,0xfe451b60}},	//   करता_, zuka_, velr, инко,
   {{0xee3909b9,0x7c219bd7,0x29029bd8,0x764d9bd9}},	//   тни_, welr, yuka_, njay,
   {{0x656d9bda,0x98a9007f,0x7c219bdb,0x290201ff}},	//   nzah, _grać_, telr, xuka_,
   {{0x9f6b0020,0x5c553051,0x61eb9bdc,0x9f479bdd}},	//   _през_, ртиф, lagl, hané_,
   {{0x9f479bdd,0x290201a6,0x6aad01b9,0x68fd0abf}},	//   kané_, wuka_, _bhaf, ersd,
   {{0x61eb2839,0x6f0356ba,0x6aad9bde,0x29029bdf}},	//   nagl, munc, _chaf, tuka_,
   {{0x9f4753a0,0x6f039be0,0xb5fb0074,0xaca30174}},	//   dané_, lunc, _plán, _agụk,
   {{0x29029be1,0x200767b9,0x61eb0c19,0x6d5b01fa}},	//   ruka_, ngni_, hagl, myua,
   {{0x6f031ec8,0xfaa644ce,0x66e6300b,0x290219fa}},	//   nunc, _како, роба, suka_,
   {{0x29020051,0x7e7b02e7,0x7afc9be2,0x6aad9be3}},	//   puka_, niup, árte, _ghaf,

   {{0x6d5b0197,0x69c41031,0x61eb9be4,0xd8f40504}},	// [ac00] nyua, _igie, dagl, _ازبک,
   {{0x6f039be5,0x7e7b0009,0xe45f0212,0x69c402a1}},	//   kunc, hiup, _stör_, _hgie,
   {{0x9f479be6,0xf7460a11,0xdc21009e,0x61eb01df}},	//   bané_, _тено, _aċċi, fagl,
   {{0x61eb00e5,0x68e49be7,0xb87b0018,0x6f0309ac}},	//   gagl, _kwid, ssít, dunc,
   {{0x7bc3008f,0xb17d0220,0x6d5b023e,0xdddb06b0}},	//   _ognu, _deťo, jyua, akuŋ,
   {{0xa07302ec,0x68e44835,0xb60800d4,0x00000000}},	//   огіч, _mwid, _fešá, --,
   {{0x53aa06ed,0x61eb028d,0xdc21009e,0x2d80020a}},	//   _करिश, bagl, _eċċi, _ţie_,
   {{0xa2cb40c1,0x6289023b,0x61eb4aa3,0xd1760dd8}},	//   _तंत्, _gjeo, cagl, _кызы,
   {{0x6d5b023e,0xbebc01d3,0x9046001c,0x68e4009c}},	//   gyua, _krīz, _پناه, _nwid,
   {{0x9f470244,0xb5fb0032,0xeb4a001c,0x6aad5fba}},	//   zané_, _alál, نشجو_, _shaf,
   {{0xe9f90028,0x6f039be8,0x9f4700bf,0x656d02a1}},	//   _chế_, cunc, yané_, zzah,
   {{0xc3330054,0x7e6964fb,0x6d5b023e,0xddc200d4}},	//   קור_, chep, byua, _hmož,
   {{0x9f470871,0xac180095,0x272700f0,0xdd920981}},	//   vané_, _болу_, _sŵn_, _بوش_,
   {{0x78620181,0xdc0801d3,0x69c40062,0xd7f8015f}},	//   _dôvo, _rēķi, _egie, иус_,
   {{0xe81602e8,0x9f479be9,0xb4c0000d,0xe9f90019}},	//   द्धा_, tané_, ँदै_, _ghế_,
   {{0x798d0d7d,0x656d0364,0x9f450383,0xb8fd0033}},	//   _txaw, tzah, _delè_, _ডি_,
   {{0x764d29cb,0x9f479bea,0x61eb9beb,0x611a00d9}},	// [ac10] rjay, rané_, vagl, nālā,
   {{0xe8163245,0x9f479bea,0xea000019,0x98650068}},	//   द्दा_, sané_, _trải_, _ایسے_,
   {{0x61eb9bec,0x9f479bdd,0x656d0364,0xbebc01d3}},	//   tagl, pané_, szah, _drīz,
   {{0x09bb00c7,0x200c010a,0xdddb00e7,0x7e690052}},	//   _অ্যা, _acdi_, knuš, xhep,
   {{0xe1f8004b,0x200c05bd,0x7e7b00c4,0x05841e46}},	//   ргі_, _bcdi_, viup, _дурм,
   {{0x6f03898d,0x6d5b023e,0x2c690065,0x00000000}},	//   tunc, vyua, _kúde_, --,
   {{0x61eb00a6,0x7e7b005c,0xb5fb0314,0x443101e9}},	//   pagl, tiup, _llám, _iaz_,
   {{0x44319bed,0x7ea50072,0x6d490a00,0x6f039bee}},	//   _haz_, rópo, txea, runc,
   {{0xee36022c,0x44319bef,0x7ea54d05,0xbef40094}},	//   сны_, _kaz_, sópo, _číňa,
   {{0x44310b27,0x3c6502fd,0x62990283,0xac1800d6}},	//   _jaz_, ског, lowo, ацює_,
   {{0x64559bf0,0x61e90006,0x6d5b6eb7,0x20120092}},	//   _mozi, _keel, syua, əyi_,
   {{0x645502e6,0x78620181,0x60c19bf1,0x9f457f71}},	//   _lozi, _pôvo, _hilm, _relè_,
   {{0x61e97547,0x61e404c8,0x60c10138,0x60c90113}},	//   _meel, ðili, _kilm, _juem,
   {{0xe9f900ef,0x64550d33,0x44319bf2,0x60c90172}},	//   _thế_, _nozi, _naz_, _muem,
   {{0x62995b31,0x60c17ee8,0x475900d3,0x2d9200f3}},	//   kowo, _milm, артя_, _øyer_,
   {{0x9f450363,0xcf92006e,0x68e402a1,0x61e99bf3}},	//   _celé_, פטן_, _twid, _neel,
   {{0x629935ef,0x44319bf4,0xceb200ca,0x9f450065}},	// [ac20] dowo, _baz_, ליל_, _delé_,
   {{0x64550396,0x44319bf5,0x60c15a50,0x48060120}},	//   _cozi, _caz_, _nilm, _упов,
   {{0x61e958a6,0x645599d0,0xddcb0034,0x9f450103}},	//   _beel, _dozi, _mogł, _felé_,
   {{0x61e9008a,0xdb9a006e,0x66ed00c3,0x171b006e}},	//   _ceel, אסער, _जबतक_, _גוטע,
   {{0x60c10dea,0x61e90934,0x44319bf6,0x863700a1}},	//   _bilm, _deel, _faz_, _הרכב_,
   {{0xd2590029,0x60c1008a,0x60c90451,0x3a3200f9}},	//   _viņa_, _cilm, _duem, _layp_,
   {{0x26c29bf7,0x60c19bf8,0xb5fb0139,0xb7db0089}},	//   _kiko_, _dilm, _amáy, אקצי,
   {{0x61e9900f,0x629900a5,0xb5fb0af0,0xa2c50285}},	//   _geel, cowo, _aláj, िदर्,
   {{0x64550027,0x443103a3,0xdc3c0078,0xe9f90023}},	//   _yozi, _yaz_, _aġġu, _chẽ_,
   {{0xddc218ed,0x61e99bf9,0x26c29bfa,0x611a01d3}},	//   _umož, _zeel, _liko_, rālā,
   {{0x61e90694,0xfd0f00d0,0xb4db05fe,0x6a6601cd}},	//   _yeel, وجی_, _gràf, _sófa,
   {{0xaa673031,0x61e90188,0x00000000,0x00000000}},	//   сток, _xeel, --, --,
   {{0x9f459bfb,0xb5fb0072,0x2e3700ca,0x60c1047e}},	//   _relé_, _imáx, _לראש_, _yilm,
   {{0x26c20044,0x9f4501dc,0x67d4831a,0xf88b0076}},	//   _aiko_, _selé_, зору, اضحى_,
   {{0x44313239,0x27ff07d1,0x26c200ac,0xeac90019}},	//   _raz_, ğun_, _biko_, _hẹn_,
   {{0x64559bfc,0xea000019,0x26c25ebb,0xf1ba0101}},	//   _sozi, _trại_, _ciko_, ेशान,
   {{0x545523c3,0x44310d9f,0x26c20270,0x2a6905db}},	// [ac30] оват, _paz_, _diko_, _ilab_,
   {{0x2a69022e,0x61e91dd2,0x44310092,0x62999bfd}},	//   _hlab_, _seel, _qaz_, wowo,
   {{0x645513ad,0x94a80465,0x0ec40b94,0x44319bfe}},	//   _vozi, стта_, _लंगड, _vaz_,
   {{0x60c1198c,0x26c20027,0xd9fb02d5,0x00000000}},	//   _silm, _giko_, ्लित_, --,
   {{0x62992f1d,0x44319bff,0xe3e800c7,0x61e97d74}},	//   rowo, _taz_, _পারব, _veel,
   {{0x212d02dd,0x60c111bc,0x81e10081,0x62999c00}},	//   _vseh_, _qilm, _দাও_, sowo,
   {{0x786b0b88,0x61e99c01,0xb4db01b9,0x60c90231}},	//   _güve, _teel, _bràg, _wuem,
   {{0x826503a9,0xeac9020b,0x00000000,0x00000000}},	//   _بهرن, _bẹn_, --, --,
   {{0x60c19c02,0xb5fb026e,0x2bda0980,0xb4db01b9}},	//   _tilm, _alák, _म्हा, _dràg,
   {{0x2a6907ac,0x9f479c03,0xb4db0428,0x00000000}},	//   _alab_, laní_, _tràf, --,
   {{0x2dd596c6,0x661d536a,0x2a6900c4,0xb4db015e}},	//   _джер, _obsk, _blab_, _fràg,
   {{0x753d0068,0x9f472351,0xa5bb0af0,0x6fe10033}},	//   _orsz, naní_, _gbóg, _নায়ে,
   {{0x26c29c04,0x00000000,0x00000000,0x00000000}},	//   _riko_, --, --, --,
   {{0x8c45007e,0x26c29c05,0x2a6900aa,0xb9270134}},	//   _феке, _siko_, _elab_, letị_,
   {{0x81ea0081,0x18a301b3,0x9f470e43,0x00000000}},	//   _মাস_, фарм, kaní_, --,
   {{0x2a6900f9,0x8afc0034,0xb92706c0,0x00000000}},	//   _glab_, rzęt, netị_, --,
   {{0x9f472351,0xeac900de,0xa50a2657,0x786b5d61}},	// [ac40] daní_, _kẹo_, реза_, _süve,
   {{0x26c2014b,0x00000000,0x00000000,0x00000000}},	//   _wiko_, --, --, --,
   {{0xeac90019,0xa5bb0139,0x26c29c06,0xb9270134}},	//   _mẹo_, _abód, _tiko_, ketị_,
   {{0xe81600c3,0x29020188,0xb9270134,0xa3d600aa}},	//   द्रा_, orka_, jetị_, _सभक_,
   {{0x2ba602d5,0xb4db01b9,0x764647e7,0xdfd4022a}},	//   _ऑर्थ, _cràd, _inky, полы,
   {{0x2902008c,0x00000000,0x00000000,0x00000000}},	//   irka_, --, --, --,
   {{0xed500018,0x42d6084c,0x03a34c46,0x00000000}},	//   کھا_, _фігу, _жиро, --,
   {{0x63ae00e7,0x200000d3,0x672200e7,0xbe8a0291}},	//   _izbn, şii_, _ćojl, јске_,
   {{0xddc200a5,0xd25900d9,0xd00a0831,0xa5bb0af0}},	//   _umoż, _ziņo_, _везе_, _gbód,
   {{0x09e32183,0x0bf30084,0x628353bc,0xeac90023}},	//   पर्य, мпью, énov, _vẹn_,
   {{0x2a69006c,0x20d00019,0x29029c07,0x7f860dce}},	//   _plab_, _hài_, erka_, _بلان,
   {{0x61e23c6e,0xb5fb033d,0x290201c2,0x00000000}},	//   nbol, _vlák, frka_, --,
   {{0x17e20081,0x00000000,0x00000000,0x00000000}},	//   _বাড়ি, --, --, --,
   {{0x20d00023,0xd7c90037,0xfb8600d3,0x9f470e43}},	//   _mài_, صوره_, _мыйн, zaní_,
   {{0x61e254b0,0x29029c08,0x7c2800f0,0xdcc80023}},	//   kbol, arka_, medr, _mỉm_,
   {{0xfb87001c,0x00000000,0x00000000,0x00000000}},	//   _بدهی, --, --, --,
   {{0x9f471cf3,0x61e201c5,0x20d000fe,0x661d54a0}},	// [ac50] vaní_, dbol, _nài_, _vbsk,
   {{0x9715184d,0xa3a70831,0x2c60022b,0x76469c09}},	//   _емоц, ојек, _bòdi_, _enky,
   {{0xd498036c,0x8c2500c7,0x9f470031,0x2c6000b3}},	//   іру_, বাচন_, taní_, _còdi_,
   {{0x20d0011b,0x7c2802e5,0x61e29c0a,0x61200294}},	//   _bài_, hedr, gbol, _ịlag,
   {{0xdd86054f,0x20d00028,0x9f47025b,0x712733c6}},	//   _أو_, _cài_, raní_, ترال,
   {{0x20d00028,0x55ba00a1,0x61e20ef0,0x660d4748}},	//   _dài_, _למרו, abol, lgak,
   {{0x61e29c0b,0xdb030579,0x752d9c0c,0x7c280407}},	//   bbol, _ozná, lwaz, dedr,
   {{0x660d9c0d,0x29029c0e,0x69db1186,0xeac90023}},	//   ngak, yrka_, ñuel, _sẹo_,
   {{0x7c289c0f,0xd840025b,0xb5fb00e3,0x628b49e9}},	//   fedr, íčky_, _clái, mngo,
   {{0x7c284bd8,0x60db0ae4,0x2c690c84,0x00000000}},	//   gedr, _itum, _búda_, --,
   {{0x628b0010,0xfaa61111,0xbb4504fd,0xb5fb037a}},	//   ongo, зано, ченк, _tláh,
   {{0x752d9c10,0x213f2281,0x628b743a,0xce380037}},	//   kwaz, _kruh_, nngo, _وأنا_,
   {{0x7c286888,0x752d8375,0x20d000de,0x2902008a}},	//   bedr, jwaz, _xài_, urka_,
   {{0x60db068d,0x7d099c11,0x9f47016d,0x6e290188}},	//   _mtum, mues, canã_, leeb,
   {{0xa7aa7207,0x7d099290,0x61e20935,0xf7435a70}},	//   сква_, lues, ybol, неро,
   {{0x6447005a,0xc6c364ba,0x61fb9c12,0x60db59e1}},	//   _anji, ейск, _ndul, _otum,
   {{0x2bd21ae6,0x7d09023b,0xb4db00ee,0x60db0435}},	// [ac60] _सलमा, nues, _aràb, _ntum,
   {{0x39409c13,0x673e04e9,0xd7f100fe,0x660d01c8}},	//   _iris_, _trpj, ữa_, agak,
   {{0xf8b300a1,0x60db51c4,0x20d00019,0x24860106}},	//   _רשת_, _atum, _sài_, đom_,
   {{0x39409c14,0x64479c15,0xf53f00f3,0x7d0900dd}},	//   _kris_, _enji, _frå_, kues,
   {{0xf53f017a,0x463b00c1,0xb5fb0af0,0x7d09023b}},	//   _grå_, _העכע, _aláw, jues,
   {{0x20d00019,0x213f025b,0x61e28a94,0x61fb808c}},	//   _vài_, _druh_, sbol, _edul,
   {{0x7c289c16,0xb5fb00e3,0x91e63047,0xd9b91757}},	//   vedr, _slái, _нове, _इण्ट,
   {{0x20d000ef,0x39400af0,0x786b0092,0x78700212}},	//   _tài_, _oris_, _müva, _hävd,
   {{0x2ab20018,0x3940023e,0x628201a5,0x63a201c2}},	//   kább_, _nris_, mioo, ƙons,
   {{0xf04409b4,0x6282748f,0xdfcf0037,0x25dc0096}},	//   _تعری, lioo, _ميك_, गुती_,
   {{0x7c280501,0x2fd7001c,0x673c04e9,0x6e294463}},	//   redr, _روند_, jvrj, beeb,
   {{0xaf4900e3,0xcf2500e3,0xe81f00b7,0x39409c17}},	//   _بشكل_, _تركي, म्ना_, _bris_,
   {{0x8c465fdd,0x7d0909b3,0xb5fb0618,0xdb0300d4}},	//   _неде, cues, _kláv, _vzná,
   {{0x80e10033,0xd91800c2,0xddc9007f,0x39409c18}},	//   _নিম্, чью_, zież, _dris_,
   {{0x628b00f0,0xec3700ca,0x15da0129,0xc5da0174}},	//   yngo, _מאגר_, _ọbụl, _ọrụb,
   {{0x443f0b88,0x752d9c19,0x394004e2,0xdb030146}},	//   _şu_, twaz, _fris_, _uzná,
   {{0x660d9c1a,0xba3b81a0,0x62829c1b,0x6fcc00a4}},	// [ac70] rgak, roïd, dioo, ाशां,
   {{0x628b0150,0x29194c19,0xb4db1e8c,0x9f4700d4}},	//   wngo, mtsa_, _aràc, haná_,
   {{0x290b9c1c,0x752d9c1d,0xaca40134,0x7d09023b}},	//   luca_, swaz, _ngọz, zues,
   {{0xe3b00080,0x628b9c1e,0x628200aa,0x9f4e0381}},	//   ارك_, ungo, gioo, café_,
   {{0x6e29650c,0xaca40134,0x9f47025b,0x29199c1f}},	//   veeb, _agọz, daná_, ntsa_,
   {{0xf9940130,0x8fa502b3,0x6e290283,0x7d090052}},	//   ערס_, мале, weeb, vues,
   {{0xc7d800ca,0x66260103,0x213f01dc,0xe81f0714}},	//   לוגי_, _ütkö, _wruh_, म्या_,
   {{0xb4db0990,0x7d0900dd,0x7bca009c,0xaca30174}},	//   _gràc, tues, _agfu, ruọn,
   {{0x60db068d,0x63a7023b,0x6e291f9a,0x290b9c20}},	//   _utum, _hyjn, reeb, juca_,
   {{0x7d0900dd,0x787000c2,0x290b1ad8,0xe81f02f0}},	//   rues, _käve, duca_, म्मा_,
   {{0x6ee79c21,0x2ab20068,0x7d0900dd,0x04030033}},	//   _رسال, vább_, sues, র্থী_,
   {{0x39401842,0x7d090eb8,0x38a402e2,0x290b00e7}},	//   _pris_, pues, hört_, fuca_,
   {{0x7d0972a7,0x9f64007b,0x786b9c22,0x00000000}},	//   ques, ätön_, _süva, --,
   {{0x3e830032,0x04030033,0xcb690284,0x660900e8}},	//   _fètè_, র্তী_, _мале_, _ķeka,
   {{0x07a30848,0xb8d50006,0xc7951ad1,0x291f0216}},	//   варн, _छी_, ерты, çuar_,
   {{0x38a4003e,0xe81f00b6,0xd9f2136b,0x00000000}},	//   vöru_, म्बा_, _अजित_, --,
   {{0x14c800bf,0x6aa431ab,0xe45a1a0e,0x38a40212}},	// [ac80] سهای_, _ikif, ожа_, fört_,
   {{0x26cc132d,0x81ea0033,0x9f470e43,0xa2e6007b}},	//   ídos_, _মাই_, zaná_, дожд,
   {{0xb4db0472,0x98a90559,0x3e7a01d3,0x00000000}},	//   _pràc, _građ_, sūti_, --,
   {{0x41aa82e2,0xb5fb135f,0xb87b34f3,0xdd130031}},	//   овен_, _sláv, mpía, dĺže,
   {{0x9f470074,0xb5fb9c23,0x6282007a,0xddc2007e}},	//   vaná_, _cláu, rioo, _ološ,
   {{0x62820006,0xa3c81fbb,0x00000000,0x00000000}},	//   sioo, _उलट_, --, --,
   {{0x44384b7b,0x9f472cd7,0x645c9c24,0x65649c25}},	//   _iar_, taná_, _iori, lyih,
   {{0x44386ab7,0x645c7bf3,0x1d340747,0x9f450257}},	//   _har_, _hori, ения, _delà_,
   {{0x645c02e6,0x44382782,0x9f479c26,0x628015bc}},	//   _kori, _kar_, raná_, _immo,
   {{0x645c9c27,0x6280023e,0x6aa49c28,0x515b00ca}},	//   _jori, _hmmo, _akif, _וכמו,
   {{0x645c9c29,0x44380b87,0x9f476b7b,0xda0a04f1}},	//   _mori, _mar_, paná_, वलंत_,
   {{0xaacf06ae,0x6ab602ad,0x60c8009e,0x3e83022b}},	//   _संरक, _chyf, _hidm, _vètè_,
   {{0x8d730214,0x394d20df,0x7c3e0072,0x6e227914}},	//   _لاوا, ães_, _ópro, _ibob,
   {{0x645c16d1,0x44389c2a,0xb9073b30,0x29199c2b}},	//   _nori, _nar_, _पऽ_, rtsa_,
   {{0x25ad61f4,0x628002a1,0x290b0234,0x67d400f3}},	//   _šel_, _ommo, suca_, тосу,
   {{0x7c385b0a,0x60c89c2c,0x4438676c,0xa3670139}},	//   _havr, _lidm, _aar_, _dọ́r,
   {{0x67d5545b,0x443800ca,0x7c38026a,0x38b602b6}},	// [ac90] _попу, _bar_, _kavr, færd_,
   {{0x62809c2d,0xb5fb3e0a,0x645c2c29,0x44380e6c}},	//   _ammo, _alát, _cori, _car_,
   {{0x44389c2e,0x645c986f,0x7c389c2f,0x20130428}},	//   _dar_, _dori, _mavr, òxim_,
   {{0x23df0751,0x68ed9c30,0x9f470428,0x60c807bc}},	//   _प्रद, _kwad, lanç_, _aidm,
   {{0x60259c31,0x645c9c32,0x6d44013f,0x443864b3}},	//   едла, _fori, _šian, _far_,
   {{0x3e710074,0x44389c33,0x7c389c34,0x6280083e}},	//   _máte_, _gar_, _navr, _emmo,
   {{0x8fa21dde,0x6d420634,0xb5fb2bb5,0xb4ab2231}},	//   лаше, _aroa, _coág, खती_,
   {{0x443802e6,0x9f45025b,0x645c0a00,0x68ed9c35}},	//   _zar_, _celá_, _zori, _owad,
   {{0x645c0139,0xddc22052,0x44389c36,0x38b6038c}},	//   _yori, _ploš, _yar_, lære_,
   {{0x765d4cd4,0x6aa40856,0x645c9c37,0x7c380dda}},	//   _losy, _skif, _xori, _cavr,
   {{0x7c3803a3,0x68ed4031,0x6d429c38,0x09c80af1}},	//   _davr, _awad, _eroa, रख्य,
   {{0xdb1e00b6,0x68ed9c39,0x6e220032,0x4423033c}},	//   áván, _bwad, _gbob, _lbj_,
   {{0x44232316,0x6d4200d3,0x7e69003e,0x7c38066a}},	//   _obj_, _groa, mkep, _favr,
   {{0x60c801d4,0x7e6901df,0x7ea50088,0xddc27a52}},	//   _xidm, lkep, rópu, _uloš,
   {{0x7c2300dc,0x7d1b9c3a,0x765d0113,0x68ed91ff}},	//   _ibnr, ltus, _bosy, _ewad,
   {{0x7c3808a9,0x998d0106,0x44389c3b,0x7ea560d3}},	//   _zavr, žeš_, _sar_, cópt,
   {{0x44389c3c,0xeb1f1085,0x645c9c3d,0x765d9c3e}},	// [aca0] _par_, _बहुत_, _pori, _dosy,
   {{0x7d1b0084,0x645c0188,0x443826ff,0x6564008c}},	//   itus, _qori, _qar_, ryih,
   {{0x443857eb,0x020616b2,0x645c226e,0xb5fb9c3f}},	//   _var_, езен, _vori, _clás,
   {{0xe2971e20,0x44389c40,0x6e39023e,0xe1f21a37}},	//   нах_, _war_, _nawb, اسا_,
   {{0x44389c41,0x21673574,0x645c14fb,0xb5fb0623}},	//   _tar_, ници_, _tori, _elás,
   {{0xdfcf00e3,0x68fb016d,0x442c0076,0xeb1f009f}},	//   ميه_, áudi, _úd_, _बहूत_,
   {{0x6e390009,0x7d1b9273,0x60c89c42,0xb5fb0231}},	//   _bawb, etus, _vidm, _ilár,
   {{0x7c3802e6,0xb65b0130,0x6d429c43,0x62800044}},	//   _savr, ִדיש, _proa, _ummo,
   {{0xb5fb6c8a,0x2dd700e3,0x6e39022b,0xe29710a6}},	//   _klár, ربية_, _dawb, _чат_,
   {{0x68ed0169,0x69cd01ff,0x20c901c3,0x7f7600ae}},	//   _rwad, _sgae, _قبلي_, _пуец,
   {{0x141b00c1,0x68ed464d,0xdfcf3a89,0x9b941f75}},	//   הויב, _swad, _ايم_, тинц,
   {{0x79a71824,0x2bd20caf,0xed5a3407,0x6d421650}},	//   ерге, _सलवा, _ное_, _troa,
   {{0x3ea606a8,0x765d76b2,0x7ea50072,0x7c38047e}},	//   _ikot_, _rosy, rópt, _tavr,
   {{0x765d325b,0xd25900d9,0x2ab20224,0xb4db00b3}},	//   _sosy, _viņi_, rába_, _bràn,
   {{0x6d401842,0x36d50291,0x5a4700ae,0x765d62d2}},	//   lvma, тобр, _зэпа, _posy,
   {{0x68ed9c44,0xb5fb026e,0x7afa0324,0x1c1c0285}},	//   _twad, _alár, mstt, ब्रल_,
   {{0xe5980565,0x8415007b,0x00000000,0x00000000}},	// [acb0] екті_, кмах, --, --,
   {{0xb5fb054f,0xb4ab000f,0x7bda9c45,0x38b601df}},	//   _clár, खते_, nctu, tære_,
   {{0x229c0146,0xf99009e5,0x6d440031,0xa5bb0af0}},	//   líky_, _نبی_, _šial, _gbón,
   {{0x61cb42d4,0xd9f100c3,0x38b601df,0xb5fb975c}},	//   िशेष, चरित_, rære_, _vlás,
   {{0x229c033d,0x865a0327,0x81c90033,0xe0d8004d}},	//   níky_, _חדרי, লুন_, еві_,
   {{0x38b60c89,0x1ae60033,0x7afa0ac9,0x00000000}},	//   pære_, _কিনে_, kstt, --,
   {{0x201a05fe,0xd00e0037,0x7afa029a,0x7ff400d1}},	//   òpia_, زلي_, jstt, اسها,
   {{0x7c2302e7,0x7d1b1c23,0x7bda00ae,0xbf21009f}},	//   _sbnr, ttus, ectu, _महीन_,
   {{0xee36022c,0x44ef45a8,0x26d3137f,0x7e699c46}},	//   тны_, nż_, _luxo_, rkep,
   {{0x229c0094,0x3ea632de,0xbc62007b,0x3c650208}},	//   díky_, _ekot_, ивык, тког,
   {{0x7d1b8ca9,0x225f00f9,0x6e399c47,0x7afa0381}},	//   stus, _kouk_, _tawb, gstt,
   {{0x7ea59c48,0x225f06a3,0x7d1b46df,0xa3b9152c}},	//   róps, _jouk_, ptus, _चरन_,
   {{0x3ead9c49,0x4e7a006e,0x00000000,0x00000000}},	//   mlet_, _קאנצ, --, --,
   {{0x3ea00f72,0x26d30072,0x3ebf9c4a,0xcd76006e}},	//   čite_, _buxo_, lmut_, _בענק_,
   {{0x44ef0067,0x26d303be,0x26cb9c4b,0x07a63122}},	//   eż_, _cuxo_, _bico_, тавн,
   {{0x7aed00a5,0x26cb0357,0x00000000,0x00000000}},	//   _łatw, _cico_, --, --,
   {{0x7d099c4c,0x26cb6fab,0x3ead9c4d,0x00000000}},	// [acc0] nres, _dico_, ilet_, --,
   {{0xb4db9c4e,0x3ead9c4f,0x69c2030b,0x224d0900}},	//   _tràn, hlet_, रेणी, _anek_,
   {{0x3ead9c50,0x26cb9c51,0x7d0901bf,0x225f02f1}},	//   klet_, _fico_, hres, _bouk_,
   {{0x6d44013f,0x518674da,0x3ead9c52,0x26cb0027}},	//   _šiam, кула, jlet_, _gico_,
   {{0xc05a00d6,0x7d0902b6,0x9f4e00b3,0x00000000}},	//   дій_, jres, rafí_, --,
   {{0x7d099c53,0x80e10081,0xdc0800d9,0xc01300d6}},	//   dres, _নিশ্, _mēģi, иміщ,
   {{0x644e9c54,0xb4c000a5,0x3ead9c55,0x229c0146}},	//   _inbi, ुदी_, flet_, zíky_,
   {{0x80e10f71,0x7d099c56,0x8c3c03a3,0x3ead0f01}},	//   _নির্, fres, doğa, glet_,
   {{0x7d091647,0xd9e3023a,0x27f89c57,0x00000000}},	//   gres, _क्षत_, karn_, --,
   {{0x225f6d85,0x3ead9c58,0xa3b90852,0x4de200a3}},	//   _zouk_, alet_, _चरम_, _ट्रै_,
   {{0x3ead9c59,0xa5bb0139,0xe7bd0081,0x27f800f0}},	//   blet_, _aból, _অভ্য, darn_,
   {{0x7d0926e0,0x9e663035,0x26c02f54,0x7afa01cb}},	//   bres, _швед, jmio_, rstt,
   {{0xa2d402d5,0x27f800f0,0x58871855,0x2904153a}},	//   _बूस्, farn_, выва, šman_,
   {{0x5887004b,0x26d303be,0xb5fb0af0,0x27f89c5a}},	//   тыма, _puxo_, _aláp, garn_,
   {{0x26cb10d9,0xd25900d9,0x25ae013c,0x00000000}},	//   _pico_, _ziņu_, əfli_, --,
   {{0x644e6042,0x2a600167,0xdce90095,0x88e20033}},	//   _anbi, _goib_, uzeć, _বিরক,
   {{0x27f80f05,0xa5bb0d79,0x26cb9143,0xf99f1695}},	// [acd0] barn_, _gból, _vico_, rgès_,
   {{0x224d6639,0x291e00ae,0xf367007e,0x3e716c8a}},	//   _snek_, ătat_, ктен, _máta_,
   {{0x3e716cc8,0x225f0087,0x3ea49c5b,0x7a4201f9}},	//   _láta_, _pouk_, komt_, sítő,
   {{0x69dd0018,0x644e40cf,0x7d090856,0xe81f030b}},	//   ncse, _enbi, yres, म्रा_,
   {{0x3ead9c5c,0x00000000,0x00000000,0x00000000}},	//   vlet_, --, --, --,
   {{0x7d099c5d,0x644e0383,0xaca30294,0x225f0154}},	//   vres, _gnbi, trọn, _wouk_,
   {{0x28da07e2,0xeaca0023,0xf2c7079c,0x00000000}},	//   _यूनि, _kẹt_, _асан, --,
   {{0x3ebf015e,0x224d0479,0x3ead00fc,0x00000000}},	//   umut_, _unek_, ulet_, --,
   {{0x3ebf9c5e,0x3ead3b69,0x2d99023b,0xc0ab0781}},	//   rmut_, rlet_, çse_, _قائل_,
   {{0x3ead52ab,0x3e714205,0xd25900d9,0xef65013c}},	//   slet_, _dáta_, _viņu_, çısı_,
   {{0x27f837b4,0xba3b9c5f,0x290b00ee,0xbe15109d}},	//   varn_, roïn, erca_, _مواع,
   {{0x7d090fd7,0x3f7a0130,0x991604a1,0x69dd01f9}},	//   pres, _אָדע, льгі, gcse,
   {{0x32360130,0xf9920308,0x27f89c60,0x38616c91}},	//   נטשן_, صبح_, tarn_, _bohr_,
   {{0x81ea0081,0xe81f030b,0xe73a00c2,0x61f951ab}},	//   _মাছ_, म्ला_, нег_, hawl,
   {{0xd62a1d6e,0xdc9a0089,0x61f907a5,0x3e6a0441}},	//   нове_, _איסל, kawl, _bùth_,
   {{0x26c0015c,0x69dd0103,0x27f89c61,0x2bdf0965}},	//   umio_, ccse, sarn_, पुरा,
   {{0x26c09c62,0xa507554c,0xe7a41101,0x3e6a01b9}},	// [ace0] rmio_, лета_, _खुरप, _dùth_,
   {{0x9f4c0146,0xa5bb0139,0xb4db01f7,0xb4630db2}},	//   _sedí_, _gbóm, _gràm, бкул,
   {{0xa3b90557,0x9f4c0314,0x1bf6006e,0x00000000}},	//   _चरण_, _pedí_, רצער_, --,
   {{0x2ca59c63,0x20d90113,0x00000000,0x00000000}},	//   hold_, _bèi_, --, --,
   {{0x64430396,0x6a66003e,0x2ca59c64,0x00000000}},	//   ônic, _hófs, kold_, --,
   {{0x3e710037,0x20d9028d,0xd8d7006e,0x2ca500f2}},	//   _ráta_, _dèi_, אוסט_, jold_,
   {{0x3ea45481,0x4acf0ff9,0xaacf0b3a,0xa2e3007b}},	//   tomt_, _संगव, _संगक, _госд,
   {{0xa3b9007d,0x68e402ef,0x39950134,0x61ed01cd}},	//   _चरत_, _otid, ụsi_, ðalt,
   {{0x5c741f0d,0x61435303,0xa2a1423b,0x2ca55543}},	//   илит, _лета, गकर्, fold_,
   {{0x3ea4038c,0x290b00cc,0x00000000,0x00000000}},	//   somt_, vrca_, --, --,
   {{0x68e4013f,0x9f470094,0x38619c65,0x00000000}},	//   _atid, ybné_, _rohr_, --,
   {{0xdd000233,0xf41a0033,0x3e7100d2,0x00000000}},	//   ştık, ড়ির_, _táta_, --,
   {{0x2ca504cc,0x6c540396,0x786b00aa,0xa3e4277c}},	//   bold_, _вклу, _hüvi, नडा_,
   {{0x6d3b00a1,0x9f470220,0xb8fd9c66,0x68e4009c}},	//   _נתונ, vanú_, _तं_, _dtid,
   {{0x68e406a3,0x99990018,0x7bdb00ca,0xa5bb0032}},	//   _etid, reső_, _אקוו, _gbój,
   {{0x58d50020,0xc6a74ef9,0x291e044c,0x00000000}},	//   _коит, урги, ătar_, --,
   {{0xb4db05fe,0x260a034c,0xeaca00fe,0x2b470141}},	// [acf0] _tràm, िलजी_, _vẹt_, _zrnc_,
   {{0x78700149,0x7e62396c,0xe9df00b3,0x00000000}},	//   _jävl, _loop, lcú_, --,
   {{0xe7eb009d,0xd4989c67,0x998d0034,0xda0900a4}},	//   _ज्या_, урт_, żeń_, _वयात_,
   {{0x39499c68,0x7e620381,0x00000000,0x00000000}},	//   _kras_, _noop, --, --,
   {{0x61f94520,0xc5fa00ca,0x00000000,0x00000000}},	//   rawl, _בפרט, --, --,
   {{0x21660831,0xa3d401a0,0xd0060e3a,0x00000000}},	//   риши_, _горч, аеше_, --,
   {{0x6fcc0789,0x21de0174,0x2ca52ca7,0x270100c6}},	//   ाशगं, _ịhe_, vold_, nėn_,
   {{0x394991f9,0x0e650a51,0x7e6234d2,0x2ca51f6d}},	//   _oras_, ркин, _coop, wold_,
   {{0x7ae403ce,0x3949022e,0x7e621a4b,0x261800c3}},	//   _čita, _nras_, _doop, _फासी_,
   {{0x3ea000cc,0x4b2540cd,0x4c85430b,0xac851689}},	//   čita_, амов, рлов, ргол,
   {{0x68e404a3,0xeb990d06,0x39499c69,0x2005009c}},	//   _stid, тин_, _aras_, _idli_,
   {{0xfaa62565,0x628b00f0,0x39499c6a,0xa96a0831}},	//   рамо, nigo, _bras_, вима_,
   {{0x999e02c6,0xec6e245c,0x00000000,0x00000000}},	//   ětů_, _дп_, --, --,
   {{0x78700149,0x628b0c23,0x3949931a,0x5d7a006e}},	//   _gävl, higo, _dras_, _באנק,
   {{0xb8fd1133,0xe7e509d0,0x39492bb5,0x628b3128}},	//   _तू_, कड़ा_, _eras_, kigo,
   {{0x7e620090,0x63ae4d7b,0x6d44013f,0x5ed70081}},	//   _xoop, _rybn, _šiai, _সবাই,
   {{0x39490c86,0x9f450220,0xc4866ff6,0x3e710139}},	// [ad00] _gras_, _celú_, алак, _láto_,
   {{0x2701004b,0x00000000,0x00000000,0x00000000}},	//   bėn_, --, --, --,
   {{0x2bab0490,0x8c3c013c,0x00000000,0x00000000}},	//   _घुमा, doğl, --, --,
   {{0x9f4c025b,0x628b178b,0x161d1677,0x20059c6b}},	//   _nedá_, gigo, _फायर_, _adli_,
   {{0xb4db0065,0x90c604c9,0x7e6203f0,0x00000000}},	//   _asàf, абде, _roop, --,
   {{0x4034117c,0x201a00aa,0x00000000,0x00000000}},	//   секс, üpi_, --, --,
   {{0x628b9c6c,0x00000000,0x00000000,0x00000000}},	//   bigo, --, --, --,
   {{0xf2a32007,0xb4db01b9,0x290c007f,0xb5fb00fe}},	//   _дисп, _bràh, ądaj_, _loán,
   {{0x61ed058a,0xf8bf020d,0x69da02c6,0xe817320a}},	//   ñale, ltée_, ětel, _ताला_,
   {{0x8c660012,0xceea00d6,0x27230031,0xdb0300d8}},	//   ртид, _адже_, nčná_, _syná,
   {{0xf8bf0257,0xdee3007e,0x78a729f9,0xdd90001c}},	//   ntée_, _дохи, vojv, توک_,
   {{0xbd87037f,0x3949001c,0x1bf20c8c,0xfe7900b6}},	//   انین_, _pras_, _आजकल_, chů_,
   {{0x78700222,0xcd3609b4,0xdb030146,0xe9df119e}},	//   _tävl, _خراب, _vyná, rcú_,
   {{0xe9df9c6d,0x628b9c6e,0x442a9c6f,0x39490052}},	//   scú_, zigo, _nbb_, _vras_,
   {{0x1cbb0130,0x44333b03,0x628b04ff,0x00000000}},	//   _שמוע, vex_, yigo, --,
   {{0x394911ce,0xaa2d00c2,0x8c3c0345,0x00000000}},	//   _tras_, ämää_, zoğl, --,
   {{0x6aad0a4b,0x8c3c0342,0x39499c70,0x00000000}},	// [ad10] _ikaf, yoğl, _uras_, --,
   {{0xc3cb0037,0xeaca0023,0x00000000,0x00000000}},	//   نظام_, _hẹp_, --, --,
   {{0x44339c71,0x628b0ba0,0x389c13b6,0x05a70104}},	//   rex_, tigo, _ביזנ, _कुरब,
   {{0xdb070103,0x7d02053f,0xf6d4001c,0x00000000}},	//   ülék, _ovos, _گزید, --,
   {{0x3ce601fa,0x61450fe3,0x4ad00caf,0xaad000b6}},	//   _ntov_, села, _संघव, _संघक,
   {{0x628b9c72,0x656d2b7c,0x656001ec,0x00000000}},	//   sigo, myah, _àmha, --,
   {{0x656d0188,0xf8bf00fd,0x8c3c008b,0x491700b7}},	//   lyah, ctée_, roğl, भूतो_,
   {{0xee396804,0xb4db01b9,0xddd30031,0x7c2a0364}},	//   уни_, _arài, ťaže, _abfr,
   {{0x656d9c73,0x6289391d,0xb4db01f7,0x98a90234}},	//   nyah, _imeo, _brài, _apač_,
   {{0x7d020995,0x6aad9c74,0x3e710181,0x10170281}},	//   _dvos, _akaf, _táto_, _خبرد,
   {{0xb4db01ec,0xeaca00fe,0x7c640076,0xdce70342}},	//   _drài, _bẹp_, تايل, ılım,
   {{0xc86907a6,0x2d7f0034,0x753d01f9,0xa5bb0503}},	//   _אן_, _płeć_, _ossz, _gcóg,
   {{0x2c690220,0xeaca0023,0x6289024a,0x1d0907ec}},	//   _súdu_, _dẹp_, _mmeo, _сели_,
   {{0xb4db0441,0x656d008c,0x37e3007e,0x00000000}},	//   _grài, dyah, зорг, --,
   {{0x62890451,0x753d0103,0x9f450036,0x6d4b00c4}},	//   _omeo, _assz, _pelù_, _hrga,
   {{0x442a9c75,0xaad006ed,0x6aad0113,0xe503074c}},	//   _sbb_, _सूचक, _gkaf, _लिखि_,
   {{0x442a0706,0x69d60103,0xe09e0174,0x00000000}},	// [ad20] _pbb_, _igye, họọ_, --,
   {{0x98a9013f,0x62895fa7,0xe09e0129,0x06e70033}},	//   _ypač_, _ameo, kọọ_, _ফিরি,
   {{0x29029c76,0xf8bf00fd,0x656d34b0,0x130a00d3}},	//   lska_, utée_, ayah, уней_,
   {{0x786b0092,0xd9fa0557,0xf1fa1a13,0xf8bf0257}},	//   _qüvv, ्णित_, اعات_, rtée_,
   {{0x656d0193,0xf8bf00fd,0xa06a03c8,0x76449c77}},	//   cyah, stée_, лада_, mdiy,
   {{0x76440092,0x2902008a,0x442a044c,0xf8bf00fd}},	//   ldiy, iska_, _ubb_, ptée_,
   {{0x6d4b9c78,0x4444637f,0x5f430037,0x68f600f0}},	//   _arga, md_, كنول, _lwyd,
   {{0x22960080,0x3ea000e9,0x76449c79,0x32960037}},	//   _الرس, čito_, ndiy, _الرأ,
   {{0x75249c7a,0x44449c7b,0x26da9c7c,0x68f600f0}},	//   ntiz, od_, _lupo_, _nwyd,
   {{0x290208a9,0x61e2008f,0x6aad1e81,0x6d4b176a}},	//   dska_, lcol, _skaf, _drga,
   {{0x6d4b9c7d,0xae20152c,0x29029c7e,0x68f600f0}},	//   _erga, _यापन_, eska_, _awyd,
   {{0x6d4401b3,0x4444440d,0x6d890018,0x75249c7f}},	//   _šiau, hd_, امیہ_, ktiz,
   {{0x0c7300bf,0xd0410092,0x76449c80,0x05a70789}},	//   زدید, _ailə, ddiy, _कुंब,
   {{0x69d600fb,0xd0410253,0x44440505,0x8c43545b}},	//   _egye, _bilə, jd_, _нече,
   {{0x44441a2e,0x1bfb0054,0xaae60602,0x26da6636}},	//   dd_, _גלוב, _استو, _cupo_,
   {{0x44449c81,0x656d0475,0xd6d80a18,0x290200f1}},	//   ed_, tyah, стр_, bska_,
   {{0x9f47025b,0x44440ab2,0x68f60150,0x29020103}},	// [ad30] daný_, fd_, _gwyd, cska_,
   {{0x44449c82,0x80dc00a5,0x656d008a,0xd37b26be}},	//   gd_, _पढ़े, ryah, лче_,
   {{0x45d5294a,0x57fa00ca,0xd1d9085f,0x81b803e3}},	//   _монс, _דלתו, адец_, ɓɓiy,
   {{0x44449c83,0x656d1281,0x61e2019f,0x7ae400cb}},	//   ad_, pyah, gcol, _čitl,
   {{0x44440085,0xf65f0537,0x00000000,0x00000000}},	//   bd_, _diæt_, --, --,
   {{0x26da0051,0xe09e0174,0x00000000,0x00000000}},	//   _yupo_, tọọ_, --, --,
   {{0x64559c84,0x7e7b0201,0x6d4701d3,0x64450b8c}},	//   _inzi, thup, ājam, mdhi,
   {{0x2902008a,0x64450694,0x61e20a5f,0x62890239}},	//   yska_, ldhi, ccol, _umeo,
   {{0xb5fb9c85,0xec794cc3,0x64456221,0x00000000}},	//   _bláz, ипи_, odhi, --,
   {{0x64459c86,0x61fb9c87,0x6d4b2bcb,0xaadd02d5}},	//   ndhi, _heul, _vrga, _नंदक,
   {{0xe8200e72,0x764401d4,0x68f602e0,0x64450013}},	//   _बाबा_, ydiy, _swyd, idhi,
   {{0x29020106,0x60db9c88,0x26da9c89,0x62991597}},	//   tska_, _kuum, _rupo_, nnwo,
   {{0x44440694,0x787003cf,0xddc240a8,0xdea30068}},	//   yd_, _hävi, _zlož, _ویڈی,
   {{0x60db7996,0x26da026e,0x38b6052f,0x787000c2}},	//   _muum, _pupo_, mærk_, _kävi,
   {{0x61e222d4,0x6d497924,0x4444004d,0xf7431b7a}},	//   ycol, lvea, vd_, меро,
   {{0x64559c8a,0x75249c8b,0x61fb9c8c,0xd04001c2}},	//   _anzi, ttiz, _neul, _yumɓ,
   {{0x9f470871,0x764401d4,0xb466311c,0x645500e7}},	// [ad40] vaný_, rdiy, окал, _bnzi,
   {{0x3e786d68,0x6299057a,0x44449c8d,0x26da0239}},	//   _méta_, enwo, ud_, _tupo_,
   {{0x75249c8e,0x673e029b,0x61fb0441,0x201e1bdf}},	//   stiz, _uspj, _beul, _rcti_,
   {{0x44449c8f,0x75249c90,0x64559c91,0x644574c5}},	//   sd_, ptiz, _enzi, adhi,
   {{0x61e29c92,0x9f5c025b,0xddc29a0d,0x61ed0890}},	//   rcol, mavé_, _slož, ñala,
   {{0x61e29c93,0x1df200c3,0xb87b00b6,0x26c201ff}},	//   scol, घर्ष_, spív, _hhko_,
   {{0x25e1007d,0xdfcf00e3,0xb5fb0af0,0x6e291842}},	//   _कलमी_, نيه_, _aláy, ffeb,
   {{0xddc2134c,0x61fb9c94,0x3940593a,0x9f5c0094}},	//   _vlož, _geul, _osis_, navé_,
   {{0x6eda0eeb,0x3eb801d3,0x067b0142,0x60db026d}},	//   _पूरु, ērt_, ינקל, _guum,
   {{0x22469c95,0x80e10033,0x26c20062,0x9f5c00d4}},	//   ldok_, _নিচ্, _lhko_, havé_,
   {{0xddc2068e,0x39400138,0x9f5c0094,0xee3a007b}},	//   _ulož, _asis_, kavé_, _вне_,
   {{0x0dca16d9,0x3a2000fc,0x00000000,0x00000000}},	//   _кули_, _ccip_, --, --,
   {{0x212606ee,0x394d184f,0x8c4608f9,0xfe9b0266}},	//   ntoh_, íes_, _меде, _דיאמ,
   {{0xfbcf12eb,0x3ea90660,0x95f5121d,0xa5bb0076}},	//   عتی_, čate_, ेण्ट_, _mbót,
   {{0x368b3cc0,0x64430161,0x224600f9,0x39400143}},	//   асан_, ônim, kdok_, _esis_,
   {{0xcb1309c1,0x9f5c02f1,0x98650018,0xf1ca1462}},	//   _חלק_, ravè_, _کیسے_, िधान,
   {{0x95cb02b3,0x394000f9,0xddd90154,0x61fb01f7}},	// [ad50] рува_, _gsis_, _fowņ, _reul,
   {{0x61fb025a,0x60db1e07,0x7af8022e,0x2919019b}},	//   _seul, _ruum, _kwvt, musa_,
   {{0x3e7100e3,0x64454d3a,0x29199c96,0x25a20f3a}},	//   _fáth_, rdhi, lusa_, _exkl_,
   {{0x9f450074,0xb4db0441,0x2cac00f0,0x2a690383}},	//   _celý_, _bràt, hodd_, _joab_,
   {{0x2a699c97,0x61fb5a46,0xb4db00ee,0x6299792a}},	//   _moab_, _veul, _cràt, rnwo,
   {{0x38b6052f,0xe042004d,0x7539020e,0x3e47020b}},	//   værk_, енши, ğazı, _ốt_,
   {{0x2cac02ad,0x61fb9c98,0x29199c99,0x26c90d6e}},	//   dodd_, _teul, husa_, omao_,
   {{0xe1ff0102,0x291955a3,0x60db0673,0x26c90124}},	//   _þó_, kusa_, _tuum, nmao_,
   {{0x2cac02ad,0x22640146,0x9f470036,0x6d490df4}},	//   fodd_, žská_, ganò_, uvea,
   {{0x29199c9a,0x6d499c9b,0x2cac0150,0x9e670018}},	//   dusa_, rvea, godd_, _ڈاؤن,
   {{0x3e7102b4,0xf412006e,0x3a390231,0xb3ad0033}},	//   _láti_, עפט_, fesp_, _কৃতজ,
   {{0x39400085,0x00000000,0x00000000,0x00000000}},	//   _psis_, --, --, --,
   {{0x2eaa00fb,0x5ed20081,0x29199c9c,0x8c640470}},	//   _اپنی_, _সবচে, gusa_, سطین,
   {{0x26c2023b,0xb87b0220,0x3ead0381,0x00000000}},	//   _shko_, dpís, loet_, --,
   {{0x38ca0018,0xeb9600f6,0x9f5c00d4,0x3a390231}},	//   لاڑی_, _ниш_, tavé_, besp_,
   {{0x39401071,0x29199c9d,0xb906008f,0xe9a6084c}},	//   _tsis_, busa_, _език, _найп,
   {{0x29199c9e,0x9f5c0146,0x3ae1003e,0x00000000}},	// [ad60] cusa_, ravé_, _hóp_, --,
   {{0x3d131592,0xf5070b91,0xdbe3020d,0x63b502c6}},	//   _दिने_, янул_, _déçu, _byzn,
   {{0x9f454073,0xb4db0139,0x9f470094,0x7ae40357}},	//   _meló_, _bràs, ybná_, _čitk,
   {{0xf8bf9c9f,0x7ebe0052,0x8289004d,0xb87b003e}},	//   ntén_, këpa, осіб_, spít,
   {{0xb4db01b5,0x442601c2,0x3ead01cb,0x25d700ca}},	//   _dràs, ƙo_, doet_, _מוכן_,
   {{0x38b60088,0x55bb00ca,0xe20a007f,0x78ae0565}},	//   færi_, _למכו, dróż_, nobv,
   {{0x7646278f,0x443a9ca0,0x274702c6,0x29191437}},	//   _kaky, mep_, míná_, zusa_,
   {{0x443a9ca1,0x6b570174,0xb4db01f7,0x139b00ca}},	//   lep_, _ọgb, _gràs, _הבלע,
   {{0x29190415,0x76469ca2,0x63820503,0x00000000}},	//   xusa_, _maky, _fíné, --,
   {{0x443a33b4,0x3ae100de,0x2919019f,0x95880034}},	//   nep_, _bóp_, vusa_, ciąż,
   {{0x59a553b8,0x200c0150,0x2cac0150,0x3ead9ca3}},	//   _गुजर, _iddi_, rodd_, boet_,
   {{0x443a9ca4,0x7646083e,0x2cac00f0,0x6e960037}},	//   hep_, _naky, sodd_, _علشا,
   {{0x443a2f91,0x3d130034,0x648000bc,0x00000000}},	//   kep_, _दिये_, _köid, --,
   {{0x29199ca5,0x443a0268,0xdd3b00a1,0x764607ac}},	//   rusa_, jep_, _לעדכ, _aaky,
   {{0x3ae10028,0x2919379b,0x671d0789,0x76460517}},	//   _góp_, susa_, बंधक_, _baky,
   {{0xfbb70054,0x29199ca6,0xfd510174,0x00000000}},	//   _מפות_, pusa_, _nkeọ, --,
   {{0x200c0150,0xa5bb4386,0x764631fb,0x3e7800b6}},	// [ad70] _oddi_, _abór, _daky, _léto_,
   {{0x443a00cd,0x68ed16ed,0x00000000,0x00000000}},	//   gep_, _itad, --, --,
   {{0x61ed0328,0x87070411,0x00000000,0x00000000}},	//   ñalo, _عبدل, --, --,
   {{0x63b5025b,0x7c3a9ca7,0x6d420a00,0x764606b0}},	//   _vyzn, hetr, _osoa, _gaky,
   {{0xa0695ac0,0x7c3a017a,0x63b50034,0x443a026a}},	//   жала_, ketr, _wyzn, bep_,
   {{0x443a9ca8,0x6e2200b3,0x764600d8,0x940100a7}},	//   cep_, _acob, _zaky, yihə_,
   {{0x6d42002b,0x442300dc,0xa5bb0032,0x8fa230fd}},	//   _asoa, _icj_, _gbór, каше,
   {{0x64479ca9,0xece90689,0x200c01ce,0x00000000}},	//   _haji, одил_, _eddi_, --,
   {{0x64472fc5,0x61e90032,0x200c0072,0x3ead7540}},	//   _kaji, _ifel, _fddi_, roet_,
   {{0x7c3a6898,0x64471ce5,0xeb990284,0x00000000}},	//   getr, _jaji, жио_, --,
   {{0x64479caa,0x290902fd,0xe81715e4,0x68ed9cab}},	//   _maji, _avaa_, _ताजा_, _atad,
   {{0x64479cac,0xdd8e09b4,0x443a5666,0x6ee70233}},	//   _laji, اوی_, zep_, _tıbb,
   {{0xda1f3922,0x764614f7,0x5d6911d9,0xe8f72a6a}},	//   _भारत_, _raky, _филм_, мля_,
   {{0x64470a55,0xf8bf5991,0x7d1b6765,0x76469cad}},	//   _naji, stén_, muus, _saky,
   {{0x68ed9cae,0xdca2007e,0x7d1b9caf,0x69c200b6}},	//   _etad, _шаши, luus, रेजी,
   {{0x44230154,0x7d030065,0x44310a7f,0xe82050da}},	//   _acj_, _gìrá, _abz_, _बावा_,
   {{0x443a9cb0,0x7d1b2a35,0x44310381,0x00000000}},	// [ad80] tep_, nuus, _bbz_, --,
   {{0x61e99cb1,0xe73a0291,0x64479cb2,0x442361d2}},	//   _afel, _део_, _caji, _ccj_,
   {{0x443a9cb3,0x76469cb4,0x366a044e,0x7e6b1570}},	//   rep_, _taky, _дано_, _oogp,
   {{0x443a21aa,0xe297433a,0x7d1b5638,0xd2500260}},	//   sep_, мах_, kuus, طنت_,
   {{0xd130037f,0x660491fb,0xc0e30084,0x443a9cb5}},	//   امت_, maik, вочк, pep_,
   {{0x6604462f,0x64472675,0x7d1b9cb6,0x6e22044c}},	//   laik, _gaji, duus, _scob,
   {{0xdfd00037,0x7c3a9cb7,0x7e6b02b6,0x44e49cb8}},	//   ديث_, vetr, _bogp, _hö_,
   {{0x6604125d,0x667b00c1,0x6447030b,0x941e099d}},	//   naik, ַװיג, _zaji, _पाँच_,
   {{0x9f5e00dd,0x64476712,0x2d840335,0x00000000}},	//   _ketë_, _yaji, uzme_, --,
   {{0x9f5e01e5,0x3e78000d,0x66040634,0xcf0c0033}},	//   _jetë_, _této_, haik, _শহীদ_,
   {{0x660443ba,0xe0e60033,0x7c23009c,0xdfcf0037}},	//   kaik, _নিয়ন, _dcnr, _نيك_,
   {{0x7d1b9cb9,0x628228ac,0xed5a36f2,0x395200f0}},	//   buus, nhoo, _мое_, _brys_,
   {{0x941e05d4,0x7c3a9cba,0x66049cbb,0x6d4200d3}},	//   _पांच_, petr, daik, _usoa,
   {{0xa3c00980,0x39520537,0x00000000,0x00000000}},	//   ुधा_, _drys_, --, --,
   {{0x64479cbc,0xe8203873,0x66040239,0x8aa71dee}},	//   _raji, _बारा_, faik, _орид,
   {{0x644718c7,0x66046996,0x39528c90,0x9f5c0031}},	//   _saji, gaik, _frys_, javí_,
   {{0x6447023b,0xa5bb0072,0x628274c5,0x44310234}},	// [ad90] _paji, _ecón, dhoo, _pbz_,
   {{0x3e710088,0x44e40212,0x660403a9,0x628205c2}},	//   _hátt_, _dö_, aaik, ehoo,
   {{0x660406ee,0xf8bf0396,0xa5bb00e3,0x52155ee6}},	//   baik, ntém_, _gcón, едет,
   {{0xfd5e00de,0xe7eb00b6,0x44e49cbd,0xd5b00103}},	//   _quyể, जुरा_, _fö_, افے_,
   {{0xc6160054,0x64479cbe,0x50b5055b,0xb4db01b9}},	//   _אחרי_, _taji, нску, _gràp,
   {{0x26d99cbf,0x7d1b007b,0x9f5e0139,0x64470350}},	//   _hiso_, vuus, _ketè_, _uaji,
   {{0xfd5e0028,0x38b601df,0x9f5c0094,0x26d9010a}},	//   _tuyể, mært_, baví_, _kiso_,
   {{0x7d1b0283,0x62829cc0,0x05c30251,0x38b601df}},	//   tuus, choo, _शराब, lært_,
   {{0xdc3a01d4,0x0c95207e,0xf8bf01f9,0xe8201073}},	//   _açıq, ешня, ttél_, _बाला_,
   {{0x6ac80789,0x26d99cc1,0x0d82013f,0x7d1b9cc2}},	//   रग्र, _liso_, ульн, ruus,
   {{0x4421445f,0x7d1b640f,0xaca30134,0x61e40117}},	//   igh_, suus, _nzụk, žile,
   {{0x26d902dd,0x39520185,0x3d0a00c6,0x00000000}},	//   _niso_, _prys_, _žuvų_, --,
   {{0xaca30134,0x66040ab3,0xceb200ca,0xed5913c7}},	//   _azụk, vaik, _גיא_, _хол_,
   {{0x66040134,0xf1b90146,0x7d094293,0xfe7900b6}},	//   waik, _myš_, mses, lků_,
   {{0x6ab62da1,0x7d091484,0x66049cc3,0x26d9001c}},	//   _псих, lses, taik, _biso_,
   {{0x7bc30039,0x39520138,0x9f5e0154,0xfe7902c6}},	//   _iznu, _trys_, _detè_, nků_,
   {{0x26d942d7,0x66049cc4,0x00000000,0x00000000}},	// [ada0] _diso_, raik, --, --,
   {{0x6604578c,0x7d090084,0x69c49cc5,0xe72a008f}},	//   saik, ises, _izie, _еоод_,
   {{0x9f5e9cc6,0x66049cc7,0x9f5c0146,0x62825c9a}},	//   _vetë_, paik, taví_, thoo,
   {{0x7d099cc8,0x236602e6,0x442101b5,0x91e6171b}},	//   kses, ćoj_, agh_, ходе,
   {{0x62829cc9,0x941e007d,0x9f5c0363,0xfe7900b6}},	//   rhoo, _पाऊच_, raví_, dků_,
   {{0x628296f9,0xe3b100fb,0x7d097aee,0x00000000}},	//   shoo, ارے_, dses, --,
   {{0x64a319ff,0x645c9cca,0x63b30146,0x37db006e}},	//   _сара, _inri, čené, פֿגע,
   {{0x9f5e96f7,0x1d3400e5,0x00000000,0x00000000}},	//   _jeté_, вния, --, --,
   {{0x62800d64,0xdd9000cd,0x7d099ccb,0x5bc8136b}},	//   _ilmo, شود_, gses, रध्व,
   {{0x6aa40a4b,0x3e71003e,0x00000000,0x00000000}},	//   _ajif, _sátt_, --, --,
   {{0x69c40465,0xa5bb0072,0xfd490134,0xfe7900b6}},	//   _azie, _acól, _kalị, bků_,
   {{0x7d090085,0x0d86169f,0x69c402a1,0xc33300ca}},	//   bses, _плен, _bzie, נור_,
   {{0xf8bf0618,0x26d99ccc,0x7ae4077e,0x3a741605}},	//   stém_, _riso_, _čitu, уляр,
   {{0x69c49ccd,0x3ea00542,0x60da009e,0xba3b014b}},	//   _dzie, čitu_, _jitm, roïq,
   {{0x26d91f8b,0x60da9991,0x779300cd,0x62809cce}},	//   _piso_, _mitm, ایجا, _olmo,
   {{0xba770604,0x26d9008c,0xdb2301cd,0x00000000}},	//   _ساعت, _qiso_, _árás, --,
   {{0x26d9583b,0x645c009c,0x333800b3,0x9f5e00ee}},	// [adb0] _viso_, _bnri, _aprx_, _deté_,
   {{0x44210054,0x7d1d05fe,0x62809ccf,0xfe7900b6}},	//   ugh_, àssi, _almo, zků_,
   {{0x41ee0174,0xad9d007f,0x00000000,0x00000000}},	//   _ịsị_, jaźn, --, --,
   {{0xa3cd0961,0xe298004d,0x7d0900f2,0x60da033c}},	//   शेष_, нає_, yses, _aitm,
   {{0xfe79000d,0x765d9cd0,0x60da9cd1,0xdced01d3}},	//   vků_, _insy, _bitm, ējīg,
   {{0x224903ce,0x62800018,0x752d0a4b,0x764d8e40}},	//   žak_, _elmo, mtaz, lday,
   {{0x752d6168,0xb4bd09d0,0xfe7900b6,0x60da01cb}},	//   ltaz, आती_, tků_, _ditm,
   {{0x764d9cd2,0x7d09007a,0xee394000,0x29190995}},	//   nday, tses, фни_, krsa_,
   {{0x752d3afb,0x290b00a5,0x7d0928f1,0xddc20b18}},	//   ntaz, jsca_, uses, _pooš,
   {{0x60da01e8,0x6ab62566,0x752d53b2,0xfe7900b6}},	//   _gitm, _skyf, itaz, sků_,
   {{0x20079cd3,0x5f7900bf,0x8c3c0b88,0x7d090b87}},	//   mani_, _تماس_, toğr, sses,
   {{0x20072d76,0x7d099cd4,0x752d057c,0x26f00081}},	//   lani_, pses, ktaz, _ছিলো_,
   {{0x764d0bf2,0xb4db0139,0x9f5c0146,0xf2d2006e}},	//   dday, _asàm, mavá_, יעט_,
   {{0x20079cd5,0x6288013f,0x765d06a3,0x7e699cd6}},	//   nani_, _įdom, _ansy, ljep,
   {{0x66e60831,0x290b1446,0xe7270f08,0x29199cd7}},	//   тоба, asca_, корд_, arsa_,
   {{0x764d74e9,0x7e7b023b,0x7e699cd8,0x20c90076}},	//   gday, nkup, njep, lúid_,
   {{0x2007694c,0xa5072549,0x7ae39cd9,0x69c4472b}},	// [adc0] kani_, кета_, _hunt, _uzie,
   {{0x7ae39cda,0xba3b0150,0x7e7b00b6,0x765d5dde}},	//   _kunt, mnïa, hkup, _ensy,
   {{0x7ae39cdb,0x68e4043e,0x7e7b9cdc,0xf8bf0103}},	//   _junt, _huid, kkup, zték_,
   {{0x7ae39cdd,0x68e40006,0x66d80065,0x35fa0568}},	//   _munt, _kuid, _dúkì, _تردد_,
   {{0x20079cde,0x60da03a9,0x7e690073,0x7ae39cdf}},	//   fani_, _pitm, djep, _lunt,
   {{0x443e9ce0,0x68e4198c,0xf1a900cd,0x3f5102a1}},	//   _út_, _muid, رانه_, _bġu_,
   {{0x7ae37c14,0x6e940f30,0x68e49ce1,0x389b006e}},	//   _nunt, лику, _luid, ויסנ,
   {{0xf8bf0018,0x7e7b9081,0x7e690052,0xad9d0034}},	//   tték_, gkup, gjep, raźn,
   {{0x20079ce2,0xc69300a1,0xc0e600d6,0x5cc6008f}},	//   bani_, יאה_, _розк, ксоз,
   {{0x7ae39ce3,0x60da0a9f,0xa3d700df,0xa0c90037}},	//   _bunt, _uitm, ाखच_, _كذلك_,
   {{0x7ae39ce4,0x8fa3385a,0x441b00c1,0x09bd1073}},	//   _cunt, _кафе, וויס, ोध्य,
   {{0x68e40013,0x7e690fa3,0xeaf70103,0x764d9ce5}},	//   _buid, cjep, کریت_, xday,
   {{0x68e4151d,0x61ed0610,0x7ae301ff,0x00000000}},	//   _cuid, ñali, _eunt, --,
   {{0xa8a49ce6,0xcb541dec,0x68e404ee,0x7ae30a00}},	//   арск, _منتظ, _duid, _funt,
   {{0xd6db0f6a,0x6b8d01c2,0x764d48e6,0x290b007e}},	//   дта_, _ƙage, tday, ssca_,
   {{0x34db02e8,0x752d772c,0x0bb700a1,0xa3d6046e}},	//   बद्द, ttaz, _שלהם_, ाइन_,
   {{0x20079ce7,0x68e40e04,0xb604020f,0x9f457378}},	// [add0] yani_, _guid, ряск, _helô_,
   {{0x752d9ce8,0x63bc9ce9,0x7ae301c2,0x20079cea}},	//   rtaz, _byrn, _yunt, xani_,
   {{0x20079ceb,0x7ae322e7,0x752d208e,0x68e40126}},	//   vani_, _xunt, staz, _zuid,
   {{0x20079cec,0xf67900c1,0x3d13009d,0x657200dd}},	//   wani_, _נאָמ, _दिले_, ëdhë,
   {{0x20079ced,0x956400e5,0x9f5c00d4,0x3f5102a1}},	//   tani_, _кърд, vavá_, _sġu_,
   {{0xb97c00ca,0x9fc9001f,0x00000000,0x00000000}},	//   ונדי, нгла_, --, --,
   {{0x20079cee,0x61e4175b,0xf65f02b6,0x63bc030a}},	//   rani_, žila, _knæ_, _gyrn,
   {{0x7ae358c6,0xdd910068,0xdb250018,0x3949007a}},	//   _runt, یوں_, épít, _osas_,
   {{0x7ae39cef,0x7e7b9cf0,0x20079cf1,0x78b5042d}},	//   _sunt, rkup, pani_, kozv,
   {{0x68e4146d,0x3a29005c,0x1abe01e4,0x629992fe}},	//   _ruid, _acap_, ोष्ठ, liwo,
   {{0x68e49cf2,0x39499cf3,0xb0b600c1,0x99c00081}},	//   _suid, _asas_, _עפעס_, _ইলেক,
   {{0x68e42515,0x20059cf4,0x3949037a,0x62830052}},	//   _puid, _heli_, _bsas_, ënoh,
   {{0x20059cf5,0x78b5007e,0x00000000,0x00000000}},	//   _keli_, fozv, --, --,
   {{0x7ae39cf6,0x3ebf02fd,0x20050995,0x7d1b9cf7}},	//   _tunt, llut_, _jeli_, mrus,
   {{0x39499cf8,0x20059cf9,0xeabf028d,0x62993c47}},	//   _esas_, _meli_, blù_, kiwo,
   {{0x224d00a4,0x20050201,0xcf92006e,0x8ee50a43}},	//   _naek_, _leli_, צטן_, _নবাগ,
   {{0xee5c003e,0x3ebf00c2,0xe9da20c0,0x2c690206}},	// [ade0] æðið_, ilut_, _яки_, _súdy_,
   {{0x200500aa,0x7d1b0f18,0x00000000,0x00000000}},	//   _neli_, irus, --, --,
   {{0x25ab5520,0x224d0da7,0x32040154,0x3ebf01ce}},	//   _excl_, _baek_, _pemy_, klut_,
   {{0xa3d600aa,0x979b006e,0xa49b05aa,0x62997812}},	//   ाइब_, _טשיק, _pwòc, giwo,
   {{0x20059cfa,0x759a0139,0x00000000,0x00000000}},	//   _beli_, _fífẹ, --, --,
   {{0x26c09cfb,0xf8b409d0,0x20059cfc,0xc3060037}},	//   llio_, ंकिय, _celi_, _مبرو,
   {{0x20059cfd,0xd8d700c1,0x9f4c00b3,0x66069cfe}},	//   _deli_, נוצט_, _redó_, _kekk,
   {{0x644e34d2,0x26c0028d,0xb5fb0131,0x9f4c00ee}},	//   _habi, nlio_, _inác, _sedó_,
   {{0x66068a22,0xf8b40789,0xd2910103,0x26c0409a}},	//   _mekk, ंकाय, _بینظ, ilio_,
   {{0x66069cff,0xdee603fc,0x9b5800c9,0x644e9d00}},	//   _lekk, _божи, виот_, _jabi,
   {{0x644e9d01,0x443801b9,0x26c00138,0x2a600167}},	//   _mabi, _mbr_, klio_, _bnib_,
   {{0x644e8a49,0x200504a3,0x66069d02,0x7d1b9d03}},	//   _labi, _zeli_, _nekk, brus,
   {{0xa3d606ed,0x4438695d,0x9f5e034f,0x9f4c0154}},	//   ाइड_, _obr_, _metí_, _gedò_,
   {{0xac1802ec,0x44381275,0x1bd4035f,0x660601ff}},	//   _року_, _nbr_, _коля, _aekk,
   {{0x6606782d,0x78b570f9,0xdb0a00f2,0x67d51af8}},	//   _bekk, rozv, _nyfø, рову,
   {{0x26c00020,0x44385d08,0x3a295102,0x569432d4}},	//   glio_, _abr_, _ucap_, баст,
   {{0x644e274a,0x660669ce,0x443802b6,0x39499d04}},	// [adf0] _babi, _dekk, _bbr_, _usas_,
   {{0x8883001c,0x7d020172,0x45b80b2f,0x52ad00aa}},	//   _ایسن, _mwos, угую_, टक्स,
   {{0x644e9d05,0xaca40129,0x20050d0a,0xf8bf020d}},	//   _dabi, _azịz, _reli_, guée_,
   {{0x66061cab,0x62358864,0x443800f0,0x61e419d0}},	//   _gekk, реду, _ebr_, žiln,
   {{0x9f5e0220,0x20059d06,0x3ce60036,0x95c83fe1}},	//   _detí_, _peli_, _nuov_, _бура_,
   {{0x8f152eb1,0x4425038c,0x764f0169,0x44389d07}},	//   афич, _øl_, _hacy, _gbr_,
   {{0x20059d08,0x7d0216ae,0xb5fb0037,0x764f0ff4}},	//   _veli_, _awos, _gnác, _kacy,
   {{0x2005008a,0x225f042d,0xcee835bf,0x7d022cd0}},	//   _weli_, _unuk_, درون_, _bwos,
   {{0x644e4681,0x645a0161,0x6f040995,0x518715d6}},	//   _yabi, _ótic, ćica, _сува,
   {{0x3ebf0222,0x7d1b8a81,0x644e9d09,0x764f0231}},	//   slut_, rrus, _xabi, _lacy,
   {{0xda660315,0x26c00150,0x7d020113,0x3ebf020a}},	//   авни, ylio_, _ewos, plut_,
   {{0x7d1b9d0a,0xeb9600c2,0x764f02a4,0xa3d600bc}},	//   prus, рию_, _nacy, ाइत_,
   {{0x66069d0b,0x7d0202f1,0xc4c5007f,0x00000000}},	//   _rekk, _gwos, वताओ, --,
   {{0x6d591f1a,0x66069d0c,0x8d74046b,0x6d4b7a6a}},	//   _irwa, _sekk, _داما, _isga,
   {{0xb8ce009f,0x66069d0d,0x764f02a4,0xdc9a2252}},	//   _कद_, _pekk, _bacy, _ביסל,
   {{0x644e9d0e,0x7ebe00dd,0x4438003e,0x26c0409a}},	//   _sabi, tëpi, _sbr_, ulio_,
   {{0x644e9d0f,0xf5e72357,0x66063c75,0x2d8d01cb}},	// [ae00] _pabi, рмул_, _vekk, nzee_,
   {{0x26c003ce,0x644e9d10,0x446302ec,0x66065899}},	//   slio_, _qabi, овув, _wekk,
   {{0x6606007a,0x26c0058a,0x644e0087,0x764f5d82}},	//   _tekk, plio_, _vabi, _facy,
   {{0x6d590b8e,0x644e6868,0x764f0169,0x673e0078}},	//   _orwa, _wabi, _gacy, _ippj,
   {{0x644e9d11,0xe0461a9c,0xa06a0291,0x11540829}},	//   _tabi, инди, када_, склю,
   {{0x442a01af,0x764f4b24,0x7d020193,0x443800e7}},	//   _ucb_, _zacy, _rwos, _ubr_,
   {{0x6d4b9d12,0x6d594eea,0xf8bf0257,0x75249d13}},	//   _asga, _arwa, quée_, luiz,
   {{0x7d0206a3,0xa5bb0076,0x9df700e5,0x68f602c3}},	//   _pwos, _scói, анът_, _otyd,
   {{0xe7fb04f8,0x44440350,0x2259003e,0xb1800174}},	//   ्रमा_, oe_, _óska_, ọọnụ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44449b92,0x6d5902e2,0x75240cad,0xe45700c1}},	//   ie_, _erwa, huiz, בייט_,
   {{0x44449d14,0x1eda00e3,0x7d0205bd,0xd00b0033}},	//   he_, _شباب_, _twos, _রায়_,
   {{0x673e00b3,0x81e80033,0x8cf40037,0xb4d60096}},	//   _appj, _মজা_, _اكتش, _हळू_,
   {{0x8c431e6d,0x752401cb,0xa5bb0065,0x7d1d0131}},	//   _мече, duiz, _gbóy, ásse,
   {{0x7e620a2c,0x00000000,0x00000000,0x00000000}},	//   _knop, --, --, --,
   {{0x44449d15,0x9f5e008f,0x96210789,0x8367010d}},	//   ee_, _metà_, यलेट_, یدال,
   {{0x7524002b,0x44440fd1,0x00000000,0x00000000}},	// [ae10] guiz, fe_, --, --,
   {{0x764f9d16,0x041a0033,0xd37b1102,0x00000000}},	//   _wacy, ন্সী_, кче_, --,
   {{0xf36721bd,0x7e629d17,0x00000000,0x00000000}},	//   штан, _onop, --, --,
   {{0x44449d18,0x4b370054,0x7bd9006e,0x75240381}},	//   ae_, שראל_, אַנק, buiz,
   {{0x44449d19,0x660d0272,0x463a00c1,0x27ec0220}},	//   be_, maak, _גערע, ždne_,
   {{0x660d60d5,0x7e629d1a,0x83f800ae,0x6d590027}},	//   laak, _anop, _верс_, _rrwa,
   {{0xf8bf8d39,0x64450051,0x3f810094,0x3e7800ee}},	//   ltés_, mehi, áhu_, _néts_,
   {{0x7ebe00dd,0x64459abd,0x660d9d1b,0xc33200a1}},	//   këpu, lehi, naak, _מול_,
   {{0xf8bf8d39,0x3e780102,0x00000000,0x00000000}},	//   ntés_, _rétt_, --, --,
   {{0x4c85186d,0xcc8900cd,0x70740037,0xf8bf00fd}},	//   слов, انده_, _والذ, ités_,
   {{0x3a2d01e9,0x5f791be8,0x09e6276f,0xbb45222a}},	//   мep_, _حماس_, йонн, щенк,
   {{0x44443f74,0x6d5900a5,0xff50010d,0x660d3eb3}},	//   ze_, _trwa, _زخم_, jaak,
   {{0x444466f5,0x6d590193,0x6e2910ec,0x64450a19}},	//   ye_, _urwa, mgeb, kehi,
   {{0x44449d1c,0x6e295b8c,0x9dd60089,0x3ff9006e}},	//   xe_, lgeb, _פוסק_, טפֿע,
   {{0x177908d1,0x9f470094,0x7c94001c,0x660d083e}},	//   асть_, ybný_, _بشنا, faak,
   {{0x07a33ad2,0x75249d1d,0x6e2932e8,0x3f7a0142}},	//   часн, tuiz, ngeb, אָמע,
   {{0xe4ea0286,0x3cfb00a4,0x00000000,0x00000000}},	// [ae20] اعره_, लीचे_, --, --,
   {{0x44449d1e,0x394007ac,0x6e29042c,0xa3ea1782}},	//   ue_, _ipis_, hgeb, уджа_,
   {{0x187700a1,0x48ee0e50,0xe9f90065,0x6e290371}},	//   _העיר_, _इंडो_, _ajẹ_, kgeb,
   {{0x366a0cd7,0x2c21009d,0x6e29029a,0x41d91cff}},	//   _само_, _माझं_, jgeb, _बृहस,
   {{0x6e290f89,0xf8bf9d1f,0x75240143,0x64453e5d}},	//   dgeb, ctés_, quiz, behi,
   {{0x44449d20,0x6d4903a9,0x6e29000b,0x7afa0063}},	//   qe_, dwea, egeb, yptt,
   {{0x43860080,0xe7fb0b7f,0x6e29357f,0x39400167}},	//   _الأق, ्रता_, fgeb, _lpis_,
   {{0x8cf48e34,0x394013c1,0xf8bf9d21,0x776303be}},	//   озиц, _opis_, ntér_, _ánxe,
   {{0x3940835d,0xf65300ca,0xdb181054,0xa3d600c3}},	//   _npis_, לצה_, _vyví, ाइव_,
   {{0x62829d22,0x660d0517,0x5b141d18,0x8fa60d9b}},	//   lkoo, zaak, омот, _лазе,
   {{0x2d821c54,0x7c2801cb,0x6fb6001c,0x6e290381}},	//   ške_, rgdr, _امضا, bgeb,
   {{0x62822836,0x6d49547b,0x7e629d23,0x660d0188}},	//   nkoo, bwea, _unop, xaak,
   {{0x660d0517,0xc9841669,0x6282715f,0x64459d24}},	//   vaak, пури, ikoo, yehi,
   {{0xd9180084,0x200e1d49,0x660d86d8,0x628b0216}},	//   щью_, nafi_, waak, zhgo,
   {{0x62829d25,0x5c37040a,0x644500d3,0x39409d26}},	//   kkoo, _הטוב_, vehi, _epis_,
   {{0xf96b013d,0x62829d27,0xfaa41009,0xe69400c2}},	//   _брой_, jkoo, _најо, писы,
   {{0x62829d28,0x660d2836,0xf8bf025a,0x200e0044}},	// [ae30] dkoo, raak, utés_, kafi_,
   {{0x660d82ad,0xf8bf9d29,0xf8070291,0x69cd01e9}},	//   saak, rtés_, _учин, _izae,
   {{0x660d9d2a,0x64456948,0xf8bf20cc,0xe7dd0c22}},	//   paak, rehi, stés_, _मणिप,
   {{0xaac90c3c,0x7aea9d2b,0x4ac920cd,0xb4db0139}},	//   रतिक, _muft, रतिव, _asàt,
   {{0x7aea6364,0x6aad00dd,0x21690581,0xe8d90134}},	//   _luft, _mjaf, рили_, _nrị_,
   {{0xa3d60378,0x7bc60034,0x11d40286,0x473400d1}},	//   ाइश_, ękuj, ستند, _بریز,
   {{0x6e291c7d,0xe8d90134,0x62820188,0x287c006e}},	//   tgeb, _arị_, bkoo, רנומ,
   {{0x623430fd,0x69cd0062,0x6d494ca9,0x00000000}},	//   _несу, _ozae, twea, --,
   {{0x6e290b5e,0x7aea02e2,0xd1310d5b,0x62890139}},	//   rgeb, _auft, _زما_, _ileo,
   {{0x6e2901f4,0x6aad0065,0x7aea020a,0x301400ae}},	//   sgeb, _ajaf, _buft, _ндур,
   {{0x39409d2c,0xb90e0129,0x7aea00c4,0x6e290abf}},	//   _spis_, balị_, _cuft, pgeb,
   {{0x7aea5cfe,0x34a600a3,0x00000000,0x00000000}},	//   _duft, _खद्द, --, --,
   {{0x3eb80018,0x00000000,0x00000000,0x00000000}},	//   _írta_, --, --, --,
   {{0x628902e0,0x39400087,0xf41f0033,0x672706b0}},	//   _lleo, _vpis_, ন্তর_, fujj,
   {{0x6289328d,0x39400034,0x869a001f,0x629b010a}},	//   _oleo, _wpis_, атат_, _omuo,
   {{0x6aad003e,0x00000000,0x00000000,0x00000000}},	//   _gjaf, --, --, --,
   {{0x3940005f,0xf8bf0ac9,0x200e03e3,0x61e404ad}},	// [ae40] _upis_, rtér_, yafi_, žilk,
   {{0xa3d60b89,0x03a60c79,0x67272ea0,0xb5fb0328}},	//   ाइल_, оизо, bujj, _unán,
   {{0x7ae4280e,0xf8bf05f1,0x200e00e7,0x78bc9d2d}},	//   _kiit, ptér_, vafi_, morv,
   {{0x7ae4008c,0x09de0033,0x200e155e,0x7bc302ac}},	//   _jiit, _ভ্যা, wafi_, _mynu,
   {{0x628258a6,0x200e9d2e,0x7ae49d2f,0x7870007b}},	//   rkoo, tafi_, _miit, _sävy,
   {{0x7ae408a3,0x62829d30,0x6b570174,0x7bc30233}},	//   _liit, skoo, _ụgw, _oynu,
   {{0x200e9d31,0x00000000,0x00000000,0x00000000}},	//   rafi_, --, --, --,
   {{0x7ae402fd,0xf41f0081,0x7aea0022,0x99990031}},	//   _niit, ন্দর_, _ruft, lesť_,
   {{0x78bc9d32,0x10a614fb,0x2b5c05bd,0x7bc3381b}},	//   korv, _диан, _srvc_, _aynu,
   {{0xb5fb132d,0x7d1d0018,0x6aad0085,0xf8bf014b}},	//   _anál, ássa, _sjaf, orée_,
   {{0x7bc302ad,0x7ae49d33,0x69c49d34,0x78bc9d35}},	//   _cynu, _biit, _ayie, dorv,
   {{0xe8d90028,0xf8bf08a8,0x69c40154,0x81de0033}},	//   _trị_, guén_, _byie, _দ্য_,
   {{0x7ae49d36,0x78bc01df,0x648000c2,0x200c026a}},	//   _diit, forv, _töih, _kedi_,
   {{0x6d420036,0x50ca00b7,0x7aea9d37,0xa5bb1094}},	//   _ipoa, ितिष, _tuft, _ocór,
   {{0x200c8a99,0x7ae43791,0x2bd102d5,0x20c90037}},	//   _medi_, _fiit, _हरया, dúil_,
   {{0xd9e32171,0xe8d90065,0xf8bf89c0,0x46682a59}},	//   _गणपत_, _irọ_, drée_, орум_,
   {{0xa5bb3906,0xe5341aad,0x00000000,0x00000000}},	// [ae50] _acór, меть, --, --,
   {{0x28d20034,0x29090174,0x78bc0036,0x629b028d}},	//   _दीपि, _iwaa_, corv, _smuo,
   {{0xf8bf00fd,0x6289020a,0x29090113,0x8c3c026a}},	//   grée_, _pleo, _hwaa_, ciğe,
   {{0x68ed9d38,0x6abd1848,0x29090134,0x7ae47944}},	//   _kuad, nosf, _kwaa_, _xiit,
   {{0x68ed061d,0x200c0634,0x59d35a5f,0x1a9c006e}},	//   _juad, _bedi_, _सरफर, סידע,
   {{0x68ed9d39,0x200c007e,0x3dd00033,0x37df0033}},	//   _muad, _cedi_, াখাল, _ব্যর,
   {{0x02a744aa,0x200c08bb,0x68ed0527,0xe8d90294}},	//   _драм, _dedi_, _luad, _nrọ_,
   {{0x64559d3a,0x200c0032,0x313544f3,0x629b024a}},	//   _hazi, _eedi_, _небр, _umuo,
   {{0x7ae40084,0xe8d90294,0x61e90062,0x29090134}},	//   _riit, _arọ_, _igel, _nwaa_,
   {{0x7ae402fd,0x200c4767,0x64555d21,0x320d3acc}},	//   _siit, _gedi_, _jazi, _heey_,
   {{0x64559d3b,0x29090174,0xb5fb0139,0x69c40063}},	//   _mazi, _awaa_, _anám, _syie,
   {{0x64559d3c,0x6abd9d3d,0x68ed01f7,0x7bc393ee}},	//   _lazi, gosf, _buad, _vynu,
   {{0x7ae49d3e,0x68ed09e9,0xaca30129,0xdb180146}},	//   _viit, _cuad, _ahụh, _vyvá,
   {{0x64559d3f,0x68ed29e4,0x00000000,0x00000000}},	//   _nazi, _duad, --, --,
   {{0x2aa40103,0x366a0cba,0x7ae44174,0x61e9039f}},	//   rűbb_, баво_, _tiit, _ogel,
   {{0x61e96139,0x61e40268,0x68ed151d,0xf8bf9d40}},	//   _ngel, žili, _fuad, quén_,
   {{0x64554858,0x68ed35b9,0x18a65db8,0x29090134}},	// [ae60] _bazi, _guad, _наим, _gwaa_,
   {{0x64559d41,0x6ad100c7,0xf8bf025a,0xa84a0037}},	//   _cazi, _সংযো, trée_, _الدم_,
   {{0xb5fb0074,0x645a00c9,0x200c9d42,0xa87b00a1}},	//   _znám, _ótim, _redi_, _האיר,
   {{0x25ad02e6,0x20c90080,0x3d1c0b89,0x200c9d43}},	//   _žele_, súil_, _मिले_, _sedi_,
   {{0x64559d44,0x66041e52,0x200c9d45,0x26c20022}},	//   _fazi, mbik, _pedi_, _ikko_,
   {{0x61ff01d4,0x64559d46,0x66041cb7,0x00000000}},	//   ıqla, _gazi, lbik, --,
   {{0x43430bb9,0x200c013d,0x76430103,0xb4db0139}},	//   _перв, _vedi_, őnye, _isàp,
   {{0x200c1a2e,0x64550201,0x66047c82,0x75242733}},	//   _wedi_, _zazi, nbik, oriz,
   {{0xc10600e3,0xfe6f0037,0x00000000,0x00000000}},	//   _رواي, ادى_, --, --,
   {{0x75249d47,0x7c3a0364,0x68ed01b5,0x6e3b010a}},	//   iriz, uftr, _ruad, afub,
   {{0x68ed9d48,0xb5fb0037,0x29090169,0x75242a83}},	//   _suad, _snám, _swaa_, hriz,
   {{0x75249d49,0x6fa2023a,0x29090350,0x7e7903a8}},	//   kriz, _केयू, _pwaa_, _gowp,
   {{0x68ed9d4a,0xac1889db,0x6298020d,0xc4be007f}},	//   _quad, _долу_, évoy, ्ताओ,
   {{0xe8d900de,0xb4db0139,0x387a0178,0x6b8101cd}},	//   _trọ_, _apàn, _copr_, bylg,
   {{0x64556bea,0xddc90ea3,0x6af300e3,0x443148f5}},	//   _razi, mješ, _كثير, _rcz_,
   {{0x64559d4b,0xddc92650,0xb4db0065,0x66048996}},	//   _sazi, lješ, _asàp, gbik,
   {{0x64559d4c,0xc867450e,0x95cb63df,0xddcb0034}},	// [ae70] _pazi, _етни, сува_, _zagł,
   {{0x2a69006c,0xddc90a39,0x645512e3,0x66049d4d}},	//   _hnab_, nješ, _qazi, abik,
   {{0x64550b9d,0x925900c2,0x2a6901d3,0x6d460216}},	//   _vazi, жает_, _knab_, çkaj,
   {{0x645552b4,0x75249d4e,0x7d030065,0xa49b0154}},	//   _wazi, briz, _jírò, _otòg,
   {{0xdb1802fd,0x7524013d,0x64552c58,0x854400ae}},	//   _hyvä, criz, _tazi, _пэре,
   {{0x26c900e1,0x660f9d4f,0xf95800d7,0x00000000}},	//   llao_, _heck, פסות_, --,
   {{0xdb1800c2,0x00000000,0x00000000,0x00000000}},	//   _jyvä, --, --, --,
   {{0x61e90036,0x77fb058f,0x00000000,0x00000000}},	//   _ugel, ्रुक_, --, --,
   {{0x9f5c0146,0x660f9d50,0x6e3b003e,0x00000000}},	//   mavý_, _meck, rfub, --,
   {{0x660f9d51,0x3b8523aa,0x6d5b8889,0x66040052}},	//   _leck, длог, rvua, zbik,
   {{0xf8bf0396,0x26c90580,0xa3d60851,0x6e3b05bd}},	//   guém_, klao_, ाइए_, pfub,
   {{0xedd50037,0xa3b500aa,0x9f5c00d4,0x00000000}},	//   _قياد, _जखन_, navý_, --,
   {{0x3ead2452,0xcdcb010d,0x3ebf9d52,0xddc90095}},	//   mnet_, _اذان_, mout_, bješ,
   {{0x3ebf14d0,0x661d0f04,0xf8bf0072,0xb90600a4}},	//   lout_, _adsk, quél_, _फळ_,
   {{0x3ead023b,0xfbd100aa,0x66046b12,0xeb9900d3}},	//   onet_, _हरिम, tbik, _фий_,
   {{0x3ead9d53,0x3ebf000d,0x75249d54,0x7afc9d55}},	//   nnet_, nout_, triz, írte,
   {{0x66049d56,0xe5a39d57,0x3ead1305,0x9f5c0094}},	// [ae80] rbik, вити, inet_, davý_,
   {{0x752402a7,0x3ead9d58,0x3ebf9d59,0xfbd10442}},	//   rriz, hnet_, hout_, _हराम,
   {{0x3ebf02f1,0x7524005c,0x93c300d3,0x3ead9076}},	//   kout_, sriz, _ţări, knet_,
   {{0x660f1081,0x65698315,0x3ebf014b,0xd1ca9d5a}},	//   _geck, _šehe, jout_, олее_,
   {{0x3cfd023e,0x2ee6009c,0xa3df00aa,0x00000000}},	//   _ntwv_, _riof_, देब_, --,
   {{0x3ead9d5b,0xb5fb037a,0x32e8026a,0x74e7004d}},	//   enet_, _anáh, _eşya_, _одяг_,
   {{0xddc903c6,0x3ead9d5c,0x20b901b3,0x3ebf5aac}},	//   vješ, fnet_, чыць_, fout_,
   {{0x3ebf9d5d,0x3ead0e9f,0x539b00ca,0x26c00036}},	//   gout_, gnet_, _וילו, noio_,
   {{0x32066a66,0xa3d60034,0xddc90357,0x00000000}},	//   mboy_, ाइक_, tješ, --,
   {{0x21260167,0x6ef50090,0x3ead9d5e,0x00000000}},	//   mroh_, _iġbn, anet_, --,
   {{0x3ebf9d5f,0x3ead9d60,0xddc91fce,0xda3502e3}},	//   bout_, bnet_, rješ, нены,
   {{0xcfa92204,0x32069d61,0xdddb0087,0xbd4600e3}},	//   _عالم_, nboy_, skuš, _يناي,
   {{0xddc903c6,0x26c00451,0xdb0a0212,0xeabf00fc}},	//   pješ, doio_, _nyfö, roù_,
   {{0x660f9d62,0xf77305bc,0x3ea4032e,0xb4b800b6}},	//   _seck, پاس_, limt_, ङको_,
   {{0x660f1177,0x320600f9,0xcc330504,0x6a7f0052}},	//   _peck, kboy_, _شروع, _dëfr,
   {{0x850502a3,0x26c00036,0x2a69037a,0xe8d900fe}},	//   فورن, goio_, _unab_, _trỏ_,
   {{0x660f070a,0xf8ae00bf,0x2d842858,0x32069d63}},	// [ae90] _veck, شکی_, nyme_, dboy_,
   {{0xdb180222,0x26c9005f,0x3ebf9d64,0x3ead0bd2}},	//   _tyvä, slao_, zout_, znet_,
   {{0x660f0222,0x3ead038c,0x26c00072,0x9f5c00d4}},	//   _teck, ynet_, boio_, tavý_,
   {{0x661d01c5,0xe29800d6,0x291900c2,0x3ebf0124}},	//   _udsk, має_, ossa_, xout_,
   {{0x291902fd,0xa069433a,0x3ead0400,0x9f5c0146}},	//   nssa_, зала_, vnet_, ravý_,
   {{0x291902fd,0x7ff503ed,0x3ebf9d65,0xf536040a}},	//   issa_, رستا, wout_, _אנשי_,
   {{0x3ead5b9f,0xdbd60fc4,0x752d01e9,0xa295097a}},	//   tnet_, _jääk, luaz, _заві,
   {{0x3ead9d66,0x00000000,0x00000000,0x00000000}},	//   unet_, --, --, --,
   {{0xdbd602fd,0xc0cb4242,0x3ebf9d67,0x752d0451}},	//   _lääk, _дуже_, rout_, nuaz,
   {{0x3ebf3806,0xeb990284,0x00000000,0x00000000}},	//   sout_, зио_, --, --,
   {{0x291902fd,0x20074389,0x3ead9d68,0x6ef502a1}},	//   essa_, mbni_, pnet_, _iġbo,
   {{0x3d9500d3,0x2d84034f,0xb5fb9bfb,0x752d0062}},	//   _пиер, byme_, _ináw, kuaz,
   {{0xf2d200c1,0x96150081,0x61fb0051,0x7e6b03a9}},	//   טעט_, িলাম_, _mful, _ingp,
   {{0x752d08b9,0xe00200aa,0xb9150294,0xeb990e05}},	//   duaz, रुपद_, ladị_, _нил_,
   {{0x2bc61860,0xfbc6000d,0x26c000e5,0x29190084}},	//   _रुपा, _रुपम, toio_, assa_,
   {{0xe81c000d,0x2bfb0789,0x61fb0172,0x764d010a}},	//   _भएका_, लुरू_, _nful, geay,
   {{0xd9de0081,0x22b8033b,0xb4660131,0x09de0033}},	// [aea0] _ভ্রম, nčke_, нкал, _ভ্রা,
   {{0x26c0028d,0x61fb5c2a,0xe8d9020b,0x00000000}},	//   soio_, _aful, _trề_, --,
   {{0x389b0130,0xb2261728,0x7e6b00f9,0x32069d69}},	//   _זיינ, емел, _ongp, tboy_,
   {{0x2ca5510f,0x6aa69d6a,0xd84300d8,0x00000000}},	//   hild_, nikf, _trčí_, --,
   {{0xc1e70084,0x752d028d,0x2ca52ba4,0xd8430094}},	//   ньше_, cuaz, kild_, _určí_,
   {{0x59d30b94,0x7e6b01af,0x6616008c,0x61fb083e}},	//   _सरसर, _angp, layk, _eful,
   {{0xb5fb0080,0xce94008f,0x7ee600d3,0x44f6003e}},	//   _snái, какъ, нцие, _hæ_,
   {{0x661601af,0x648000c2,0x29199d6b,0x433b006e}},	//   nayk, _töis, yssa_, _מעלב,
   {{0x2900023e,0x2ca59d6c,0x00000000,0x00000000}},	//   _ntia_, fild_, --, --,
   {{0x4f9617e9,0x253700c1,0xb4db0139,0x61e4033b}},	//   _преу, עניש_, _apàj, žils,
   {{0xa3d634d8,0x290009d7,0x6aa6160e,0xab27001f}},	//   ाइट_, _atia_, fikf, ноќа_,
   {{0xdbd6007a,0x2d84034f,0x98a700c4,0x672e0231}},	//   _rääk, pyme_, _điđe_, dubj,
   {{0x2ca59d6d,0x291900c2,0x44f64d1e,0x00000000}},	//   bild_, ussa_, _næ_, --,
   {{0xdbd600c2,0x3a20026a,0x672101f9,0x25870139}},	//   _pääk, _edip_, áljo, _lílú_,
   {{0x92100e72,0x764d037a,0x69c09d6e,0x00000000}},	//   ाराज_, teay, ümer, --,
   {{0x752d9d6f,0xadc30032,0x672114f3,0x7af70328}},	//   tuaz, _akẹk, šljo, _éxta,
   {{0x659400d3,0x00000000,0x00000000,0x00000000}},	// [aeb0] гату, --, --, --,
   {{0x752d08b9,0xa49b01b9,0x00000000,0x00000000}},	//   ruaz, _stòb, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a70126,0x44f6003e,0x00000000,0x00000000}},	//   lijv, _fæ_, --, --,
   {{0x752d028d,0x69da007f,0xb7f20a43,0x00000000}},	//   quaz, ęteg, _জড়িত_, --,
   {{0x8fa52ca3,0x999205aa,0xd1b80246,0x21661412}},	//   кале, _deyň_, رانا_, тиши_,
   {{0xb88200b6,0x394900dc,0x2eb52753,0x623500ae}},	//   _říka, _lpas_, ксис, _иеву,
   {{0x2ca51507,0x78a701c0,0x61fb3e35,0x92580077}},	//   wild_, hijv, _uful, _паст_,
   {{0x2d8b0343,0x3949022e,0x2ca58d46,0x00000000}},	//   áce_, _npas_, tild_, --,
   {{0x44331df6,0x4c8518be,0x9d440d5b,0x6abc0d7e}},	//   ngx_, тлов, ائين, ैत्र,
   {{0x39499d70,0x6aa67186,0x29001043,0x3a2000ec}},	//   _apas_, tikf, _stia_, _pdip_,
   {{0xfeb80080,0x60c39d71,0xfaa603bf,0x628b084e}},	//   _كانت_, lonm, тамо, nkgo,
   {{0x82760130,0x7e9a006e,0xed590231,0x78a70052}},	//   דערע_, _קסנו, _цол_, fijv,
   {{0x60c3022b,0x6aa68921,0x7d1b9a21,0xdca50095}},	//   nonm, sikf, msus, _шали,
   {{0xe7371312,0x7d1b3831,0x6b8d01c2,0x661600f9}},	//   кер_, lsus, _ƙagu, tayk,
   {{0x61ed0995,0x60c30364,0x656902ef,0xddd90383}},	//   žalj, honm, _šeha, _pawň,
   {{0x6616008a,0x9583249c,0x60c30be3,0x66e32cbf}},	// [aec0] rayk, алте, konm, рота,
   {{0x14c80979,0x66160270,0x64be0285,0x628b084e}},	//   رهای_, sayk, ्तेश, ekgo,
   {{0xddc2005f,0x7d1b35c0,0x60c353c8,0x2552022b}},	//   _mnoš, hsus, donm, _wņl_,
   {{0x7d1b0f06,0xd36f00e3,0x6b7a006e,0x527507ed}},	//   ksus, تهم_, ורענ, лучу,
   {{0x60c30324,0x00000000,0x00000000,0x00000000}},	//   fonm, --, --, --,
   {{0xa3df2373,0xe0430012,0x399b0089,0x7d1b257f}},	//   देह_, инчи, וינד, dsus,
   {{0x64a31acf,0x425600d3,0x4438044c,0x00000000}},	//   _тара, _итат, _icr_, --,
   {{0x44389d72,0x7d780037,0xc7b300ca,0xeea70077}},	//   _hcr_, فمبر_, יבו_, ктык_,
   {{0x645c9d73,0x7d1b152a,0xdd900391,0xa49b0154}},	//   _kari, gsus, صود_, _gwòs,
   {{0xa3df0336,0x9f980579,0x013700ca,0xec320103}},	//   देव_, lším_, _ברמת_, جودگ,
   {{0x5fb605cd,0x6148003e,0x7d1b0e22,0x645e0365}},	//   _अखिल, _félö, asus, idpi,
   {{0x645c9d74,0x2fd700cd,0xc333028c,0x39490167}},	//   _lari, _شوند_, סור_, _ppas_,
   {{0x81e400c7,0x62809d75,0x6e220129,0xf6530103}},	//   পুর_, _momo, _idob, یئر_,
   {{0x645c9d76,0x62809d77,0x7d020032,0x6aa46ecd}},	//   _nari, _lomo, _itos, _emif,
   {{0x9cd700a1,0x78a79d78,0x6cd900c1,0xdbcc003e}},	//   _שווה_, rijv, _אַקצ, _góði,
   {{0x62809d79,0x645c9d7a,0x9f98025b,0x60c305aa}},	//   _nomo, _aari, jším_, zonm,
   {{0x645c9d7b,0x35f46d70,0x44389d7c,0x645e029a}},	// [aed0] _bari, рпур, _bcr_, fdpi,
   {{0x645c9d7d,0x7d1d001f,0xa8551e58,0xa49b0065}},	//   _cari, ássi, _скоч, _awòr,
   {{0x645c440c,0x62809d7e,0x7aed1f9e,0x2c1a0285}},	//   _dari, _bomo, _kiat, _मजनू_,
   {{0x6e223a77,0x7aed0090,0x60da00b7,0xe61f00fc}},	//   _ndob, _jiat, _ahtm, _clôt_,
   {{0x645c9d7f,0x62805bdf,0x7aed0068,0x7c381271}},	//   _fari, _domo, _miat, _ocvr,
   {{0x645c6dff,0x2ecb04d7,0x7aed9d80,0x765d0ddc}},	//   _gari, ात्त, _liat, _hasy,
   {{0xa3df3516,0xa28300cd,0x7d029d81,0x6280137f}},	//   देश_, _پیشو, _atos, _fomo,
   {{0x645c9d82,0x7d1b0006,0x7aed0da3,0xb5fb0a93}},	//   _zari, tsus, _niat, _gnát,
   {{0x765d4956,0x645c9d83,0x5c150ab3,0x7d020063}},	//   _masy, _yari, льну, _ctos,
   {{0x645c46f7,0x6e220129,0x7d020076,0xaca30294}},	//   _xari, _edob, _dtos, mpịn,
   {{0x62800415,0x69cd0167,0x7d02084e,0xb5fb010a}},	//   _yomo, _ayae, _etos, _gaág,
   {{0x765d0c56,0x7aed9d84,0x7d1b00aa,0x628001ff}},	//   _nasy, _ciat, psus, _xomo,
   {{0x7aed042b,0x8c4509b9,0x22b80087,0xe8f70c10}},	//   _diat, _беле, nčka_, лля_,
   {{0x6d59311b,0x7e7b005f,0x6e221670,0xddc20542}},	//   _iswa, ljup, _zdob, _unoš,
   {{0x645c006d,0x7aed0018,0x765d66e5,0xb8dc09a1}},	//   _rari, _fiat, _basy, _अद_,
   {{0x645c9d85,0x7aed9d86,0x99860182,0x765d03a8}},	//   _sari, _giat, _ملبو, _casy,
   {{0x05661119,0x765d02e7,0x9f98030b,0x22b8174d}},	// [aee0] ыван, _dasy, vším_, jčka_,
   {{0x62800d9f,0x645c9d87,0x399b00ca,0x6d593455}},	//   _somo, _qari, _נייד, _mswa,
   {{0x03265c84,0x22b80031,0x9f9802c6,0xe61f03a8}},	//   уден, ečka_, tším_, _clôs_,
   {{0xe29731ef,0x6d4b5dc0,0xdce203e5,0xa5bb0610}},	//   лах_, _opga, _proċ, _idón,
   {{0x645c3c2e,0x9f980146,0xe7b3001c,0x216714e0}},	//   _tari, rším_, _نمید, лици_,
   {{0x4438034f,0xd00f0037,0xe8d90023,0x645c9d88}},	//   _ucr_, كله_, _trễ_, _uari,
   {{0x7d020067,0x6d4b39c1,0xb4e00971,0x9f980146}},	//   _stos, _apga, दगी_, pším_,
   {{0x4444501b,0x44236bea,0x62800036,0x6d4b01ff}},	//   lf_, _zdj_, _uomo, _bpga,
   {{0x7aed9d89,0x0caa1121,0xb5fb0146,0x4444019e}},	//   _riat, етни_, _znás, of_,
   {{0x7aed9d8a,0x7c2301ff,0x6d5902ac,0x2018003e}},	//   _siat, _cdnr, _dswa, _þri_,
   {{0x44449d8b,0x7aed9d8c,0x6d4b0072,0x29120113}},	//   if_, _piat, _epga, _awya_,
   {{0x6e22011d,0xf1b81f77,0x20c90076,0x7f5a009e}},	//   _udob, _अशान, búis_, _istq,
   {{0x7aed8e7a,0xa80208bb,0x984b008f,0x3ea6004d}},	//   _viat, ğınd, нява_, _imot_,
   {{0x44440505,0xa8020702,0xa49b098d,0x7c38015c}},	//   jf_, şınd, _atòn, _ucvr,
   {{0xd6db00b8,0x765d9d8d,0x6d409d8e,0x7aed0139}},	//   ета_, _pasy, ltma, _tiat,
   {{0x7bd802e6,0x44443f76,0x61ed0995,0x6d4076b8}},	//   _izvu, ef_, žali, otma,
   {{0x44449d8f,0x6d409d90,0x1fe10852,0xf1a40034}},	// [aef0] ff_, ntma, _पण्ड, _खेलन,
   {{0x78a50088,0x765d97eb,0xb4bf00b6,0x6d409d91}},	//   _umhv, _wasy, ँके_, itma,
   {{0x1cbb00c1,0x6d402c97,0x3ea60559,0x6ec70285}},	//   עמבע, htma, _omot_, ावमु,
   {{0x44448184,0x9f5e00b3,0xdf610065,0x00000000}},	//   af_, _letó_, _lẹ́è, --,
   {{0x660d34ac,0x44440063,0x6d4002c6,0xe1f8013f}},	//   mbak, bf_, jtma, угі_,
   {{0x660d02ec,0x3ea688a0,0x5f050ff5,0x22b81e4d}},	//   lbak, _amot_, азка, rčka_,
   {{0x752d0063,0x6d5906b0,0xf8bf014b,0x1e950161}},	//   lraz, _sswa, lués_, ирир,
   {{0x660d0a00,0x752d2f8e,0xdce205db,0xb5fb00d8}},	//   nbak, oraz, _droč, _znár,
   {{0x212b0028,0xdf610032,0x7e7b00bc,0xe7fa00b6}},	//   _ích_, _bẹ́è, rjup, ्डमा_,
   {{0x3ea60222,0x103500cd,0x752d0072,0x0b45007e}},	//   _emot_, _خبرگ, iraz, анон,
   {{0x752d030b,0xbb456aa5,0x660d3cea,0x2bfb04f1}},	//   hraz, шенк, kbak, लुगू_,
   {{0x09e60d47,0xfc3f000d,0x752d9d92,0x6d592c4e}},	//   ионн, ří_, kraz, _tswa,
   {{0x6d599d93,0x89d600f3,0x6d4001cb,0x660d0c89}},	//   _uswa, рінш, ctma, dbak,
   {{0x752d042d,0x225f9d94,0xa5bb0139,0xb4bf00b6}},	//   draz, _lauk_, _adóo, ँको_,
   {{0x752d02a7,0x7d0913b2,0xdb03015e,0xeb9911db}},	//   eraz, lpes, _exnò, _шик_,
   {{0xfb2400cd,0x660d299a,0xcf9200c1,0x752d7f71}},	//   _اروپ, gbak, קטן_, fraz,
   {{0x752d8c47,0xf8bf6521,0xa3e82231,0x7d099d95}},	// [af00] graz, gués_, मेन_, npes,
   {{0x44449d96,0x2a60022e,0xd90d0470,0x3940009e}},	//   uf_, _haib_, _سیف_, _iqis_,
   {{0x44449d97,0x660d9d98,0x752d7b5b,0xd7640260}},	//   rf_, bbak, araz, _انجی,
   {{0x752d0c01,0xd7bb0054,0xe24600e3,0xf8bf020d}},	//   braz, _יציר, شخصي, bués_,
   {{0x28db1362,0x752d00e5,0x444401bf,0xc05a004d}},	//   _मीडि, craz, pf_, вій_,
   {{0xdce203ce,0x2a60022e,0x7e0e3ec9,0x394d3b82}},	//   _proč, _laib_, सर्ग_, çesi_,
   {{0xd372177a,0x20c90037,0xd9d30386,0x00000000}},	//   _ظهر_, túir_, _सर्ट, --,
   {{0xdce202dd,0x629901bf,0x2a609d99,0x6d400aab}},	//   _vroč, chwo, _naib_, ttma,
   {{0x8c3c01e8,0xddc901e8,0x39400197,0x66fc0146}},	//   liği, rdeş, _nqis_, _očko,
   {{0x672106b8,0xdce2042d,0x20c90076,0x5fa73c80}},	//   šlji, _troč, súir_, _केवल,
   {{0x99920154,0xdce205db,0x201c4b2b,0xa80204a8}},	//   _deyō_, _uroč, mavi_, ğıld,
   {{0x201c9d9a,0x38ad02ef,0x2a608bed,0xa8020367}},	//   lavi_, džra_, _caib_, şıld,
   {{0x2a60023e,0xf8bf0103,0x0e9b0327,0xc98400d3}},	//   _daib_, nség_, _בשאל, оури,
   {{0xda070521,0x8d850260,0x752d0e9e,0xb5fb0131}},	//   _व्रत_, _دشمن, vraz, _anáp,
   {{0x2a60006c,0x629800d9,0x23a50034,0x660d9d9b}},	//   _faib_, īvoj, _गेंद, tbak,
   {{0x8c3c0b88,0x35f54d0c,0x2a600510,0xf8bf00fd}},	//   diği, спар, _gaib_, tués_,
   {{0x201c0660,0x95cb63df,0x752d20a6,0xf8b10a85}},	// [af10] kavi_, тува_, uraz, _فکس_,
   {{0x752d20b0,0x7af8023e,0xf3672a5a,0x225f6619}},	//   rraz, _kuvt, итен, _sauk_,
   {{0x201c01e8,0xa85600a1,0x14b8142e,0x00000000}},	//   davi_, _היתה_, _आदरण, --,
   {{0x2a600197,0x62351009,0x7d090e1d,0x00000000}},	//   _xaib_, седу, ypes, --,
   {{0xf8bf9d9c,0xaca40065,0xe8d90294,0xddd905aa}},	//   qués_, _ajọy, _nsị_, _pawō,
   {{0x386102e2,0x77f50751,0x00000000,0x00000000}},	//   _jahr_, _आलोक_, --, --,
   {{0xe3e500c7,0xb3e500c7,0xe8d90129,0x339500e3}},	//   _প্রব, _প্রজ, _asị_, _الأز,
   {{0x02a444b2,0x945400a7,0x57b800ca,0xdc016bbd}},	//   _друм, _çərş, ילוב_, ोर्ड_,
   {{0x201c02e6,0xa1943140,0x2a600085,0xdb1800d4}},	//   bavi_, _датч, _raib_, _vyvý,
   {{0x2a6001bb,0x201c26ae,0x386103e3,0x0dc80291}},	//   _saib_, cavi_, _nahr_, јући_,
   {{0x7d099d9d,0x1fa70e48,0x2a60022e,0x26c90172}},	//   spes, _траг, _paib_, koao_,
   {{0x7d09254d,0xdb1e030b,0x2a60006c,0x321d01c2}},	//   ppes, íván, _qaib_, nawy_,
   {{0xddc90292,0x3ead9d9e,0x290d00d3,0xa49b015e}},	//   ljež, miet_, ţean_, _atòm,
   {{0x3ead9d9f,0xe73a4d40,0xdd8e0037,0x00000000}},	//   liet_, лег_, _سوى_, --,
   {{0xd62a7ee9,0x2a60061d,0xf8bf0103,0x38610090}},	//   лове_, _taib_, zség_, _dahr_,
   {{0x3ead2b8c,0x629800d9,0x201c15f4,0x86991f47}},	//   niet_, īvok, zavi_, атут_,
   {{0x98a600c2,0x3861107b,0x66fc0154,0xdddb05db}},	// [af20] _гипе, _fahr_, _zčkl, hkuž,
   {{0xb97b00a1,0x8c3c01e8,0x3ead9da0,0x2d9f0062}},	//   _עניי, tiği, hiet_, izue_,
   {{0x8c1a00a1,0x201c0559,0x3ead9da1,0xa2c46bbd}},	//   רועי, vavi_, kiet_, िकल्,
   {{0x3ead2751,0xf8bf0018,0x8c3c026a,0x490f00b6}},	//   jiet_, tség_, riği, तीको_,
   {{0x724300cd,0x3ead9da2,0x644305fe,0x74ba0285}},	//   سپول, diet_, ònic, ्वदृ,
   {{0x2eb21178,0x04960308,0x31660813,0x2ef900d8}},	//   ुक्त, _السح, rvoz_, _čsfr_,
   {{0xf8bf0018,0xe809009d,0x321d0034,0x3f410072}},	//   sség_, वडता_, bawy_, góu_,
   {{0xe2979da3,0x3ead619c,0x93b700ca,0x877b006e}},	//   _лас_, giet_, _הללו_, טאצי,
   {{0x25a000a7,0x2b4e016d,0x201c6404,0x41dc00aa}},	//   nzil_, _spfc_, pavi_, _बरिस,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ead9da4,0xf8bf00fd,0x2cac9da5,0x15f80034}},	//   biet_, nsée_, ridd_, ंखार_,
   {{0x59aa0e72,0x3ead9da6,0xf8bf020d,0x386102ac}},	//   _चेहर, ciet_, isée_, _sahr_,
   {{0xa3e80966,0x00000000,0x00000000,0x00000000}},	//   मेत_, --, --, --,
   {{0x321d0034,0xf99f0036,0x98ab020a,0xa49b009c}},	//   zawy_, rzè_, ducă_, _ptòm,
   {{0x7e6200f9,0x25a00124,0x2bcf11c7,0x6fb80034}},	//   _kaop, ezil_, _सुपा, इपिं,
   {{0x38610364,0x7c3a0313,0xa3be007a,0xe8d90065}},	//   _wahr_, lgtr, ुअन_, _isọ_,
   {{0x9419261f,0x3a290139,0xdddb0117,0x7d0401b9}},	// [af30] ижат_, _idap_, zkuž, _éisd,
   {{0x7c3a9da7,0x3ead01d3,0x00000000,0x00000000}},	//   ngtr, ziet_, --, --,
   {{0xd3710080,0x321d0034,0x96b802d5,0xb4db01b9}},	//   بها_, tawy_, ्कशॉ, _spàs,
   {{0xddc90ea3,0x7e620244,0xa3e802d5,0x6aaf0124}},	//   vjež, _naop, मेध_, nicf,
   {{0x2bcf04dd,0x321d0034,0x763a00c1,0x61f80220}},	//   _सुना, rawy_, _דערג, _šalá,
   {{0xa06907ec,0x29090051,0x3ead4299,0x8cd8023a}},	//   рака_, _mtaa_, wiet_, _नीलो,
   {{0x3ead9da8,0xe8d900ac,0x6457850c,0x00000000}},	//   tiet_, _nsọ_, mexi, --,
   {{0x64579da9,0x7e629daa,0xd1091f11,0x2d9f0062}},	//   lexi, _caop, _نقره_, tzue_,
   {{0x0c7902e3,0xe8d90134,0xa2820103,0x8d550120}},	//   асны_, _asọ_, _تینو, ітич,
   {{0x6457299e,0x3ead9dab,0x4b251da3,0xa5bb01f9}},	//   nexi, siet_, омов, _adók,
   {{0x3f670335,0xa49b23c0,0x2909010a,0x3ead9dac}},	//   _uđu_, _atòk, _ataa_, piet_,
   {{0x39ea246b,0x316d02ef,0x64573b2d,0x28d20034}},	//   идно_, _krez_, hexi, _दीजि,
   {{0x6abd00e1,0x224d01dc,0x2d820120,0x00000000}},	//   érfa, _mbek_, øket_, --,
   {{0x64b80efb,0xfd620174,0xf8bf17f9,0xfc460a7f}},	//   _आदेश, _latị, ysée_, čích_,
   {{0x7c640018,0x92190557,0x290913d0,0x3787001f}},	//   _راول, दराज_, _etaa_, обро_,
   {{0x6e3b9bb7,0x316d00ae,0x29090154,0x224d0062}},	//   ngub, _orez_, _ftaa_, _nbek_,
   {{0xda7b00ca,0x00000000,0x00000000,0x00000000}},	// [af40] _כנקר, --, --, --,
   {{0x76980139,0x61e602c6,0x224d01ff,0x67030134}},	//   _díya, _úkli, _abek_, ọkat,
   {{0x2bcf009d,0xe1fa0284,0x00000000,0x00000000}},	//   _सुमा, аге_, --, --,
   {{0x316d0b27,0x20059dad,0xf8bf00fd,0x7c2d0022}},	//   _brez_, _afli_, rsée_, _ɓara,
   {{0xf8bf0257,0x60ca18f0,0x6f08037a,0x316d078e}},	//   ssée_, tofm, _stdc, _crez_,
   {{0x7e62215e,0x752471a5,0x2bcf087c,0x201a50d6}},	//   _saop, msiz, _सुभा, úpi_,
   {{0xd2590154,0x644e00bd,0x179a006e,0x75249dae}},	//   _djņb_, _ibbi, ייַב, lsiz,
   {{0x66040803,0x65697a1d,0x6e3b0196,0x00000000}},	//   ncik, _šehi, ggub, --,
   {{0x7524973d,0x442a01ff,0x316d00fc,0x00000000}},	//   nsiz, _kdb_, _grez_, --,
   {{0x62820084,0x75248e63,0x7a4401f9,0x00000000}},	//   ljoo, isiz, yító, --,
   {{0x66040332,0x442a00a7,0xc3fb006e,0x644e0113}},	//   kcik, _mdb_, יליש, _mbbi,
   {{0x62829daf,0x75249db0,0x442a0324,0x660431f2}},	//   njoo, ksiz, _ldb_, jcik,
   {{0x6e209db1,0x644e0451,0x6ef50138,0xc8670c59}},	//   mamb, _obbi, _išba, отви,
   {{0x6e2055a3,0x75249db2,0xd7f80ed4,0x7a4401f9}},	//   lamb, dsiz, жут_, tító,
   {{0x58d41728,0x6e20024a,0x00000000,0x00000000}},	//   форт, oamb, --, --,
   {{0x644e9db3,0xdea801c2,0x8ca602d5,0x3d000154}},	//   _abbi, _ƙoƙo, टोरो, _kòw_,
   {{0x64570933,0x6e200051,0xa3e80ded,0x5507008f}},	// [af50] texi, iamb, मेस_, ючва,
   {{0x6e20641f,0xd5b80c10,0x644e00e7,0xc9540089}},	//   hamb, іст_, _cbbi, _חמץ_,
   {{0x39b80134,0x32557595,0xd37b013f,0x00000000}},	//   ọst_, звер, шча_, --,
   {{0x6e2035f5,0x644e083e,0x442a9db4,0x660401c2}},	//   jamb, _ebbi, _edb_, ccik,
   {{0x661d39c1,0x2169021c,0xc61700c0,0x6e209db5}},	//   _iesk, сили_, तरीय_, damb,
   {{0xa5bb0037,0x80a8004d,0x628249b3,0x00000000}},	//   _ndói, овів_, ajoo, --,
   {{0x661d1c73,0x442110e3,0x6282008c,0x6aad0bd3}},	//   _kesk, mah_, bjoo, _omaf,
   {{0x44210496,0x6e2016db,0xa5bb9db6,0x3d000154}},	//   lah_, gamb, _adói, _bòw_,
   {{0x661d9db7,0x2d8b025a,0xf1b9077e,0x316d2a9a}},	//   _mesk, âce_, _beše_, _urez_,
   {{0x44211a27,0x23bf02e8,0x6aad18b1,0xa3e80714}},	//   nah_, _एखाद, _amaf, मेव_,
   {{0x44219db8,0x6e202e02,0x2d82004d,0xfa6a008d}},	//   iah_, bamb, øker_, банк_,
   {{0x44219db9,0x661d9dba,0x6e209dbb,0xa5bb037a}},	//   hah_, _nesk, camb, _geóg,
   {{0x442110e3,0xed58004d,0x00000000,0x00000000}},	//   kah_, _мої_, --, --,
   {{0x20cb1317,0xf8bf1d32,0x45090081,0x2bc6009f}},	//   िविध, drés_, _লিংক_, _रुका,
   {{0x442110dd,0x66e60ed8,0x661d9dbc,0x96964e6f}},	//   dah_, зова, _besk, праш,
   {{0x661d1904,0xa5bb002b,0x7524071d,0x442a014b}},	//   _cesk, _xeóg, tsiz, _sdb_,
   {{0x44210496,0xf8bf36e7,0x442a0085,0x656f009c}},	// [af60] fah_, grés_, _pdb_, _crch,
   {{0x44210498,0x6e200b2a,0x7c210973,0x75240511}},	//   gah_, zamb, nalr, rsiz,
   {{0x6e2026d9,0x62890113,0x22b8033b,0x0af90033}},	//   yamb, _boeo, lčki_, _আবুল_,
   {{0x661d0665,0x254e00e8,0xf8bf9dbd,0x7c21042c}},	//   _gesk, tēlā_, brés_, halr,
   {{0x44219dbe,0x22b80087,0x6e201c48,0x628254ab}},	//   bah_, nčki_, vamb, rjoo,
   {{0x44211bd0,0x6e2082b9,0x10a30d06,0x644e183b}},	//   cah_, wamb, ничн, _ubbi,
   {{0x6e203128,0xb4d80e72,0x7ae48f30,0x7c210103}},	//   tamb, ाती_, _ohit, dalr,
   {{0x2bcf0635,0x3da600d6,0x61468498,0xb3bb1777}},	//   _सुधा, зроб, _неба, _המלכ,
   {{0x6e203f63,0xa3e800a5,0xa49b9716,0x22b8033b}},	//   ramb, मेर_, _awòy, jčki_,
   {{0x7ae4674b,0x7af60154,0x61e009ac,0x6e2b009c}},	//   _ahit, _aiyt, _izml, _edgb,
   {{0x6e200010,0x7ae40049,0xb5fb026e,0x69c401ff}},	//   pamb, _bhit, _baál, _axie,
   {{0x7ae49dbf,0x201e61b0,0x44219dbe,0xb4d8023a}},	//   _chit, _heti_, zah_, ातु_,
   {{0x44212d96,0xa3d3000d,0x661d06a3,0x7ae49dc0}},	//   yah_, _हुन_, _resk, _dhit,
   {{0x7ae40006,0x201e00dc,0x7c2100ee,0xf8bf00fd}},	//   _ehit, _jeti_, calr, vrés_,
   {{0xc7c4062a,0x44219dc1,0x661d5db7,0x7ae49dc2}},	//   ести, vah_, _pesk, _fhit,
   {{0x44211bd6,0xddc2134c,0x201e7cc5,0xf8bf97b2}},	//   wah_, _množ, _leti_, trés_,
   {{0x44210498,0x661d9dc3,0xd8cb00d3,0x00000000}},	// [af70] tah_, _vesk, _гынд_, --,
   {{0x656f0579,0x661d9dc4,0xf8bf232f,0x629b0138}},	//   _vrch, _wesk, rrés_, _sluo,
   {{0x442126f7,0x661d03ce,0x6abd9dc5,0xd6d10037}},	//   rah_, _tesk, onsf, _لقد_,
   {{0xb184025b,0xf8bf00ee,0x6abd056b,0x201e09a1}},	//   _šťas, prés_, nnsf, _aeti_,
   {{0x656f0a02,0x4421971c,0x201e0a00,0xf194004d}},	//   _urch, pah_, _beti_, ниць,
   {{0x68ff025e,0x442114f7,0xe7e417ff,0x6f1a03a8}},	//   _muqd, qah_, _गरमा_, _bwtc,
   {{0x201e0038,0x00000000,0x00000000,0x00000000}},	//   _deti_, --, --, --,
   {{0x2d95124c,0x68f70188,0x00000000,0x00000000}},	//   дрос, _lixd, --, --,
   {{0x62980029,0x7c210a04,0x4c35013f,0x61fb6747}},	//   īvot, talr, мэнт, _igul,
   {{0x7ae49dc6,0x201e0088,0x22b8033b,0x2d83007e}},	//   _shit, _geti_, včki_, ćje_,
   {{0x7fb9001c,0x60c40037,0x00000000,0x00000000}},	//   _بهار_, éime, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c450b2c,0x7c290769,0x2bcf074c,0x61fb0350}},	//   _желе, _долг_, _सँवा, _mgul,
   {{0x7ae400a1,0x22b8033b,0x7e691f35,0x6d499dc7}},	//   _whit, rčki_, ldep, mtea,
   {{0x6d491519,0x61fb9dc8,0x7ae49dc9,0xf7435e66}},	//   ltea, _ogul, _thit, керо,
   {{0xe8d90028,0x61fb9dca,0x7e699dcb,0x7ae49dcc}},	//   _trở_, _ngul, ndep, _uhit,
   {{0x17fa0037,0x75d30076,0x00000000,0x00000000}},	// [af80] _وردة_, نيفا, --, --,
   {{0x61fb47dc,0xb4d80f78,0x6d490091,0xb93700c1}},	//   _agul, ाते_, itea, _קריג_,
   {{0xe8140454,0xa3e810ed,0x201e9dcd,0xf99200cd}},	//   _त्या_, में_, _reti_, _سبک_,
   {{0x201e9dce,0x673c0ebd,0x7e690537,0xe0cf05d1}},	//   _seti_, murj, jdep, یزو_,
   {{0xba48013f,0x7e690078,0xbef7030b,0x662900b6}},	//   _grįž, ddep, ँदैन_, řský,
   {{0xd00f3345,0x6d4900e3,0x61fb2673,0x00000000}},	//   لله_, dtea, _egul, --,
   {{0x201e9dcf,0x321f0154,0x9f982458,0x6d499dd0}},	//   _veti_, _feuy_, явку_, etea,
   {{0x61fb0283,0x6d492bc0,0xf1a9001c,0x3a20009c}},	//   _ggul, ftea, _کافه_, _neip_,
   {{0x1ee80068,0x814600cd,0x63ae0138,0x6d490037}},	//   _ہوئی_, _زنان, žinė, gtea,
   {{0xe57100c1,0x2bcf0e19,0x00e3002d,0x61fb0357}},	//   אַט_, _सुहा, _ажун, _zgul,
   {{0x6d499dd1,0x764d026a,0xaab501b3,0x656d00d4}},	//   atea, yfay, ейні, zvah,
   {{0x3a2077e4,0x6d499dd2,0x3d1908d4,0x29009dd3}},	//   _ceip_, btea, _मौके_, _buia_,
   {{0x6d498fa9,0x1de2080f,0x6abd1a88,0xdd921ac9}},	//   ctea, _परित, rnsf, _جوش_,
   {{0x2900015e,0x2bcf201e,0xfb190018,0x673c0141}},	//   _duia_, _सुवा, _کروں_, furj,
   {{0x67d4319f,0xf1b90786,0x29000428,0x64430428}},	//   вору, _meša_, _euia_, ònim,
   {{0x1de204a9,0xdddb2461,0xf1b9015c,0xdce209ac}},	//   _परात, ljuš, _leša_, _broć,
   {{0x29009dd4,0x7d0d0052,0x22b80117,0xd7fb456d}},	// [af90] _guia_, _çast, nčku_, _мун_,
   {{0x2a694fcb,0xdddb14f3,0x673c0141,0x656d0e22}},	//   _haab_, njuš, burj, rvah,
   {{0x5fae007d,0x656d32d2,0x6d490a00,0x2a699dd5}},	//   _झेलल, svah, ztea, _kaab_,
   {{0x38ad02ef,0x99920154,0x4ed00033,0x00000000}},	//   džri_, _deyņ_, াগুল, --,
   {{0x7e690220,0xa3b409f6,0x22b87035,0x00000000}},	//   vdep, _जेठ_, jčku_, --,
   {{0xfc4e00fe,0x2a69008c,0x3f692b67,0x00000000}},	//   _sửng_, _laab_, зико_, --,
   {{0xff510e5a,0xf1b900c4,0x7e690120,0xcef5001f}},	//   اخت_, _deša_, tdep, нчињ,
   {{0x6d499dd6,0x2a69023e,0x2ee64c80,0x4d650284}},	//   ttea, _naab_, _chof_, екив,
   {{0x2d99310c,0x7e699dd7,0xee36004b,0x6d4901ff}},	//   áse_, rdep, хны_, utea,
   {{0x6d491b08,0x31780018,0x7e692bc3,0xa3b400c3}},	//   rtea, _تحفظ_, sdep, _जेड_,
   {{0x6d497f8c,0x7a6a171b,0x2bcf0469,0x2a69026d}},	//   stea, пинг_, _सुशा, _baab_,
   {{0x9cea00fb,0x6d499dd8,0xeabf0036,0xaca30032}},	//   _ہونے_, ptea, gnù_, _iyọk,
   {{0x2bcf274c,0x2a6901ee,0xac95147c,0x00000000}},	//   _सुरा, _daab_, _падш, --,
   {{0x6f010018,0x2a6901ff,0xddd9022b,0x2900044c}},	//   _kulc, _eaab_, _pawņ, _vuia_,
   {{0x3a207e2e,0x61dc030b,0x7bd80138,0xc5f83ec9}},	//   _teip_, _बर्ष, _gyvu, ंख्य_,
   {{0xb4d800e2,0x3ebf02fd,0xdce2005f,0xf65f02b6}},	//   ात्_, nnut_, _proć, _skær_,
   {{0x69c101e8,0xe5a30058,0x3ebf00ce,0x00000000}},	// [afa0] şler, гити, inut_, --,
   {{0x03a62311,0xa3be0789,0x6299000b,0xa5bb0103}},	//   низо, ुअल_, ekwo, _adós,
   {{0xdce902dd,0x2a690188,0xf4840281,0x00000000}},	//   jveč, _yaab_, _یاسی, --,
   {{0x2a69023e,0xa6832c37,0xe8142171,0xdce971a6}},	//   _xaab_, _блюд, _त्ता_, dveč,
   {{0xaca3026e,0x26d29dd9,0x3ebf45ca,0x26c01bb5}},	//   _ayọk, moyo_, dnut_, mnio_,
   {{0x232a0686,0x26c000c6,0x74160e27,0x2ee60216}},	//   _ноги_, lnio_, _سورا, _shof_,
   {{0x82a600d6,0x645e9dda,0xf1b90542,0x6f019ddb}},	//   _завж, mepi, _veša_, _culc,
   {{0x3ebf04a3,0x6f019ddc,0x645e9ddd,0x26c000e5}},	//   gnut_, _dulc, lepi, nnio_,
   {{0x8ffa09b4,0xfd0f010d,0x26c09dde,0x764602ac}},	//   _فرار_, یجی_, inio_, _mcky,
   {{0x2a690006,0xc5f30130,0x645e9ddf,0x6f01028d}},	//   _saab_, נדז_, nepi, _fulc,
   {{0x2a69023e,0x34b70327,0xdb1c0233,0x00000000}},	//   _paab_, תפים_, _özür, --,
   {{0x6ee578ca,0x645e39e3,0xa3d30fef,0x2a699bbd}},	//   tóbe, hepi, _हँस_, _qaab_,
   {{0x26c09de0,0x26d200d1,0x00000000,0x00000000}},	//   dnio_, doyo_, --, --,
   {{0x645e0ea3,0x7c2d0d2a,0x26c09de1,0x00000000}},	//   jepi, _ɓark, enio_, --,
   {{0x645e9de2,0x67d53602,0xa49b0154,0x656601ce}},	//   depi, тову, _otòr, _askh,
   {{0xa3e704a9,0xd6d8131b,0x7bdb040a,0x497505ed}},	//   _परब_, ету_, _מקוו, _алис,
   {{0x7d02022c,0xa802071d,0x35f53283,0xeaf84345}},	// [afb0] _juos, ğırd, тпар, _ثروت_,
   {{0xa80203e0,0x7d020350,0x64a40291,0x2297071d}},	//   şırd, _muos, гађа, _içki_,
   {{0x7d1d01f9,0x26d29de3,0x00000000,0x00000000}},	//   ássz, boyo_, --, --,
   {{0xe8d9020b,0x00000000,0x00000000,0x00000000}},	//   _trồ_, --, --, --,
   {{0x7d02013f,0x6299112f,0x645e9de4,0xdd0002c6}},	//   _nuos, rkwo, bepi, čtěj,
   {{0x6f019de5,0xf1b9007e,0xdceb00e8,0xc9542252}},	//   _pulc, _fešn_, _orgā, רמס_,
   {{0x6e2201bf,0x3c2d0103,0x6f010036,0xb2ab00e5}},	//   _beob, _jövő_, _qulc, _етаж_,
   {{0x44239de6,0x4431239f,0x7d023ef4,0x6e22033c}},	//   _hej_, _hdz_, _buos, _ceob,
   {{0xc05b00d6,0x6e223748,0x44235186,0x50f50450}},	//   _ніж_, _deob, _kej_, _азат,
   {{0x44231671,0xeb990058,0x1fa73574,0x26c00580}},	//   _jej_, дио_, _прег, znio_,
   {{0x44239de7,0xfaa63277,0x26d2083e,0x3ebf00d4}},	//   _mej_, вано, yoyo_, pnut_,
   {{0x44239de8,0x645e0067,0x5a961ca5,0xeb96007b}},	//   _lej_, zepi, троф, тию_,
   {{0x645502e6,0x81d30081,0x645e024a,0xb9270134}},	//   _obzi, হের_, yepi, matị_,
   {{0x44239de9,0x26d20283,0xe8f7160f,0xf1b904e9}},	//   _nej_, woyo_, кля_, _lešo_,
   {{0x26c000a5,0x6e2200ec,0x26d2010a,0x645e9dea}},	//   tnio_, _yeob, toyo_, vepi,
   {{0x7c230501,0x64551fc5,0x44317df9,0xc6c307ef}},	//   _henr, _abzi, _adz_, айск,
   {{0x7e6b4c9c,0xa2c0000f,0x26d29deb,0x44239dec}},	// [afc0] _magp, लचस्, royo_, _bej_,
   {{0x26c06d61,0x7e6b07ac,0x29120169,0x6d590a4b}},	//   snio_, _lagp, _itya_, _mpwa,
   {{0x442301bb,0x645e9ded,0x7c23005c,0xc7a600d6}},	//   _dej_, repi, _menr, _ринк,
   {{0xe2972e62,0x7e6b1336,0x6d590371,0x1dc100aa}},	//   ках_, _nagp, _opwa, शपात,
   {{0x6e22015e,0x764401c2,0x443101c8,0x44239dee}},	//   _reob, mgiy, _fdz_, _fej_,
   {{0x44237701,0x212d02dd,0x7644026a,0x7d0210e0}},	//   _gej_, _dveh_, lgiy, _ruos,
   {{0x7d0202fd,0xb17d0181,0x6d5905aa,0x7e6b9def}},	//   _suos, _vzťa, _apwa, _bagp,
   {{0x76449df0,0xa3e702e8,0x44449df1,0x4423006c}},	//   ngiy, _परत_, lg_, _zej_,
   {{0x44449df2,0xa2cf0557,0xade300d6,0x7e6b9df3}},	//   og_, धकर्, ицьк, _dagp,
   {{0x7d0202fd,0x5c730805,0x442302a1,0x00000000}},	//   _vuos, альт, _xej_, --,
   {{0xdeef280f,0x44449df4,0x29129df5,0x765f023b}},	//   _вы_, ig_, _atya_, yeqy,
   {{0x7d020084,0x98b100e7,0x656402a4,0x7c2d03e3}},	//   _tuos, _čađu_, kwih, _ɓari,
   {{0xf2d30130,0x7e607e7c,0x20b600b7,0x98a200c6}},	//   שער_, memp, _अगाध, nukė_,
   {{0x44440ab2,0x25a90094,0x00000000,0x00000000}},	//   jg_, vzal_, --, --,
   {{0x6d400253,0x87040465,0xb8cb1488,0xb6073566}},	//   luma, ияте, _खत_, вязк,
   {{0x44449df6,0x7c289df7,0x7e603cb8,0x44239df8}},	//   eg_, ladr, nemp, _sej_,
   {{0x6d404609,0x4423006c,0x4431119f,0xf1b9007e}},	// [afd0] numa, _pej_, _pdz_, _rešo_,
   {{0x444400f3,0x7e609df9,0x34bf034d,0x4423023e}},	//   gg_, hemp, ्वेद, _qej_,
   {{0x6d409dfa,0x44230021,0x7e609dfb,0x3cfc0036}},	//   huma, _vej_, kemp, _mivv_,
   {{0x44449dfc,0x6d409b84,0x1de240c1,0x7e609dfd}},	//   ag_, kuma, _परंत, jemp,
   {{0xdd86097d,0x44239dfe,0x7c289821,0x6d409dff}},	//   _او_, _tej_, kadr, juma,
   {{0x7c280220,0x6d409e00,0xe8d90023,0x00000000}},	//   jadr, duma, _trổ_, --,
   {{0x7e6b1395,0xa3e740ba,0xc4d222fe,0x752d0036}},	//   _pagp, _परि_, _הגם_, lsaz,
   {{0x6d4031d6,0x660d5ed5,0x7c231fad,0x9f529e01}},	//   fuma, ncak, _senr, ádán_,
   {{0x6d409e02,0x752d6c5f,0x41b70789,0x7c2300f0}},	//   guma, nsaz, _अधिस, _penr,
   {{0x64450d11,0x4c850582,0x98a082aa,0xac85314b}},	//   nghi, улов, _ivić_, угол,
   {{0x7c230933,0x7e6b9e03,0x64450013,0x2d820212}},	//   _venr, _tagp, ighi, äker_,
   {{0xc869028c,0x6d409e04,0x7e6003a9,0x7c232e97}},	//   _מן_, buma, cemp, _wenr,
   {{0xf2d200f5,0x7c239e05,0x6d409e06,0x7bca6165}},	//   מעט_, _tenr, cuma, _exfu,
   {{0xb4bf000d,0x7c289e07,0x91ba00a1,0xa5bb0042}},	//   ुको_, cadr, תמשי, _peón,
   {{0xb8dc245a,0xc7950138,0x07a313f5,0x00000000}},	//   _आग_, арты, барн, --,
   {{0x44440197,0x6b9c0c08,0x64450036,0x2aa20139}},	//   wg_, ørge, eghi, _fóba_,
   {{0x44449e08,0x6aa40051,0x76448e40,0x29120169}},	// [afe0] tg_, _ilif, rgiy, _utya_,
   {{0x444401bb,0x7e609e09,0x6445028d,0x65640169}},	//   ug_, zemp, gghi, rwih,
   {{0xe29a311c,0x7e604dc4,0xd62a013d,0x6aa49e0a}},	//   наж_, yemp, _поне_, _klif,
   {{0x44440049,0x6d4025b9,0x7e600c19,0xddc2007e}},	//   sg_, yuma, xemp, _laoš,
   {{0xa3e8049d,0x394200aa,0x7e60007b,0x7d090216}},	//   मेज_, nuks_, vemp, jqes,
   {{0xddc2015c,0x6aa400f0,0x6d409e0b,0xc95300ca}},	//   _naoš, _llif, vuma, צמו_,
   {{0x6aa49e0c,0x394200bc,0x03a6972b,0x7c2801ce}},	//   _olif, huks_, _сиво, vadr,
   {{0x1d340e38,0x3942007a,0x60c300e3,0x7c289e0d}},	//   ания, kuks_, annm, wadr,
   {{0x7e60734d,0x22930080,0x62802eee,0x91e300d6}},	//   remp, _القس, _inmo, _готе,
   {{0x6d409e0e,0x7e6009af,0x6aa49e0f,0xfc4600b6}},	//   ruma, semp, _alif, _číst_,
   {{0x6d409e10,0xf8bf01f9,0x00000000,0x00000000}},	//   suma, ssék_, --, --,
   {{0x7c280665,0x22469e11,0x6d409e12,0x6aa43d0f}},	//   sadr, ngok_, puma, _clif,
   {{0x7c289e13,0x2f0a009c,0xdebb0142,0x00000000}},	//   padr, _hùg_, _אמאל, --,
   {{0x2a6d030b,0x6aa49e14,0xfbcf0179,0x2bcf07ad}},	//   žeb_, _elif, _सुकम, _सुका,
   {{0x6280051c,0xa3b40abe,0xe78417a8,0x81b80033}},	//   _onmo, _जेल_, буто, _ঘুম_,
   {{0x7d0d00e3,0xb4bf02d5,0xa3d802d5,0xddc2031a}},	//   _éasc, ुक्_, ाथन_, _zaoš,
   {{0x660d9e15,0x7aed9e16,0xa5bb0850,0xf55900d1}},	// [aff0] rcak, _ihat, _geól, ضلاب_,
   {{0x62809e17,0x752d4126,0x68fe0124,0x26150fdd}},	//   _anmo, rsaz, _gipd, _फ्री_,
   {{0x7aed9e18,0x64459e19,0x752d9e1a,0xb4b517ff}},	//   _khat, rghi, ssaz, _जगी_,
   {{0x7d090216,0x38630537,0x00000000,0x00000000}},	//   yqes, lejr_, --, --,
   {{0x21690581,0x7aed01b5,0x7aff023b,0xa5bb0072}},	//   тили_, _mhat, _miqt, _xeól,
   {{0xf4870426,0x22460062,0x00000000,0x00000000}},	//   _сумн, agok_, --, --,
   {{0xe8d90134,0x7aed1acc,0x00000000,0x00000000}},	//   _apị_, _ohat, --, --,
   {{0x7aed997d,0x8d5571af,0xed5922f6,0x00000000}},	//   _nhat, аточ, вои_, --,
   {{0x315800e3,0x776701fa,0x98a2007f,0x00000000}},	//   _مجلة_, hwjx, lską_, --,
   {{0xdd9905d6,0x7aed9d7b,0x61e99e1b,0xc1b82569}},	//   ryň_, _ahat, _izel, _слух_,
   {{0x7aed01b5,0x6a860d5e,0x2bcf9e1c,0xfbcf5ce3}},	//   _bhat, ална, _सुखा, _सुखम,
   {{0x7f43013d,0x3942007a,0x00000000,0x00000000}},	//   munq, tuks_, --, --,
   {{0x7aed9e1d,0x7f43008f,0xa2d60285,0x00000000}},	//   _dhat, lunq, यकत्, --,
   {{0x8c422917,0x7ebe347c,0x39429e1e,0x5c074a13}},	//   _деше, rūpe, ruks_, _сяда,
   {{0xd62a1a29,0x4cba00a1,0x7aed0013,0x394200aa}},	//   кове_, _במסג, _fhat, suks_,
   {{0xa5bb10d9,0x3942007a,0x6aa40a58,0x7aed9e1f}},	//   _teól, puks_, _ulif, _ghat,

   {{0xe9df03be,0x68fe7f59,0x942600c2,0x386300e7}},	// [b000] lgún_, _tipd, имае, bejr_,
   {{0xaa7b00d4,0xb4d000a4,0xc48320c0,0x00000000}},	//   plýc, शवे_, олук, --,
   {{0xa3d30067,0xe9df11ce,0xadff009f,0x145900c6}},	//   _हुआ_, ngún_, _उलझन_, ышты_,
   {{0x5b56006e,0x25081ac9,0x78bc0172,0x00000000}},	//   ישען_, _مرسی_, lirv, --,
   {{0x61e9007f,0x00000000,0x00000000,0x00000000}},	//   _czel, --, --, --,
   {{0x61e900d9,0x64a69e20,0x26121cff,0x00000000}},	//   _dzel, _тага, धुरी_, --,
   {{0x61e99e21,0x00000000,0x00000000,0x00000000}},	//   _ezel, --, --, --,
   {{0xe2972f0c,0x62805411,0x78bc00ce,0x00000000}},	//   _кас_, _unmo, hirv, --,
   {{0x3b07034f,0x00000000,0x00000000,0x00000000}},	//   _aunq_, --, --, --,
   {{0x7aed5cd0,0xaa1f030b,0x00000000,0x00000000}},	//   _shat, पर्छ_, --, --,
   {{0xb4790130,0x7aed9e22,0x9e660978,0xe47900c1}},	//   אָרי, _phat, _введ, אָרש,
   {{0xd90f00d1,0x7aed0415,0x00000000,0x00000000}},	//   ویب_, _qhat, --, --,
   {{0xa3d30067,0x65760094,0xa49b01ec,0x6f080973}},	//   _हुई_, jvyh, _suòm, _hudc,
   {{0xa8a4123a,0x7aed3d46,0x98b900ae,0xa3e7007a}},	//   орск, _what, dusă_, _परल_,
   {{0x7c65172a,0x7aed9e23,0xd6db016e,0x787c0149}},	//   _دانل, _that, вта_, _såvä,
   {{0xabfb00ca,0x2612030b,0x38630537,0x7aed9e24}},	//   _בהור, धुली_, sejr_, _uhat,
   {{0x78bc0072,0x38c9015a,0x04c901c3,0x442b110c}},	// [b010] birv, _مادی_, هوري_, вцем_,
   {{0x442700e3,0xe8d90134,0xb5fb0139,0x673a033b}},	//   ún_, _kpọ_, _baár, štja,
   {{0x61e90018,0x3ea605fe,0x29090167,0x00000000}},	//   _szel, _olot_, _huaa_, --,
   {{0x42d8224a,0x7f43028d,0x6abd9e25,0xddc9020a}},	//   афія_, vunq, nisf, ndeţ,
   {{0x290101af,0x61e003a8,0x00000000,0x00000000}},	//   _kiha_, _cyml, --, --,
   {{0x41740177,0x2bcf34d8,0x29010d2a,0x61e9033b}},	//   غانس, _सुझा, _jiha_, _vzel,
   {{0x29019e26,0x3d0c0251,0x533400ba,0x6abd01cd}},	//   _miha_, _डूबे_, _мерт, kisf,
   {{0xa3d30d1b,0x3ea62441,0x1e8519e8,0x29010673}},	//   _हुए_, _clot_, слим, _liha_,
   {{0x17e4049d,0xf2d200c1,0x6abd003d,0x77e409c3}},	//   _गर्व_, _זען_, disf, _गर्क_,
   {{0xdce20234,0xf65f3229,0x29019e27,0x00000000}},	//   _brođ, _sjæl_, _niha_, --,
   {{0x3ea601c5,0x60da006e,0x6f08026d,0x00000000}},	//   _flot_, _עקענ, _gudc, --,
   {{0x3a2903ea,0x00000000,0x00000000,0x00000000}},	//   _ceap_, --, --, --,
   {{0x29019e28,0x3a2901b9,0x00000000,0x00000000}},	//   _biha_, _deap_, --, --,
   {{0x7d1b9e29,0x29090350,0x96200e28,0xab990214}},	//   mpus, _duaa_, बर्ट_, _مخبر_,
   {{0x2bcf2183,0x290102c9,0x31ae0103,0x78bc003e}},	//   _सुचा, _diha_, _közé_, rirv,
   {{0x5986004d,0x316d014b,0xf74316d8,0x00000000}},	//   _глиб, _osez_, џето, --,
   {{0x2901003d,0xb1130294,0x28ba002d,0xe57a01b6}},	// [b020] _fiha_, wụnw, _бунэ_, ыза_,
   {{0x29010169,0x61e002c3,0x2a72008c,0x00000000}},	//   _giha_, _ryml, _hayb_, --,
   {{0x28970327,0x3a290063,0x0fd600aa,0x61e00178}},	//   _הדין_, _yeap_, _ढुंढ, _syml,
   {{0x2005013d,0x63ae2461,0x98b900ae,0x2a72022b}},	//   _agli_, _đinđ, pusă_, _jayb_,
   {{0x6f080031,0xc05a04a1,0x613a1da9,0x29010079}},	//   _sudc, гій_, учер_, _yiha_,
   {{0x94073c32,0x987a00c1,0x224d0449,0x7d1b00d8}},	//   _герб_, ראַט, _ecek_, dpus,
   {{0x44389e2a,0x442a01ff,0x3ea600d7,0x7d1b9e2b}},	//   _idr_, _ieb_, _plot_, epus,
   {{0x442a9e2c,0x2005008f,0x66f84c5b,0x9d141272}},	//   _heb_, _egli_, ंगिक_, одич,
   {{0x442a9e2d,0x7d1b9081,0x3ea604e2,0x7c3c0610}},	//   _keb_, gpus, _vlot_, órro,
   {{0xdce2005f,0x442a00d9,0x3a294c1f,0xa2c000aa}},	//   _prođ, _jeb_, _seap_, लचक्,
   {{0xef1a11b7,0x44389e2e,0xf1b93836,0x29019e2f}},	//   _сме_, _mdr_, _reši_, _riha_,
   {{0x442a9e30,0xe8d90019,0x29011f9e,0x00000000}},	//   _leb_, _trừ_, _siha_, --,
   {{0x645c7278,0x58871736,0x81da0081,0x44389e31}},	//   _obri, быва, ডের_, _odr_,
   {{0x442a9a44,0x60c400e3,0xa3d84735,0x2d9900c2}},	//   _neb_, éimh, ाथा_, äsee_,
   {{0x499300bf,0xdce200cc,0x29010f06,0x0c730037}},	//   زیگر, _urođ, _viha_, _ردود,
   {{0x59da22a0,0x237f04e9,0x442a0634,0x29010027}},	//   _युवर, _čuj_, _aeb_, _wiha_,
   {{0xca3800a1,0x442a7de9,0xf1b90095,0x7c2a0090}},	// [b030] _הנחה_, _beb_, _teši_, _kefr,
   {{0xf99f06a3,0x7c2a9e32,0x645c009c,0x98740fe9}},	//   myè_, _jefr, _cbri, _ельц,
   {{0x442a5e22,0x7d1b1672,0x44380ec7,0x6d40680b}},	//   _deb_, zpus, _ddr_, hrma,
   {{0x645c0150,0x442a9e33,0x7c2a9e34,0x7cef00f2}},	//   _ebri, _eeb_, _lefr, pørg,
   {{0x442a9e35,0x00000000,0x00000000,0x00000000}},	//   _feb_, --, --, --,
   {{0xb6080074,0xb5fb0065,0x657d6206,0x6d400542}},	//   _vyšš, _abág, _irsh, drma,
   {{0x6d403dd6,0x7cef01df,0x26c90a4b,0x442102db}},	//   erma, nøre, onao_, mbh_,
   {{0x442a0197,0x6f0210de,0x44210049,0xf99f05fe}},	//   _zeb_, _cioc, lbh_, ncès_,
   {{0xa2d6077d,0x442110f0,0x7c2a2a0d,0x6d400124}},	//   यकर्, obh_, _befr, grma,
   {{0x4034090f,0x44210a6c,0x442a01fa,0x2ba50557}},	//   _неус, nbh_, _xeb_, खनला,
   {{0xda662c6b,0x44210055,0x6d409e36,0x6f024bcc}},	//   овни, ibh_, arma, _fioc,
   {{0x6f020465,0x2a72008a,0xc33203c2,0x7d1b2ab2}},	//   _gioc, _qayb_, ווט_, ppus,
   {{0xdce900e9,0x3ead1918,0x7de70e5a,0x3ebf9e37}},	//   jveć, mhet_, _اسام, miut_,
   {{0x7c2a32ae,0x7cef0939,0x3ead9e38,0x25dd0e4c}},	//   _gefr, føre, lhet_, _खड़ी_,
   {{0x7d0b2e6f,0x656f9e39,0x7cef01c5,0x657d9e3a}},	//   _hugs, _asch, gøre, _arsh,
   {{0x442a9e3b,0xe61a0058,0x3ead9e3c,0x7d039e3d}},	//   _seb_, рда_, nhet_, _hins,
   {{0x442a1071,0x7d039e3e,0x6e2b0018,0x7d0400e3}},	// [b040] _peb_, _kins, _megb, _éist,
   {{0x7d039e3f,0x6e2b9e40,0x442a006c,0x25de009d}},	//   _jins, _legb, _qeb_, _कुणी_,
   {{0x7d039e41,0x442a9e42,0x656f6c30,0x3ead1f60}},	//   _mins, _veb_, _esch, khet_,
   {{0x442a0d07,0xf99f0257,0x442102bc,0x4b4c00c1}},	//   _web_, ccès_, abh_, רגאַ,
   {{0x442a0d7d,0x3ead2368,0x64430fb6,0x6f0209f7}},	//   _teb_, dhet_, ónic, _rioc,
   {{0x7d039e43,0x10a33f67,0x442a0052,0x6f02700a}},	//   _nins, мичн, _ueb_, _sioc,
   {{0x7d0b0029,0xf99f0c56,0x6f029e44,0x3ead0313}},	//   _augs, zyè_, _pioc, fhet_,
   {{0x7d039e45,0x3ead0d40,0x7d0b8797,0x63a313c8}},	//   _ains, ghet_, _bugs, ønne,
   {{0x7d039e46,0x6e2b8a39,0x6fda3ec9,0x6d409e47}},	//   _bins, _degb, _पुरू, urma,
   {{0x26c900e9,0x7d039e48,0x7d0b008a,0xf99f06a3}},	//   znao_, _cins, _dugs, vyè_,
   {{0x7d03226f,0xdee6121c,0x6f020527,0xf41300ca}},	//   _dins, _дожи, _tioc, ופת_,
   {{0x7d039e49,0x3ead9c45,0x6e2b0139,0xddc900c6}},	//   _eins, chet_, _gegb, sdeš,
   {{0x7d030727,0x26c9015c,0x00000000,0x00000000}},	//   _fins, vnao_, --, --,
   {{0x7d039e4a,0x7cef038c,0xf7730a09,0xf99f06a3}},	//   _gins, tøre, واز_, ryè_,
   {{0xeabf028d,0x23d90386,0x7d0b9e4b,0x00000000}},	//   più_, _बुंद, _zugs, --,
   {{0x7d039e4c,0x7cef01df,0x69da00ae,0x00000000}},	//   _zins, røre, ştea, --,
   {{0x7d034b2d,0x7cef00f2,0x7d040131,0xf99f00ee}},	// [b050] _yins, søre, _éiss, rcès_,
   {{0x3ead183a,0xd37b625b,0xde8f00de,0x92c70081}},	//   zhet_, иче_, _kịch_, _উঠে_,
   {{0x442110f0,0xdce900e9,0xf8bf0257,0x656f0034}},	//   rbh_, sveć, ssés_, _wsch,
   {{0x656f7746,0x69c00789,0x1dca00aa,0x442159f8}},	//   _tsch, _लेडी, ापात, sbh_,
   {{0xde8f00ef,0x24984bf9,0x656f3e8a,0x44210063}},	//   _lịch_, _form_, _usch, pbh_,
   {{0x3cf6000f,0xc5fa00a1,0x7d0b013f,0xccf8030b}},	//   ीदों_, _לפרט, _rugs, jmě_,
   {{0x656d9e4d,0x3ead9e4e,0x7d038d95,0xbf680037}},	//   lwah, thet_, _rins, قصيم_,
   {{0x764d9e4f,0x7d039e50,0xa3b482d0,0x656d6221}},	//   ngay, _sins, _जेट_, owah,
   {{0x3ead9e3c,0x7d039e51,0x3ebf00dd,0x656d9e52}},	//   rhet_, _pins, riut_, nwah,
   {{0x2ca9455b,0x3ead9e53,0x6e2b1158,0x764d00dc}},	//   скоп_, shet_, _wegb, hgay,
   {{0x3c2101e9,0x7d031fb9,0xf1b9049c,0x3ebf0124}},	//   _vгv_, _vins, _vešu_, piut_,
   {{0xde8f00ef,0x7d034bbc,0x656d1621,0xa96a4c42}},	//   _dịch_, _wins, kwah, бима_,
   {{0x7d03003d,0x499900c2,0x290f020d,0x5fdf5660}},	//   _tins, отря_, _égal_, _पुतल,
   {{0x23bd17ad,0xa3ab0da9,0x764d6ed4,0x00000000}},	//   ्पाद, गना_, egay, --,
   {{0x177902fd,0xfaa62c59,0x6d4900ae,0x2718037d}},	//   ость_, _нако, luea, _očne_,
   {{0x784e0103,0x46f5004d,0x6b9c17a5,0xa3ce02c6}},	//   _bőví, дчут, ärge, tíží_,
   {{0xb5fb0072,0x6d499e54,0x656d5197,0x00000000}},	// [b060] _abáb, nuea, gwah, --,
   {{0x6aac0ed5,0x7e690371,0x897b0327,0x00000000}},	//   _चतुर, heep, _פריצ, --,
   {{0x389b0c6a,0x2498685e,0x35fa00cd,0x37e646ff}},	//   _היינ, _vorm_, _گردد_, _хонг,
   {{0xe9f90af0,0x5b3a006e,0x656d02a4,0x317f00fc}},	//   _alẹ_, מגעק, bwah, _bruz_,
   {{0x24989e55,0x0555036a,0xc219004d,0x3a3700ca}},	//   _torm_, _отря, ієї_, פרסם_,
   {{0x6d49009c,0x00000000,0x00000000,0x00000000}},	//   duea, --, --, --,
   {{0xa85700a1,0xb5fb0032,0xb17d0031,0x00000000}},	//   פיקה_, _gbáb, _vyťa, --,
   {{0x877b00c1,0xbd18534b,0xde8f020b,0x00000000}},	//   מאצי, ожих_, _rịch_, --,
   {{0x6ce601b6,0x6d490165,0x61431a57,0x5046013f}},	//   зіне, guea, _пета, _неаб,
   {{0xd00f0037,0x2f110037,0xf1b9007e,0x00000000}},	//   _ملك_, _fág_, _vešt_, --,
   {{0xe45700c1,0xccf800b6,0xa0671102,0x09e40033}},	//   הייט_, rmě_, _хаха_, নেমা,
   {{0xdc0200d4,0x00000000,0x00000000,0x00000000}},	//   _učím, --, --, --,
   {{0x69da00d3,0xc9842357,0xc9870d62,0x00000000}},	//   şten, нури, чуни, --,
   {{0xddeb07a6,0xb1130857,0xde8f0019,0xb9250174}},	//   _פֿאָ, wụkw, _tịch_, _zipụ_,
   {{0x7b0600b6,0xd7f81cb1,0x24c40033,0x6d9502a1}},	//   ístě, зут_, ্তাহ, _eżaġ,
   {{0x56943035,0xe8d90019,0x27ed02c6,0x70a90179}},	//   наст, _trữ_, řeno_, _कत्ल,
   {{0x764d9e56,0xb1130129,0xa5f80d72,0x26c714f3}},	// [b070] rgay, rụkw, зету_, đno_,
   {{0x656d6733,0xe8d30068,0x6ee5065b,0x00000000}},	//   rwah, _سمجھ, róbi, --,
   {{0x656d9e57,0x98ab00d3,0x32551231,0xb1130294}},	//   swah, ască_, двер, pụkw,
   {{0x38af0364,0xddd402c6,0x00000000,0x00000000}},	//   _würd_, žařs, --, --,
   {{0x6aad0350,0x20d507bf,0x00000000,0x00000000}},	//   _mlaf, мікс, --, --,
   {{0x6aad40a1,0x2f110cb6,0x205400e5,0x3cf600c3}},	//   _llaf, _pág_, етър, ँगों_,
   {{0xb4d902e8,0xa3d40077,0xc4d200ca,0xa34400ae}},	//   ावी_, _зорч, _סגל_, _пэтл,
   {{0x44339e58,0x317f0085,0x6d49020a,0xa2820504}},	//   lax_, _truz_, tuea, _لیمو,
   {{0x7e691183,0xdb080146,0x628901ec,0xa1590c3f}},	//   reep, vzdá, _ineo, _фазу_,
   {{0x6aad9e59,0x4c69545b,0x7cef004d,0x394b014b}},	//   _alaf, цион_, føra, ducs_,
   {{0x60c30889,0xeb9912e9,0x6aad1f6d,0xbc690103}},	//   minm, цин_, _blaf, ممکن_,
   {{0x60c34482,0x929d00a5,0x6aad8b74,0xb80700aa}},	//   linm, _miło, _claf, _शलजम_,
   {{0x6d49386c,0x3ea20149,0x4433009e,0x00000000}},	//   quea, ökte_, kax_, --,
   {{0xfbc528dc,0xb69b001f,0x60c30044,0x44331b2b}},	//   _обло, _diâm, ninm, jax_,
   {{0x66e6344d,0x4433008a,0x48073b2f,0x6aad0316}},	//   дова, dax_, дерн_, _flaf,
   {{0x26f8007a,0x60c33eae,0xfe7902c6,0x644304c8}},	//   ंगेर_, hinm, ndů_, ónin,
   {{0x38af01e8,0x60c3492c,0x6616422e,0x7ae49e5a}},	// [b080] _süre_, kinm, rcyk, _ikit,
   {{0xf8d200a3,0x44330188,0x60c39e5b,0x6dc500bd}},	//   _सदिय, gax_, jinm, _iċaħ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9c7c39a2,0xeb9600c1,0x2d8001d3,0xf7730e27}},	//   moče, ודער_, _šiem_, _شاپ_,
   {{0x9c7c19be,0x44330188,0x657b00e7,0x60c35a59}},	//   loče, bax_, _šuhv, finm,
   {{0x1de105d4,0x60c3003e,0x6dc502a1,0x92c00033}},	//   _पड़त, ginm, _mċaħ, ুতে_,
   {{0xb4ea08c0,0x2d9911cd,0x7cf400b3,0x41de269c}},	//   मती_, äsen_, nàre, _फुरस,
   {{0x3da6571b,0x629b0124,0x7ae49e5c,0x69d60131}},	//   дроб, _gouo, _nkit, _oxye,
   {{0x63bb006d,0x9c7c02c6,0x60c372f4,0x459b0142}},	//   _ƙung, hoče, binm, ַסטע,
   {{0x7ae49e5d,0x9c7c03f1,0x6aad9e5e,0x60c30d30}},	//   _akit, koče, _slaf, cinm,
   {{0x9c7c141f,0x69da00ae,0x00000000,0x00000000}},	//   joče, ştel, --, --,
   {{0x1d0a1525,0x7af61347,0xa2a10789,0xf8bf00fd}},	//   _деди_, _chyt, कॉप्, ipée_,
   {{0x25de007a,0x7e628fb9,0xac73001c,0xb9e4004d}},	//   _कुली_, _ibop, رایش, віри,
   {{0x7ae49e5f,0x1bd41681,0xdb02014b,0x394b015e}},	//   _ekit, _поля, hylè, rucs_,
   {{0x9c7c02dd,0xa2bf0789,0x248d0019,0x7cf400b3}},	//   goče, लोड्, _đem_, gàre,
   {{0x44331b7b,0xbebc01d3,0x8f9b00ca,0x6aad024a}},	//   wax_, _avīz, חילי, _ulaf,
   {{0x443388ad,0x60c3234f,0x672200e7,0x7afd9e60}},	// [b090] tax_, yinm, _čoje, mmst,
   {{0xb4d9267b,0x7afd152d,0xa7750acf,0x9c7c3e76}},	//   ावे_, lmst, _злоч, ločb,
   {{0x44339e61,0xca4800cd,0x65660063,0x321c0294}},	//   rax_, _علیه_, _epkh, _ịnụ_,
   {{0xd6270080,0xd9f3009d,0x7cef00f2,0x44339e62}},	//   _تعدي, _घरात_, jørn, sax_,
   {{0x58b8001c,0x60c39e63,0xde8f020b,0x00000000}},	//   _رایج_, tinm, _bịnh_, --,
   {{0xe1f00037,0x63bb03e3,0x7e624e95,0x00000000}},	//   جسم_, _ƙund, _abop, --,
   {{0x60c3006d,0xd0065ee6,0xa5bb0231,0x00000000}},	//   rinm, неше_, _geór, --,
   {{0xee3908c3,0xfe711857,0x62890a34,0x63b10106}},	//   чни_, ادث_, _uneo, đenč,
   {{0x44310b88,0x98ef000f,0xc05b0c10,0x6fdf0096}},	//   _kez_, छताछ_, _між_, _पुरं,
   {{0x7ae419bd,0xd01100e3,0x16010490,0x7afd0629}},	//   _skit, _إلا_, लेयर_, emst,
   {{0x3b090063,0x61e90167,0x27180218,0x7cef0537}},	//   _biaq_, _hyel, _očna_, børn,
   {{0xeab20192,0x44319e64,0xe7e30251,0xfb2400cd}},	//   اعد_, _lez_, _गड़ा_, کریپ,
   {{0x8c4509f2,0x160100b6,0x443100d8,0x00000000}},	//   _зеле, लेमर_, _oez_, --,
   {{0x26fa1344,0x7e7b07ee,0x7afd9e65,0xb4d93aee}},	//   ्द्र_, ldup, amst, ावो_,
   {{0x46f62c13,0x6d5b9e66,0x61e90172,0x290c0031}},	//   ечат, ltua, _lyel, _žiaľ_,
   {{0xcf9200c1,0x9c7c88ce,0x81da0081,0x7ae49e67}},	//   נטן_, roče, ডেট_, _ukit,
   {{0x61e900d0,0x3486002e,0x60c1010a,0xceb20327}},	// [b0a0] _nyel, нгаг, _omlm, אין_,
   {{0x23d61c0e,0x44310038,0xb4ea048a,0xb9db00a1}},	//   нцер, _cez_, मते_, _מחפש,
   {{0x7b0907d1,0x44312b9d,0x61e940fa,0x03a32a84}},	//   _üstü, _dez_, _ayel, лифо,
   {{0x6d5b293c,0xe8d90028,0xa50a1e6e,0x29129e68}},	//   ktua, _trợ_, _нема_, _kuya_,
   {{0x44310396,0x6d5b00dd,0x2912006d,0xf8a400a4}},	//   _fez_, jtua, _juya_, _ऐकाय,
   {{0xa5bb9e69,0xd00f08ba,0x80bc02d5,0x6d5b019c}},	//   _teór, مله_, ्चें, dtua,
   {{0x2912410b,0x25fc045f,0x232a261f,0xde8f0023}},	//   _luya_, लेरी_, _хоби_, _vịnh_,
   {{0x38b40149,0x6d5b023b,0x38af00bc,0x27e501f9}},	//   _färg_, ftua, _müra_, ülni_,
   {{0x6d5b9e6a,0xde8f0023,0xf65f181f,0xf8de0027}},	//   gtua, _tịnh_, _kjær_, n篩s_,
   {{0x387a0181,0x6b830167,0xe0850037,0x00000000}},	//   _napr_, _brng, _لجمي, --,
   {{0x79849748,0xe7e000e2,0xd00f00e3,0x6d59039f}},	//   _ariw, _खुला_, _الم_, _eqwa,
   {{0x29124f10,0x9e731f11,0x79840178,0x68e5020b}},	//   _buya_, _مهمت, _briw, _skhd,
   {{0xf2d30130,0x29121ea5,0xb5fb0032,0x6d5b1173}},	//   רער_, _cuya_, _abán, ctua,
   {{0x798403a8,0x26c20b14,0x6b830b14,0xf88b0037}},	//   _driw, _amko_, _frng, أضحى_,
   {{0xe7db084a,0x64439e6b,0x7984083e,0x7c280063}},	//   _मुखप, ónim, _eriw, mbdr,
   {{0x44318fa8,0x63a52347,0x3cfe0036,0x79844c80}},	//   _sez_, vyhn, lmtv_, _friw,
   {{0x25fc02e8,0x44310487,0x54550476,0x998400e3}},	// [b0b0] लेली_, _pez_, кват, _مليو,
   {{0x26c20b14,0x5fb000a8,0x00000000,0x00000000}},	//   _emko_, जनाल, --, --,
   {{0x44310d9f,0x92590084,0x6d5b0a00,0x61e90063}},	//   _vez_, дает_, ztua, _syel,
   {{0x61e901af,0x44319e6c,0x7ec70113,0x27180117}},	//   _pyel, _wez_, _mèpè, _učna_,
   {{0x44319e6d,0x7ec7001c,0x644a124d,0x38b402c3}},	//   _tez_, _lèpè, ófic, _färd_,
   {{0xfaff023b,0x6d5b023e,0x7d0a533d,0x9f6400d4}},	//   hmë_, vtua, _nifs, _štáb_,
   {{0x7e79010a,0xe2d9001c,0xe0d00076,0x00000000}},	//   _pawp, _قارچ_, حزن_, --,
   {{0xfaff01e5,0x6d5b9e6e,0xa3e60096,0x00000000}},	//   jmë_, ttua, _पडत_, --,
   {{0xc212040a,0x6b9c00bc,0x7e7b0324,0x6d5b9e6f}},	//   _כהן_, ärgn, rdup, utua,
   {{0x5ba91249,0x00000000,0x00000000,0x00000000}},	//   дком_, --, --, --,
   {{0x6d5b9e70,0xf41200a1,0x79841bdf,0x291255c3}},	//   stua, יפי_, _sriw, _suya_,
   {{0x6d5b9e71,0x29129e72,0x9f96021e,0x6d4600d4}},	//   ptua, _puya_, _בדעה_, ákac,
   {{0x6e299e73,0xec6e0e1d,0xdce200d2,0x00000000}},	//   mbeb, _кп_, _zpoč, --,
   {{0xdca23ae7,0x2eed9e74,0x661d9e75,0x6d499e76}},	//   _ваши, llef_, _afsk, mrea,
   {{0x2912006d,0x7ec703a9,0xeb9900ae,0xe73a00c2}},	//   _wuya_, _gèpè, _ций_, ьев_,
   {{0x29129e77,0x79849e78,0x598611cc,0xf1d10ff9}},	//   _tuya_, _triw, _алиб, तपान,
   {{0x9c7c3c34,0x6d499e79,0x657b00e7,0xf50a261f}},	// [b0c0] loča, nrea, _šuhr, днал_,
   {{0x6d494450,0x2937040a,0x7ebe0138,0x3f850134}},	//   irea, _שאין_, rūpi, _orlu_,
   {{0x6d499e7a,0xaac60251,0x4ac6007a,0x38b40149}},	//   hrea, _लगाक, _लगाव, _värd_,
   {{0x23270396,0xc4c40033,0xdcfb09ac,0x6f0b0372}},	//   тоци_, ্তেজ, dvuč, _nigc,
   {{0x7543333f,0xdce26c8d,0xaa7b2347,0x6d49031a}},	//   _княз, _spoč, plýv, jrea,
   {{0x6f0b01b9,0x2ee60f5a,0x00000000,0x00000000}},	//   _aigc, _skof_, --, --,
   {{0x547b00ca,0x7bc735d5,0x6d490a05,0xfaff0052}},	//   _קטלו, újul, erea, ymë_,
   {{0x6d491ac3,0x9c7c005f,0xb7db0341,0x63a348ca}},	//   frea, doča, וקצי, änne,
   {{0x6ee50181,0x00000000,0x00000000,0x00000000}},	//   tóbr, --, --, --,
   {{0x8ffa0de1,0x212618c4,0x9ffa02a3,0x25f50096}},	//   _قرار_, mpoh_, _قراء_, ्धती_,
   {{0xda351736,0x6d499e7b,0x9c7c02dd,0x26d20167}},	//   лены, area, goča, knyo_,
   {{0x8aa70012,0x2eed0383,0x4ea30c37,0x00000000}},	//   трод, clef_, _врша, --,
   {{0x6d490054,0xfaff00dd,0xe94700e5,0x7d0a0078}},	//   crea, rmë_, ъхно, _tifs,
   {{0x929d00a5,0xfaff023b,0x690b009e,0x26d20294}},	//   _piłk, smë_, _eżen, enyo_,
   {{0x57a40ba3,0x38af042c,0x00000000,0x00000000}},	//   ашта, _fürn_, --, --,
   {{0x2f1800fb,0xa3e6000f,0x49757a87,0x96f80d86}},	//   _még_, _पड़_, _блис, вест_,
   {{0xdcfb0335,0xb5fb0032,0x26190336,0xf8ae01f3}},	// [b0d0] zvuč, _gbál, युगी_, زکی_,
   {{0xd3a70b40,0x26d2008c,0x00000000,0x00000000}},	//   креп, anyo_, --, --,
   {{0x6d495449,0x00000000,0x00000000,0x00000000}},	//   zrea, --, --, --,
   {{0xe298004d,0xfb15006e,0x201e026d,0x6d4901ce}},	//   кає_, אַסט_, _afti_, yrea,
   {{0x38b402e2,0x7abc00ca,0xa069268e,0xc2440138}},	//   _wäre_, וצאו, еала_, рнік,
   {{0x6d499e7c,0xfc470031,0x6f0b019f,0x69da0364}},	//   vrea, číky_, _sigc, ßtei,
   {{0x5334772d,0x289c00c1,0x2eed25c0,0x25a97e2f}},	//   _вест, ויגא, tlef_, lyal_,
   {{0x9c7c033b,0x6d493d33,0x26c9016d,0x2f18033c}},	//   voča, trea, niao_, _dég_,
   {{0x64680088,0x6e299e7d,0x6d4901f7,0x2eed03e3}},	//   _þrið, rbeb, urea, rlef_,
   {{0x9c7c2af0,0x7522016d,0x6d490cd6,0x2d86084e}},	//   toča, ãozi, rrea, _droe_,
   {{0x2d860451,0xfaa64c46,0x26c9024a,0x00000000}},	//   _eroe_, гано, kiao_, --,
   {{0x9c7c02dd,0x38af9e7e,0x6d5c00ae,0x25a900f9}},	//   roča, _büro_, ărar, kyal_,
   {{0x38c800cd,0xc956055b,0x9c7c9e7f,0x2d820b85}},	//   ناسی_, ытны, močn, åket_,
   {{0x9c7c6c8d,0x3ead1bfa,0x290c3b90,0x00000000}},	//   ločn, lket_, öda_, --,
   {{0xaa7b0102,0x9cda00ca,0x81a90033,0xb5fb00d8}},	//   glýs, _אקספ, খছি_, _dbám,
   {{0x9c7c025b,0x3ead4287,0x26c99e80,0x39e50134}},	//   nočn, nket_, giao_, ụzị_,
   {{0x95861402,0x7ae63a14,0x7d0d0131,0xb4667ed6}},	// [b0e0] ылае, mokt, _éass, лкал,
   {{0x27180087,0xf4c40081,0x7ae605f1,0xe61f03a8}},	//   _učno_, ্ত্ব, lokt, _efô_,
   {{0x39401a08,0x3ead388d,0x63bb0022,0x07a629b6}},	//   _hvis_, kket_, _ƙuna, _санн,
   {{0x26c9028d,0x2f1801f9,0x25a90154,0x00000000}},	//   ciao_, _rég_, byal_, --,
   {{0xc1e73840,0x10a62b99,0xc6930266,0x255a00ae}},	//   льше_, лидн, _האר_, _ярнэ_,
   {{0x3ead9e81,0xe9f900fe,0xc0e30ed4,0x7ae61168}},	//   eket_, _hoả_, бочк, hokt,
   {{0x7ae69e82,0x00000000,0x00000000,0x00000000}},	//   kokt, --, --, --,
   {{0x443a9e83,0xdd90048f,0xe8d90174,0x3ead0085}},	//   lap_, قوب_, _irụ_, gket_,
   {{0xb5fb0065,0xe0561f11,0x00000000,0x00000000}},	//   _abáj, _مخاب, --, --,
   {{0x443a9e84,0x5b263ae2,0x7eb50072,0x201e0063}},	//   nap_, льма, _rápe, _ufti_,
   {{0x39409e85,0xdfcf00e3,0xdeef0086,0xdd92001c}},	//   _avis_, _فيك_, _гы_, _گوش_,
   {{0x3ead9e86,0x7eb50031,0x00000000,0x00000000}},	//   cket_, _pápe, --, --,
   {{0xdd920d7f,0x00000000,0x00000000,0x00000000}},	//   _دوش_, --, --, --,
   {{0x6b9c0021,0xed570054,0x443a3653,0xe8d90174}},	//   ørgs, _עבור_, jap_, _orụ_,
   {{0x443a10f3,0x8c1b00a1,0xb8dd009d,0x69c09e87}},	//   dap_, _אווי, _आत_, úmer,
   {{0x7c3a9e88,0xaa7b003e,0x00000000,0x00000000}},	//   latr, rlýs, --, --,
   {{0xe8d906c0,0x443a90d7,0x344b261f,0x9c830141}},	// [b0f0] _arụ_, fap_, ечен_, _ščip,
   {{0xaa7b0102,0x443a9e89,0x25a951aa,0x9c7c080e}},	//   plýs, gap_, ryal_, zočn,
   {{0x25a91636,0xd3713345,0x7c3a00e5,0xe787678b}},	//   syal_, تها_, iatr, _супо,
   {{0xf53f070a,0x7c3a9e8a,0x7cef00f2,0x3ce5044c}},	//   _två_, hatr, tørk, zolv_,
   {{0x210f0f53,0x7c3a9e8b,0x763a00c1,0x11670260}},	//   ादेश_, katr, _בערג, التی_,
   {{0x443a0706,0x7c3a005f,0xa069069c,0x38b430c1}},	//   cap_, jatr, така_, _kära_,
   {{0x9c7c0038,0xc4d200a1,0x7ae656ae,0x3ead007b}},	//   točn, _וגם_, yokt, tket_,
   {{0xa3b20034,0x29030216,0x00000000,0x00000000}},	//   टनर_, hmja_, --, --,
   {{0x9c7c41f9,0x38b40149,0x7c3a030a,0x6d46774a}},	//   ročn, _lära_, fatr, škan,
   {{0x3ead8f76,0xa2a139d4,0x2d80003d,0x64579e8c}},	//   sket_, कॉर्, _ġiet_, ngxi,
   {{0x38b40222,0xdfd11cc8,0x24810076,0x3940007e}},	//   _nära_, _بيا_, idhm_, _svis_,
   {{0x9c7c0117,0x1fa40e05,0x8a06166f,0x00000000}},	//   ločl, _уруг, изне, --,
   {{0xfeb8037f,0x690b009e,0xed5900d3,0xb276006e}},	//   _حالت_, _eżem, _рол_, בערג_,
   {{0x6e3b9e8d,0x38b40212,0xa3e61101,0x764b01f9}},	//   laub, _bära_, _पडल_, ógyn,
   {{0xac740979,0x443a0b88,0xe7371d12,0x7cef004d}},	//   _دانش, vap_, иер_, jøri,
   {{0x7a0c00d9,0x6e3b8996,0xb5fb0032,0x690b00bd}},	//   _pētī, naub, _gbák, _jżej,
   {{0x443a2b0f,0xe617402c,0x80d69e8e,0x690b00bd}},	// [b100] tap_, рду_, _बदले, _mżej,
   {{0x7cef038c,0xe3b200e3,0x25fc0034,0x6aa40037}},	//   føri, يرا_, लेगी_, _hoif,
   {{0x443a313d,0x6e3b9e8f,0x316d0062,0xe9f900fe}},	//   rap_, kaub, _apez_, _toả_,
   {{0x443a2b20,0x63a30222,0xe9f90023,0x7c3a578a}},	//   sap_, änna, _hoạ_, zatr,
   {{0x7c3a9e90,0x00000000,0x00000000,0x00000000}},	//   yatr, --, --, --,
   {{0x6ab602ad,0xe8d90019,0x045a0076,0x25af0537}},	//   _llyf, _trụ_, _جلسة_, øgle_,
   {{0x7c3a9e91,0xdfcf00e3,0x645c0451,0x443800fc}},	//   vatr, ويه_, _icri, _ier_,
   {{0x443840d5,0x63620129,0x00000000,0x00000000}},	//   _her_, _ọnwe, --, --,
   {{0x44380b27,0xdd901915,0xe51c34d8,0x62809e92}},	//   _ker_, سود_, _भूमि_, _iamo,
   {{0x443802e6,0x62809e93,0x62820254,0x6aa49e94}},	//   _jer_, _hamo, ldoo, _aoif,
   {{0x4438863c,0x7c3a9e95,0x62809e96,0x764600d8}},	//   _mer_, ratr, _kamo, _odky,
   {{0x44389e97,0x62808310,0x6aa430ca,0x690b0078}},	//   _ler_, _jamo, _coif, _gżej,
   {{0x44389e98,0xdd8f0080,0x62809e99,0x2903023b}},	//   _oer_, _يوم_, _mamo, tmja_,
   {{0x4438070a,0x6d404559,0x6ab6030a,0x00000000}},	//   _ner_, msma, _elyf, --,
   {{0x6ab61d91,0x6aa4009c,0x62821353,0xe8020096}},	//   _flyf, _foif, kdoo, ळेला_,
   {{0x62804091,0x44389e9a,0x5a35002d,0x0bb700ca}},	//   _namo, _aer_, _унит, _כלום_,
   {{0x4438753f,0x6d409e9b,0x62820694,0xf5590037}},	// [b110] _ber_, nsma, ddoo, طلاب_,
   {{0x7c380c27,0x44389e9c,0x645c00dc,0x6d4000c2}},	//   _jevr, _cer_, _ccri, isma,
   {{0x44389e9d,0xdd860434,0x7c380371,0x628010b1}},	//   _der_, _کو_, _mevr, _bamo,
   {{0xe6950b05,0x645c0257,0x6d409e9e,0x44389e9f}},	//   _الحد, _ecri, ksma, _eer_,
   {{0x44389ea0,0x7eb5025b,0x7aed0010,0x78a5007a}},	//   _fer_, _nápa, _mkat, _kohv,
   {{0x44389ea1,0x6e227ca8,0x62802bc0,0x3e7100fe}},	//   _ger_, _afob, _eamo, _ạt_,
   {{0x6d429ea2,0x6d461c57,0x6d40650a,0x2fde0042}},	//   _avoa, škal, esma, _cxtg_,
   {{0x44211933,0x443802a7,0x62809ea3,0x417700cd}},	//   lch_, _zer_, _gamo, _پارس,
   {{0x44380702,0x9c7c02dd,0x7c380305,0x6d401a92}},	//   _yer_, močj, _bevr, gsma,
   {{0x7aed9ea4,0x44219ea5,0x6aa4009c,0x7eb50139}},	//   _akat, nch_, _soif, _dápa,
   {{0x44219ea6,0x7c389ea7,0xa3d711c7,0x62802b47}},	//   ich_, _devr, ापि_, _yamo,
   {{0xf8a90796,0x62800072,0x34d400c3,0x70b700a8}},	//   _אש_, _xamo, _दद्द, _अतुल,
   {{0x7c389ea8,0x6b8a0371,0x8276006e,0x00000000}},	//   _fevr, _erfg, זערע_, --,
   {{0x7c3801a2,0x7aed0c3b,0xe8f7002d,0x7cfd020d}},	//   _gevr, _ekat, йля_, fère,
   {{0x78a50106,0x7eb50074,0x7cfd0257,0x44389ea9}},	//   _dohv, _zápa, gère, _rer_,
   {{0x645c9eaa,0x4438727a,0x6447060f,0x62820188}},	//   _scri, _ser_, _adji, xdoo,
   {{0x44389eab,0x62809eac,0x7c3811bc,0x2bb70092}},	// [b120] _per_, _ramo, _yevr, dəcə_,
   {{0x9992000d,0x44230169,0x6447084e,0x44380216}},	//   _když_, _cfj_, _cdji, _qer_,
   {{0x44380d9f,0x62809ead,0x61fb22bf,0xb5fb0072}},	//   _ver_, _pamo, _azul, _acád,
   {{0x443802dc,0xd25900d6,0x44214f4e,0x6b9c007a}},	//   _wer_, иці_, ach_, ärgi,
   {{0x44389eae,0x62822851,0x62809eaf,0x673b005f}},	//   _ter_, rdoo, _vamo, ćuje,
   {{0xdb1a0068,0x61fb0706,0x6ab502d5,0x6280198d}},	//   szté, _dzul, _ंत्र, _wamo,
   {{0x65649eb0,0x20c900e3,0x61fb0201,0x9c7c0117}},	//   ltih, جبني_, _ezul, bočj,
   {{0x6d409eb1,0x7c382bc7,0x6282008c,0x6280039f}},	//   tsma, _sevr, qdoo, _uamo,
   {{0x6d409eb2,0x65649eb3,0xb146002d,0x7c860d4f}},	//   usma, ntih, _ынал, буне,
   {{0x7aed6a3a,0x9c7c02dd,0x757b0089,0x7d190381}},	//   _skat, močk, נטיפ, _duws,
   {{0x95f502d5,0xc5f509c4,0x00000000,0x00000000}},	//   _आर्ट_, _आर्य_, --, --,
   {{0x38af0702,0x15fa0be4,0x6d401a85,0x78a512f1}},	//   _türk_, ्धार_, psma, _sohv,
   {{0x44219eb4,0x7c3803ee,0x656421dc,0x984b008f}},	//   ych_, _tevr, jtih, лява_,
   {{0x7cfd0257,0xd90f001c,0x4c941e79,0xdb020094}},	//   tère, ژیک_, _фикс, rylá,
   {{0x38af8ab6,0x3ea69eb5,0x388b00c6,0x501b00d7}},	//   _jüri_, _koot_, vėrė_, רולו,
   {{0x44211a2e,0x7aed9eb6,0x7cfd020d,0x9c7c2c06}},	//   wch_, _ukat, rère, kočk,
   {{0x44214589,0x69da8907,0xf77803e5,0x3ea60849}},	// [b130] tch_, şter, ħħa_, _moot_,
   {{0x3f8c03f3,0x44219eb7,0x798d9eb8,0x9d1b00a1}},	//   _ordu_, uch_, _iraw, טומט,
   {{0x442168eb,0xcfad0033,0x61fb3e15,0x00000000}},	//   rch_, _কেনন, _szul, --,
   {{0x44211b0a,0xe5700068,0x3ea69eb9,0x798d2aeb}},	//   sch_, بطہ_, _noot_, _kraw,
   {{0x9c7c033b,0x26cb00b3,0x798d02a1,0x2bb700a7}},	//   ročj, _imco_, _jraw, rəcə_,
   {{0x3f8c00cc,0x493c0341,0x1fa96cb6,0x2eb1030b}},	//   _brdu_, נגוו, икли_, जस्त,
   {{0xf3f31374,0x291307ee,0x3ea651e4,0x1048007b}},	//   _رأس_, _mixa_, _boot_, сячи_,
   {{0x92b70dd0,0x9c7c025b,0x291320df,0x1d251146}},	//   _احسا, bočk, _lixa_, омим,
   {{0x798d006c,0x2d8b030b,0x61fb6789,0x3f8c0062}},	//   _nraw, íce_, _uzul, _erdu_,
   {{0x7cef004d,0x690b0090,0x00000000,0x00000000}},	//   jørt, _iżew, --, --,
   {{0x798d9eba,0xf9890796,0x3ea62198,0x3ee700c6}},	//   _araw, _שר_, _foot_, _людв,
   {{0xef0e116d,0x798d9ebb,0x2483023b,0x65643285}},	//   _ім_, _braw, _lajm_, ytih,
   {{0x8c453f1d,0x6da51a9f,0x7cef01df,0x29139ebc}},	//   _деле, _фила, ført, _bixa_,
   {{0x2483005c,0x798d9ebd,0x291b008c,0x690b02a1}},	//   _najm_, _draw, _duqa_, _mżew,
   {{0xfaa60db2,0x798d89e3,0x7cfd09c2,0xe9a700d1}},	//   _мако, _eraw, pèrb, مگین_,
   {{0x2ca703ee,0x291b0090,0x2913015e,0x656414b0}},	//   _hond_, _fuqa_, _eixa_, ttih,
   {{0x798d9ebe,0x2913687b,0xb5fb002b,0x09e40033}},	// [b140] _graw, _fixa_, _acáb, নেজা,
   {{0x33f612e7,0x7cef09af,0x00000000,0x00000000}},	//   очес, mørs, --, --,
   {{0x2ca790b6,0x7eb50074,0x65643ebd,0x3e4c013f}},	//   _mond_, _nápo, stih, lėtų_,
   {{0x7ebc0068,0x2ca79ebf,0x00000000,0x00000000}},	//   _képe, _lond_, --, --,
   {{0x2ca7057a,0x3ea6506b,0x055500ae,0x38b40696}},	//   _oond_, _root_, _нтря, _lärm_,
   {{0x9c7c19ad,0x11390138,0x60cd014b,0x27ed9ec0}},	//   ročk, сяцы_, éamp, şene_,
   {{0x3ea66f72,0x7eb50094,0x9c7c00e7,0x7e6917d2}},	//   _poot_, _vápn, sočk, ffep,
   {{0xa3d704a9,0x7cf405fe,0xbe8a2f93,0x3e4c0138}},	//   ापर_, màri, рске_, kėtų_,
   {{0x9c7c0b27,0x41271312,0xeeb700d6,0x7ebc0103}},	//   loči, _мото_, ільш_, _népe,
   {{0x0caa545a,0x3878023b,0x3b5405b6,0x38af00bc}},	//   ртии_, jerr_, пкор, _türi_,
   {{0x7cf40472,0x3ea60270,0x9c7c8e15,0x38780052}},	//   nàri, _toot_, noči, derr_,
   {{0x798d9ec1,0x29130072,0x7cef00f2,0x5fc302d5}},	//   _praw, _sixa_, førs, _वेटल,
   {{0x7eb51e6f,0x99920034,0x101e009f,0xc98400d3}},	//   _zápo, _gdyż_, _पलाश_, мури,
   {{0x7ebc0257,0x9c7c9ec2,0x2ca70103,0x6f02009c}},	//   _dépe, koči, _gond_, _hhoc,
   {{0x9c7c0087,0xa8140396,0x8bc3008f,0x9a873e1c}},	//   joči, ддрш, _осъд, _дупл,
   {{0x798d9ec3,0x7eb5025b,0x56949e20,0x7cf405fe}},	//   _traw, _nápl, маст, dàri,
   {{0x7ebc0018,0x651502a3,0x6f028a17,0x798d0027}},	// [b150] _gépe, سوائ, _mhoc, _uraw,
   {{0x44981119,0x7d1d25da,0x752d037a,0xb5fb0231}},	//   овую_, íssi, rpaz, _acác,
   {{0x9c7c02dd,0x395901bf,0xd2510037,0x7cf4015e}},	//   goči, luss_, فنا_, gàri,
   {{0xb77a07a6,0x877a0341,0x7c2d0095,0x6f020023}},	//   _פארש, _פארי, _đarm, _nhoc,
   {{0xc69207a6,0x39598a33,0x24830095,0x7cfd0113}},	//   _נאך_, nuss_, _tajm_, hèra,
   {{0x63a300d6,0x00000000,0x00000000,0x00000000}},	//   ønns, --, --, --,
   {{0x2ca766d8,0x6f02151d,0x39590364,0xdddb007e}},	//   _rond_, _bhoc, huss_, dduš,
   {{0x6f029ec4,0x3eb90088,0x2ca7007f,0xfe45001f}},	//   _choc, óst_, _sond_, чнио,
   {{0xee3601b3,0x38610150,0xb5fb0065,0x6f0275e4}},	//   чны_, _ochr_, _gbát, _dhoc,
   {{0x7ebc0257,0xdce2003d,0x7eb50146,0x3861022b}},	//   _répe, _proġ, _zápl, _nchr_,
   {{0x2ca70ab2,0x6f02152f,0x7cfd03a9,0x00000000}},	//   _vond_, _fhoc, gèra, --,
   {{0x2ca79ec5,0x6f02009c,0x7cef0ac9,0x39599ec6}},	//   _wond_, _ghoc, tørs, fuss_,
   {{0xfd480174,0x9c7c02f7,0xf9920076,0x2ca700bd}},	//   _momọ, zoči, ربح_, _tond_,
   {{0x3e4c013f,0x6f099ec7,0x3ebf0167,0xe51f00bc}},	//   rėtų_, lmec, lhut_, _बढ़ि_,
   {{0xc7a6013d,0x3b0a008f,0xb8d43e2a,0x7cfd0113}},	//   чивк, _леко_, _झक_, cèra,
   {{0x6f1e1f32,0x6f094d4b,0x9c7c0146,0x39599ec8}},	//   ípci, nmec, voči, buss_,
   {{0xcb1300a1,0x00000000,0x00000000,0x00000000}},	// [b160] _אלה_, --, --, --,
   {{0x7cf40472,0x6f0901bf,0xf8e00cce,0x38b42dd3}},	//   tàri, hmec, _नदिय, _märk_,
   {{0x3ebf3b7c,0x6f0912db,0x00000000,0x00000000}},	//   khut_, kmec, --, --,
   {{0x9c7c0211,0xdddb1c5f,0x7cf40472,0x6d460138}},	//   roči, zduš, ràri, škai,
   {{0x290a0051,0x26d20188,0x9c7c9ec9,0x7ebc01f9}},	//   omba_, miyo_, soči, _lépc,
   {{0x26d23336,0x92cc0081,0x92be0081,0x6f02095b}},	//   liyo_, রকে_, ীকে_, _shoc,
   {{0xdddb0087,0x6f029eca,0xdfd00037,0x7eb50103}},	//   vduš, _phoc, ضية_, _tápl,
   {{0x6d550067,0x3ebf02e7,0x26d29ecb,0x00000000}},	//   ązan, ghut_, niyo_, --,
   {{0x7c86020f,0x38af026a,0x25a00072,0xed5904e9}},	//   пуне, _kürt_, nxil_, guž_,
   {{0x26d260ba,0x645e02c9,0x31bb00a1,0xdb1a0018}},	//   hiyo_, ngpi, _הזמנ, sztí,
   {{0x7cef038c,0x2d8f9ecc,0x26d29ecd,0x6f025bf3}},	//   tørr, _erge_, kiyo_, _thoc,
   {{0xed5a207e,0x26d2008a,0x395901d3,0xbf9b0142}},	//   _год_, jiyo_, tuss_, _ליבש,
   {{0x26d29ece,0x7e62063d,0x26c000d1,0x00000000}},	//   diyo_, _icop, dhio_, --,
   {{0xa3ac8101,0x39590a84,0xb69b00eb,0x26de014b}},	//   गहा_, russ_, _chân, éton_,
   {{0x6c830037,0x26d22d9d,0x77930504,0x00000000}},	//   _سليم, fiyo_, ریحا, --,
   {{0x26c00124,0x0ccd0081,0xc6f9224a,0x26d2008c}},	//   ghio_, রকৃত, інах_, giyo_,
   {{0x27ed0034,0x1ddc01e4,0x7bdc01cd,0x00000000}},	// [b170] łen_, मपित, úruf, --,
   {{0x44273bb9,0x00000000,0x00000000,0x00000000}},	//   ùn_, --, --, --,
   {{0x23792761,0x26d20188,0x57b400d3,0x7e62039f}},	//   تماد_, biyo_, _збэт, _ocop,
   {{0x26c09ecf,0x394905db,0x26d2008c,0x00000000}},	//   chio_, _kvas_, ciyo_, --,
   {{0x98b900e8,0x00000000,0x00000000,0x00000000}},	//   jusī_, --, --, --,
   {{0x7e629ed0,0xb9260065,0xf484013d,0x00000000}},	//   _acop, _aawọ_, _пусн, --,
   {{0xb5fb0032,0xd34700d1,0x38b400bc,0x6f09047e}},	//   _gbár, _ریشه_, _särk_, tmec,
   {{0x39490143,0x2d9f0062,0x00000000,0x00000000}},	//   _ovas_, txue_, --, --,
   {{0x224d9ed1,0x6f092972,0x2eed1030,0xdceb01d3}},	//   _idek_, rmec, roef_, _apgā,
   {{0x26d20060,0x38b432ee,0x3ebf1832,0xaf373160}},	//   ziyo_, _värk_, shut_, _فرصت,
   {{0x3b0a1994,0x394900aa,0x26d25adb,0x3a2902ac}},	//   жено_, _avas_, yiyo_, _bfap_,
   {{0x26d20188,0x5f740781,0x2d8f0117,0x00000000}},	//   xiyo_, _سامر, _trge_, --,
   {{0x68ee010a,0x7e7b024a,0x19b900d3,0x00000000}},	//   tobd, meup, пурь_, --,
   {{0x31560130,0xdc3c0031,0x290a9ed2,0xa3bd0861}},	//   וישן_, _záľu, umba_, इना_,
   {{0x26c002ad,0x7ebc39f4,0x26d29ed3,0x00000000}},	//   thio_, _hépa, tiyo_, --,
   {{0x212d01c2,0x224d00d1,0xb4b6007f,0xf4840504}},	//   _oteh_, _ndek_, जस्_, کاری,
   {{0x26d29ed4,0x6d460b9c,0x34aa0284,0xba7600d1}},	// [b180] riyo_, škav, овао_, _فاکت,
   {{0x26d29ed5,0x9c7c1efa,0x224d2fc5,0x26c09ed6}},	//   siyo_, boču, _adek_, shio_,
   {{0x212d3e41,0x03a3007e,0x00000000,0x00000000}},	//   _ateh_, кифо, --, --,
   {{0xe1fa2311,0x38af01bf,0xdb1a0103,0x6d5b9ed7}},	//   оге_, _fürs_, nztá, kuua,
   {{0x69c62689,0x764445ee,0x7ebc2591,0xd043013c}},	//   nzke, maiy, _népa, linə,
   {{0x7e629ed8,0x79840239,0x628f0072,0x76442bb3}},	//   _scop, _msiw, _ócon, laiy,
   {{0x63831456,0x75240216,0x6d4f9ed9,0x00000000}},	//   _игра, lqiz, ácan, --,
   {{0x44449eda,0xf8bb00e2,0x2f170084,0x764402c9}},	//   la_, _उत्प, мощь_, naiy,
   {{0x444402a7,0x61461469,0x6d4f0a39,0x7ebc014b}},	//   oa_, _цеза, šcan, _cépa,
   {{0x44449edb,0x7ebc04ea,0x00000000,0x00000000}},	//   na_, _dépa, --, --,
   {{0x44444673,0x79849edc,0x403300d6,0x7aef0036}},	//   ia_, _asiw, _реєс, toct,
   {{0x44449edd,0x63a39ede,0x6d5b0bb6,0x7644005c}},	//   ha_, änni, buua, jaiy,
   {{0x44449c74,0x7aef3236,0x76440113,0x984b00d3}},	//   ka_, roct, daiy, жяба_,
   {{0xfbcf0814,0x690b00bd,0x798400fc,0x00000000}},	//   اتی_, _ażer, _dsiw, --,
   {{0xd7f85c95,0x2f016880,0x86020154,0x7c2a009e}},	//   дут_, lóga_, _dakٍ_, _iffr,
   {{0x4444002d,0x442a211d,0x764401c2,0xddc9020a}},	//   ea_, _afb_, gaiy, ngeş,
   {{0x44445c0c,0x09d90f71,0x39491f84,0x442a0abd}},	// [b190] fa_, _সরকা, _uvas_, _bfb_,
   {{0x599600ca,0x80b3034c,0x9c7c0031,0x690b0078}},	//   _נכתב_, _अवधे, poču, _eżer,
   {{0x70db009f,0x32550d86,0x442a9edf,0xf3671231}},	//   _बदौल, евер, _dfb_, ьтан,
   {{0x7d1809ce,0x44449ee0,0x95cb0307,0x442a3afc}},	//   _livs, aa_, _дуга_, _efb_,
   {{0x7c2a906c,0x442a00d1,0xda010179,0xb5fb0139}},	//   _offr, _ffb_, ोधित_, _gbáp,
   {{0x7ebc0257,0xf8bf16e7,0xd1b8006f,0xc1040037}},	//   _répa, mpés_, باما_, نوني,
   {{0x644527e5,0x7ebc0257,0x00000000,0x00000000}},	//   mahi, _sépa, --, --,
   {{0x7c2a9ee1,0x0d852569,0x38b400c2,0xa2820e27}},	//   _affr, елин, _väri_, _میمو,
   {{0x7d1801ac,0x9f4c0094,0x2f012c85,0x61550103}},	//   _bivs, _vydá_, góga_, _سنائ,
   {{0x64454dc4,0x313400d3,0xf0bb0260,0xb16e00b6}},	//   nahi, _рефр, _بارش_, ížeč,
   {{0xeb99064f,0x7eb57e46,0x4ea73da5,0x76440022}},	//   чин_, _lápi, _орда, yaiy,
   {{0x644530ff,0x6aad00d3,0x1a66110a,0x628b5cc0}},	//   hahi, _coaf, ریخی_, ndgo,
   {{0xed4e1d1b,0x6445152a,0x7eb50146,0xd0100018}},	//   _що_, kahi, _nápi, _ملے_,
   {{0x44441258,0xdb1a0068,0xfc3109e5,0x6d49009b}},	//   xa_, sztá, _صحت_, msea,
   {{0x6d49703c,0x64459ee2,0x69c60103,0x629b01c2}},	//   lsea, dahi, szke, _onuo,
   {{0x64430088,0x798401c2,0x98a002f7,0x442a0169}},	//   ðnin, _tsiw, _otić_, _sfb_,
   {{0x6d499ee3,0x764419e4,0x9c7c025b,0x7eb524c7}},	// [b1a0] nsea, raiy, počt, _cápi,
   {{0x6d4910f0,0x44449ee4,0xb4630b2e,0x64459ee5}},	//   isea, ua_, лкул, gahi,
   {{0x7c240dea,0x929d00a5,0x764407ac,0x442a7adb}},	//   _şirk, _chło, paiy, _vfb_,
   {{0x44449ee6,0xaa7b025b,0xd252001c,0x6289030a}},	//   sa_, mnýc, انش_, _caeo,
   {{0x64459ee7,0xaa7b025b,0x291a3620,0xa2b19ee8}},	//   bahi, lnýc, _kipa_, _अकर्,
   {{0x10a308a4,0x44449ee9,0x6d4901b5,0x6445001c}},	//   личн, qa_, dsea, cahi,
   {{0xaa7b025b,0x7eb5025b,0x6d4b9eea,0x291a0167}},	//   nnýc, _zápi, _avga, _mipa_,
   {{0x6f19030a,0x7ae418fd,0x6289030a,0x00000000}},	//   _ciwc, _njit, _gaeo, --,
   {{0x6d497566,0x91e3008f,0x301a0037,0x66db007b}},	//   gsea, _боте, _فتاة_, läkä,
   {{0x291a0649,0x7ae4411d,0x22460270,0xaa7b0094}},	//   _nipa_, _ajit, laok_, knýc,
   {{0xaa7b025b,0x31e20081,0x5457006e,0xaa593a69}},	//   jnýc, _বরিশ, עסטן_, мину_,
   {{0xaa7b18ed,0x6d49009c,0x34dd045f,0xad260037}},	//   dnýc, bsea, _मद्द, _كرتو,
   {{0x64459eeb,0x6d4903dc,0x6aad0350,0x291a0234}},	//   yahi, csea, _voaf, _bipa_,
   {{0x7eb50b0b,0x26f903a2,0xb4af60a3,0x212b002b}},	//   _rápi, ंत्र_, _ओके_, _éche_,
   {{0x64459eec,0x291a7cf1,0x00000000,0x00000000}},	//   vahi, _dipa_, --, --,
   {{0x7ae40910,0x64459eed,0x7cf400ee,0xabfb00ca}},	//   _gjit, wahi, càrr, _מהור,
   {{0x64458396,0x291a9eee,0xf8bf020d,0xaa54007b}},	// [b1b0] tahi, _fipa_, upés_, _свыш,
   {{0x7afd9eef,0xaa7b135f,0x98650068,0xa3bd34d8}},	//   llst, bnýc, _جیسے_, इनल_,
   {{0xf09f00de,0x764b0018,0xd6d1212c,0xaa7b0146}},	//   _đà_, ógys, _نقد_, cnýc,
   {{0x64459ef0,0x291a0307,0xbd050139,0x48fb030b}},	//   sahi, _zipa_, _akẹ́, ोगको_,
   {{0x64456a9f,0xc2c40037,0x63bb0044,0xf194004d}},	//   pahi, ديني, _ƙuns, лиць,
   {{0x7afd32f4,0x656d0350,0x7cfd7683,0x00000000}},	//   hlst, mtah, tèrm, --,
   {{0x656d9ef1,0x6d490381,0x00000000,0x00000000}},	//   ltah, wsea, --, --,
   {{0x7ebc025a,0xcf24012b,0xf1d21362,0x6d499ef2}},	//   _dépo, دروي, _देवन, tsea,
   {{0x6e299ef3,0xaa7b030b,0x98b900c6,0x38b487c8}},	//   rceb, znýc, jusį_, _kärt_,
   {{0x6d499ef4,0x7af634cb,0x7afd8082,0x61fb00a7}},	//   rsea, _skyt, elst, _iyul,
   {{0xa3ba0ed3,0x6d499ef5,0xb5fb0076,0x272700fe}},	//   आईए_, ssea, _scál, _nõn_,
   {{0x291a0580,0xaa7b135f,0x656d1281,0xe61f00de}},	//   _sipa_, vnýc, ktah, _ngô_,
   {{0x6d4602e6,0x656d56ba,0x1ae306c4,0x3b090188}},	//   škar, jtah, роям, _dhaq_,
   {{0xaa7b18ed,0x7afd0b8e,0x201800b3,0x00000000}},	//   tnýc, alst, _úric_, --,
   {{0x46f600d6,0x656d0313,0x98a370a4,0xf743001f}},	//   вчат, etah, шире, иеро,
   {{0xcf920130,0xaa7b025b,0x321f0019,0x656d04c8}},	//   סטן_, rnýc, _nguy_, ftah,
   {{0x61fb0d7f,0xaa7b025b,0x656d3b2e,0x7c240491}},	// [b1c0] _nyul, snýc, gtah, _şiri,
   {{0xaa7b0146,0xfaf901d3,0x66db007b,0x3eaf0381}},	//   pnýc, stīt_, täkä, _logt_,
   {{0x61e929fb,0x213f0113,0x3eaf029a,0x00000000}},	//   _axel, _awuh_, _oogt_, --,
   {{0x7ebc04ea,0x60c19ef6,0x61fb0027,0x39404bb9}},	//   _répo, _allm, _byul, _kwis_,
   {{0x80b30d75,0x7ebc025a,0x20050063,0xf1d20179}},	//   _अवशे, _dépl, _azli_, _देशन,
   {{0xed590146,0x61fb03a9,0x21260167,0x6909003e}},	//   drž_, _dyul, rqoh_, rþeg,
   {{0x61e99ef7,0x7ee617b9,0x213f01dc,0x61fb010a}},	//   _exel, кцие, _ewuh_, _eyul,
   {{0x2d8626e0,0x7bc80146,0x99990220,0x91bf1efb}},	//   _psoe_, vzdu, lasť_, वनशै,
   {{0x61fb0103,0x7c2d0233,0xe04600ae,0x51661146}},	//   _gyul, _şara, _анзи, _шваб,
   {{0x98b900c6,0x7bc801ff,0x00000000,0x00000000}},	//   vusį_, tzdu, --, --,
   {{0x34b700a1,0x394000d1,0x7b21014b,0xead90120}},	//   דפים_, _awis_, _nœud, емні_,
   {{0x4fd90130,0xed5902c6,0x799603a8,0x656d0509}},	//   _אַנד, brž_, _bryw, ytah,
   {{0x394d10af,0xdd920688,0x7afd0149,0x1dd900b6}},	//   ées_, _خوش_, rlst, _बेपत,
   {{0x799659f5,0x26c20dd8,0x00000000,0x00000000}},	//   _dryw, _alko_, --, --,
   {{0x9725048f,0xb8670281,0xb8db0336,0x6abd0216}},	//   افرو, _یادو, _अक_, ërfs,
   {{0x656d811e,0x00000000,0x00000000,0x00000000}},	//   ttah, --, --, --,
   {{0xe8d90294,0x7ebc47a1,0xcb1400ca,0x2a6945fd}},	// [b1d0] _asụ_, _répl, _דלק_, _icab_,
   {{0xfaff01e5,0x656d0c71,0xa5bb0669,0x6abd8d64}},	//   llë_, rtah, _agóc, lksf,
   {{0xa2b405a5,0x656d4dc4,0x68f553d9,0x38b40149}},	//   _आवश्, stah, mozd, _värt_,
   {{0x656d01cd,0x2ee60216,0x00000000,0x00000000}},	//   ptah, _njof_, --, --,
   {{0x865a00ca,0x2124009c,0xc8a702d5,0xa2b409a0}},	//   _אדרי, _cumh_, खापट, _आवर्,
   {{0xdce9003d,0xe057001c,0xd0090012,0x672509a1}},	//   rteċ, ئیات_, неле_, _kuhj,
   {{0x3d06000f,0x8384002d,0x00000000,0x00000000}},	//   _सीधे_, _кыте, --, --,
   {{0x2a69023e,0x7cfd0428,0x61e90b7e,0x6abd01cb}},	//   _ncab_, mèri, _txel, jksf,
   {{0x403525a7,0x68f51f20,0x213f00d1,0x4d156561}},	//   _безс, kozd, _uwuh_, льот,
   {{0x60c100e3,0xaba91c21,0x24810364,0x6abd01cb}},	//   _ullm, евоз_, nehm_, eksf,
   {{0x7a6a062a,0x7c9500bf,0x3f67402c,0x68f500e7}},	//   нинг_, نشگا, _штаб, dozd,
   {{0x79960067,0x66e500c6,0x2e3800ae,0x7ebc01f9}},	//   _pryw, dėko, _апць_, _lépj,
   {{0x7c3a2452,0x80b9142e,0x00000000,0x00000000}},	//   bbtr, ्सपे, --, --,
   {{0x7996057a,0xdce90a39,0xfaff0216,0x7c2400a7}},	//   _vryw, oteč, alë_, _şirv,
   {{0x2cb89ef8,0xeb990b26,0x869a00d3,0x00000000}},	//   örde_, _чий_, нтат_, --,
   {{0x292500e3,0x79960178,0x6abd03bd,0x39400f5a}},	//   úpaí_, _tryw, cksf, _twis_,
   {{0xceb209c1,0xe5a34776,0x68f50087,0x1dd903b3}},	// [b1e0] זין_, бити, bozd, _बेमत,
   {{0x888610f7,0x03a6523b,0xf7f615f8,0x7cfd0428}},	//   _слож, лизо, _مسجد, fèri,
   {{0xfaf900d9,0x9cd600ca,0x80b900aa,0x7cfd015e}},	//   brīd_, נועה_, ्सने, gèri,
   {{0x6d5b01e5,0x2bf6006e,0x316a075f,0x00000000}},	//   krua, אמען_, ешко_, --,
   {{0x60d80383,0x6e3b09ac,0x35fa0018,0x00000000}},	//   tivm, dbub, _سرحد_, --,
   {{0x7ebc01f9,0x7cfd1848,0x6d5b0216,0x00000000}},	//   _gépj, bèri, drua, --,
   {{0x76468247,0x7cfd00b3,0x9c7c0141,0x00000000}},	//   _keky, cèri, jnča, --,
   {{0x6e3b1331,0x7986366c,0x7d54008f,0x727912d3}},	//   gbub, kwkw, авих, _исус_,
   {{0x6d5b9ef9,0x66e500c6,0xcd3600d1,0x00000000}},	//   grua, dėkl, درعب, --,
   {{0xddcb00d3,0x752600dc,0x2a69010a,0x00000000}},	//   ţişt, _mukz, _scab_, --,
   {{0x7eb51f97,0x4f5a0f36,0x5fa82a29,0x68f51de1}},	//   _cáps, _سجاد_, _कपिल, vozd,
   {{0x7646285a,0x68f5007f,0x6efe0216,0x672303a9}},	//   _neky, wozd, këbi, _énji,
   {{0x75260063,0x6e2204ff,0x6abd9efa,0x00000000}},	//   _nukz, _igob, rksf, --,
   {{0x9b9400d3,0xa3c4023a,0x672512f1,0xe7878c7f}},	//   _викц, एना_, _puhj, лубо,
   {{0x764601be,0x68f50094,0xb4db00b3,0x00000000}},	//   _beky, rozd, _ovàr, --,
   {{0x96359c67,0x79a70832,0x6d4205aa,0x6d5d01cd}},	//   рнац, _брое, _kwoa, ásag,
   {{0xf8ae0260,0x628212dc,0x6e22039f,0x68f51206}},	// [b1f0] سکی_, deoo, _mgob, pozd,
   {{0x7cfd0472,0xdce900b6,0x76460172,0xa6144911}},	//   tèri, yteč, _eeky, смуч,
   {{0xd2510f43,0x6e2206b0,0xc7ab0076,0x00000000}},	//   قنا_, _ogob, _أدخل_, --,
   {{0x6e227246,0x0ce11e9f,0x7646057a,0x6d5b0216}},	//   _ngob, _पद्म, _geky, yrua,
   {{0xa0690528,0xe0450636,0xd04a0092,0x7cfd0428}},	//   вала_, анли, lifə, sèri,
   {{0x2f55290e,0x7eb50146,0x6e229efb,0xdceb0090}},	//   атис, _nápr, _agob, _irgħ,
   {{0x256f2599,0x628201c0,0x6d42010a,0x64550034}},	//   lül_, beoo, _awoa, _idzi,
   {{0x6d5b7e32,0x44310b14,0x26c90131,0x00000000}},	//   trua, _hfz_, nhao_, --,
   {{0x64479efc,0x256f9efd,0xd04a01d4,0xa2c20eeb}},	//   _keji, nül_, hifə, लसर्,
   {{0x6d5b2011,0x6447000d,0xeb990291,0x6e229efe}},	//   rrua, _jeji, вио_, _egob,
   {{0x64479eff,0xdb22003e,0xc0c8002d,0x00000000}},	//   _meji, ærðf, _суте_, --,
   {{0x64478127,0x6d5b023b,0x256f9f00,0xddd40357}},	//   _leji, prua, kül_, šašt,
   {{0xddc2000d,0x64550bbc,0x3ead023b,0x76468870}},	//   _zbož, _odzi, mjet_, _reky,
   {{0xe8f720ec,0x3ead9f01,0x291e4249,0x256f807d}},	//   иля_, ljet_, öta_, dül_,
   {{0xb8de82eb,0x290400d9,0xf7461262,0x00000000}},	//   _आव_, ēma_, ребо, --,
   {{0x3ead0fb2,0x0686001f,0xc6c31787,0xd5e600e5}},	//   njet_, јган, ойск, ажби,
   {{0xa44633a0,0x256f0ffc,0x4ad80018,0x7ebc9f02}},	// [b200] инад, gül_, _لاکھ_, _déph,
   {{0x3ead45f0,0x389a006e,0x76460172,0x00000000}},	//   hjet_, _ייִנ, _weky, --,
   {{0xdddb0335,0x7d010013,0x3ead9f03,0x64479f04}},	//   jduž, ills, kjet_, _deji,
   {{0x3ebf1a0d,0x26c90227,0xd4090076,0x00000000}},	//   jkut_, chao_, اتكم_, --,
   {{0x27f71e49,0x3ead0268,0xf19400a9,0x690000c2}},	//   _مفید_, djet_, силь, töeh,
   {{0x64550067,0x60f70c10,0x64479f05,0x899700ca}},	//   _gdzi, анія_, _geji, יכנס_,
   {{0x656400c2,0xadc30032,0x00000000,0x00000000}},	//   luih, _ilẹk, --, --,
   {{0x3f980102,0x3ead00dd,0x3ebf67c4,0xb5fb0a93}},	//   _árum_, gjet_, gkut_, _abáy,
   {{0xd04a0092,0x7b33020a,0x27ed0233,0x81d40033}},	//   zifə, _lăud, ğeni_, _সুর_,
   {{0x27ed59cf,0x26c903e3,0x00000000,0x00000000}},	//   şeni_, zhao_, --, --,
   {{0x256f0018,0x26c00036,0xa5bb00fe,0x9e66001c}},	//   zül_, kkio_, _ngón, _ناشن,
   {{0x6d42022b,0x7d011ab6,0x6e225a33,0x00000000}},	//   _twoa, alls, _ugob, --,
   {{0xfce6188d,0xa3dd2647,0xe8b409b0,0x00000000}},	//   _кодо, _तेन_, ुसूच, --,
   {{0x256f0018,0xe7f2045f,0xaa7b0094,0x7d7b00ca}},	//   vül_, _आँखा_, mným, _סרוג,
   {{0xab274bac,0x64479f06,0xaa7b0146,0x66e500c6}},	//   _која_, _reji, lným, sėkm,
   {{0x256f0018,0x442303e3,0x44310206,0x25a901ff}},	//   tül_, _sgj_, _sfz_, txal_,
   {{0x64470580,0xaa7b0146,0xdddb050d,0x4423037a}},	// [b210] _peji, nným, zduž, _pgj_,
   {{0x256f0018,0x7ebc00fd,0x3ead9f07,0x798d9f08}},	//   rül_, _dépi, zjet_, _isaw,
   {{0x9f5e00dd,0x64479f09,0x69cf01d3,0x256f9631}},	//   _dytë_, _veji, lzce, sül_,
   {{0xb69b0257,0x29034f84,0x6447008c,0x6455007f}},	//   _chât, llja_, _weji, _wdzi,
   {{0x3ead9f0a,0x764d9f0b,0x64470890,0x50b55566}},	//   vjet_, maay, _teji, йску,
   {{0x645500a5,0xaa7b0146,0x764d9f0c,0x26d905ff}},	//   _udzi, dným, laay, _hmso_,
   {{0x3ead00dd,0x987c00c1,0x3ebf00c2,0x02a74f40}},	//   tjet_, דרוק, tkut_, _крам,
   {{0x764d3329,0x212b020d,0x798d53ed,0x29030141}},	//   naay, _écho_, _osaw, hlja_,
   {{0x3ead9f0d,0x3ebf9f0e,0x798d0361,0x2d993ee9}},	//   rjet_, rkut_, _nsaw, íse_,
   {{0x3ead9f0f,0x764d008a,0x26c001e9,0x3ebf9f10}},	//   sjet_, haay, zkio_, skut_,
   {{0x798d608a,0x764d7692,0x2cb80212,0x5f950103}},	//   _asaw, kaay, örda_, _دلائ,
   {{0xaa7b0146,0xddd90078,0x3ead0216,0x00000000}},	//   bným, _kawż, qjet_, --,
   {{0xed590476,0x764d9f11,0xfe700e11,0x6bd50018}},	//   _сол_, daay, _آدم_, شتگر,
   {{0x6c350814,0x7e699f12,0x7ebc014b,0xcb690b0a}},	//   _افغا, lgep, _répi, _баке_,
   {{0x5b351dec,0x764d0517,0xdc36006e,0x798d10df}},	//   _اعتر, faay, _פאקט_, _esaw,
   {{0x9f5e023b,0x752d00a7,0x7ebc020d,0x764d9f13}},	//   _sytë_, fqaz, _pépi, gaay,
   {{0x290319d0,0x6aa49f14,0xe5a38519,0xae0d00aa}},	// [b220] blja_, _inif, пити, ाइटन_,
   {{0x07fa00cd,0x387a0169,0xdb0f007b,0x290305db}},	//   _مرجع_, _ubpr_, ädök, clja_,
   {{0xe29a1a21,0xa2e6036a,0xb69b020d,0xaa7b0a7f}},	//   лаж_, божд, _châs, zným,
   {{0x764d0188,0x673b09ac,0xa97a0142,0x55e601b6}},	//   caay, ćujt, ָאַכ, _гомб,
   {{0xf1d202b0,0x7ebc0018,0xfd4b0174,0x6aa40350}},	//   _देखन, _képv, ranị, _mnif,
   {{0xaa7b0146,0xf99300d7,0x00000000,0x00000000}},	//   vným, פרו_, --, --,
   {{0x7e69042c,0x00000000,0x00000000,0x00000000}},	//   fgep, --, --, --,
   {{0x1dd905d4,0xa5bb00a5,0xaa7b035d,0x7e6959c1}},	//   _बेहत, _ogól, tným, ggep,
   {{0xc69300a1,0xfbd50033,0x61430b9c,0x3eb902c3}},	//   לאה_, _সুলত, _нета, östa_,
   {{0x6aa40150,0xaa7b0094,0xb5b700ca,0x3b5414a4}},	//   _anif, rným, צליח_, окор,
   {{0x764d9f13,0xaa7b0094,0xb4fb006e,0x798d9f15}},	//   yaay, sným, רליר, _ssaw,
   {{0x635c00ae,0x764d008c,0xaa7b00d4,0x00000000}},	//   mănă, xaay, pným, --,
   {{0x290300cc,0x00000000,0x00000000,0x00000000}},	//   tlja_, --, --, --,
   {{0x764d0bf2,0x66e50138,0x6aa40372,0xac18131b}},	//   waay, mėki, _enif, _колу_,
   {{0x764d82ad,0xb6c708cb,0x66e500c6,0x5fa809a1}},	//   taay, бсай, lėki, कमिल,
   {{0x798d9f16,0x36d41b77,0x29030580,0xbb3b00c1}},	//   _tsaw, поср, slja_, _געהי,
   {{0x2903042d,0x798d5658,0x764d399b,0x58d502b3}},	// [b230] plja_, _usaw, raay, _моит,
   {{0x764d0283,0x00000000,0x00000000,0x00000000}},	//   saay, --, --, --,
   {{0x7c2d01e8,0xdce00335,0x764d02c9,0x00000000}},	//   _şark, jumč, paay, --,
   {{0x26d90364,0x764d008c,0x66e500c6,0xddd902a1}},	//   _umso_, qaay, kėki, _pawż,
   {{0x6025016d,0x00000000,0x00000000,0x00000000}},	//   одла, --, --, --,
   {{0x10a201c9,0x90c500a9,0x66e50138,0xe1f00781}},	//   дишн, юбле, dėki, رسن_,
   {{0x7e691044,0xdddb007e,0xaa7b003e,0x9ea91e79}},	//   tgep, deuš, rnýj, ивка_,
   {{0x7aed9f17,0x8d55169f,0x00000000,0x00000000}},	//   _njat, оточ, --, --,
   {{0x7e699f18,0xed5910a6,0x00000000,0x00000000}},	//   rgep, шоп_, --, --,
   {{0x7aed6c9c,0x7cfd9f19,0xcd280037,0x7e691597}},	//   _ajat, vèrs, حسين_, sgep,
   {{0x6a861da9,0x00000000,0x00000000,0x00000000}},	//   олна, --, --, --,
   {{0x6d4f0072,0x78a5020b,0x00000000,0x00000000}},	//   ácas, _anhv, --, --,
   {{0x7aed023b,0x0f1800b9,0x272e01cd,0x00000000}},	//   _djat, _اغلب_, _sýn_, --,
   {{0x8afd0d1b,0x186a372d,0x52b6417a,0xa315009d}},	//   stęp, јави_, _अक्स, तगुज_,
   {{0xd7f20037,0x2d8f05db,0x00000000,0x00000000}},	//   ذكر_, _hsge_, --, --,
   {{0x7aed01e5,0xb6a31756,0x78a50856,0x672f00d2}},	//   _gjat, мисл, _enhv, _žijí,
   {{0x2bc12918,0x00000000,0x00000000,0x00000000}},	// [b240] शनका, --, --, --,
   {{0xaca30294,0x2d9d010a,0x63be7e32,0x00000000}},	//   knọl, _mrwe_, typn, --,
   {{0x68fc0429,0x934601ce,0x2f010220,0xb5fb0037}},	//   mord, інде, lógu_, _scát,
   {{0xf1db143d,0xa20692bb,0xe5a6249b,0x9c7c0147}},	//   _मेहन, опед, _дими, miče,
   {{0x68fc01c0,0x9c7c9f1a,0x29180076,0x00000000}},	//   oord, liče, omra_, --,
   {{0x2574070a,0x68fc9f1b,0x7bcd01c2,0x399b0266}},	//   mäl_, nord, _ƙaul, יינד,
   {{0x9c7c02e6,0x2d990537,0x63be0216,0x00000000}},	//   niče, æsen_, qypn, --,
   {{0x1ef70037,0x68fc31ba,0xb5fb0076,0x00000000}},	//   يعية_, hord, _gcás, --,
   {{0x657690e3,0x0caa1b4d,0x307600c2,0x00e62768}},	//   ntyh, атни_, _мужс, _джан,
   {{0xf06363fe,0x7ebc5320,0x68fc34cb,0x8afd0034}},	//   _окуп, _répu, jord, kręc,
   {{0x9c7c1419,0x7aed9f1c,0x6d4f016d,0x2d9d0f5a}},	//   jiče, _pjat, ácar, _erwe_,
   {{0xf3ec0f71,0x8afd0034,0x9c7c63f0,0x00000000}},	//   _করার_, dręc, diče, --,
   {{0x25740149,0x2d96322c,0xae16099d,0x68fc0d4b}},	//   jäl_, _фрес, देशन_, ford,
   {{0x2bca000f,0xbb2a00d3,0x9c7c0141,0x00000000}},	//   ानदा, _кцие_, fiče, --,
   {{0xd6db9f1d,0x7aed9f1e,0xcb670284,0x00000000}},	//   ата_, _tjat, _даје_, --,
   {{0xa5350d72,0x257402c3,0x7aed063d,0x00000000}},	//   знач, fäl_, _ujat, --,
   {{0x38c9001c,0xdb17007f,0x06cd0033,0x00000000}},	// [b250] _هادی_, ńców, রচলি, --,
   {{0x7afd9f1f,0x68fc9f20,0x3f9e94c6,0x394906a8}},	//   lost, cord, _ortu_, _iwas_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f9e3041,0x25ad0216,0x66c300bc,0x00000000}},	//   _artu_, _çel_, _lõkk, --,
   {{0xe0d802ec,0xfbca04d7,0x55ba00a1,0x3ea60138}},	//   ові_, ानाम, _המשו, _anot_,
   {{0x60222cbf,0x7ebc0018,0x3f9e0995,0x387c0212}},	//   ндша, _néps, _crtu_, _övre_,
   {{0x0ea902fd,0xee39008f,0x68fc9f21,0x00000000}},	//   ский_, щни_, zord, --,
   {{0x68fc0b88,0x7ebc0bf8,0x3f9e0088,0x9c7c033b}},	//   yord, _répt, _ertu_, ziče,
   {{0x7ebc04d8,0x2b470150,0x3ea6033b,0x00000000}},	//   _sépt, _pwnc_, _enot_, --,
   {{0x7afd9f22,0x68fc01a2,0x3949113a,0x01bd0081}},	//   fost, vord, _awas_, _অধিদ,
   {{0x7afd9f23,0x9c7c9f24,0xef0e00d6,0x212d00dc}},	//   gost, viče, _їм_, _kueh_,
   {{0x224d0611,0x6da517e9,0x2d9d0169,0x2d9100e8}},	//   _meek_, _хила, _urwe_, āzes_,
   {{0x9c7c0660,0x224d01c0,0x20120092,0x25740149}},	//   tiče, _leek_, əyib_, väl_,
   {{0x07a324e9,0x2ca701ec,0x2d8d0231,0x00000000}},	//   нарн, _innd_, lwee_, --,
   {{0xcf9207a6,0x7afd23fa,0x68fc4bf9,0x200516c3}},	//   עטן_, cost, sord, _myli_,
   {{0x05665414,0x68fc9f25,0x38b402e2,0xc566008f}},	// [b260] яван, pord, _märz_, якак,
   {{0x9c7c033b,0x8ca10285,0x26cb9f26,0x00000000}},	//   piče, _कोमो, _elco_, --,
   {{0xc61d0081,0x7bc10113,0x224d029a,0x7ebc020d}},	//   ধুলা_, nylu, _beek_, _mépr,
   {{0xc7b30341,0x212d037a,0xaacc11c7,0x00000000}},	//   _טבת_, _bueh_, ासिक, --,
   {{0xd24f0979,0x76449f27,0x00000000,0x00000000}},	//   انه_, mbiy, --, --,
   {{0x7afd3f78,0x20050640,0xfd0707e8,0x76443cae}},	//   zost, _byli_, _سج_, lbiy,
   {{0x76440694,0x6d5d0037,0x7afd3030,0xe29a21be}},	//   obiy, ásan, yost, _лав_,
   {{0x444402dc,0x3f9e13e8,0x442a128c,0x76442592}},	//   lb_, _vrtu_, _hgb_, nbiy,
   {{0x644e6d5f,0x7afd9f28,0x44440d7d,0xb5fb0072}},	//   _kebi, vost, ob_, _edáf,
   {{0x44449f29,0xdb1b0018,0x644e157b,0x3d060378}},	//   nb_, sztü, _jebi, _सीखे_,
   {{0x44440a86,0x644e0129,0x66060939,0x28b00f62}},	//   ib_, _mebi, _lykk, ञानि,
   {{0x644e2129,0x4438010a,0x6726033b,0x65640052}},	//   _lebi, _lfr_, _nikj, krih,
   {{0xdca61a9c,0x0e9b00a1,0x76440188,0x3157006e}},	//   _нади, _לשאל, dbiy, ּילן_,
   {{0x644e9f2a,0x645c023b,0x442a9f2b,0x00000000}},	//   _nebi, _ndri, _ngb_, --,
   {{0x628002dd,0x44449f2c,0x6c7b00a1,0xe7842f03}},	//   _obmo, db_, _האופ, нуто,
   {{0x44449f2d,0x442a02e2,0x96d80034,0x65640bc6}},	//   eb_, _agb_, नोलॉ, frih,
   {{0xdb1b1feb,0x6726003d,0x645c1d09,0x442a8f9c}},	// [b270] sztó, _dikj, _bdri, _bgb_,
   {{0x6606038c,0x66ca0094,0x29070037,0x644e9f2e}},	//   _dykk, _výka, _óna_, _cebi,
   {{0x76449f2f,0x645c6211,0x6564189e,0xe8d800d7}},	//   bbiy, _ddri, arih, _מוזר_,
   {{0x44441071,0x66ca025b,0x645c03a9,0x65649f30}},	//   ab_, _týka, _edri, brih,
   {{0x44449f31,0x9c7c013f,0x442a9f32,0x644e875b}},	//   bb_, anči, _fgb_, _febi,
   {{0x644e0d50,0x224d00a1,0xb5fb0139,0x444401ec}},	//   _gebi, _week_, _adág, cb_,
   {{0x7ebc39f4,0x64450372,0x224d01cb,0xf83800ca}},	//   _répr, mbhi, _teek_, הנות_,
   {{0x3eb9003e,0x442a9f33,0x644e9f34,0x7c381030}},	//   ðst_, _zgb_, _zebi, _afvr,
   {{0x802712eb,0x628b9f35,0x644e9f36,0x3cfe00fe}},	//   _فرام, mego, _yebi, fotv_,
   {{0x628b0778,0x62999f37,0xf65f052f,0x2d8d02ac}},	//   lego, ldwo, _blæk_, rwee_,
   {{0x76440188,0x7527029a,0x644503dc,0x6d400381}},	//   ybiy, _mijz, ibhi, apma,
   {{0x628b9f38,0xbe150391,0x63a316f9,0x764f00d8}},	//   nego, _قواع, änny, _necy,
   {{0x6f0903a8,0xed4e9f39,0x6f1b9f3a,0x4444041c}},	//   mlec, _шо_, mmuc, yb_,
   {{0x6f099f3b,0x628b0042,0x660613c8,0x38730113}},	//   llec, hego, _rykk, _ccxr_,
   {{0xa3dd45c8,0x660600d6,0x628b0113,0xe73741c3}},	//   _तेल_, _sykk, kego, дес_,
   {{0x4444925c,0x9c7c005f,0x628b9145,0x44389f3c}},	//   wb_, miča, jego, _sfr_,
   {{0x76449f3d,0x75270ab2,0x764f00a5,0x628b9f3e}},	// [b280] rbiy, _bijz, _decy, dego,
   {{0x444401bb,0x6f0902e2,0xe3df0081,0x76440188}},	//   ub_, hlec, _বুধব, sbiy,
   {{0x9c7c02e6,0x6f0993ae,0x644e01bf,0x764f0072}},	//   niča, klec, _vebi, _fecy,
   {{0x66069f3f,0xb4db0065,0x628b0eb3,0xfbd200ca}},	//   _tykk, _atàd, gego, כתב_,
   {{0x644e9f40,0x44380036,0x6f099f41,0xdce000ae}},	//   _tebi, _tfr_, dlec, numă,
   {{0x6f0921d8,0x6f029f42,0x7527029a,0x644e0052}},	//   elec, _skoc, _gijz, _uebi,
   {{0x628b8d4b,0xdfd000e3,0x6d590154,0x6f099f43}},	//   bego, طية_, _avwa, flec,
   {{0x628b02ef,0x26d20167,0x6d4b030a,0x6f090158}},	//   cego, nhyo_, _bwga, glec,
   {{0x224691f6,0x24983ff5,0x3f85007e,0x00000000}},	//   mbok_, _karm_, _eplu_, --,
   {{0xa2da0751,0x22469f44,0x9c7c0106,0x673e0dd9}},	//   पोर्, lbok_, fiča, _otpj,
   {{0x6f0911ce,0x7d080222,0x9c7c0106,0x24980072}},	//   blec, rlds, giča, _marm_,
   {{0x7c2d01e8,0x22468870,0x2498057e,0x0357006e}},	//   _şart, nbok_, _larm_, ויטש_,
   {{0x2bde09c3,0xace90281,0x2246084e,0x00000000}},	//   _फेरा, _کرنل_, ibok_, --,
   {{0x9c7c02e6,0x7b760100,0x212b0451,0x31662875}},	//   biča, _قطعا, _èche_, iroz_,
   {{0xa3dd1349,0x0cca02d5,0x764f00f0,0x67d5004d}},	//   _तें_, िसीम, _pecy, хову,
   {{0x929d0034,0xbbca17ad,0x290a037a,0x2ee400b3}},	//   _okła, ानीक, alba_, nimf_,
   {{0x22462ba4,0x310e2647,0x628b0565,0x99480037}},	// [b290] dbok_, िताः_, vego, _قليل_,
   {{0x628b083e,0x24980090,0x00000000,0x00000000}},	//   wego, _carm_, --, --,
   {{0xdce9005f,0x64450a02,0x6f0998da,0x24983180}},	//   steć, rbhi, ylec, _darm_,
   {{0x75270ab2,0x2175004d,0x22469f45,0xb4db01b9}},	//   _wijz, еукр, gbok_, _stàd,
   {{0x9c7c0039,0x62999f46,0xbbca2a29,0xcad800a1}},	//   ziča, rdwo, ानुक, וואת_,
   {{0x3cf8009f,0x26c99f47,0x6d5d0076,0x4f95001f}},	//   ँवों_, lkao_, ásam, ериу,
   {{0x656d0332,0xfe710037,0x00000000,0x00000000}},	//   luah, هدة_, --, --,
   {{0xf53f0c9b,0x27350222,0x9c7c042d,0x26c900c4}},	//   _tråd_, _mån_, viča, nkao_,
   {{0x6f099f48,0x273502fe,0x998000a5,0x656d2430}},	//   rlec, _lån_, _dziś_, nuah,
   {{0x9c7c02e6,0xc4d20130,0x6f099f49,0x213f0085}},	//   tiča, ָגט_, slec, _ituh_,
   {{0x27350222,0x656d9f4a,0x20ac0b76,0xb0ac058f}},	//   _nån_, huah, चारध, चारग,
   {{0x5fd80096,0x26c90234,0x04eb0033,0x6f000231}},	//   _भेटल, jkao_, _কঠোর_, comc,
   {{0x9c7c9f4b,0xa3e600c3,0xfd500134,0x213f0090}},	//   mičn, _बेन_, _medị, _jtuh_,
   {{0x9c7c00cb,0x213f0350,0x00000000,0x00000000}},	//   piča, _mtuh_, --, --,
   {{0x9cd60054,0x8cac007f,0x3ebd9f4c,0xe9df003e}},	//   _רוצה_, जारो, _kowt_, rbúa_,
   {{0x7bda0054,0x66ca18ed,0x225f0ece,0xba010174}},	//   _מקצו, _výko, _nduk_, ụsịt,
   {{0x27ff0511,0x213f096f,0x656d00f9,0x00000000}},	// [b2a0] ğuna_, _ntuh_, guah, --,
   {{0x7ae69f4d,0x225f0f8b,0x33f60a7c,0x26d202a4}},	//   likt, _aduk_, нчес, shyo_,
   {{0x929d00a5,0x213f0479,0x249802fe,0x69c69f4e}},	//   _skła, _atuh_, _varm_, lyke,
   {{0x213f0167,0x26c900cc,0x9c7c0117,0x8ca12397}},	//   _btuh_, ckao_, jičn, _कोसो,
   {{0x9c7c023c,0x27f200d9,0x76560044,0x3265004d}},	//   dičn, šanā_, mayy, ттєв,
   {{0x76560d2a,0x7ae69f4f,0x31660062,0x22469f50}},	//   layy, hikt, rroz_, sbok_,
   {{0x9c7c0117,0xb9250294,0x929d0034,0xb4db009c}},	//   fičn, _akpụ_, _wkła, _ftàb,
   {{0x394014d0,0xdd900192,0xc7b3040a,0x42530241}},	//   _otis_, لوب_, רבה_, _منفر,
   {{0x394001fa,0x929d00a5,0xe0da311c,0x6f009f51}},	//   _ntis_, _ukła, _ева_, romc,
   {{0x20120092,0x2a603c21,0x7ae60062,0x6f0000b3}},	//   əyin_, _adib_, eikt, somc,
   {{0xdeef0ff8,0x9c7c02e6,0x394006a3,0x76560044}},	//   _бы_, bičn, _atis_, kayy,
   {{0xe8d90134,0x7ec600fd,0x27350212,0x00000000}},	//   _mpụ_, _dépê, _rån_, --,
   {{0x66ca0146,0x27350149,0x7656049e,0x212b01c0}},	//   _výkl, _sån_, dayy, _écht_,
   {{0x2a6001d4,0x7d0101b9,0x52bd02d5,0x00000000}},	//   _edib_, cols, _ऍक्स, --,
   {{0xb90902e8,0xf53f3813,0x39400085,0x7ae62a0b}},	//   _मग_, _stå_, _etis_, bikt,
   {{0x56944e66,0xf1c60028,0x7c250146,0x76560022}},	//   ласт, _đánh_, _úhra, gayy,
   {{0x6aad0010,0xe8d90294,0x69c69f52,0xdce900ae}},	// [b2b0] _inaf, _apụ_, cyke, _înăl,
   {{0x47352f17,0x9c7c011d,0x26c9042d,0x765600f9}},	//   _инос, zičn, skao_, aayy,
   {{0x29031ee3,0x765601c2,0x656d0131,0x6aad05db}},	//   moja_, bayy, suah, _knaf,
   {{0xd6db013a,0x290338bc,0x68e7029a,0x00000000}},	//   _хто_, loja_, lijd, --,
   {{0x9c7c1027,0xb0ac0789,0x6aad0239,0xcb140266}},	//   vičn, चांग, _mnaf, אלף_,
   {{0x29039f53,0x9c7c15f2,0xd0090012,0x68e7735f}},	//   noja_, dičo, меле_, nijd,
   {{0x9c7c19d0,0x6aad01a2,0x7d019f54,0x69c600d2}},	//   tičn, _onaf, vols, zyke,
   {{0x225f0449,0x290300c2,0x6aad0361,0x00000000}},	//   _uduk_, hoja_, _nnaf, --,
   {{0x9c7c03f1,0x29039f55,0x213f62af,0x7d019f56}},	//   ričn, koja_, _utuh_, tols,
   {{0x6aad9f57,0x29039f58,0xa2bd02d5,0x629b024a}},	//   _anaf, joja_, वॉर्, _hauo,
   {{0x76561114,0x7ae660a6,0x29039c06,0x7a6a0231}},	//   yayy, tikt, doja_, минг_,
   {{0xd0100018,0x7d011206,0x9c7c0206,0x6aad03a8}},	//   _چلے_, sols, bičo, _cnaf,
   {{0x7d0100a5,0x645701ff,0xbd8900d1,0x00000000}},	//   pols, kaxi, _آنتن_, --,
   {{0x7ae6038b,0x29032af0,0x6aad010a,0x69c6611f}},	//   sikt, goja_, _enaf, ryke,
   {{0x66e60ed4,0x2fc700f9,0x4807002d,0x64571321}},	//   вова, nyng_, верн_, daxi,
   {{0x6e3b08d3,0x246400d9,0xe3b209b4,0x629b01c2}},	//   ncub, zīmē_, یرا_, _nauo,
   {{0x7ae49f59,0x76561114,0x78be18f0,0x64573c6b}},	// [b2c0] _imit, rayy, _topv, faxi,
   {{0x29039f5a,0xa44305cb,0x5a8a0174,0x765647be}},	//   coja_, инуд, _ụlọọ, sayy,
   {{0x6d5b9f5b,0x7ae4023c,0x6e3b02ac,0x00000000}},	//   hsua, _kmit, kcub, --,
   {{0x7656005c,0xd0410092,0x614647b0,0x25ad0087}},	//   qayy, _illə, веда, _šele_,
   {{0x6d5b023e,0x7ae40172,0x00000000,0x00000000}},	//   jsua, _mmit, --, --,
   {{0x04439f5c,0x9c7c2347,0x8ca108c0,0x64570231}},	//   _верн, vičo, _कोलो, caxi,
   {{0xc6070081,0x66d10212,0xdce000e7,0x84e322ff}},	//   লেদা_, _håka, lumć, _торж,
   {{0xe81a0251,0x0cca0f8f,0x68e7029a,0x7c2d020a}},	//   _धरना_, िस्म, zijd, _şarp,
   {{0x6282672e,0xaca90018,0x127b006e,0x4e0500b6}},	//   mfoo, کھنے_, _קאמע, _हुदै_,
   {{0x7ae49f5d,0x62823cbc,0x2617009d,0x4c940291}},	//   _amit, lfoo, पेटी_, ћинс,
   {{0x29039f5e,0x9c7c0031,0x2fd80537,0x81f40033}},	//   voja_, sičo, _årg_, _জরিপ_,
   {{0x7e981f11,0x68e701c0,0x4caf0033,0xbe210032}},	//   _سنتر_, wijd, টসগু, _kọlẹ,
   {{0x29039f5f,0x68e70126,0x4cba0081,0x291a01ec}},	//   toja_, tijd, ইসবু, _bhpa_,
   {{0x7ae49f60,0x5ba60231,0x6d4201ff,0xa5bb9f61}},	//   _emit, _ариз, _itoa, _ogór,
   {{0xc7c40870,0x29034016,0x68e70126,0x2cae039f}},	//   асти, roja_, rijd, _infd_,
   {{0x6aad0051,0x8f9b006e,0x29039f62,0x212c023b}},	//   _unaf, וילי, soja_, _lidh_,
   {{0xa5bb0830,0xa61598c8,0x29036c9a,0x628200bc}},	// [b2d0] _agór, умач, poja_, dfoo,
   {{0x03c7460b,0x89da1aaa,0xca2a006e,0x6d5d071c}},	//   ксем, _سوپر_, _אופֿ, ásai,
   {{0x64579f63,0xed460260,0x442700c2,0x68e501b9}},	//   raxi, _گپ_, än_, _imhd,
   {{0xe8e10019,0x212c01f7,0x6d5d00e8,0x9c7c0206}},	//   _đột_, _aidh_, šsai, dičm,
   {{0x212c0013,0x208914fb,0x00000000,0x00000000}},	//   _bidh_, ейли_, --, --,
   {{0x92e30081,0x212c9f64,0xaf994402,0x629b0350}},	//   নকে_, _cidh_, етих_, _wauo,
   {{0x6d4201c8,0x212c01b9,0x443101cb,0xd0060e3a}},	//   _atoa, _didh_, _igz_, леше_,
   {{0xdd915e51,0x645535ee,0x6d5b9f65,0x200c00f0}},	//   موع_, _hezi, tsua, _dydi_,
   {{0x6e3b9f66,0x6d5b01fa,0x60f93ac9,0xb1cd0134}},	//   rcub, usua, _зная_, ọọkụ_,
   {{0x6e3b309c,0x6acc02d5,0x9c7c28fc,0x7ae49c53}},	//   scub, ास्र, ličj, _smit,
   {{0xa3d62a24,0xd0110cd2,0x6d5b6349,0x6d4271f6}},	//   िनय_, _الا_, ssua, _etoa,
   {{0x64559f67,0xd94601c9,0x60c134cb,0xa96a0291}},	//   _lezi, леми, _holm, нима_,
   {{0x60c113e3,0xdbc900aa,0x3eaf0063,0x2d58002d}},	//   _kolm, _rõõm, _ingt_, _аичь_,
   {{0x64559f68,0x8d5a00a1,0x66d1320e,0x8b950f21}},	//   _nezi, _טכני, _råka, _брич,
   {{0x66d1038c,0x657d0167,0x7bc80034,0xac091dc6}},	//   _såka, _aqsh, cydu, _янка_,
   {{0x66e3007e,0xdb04014b,0x7ae4039f,0x00000000}},	//   боса, _orné, _umit, --,
   {{0x64559f69,0x25a60037,0xdb09001c,0x61fb039f}},	// [b2e0] _bezi, íol_, _جزوه_, _nxul,
   {{0x779412eb,0xbf0f00a4,0x00000000,0x00000000}},	//   _پیرا, ातुन_, --, --,
   {{0x332d2751,0x64559f6a,0x320d008a,0x44310134}},	//   _biex_, _dezi, _ayey_, _dgz_,
   {{0x44319f6b,0xe1fa1165,0x20d001ec,0x6455010a}},	//   _egz_, нге_, _càin_, _eezi,
   {{0x63a7010a,0x20d00441,0x212c0052,0xa0540120}},	//   _erjn, _dàin_, _pidh_, авлі,
   {{0x64554e56,0xb4260182,0x7e626848,0x4431029a}},	//   _gezi, _معزو, _sdop, _ggz_,
   {{0x26c29f6c,0xbf0f02e8,0x60c1877f,0x3eaf0085}},	//   _koko_, ातून_, _dolm, _bngt_,
   {{0x64550201,0x26c29f6d,0x332d0090,0x4431037a}},	//   _zezi, _joko_, _giex_, _zgz_,
   {{0x7ebc0018,0x26c29f6e,0x504607c8,0x64550060}},	//   _képz, _moko_, _безб, _yezi,
   {{0x26c29f6f,0x60c1042d,0x859700c1,0x9c7c13cf}},	//   _loko_, _golm, נדיג_, mičk,
   {{0x9c7c01d9,0xfaf901d3,0x9b431ac9,0xee860138}},	//   ličk, krīt_, ینیو, _было,
   {{0xbda6012b,0x26c200f3,0xdc3c043c,0xdfcf0037}},	//   _محتو, _noko_, mšči, _عين_,
   {{0x9c7c08a9,0x7bda297d,0xb5fb0af0,0x6d420051}},	//   ničk, sztu, _adán, _utoa,
   {{0x3aeb05aa,0xa2a602d5,0x752e02a1,0x39520178}},	//   _bòpè_, _घोस्, _nibz, _dwys_,
   {{0x64559f70,0x26c21114,0xdc3c02dd,0x9c7c005f}},	//   _rezi, _boko_, nšči, hičk,
   {{0x64559f71,0x26c20218,0xdc3c0141,0x00000000}},	//   _sezi, _coko_, išči, --,
   {{0xa3dd05d4,0x26c20139,0x64559f72,0xb5fb0065}},	// [b2f0] _तेज_, _doko_, _pezi, _edán,
   {{0xf53f1424,0x9c7c0074,0x2bb80b94,0xdc3c013f}},	//   _från_, dičk, इमपा, kšči,
   {{0x925902fd,0x26c201ff,0x5c37006e,0x60c1469d}},	//   вает_, _foko_, ארבן_, _rolm,
   {{0x9c7c0039,0x64550201,0x60c19f73,0x99480281}},	//   fičk, _wezi, _solm, _جلیل_,
   {{0x64559f74,0x60c19f75,0xb465001c,0x66d1004d}},	//   _tezi, _polm, _نگاه, _håko,
   {{0xe05700d0,0x656d9f76,0x3eaf02fa,0x236601d3}},	//   ایات_, mrah, _sngt_, ņoja_,
   {{0x442596c1,0xa3dd009d,0x60c16bc5,0x20540565}},	//   _àl_, _तेच_, _volm, стір,
   {{0x8c0a00c7,0x9c7c134c,0x8d651031,0x764d9f77}},	//   রধান_, bičk, авие, nbay,
   {{0x798d006c,0x60c19f78,0x9c7c0094,0x764d008c}},	//   _npaw, _tolm, cičk, ibay,
   {{0x660f1424,0x3b855566,0x656d061d,0xdc3c033b}},	//   _myck, алог, irah, bšči,
   {{0x660f0222,0x764d8a45,0x20d001f7,0x395202ac}},	//   _lyck, kbay, _màil_, _swys_,
   {{0x2023003d,0x656d9f79,0x3eaf25cc,0x00000000}},	//   ħriġ_, krah, _ungt_, --,
   {{0x660f0149,0x26c29f7a,0x656d0332,0x764d008c}},	//   _nyck, _roko_, jrah, dbay,
   {{0x6d4900ab,0x26c24545,0x4dda00ca,0x7c94008f}},	//   mpea, _soko_, _בחנו, _гръц,
   {{0x9c7c0335,0x26c206a3,0x6d493599,0xeb9900d3}},	//   zičk, _poko_, lpea, _рий_,
   {{0x764d8455,0xdce2009e,0xf65f041b,0x00000000}},	//   gbay, _ipoġ, _slær_, --,
   {{0x656d9f7b,0x6d499f7c,0xb53a0134,0x7afd708b}},	// [b300] grah, npea, ptọ́, érte,
   {{0x9c7c1b32,0x628902a6,0x2ed21efb,0x6d49033f}},	//   vičk, _abeo, _तत्त, ipea,
   {{0x26c21fb5,0x3dbd00c7,0xb4db05fe,0x656d9f7d}},	//   _toko_, েছিল, _itàl, arah,
   {{0x9c7c03ce,0x656d9f7e,0xdc3c0087,0xdce202a1}},	//   tičk, brah, všči, _mpoġ,
   {{0x6724003d,0xa3e60006,0x20d0009c,0x752e02a1}},	//   mmij, _बेर_, _fàil_, _tibz,
   {{0x273c1ba2,0x9c7c00e9,0x3f661f46,0x00000000}},	//   _kín_, ričk, атиб, --,
   {{0x9c7c6201,0x6d49033c,0x273c0139,0x2f010206}},	//   sičk, epea, _jín_, lógy_,
   {{0x273c0102,0xdc3c9f7f,0xbe8a0291,0x9c7c9f80}},	//   _mín_, ršči, тске_, miči,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x273c0072,0x672402ef,0xdc3c033b,0xafe60b9e}},	//   _oín_, hmij, pšči, _козл,
   {{0x764d2839,0x50b57892,0xa3d6294e,0x9c7c5695}},	//   ybay, _усту, िनि_, niči,
   {{0x67249f81,0x7b22020d,0x00000000,0x00000000}},	//   jmij, _sœur, --, --,
   {{0x2c06009d,0x00000000,0x00000000,0x00000000}},	//   _सुरू_, --, --, --,
   {{0x386d02e2,0xa3d64255,0x660f0212,0x66d1298b}},	//   ßer_, िना_, _ryck, _påko,
   {{0x386d0b88,0x9c7c031a,0x57a4001f,0x7d080537}},	//   ğer_, jiči, ошта, mods,
   {{0x656d2ee9,0xd6d809e4,0x9c7c0220,0x273c9f82}},	//   trah, ату_, diči, _dín_,
   {{0x764d4881,0x798d0060,0x84475f34,0x656d008c}},	// [b310] rbay, _upaw, لخال, urah,
   {{0xb89500e3,0x6724008a,0xe8730504,0x273c6a3e}},	//   _الدع, amij, _بندگ, _fín_,
   {{0x656d9f83,0x273c0065,0xb5fb00d2,0x00000000}},	//   srah, _gín_, _zdál, --,
   {{0x660f070a,0x236702dd,0x56943c75,0x6d499f84}},	//   _tyck, šnjo_, _дают, ypea,
   {{0x7d089f85,0xe1f0450f,0x00000000,0x00000000}},	//   kods, وسه_, --, --,
   {{0x66d8025b,0x00000000,0x00000000,0x00000000}},	//   _víke, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x77f80327,0x29f8020b,0x2ca950e7,0x00000000}},	//   ימוד_, ọai_, _şad_, --,
   {{0x41740037,0x6d49020d,0xdcfb9f86,0x00000000}},	//   _واكس, upea, stuč, --,
   {{0x2ba50b4b,0x6d49796c,0x66d12708,0x25ff0378}},	//   _pēc_, rpea, _såkl, _रखनी_,
   {{0x1fe50033,0xfaa6028d,0xe2171efb,0x66d117d2}},	//   _পুরস, бано, _तरुण_, _påkl,
   {{0x6d5d0072,0x6d4949fb,0xb4db01ec,0x44ff0033}},	//   ásas, ppea, _stàl, ্গিক_,
   {{0x273c16c5,0xdca58e34,0xfe7000cd,0x00000000}},	//   _sín_, _гали, _زدن_, --,
   {{0x7b3300ae,0x2eed34c0,0xbbe8001c,0x7d08008c}},	//   _băut, lief_, اریم_, cods,
   {{0xb8f007e2,0x7b33002d,0xdc120092,0xe9df037a}},	//   _शव_, _căut, _işğa, azú_,
   {{0x3ebf06ee,0x9c7c01b3,0x273c3ea2,0x2eed0063}},	//   njut_, viči, _vín_, nief_,
   {{0xe61a3974,0x67240ab2,0x998600e3,0xb5fb00b6}},	// [b320] уда_, rmij, _الخو, _udál,
   {{0x273c0019,0x67240ea3,0x2eed2128,0x9c7c830e}},	//   _tín_, smij, hief_, tiči,
   {{0x1d16006e,0xb386171b,0x00000000,0x00000000}},	//   צקער_, слел, --, --,
   {{0x9c7c7689,0x290a955f,0x68ee1a4a,0x2d8f02ac}},	//   riči, loba_, libd, _opge_,
   {{0x2eed01d0,0x00000000,0x00000000,0x00000000}},	//   dief_, --, --, --,
   {{0xa3d5007d,0x290a9f87,0x26c00106,0x66ca0146}},	//   ाईश_, noba_, ljio_, _výku,
   {{0x645e9f88,0x2d9d05aa,0x934600d3,0x00000000}},	//   mapi, _aswe_, _ынве, --,
   {{0x645e9f89,0x26c00106,0x26d20167,0xb3f700ca}},	//   lapi, njio_, nkyo_, _המלח_,
   {{0x7cd84e08,0x7d089f8a,0xb5fb0032,0xa3d60e28}},	//   имир_, tods, _adáj, िनव_,
   {{0x290a9f8b,0x645e7581,0x00000000,0x00000000}},	//   joba_, napi, --, --,
   {{0xdee60b91,0x290a06e9,0xac18083c,0x68ee00f9}},	//   _ложи, doba_, рону_, dibd,
   {{0x3f9e02e6,0x645e00bf,0xee3a04a1,0xf8d187bf}},	//   _istu_, hapi, _снд_, हस्प,
   {{0x645e4d9b,0x290a02ef,0x7d080094,0xff270504}},	//   kapi, foba_, pods, _ابلی,
   {{0x290a0517,0x645e9f8c,0x1bd472b0,0x7d7b006e}},	//   goba_, japi, _моля, _ענוו,
   {{0x368b0077,0x645e9928,0x67d48238,0xccf800b6}},	//   лсан_, dapi, пору, mně_,
   {{0xccf8000d,0xa3ac00aa,0xe3df0033,0x00000000}},	//   lně_, कटन_, _বুঝব, --,
   {{0x634501b3,0x290a6416,0xdcdc030b,0xfaf8001c}},	// [b330] _mėne, boba_, यसपछ, _دروغ_,
   {{0x645e7e8d,0x7aef9f8d,0x69cf1423,0x290a9f8e}},	//   gapi, lict, myce, coba_,
   {{0x43949f8f,0x163500c2,0x2d8400bc,0x00000000}},	//   захс, _меня, htme_, --,
   {{0x7aef045f,0xd0480092,0xdce96404,0x6f09002b}},	//   nict, _ildə, vreč, xoec,
   {{0x645e9f90,0xccf800b6,0x3f9e9f91,0x00000000}},	//   bapi, kně_, _astu_, --,
   {{0x661d0029,0xccf8030b,0x9fc9193d,0x2bcb0285}},	//   _izsk, jně_, игла_, ाहमा,
   {{0xccf8000d,0x2eed04ee,0x25a93d9c,0x3ebf007b}},	//   dně_, tief_, lval_, tjut_,
   {{0xee391b4d,0x290a6bbc,0x63b40146,0x66d80032}},	//   шни_, zoba_, šený, _kíka,
   {{0x7aef9f92,0x2eed04ee,0x25a90a9f,0xdce902dd}},	//   dict, rief_, nval_, sreč,
   {{0x2eed0ab2,0x2a691a47,0xdce967e3,0xab650870}},	//   sief_, _adab_, preč, овол,
   {{0x39492c09,0x66d80088,0xb4db0139,0xf53f05e8}},	//   _atas_, _líka, _atàk, _bråk_,
   {{0xeb960084,0x290a0193,0xc9aa001f,0x25a916cf}},	//   цию_, woba_, авме_, kval_,
   {{0x290a68ce,0xccf8030b,0x64580088,0x645e0aa9}},	//   toba_, bně_, ðvik, yapi,
   {{0x26d96c2c,0x6efe01d3,0xccf800b6,0x92d50033}},	//   _also_, mība, cně_, িচয়_,
   {{0x6efe00d9,0x68ee1a4a,0x645e9f93,0x39490154}},	//   lība, ribd, vapi, _etas_,
   {{0x7e7b9f94,0x290a9618,0x645e0051,0x25a91183}},	//   ngup, soba_, wapi, fval_,
   {{0x056602ec,0x6efe00d9,0xe45a1ada,0x54c600d3}},	// [b340] юван, nība, ижа_, обаб,
   {{0x6aa47e48,0xa3d51fe6,0xdb2100c2,0x7b34044c}},	//   _haif, ाईं_, ätök, _găur,
   {{0x6aa49f95,0x39849f96,0x00000000,0x00000000}},	//   _kaif, lös_, --, --,
   {{0x645e81eb,0x914a29db,0x41aa21fd,0xccf8030b}},	//   sapi, ачка_, ивен_, zně_,
   {{0x645e5cfe,0xccf8030b,0x398431b2,0x76449f97}},	//   papi, yně_, nös_, mciy,
   {{0x6aa41114,0x6efe00d9,0x8f3436bf,0x65640b8c}},	//   _laif, dība, пекц, msih,
   {{0xccf8000d,0x444400dc,0x645c00e8,0x00000000}},	//   vně_, mc_, _ieri, --,
   {{0x76449f98,0x4444968d,0xeeb84cc3,0x39840311}},	//   nciy, lc_, слиш_, kös_,
   {{0x016300b4,0x645c048e,0xccf8000d,0x44449f99}},	//   _окто, _keri, tně_, oc_,
   {{0x44449f9a,0x645c9f9b,0x00000000,0x00000000}},	//   nc_, _jeri, --, --,
   {{0x44449f9c,0x443892ad,0xccf8030b,0x20180088}},	//   ic_, _mgr_, rně_, _ári_,
   {{0xccf8030b,0x65649f9d,0x6aa42425,0xe8e100de}},	//   sně_, ksih, _caif, _đốt_,
   {{0x7e60048e,0x6efe0029,0xccf8030b,0x6aa40090}},	//   mamp, cība, pně_, _daif,
   {{0x645c360d,0x9c7c08a9,0x69cf009c,0x44440141}},	//   _neri, tiču, ryce, jc_,
   {{0x6aa40d2a,0x764401c2,0x25a901cb,0x7aef9f9e}},	//   _faif, fciy, wval_, pict,
   {{0x7e609f9f,0x645c9fa0,0x44449fa1,0x25a93927}},	//   namp, _aeri, ec_, tval_,
   {{0x645c9fa2,0x25a9659e,0x65645511,0x44449fa3}},	// [b350] _beri, uval_, gsih, fc_,
   {{0x645c06e1,0x25a9318e,0x63ae009c,0x2bae049d}},	//   _ceri, rval_, _brbn, टिपा,
   {{0x6efe00d9,0x44389fa4,0x66ca0094,0x27e60022}},	//   zība, _dgr_, _výkr, _ƙone_,
   {{0x44449fa5,0x76440044,0x7e600138,0xf7720266}},	//   ac_, cciy, jamp, _אקט_,
   {{0x27ff0390,0x661d0029,0x7aed9fa6,0x78a57651}},	//   ğunu_, _uzsk, _mmat, _kahv,
   {{0x645c9fa7,0x8505110a,0xb5fb00e3,0x44380149}},	//   _geri, _روزن, _ndái, _ggr_,
   {{0x765d0c56,0x64459fa8,0xd343110a,0x39840103}},	//   _kesy, mchi, _آفری, zös_,
   {{0x64459fa9,0x645c9faa,0x6efe00d9,0x7e609fab}},	//   lchi, _zeri, tība, gamp,
   {{0x645c0390,0x765d9fac,0x753506b0,0x201e01c8}},	//   _yeri, _mesy, _kizz, _ezti_,
   {{0x75350090,0x7aed9fad,0x6efe00d9,0x753d2627}},	//   _jizz, _amat, rība, _musz,
   {{0x64459fae,0x6efe0029,0x753d58c8,0x75359faf}},	//   ichi, sība, _lusz, _mizz,
   {{0x6efe01d3,0x7aed0072,0x6445033c,0x319d0383}},	//   lībn, _cmat, hchi, _kňz_,
   {{0xec6e0379,0x78a50113,0x64453a9d,0x7aed6c1a}},	//   _пп_, _bahv, kchi, _dmat,
   {{0x7aed02a7,0x75359fb0,0x17fa00e3,0xdca5107a}},	//   _emat, _nizz, مرأة_, _хаки,
   {{0x6aa49fb1,0x753d6389,0x61e26ca1,0x44380113}},	//   _taif, _ausz, zzol, _rgr_,
   {{0xaad0007d,0x3b070465,0x443801b5,0xa3e62397}},	//   _हकिक, _нещо_, _sgr_, _बेग_,
   {{0xa3de030b,0x44389fb2,0x765d0154,0x76449b42}},	// [b360] दैन_, _pgr_, _desy, rciy,
   {{0x6564005a,0x44449fb3,0x644504de,0x3f870542}},	//   rsih, uc_, gchi, ktnu_,
   {{0x44449ee3,0x75359fb4,0x645c9fb5,0x7aed02ad}},	//   rc_, _dizz, _veri, _ymat,
   {{0xd7bb004f,0x78a50335,0x44443d31,0x62993994}},	//   _הצטר, _zahv, sc_, gewo,
   {{0x60c85141,0x645c7c6b,0x7e603b1b,0xa9280138}},	//   _podm, _teri, vamp, pažį,
   {{0x64450465,0xb5fb0032,0x5f943340,0x9879015c}},	//   cchi, _adáw, дикт, ršću_,
   {{0x7e609fb6,0x61e20018,0x6d4b013f,0x6d597f49}},	//   tamp, szol, _atga, _awwa,
   {{0x75350172,0x6f040a9e,0xaa7b00d4,0x00000000}},	//   _zizz, čico, zhýb, --,
   {{0x7e600706,0xa06a38bc,0x6022033c,0xb4db01b5}},	//   ramp, _газа_, _bímí, _stài,
   {{0x7aed03ce,0x7e602d96,0xa0c900e3,0x8fa64f14}},	//   _smat, samp, _وذلك_, _назе,
   {{0xa3be04a9,0x78a50006,0x7e609fb7,0xa3d5023a}},	//   ेहि_, _rahv, pamp, ाईए_,
   {{0xdee32a61,0x00000000,0x00000000,0x00000000}},	//   _похи, --, --, --,
   {{0xf2d30130,0xf1be007d,0x765d0178,0x2d96004d}},	//   גער_, ्हिन, _resy, _хрес,
   {{0x23670106,0x3d140b89,0x765d9fb8,0x629900a5}},	//   šnji_, _नीचे_, _sesy, zewo,
   {{0x78a50fc4,0x75359fb9,0x9c7c0146,0x22460167}},	//   _vahv, _rizz, sičs, kcok_,
   {{0xabfb0054,0x7aed9fba,0x753d663b,0xf1be0961}},	//   _להור, _umat, _pusz, ्हान,
   {{0x644500ca,0x78a58ab6,0x75359fbb,0x65940219}},	// [b370] tchi, _tahv, _pizz, нату,
   {{0x3ea607ac,0xda07001c,0xf8d100b6,0x00000000}},	//   _laot_, _ويژه_, _सकिय, --,
   {{0x629914d0,0x7afd04dc,0x753502a1,0x64459fbc}},	//   tewo, onst, _vizz, rchi,
   {{0x753d9fbd,0x7afd0bd8,0x64454779,0xdb0401df}},	//   _tusz, nnst, schi, _ernæ,
   {{0x62999fbe,0x7afd0d87,0x64459fbf,0x75350dda}},	//   rewo, inst, pchi, _tizz,
   {{0x66d80088,0x7afd28c1,0xb4db00b3,0x6d590027}},	//   _líkl, hnst, _quàd, _rwwa,
   {{0xb4fb0557,0xdb240103,0x29010090,0xdce200d8}},	//   ्वीप_, őség, _mjha_, _cvoč,
   {{0x24bf00c7,0xdd9106f6,0x3f870542,0x7afd01c0}},	//   _ইতিহ, نوع_, rtnu_, jnst,
   {{0x3f879fc0,0xfce519cb,0x26cb00d1,0x290102ef}},	//   stnu_, допо, _moco_, _ojha_,
   {{0xd1310979,0x7afd9fc1,0x26cb9fc2,0xdb1b0094}},	//   _شما_, enst, _loco_, rytý,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc8690054,0x29010167,0x7afd0596,0x673e01d3}},	//   _כן_, _ajha_, gnst, _rupj,
   {{0xdce20087,0x6d4b00d6,0xad880781,0x673e00c6}},	//   _zvoč, _utga, _فضول_, _supj,
   {{0x225f0505,0x7afd9fc3,0x7c8700c2,0xe73a0e3a}},	//   _leuk_, anst, _худе, жев_,
   {{0xaa7b00d2,0x00000000,0x00000000,0x00000000}},	//   uhýc, --, --, --,
   {{0x2ca7019e,0x225f9fc4,0x4ae2058f,0x26cb8537}},	//   _hand_, _neuk_, _पतिव, _coco_,
   {{0x090659b2,0x2ca748b8,0x213f0350,0x6124015e}},	// [b380] _опин, _kand_, _nuuh_, lòle,
   {{0xb4e800aa,0x00000000,0x00000000,0x00000000}},	//   यफे_, --, --, --,
   {{0x39401d19,0x2ca701c5,0x26cb44c2,0xe9df034f}},	//   _huis_, _mand_, _foco_, ncún_,
   {{0x2ca79fc5,0x26cb0307,0x2d9f0134,0xab620342}},	//   _land_, _goco_, kwue_, _şükr,
   {{0x61435bb2,0xa1580084,0x39400185,0xddc20031}},	//   веча, чалу_, _juis_, _odoš,
   {{0x39409fc6,0x2a602169,0x213f0066,0x224601c8}},	//   _muis_, _leib_, _duuh_, scok_,
   {{0xdb020146,0x7afd698a,0xa3e61784,0x3940202c}},	//   zvlá, ynst, _बेच_, _luis_,
   {{0x2ca70185,0x225f0634,0x93260286,0xbd6a007b}},	//   _aand_, _geuk_, _آرسن, орое_,
   {{0x25a0128c,0x2ca7157a,0x20d0009c,0x7afd0ac1}},	//   nwil_, _band_, _bàit_, vnst,
   {{0x2ca70012,0x225f01e9,0x20d001ec,0x3b54268e}},	//   _cand_, _zeuk_, _càit_, нкор,
   {{0xb5fb0094,0xc4770327,0x2ca79fc7,0xbbb8023a}},	//   _udáv, ותיו_, _dand_, इमेक,
   {{0xf9e70081,0x25a03b99,0x3940319e,0x2bac00b6}},	//   _গুগল_, kwil_, _buis_, _věc_,
   {{0x2ca723a8,0xc984002d,0xb5fb0037,0x394001f7}},	//   _fand_, кури, _meác, _cuis_,
   {{0x6e229fc8,0x39409fc9,0xa80301e8,0x26cb9fca}},	//   _izob, _duis_, _çıkm, _soco_,
   {{0x26cb9fcb,0x61240428,0x5ba30077,0x27e60022}},	//   _poco_, còle, _арыз, _ƙona_,
   {{0x2ca701c0,0x56942290,0x2bcb023a,0xfa90020b}},	//   _zand_, каст, ाहरा, _hẫng_,
   {{0x225f0313,0xdbde0072,0x66d8003e,0x44b51aad}},	// [b390] _reuk_, míña, _kíkj, нбас,
   {{0x2edb143d,0xdb0401bf,0x65150182,0xd1380034}},	//   _बत्त, _ernä, روائ, _nią_,
   {{0x68f50702,0x26cb0850,0x69120537,0xd3410103}},	//   mizd, _toco_, pæer, اہری,
   {{0x291170f6,0x6e220415,0x00000000,0x00000000}},	//   loza_, _ozob, --, --,
   {{0x6e220079,0x20d0009c,0x00000000,0x00000000}},	//   _nzob, _nàis_, --, --,
   {{0x68f503a3,0x29119fcc,0x64580088,0x672d9fcd}},	//   nizd, noza_, ðvit, lmaj,
   {{0x386102d6,0x2ca79fce,0x225f0da7,0x6e226b52}},	//   _mehr_, _rand_, _teuk_, _azob,
   {{0xfaff074a,0xf838004f,0x7b162ad4,0x29110198}},	//   jnë_, ונות_, náut, hoza_,
   {{0x29111a05,0x2ca701c0,0x6f02009e,0xf53f17d2}},	//   koza_, _pand_, _djoc, _gråt_,
   {{0x236703ce,0x39409fcf,0x672d3846,0x6f02078e}},	//   šnju_, _ruis_, hmaj, _ejoc,
   {{0x394004ea,0x2ca79fd0,0xa3d513ae,0x2b4e00ee}},	//   _suis_, _vand_, ाईट_, _ctfc_,
   {{0x3940025a,0x2ca70691,0x672d007e,0xfe7001dc}},	//   _puis_, _wand_, jmaj, _نده_,
   {{0x3940001f,0x672d00e7,0x634c0233,0xe9df00b3}},	//   _quis_, dmaj, _iğne, scún_,
   {{0x29119fd1,0xdca20360,0x65760313,0x6f0200c4}},	//   goza_, _баши, vryh, _zjoc,
   {{0x6f020113,0xc5cd0033,0x00000000,0x00000000}},	//   _yjoc, _রেলপ, --, --,
   {{0x39400185,0x6f1b9fd2,0x63a20034,0xab27008f}},	//   _tuis_, nluc, łonk, _поща_,
   {{0xe6e0000f,0x291118b1,0xb5fb0037,0x6f1b037a}},	// [b3a0] _नतीज, boza_, _reác, iluc,
   {{0x25a01d06,0x6f1b1e76,0x20d001ec,0xb5fb9fd3}},	//   rwil_, hluc, _làir_, _adás,
   {{0x25a03155,0x6f1b9fd4,0x6576007b,0x00000000}},	//   swil_, kluc, sryh, --,
   {{0xbee90f35,0xc7b30327,0x016630da,0x20d0009c}},	//   टफोन_, _עבר_, екдо, _nàir_,
   {{0xc69300c1,0x6f1b0044,0xfd480139,0xd138007f}},	//   _גאר_, dluc, _damọ, _pią_,
   {{0x6aa900c7,0x64430220,0x7f4112e3,0x00000000}},	//   গাযো, ľnic, _bulq, --,
   {{0x64437d30,0x6e220018,0x20d001b9,0xfd480065}},	//   žnic, _szob, _bàir_, _famọ,
   {{0x29119fd5,0x20d001b9,0x7f410188,0x238902c6}},	//   zoza_, _càir_, _dulq, žují_,
   {{0x569b0054,0xdce000e8,0x3d0c00b6,0xfe6f0076}},	//   ליקצ, esmā, ठकले_, حدى_,
   {{0x672d007e,0xa5bb00d4,0x00000000,0x00000000}},	//   zmaj, _ozón, --, --,
   {{0x291100cb,0x6f020149,0x68f51820,0xdbde0072}},	//   voza_, _tjoc, vizd, tíña,
   {{0x386102dc,0x62820517,0x20d001b9,0x6fcd00b6}},	//   _sehr_, ngoo, _gàir_, तहरू,
   {{0xaca40174,0x29110384,0x4dd3097d,0xba3b0428}},	//   _arụz, toza_, _متوس, veïd,
   {{0x52dd1efb,0xddc90094,0xba3b02ac,0x00000000}},	//   _मत्स, dceň, deïe, --,
   {{0xd6db33d0,0x672d9fd6,0x69c0007b,0x00000000}},	//   пта_, tmaj, ämer, --,
   {{0xf5e70c10,0x6d420a4b,0xe8d90d79,0x68f59fd7}},	//   нізм, _kuoa, _iwọ_, sizd,
   {{0x672d5eb4,0xb5fb0af0,0x68f50ebd,0x386100dc}},	// [b3b0] rmaj, _adár, pizd, _tehr_,
   {{0x672d9fd8,0x9964008f,0x6d420350,0xba3b00b3}},	//   smaj, _стъл, _muoa, reïd,
   {{0xdcfb0335,0xd2510192,0x7ce401ec,0x00000000}},	//   stuć, لنا_, _iòrd, --,
   {{0x7e620542,0x62827a7b,0xb6030206,0xe8d1074c}},	//   _neop, ggoo, tláč, _सकुच,
   {{0x6f1b80ab,0x5eef0034,0x00000000,0x00000000}},	//   vluc, इफस्_, --, --,
   {{0x26c908a9,0x7f419fd9,0x20d0009c,0xf0750103}},	//   ljao_, _pulq, _sàir_, ئیاں_,
   {{0x7e620307,0xbea5008f,0xc4d200ca,0x7f41008c}},	//   _beop, вайк, _דגם_, _qulq,
   {{0x26c904a3,0x53344c88,0x00000000,0x00000000}},	//   njao_, _бест, --, --,
   {{0xe8d9026e,0x7e6200ae,0x00000000,0x00000000}},	//   _awọ_, _deop, --, --,
   {{0x6f1b054f,0xdbde003e,0x7ce4015e,0x00000000}},	//   sluc, tíða, _nòrd, --,
   {{0x3b0a1c0e,0x5e950037,0x2d9800ae,0xef740281}},	//   дено_, _للاط, ărea_, _مدنظ,
   {{0x7e629fda,0x63b50580,0xf41200a1,0xdce9005f}},	//   _geop, _mrzn, שפט_, kreć,
   {{0x4e7800e3,0x26c90e94,0x7ce401b9,0xdbde04c8}},	//   _أحمد_, djao_, _bòrd, síða,
   {{0x3ead5c05,0x8c42007e,0xa3e112f4,0x7ce40441}},	//   ldet_, _кеше, धना_, _còrd,
   {{0xb90a04a9,0x628231ed,0xa6db01ab,0x00000000}},	//   _मत_, ygoo, _miðf, --,
   {{0x3ead21ad,0xfd620294,0x7e624d86,0xc5f401c2}},	//   ndet_, _netị, _xeop, zaɓu_,
   {{0x3ead9fdb,0x66d101df,0x63b50364,0xba3b0313}},	// [b3c0] idet_, _påkr, _arzn, teïe,
   {{0xe8f7141b,0xb97b040a,0x3ead00c2,0x7ce401f7}},	//   _аль_, _קניי, hdet_, _gòrd,
   {{0x316d025a,0x64a3539a,0x187700a1,0x2d8d00c2}},	//   _avez_, раха, _בעיר_, htee_,
   {{0x3ead01c5,0xdb0400b3,0x63b50117,0x2bc20469}},	//   jdet_, _arnú, _drzn, षमता,
   {{0x6443013f,0x62829fdc,0x3ead9fdd,0x00000000}},	//   žnia, rgoo, ddet_, --,
   {{0xc95300a1,0x224d36ac,0xdce20220,0x6d4200c2}},	//   סמו_, _efek_, _spoľ, _ruoa,
   {{0x7e629fde,0x741600cd,0x673b2347,0x644e01ee}},	//   _peop, _شورا, ňuje, _ifbi,
   {{0x753c00e7,0xb5fb0037,0x3ead9fdf,0x717600d1}},	//   _hirz, _meán, gdet_, _لهرا,
   {{0x80c2262c,0x9d145c24,0x6d420227,0xb5fb01f9}},	//   लादे, лдич, _quoa, _leán,
   {{0x9b580303,0x8f76004d,0xfba800ae,0x00000000}},	//   ниот_, _ауді, еӂий_, --,
   {{0x753c9fe0,0x2d8d008a,0x395200b3,0x547b0796}},	//   _mirz, atee_, _atys_, וטיו,
   {{0xb4df0bf5,0xbe850037,0xf41300ca,0x50f2074c}},	//   _तत्_, _مجهو, יפת_, _अगुआ_,
   {{0x7e7d10d9,0xba3b00b3,0xcd06007e,0x00000000}},	//   óspe, deïc, _ички, --,
   {{0xab62013c,0xdce600e8,0x00000000,0x00000000}},	//   _şüur, ēmēj, --, --,
   {{0x09cb00c7,0xb5fb002b,0xd7f800c2,0x9c7c00d4}},	//   _লেখা, _adáp, вут_, lhčo,
   {{0xdce0013f,0xdce914f3,0xb5fb0503,0x644e4fb5}},	//   tumė, treć, _deán, _afbi,
   {{0x753c9fe1,0xa5f8562b,0x00000000,0x00000000}},	// [b3d0] _birz, вету_, --, --,
   {{0xfd620174,0x798d02a1,0x6aad0381,0x00000000}},	//   _setị, _iqaw, _haaf, --,
   {{0xdce902e6,0x29030039,0x3ead9fe2,0x6aad008c}},	//   sreć, mnja_, ydet_, _kaaf,
   {{0x6aad00dc,0xdce90095,0x3ae20032,0xa6db01cd}},	//   _jaaf, preć, _kópa_, _siðf,
   {{0x6aad9fe3,0x644e00e7,0x667a00ca,0x3ead01ce}},	//   _maaf, _ffbi, _אטרק, vdet_,
   {{0x66d80102,0x89dc00a1,0x656d9fe4,0x6aad041c}},	//   _ríki, וחדי, msah, _laaf,
   {{0xd347001c,0xa6db01cd,0x661d9fe5,0x93881009}},	//   _شیشه_, _viðf, _hysk, _иста_,
   {{0x29036559,0x63b802b6,0x6aad9fe6,0x2d8d00ca}},	//   hnja_, ævne, _naaf, ttee_,
   {{0x3ead34cb,0x656d1d11,0x798d023e,0x673d052e}},	//   rdet_, nsah, _nqaw, _misj,
   {{0x66d8003e,0x656d9fe7,0x2d8d66f4,0x91bf020b}},	//   _víki, isah, rtee_, _ngủ_,
   {{0xa5bb0018,0x9f55215f,0x2d8d900f,0x6aad554f}},	//   _szól, _свеч, stee_, _baaf,
   {{0xa5bb0068,0x6aad008a,0x673d079f,0xaf210a43}},	//   _gyóg, _caaf, _nisj, _পূরণ_,
   {{0x6dc40f36,0x661d0073,0x6aad0188,0xaa7b00d4}},	//   _نزول, _nysk, _daaf, chým,
   {{0xd9430012,0x290300c4,0x9409013c,0xa3b600e2}},	//   сери, gnja_, şkən_, जिम_,
   {{0x66e6064f,0x1cb833ce,0x6aad0188,0x656f033c}},	//   гова, _جانب_, _faaf, _avch,
   {{0x6aad0b6e,0x661d09a3,0xb4db9fe8,0x273b0134}},	//   _gaaf, _bysk, _quàn, ụnne_,
   {{0x2bcb04dd,0x29039fe9,0x7ae46c33,0x656d9fea}},	// [b3e0] ाहका, bnja_, _ilit, gsah,
   {{0x661d00a5,0xe6171c03,0x2903015c,0x5fb30442}},	//   _dysk, уду_, cnja_, ंटाल,
   {{0x2b4f00d3,0x656d00a6,0x753c00d9,0x291a0134}},	//   _încă_, asah, _virz, _ikpa_,
   {{0x55e60058,0x6aad008a,0x656d9653,0x6efe01d3}},	//   _бомб, _xaaf, bsah, lībv,
   {{0x7ae49fc9,0x6b819feb,0x753c9fec,0x6fb80386}},	//   _mlit, hulg, _tirz, ्मभू,
   {{0x7ae45c8e,0x7ce401b9,0x673d0062,0x386a00c4}},	//   _llit, _mòrc, _zisj, nabr_,
   {{0xfbc73345,0x248a01af,0x7ae49fed,0x291a06c0}},	//   _ات_, _icbm_, _olit, _mkpa_,
   {{0xa6db01cd,0x290308a9,0x7ae403a9,0x62890076}},	//   _viðg, znja_, _nlit, _gceo,
   {{0xa2062565,0x386a0d5f,0xf1a9001c,0x290301cd}},	//   _спад, kabr_, _لاله_, ynja_,
   {{0x7ae49302,0x764d9fee,0x291a0294,0x90d500de}},	//   _alit, zcay, _nkpa_, _hìn,
   {{0x7ae44896,0x290316a2,0x656d025b,0x28c30789}},	//   _blit, vnja_, zsah, शासि,
   {{0x291a00ac,0xb5fb0018,0xf4260033,0xd4370142}},	//   _akpa_, _beál, _বলার_, טריק_,
   {{0x90d500de,0x7ce4009c,0x7ae40076,0x8d562cad}},	//   _mìn, _còrc, _dlit, _стеч,
   {{0x6aad74c5,0x661d9fef,0x6b819ff0,0x7ae44e6d}},	//   _waaf, _rysk, bulg, _elit,
   {{0x7ae49ff1,0x661d05e8,0x76520134,0x66d8003e}},	//   _flit, _sysk, _ọkọw, _líku,
   {{0x656d0a69,0x29030b18,0xdce001d3,0x213e0113}},	//   tsah, snja_, kumī, _lith_,
   {{0x764d0496,0x290375ba,0x656d79fc,0xa3e70034}},	// [b3f0] rcay, pnja_, usah, मैन_,
   {{0x656d005a,0x661d597e,0x764d46c3,0xe816009d}},	//   rsah, _vysk, scay, _दुवा_,
   {{0x569501b3,0x7ae400c2,0x90d50023,0x656d9ff2}},	//   _кант, _ylit, _bìn, ssah,
   {{0x661d16f4,0x98b300d3,0xbd050139,0x213e9ff3}},	//   _tysk, _fixă_, _amẹ́, _aith_,
   {{0xe1350138,0x213e003b,0x201e0383,0xd6d800d3}},	//   анды, _bith_, _ayti_, _стэ_,
   {{0x6ae20851,0xdddb09ac,0x3a2901ff,0x7bda16c0}},	//   _पत्र, jguš, _mzap_, kytu,
   {{0x213e01ec,0x6b810072,0x2e4e026e,0xa3d50565}},	//   _dith_, xulg, _jọwọ_, _товч,
   {{0x6b81016d,0x2d952813,0xfe450396,0x201e0052}},	//   vulg, арос, шнио, _dyti_,
   {{0x386a0d5f,0x608700e3,0x51870215,0x201e0139}},	//   yabr_, _مشاك, _љуба, _eyti_,
   {{0xb5fb2299,0x7ae4502c,0xee360fe9,0x6b8125cb}},	//   _reál, _slit, шны_, tulg,
   {{0x9b0624ec,0xa6db003e,0x66d801cd,0x00000000}},	//   изод, _miðb, _kíkt, --,
   {{0x4e190084,0xf1b90559,0x7ce400ee,0xde59004d}},	//   _июля_, _krš_, _pòrc, _раді_,
   {{0xd94628d4,0x7ae405db,0x00000000,0x00000000}},	//   реги, _vlit, --, --,
   {{0xcc8900bf,0x271e0d88,0x2e4e0065,0x9d520037}},	//   _شنبه_, पत्र_, _bọwọ_, _بنوت,
   {{0x46f62b69,0xbebd2c2e,0x25e80fef,0x7bda0034}},	//   ачат, plūd, चैनी_, cytu,
   {{0xfd4c0019,0x29d80220,0x7ae49ff4,0x3eaf052f}},	//   _nhiễ, eľať_, _ulit, _jagt_,

   {{0xe737160b,0xb46691e5,0x3eaf02b6,0x9420013c}},	// [b400] рет_, икал, _magt_, əsən_,
   {{0x3eaf9ff5,0x25bf71f1,0x2e4e0065,0xd9101aaa}},	//   _lagt_, _šulc_, _fọwọ_, _ریز_,
   {{0x213e00e3,0xf1b900e7,0x287b0796,0xa87b00ca}},	//   _rith_, _arš_, _בנימ, _באיר,
   {{0x291848fb,0xeb960130,0x213e01ec,0x68fc07aa}},	//   lora_, ידער_, _sith_, lird,
   {{0x332d0694,0x80c21792,0xaa7b02c6,0x7bda007f}},	//   _dhex_, लाले, lkýc, zytu,
   {{0x68fc0555,0xa87a006e,0xa6db01cd,0x79b700ca}},	//   nird, דאַר, _viðe, ילנד_,
   {{0xa3ba0006,0x7ee62922,0x2d9d05aa,0x90d50023}},	//   _अछि_, ицие, _apwe_, _tìn,
   {{0x213e1723,0x29189ff6,0x68fc0230,0x442a0031}},	//   _with_, hora_, hird, _izb_,
   {{0x29187a5b,0x68fc008b,0xaa7b0094,0x91e32e98}},	//   kora_, kird, hkýc, _доте,
   {{0x29189c7a,0x14c90569,0x7bda52eb,0xa3ba009f}},	//   jora_, रायण, tytu, _अछा_,
   {{0x26c202fd,0x68fc0491,0xa113010d,0x7ce40441}},	//   _onko_, dird, _بولت, _còra,
   {{0x7ce401ec,0xc4d30caf,0x3f9e016d,0x7bda1c8a}},	//   _dòra, _दक्ख, _iptu_, rytu,
   {{0x41c6007f,0x00000000,0x00000000,0x00000000}},	//   लमिस, --, --, --,
   {{0x26c206a3,0x68fc9ff7,0x3a2006a8,0x2d849ff8}},	//   _anko_, gird, _dyip_, mume_,
   {{0xbb8418a9,0x7ce401ec,0x442a2143,0xdcfb0342}},	//   _العي, _gòra, _nzb_, ltuğ,
   {{0x68fc009c,0x00000000,0x00000000,0x00000000}},	//   aird, --, --, --,
   {{0x7afd2b61,0x29189ff9,0x2d849ffa,0xb99500e3}},	// [b410] mist, bora_, nume_, _الخب,
   {{0x29189ffb,0x26c29ffc,0x69dd9ffd,0xf99200d7}},	//   cora_, _enko_, myse, _צרי_,
   {{0xaa7b0871,0x69dd17d2,0x394901fa,0xa6db0088}},	//   ckýc, lyse, _huas_, _viðb,
   {{0x39499ffe,0x2d849fff,0x7b1d04d8,0xb062007b}},	//   _kuas_, kume_, céut, äänk,
   {{0x2d846826,0xf1a70cd1,0x442a7b2d,0x3949309e}},	//   jume_, ррен, _ezb_, _juas_,
   {{0x3eaf5732,0x3949006c,0x2d84a000,0xd0091491}},	//   _sagt_, _muas_, dume_, леле_,
   {{0x7afda001,0x3949a002,0xc446010d,0x2ee6022b}},	//   kist, _luas_, _ایمن_, _blof_,
   {{0x7afd7c1f,0xf1b900e7,0x68fc50e7,0x63055f34}},	//   jist, _trš_, zird, _اورل,
   {{0x7afd2508,0x39490013,0x25a907ae,0x2d84a003}},	//   dist, _nuas_, nwal_, gume_,
   {{0x50db0b7f,0x7afd086f,0x2b47a004,0xba3ba005}},	//   _भविष, eist, _punc_, teïn,
   {{0x291808a9,0xa3d7007d,0x7a6a1e11,0x68fca006}},	//   vora_, िहि_, линг_, vird,
   {{0x39490808,0x2ee60124,0x7b1d0072,0x25a90022}},	//   _buas_, _glof_, déus, kwal_,
   {{0x39491d07,0x68fc03a3,0x2d84002b,0x8c452ca4}},	//   _cuas_, tird, cume_, _леле,
   {{0x644302e6,0x6d5b10e3,0x3949a007,0xaa7b0181}},	//   žnij, mpua, _duas_, tkýc,
   {{0x7afda008,0x2918a009,0x2ca55dc0,0x5eaa00c7}},	//   bist, rora_, meld_, কারে,
   {{0x68fca00a,0x5b7a0266,0x394901b9,0x69dd3177}},	//   sird, _ערפא, _fuas_, byse,
   {{0xf50a455b,0xaa7b0363,0x70b7030b,0xceb2006e}},	// [b420] гнал_, skýc, _आफूल, הין_,
   {{0x77ca0cf5,0xf48400cd,0x68fc00bd,0x8886193d}},	//   _блог_, تاری, qird, _улож,
   {{0x493b0054,0x7b1d0610,0x3ce701ff,0xf7720037}},	//   _תגיו, péut, _mlnv_, _عاد_,
   {{0x6d5b02e7,0x2ca5a00b,0x394901fa,0xa29400d6}},	//   kpua, held_, _yuas_, іалі,
   {{0x2ca5a00c,0x6724a00d,0x3949006c,0x3636001c}},	//   keld_, mlij, _xuas_, _دردس,
   {{0x7afda00e,0x836a00cd,0x3d1100a5,0x9fa2003e}},	//   zist, _مصرف_, ठकों_, _bíða_,
   {{0x22490ca7,0x442a0113,0x8f342753,0x7986a00f}},	//   žaka_, _uzb_, оекц, hukw,
   {{0x7afda010,0x2d84a011,0x67240ab2,0x79862712}},	//   xist, tume_, nlij, kukw,
   {{0x6724512c,0x2ca501bf,0x6d5b00a6,0x3ea49a92}},	//   ilij, feld_, gpua, remt_,
   {{0x3949a012,0x7afda013,0x2d8416dc,0x2ca53b6c}},	//   _ruas_, wist, rume_, geld_,
   {{0xa3e804a9,0x3949a014,0x2a690006,0x2d84436f}},	//   यनि_, _suas_, _peab_, sume_,
   {{0x394901bb,0x67242cea,0x798605a0,0x612d0088}},	//   _puas_, jlij, fukw, rúle,
   {{0x394901fa,0x672400cc,0x2ca501c0,0xa6db0653}},	//   _quas_, dlij, beld_, _niða,
   {{0x7afda015,0x3949023e,0x69dd02ac,0x6e221937}},	//   sist, _vuas_, ryse, _iyob,
   {{0x7afd395e,0x6443011d,0x7d1aa016,0x25a9205f}},	//   pist, žnik, mots, wwal_,
   {{0x3949a017,0xaae70dd0,0x25a97447,0x6724a018}},	//   _tuas_, _دستو, twal_, glij,
   {{0xf8ae010d,0xb8ef0033,0x84470037,0x55550103}},	// [b430] رکی_, _শত_, مخال, زپار,
   {{0xfaff0305,0xf9900037,0x6e222ad8,0x7d1a8ba9}},	//   lië_, _أبي_, _myob, nots,
   {{0x6724a019,0xb5fb0037,0x25a91ef8,0x69ce00ae}},	//   blij, _meái, swal_, ăieş,
   {{0x63ae005c,0xfaff04e2,0x7d1aa01a,0x2bb00179}},	//   _dsbn, nië_, hots, _जनना,
   {{0xdd861fa7,0x6e2204da,0x9fa20088,0x7d1aa01b}},	//   _تو_, _nyob, _síða_, kots,
   {{0x7bc50088,0xa3b6000f,0x7ce4009c,0x4f7900e5}},	//   _áhug, जिश_, _sòrn, ащия_,
   {{0x2ca5370f,0xdb0b10d9,0xe3b302a3,0x6e221937}},	//   veld_, _esfé, _عرس_, _ayob,
   {{0x2ca54e4c,0xa3b61757,0x6e223683,0x9fa2003e}},	//   weld_, जिर_, _byob, _víða_,
   {{0x2ca55d1e,0xfaff1507,0x6d5b07ac,0x6e220169}},	//   teld_, dië_, upua, _cyob,
   {{0x6d5b1a47,0x67240357,0x7d1aa01c,0x7ced00b3}},	//   rpua, zlij, gots, _múrg,
   {{0x2ca50db8,0xeb9911b6,0x7ce4009c,0x7ced00ee}},	//   reld_, шин_, _eòro, _lúrg,
   {{0x628b2d0b,0x3f87a01d,0x6d5b007b,0x20c70096}},	//   nggo, munu_, ppua, लावध,
   {{0x7d1aa01e,0x3f8707aa,0xec6e0bd0,0x6f1b00b6}},	//   bots, lunu_, _оп_, mouc,
   {{0x6d599e28,0x6447023b,0x6f090231,0x79860dd5}},	//   _itwa, _ngji, lnec, rukw,
   {{0xb902007d,0x67246279,0xfaff0185,0x3f873253}},	//   _दव_, tlij, bië_, nunu_,
   {{0x6d43a01f,0x6f0904e4,0x6d4b5fa6,0x7c3e18ed}},	//   _hina, nnec, _kuga, _úpra,
   {{0x6d43434b,0x67240505,0x6d4ba020,0x2e4e0294}},	// [b440] _kina, rlij, _juga, _kọrọ_,
   {{0x67240480,0x6d4ba021,0x6d43a022,0x3f87a023}},	//   slij, _muga, _jina, kunu_,
   {{0x6d4ba024,0x6d434d82,0x672400cc,0x389b00c1}},	//   _luga, _mina, plij, _דיינ,
   {{0xe29a5dbe,0xdcfb20e4,0xd250300d,0x6d43a025}},	//   рад_, druč, رنت_, _lina,
   {{0x6d4302a7,0x6f1b030b,0x6d4ba026,0xa5bb0018}},	//   _oina, douc, _nuga, _szóv,
   {{0x6d43a027,0xfbc91843,0x2e4e0129,0x99bb006e}},	//   _nina, िमाम, _nọrọ_, יזנט,
   {{0x6d593304,0x6d4ba028,0xa6db01cd,0x7ce4009c}},	//   _atwa, _auga, _miðn, _dòrl,
   {{0x6d4b0a37,0x6d43a029,0x644700dd,0xdce908c5}},	//   _buga, _aina, _zgji, dređ,
   {{0x6d4b99b4,0x6d43a02a,0x7d1aa02b,0x2e4e0294}},	//   _cuga, _bina, tots, _sọsọ_,
   {{0x6d4b11b9,0x6d43a02c,0x3326003d,0x7d080364}},	//   _duga, _cina, llox_, unds,
   {{0x6d5902dc,0x2e4e0134,0x6d4ba02d,0x7d1aa02e}},	//   _etwa, _dọrọ_, _euga, rots,
   {{0x2eeda02f,0x6d4323ff,0x6f1b00fd,0x7d1aa030}},	//   chef_, _eina, couc, sots,
   {{0xfaff0a9f,0x6d4ba031,0x2e4e0134,0x80ad0033}},	//   rië_, _guga, _fọrọ_, চার্,
   {{0x6d430f4f,0xfaff6c68,0x6f00a032,0x00000000}},	//   _gina, sië_, limc, --,
   {{0x466b02b3,0x6d4b6e11,0x7c2300f0,0x332601ff}},	//   ирам_, _zuga, _gynr, klox_,
   {{0x6d435fa7,0x6d4ba033,0x290a0188,0x6f00a034}},	//   _zina, _yuga, anba_, nimc,
   {{0x344b2383,0x3f87071d,0x6b880537,0x00000000}},	// [b450] ачен_, zunu_, ludg, --,
   {{0x6f000044,0xb9a40018,0x612d0653,0xe9df03a4}},	//   himc, _کمیٹ, kúla, scús_,
   {{0x141900e3,0xa5bb0103,0x612400ee,0x6f000350}},	//   حياة_, _azót, còli, kimc,
   {{0x9948110a,0x00000000,0x00000000,0x00000000}},	//   _دلیل_, --, --, --,
   {{0x6f00015c,0x6f1b02c6,0xdce90095,0x7e6b02ac}},	//   dimc, vouc, zređ, _regp,
   {{0x6d4ba035,0x463a0341,0xe4a4007e,0x7ced0220}},	//   _ruga, _לערע, _орсо, _kúre,
   {{0x6d43a036,0x2e4e0174,0x6d4ba037,0x612d002b}},	//   _rina, _rọrọ_, _suga, gúla,
   {{0x6d43a038,0xdce90291,0x6d4ba039,0x3f871f14}},	//   _sina, vređ, _puga, runu_,
   {{0x6f09a03a,0x6d433066,0xddcb00d9,0x3f8703a3}},	//   rnec, _pina, _iegū, sunu_,
   {{0xa3df5516,0x6f1ba03b,0x6d4ba03c,0x6f09a03d}},	//   _तथा_, souc, _vuga, snec,
   {{0x6d43a03e,0x6f0002e6,0xf989006e,0xdce90fa3}},	//   _vina, bimc, _תר_, uređ,
   {{0x26d90933,0x6d4ba03f,0x6d43a040,0xfeb808ba}},	//   _noso_, _tuga, _wina, _وانت_,
   {{0x6d430f4f,0x6d596b00,0xdc3c00d9,0x6d4b66f9}},	//   _tina, _utwa, kšķi, _uuga,
   {{0xdce91100,0xe8e100de,0x612405fe,0x6b88a041}},	//   pređ, _đợt_, tòli, budg,
   {{0x26d9a042,0xb8e4000c,0xe81f007a,0x3f7700ae}},	//   _boso_, _एफ_, _मुदा_, nău_,
   {{0x9c7c0363,0x3f510019,0x2bb0030b,0x26d984cc}},	//   nkčn, _máu_, _जनता, _coso_,
   {{0xe5a33f9c,0xb062007b,0x6124015e,0x00000000}},	// [b460] нити, ääkk, sòli, --,
   {{0xe5230e58,0x6ab60f20,0x5fbd063c,0x644900a7}},	//   едуп, _hayf, ्माल, _şeir,
   {{0xa5bb0103,0x68e176c1,0x26d9a043,0x00000000}},	//   _szót, ölde, _foso_, --,
   {{0x7d010ac9,0x8b560142,0x6f00020b,0x00000000}},	//   hils, ליעס_, ximc, --,
   {{0x6ab622d4,0x7d01a044,0xa6db003e,0x399600f2}},	//   _mayf, kils, _miðl, næs_,
   {{0x3f510023,0x612da045,0x00000000,0x00000000}},	//   _báu_, túla, --, --,
   {{0x03a32e0f,0x3f5100fe,0x53a300ae,0x6f00115f}},	//   _пиро, _cáu_, _парб, timc,
   {{0xc7b300a1,0x74c42918,0x044339f8,0x64620034}},	//   תבה_, राकृ, _чесн, świę,
   {{0x6f000d30,0x216723f9,0x612d6c6c,0x00000000}},	//   rimc, _нити_, súla, --,
   {{0x61e20154,0x3b540036,0x7d01a046,0x00000000}},	//   myol, мкор, gils, --,
   {{0x61e20361,0x3f7700ae,0x60c80537,0x00000000}},	//   lyol, cău_, _indm, --,
   {{0x6b8802b6,0x60da1dbd,0x9f040d7f,0x00000000}},	//   rudg, _hotm, _کوچو, --,
   {{0x61e2a047,0x7d01a048,0xa3b3086d,0x26d900d1}},	//   nyol, bils, _जैन_, _roso_,
   {{0x26d9a049,0x7d5700a1,0x00000000,0x00000000}},	//   _soso_, _ציוד_, --, --,
   {{0xb8f5000f,0x26d9a04a,0x57a43e1c,0x60daa04b}},	//   _सच_, _poso_, ншта, _motm,
   {{0xf7700103,0xd6d80408,0x6ab601ff,0x60da21ab}},	//   طاف_, пту_, _gayf, _lotm,
   {{0xf6502204,0x7aeda04c,0x44b50360,0x26d903be}},	// [b470] ائف_, _ilat, мбас, _voso_,
   {{0xa5bb3e11,0x7aed1c48,0xfe7900d2,0x61e2a04d}},	//   _szós, _hlat, vkům_, dyol,
   {{0xa77400ae,0x0edc00c3,0xa3e7023a,0x00000000}},	//   _плэч, _बवंड, मैं_, --,
   {{0x60c80006,0x629e0018,0x0ca90213,0xd047013c}},	//   _andm, őpon, _कस्म, ələl,
   {{0x3f51a04e,0xe8d900ac,0x60da18f0,0x7d01013c}},	//   _sáu_, _ntị_, _botm, yils,
   {{0x7aed0e0f,0x7ced015e,0x00000000,0x00000000}},	//   _llat, _múrc, --, --,
   {{0x7d011724,0x7aed02c4,0xdb0b00ee,0x7ae6003e}},	//   vils, _olat, _asfí, ykkt,
   {{0x44310063,0x7aed0113,0x3f77020a,0x00000000}},	//   _izz_, _nlat, rău_, --,
   {{0x7d01a04f,0x443102f7,0xbeed0d75,0x00000000}},	//   tils, _hzz_, _जतीन_, --,
   {{0x7aed6e53,0x6ab6074e,0x60da010a,0xdd8e001c}},	//   _alat, _sayf, _gotm, گوی_,
   {{0xa3b600a5,0x7d01a050,0x2d840b44,0xdb0b0143}},	//   जिए_, rils, arme_, _esfí,
   {{0x7aeda051,0x7d01a052,0xdd8e001c,0x443105db}},	//   _clat, sils, دوی_, _mzz_,
   {{0xe816007d,0x80b400a5,0xaa7b025b,0x7aed00a5}},	//   _दुजा_, _इसमे, ckým, _dlat,
   {{0x7aeda053,0xdcfb00d9,0x39960537,0x00000000}},	//   _elat, bruā, ræs_, --,
   {{0xd9430e23,0x7aeda054,0x6ab603e0,0x443102db}},	//   тери, _flat, _tayf, _nzz_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29033b7b,0xcb130054,0xe57a3ac8,0xa5bb0018}},	// [b480] bija_, _שלח_, юза_, _szór,
   {{0x7aed5955,0x61e26134,0x00000000,0x00000000}},	//   _zlat, vyol, --, --,
   {{0xa6db003e,0x00000000,0x00000000,0x00000000}},	//   _miðj, --, --, --,
   {{0x60da17ce,0x05000033,0x44310169,0xfbb008c0}},	//   _sotm, ্তের_, _dzz_, _जनसम,
   {{0x6fc0007d,0x4431a055,0x7bd50206,0x00000000}},	//   विभू, _ezz_, äzuj, --,
   {{0xd259022b,0x61e2a056,0x00000000,0x00000000}},	//   _efņ_, ryol, --, --,
   {{0xe2aa2c31,0x61e24fb7,0x00000000,0x00000000}},	//   _وارن_, syol, --, --,
   {{0x3f80013f,0x877b006e,0xaa7b0031,0x00000000}},	//   čiu_, קאפי, tkým, --,
   {{0xa3b60469,0x645900a5,0xa6db003e,0x0caa079c}},	//   जिक_, świe, _biðj, отни_,
   {{0x290303e5,0x7ce405aa,0x8c3c0233,0x00000000}},	//   xija_, _kòri, leği, --,
   {{0xa2c30096,0xaa7b0a7f,0x00000000,0x00000000}},	//   ळाच्, ským, --, --,
   {{0x290397eb,0x8c3c01e8,0x00000000,0x00000000}},	//   wija_, neği, --, --,
   {{0xf2d307a6,0x7aed0106,0x7ce400ee,0x00000000}},	//   דער_, _vlat, _lòri, --,
   {{0xa6db003e,0x3cf70076,0x00000000,0x00000000}},	//   _viðm, _يعود_, --, --,
   {{0xd6db142f,0x7aed00cd,0x3cf9023b,0x7ce400ee}},	//   ота_, _tlat, ësve_, _nòri,
   {{0x2caca057,0xe8d90174,0x7aed00aa,0x98a401d3}},	//   ledd_, _itọ_, _ulat, ēmā_,
   {{0x2cac02ad,0x0577001c,0xa5bb0065,0xa5353a62}},	// [b490] oedd_, بازد, _iyók, енач,
   {{0x2cac0150,0x7ce400ee,0x29030052,0xcd9700ca}},	//   nedd_, _bòri, qija_, ודמת_,
   {{0xb5fb0503,0x00000000,0x00000000,0x00000000}},	//   _ceár, --, --, --,
   {{0x5215028d,0x2cac02ad,0x7ce41e8c,0xb5fb033c}},	//   ндет, hedd_, _dòri, _deár,
   {{0x865a0054,0x21691e6d,0xb65a0089,0x00000000}},	//   _מדרי, чили_, _מדרש, --,
   {{0x2cac004d,0xa29f06eb,0x6ea100b6,0x00000000}},	//   jedd_, _गॉर्, क्नु, --,
   {{0xf1b90146,0x8c3c026a,0x2cac00f0,0xdfd10286}},	//   _myši_, beği, dedd_, ايع_,
   {{0x8c3c0b88,0xb4db05fe,0x680e01f9,0x00000000}},	//   ceği, _guàr, lődé, --,
   {{0xe8d906c0,0x2cac00f0,0x3a2900b3,0xc1050037}},	//   _atọ_, fedd_, _nyap_, _كوري,
   {{0xdb0ba058,0x2cac5b95,0xa5bb0139,0x0d8202e3}},	//   _erfü, gedd_, _ayók, ыльн,
   {{0xab2a188d,0x7ced00e3,0x00000000,0x00000000}},	//   зона_, _cúra, --, --,
   {{0xf412006e,0x7ced0076,0xc4dc0d77,0xb5fb0139}},	//   רפט_, _dúra, _मक्ख, _ifáf,
   {{0x3eada059,0xaca30129,0xc332040a,0x690902ef}},	//   meet_, _arụk, טוט_, džeb,
   {{0x3ead2349,0xdce90307,0x80bf0033,0x00000000}},	//   leet_, dseć, ্সক্, --,
   {{0x07a311d9,0x68e101cd,0x00000000,0x00000000}},	//   ларн, ölda, --, --,
   {{0x3ead02fd,0x224d0270,0x2b4900fe,0x00000000}},	//   neet_, _ngek_, _giac_, --,
   {{0x6aa405bd,0xd5af0103,0x7ce400ee,0x3f870e43}},	// [b4a0] _ibif, یفہ_, _sòri, hrnu_,
   {{0x05000081,0x3ead5665,0x224d0113,0x395f0042}},	//   ্ত্র_, heet_, _agek_, íuse_,
   {{0x66e6a05a,0x3ead032c,0x69c40031,0x6eee01f7}},	//   _зона, keet_, _hrie, _lùba,
   {{0x69c4a05b,0x3ead00c2,0xdb190094,0x14c9023a}},	//   _krie, jeet_, _krvá, राउण,
   {{0x672600f3,0x8c3c026a,0xf1260457,0x6aa405bd}},	//   _ikkj, reği, нько, _mbif,
   {{0x65644a00,0xab680090,0x69c422f3,0x7d060139}},	//   mpih, _heżż, _mrie, _mérè,
   {{0x3ead000b,0x656400f9,0x644e026e,0x6aa4010a}},	//   feet_, lpih, _igbi, _obif,
   {{0x539b00a1,0x2cac02ad,0x81af0081,0x3ead02ac}},	//   _מילו, wedd_, _ওপর_, geet_,
   {{0x10a62120,0x3f8700cc,0xcd061a54,0x6eee009c}},	//   _пиан, arnu_, ечни, _cùba,
   {{0x559707a6,0x7e760b14,0x3f87042d,0x9b580396}},	//   עדיע_, _šapć, brnu_, миот_,
   {{0x2cac043a,0x644e0134,0xe1ff003e,0x3ead0cc4}},	//   redd_, _mgbi, _þór_, beet_,
   {{0x2cac043a,0xa6db0088,0x39522d27,0x290406a3}},	//   sedd_, _viðk, _buys_, èman_,
   {{0xfce6133d,0x2b492ba9,0x645ca05c,0x7fb300a7}},	//   _подо, _viac_, _ofri, _rəqə,
   {{0x2c860139,0x6aa40517,0x69c4501b,0x656405db}},	//   _dídà_, _ebif, _drie, dpih,
   {{0x628002e6,0xdce20039,0x8ccd1bc3,0x69c4a05d}},	//   _odmo, _uvođ, तारो, _erie,
   {{0x645ca05e,0x69c40054,0x644ea05f,0x6d4a30ff}},	//   _afri, _frie, _agbi, _hifa,
   {{0x6d4aa060,0x6564019c,0x644e0090,0x3952a061}},	// [b4b0] _kifa, gpih, _bgbi, _guys_,
   {{0x2901a062,0x3f8ea063,0x6d4a5d59,0x6abd254e}},	//   _umha_, kufu_, _jifa, ldsf,
   {{0xa6db0088,0x6d4a0051,0x9d1b00ca,0x6f020036}},	//   _liði, _mifa, לומט, _omoc,
   {{0x6abd4a75,0xf6790130,0x7c2a4318,0x877a0089}},	//   ndsf, _קאָמ, _myfr, _קארי,
   {{0x645c02ad,0x6abd19fb,0x7c2a00f0,0x672d03f1}},	//   _ffri, idsf, _lyfr, mlaj,
   {{0x672da064,0x3ead057a,0x6d4aa065,0x91e25bc7}},	//   llaj, weet_, _nifa, роше,
   {{0x3ead0fc4,0x6fb200e3,0x3f8e0193,0x02a701b3}},	//   teet_, لموا, gufu_, _прам,
   {{0x672d6ccc,0xb4ac0336,0x6abd02b6,0x6d4a024a}},	//   nlaj, कड़ी_, jdsf, _aifa,
   {{0x6d4aa066,0x3eada067,0x7bdc01bf,0xa6db003e}},	//   _bifa, reet_, ärun, _viðh,
   {{0x2d83011d,0x82340080,0x3ead3813,0x7bc300e7}},	//   čje_, _إرفا, seet_, _prnu,
   {{0x7c2a02e0,0x6d4a9f7d,0x69c4a068,0x672d25e2}},	//   _cyfr, _difa, _srie, klaj,
   {{0x69c4a069,0x2911013d,0x2a72008a,0x7c2a00f0}},	//   _prie, enza_, _qeyb_, _dyfr,
   {{0x6d4a3b5b,0x2d8d0639,0x6b8805c2,0x69c40090}},	//   _fifa, quee_, ardg, _qrie,
   {{0x69c41db2,0x6d4a05bd,0x765d2d5b,0xb4e00285}},	//   _vrie, _gifa, _afsy, _तवे_,
   {{0x7c2a02ad,0xf09200a1,0x81d70081,0x7cf6020a}},	//   _gyfr, ינם_, ানি_, _bârf,
   {{0x2911a06a,0x672da06b,0x6d4aa06c,0x799d023e}},	//   anza_, glaj, _zifa, btsw,
   {{0x7afd0052,0x6d4a05bd,0xf2120134,0x7bc101cb}},	// [b4c0] ërte, _yifa, họrọ, lvlu,
   {{0x81d700c7,0x7ce40472,0x25b20665,0x65640808}},	//   ানা_, _fòru, rwyl_, rpih,
   {{0x672da06d,0x1fbd0034,0x25b200f0,0x260700c3}},	//   blaj, ्मोड, swyl_, _सेठी_,
   {{0x66e65ecf,0x672d058a,0x6d460146,0x3f8e00e7}},	//   _рома, claj, íkaz, vufu_,
   {{0x645900a5,0x14c90851,0xa3b600b6,0x00000000}},	//   świa, राखण, जिङ_, --,
   {{0x28d50b3a,0x645ca06e,0xa3b33ec4,0x7e6905c2}},	//   दायि, _ufri, _जैव_, ebep,
   {{0xdfd000e3,0xc29a0284,0x7e69084e,0x00000000}},	//   صية_, _отац_, fbep, --,
   {{0x3f8ea06f,0x7c3e0031,0x7bc10f5a,0x00000000}},	//   rufu_, _úpri, dvlu, --,
   {{0x3f8ea070,0xaad600b6,0x6d4a0077,0x00000000}},	//   sufu_, धानक, _pifa, --,
   {{0x799d023e,0xf2120174,0x7bdc00ce,0x00000000}},	//   vtsw, bọrọ, äruo, --,
   {{0x6d4a0010,0x7bc1442a,0x00000000,0x00000000}},	//   _vifa, gvlu, --, --,
   {{0xb69b00d3,0x7ce400b3,0x6d4a0079,0x799d042c}},	//   _amân, _aòrt, _wifa, ttsw,
   {{0x6abd040f,0x6d4a8744,0x00000000,0x00000000}},	//   rdsf, _tifa, --, --,
   {{0xdb0b003e,0x6f070113,0x6d4a0350,0xac18219d}},	//   _erfð, _tèbè, _uifa, _полу_,
   {{0x799d023e,0xa6db0088,0x7ce401ec,0x7ced00d4}},	//   stsw, _miðv, _dòrt, _zúro,
   {{0x66090088,0x1db60285,0x7cf6044c,0xab830dfb}},	//   _þekk, _अनात, _bârg, _тушк,
   {{0x06c50081,0x672da071,0xd49b294a,0x3ea60113}},	// [b4d0] _একদি, rlaj, дре_, _mbot_,
   {{0x7d0800e7,0x672da072,0x04f41aad,0x3878009c}},	//   nids, slaj, азую, carr_,
   {{0xd2511e56,0x6ef51bf1,0xd498008f,0xa3b300aa}},	//   منا_, _hábe, ърт_, _जैश_,
   {{0x7d08031b,0xaad6009f,0x24980124,0x6ef5838a}},	//   hids, धायक, _ecrm_, _kábe,
   {{0x4aa51e5e,0xf99f0c56,0x656f0150,0x7ced0206}},	//   ग्यव, ntè_, _uwch, _búrl,
   {{0x3ea6a073,0x6e2b00f0,0xf0750018,0x7ce4009c}},	//   _abot_, _rygb, ایاں_, _mòrs,
   {{0x3f580161,0x63b802b6,0x4ac30096,0x7ced2c85}},	//   _céu_, ævnt, षयाव, _súro,
   {{0xf8380054,0xf99f0c56,0x3f5805fe,0xa2ca0096}},	//   כנות_, ktè_, _déu_, _सोप्,
   {{0x7bc1023e,0x7e692b34,0x00000000,0x00000000}},	//   wvlu, rbep, --, --,
   {{0xee36013f,0x61e400c2,0x3f58015e,0x7bc1000b}},	//   ыны_, äile, _féu_, tvlu,
   {{0xd120007a,0xfc0500d5,0xe81f00bc,0x67243620}},	//   मकरण_, упно, _मँगा_, yoij,
   {{0x22490477,0x94070092,0xa3b6009f,0x7cf90065}},	//   žaku_, ünə_, ड़ित_, _bùrù,
   {{0x6f0900a5,0xdca524ec,0x7ce48bed,0x3878a074}},	//   miec, _бали, _còrs, tarr_,
   {{0x6f0900d9,0xf1b902ef,0xa6db003e,0xa2ca0096}},	//   liec, _msš_, _miðu, _सोन्,
   {{0xa6db01cd,0xdc9a0796,0x9d1a0327,0x7ce400b3}},	//   _liðu, _ניקל, _אוסט, _vòrt,
   {{0xb8eb000f,0x6f09a075,0x3ebf442c,0x7ce4009c}},	//   _रो_, niec, ndut_, _fòrs,
   {{0xa6db0102,0x80b30378,0x2d9fa076,0x2498020a}},	// [b4e0] _niðu, ंजाइ, ntue_, _pcrm_,
   {{0x690967e3,0x00000000,0x00000000,0x00000000}},	//   lžen, --, --, --,
   {{0x389b07a6,0x6f0929aa,0x6ef50220,0x1fd200c3}},	//   _איינ, kiec, _zábe, _थपेड,
   {{0x290aa077,0x7cf600d3,0x3f58016d,0xa6db01cd}},	//   liba_, _târg, _réu_, _biðu,
   {{0x281300bf,0xc05a02ec,0x3f580088,0x6f09a078}},	//   _نویس, ній_, _séu_, diec,
   {{0xe5a30291,0x290aa079,0x00000000,0x00000000}},	//   _ћири, niba_, --, --,
   {{0x6d5da07a,0x7d08a07b,0xa6db01cd,0x6d410786}},	//   ísan, vids, _viðv, dmla,
   {{0x2d8288ce,0x3dc6a07c,0x7176001c,0x660902ef}},	//   škem_, _prow_, _مهرا, _žeki,
   {{0x7d080501,0x290a0453,0x69090a39,0x26c000f0}},	//   tids, kiba_, džen, idio_,
   {{0xdce90181,0x8f7602ec,0x3dc60131,0x290aa07d}},	//   ateľ, _буді, _vrow_, jiba_,
   {{0x6f09a07e,0x290aa07f,0x7d080973,0x6ef50042}},	//   biec, diba_, rids, _sábe,
   {{0xa2ca10e9,0x6f090034,0x7ce48bed,0xf99f0036}},	//   _सोम्, ciec, _còrr, ttè_,
   {{0x7d08a080,0x26c002ad,0xf1c70b94,0x588702e3}},	//   pids, ddio_, लियन, лыва,
   {{0x25a001c5,0x7faa01d4,0x5d8300e3,0xac9700e3}},	//   dtil_, _təqd, _الول, _منها_,
   {{0xd7f802fd,0xf99f4a69,0x00000000,0x00000000}},	//   гут_, stè_, --, --,
   {{0xa4ff000c,0x00000000,0x00000000,0x00000000}},	//   ोच्च_, --, --, --,
   {{0x4438a081,0x290aa082,0x65950f32,0x00000000}},	// [b4f0] _azr_, biba_, разу, --,
   {{0x290aa083,0x753c0034,0x6f09007f,0xb5fb033c}},	//   ciba_, _chrz, ziec, _afác,
   {{0x3255013f,0x29d80031,0x00000000,0x00000000}},	//   авер, ržať_, --, --,
   {{0xd6db4043,0x6595013f,0x00000000,0x00000000}},	//   _что_, _каму, --, --,
   {{0x25a05b8f,0x867a00ca,0x6abf02a1,0x4438039f}},	//   ctil_, _שרשו, _maqf, _ezr_,
   {{0x6f0900a5,0xa6db0088,0xc05b00d6,0xdd010220}},	//   wiec, _viðu, хід_, _ľuďo,
   {{0x6f090029,0x3ebf0124,0x7fd501ce,0x09e20096}},	//   tiec, tdut_, рілі, _पथ्य,
   {{0x290a3184,0x0d851785,0x2d9f7dff,0x225fa084}},	//   ziba_, алин, ttue_, _ufuk_,
   {{0x3ebf5c36,0xf1ca0146,0xa1594e42,0xdce90206}},	//   rdut_, _pláž_, _разу_, rteľ,
   {{0x6f090150,0xdce90031,0x7ced00b3,0x26c00357}},	//   siec, steľ, _túrm, zdio_,
   {{0xd0111e53,0x6f090029,0x6d41a085,0x2fd9046b}},	//   _بلا_, piec, rmla, _جواد_,
   {{0x690900b6,0x1f5a00ca,0xa6db01cd,0x25a00094}},	//   užen, _סדנא, _miðs, ytil_,
   {{0x290aa086,0x0d6700c2,0x69094160,0xa6db003e}},	//   tiba_, _съем, ržen, _liðs,
   {{0x7e7b06ee,0x8c455ddd,0x2ca700de,0x6d5b020b}},	//   laup, _келе, _ubnd_, mqua,
   {{0x61eb0088,0x37e3a087,0x2f1a00e8,0x7ce401b9}},	//   hygl, оорг, līga_, _tòrr,
   {{0x09e643a9,0x26c0a088,0x290a0453,0x78be0023}},	//   _воин, udio_, siba_, _wapv,
   {{0x6d5ba089,0x4438007e,0x2f1a00e8,0x00000000}},	// [b500] nqua, _szr_, nīga_, --,
   {{0x69090074,0x7ae42a3c,0x25a06073,0xb97b028c}},	//   nžel, _hoit, rtil_, _שניי,
   {{0x25a0a08a,0x7e7b007b,0x4ada314d,0x7ae400c2}},	//   stil_, kaup, _बचाव, _koit,
   {{0x7ae40084,0x877b006e,0x25a0a08b,0x82a6013f}},	//   _joit, _באטי, ptil_, радж,
   {{0x7ae422e7,0x44260067,0x41b6116a,0xa6db0088}},	//   _moit, ło_, рсет, _viðt,
   {{0x7ae40933,0xb1140081,0x6b5e01d3,0x7af60150}},	//   _loit, িত্ব_, _līga, _llyt,
   {{0xd00f00ab,0xa2c100b6,0x69098962,0x251b00ca}},	//   وله_, _रोक्, džel, _סולא,
   {{0x7ae4a08c,0x7e7ba08d,0x3da60138,0x975700d7}},	//   _noit, gaup, ароб, סיפו_,
   {{0x50b6004d,0x2d8da08e,0x316405db,0x00000000}},	//   _всеу, gree_, _utmz_, --,
   {{0x7af6013f,0x7cf6442c,0x00000000,0x00000000}},	//   _alyt, _sârb, --, --,
   {{0x7ae40257,0xdeef01b3,0x00000000,0x00000000}},	//   _boit, _ды_, --, --,
   {{0x7ae4006b,0x6da694bf,0x6d5b023e,0x7ce401b5}},	//   _coit, _вида, bqua, _eòrp,
   {{0x4efb0341,0x7ae40062,0x7e620065,0x7cf6020a}},	//   _בלאג, _doit, _ifop, _cârc,
   {{0xa6db01cd,0x6abf0078,0x00000000,0x00000000}},	//   _niðr, _waqf, --, --,
   {{0x7af60b97,0xc7c4121c,0x7c380039,0x9a87088c}},	//   _flyt, ости, _uzvr, _купл,
   {{0x7ae40634,0xddc9044c,0x7af64f34,0x00000000}},	//   _goit, nceş, _glyt, --,
   {{0xa2ca00b6,0x00000000,0x00000000,0x00000000}},	// [b510] _सोध्, --, --, --,
   {{0x629b013d,0x04670bd5,0x7ced0206,0x00000000}},	//   _scuo, ртам, _rúrk, --,
   {{0x613600d3,0xd6d100e3,0x2d8d0063,0x3b0903a9}},	//   tâln, _فقد_, zree_, _kmaq_,
   {{0xa6db0102,0x91b5007f,0xc6a71785,0x6d5b020b}},	//   _viðs, _आईआई, _трои, yqua,
   {{0x68e502fd,0x6eee009c,0xf994006e,0x00000000}},	//   _kohd, _iùbh, ַרק_, --,
   {{0x68e500c2,0x61eb0150,0x6d5d0328,0x92d70033}},	//   _johd, rygl, ísam, িসে_,
   {{0xa3bb000d,0x7e7b2c2e,0x68e500dc,0x213e01b9}},	//   _अनि_, taup, _mohd, _dhth_,
   {{0x2d8d0185,0x381800a1,0x2bb01c0a,0x2d953164}},	//   tree_, יקום_, _जनजा, брос,
   {{0x6b5e0029,0x7e7ba08f,0x6ef50143,0x7ae4033c}},	//   _rīga, raup, _cába, _roit,
   {{0x7ae4a090,0x6d5ba091,0x2f1a00d9,0x44310124}},	//   _soit, rqua, rīga_, _kyz_,
   {{0x6909013f,0x6d5ba092,0x7ae4311e,0x7af6a093}},	//   ržel, squa, _poit, _plyt,
   {{0x60c1a094,0xdce000d9,0x3d9500c2,0xa96a0291}},	//   _halm, rpmā, _гидр, лима_,
   {{0x7ae4a095,0x60c1a096,0x333f04f9,0x78a98831}},	//   _voit, _kalm, _mhux_, đevn,
   {{0x60c100d1,0xeb99328d,0x612d002b,0x7cf6020a}},	//   _jalm, _бик_, cúlt, _vârc,
   {{0xbb85054f,0x60c1a097,0x6ef50074,0x6d59a098}},	//   _البي, _malm, _zába, _huwa,
   {{0x6d591fc9,0xfb860260,0x6eee01b9,0xaa7b003e}},	//   _kuwa, _ادوی, _cùbh, skýr,
   {{0xe73707ec,0x7faa01d4,0x6d596e9c,0xbd0200fd}},	// [b520] сет_, _məqa, _juwa, _àécr,
   {{0x6d5963b6,0x00000000,0x00000000,0x00000000}},	//   _muwa, --, --, --,
   {{0x8ca92231,0x6d592c98,0xcc7a00c1,0x7ced00b3}},	//   ज्यो, _luwa, רװער, _cúri,
   {{0x6455a099,0xe5a637fa,0xe9f90af0,0x918600e3}},	//   _egzi, _лими, _abẹ_, مجتم,
   {{0x26c202e6,0x2b400091,0x6d599447,0x4a9b0341}},	//   _iako_, _mhic_, _nuwa, רינג,
   {{0xa50a07f3,0x863700a1,0x26c2a09a,0x7ceda09b}},	//   _сега_, _לרכב_, _hako_, _fúri,
   {{0x60c11912,0x6ef50b0b,0x68e10c0a,0x6d59260a}},	//   _dalm, _sába, öldi, _auwa,
   {{0x26c2a09c,0x6d59a09d,0x76400094,0x6ab2007f}},	//   _jako_, _buwa, _úmys, ज़ोर,
   {{0x26c2001b,0x2dda0037,0x6d5909f0,0xa2d51efb}},	//   _mako_, ابعة_, _cuwa, णार्,
   {{0x6d59a09e,0x2d8a4289,0x60c10188,0xe9f90065}},	//   _duwa, čbe_, _galm, _gbẹ_,
   {{0x7afd023b,0x68e513ea,0x09e60033,0x24870206}},	//   ërto, _rohd, _পেলা, ónmi_,
   {{0x26c2a09f,0x6d5903e3,0x612d0072,0x2b4067cd}},	//   _nako_, _fuwa, súlt, _chic_,
   {{0x68e5007b,0x00000000,0x00000000,0x00000000}},	//   _pohd, --, --, --,
   {{0xa2d5009d,0x2ee60185,0x1958065c,0x26c2010a}},	//   णाऱ्, _hoof_, сары_, _aako_,
   {{0x6e3c025c,0x6d59a0a0,0x26c278f1,0x78b59b19}},	//   ərba, _zuwa, _bako_, rezv,
   {{0xdce000d9,0xceb900b6,0x2c4e00a7,0x2ee60381}},	//   ksmī, toři_, məd_, _joof_,
   {{0x26c26fb9,0x26c700b6,0x6909080e,0x6aad53fb}},	// [b530] _dako_, ěno_, nžek, _ibaf,
   {{0x89dc00ca,0x2ee60313,0x26c201c8,0x69cd0062}},	//   _תחזי, _loof_, _eako_, _irae,
   {{0x26c20135,0xaadd00a8,0x2c4e00a7,0xdce000e8}},	//   _fako_, यापक, nəd_, esmī,
   {{0x81bd0033,0x60c117bb,0x69cd2c97,0x26c246e1}},	//   ইমস_, _salm, _krae, _gako_,
   {{0x99480281,0x6aad0ab9,0x7faa013c,0x00000000}},	//   _خلیل_, _mbaf, _rəqa, --,
   {{0x6d59a0a1,0x656da0a2,0x60c10092,0x26c2a0a3}},	//   _ruwa, mpah, _qalm, _zako_,
   {{0x60c15460,0x26c2068d,0x6d59a0a4,0x43943283}},	//   _valm, _yako_, _suwa, _нарс,
   {{0xa3ae0006,0x7d0a009c,0x6d590d1f,0xb2751c66}},	//   _कहत_, _amfs, _puwa, _флаш,
   {{0x60c1a0a5,0x4add00c3,0x656d51a0,0x30a70f21}},	//   _talm, यानव, npah, _грев,
   {{0x3b853f98,0x6aad571e,0x5ba93967,0x63a51821}},	//   олог, _abaf, аком_, othn,
   {{0x69cd0f20,0x656d0479,0x6aad7e18,0x2f1a01d3}},	//   _arae, hpah, _bbaf, cīgo_,
   {{0x6d59a0a6,0x63a50a1b,0x69cda0a7,0x2b830092}},	//   _tuwa, ithn, _brae, rıc_,
   {{0xabd70068,0x26c201e9,0x6ef50103,0x6f0b033c}},	//   _گزشت, _rako_, _hábo, _imgc,
   {{0x26c2a0a8,0x672f00a5,0x69cd18ce,0x6aad2673}},	//   _sako_, _akcj, _drae, _ebaf,
   {{0x69cd40e3,0x7cc400d1,0x7afd01b9,0x00000000}},	//   _erae, _رزوم, bhst, --,
   {{0x7afd02dc,0x6aad619e,0x1b180033,0x3a2001ff}},	//   chst, _gbaf, _ধীরে_, _txip_,
   {{0x69cd279c,0x656d2846,0xe5a32f34,0x26c21197}},	// [b540] _grae, gpah, мити, _vako_,
   {{0x26c2068d,0x62890af0,0xe577021a,0x00000000}},	//   _wako_, _adeo, юзу_, --,
   {{0x6ef5025b,0x6efc0257,0x66e6355b,0xe3baa0a9}},	//   _nábo, _hébe, _дона, рбе_,
   {{0xaadd00b6,0x68e1a0aa,0x7d000032,0x81b30033}},	//   यायक, öldv, _kárù, টিন_,
   {{0xdce2042d,0x63a500e3,0x2c4e00a7,0x2ee6024f}},	//   _stoč, athn, zəd_, _roof_,
   {{0xc5f30054,0x6ef51f20,0x6efc0113,0x6f0b063d}},	//   _חדש_, _bábo, _mébe, _amgc,
   {{0x4aca4422,0xaadd0557,0xa3ae00aa,0xaaca045f}},	//   ियाव, यामक, _कहि_, ियाक,
   {{0xe29755dc,0xddaa00ae,0x9ed800ae,0x2f1a00e8}},	//   _мас_, атол_, смит_, rīgo_,
   {{0xe0da1a0c,0xf26700d3,0x6380033c,0x00000000}},	//   _ква_, _фиул_, _fáná, --,
   {{0xa3ae0d1b,0xbc4a0acf,0x6ef5037a,0x504600ae}},	//   _कहा_, ичне_, _hábl, _дезб,
   {{0x3ce700e7,0x6ef5838a,0xdce20106,0x7d000065}},	//   _donv_, _kábl, _utoč, _aárù,
   {{0x69cda0ab,0xeb0702ec,0x6efc16e7,0x00000000}},	//   _prae, ічно, _bébe, --,
   {{0x9e6500cd,0xad5a00c2,0x6ef500d4,0xddc3002d}},	//   _رانن, _трех_, _zábo, _обци,
   {{0x6efc08a8,0x69cd0313,0x63a500f0,0xd90f0e27}},	//   _débe, _vrae, ythn, ئید_,
   {{0xb9030f35,0x6d484e8d,0x36d50b36,0x00000000}},	//   _नच_, mmda, повр, --,
   {{0x69cd4d2f,0xd6d80818,0xae1e152c,0x656d51a0}},	//   _trae, оту_, _बखान_, tpah,
   {{0x2d8400ec,0x61e400c2,0xe80b0caf,0x7d1a0381}},	// [b550] nsme_, äill, _हेरा_, onts,
   {{0x2d84a0ac,0x656d005c,0x888300cd,0xe46b15d6}},	//   isme_, rpah, _زیرن, ршал_,
   {{0x29111cd5,0x656da0ad,0x7d1a452d,0x68e1003e}},	//   miza_, spah, ints, öldu,
   {{0x0cb704a9,0x63a502ad,0x2d8400d9,0x6ef50037}},	//   _अस्म, rthn, ksme_, _cábl,
   {{0x2d8400d2,0x1a9c006e,0x672d1242,0x6d48013c}},	//   jsme_, שידע, moaj, kmda,
   {{0x2911a0ae,0x7d1a01fa,0xf8cb00c3,0xdcfb01d3}},	//   niza_, jnts, ायिय, ksuā,
   {{0xa3b803c5,0x00000000,0x00000000,0x00000000}},	//   _وافر_, --, --, --,
   {{0x2d95504a,0x7d1a0146,0x2911a0af,0x2d8b002b}},	//   прос, ents, hiza_, áceo_,
   {{0x29112760,0xfaff00dd,0x7f4201ee,0x00000000}},	//   kiza_, dhë_, _dhoq, --,
   {{0x29110239,0xeb990291,0x6ef500d4,0x6efc014b}},	//   jiza_, био_, _zábl, _rébe,
   {{0xca298943,0x2d845b1b,0xc1041f11,0x2911a0b0}},	//   _עם_, asme_, _تولي, diza_,
   {{0xdb04052f,0x28de42d4,0x7cf6078e,0x6f0b0372}},	//   _opnå, माभि, _hârl, _umgc,
   {{0x2911a0b1,0x7d1a023e,0x6f1b0129,0xae5a00ca}},	//   fiza_, bnts, mnuc, _הכנר,
   {{0x2911a0b2,0x18672440,0xccc4004d,0x291e09a1}},	//   giza_, зари_, _обій, õta_,
   {{0x7faa0092,0x00000000,0x00000000,0x00000000}},	//   _nəql, --, --, --,
   {{0x056600a0,0x66e32657,0x6f1ba0b3,0x9f560103}},	//   зван, носа, nnuc, ógép_,
   {{0x29111fa6,0x8afb00ca,0x28ba002d,0x69c00233}},	// [b560] biza_, _להקי, _лунэ_, çmed,
   {{0x7ced0653,0x00000000,0x00000000,0x00000000}},	//   _túru, --, --, --,
   {{0x9c7ca0b4,0x7986020a,0x6d431ab6,0xd33601b3}},	//   njča, lskw, _mhna, пэды,
   {{0xe29a4171,0x2d84a0b5,0xdce905db,0xdcfb0345}},	//   сад_, ysme_, dpeč, yruğ,
   {{0x5ee10081,0x7cf6020a,0x00000000,0x00000000}},	//   বসাই, _bârl, --, --,
   {{0x7f4201e5,0x66040051,0xfaff0052,0x6eee009c}},	//   _shoq, mzik, zhë_, _lùbt,
   {{0xd0100080,0x6ef51574,0x7d1a023e,0x7f42014b}},	//   ضلة_, _tábl, vnts, _phoq,
   {{0xe2f80018,0x29110bbd,0x2d8400bc,0xfaff0216}},	//   _بورڈ_, ziza_, tsme_, xhë_,
   {{0x6604a0b6,0x3cfe12ba,0x29112ea9,0x20560b2e}},	//   nzik, thtv_, yiza_, _етер,
   {{0x6d439ff3,0x7d1a01ff,0x79860629,0x69cb0231}},	//   _chna, unts, dskw, _ágei,
   {{0xfaff01e5,0x7d1a0b6a,0x6d48a0b7,0x00000000}},	//   thë_, rnts, rmda, --,
   {{0x23be030b,0xf7730018,0x7d1a023e,0x291102a4}},	//   _můj_, ہار_, snts, wiza_,
   {{0xdd8f0391,0x7ced00e3,0x29119295,0xa5bb002b}},	//   _مون_, _cúrs, tiza_, _axón,
   {{0xfaff00dd,0x7bdc007a,0xc2fa0081,0x6d431ab6}},	//   shë_, ärus, েকটি_, _ghna,
   {{0x291126d8,0x368b0450,0x8ca10789,0x9b6a1055}},	//   riza_, йсан_, _खातो, _ушла_,
   {{0xb8f40354,0x70b92853,0x29112828,0x8c1b0796}},	//   _सो_, _इस्ल, siza_, _לווי,
   {{0xdce90871,0xa5bb0072,0x69090580,0x29111c35}},	// [b570] zpeč, _exón, džev, piza_,
   {{0xe94500d0,0x672d0a4b,0x28de0296,0x00000000}},	//   _تربی, soaj, माणि, --,
   {{0xccf300c1,0xe8d90134,0xc7ab0037,0x6604010a}},	//   עכע_, _juọ_, _ادخل_, azik,
   {{0xa3ae000f,0xe8d965aa,0xd25135ac,0x7afd0052}},	//   _कहर_, _muọ_, ننا_, ërth,
   {{0xdd8600fb,0x6f000037,0x2d910034,0x5ee005d6}},	//   _جو_, dhmc, ązek_, कान्_,
   {{0xf77000cd,0x25a9a0b8,0xc2440c10,0x684700fd}},	//   _جای_, mtal_, хнік, cédé,
   {{0x25a91a92,0x7cf6044c,0x00000000,0x00000000}},	//   ltal_, _cârm, --, --,
   {{0x26c90010,0xdb190220,0x25a9a0b9,0x614302c6}},	//   ndao_, _prvý, otal_, _bílý,
   {{0x25a96445,0x00000000,0x00000000,0x00000000}},	//   ntal_, --, --, --,
   {{0xab6521b6,0x2a690154,0x7ce4022b,0xb1141536}},	//   мвол, _afab_, _kòry, _змуш,
   {{0x1c450938,0xaca30134,0x25a90141,0x7cff0313}},	//   ьном, jiụl, htal_, _nêre,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5fc50d1a,0xb4bd2171,0xdca5232c,0x644800d8}},	//   विकल, _आसू_, _жали, _údiv,
   {{0xa3ae0006,0xdb1900b3,0x7cff02ac,0x1dbc2397}},	//   _कहल_, _esvà, _bêre, ्टरत,
   {{0x07a305af,0xe8d90174,0x25a90629,0x7cff02ac}},	//   карн, _guọ_, etal_, _vêrd,
   {{0x660401e9,0x25a9029a,0xd2450504,0x79860381}},	//   tzik, ftal_, _مچ_, pskw,
   {{0x28de00bc,0xdb0b0072,0xe8d90174,0x6aa40027}},	// [b580] मादि, _esfó, _zuọ_, _icif,
   {{0x6604a0ba,0xf53f0fbc,0x6ef50206,0x69c44c53}},	//   rzik, _spår_, _bábk, _isie,
   {{0xf36500f3,0x78bca0bb,0x69c4009e,0x316d0634}},	//   етін, merv, _hsie, _atez_,
   {{0x78bca0bc,0x7cf6078e,0x25a901b9,0x00000000}},	//   lerv, _cârj, btal_, --,
   {{0x7afd00dd,0x914a30da,0x8c110033,0x6efc0113}},	//   ërti, очка_, _সুমন_, _néba,
   {{0x2f1a00d9,0x69c49357,0x22940065,0x6ef50037}},	//   mīgi_, _msie, _búkà_, _hábh,
   {{0x64a37f2c,0x3ead0d2d,0x2f1a01d3,0xe3631a21}},	//   _шара, ffet_, līgi_, _акси,
   {{0x78a902e6,0x6efc00cd,0x78bc075c,0x69c4a0bd}},	//   đevi, _béba, herv, _osie,
   {{0x4438a0be,0x2f1a00d9,0x78bca0bf,0x5d5402b3}},	//   _hyr_, nīgi_, kerv, нкит,
   {{0x628005e6,0x6efc025a,0xb143002d,0x69090094}},	//   _hemo, _déba, _анул, nžet,
   {{0x78bc01be,0x7ced53d2,0x25a901f9,0xd49700ca}},	//   derv, _púrr, ztal_, וכית_,
   {{0x60c8a0c0,0x4438a0c1,0xed5a2bcf,0x25a90094}},	//   _hadm, _myr_, _дод_, ytal_,
   {{0x5ea30068,0x645c3c9a,0x3f9c4ec5,0x78bc00fc}},	//   _شمول, _ogri, luvu_, ferv,
   {{0x645c238e,0xa3de000d,0x78bc1410,0x25a90149}},	//   _ngri, तमा_, gerv, vtal_,
   {{0x69096c50,0xdb190072,0xe7330037,0x69c4a0c2}},	//   džet, _esvá, نصر_, _esie,
   {{0x6d580018,0x25a9a0c3,0x00000000,0x00000000}},	//   _hiva, ttal_, --, --,
   {{0x7cff0665,0x60da01a2,0x4438009c,0x6d583661}},	// [b590] _wêre, _ontm, _ayr_, _kiva,
   {{0x443848dc,0x3f9c0283,0x7aeda0c4,0x799d149c}},	//   _byr_, kuvu_, _hoat, musw,
   {{0x6280a0c5,0x4438014b,0x78a5022b,0x316d05db}},	//   _bemo, _cyr_, _ichv, _stez_,
   {{0x6d58a0c6,0x443817d2,0x7aed0a00,0x6280a0c7}},	//   _liva, _dyr_, _joat, _cemo,
   {{0x7aed01af,0xa069a0c8,0x7d080138,0x2f1a01d3}},	//   _moat, пала_, _kūrė, cīgi_,
   {{0x628000f9,0x7aed4f3f,0x44384ada,0x60c8a0c9}},	//   _eemo, _loat, _fyr_, _cadm,
   {{0x6ef51f9f,0x6efca0ca,0x60c8a0cb,0x6abd20ab}},	//   _hábi, _séba, _dadm, kesf,
   {{0x62800305,0x6d58a0cc,0x60c80072,0x645c0357}},	//   _gemo, _aiva, _eadm, _zgri,
   {{0x6d58a0cd,0x6abd021f,0x3eada0ce,0x00000000}},	//   _biva, desf, rfet_, --,
   {{0x620103a3,0x3eada0cf,0x6d58a0d0,0x6280a0d1}},	//   ızlı, sfet_, _civa, _zemo,
   {{0x7c9500bf,0x290300dd,0x78bc0f6f,0x6ef50161}},	//   وشگا, dhja_, verv, _lábi,
   {{0x2e4e0174,0x6d589ea2,0x78bc3efe,0x6abd4fba}},	//   _kọlọ_, _eiva, werv, gesf,
   {{0x6d5802ac,0x99d60018,0x799d0151,0x6e920fba}},	//   _fiva, رتحا, gusw, _صلوا,
   {{0xa3c107ad,0x6ef500e3,0x6d58a0d2,0x61e4007b}},	//   ्टा_, _sábh, _giva, äili,
   {{0x657d0065,0x0ea6009f,0x656f03a8,0xfc64008f}},	//   _awsh, क्कड, _atch, _ръчн,
   {{0xc4c600bf,0x7aeda0d3,0x645c1301,0x2f1a01d3}},	//   کترو, _goat, _sgri, tīgi_,
   {{0x443e40a3,0x6280a0d4,0x4438a0d5,0xf98a00e3}},	// [b5a0] _št_, _remo, _syr_, _عندي_,
   {{0x62800496,0x2ebd009d,0x2f1a00d9,0xaaac397e}},	//   _semo, ्युत, rīgi_, ट्रक,
   {{0x6280005a,0x6ef500e3,0x60c80106,0xe73a0cc6}},	//   _pemo, _tábh, _radm, _нео_,
   {{0x869a02fd,0x222800bf,0xe3631602,0x6ef5956b}},	//   _этот_, وزشی_, укци, _fábi,
   {{0x60c803a9,0x62802ad4,0x395aa0d6,0xbbdb0285}},	//   _padm, _vemo, _kips_, यमुक,
   {{0x7faa0092,0xc0e30686,0xddcb0555,0x3f9ca0d7}},	//   _həqi, лочк, _şişi, tuvu_,
   {{0x6280a0d8,0x443e0018,0x04436262,0x60c82106}},	//   _temo, _át_, _берн, _vadm,
   {{0x6d58a0d9,0x03d700ca,0x395aa0da,0xd84300d8}},	//   _siva, _אולם_, _lips_, _hučí_,
   {{0x6d580559,0x7aed00ae,0x7ced2ad4,0x00000000}},	//   _piva, _roat, _púrp, --,
   {{0x81b30081,0xdbdb0139,0xafe60aeb,0x395a066a}},	//   টিশ_, _bààr, _позл, _nips_,
   {{0x7aed0a29,0x6d58a0db,0xa2d50096,0x201800aa}},	//   _poat, _viva, णाच्, _äri_,
   {{0x81b300c7,0x78a5025b,0x7c380146,0x141b006e}},	//   টির_, _schv, _vyvr, לויב,
   {{0x6d58a0dc,0xdc12071d,0xee3a0dd8,0x29030052}},	//   _tiva, rşım, _энд_, thja_,
   {{0x395a3428,0x80a40285,0x2e4e0065,0x799d0027}},	//   _cips_, च्चे, _jọmọ_, rusw,
   {{0x7aed0a29,0x7a4900d9,0x6ef5016d,0x913b006e}},	//   _toat, _sūtī, _sábi, פעלק,
   {{0x290300dd,0xdc3b040a,0x2e4e0139,0x00000000}},	//   shja_, _מעור, _lọmọ_, --,
   {{0x65943fe2,0x7faa0092,0x7afd023b,0x00000000}},	// [b5b0] лату, _dəqi, ërtu, --,
   {{0xa3e20034,0x2f1a01d3,0x78a50094,0x6ef500d8}},	//   _गपशप_, mīgu_, _uchv, _vábi,
   {{0x2901a0dd,0x80a40966,0x2b4900de,0x6efc0042}},	//   _ilha_, च्छे, _khac_, _nébo,
   {{0x91bf0ed3,0x395a0031,0x29010113,0xf7760796}},	//   _एनआई, _zips_, _hlha_, _שערי_,
   {{0x2b490a02,0x3f8c00e7,0x10a50202,0x2f1a00e8}},	//   _mhac_, _avdu_, вилн, nīgu_,
   {{0x6e3900f0,0x395a00ee,0xdddb00e8,0x25b99312}},	//   _rywb, _xips_, jauš, _ipsl_,
   {{0x6efc03a9,0x7faa00a7,0x26cb026d,0xafe50138}},	//   _cébo, _yəqi, _kaco_, тойл,
   {{0x2b4900de,0x6efca0de,0x26cba0df,0x25b90063}},	//   _nhac_, _débo, _jaco_, _kpsl_,
   {{0x2901001f,0x26cba0e0,0xf2d200c1,0x2e4e0065}},	//   _olha_, _maco_, _דען_, _fọmọ_,
   {{0x6b5e00d9,0xfc3f00b6,0x2b490141,0x7d0600e8}},	//   _līgu, řím_, _ahac_, ūksn,
   {{0xaadd022d,0x8cd60034,0x2b4903ea,0x4add0096}},	//   यांक, बाजो, _bhac_, यांव,
   {{0x2b496e01,0x26cba0e1,0xf1b905db,0x2913033c}},	//   _chac_, _naco_, _kpš_, _amxa_,
   {{0xed4e241d,0x28de00a3,0x2b490188,0xdbdb0032}},	//   _во_, मालि, _dhac_, _dàár,
   {{0x7c872383,0x2901009c,0x2d9f0350,0x00000000}},	//   _чуде, _clha_, muue_, --,
   {{0xe73a0478,0x395a2c28,0xdb02002b,0xdbdb0139}},	//   дев_, _vips_, atlá, _fàár,
   {{0x3ebf01bf,0x07a30396,0x2b4902a1,0xdbdb0065}},	//   neut_, јатн, _ghac_, _gàár,
   {{0xe8121757,0x2a605d4e,0x395a00a1,0x68470072}},	// [b5c0] _डेरा_, _igib_, _tips_, _pédí,
   {{0xdbe40af0,0x33f600d3,0x80c00179,0x69d60169}},	//   _bèèr, кчес, _एसें, _irye,
   {{0x2918a0e2,0x26cba0e3,0x9406001c,0x25b9039f}},	//   mira_, _faco_, خواه, _epsl_,
   {{0x69d6074a,0x29180a15,0xdbe40139,0x26cb4b29}},	//   _krye, lira_, _dèèr, _gaco_,
   {{0x4aaa007d,0x6efc00fd,0x26c00131,0x21672569}},	//   _कानव, _débl, meio_, вичи_,
   {{0x2918559d,0x81b300c7,0x3ea66179,0x26c00231}},	//   nira_, টিং_, _scot_, leio_,
   {{0x0fe00f71,0x73e371af,0x26cb037a,0x6576007b}},	//   বন্ধ, _корз, _yaco_, lpyh,
   {{0x2918a0e4,0xa3c10b7f,0x69d6210a,0x2bd5023a}},	//   hira_, ्टर_, _orye, धिना,
   {{0x2918a0e5,0xf1aa00bf,0x1d34008f,0x41bf3613}},	//   kira_, _تازه_, лния, _एनएस,
   {{0x29181619,0x64434197,0x93600174,0xb5fb0139}},	//   jira_, żnie, _ịnyị, _ifát,
   {{0x2918a0e6,0x3ebf5fd5,0x69d62dec,0x25a0a0e7}},	//   dira_, beut_, _arye, huil_,
   {{0x29180bfe,0x2f1a00e8,0x3b5400d3,0x25a09f18}},	//   eira_, tīgu_, икэр, kuil_,
   {{0xc3330054,0x69d600ee,0x6f021bb2,0x7bd7002b}},	//   שור_, _crye, _iloc, _áxun,
   {{0x29186bf4,0x26cb3916,0x853003e3,0x2f1a01d3}},	//   gira_, _saco_, buɗi, rīgu_,
   {{0x1958013f,0x6f025649,0x26cb1d32,0x69d6787e}},	//   тары_, _kloc, _paco_, _erye,
   {{0x25a016cc,0x69d656d8,0x6ef510d9,0x3704a0e8}},	//   fuil_, _frye, _fábu, ачув,
   {{0x2918a0e9,0x2f1a01d3,0x69d68b85,0x44b50b40}},	// [b5d0] bira_, līgs_, _grye, лбас,
   {{0x291841e3,0x6f024d9e,0x7afd39eb,0x26cba0ea}},	//   cira_, _lloc, lkst, _waco_,
   {{0x2bd500a5,0xaaaa1d96,0xf2b10081,0x7d1d15c9}},	//   धिया, _कामक, _ঘোষণ, éssi,
   {{0x7afda0eb,0x26c0016d,0x25a0009c,0x00000000}},	//   nkst, ceio_, buil_, --,
   {{0x442a0072,0xf1a71165,0x25a00085,0xf62b004d}},	//   _exb_, трен, cuil_, _ціни_,
   {{0xa5da00c1,0x6f0200d3,0x2bd5382b,0x80cd034c}},	//   _אַלי, _aloc, धिमा, _धोखे,
   {{0x6f022366,0x46aa030b,0x7afd7847,0x386101ec}},	//   _bloc, ङ्कह, kkst, _mghr_,
   {{0x2918a0ec,0x7afd0126,0x7fb600e3,0xb7f60034}},	//   zira_, jkst, اهير_, ीनतम_,
   {{0x6d4a0080,0x29180b92,0xed590e05,0x3ebf573b}},	//   _bhfa, yira_, нои_, reut_,
   {{0x291803be,0x7afda0ed,0x6f02a0ee,0x00000000}},	//   xira_, ekst, _eloc, --,
   {{0xdfd106cf,0x6f020d56,0x00000000,0x00000000}},	//   _ديا_, _floc, --, --,
   {{0x6f025d2f,0x2918a0ef,0xaca30174,0x38610027}},	//   _gloc, wira_, _krịk, _aghr_,
   {{0x26c00231,0x00000000,0x00000000,0x00000000}},	//   veio_, --, --, --,
   {{0x6f0204a3,0xef1910a4,0x2918014b,0x7afd8a21}},	//   _zloc, liż_, uira_, akst,
   {{0x2918a0f0,0x81e90033,0x26c0016d,0x3156006e}},	//   rira_, মনি_, teio_, טישן_,
   {{0xef19003d,0x6ef5016d,0x7faa00a7,0x69d60052}},	//   niż_, _tábu, _təqv, _trye,
   {{0x2918a0f1,0xb90a00c7,0x2d8da0f2,0x26c0016d}},	// [b5e0] pira_, _মত_, nsee_, reio_,
   {{0xb5fb0072,0x26c00161,0x81e90033,0x25a01570}},	//   _afás, seio_, মনা_, ruil_,
   {{0xdb0202b6,0x1d16006e,0x00000000,0x00000000}},	//   rtlæ, נקער_, --, --,
   {{0x7cf600ae,0x5c36006e,0xaadd00b6,0xdb023459}},	//   _hârt, ארען_, याएक, stlæ,
   {{0x25a000e1,0xe61f03a8,0x00000000,0x00000000}},	//   quil_, _ddôs_, --, --,
   {{0x672402e6,0x8aff0d2a,0xf4870281,0x6f0226c4}},	//   lnij, _muƙa, _مافی, _sloc,
   {{0x6f027ac7,0x6d4704f9,0xdfd000e3,0x7afd00c6}},	//   _ploc, ċjal, زية_, ykst,
   {{0x6d4a00dd,0x672404f9,0x65660060,0x64430034}},	//   _shfa, nnij, _kukh, żnic,
   {{0x0caa4cc3,0x2d8d0124,0xb22625f3,0x9c7c0aa0}},	//   нтни_, gsee_, _смал, ljči,
   {{0x656667b6,0x2f1aa0f3,0x672400e7,0xb8040285}},	//   _mukh, _bàgè_, hnij, रनाम_,
   {{0x5ea60018,0xdb02548d,0x6f0202f7,0x6566019f}},	//   _ممال, ktlä, _tloc, _lukh,
   {{0x672403ce,0xe45700c1,0x8aff0044,0x2f1a00d9}},	//   jnij, טייט_, _buƙa, rīgs_,
   {{0xb69b020a,0x00000000,0x00000000,0x00000000}},	//   _blân, --, --, --,
   {{0xbd020a7f,0x7b1600d4,0x7cf6078e,0x00000000}},	//   _šéfr, nšuj, _cârt, --,
   {{0x7d1a9e24,0x00000000,0x00000000,0x00000000}},	//   mits, --, --, --,
   {{0x7d1aa0f4,0xc878008e,0xeafb00cd,0x3a360129}},	//   lits, ığa_, _سرعت_, ọgụ_,
   {{0xd49b0205,0xb5fb0af0,0xb4c25c65,0xdb020313}},	// [b5f0] ере_, _afár, ्यू_, kulê,
   {{0x7d1aa0f5,0x6566a0f6,0x3f9c0580,0xb69b0131}},	//   nits, _dukh, krvu_, _glân,
   {{0x6724a0f7,0x7faa01d4,0x201a0031,0x7e625fff}},	//   bnij, _məqs, úpil_, _ogop,
   {{0x672404a3,0x7e62a0f8,0x7d1aa0f9,0x2d8d026d}},	//   cnij, _ngop, hits, ysee_,
   {{0xef1903e5,0xd49b0396,0x91e5098a,0x7d1a0e22}},	//   viż_, _прв_, роле, kits,
   {{0x7e62028d,0x6ef50206,0x00000000,0x00000000}},	//   _agop, _nábr, --, --,
   {{0x7d1aa0fa,0x660d16ce,0x3d1b0065,0x35ab278e}},	//   dits, lzak, _láwè_, _चमड़,
   {{0x2d8d09d9,0x64630233,0x0e652467,0x00000000}},	//   tsee_, ştiğ, шкин, --,
   {{0x7bd80006,0x660d1d70,0x628ba0fb,0x7d1aa0fc}},	//   _arvu, nzak, mago, fits,
   {{0x7d1aa0fd,0x5f95013d,0x2d8da0fe,0x7b16a0ff}},	//   gits, _вижт, rsee_, ršum,
   {{0x3b0a1121,0x60c3a100,0x8c452a61,0x4b2616e6}},	//   вено_, menm, рене, имов,
   {{0x60c3074e,0x628ba101,0x81d80081,0x660d0044}},	//   lenm, nago, াহর_, kzak,
   {{0xfce5a102,0x6ef5132d,0x672403ce,0x7bcaa103}},	//   _воло, _fábr, vnij, _esfu,
   {{0x393601b6,0x660da104,0x6f090161,0x7d1a0193}},	//   рэмс, dzak, lhec, cits,
   {{0x672403ce,0xb8ee0e19,0x628b8b8a,0xc7160396}},	//   tnij, _रस_, kago, аќањ,
   {{0x6f0900c9,0x6ef50146,0x672400d9,0x3d1b0af0}},	//   nhec, _zábr, unij, _fáwè_,
   {{0x67240106,0x60c3a105,0x7b160146,0x6d41a106}},	// [b600] rnij, kenm, yšuj, olla,
   {{0xb4c20454,0x672403ce,0x6d4102ad,0x79840270}},	//   ्ये_, snij, nlla, _iwiw,
   {{0x6d41a107,0x389b0341,0x845a3c91,0x60c3a108}},	//   illa, _ביינ, трат_, denm,
   {{0x628ba109,0x7d1a7a70,0xe29aa10a,0xa5bb0042}},	//   gago, zits, тад_, _axóu,
   {{0x7d1a1632,0x6d410216,0xb0e200c0,0xdb020231}},	//   yits, klla, पालग, tulê,
   {{0xaca30174,0x3f9c21d5,0x60c3a10b,0x2fc700f0}},	//   _brọk, trvu_, genm, fwng_,
   {{0x7b2404a3,0x628ba10c,0xfbc71a37,0x212008c5}},	//   rđuj, bago, _بت_, đih_,
   {{0x6d4162df,0xa85700a1,0x7d1a235f,0x6f096179}},	//   ella, סיקה_, wits, ghec,
   {{0x10a602ec,0x7d1a3be5,0xc0e628f1,0x7b160146}},	//   _визн, tits, _коак, pšuj,
   {{0x6208008b,0x60c3a10d,0xdb0203a9,0x00000000}},	//   ırlı, cenm, lulè, --,
   {{0x7d1aa10e,0x660d47fd,0x14d9006e,0x9b590396}},	//   rits, zzak, אַרמ, лиот_,
   {{0x6d41a10f,0x7d1aa110,0x6f1ba111,0x79840169}},	//   alla, sits, ciuc, _bwiw,
   {{0xb5fb0065,0xfaff0052,0x7d1aa112,0x799d0313}},	//   _agán, rkë_, pits, ursw,
   {{0xb4c2000d,0x29050102,0x7cf600d3,0x628ba113}},	//   ्यो_, óla_, _vârs, zago,
   {{0xb4c200b6,0x9b940dd0,0xdb0b052f,0x628ba114}},	//   ्यै_, _البت, _opfø, yago,
   {{0x27ed00e9,0x660d02a7,0x60c3a115,0x00000000}},	//   ćen_, tzak, zenm, --,
   {{0x60c3a116,0x7984006d,0x0467180b,0x00000000}},	// [b610] yenm, _gwiw, атем, --,
   {{0x660da117,0x6efc1e7d,0x5fc6030b,0x69cd0036}},	//   rzak, _débi, लबाल, _isae,
   {{0x660d0018,0x60c3a118,0xdce9031a,0xdb02032e}},	//   szak, venm, speć, stlå,
   {{0xf2120134,0x3cdd007f,0x00000000,0x00000000}},	//   rọnọ, _कोने_, --, --,
   {{0x6d414bb2,0x60c3a119,0x31c70c37,0x00000000}},	//   ylla, tenm, рсев, --,
   {{0x628b7aa7,0xe8d900fe,0x00000000,0x00000000}},	//   sago, _duệ_, --, --,
   {{0x628b6ada,0xa2d8009d,0x4394098f,0x60c3047e}},	//   pago, _नोव्, _марс, renm,
   {{0x533433d0,0x3eb9003e,0x0d851c1b,0x60c332ad}},	//   _дест, ýst_, блин, senm,
   {{0x20c702fd,0xc33200c1,0x6d4173b4,0x63a5005c}},	//   _всег, _זון_, tlla, luhn,
   {{0xa5da00c1,0xf99f028d,0x6aad007e,0x2eed004d}},	//   אַטי, drè_, _acaf, sjef_,
   {{0x63a5005a,0x673d00aa,0x6d4100f0,0x2bed0033}},	//   nuhn, _oksj, rlla, _ছেড়ে_,
   {{0xc86900c1,0x6d4117ce,0xf2120174,0x9f55131b}},	//   _טן_, slla, kọlọ, _увеч,
   {{0xdb026423,0x6d410216,0x00000000,0x00000000}},	//   nulé, plla, --, --,
   {{0xcd7600a1,0x673d00d6,0xa96763df,0xed4400d6}},	//   _העסק_, _aksj, сира_, _дніп,
   {{0x69cd0634,0x66e67b30,0x00000000,0x00000000}},	//   _esae, бова, --, --,
   {{0x753c10cf,0x9666163d,0xc61f0033,0xb4c20167}},	//   _skrz, скае, _দরজা_, ्य्_,
   {{0x98a6276f,0x00000000,0x00000000,0x00000000}},	// [b620] _липе, --, --, --,
   {{0x7af601af,0x88ca0686,0x673d87c8,0xdb02014b}},	//   _hoyt, _слов_, _eksj, dulé,
   {{0x63a506ee,0x25b2084e,0xb4c220cd,0x291aa11a}},	//   guhn, styl_, ्यौ_, _impa_,
   {{0xddc90031,0x7ae40090,0x2d9f01ea,0x00000000}},	//   dbež, _jnit, krue_, --,
   {{0xdce204a3,0x61460832,0xddc90031,0x9f5a02c6}},	//   _suoč, беда, ebež, ápí_,
   {{0x63a529dd,0x291a0063,0x2fcc002b,0x2ba800a8}},	//   buhn, _jmpa_, _psdg_, _कमला,
   {{0x7ae40af0,0xa3bc09a1,0x8cd2023a,0x00000000}},	//   _onit, _अहि_, _भोगो, --,
   {{0xe8d900de,0xf2120129,0x3f8503a8,0x00000000}},	//   _tuệ_, lọmọ, _dwlu_, --,
   {{0x24980063,0xa2064447,0xdb0200fd,0x7a1c01d3}},	//   _kdrm_, _упад, culé, nātī,
   {{0x6aada11b,0x25a000b7,0x7cf6044c,0x00000000}},	//   _scaf, iril_, _cârp, --,
   {{0xb5fb0072,0x25a037e5,0x7af68518,0x00000000}},	//   _agál, hril_, _boyt, --,
   {{0x291aa11c,0x69cd0072,0x7ae4009c,0x25a00117}},	//   _ampa_, _psae, _cnit, kril_,
   {{0x4aaa41f2,0x2d9f54ca,0xaaaa2f4f,0x00000000}},	//   _कारव, crue_, _कारक, --,
   {{0x7ae4263a,0x25a0a11d,0xee3700ae,0xf99f0036}},	//   _enit, dril_, _унч_, rrè_,
   {{0x28de0469,0x236a0113,0x00000000,0x00000000}},	//   माजि, _nubj_, --, --,
   {{0xf99f02f1,0x7af60131,0x7ae4a11e,0x79820134}},	//   prè_, _goyt, _gnit, ọwag,
   {{0x44f51942,0xddc90d12,0x49c800ae,0x7a1c00e8}},	// [b630] опас, zbež, _луэм_, gātī,
   {{0x04672863,0x63a57199,0x00000000,0x00000000}},	//   стам, tuhn, --, --,
   {{0x645aa11f,0x25a000bc,0x00000000,0x00000000}},	//   _útil, aril_, --, --,
   {{0xa29402ec,0x63a5063f,0x25a07190,0xe8122231}},	//   заці, ruhn, bril_, _डेटा_,
   {{0x63a50808,0xbebd00c6,0x00000000,0x00000000}},	//   suhn, liūg, --, --,
   {{0x28ad0213,0x63a500c4,0xaf9907f6,0x2903004d}},	//   ञ्चि, puhn, атих_, nkja_,
   {{0xaaaa08c0,0x4aaa00a4,0x290301cd,0x00000000}},	//   _कालक, _कालव, ikja_, --,
   {{0x2d9523a3,0xdb02353a,0x4ad90d29,0xdcfb00e8}},	//   орос, pulé, _बोलव, stuļ,
   {{0x2903a120,0xdd8e00ab,0x6efc014b,0xa0c501c3}},	//   kkja_, نوي_, _nébu, _ويرو,
   {{0x7af6a121,0x7e990504,0x709400ae,0x7ae4a122}},	//   _soyt, _چنار_, _науф, _snit,
   {{0xddc20034,0x25a00063,0xdceb00d2,0x79600139}},	//   _czoł, zril_, řiďt, _láwì,
   {{0x6b9c00e1,0x25a0039f,0xbdf8010d,0x68e500fe}},	//   árga, yril_, _گرما_, _anhd,
   {{0xa96a00e5,0x7ae4030b,0x00000000,0x00000000}},	//   рига_, _vnit, --, --,
   {{0x6efc025a,0xb4e800a3,0x00000000,0x00000000}},	//   _débu, _मचे_, --, --,
   {{0xd9430012,0x46f6004d,0xdb0200f2,0x00000000}},	//   фери, очат, ktlø, --,
   {{0x7ae43181,0x25a03b37,0x2615007a,0x224d0141}},	//   _unit, tril_, _नइखी_, _ozek_,
   {{0x24987a4b,0x00000000,0x00000000,0x00000000}},	// [b640] _pdrm_, --, --, --,
   {{0x25a03bf0,0x81cf0033,0x7a1c00e8,0x291a3454}},	//   rril_, ষমা_, rātī, _umpa_,
   {{0xba29010d,0x80d4274c,0x25a0076c,0xb376001c}},	//   _نسیم_, _योगे, sril_, زداش,
   {{0x3bba006e,0x6efc0113,0x55e60e1d,0x645a01ab}},	//   ימעד, _yébu, _домб, _útim,
   {{0x68f701d4,0x00000000,0x00000000,0x00000000}},	//   _yoxd, --, --, --,
   {{0x6ea7030b,0x224d3360,0xdfd01f11,0xcf9a0284}},	//   _गाउँ, _dzek_, فيت_, аји_,
   {{0x224d0018,0x28b23212,0x4aaa0e4c,0x04430161}},	//   _ezek_, _जानि, _कांव, _жерн,
   {{0x644e19d0,0x63b3033d,0xe1fa6c35,0x63b4007f}},	//   _izbi, žení, _кгб_, ągnę,
   {{0x62829712,0xd1320192,0x290301cd,0x00000000}},	//   mboo, _قمر_, ykja_, --,
   {{0x6282a123,0xe8d90294,0x6efc1ea1,0x00000000}},	//   lboo, _kwụ_, _rébu, --,
   {{0x2fd80381,0x00000000,0x00000000,0x00000000}},	//   _érg_, --, --, --,
   {{0x62821575,0x539b00ca,0x00000000,0x00000000}},	//   nboo, סיכו, --, --,
   {{0x628201d0,0x00000000,0x00000000,0x00000000}},	//   iboo, --, --, --,
   {{0x644e03ce,0x62825411,0x00000000,0x00000000}},	//   _ozbi, hboo, --, --,
   {{0x6282a124,0x368b8084,0x29030c09,0x1dd20bf5}},	//   kboo, исан_, rkja_, तिकत,
   {{0x442d02e6,0x2903a125,0x443100dc,0x7cff0f5a}},	//   _će_, skja_, _rxz_, _rêri,
   {{0x644e03e3,0x62820188,0x95cb0396,0x746b11db}},	// [b650] _azbi, dboo, шува_, арев_,
   {{0x628205c2,0x00000000,0x00000000,0x00000000}},	//   eboo, --, --, --,
   {{0x628201d0,0xdb0200f3,0x7b16250f,0x527500ae}},	//   fboo, ttlø, ršuv, пулу,
   {{0x6282a126,0x2d4b004d,0x6729007e,0x00000000}},	//   gboo, jøen_, čejs, --,
   {{0x28b202d5,0xdb0209af,0x7b1600c4,0x21697595}},	//   _जामि, rtlø, pšuv, щили_,
   {{0x98aa00b6,0xddc90a39,0xdb0200f2,0x6282008c}},	//   době_, jceš, stlø, aboo,
   {{0xe8d90174,0x62820188,0x5ed40a43,0x00000000}},	//   _gwụ_, bboo, থানে, --,
   {{0x0d8517de,0xe8a8030b,0xf2120134,0x6b8d007f}},	//   плин, _कञ्च, kọhọ, _łago,
   {{0xb364008f,0x25a900a1,0x1ddb00aa,0x00000000}},	//   _църк, nual_, बिधत, --,
   {{0x2b4005db,0x2a69a127,0x4cd30a43,0x00000000}},	//   _skic_, _agab_, তাভু, --,
   {{0xbb460219,0x28ca0285,0x6b73020a,0x78bb14f3}},	//   зенк, ाजसि, _băga, đuvl,
   {{0x7d0aa128,0x691000bc,0x25a901ff,0x00000000}},	//   _elfs, _käeg, kual_, --,
   {{0x25a92664,0x316d2200,0xdddb33f4,0x14ac0096}},	//   jual_, _juez_, lauž, _चालण,
   {{0x3eada129,0x25a9a12a,0x4dda00ca,0xcdf600ca}},	//   lget_, dual_, _לחנו, _ממני_,
   {{0x6282a12b,0x3ce8149b,0x8c42364c,0x7d0600e8}},	//   yboo, जारे_, _пеше, īkst,
   {{0x3ead1bdf,0x628201af,0x7d062224,0xea8a0a95}},	//   nget_, xboo, ūkst, _убил_,
   {{0x316d0314,0xf6510018,0x00000000,0x00000000}},	// [b660] _nuez_, ہئے_, --, --,
   {{0x6282211d,0xd884001c,0x00000000,0x00000000}},	//   wboo, _تهدی, --, --,
   {{0xc95300a1,0xf2120174,0xe73a22fb,0xae1d0714}},	//   _רמת_, pọkọ, _ген_, _बेसन_,
   {{0xcfc300c7,0x25a9061d,0xe29756f6,0x69c402a1}},	//   ্মান, bual_, зац_, _kpie,
   {{0x3eada12c,0x62825902,0x237f005f,0xcb13006e}},	//   dget_, rboo, _čuje_, עלד_,
   {{0x673ba12d,0x7bc31d4e,0x62823337,0x69c40042}},	//   čuje, _opnu, sboo, _mpie,
   {{0x62828bc9,0xdfda00e5,0x00000000,0x00000000}},	//   pboo, съл_, --, --,
   {{0x3ead0c2e,0x3da62c22,0x69c43430,0xb2260012}},	//   gget_, проб, _opie, _ембл,
   {{0xa0a60138,0x5d540476,0x316d16e7,0xdbcb0328}},	//   _наад, мкит, _guez_, dóñe,
   {{0xcb9802ec,0x48d70033,0xa61700ca,0x98aa02c6}},	//   ової_, _সক্র, פקיד_, robě_,
   {{0xa9f7000d,0x6efc00fd,0xc05900d6,0x25a9a12e}},	//   ुन्छ_, _débr, _дії_, zual_,
   {{0x61e00141,0xcb0b1855,0x776602a1,0xbd8700d1}},	//   _krml, сход_, _nikx, _کنون_,
   {{0x76460084,0xa6b40033,0x25a9a12f,0xfe46007b}},	//   _nyky, ুযায়, xual_, _эндо,
   {{0xa3df03a2,0xd90f00bf,0xa3bca130,0x61e000c4}},	//   तिम_, اید_, _अहं_, _mrml,
   {{0xc7c40b26,0x1cbb040a,0x8c4101bf,0x69c4084e}},	//   нсти, _המוע, ößte, _epie,
   {{0x6d48a131,0x25a9a132,0x64430034,0x61e001b9}},	//   llda, tual_, żnik, _orml,
   {{0xa63400d6,0xdb020131,0x6d48a133,0x7b1600c6}},	// [b670] енті, bulâ, olda, ršut,
   {{0x64c700b7,0x3ead64d3,0x00000000,0x00000000}},	//   रजेश, zget_, --, --,
   {{0x28b2896a,0x25a96e70,0x3ead0212,0x80bf0285}},	//   _जाति, sual_, yget_, ल्फे,
   {{0x27fe1206,0x2d9900d2,0x80bf00b6,0x00000000}},	//   ätne_, ásek_, ल्ने, --,
   {{0x672d2db7,0xd6d800ae,0x3165042c,0x964713a4}},	//   mnaj, _этэ_, _pilz_, _хэнд,
   {{0x69dd00aa,0x657d209b,0x7b1600e7,0x656f01b5}},	//   ivse, _itsh, nšur, _iuch,
   {{0xdfce00e3,0x656fa134,0xdb09016d,0x672da135}},	//   ليو_, _huch, rudê, onaj,
   {{0x656fa136,0x6d5a34fa,0xa3da009f,0xe3b200c1}},	//   _kuch, emta, ़िर_, _שױן_,
   {{0x5187013d,0x3ead9c53,0x61e00106,0x00000000}},	//   _хуба, rget_, _grml, --,
   {{0x656f0eb8,0x69dd02dd,0x2f230139,0x6ea9178c}},	//   _much, dvse, _bègè_, _टाकु,
   {{0x656f4453,0x69c4a137,0xfaa61107,0x00000000}},	//   _luch, _spie, мано, --,
   {{0x6d48a138,0x656fa139,0xdb02037a,0x657d0415}},	//   alda, _ouch, pulí, _otsh,
   {{0x657d01bb,0x672da13a,0x656fa13b,0xdce302a1}},	//   _ntsh, dnaj, _nuch, _jinċ,
   {{0xdce20220,0xa3c209c4,0x65672c64,0x7f490c2f}},	//   _zvoľ, ्बम_, _nijh, lleq,
   {{0x18670aec,0x2f230065,0xdbcb002b,0x657d9e1b}},	//   дари_, _gègè_, póñe, _atsh,
   {{0x656fa13c,0x69c00233,0xeab23a1d,0x00000000}},	//   _buch, çmes, _شعب_, --,
   {{0x656f1d2b,0x2bd500c3,0xf7431107,0x65678c92}},	// [b680] _cuch, धिका, тето, _bijh,
   {{0x656f3236,0x80bf0034,0x764600d4,0x00000000}},	//   _duch, ल्मे, _vyky, --,
   {{0x6d430063,0x657d0415,0x776600bd,0x00000000}},	//   _mkna, _etsh, _tikx, --,
   {{0x2bf60130,0x4e0d3d34,0xaac104f8,0xfe6713c3}},	//   ומען_, िनाई_, ष्पक, _لد_,
   {{0xc693040a,0x2fc50167,0x6d48003e,0x00000000}},	//   _באר_, _aplg_, ylda, --,
   {{0x60c10063,0x26c201ff,0x6d4602c6,0x00000000}},	//   _cblm, _hbko_, ůkaz, --,
   {{0xd01000e3,0x656f6d7e,0x66040103,0xa0670284}},	//   طلة_, _zuch, lyik, маља_,
   {{0x6d43a13d,0xdd9a016d,0x00000000,0x00000000}},	//   _akna, ошо_, --, --,
   {{0x660451d2,0xd1b3015a,0xdb2501f9,0x00000000}},	//   nyik, _لینک, ósít, --,
   {{0x672d0335,0x28c01a09,0xf0a700ae,0x00000000}},	//   znaj, श्मि, _окул_, --,
   {{0x672d007f,0x6d4802c3,0x660405bd,0xa6b30033}},	//   ynaj, rlda, hyik, ঁড়িয়,
   {{0xdd8f00cd,0xa3df2125,0xdce20031,0xd52b0139}},	//   _چون_, तित_, _uvoľ, _kọ̀n,
   {{0x6ef50074,0xdd8f0867,0x6abd0088,0x672d3da7}},	//   _náby, _نون_, rfsf, vnaj,
   {{0x656f12c5,0x61e400c2,0x20010364,0xab940291}},	//   _ruch, äily, ähig_, _закљ,
   {{0x656fa13e,0xb8820181,0xdb020428,0x65670381}},	//   _such, _číta, bulà, _rijh,
   {{0x63a50146,0x656701bb,0x656fa13f,0x66040027}},	//   vrhn, _sijh, _puch, fyik,
   {{0x672d2efd,0x05740604,0xdb020328,0x660401f9}},	// [b690] rnaj, نالد, atló, gyik,
   {{0x88c400a5,0xdb025374,0x63a50094,0x26c201c8}},	//   ęści, mulá, trhn, _ebko_,
   {{0x56951111,0x656fa140,0xb0d9023a,0x391400ae}},	//   _пант, _wuch, _योगग, _рмэр,
   {{0x656fa141,0x798d533a,0x60c10085,0x3dc601dc}},	//   _tuch, _kwaw, _sblm, _opow_,
   {{0xe664100f,0xaac10034,0xdb020103,0x2fc50063}},	//   _атро, ष्यक, nulá, _splg_,
   {{0x2c0e0167,0x26d900cb,0x798d083e,0xdce302a1}},	//   ानां_, _haso_, _mwaw, _vinċ,
   {{0x26d9a142,0x798d12ed,0x00000000,0x00000000}},	//   _kaso_, _lwaw, --, --,
   {{0x26d90a00,0xdb02a143,0xd1bb0037,0x798d019f}},	//   _jaso_, kulá, _واذا_, _owaw,
   {{0x2d990068,0x26d9a144,0x2d8b025a,0x2bd10285}},	//   ése_, _maso_, èce_, _तनहा,
   {{0xdb022e16,0x26d9a145,0x00000000,0x00000000}},	//   dulá, _laso_, --, --,
   {{0x8b262de9,0x798da146,0x6b5f01d3,0x00000000}},	//   едне, _awaw, _lūgu, --,
   {{0x28b21fbb,0x26d977fe,0x798d5fa6,0xa3c200af}},	//   _जाहि, _naso_, _bwaw, ्बत_,
   {{0xdca51bec,0xdb020437,0xf1e2397e,0x645a003e}},	//   _зали, gulá, पियन, _útiv,
   {{0xfe7902c6,0x26d9026d,0x6846065c,0x00000000}},	//   lců_, _aaso_, енга, --,
   {{0x26d9a147,0x672445fe,0x3b0a0291,0x00000000}},	//   _baso_, tiij, _неко_, --,
   {{0x6d411571,0xfe7900b6,0xdb027fbc,0x8c1a00ca}},	//   lola, nců_, bulá, _מוצי,
   {{0xe5a30cfc,0xdce3007e,0x26d9a148,0x05aa1a5c}},	// [b6a0] лити, _linč, _daso_, явай_,
   {{0x6d415b9d,0xaac1000d,0x8aff0022,0x69d6a149}},	//   nola, ष्ठक, _duƙu, _isye,
   {{0x26d9a14a,0x660496aa,0x661600a5,0x29290220}},	//   _faso_, syik, szyk, ýtať_,
   {{0x6d41a14b,0x6724008a,0xe29200e3,0x6b5643b3}},	//   hola, qiij, اذا_, lágb,
   {{0x6d413656,0x68fea14c,0xfe7902c6,0x00000000}},	//   kola, _kopd, dců_, --,
   {{0x6d410479,0x00000000,0x00000000,0x00000000}},	//   jola, --, --, --,
   {{0x6d41a14d,0x7cf600ae,0xdce30357,0x257621d0}},	//   dola, _târz, _cinč, _hæl_,
   {{0xb1830244,0x6e2d0a39,0x26c0a14e,0xdce30a39}},	//   šťan, _žaba, nfio_, _dinč,
   {{0x6d41a14f,0xe2a60088,0x68fe02ac,0x00000000}},	//   fola, æðum_, _oopd, --,
   {{0x6d41a150,0x798d05bd,0x00000000,0x00000000}},	//   gola, _rwaw, --, --,
   {{0x69d613e0,0xac180686,0xfe7902c6,0x798da151}},	//   _asye, фону_, bců_, _swaw,
   {{0x60daa152,0xdb0245de,0xbebd00c6,0x00000000}},	//   _hatm, tulá, liūn, --,
   {{0x6d41a153,0xc33300a1,0x26d9a154,0x60daa155}},	//   bola, רור_, _raso_, _katm,
   {{0x6d415418,0xa3c20abe,0xd0480092,0xbebd0138}},	//   cola, ्बा_, _sadə, niūn,
   {{0x26d911ce,0x26c041ac,0x60daa156,0x3cf71629}},	//   _paso_, ffio_, _matm, _سعود_,
   {{0xdb022299,0xd6d82f1f,0xf7700018,0x798d646a}},	//   pulá, нту_, صاف_, _twaw,
   {{0x7aeda157,0xe5735e51,0xe4a71048,0xa2b6030b}},	// [b6b0] _inat, اطر_, ерео, ैभन्,
   {{0x6fe004a9,0xaab10aa6,0x81d60033,0xdb0200f2}},	//   पटां, _झाँक, িমা_, gulæ,
   {{0x26d9a158,0x7aed0088,0x6b9a5383,0x64150037}},	//   _taso_, _knat, nstg, خواط,
   {{0x6d41a159,0x66fb10e9,0x8aff03e3,0x7aff009e}},	//   zola, _एकटक_, _tuƙu, _joqt,
   {{0x7aeda15a,0xe4a73db3,0xdce30433,0xfe7900b6}},	//   _mnat, _прво, _sinč, vců_,
   {{0xeafe0640,0x60daa15b,0x44380167,0x6b9a1ca4}},	//   _उक्त_, _catm, _fxr_, kstg,
   {{0x6d41a15c,0xaab1009f,0xe53400c2,0x7aeda15d}},	//   vola, _झांक, _серь, _onat,
   {{0x6455a15e,0x6d412ea3,0xdce3197e,0x7aed3eb7}},	//   _izzi, wola, _vinč, _nnat,
   {{0x6d41a15f,0x6f09063f,0x60daa160,0x200900d9}},	//   tola, rkec, _fatm, ņai_,
   {{0x7aed4e05,0x270e1161,0x25a90bb6,0x60da0313}},	//   _anat, _सत्र_, iral_, _gatm,
   {{0x25a90220,0x6d580090,0xa3da0034,0xbf8b001c}},	//   hral_, _dhva, ़िए_, _رئال_,
   {{0x6d41a161,0x25a9a162,0x74c10d75,0x68fe00f9}},	//   sola, kral_, र्तृ, _sopd,
   {{0x6d41a163,0x60da03e0,0xfe7008ba,0xd6b90033}},	//   pola, _yatm, _ادم_, ুযায,
   {{0x6d410188,0x7aed01a8,0xdca53715,0x69a30034}},	//   qola, _enat, _раки, _कटरी,
   {{0xa96721fd,0x673b031a,0x257601cd,0xd8230fe3}},	//   тира_, čujn, _sæl_, адри,
   {{0x212700fe,0x6b560103,0x7c2e0328,0x6d580216}},	//   hinh_, ságb, úbre, _zhva,
   {{0x1666430b,0x645506b0,0x26c00150,0x68fea164}},	// [b6c0] твам, _azzi, rfio_, _topd,
   {{0x7aed02e6,0x257604c8,0xd91000fb,0x00000000}},	//   _znat, _væl_, _ایس_, --,
   {{0xa3df0f73,0x60da0c45,0x212700de,0x25a90270}},	//   तिष_, _ratm, dinh_, aral_,
   {{0x60da071d,0x130a0fe9,0x2aeb023a,0x00000000}},	//   _satm, ьней_, टाएँ_, --,
   {{0xdb021484,0x161a02d5,0x645506b0,0x60daa165}},	//   pulæ, _नेचर_, _ezzi, _patm,
   {{0xa3df2397,0x00000000,0x00000000,0x00000000}},	//   तिश_, --, --, --,
   {{0xd00f00e3,0x2d9d022b,0x20070103,0xdb0200b3}},	//   يله_, _avwe_, gyni_, erlí,
   {{0x6d5802e6,0xa3df3b30,0x00000000,0x00000000}},	//   _shva, तिर_, --, --,
   {{0x32461994,0x60da0233,0x212700fe,0x224700ae}},	//   _реаг, _tatm, binh_, _апти_,
   {{0x61e2013c,0x645a04c8,0x00000000,0x00000000}},	//   mvol, _útis, --, --,
   {{0x61e2a166,0xdb0232f4,0x3fa5071c,0xaa95007e}},	//   lvol, kulä, _مصنف, линч,
   {{0x7e7b4d39,0x6b9a18ef,0x69c8020a,0xbb93007b}},	//   ccup, rstg, ăden, шающ,
   {{0xf2d307a6,0x61e22e84,0xceb300ca,0x79a700e5}},	//   בער_, nvol, _כיף_, ърне,
   {{0x6d5800e9,0x25a90092,0xa8a42ac0,0xaca40174}},	//   _uhva, vral_, ирск, _kpọz,
   {{0x394301d3,0xd91800c2,0xe894013f,0x7aed009c}},	//   rojs_, тья_, рась, _tnat,
   {{0x7aeda167,0x473429b6,0x7bca05bd,0xdb02042c}},	//   _unat, ансс, _ipfu, gulä,
   {{0x273704f9,0xe6642383,0x00000000,0x00000000}},	// [b6d0] għna_, атфо, --, --,
   {{0x58d50084,0x61e21c74,0x2ba90403,0x21270023}},	//   _соот, dvol, _किमा, xinh_,
   {{0xdd860260,0x212700fe,0x61e2730c,0xb88202c6}},	//   _گو_, vinh_, evol, číte,
   {{0x25a9a168,0x7bca0169,0xef1f007f,0xf679006e}},	//   pral_, _mpfu, ężko_, _ראָמ,
   {{0xdd861b67,0x28c0000f,0x29014f9b,0x3f9e033b}},	//   _دو_, श्वि, _koha_, _avtu_,
   {{0xadc30065,0xe3b30421,0x7bca0537,0x9582007f}},	//   _gbẹk, _پرس_, _opfu, żące,
   {{0x6455a169,0xb4c12ebd,0x2901a16a,0xf3670a52}},	//   _uzzi, ्जी_, _moha_, _атан,
   {{0xa3c2320a,0xdce300d8,0x2127020b,0x7e7b0231}},	//   ्बर_, _pinď, sinh_, ucup,
   {{0x629900bf,0x7bca05bd,0x7e7ba16b,0x2007003e}},	//   mawo, _apfu, rcup, syni_,
   {{0x6299a16c,0x637300bd,0x14c6521f,0x7e7b00f3}},	//   lawo, _aħni, र्पण, scup,
   {{0x5edb0033,0x00000000,0x00000000,0x00000000}},	//   ভাবে, --, --, --,
   {{0x6299a16d,0x2f110139,0xaca30139,0xdb0900d4}},	//   nawo, _fága_, _isọk, budí,
   {{0xed4e9f1d,0x6da53549,0x29010146,0xdb020c19}},	//   _го_, _сила, _boha_, ktlö,
   {{0xdce301d3,0xeb9900d3,0x00000000,0x00000000}},	//   _finā, _зик_, --, --,
   {{0xab2a0084,0x6299a16e,0xe73a185c,0x00000000}},	//   _пока_, kawo, еев_, --,
   {{0x236d00a5,0x224d01ff,0x00000000,0x00000000}},	//   _niej_, _oyek_, --, --,
   {{0xdce30029,0xe73702fd,0x224d8a45,0x00000000}},	// [b6e0] _zinā, ует_, _nyek_, --,
   {{0x79840270,0x61e20036,0xdb02007b,0xa3c2a130}},	//   _itiw, vvol, sulä, ्बल_,
   {{0xdb029ede,0x6e2d09ac,0x00000000,0x00000000}},	//   pulä, _žabl, --, --,
   {{0xf8c00285,0x28c02918,0x24870342,0x05240033}},	//   श्रय, श्रि, ınma_, বকের_,
   {{0xf1265550,0xdb090072,0x00000000,0x00000000}},	//   лько, xudí, --, --,
   {{0x61e22ba3,0x26d20060,0xbebd013f,0xdfd00037}},	//   rvol, leyo_, siūl, قيت_,
   {{0x3d07033a,0x61e210ec,0xa3df0213,0x6299a16f}},	//   ाउने_, svol, तिः_, bawo,
   {{0x26d216ed,0x61e21044,0x656e009c,0x6aa422f5}},	//   neyo_, pvol, _hibh, _ndif,
   {{0x9d141c00,0xa0b60867,0x798402a4,0x00ca00ae}},	//   идич, _محاص, _ntiw, _плак_,
   {{0x6aa40032,0x26d200f9,0x0203085f,0x00000000}},	//   _adif, heyo_, _узун, --,
   {{0x9b5900c9,0xef860508,0x61d405fa,0x79846413}},	//   киот_, _слеп, _धनुष, _atiw,
   {{0x2901a170,0x656e83af,0x7de608ba,0x26d20b58}},	//   _soha_, _libh, _مستم, jeyo_,
   {{0xf2d30130,0x644e03e3,0x26d2220a,0x6aa40150}},	//   זער_, _lybi, deyo_, _ddif,
   {{0x6aa41c40,0x14c65ed7,0x28c0023a,0x656ea171}},	//   _edif, र्मण, श्लि, _nibh,
   {{0x79840174,0x19580084,0x7bca05bd,0x644e0973}},	//   _etiw, уары_, _upfu, _nybi,
   {{0x2ba900af,0x656e0a02,0xa3e80287,0x6b56660e}},	//   _किता, _aibh, बिन_, pága,
   {{0x291800e3,0x2901005c,0x2bdc0569,0x6f020231}},	// [b6f0] bhra_, _toha_, यिका, _mooc,
   {{0x291857e5,0xb4c10176,0x62804fb5,0x00000000}},	//   chra_, ्जे_, _afmo, --,
   {{0x6299a172,0x644e0124,0x656e01f7,0xa87a00ca}},	//   tawo, _cybi, _dibh, _באתר,
   {{0x6f02008a,0x656e03ea,0xdb02a173,0x644e00eb}},	//   _nooc, _eibh, stlö, _dybi,
   {{0x6299a174,0xf99f06a3,0x69cb00bc,0xb60700e5}},	//   rawo, nsè_, _äged, _сянк,
   {{0x656ea175,0x777700bd,0x00000000,0x00000000}},	//   _gibh, _kuxx, --, --,
   {{0xfe71054f,0x629960a2,0x6f0279af,0xc0780120}},	//   يدة_, pawo, _booc, усії_,
   {{0x3eb956ef,0x00000000,0x00000000,0x00000000}},	//   üst_, --, --, --,
   {{0x7afd007e,0x6b840117,0x6f02138f,0x00000000}},	//   djst, _čiga, _dooc, --,
   {{0x656e01fa,0x61e9a176,0x1d252cf5,0xdca51009}},	//   _xibh, _irel, рмом, јани,
   {{0x5ea70081,0xf99f06a3,0x69cda177,0xd5b70034}},	//   ক্ষে, syèl_, _apae, इंडज,
   {{0xda6644ab,0x6f0201cb,0x2bb60ed5,0xab2a0e20}},	//   ивни, _gooc, _अमरा, тома_,
   {{0x82d60105,0x4a4300e5,0x26d20027,0x00000000}},	//   בורג_, жняв, veyo_, --,
   {{0x26d2019f,0x61e90113,0xdce3078e,0x00000000}},	//   weyo_, _mrel, _dină, --,
   {{0x7d0300e3,0x6f026252,0x61e90124,0x96965598}},	//   _ions, _yooc, _lrel, ираш,
   {{0x06865be9,0x61e9020a,0x644e5141,0x656e8332}},	//   рган, _orel, _rybi, _sibh,
   {{0x7d03a178,0x78bb005f,0x6b560018,0xa52608a1}},	// [b700] _kons, đuvr, lágo, амад,
   {{0x64a66e90,0x26d2a179,0x7d03a17a,0x399b021e}},	//   ража, seyo_, _jons, _שייד,
   {{0x61e90328,0x7d03a17b,0x93460fbe,0x26d2861b}},	//   _arel, _mons, анже, peyo_,
   {{0xf99f06a3,0x66e630fd,0x7d03a17c,0x644e0094}},	//   zyèm_, _тома, _lons, _vybi,
   {{0x644e0067,0x98a300d9,0x7bc1007a,0xd24f001c}},	//   _wybi, lijā_, htlu, ونم_,
   {{0x656e01b5,0x25a00491,0x2fcc0072,0x6f020188}},	//   _uibh, msil_, _ppdg_, _sooc,
   {{0xdfd00080,0x64a30265,0x03a30b2c,0x98a300d9}},	//   سية_, _фаса, _миро, nijā_,
   {{0x61e9354e,0x3ec3163d,0x7d03033c,0x2616278e}},	//   _frel, осьб, _aons, पैथी_,
   {{0x61e9a17d,0xe0da1a9c,0x24980f5a,0x7d030632}},	//   _grel, _ива_, _kerm_, _bons,
   {{0xdceb00d3,0x8fa61693,0x28b200b6,0x00000000}},	//   _rugă, _важе, _जागि, --,
   {{0x25a001d4,0xa3df0034,0x6c340037,0x00000000}},	//   hsil_, तिए_, صفحا, --,
   {{0x25a0a17e,0x98a301d3,0x9b270566,0x4cd30033}},	//   ksil_, dijā_, рфол, তাগু,
   {{0x7d039e34,0xdd8e0018,0x777702a1,0x5ebe0033}},	//   _fons, _کوڈ_, _suxx, ্যদে,
   {{0x7d03a17f,0x2d8620e3,0x00000000,0x00000000}},	//   _gons, _itoe_, --, --,
   {{0x6b560072,0xf1fa0336,0x00000000,0x00000000}},	//   cágo, ्हड़_, --, --,
   {{0x6d48a180,0x25a00090,0xa3c2121d,0x7d0343da}},	//   loda, fsil_, ्बई_, _zons,
   {{0x249801cb,0xd49b0c3f,0xe6670ff7,0x7d038af6}},	// [b710] _berm_, вре_, ртво, _yons,
   {{0x44f405e1,0xa8a70f08,0x6e2d0094,0xf487872f}},	//   опус, _трик, _žabk, руан,
   {{0x61e908a9,0x98a300d9,0x9cd700a1,0x39460037}},	//   _srel, cijā_, שובה_, _íosa_,
   {{0xfaff01e5,0x2ba90abe,0x6b5d33c3,0x00000000}},	//   një_, _किसा, légb, --,
   {{0x2498a181,0x672d0010,0x26cb023e,0x6d48a182}},	//   _ferm_, miaj, _ibco_, koda,
   {{0x61e90b18,0x660d1e59,0x672da183,0x1c06009f}},	//   _vrel, myak, liaj, शहाल_,
   {{0x6d48a184,0x660d178b,0x83520018,0x237802a1}},	//   doda, lyak, _کھلا, _gurj_,
   {{0x7d03a185,0xf838040a,0x28a708fa,0x283800a1}},	//   _sons, ינות_, कृति, ינוך_,
   {{0x660d3d3a,0xa3df2fc2,0x7d03a186,0x6d480150}},	//   nyak, तिक_, _pons, foda,
   {{0x6d4802e6,0x7bc101bf,0x660d0270,0x672d00bc}},	//   goda, ttlu, iyak, hiaj,
   {{0x660d0193,0x672d0239,0x3ea60154,0x2d9fa187}},	//   hyak, kiaj, _fdot_, ssue_,
   {{0xa3e8000f,0xf1bb000f,0xfaff023b,0x6b560103}},	//   बित_, _ईमान, gjë_, rágo,
   {{0xfce55782,0x6d48a188,0x7bc1a189,0x5d8500e3}},	//   _голо, boda, stlu, _التل,
   {{0x7d1a3d25,0x2f180103,0x6d48a18a,0x97da05b6}},	//   chts, _vége_, coda, льбу_,
   {{0x31d4074c,0x00000000,0x00000000,0x00000000}},	//   _धन्ध, --, --, --,
   {{0x98a300d9,0x6b5d0257,0x25a000bc,0x691000bc}},	//   rijā_, tége, tsil_, _käek,
   {{0x660da18b,0x7c2401c2,0x98a301d3,0x00000000}},	// [b720] gyak, _ƙirg, sijā_, --,
   {{0x2ed404dd,0x25a0a18c,0xaa7b2347,0x0446455b}},	//   _दस्त, rsil_, ndýn, безн,
   {{0x6b5d00fb,0x25a0a18d,0x4adc007a,0x845a22e4}},	//   sége, ssil_, _बसाव, урат_,
   {{0x1db70455,0x734900d6,0x0f1100c3,0xeb76006e}},	//   _आमंत, ачів_, ़सोस_, צענץ_,
   {{0x249800a1,0x6d48a18e,0xc29701b3,0x660d05bd}},	//   _term_, yoda, скіх_, cyak,
   {{0x61432c13,0x69c00233,0xc05a084c,0xb97b021e}},	//   печа, çmey, лій_, אנסי,
   {{0x6d481b32,0xf4870068,0x956201c2,0x0877006e}},	//   voda, _چاہی, ttمf, זעצט_,
   {{0x6d48a18f,0xba3b02ac,0xf77300d7,0x00000000}},	//   woda, laïe, הקה_, --,
   {{0x6d48a190,0x62824fcb,0x6ce6097a,0xa0a60da5}},	//   toda, mcoo, біне, _газд,
   {{0xa3bc030b,0xdb02042c,0xd24f0076,0x672d024a}},	//   _आमा_, hrlä, _أنك_, ziaj,
   {{0x6d482c5a,0x00000000,0x00000000,0x00000000}},	//   roda, --, --, --,
   {{0x2ba907e2,0x660d1114,0x6d48a191,0x6f1b7a2c}},	//   _किरा, yyak, soda, chuc,
   {{0x6d48a192,0x63ab00a5,0x672d2c7e,0x2bda1fbb}},	//   poda, ągni, viaj, _बनवा,
   {{0x672d00a5,0x47d20081,0x29050088,0xf7730037}},	//   wiaj, হিনী, ðla_, كار_,
   {{0xe8d90294,0xd7f803a0,0x672da193,0x00000000}},	//   _ntụ_, бут_, tiaj, --,
   {{0x660d0d7f,0x6b5d0103,0xec3700ca,0x6e2d05db}},	//   tyak, ségb, _לאור_, _žabi,
   {{0xe8d900ac,0x645c440d,0x23660580,0x799603a8}},	// [b730] _atụ_, _azri, dmoj_, _gwyw,
   {{0xe6c008c5,0x660da194,0xba3b0309,0x00000000}},	//   čišć, ryak, raïd, --,
   {{0x8cca0789,0x3e6f01e8,0x660d03ec,0x73d90360}},	//   त्यो, _kötü_, syak, рдер_,
   {{0x325510f7,0xd6db7cbf,0xa3aa09c3,0x00000000}},	//   овер, _сто_, _गटर_, --,
   {{0x28c005d4,0x673d029a,0xf487061b,0x00000000}},	//   श्कि, _ijsj, _губн, --,
   {{0x644000a5,0x216930fd,0xa99c0266,0xc24401b3}},	//   _śmie, шили_, נבור, чнік,
   {{0xdbf1030b,0x6f1b5b15,0x6282026d,0x7f490231}},	//   _přít, thuc, bcoo, toeq,
   {{0x0d850c58,0xe8b6046e,0x00000000,0x00000000}},	//   олин, _अञ्च, --, --,
   {{0x645c0063,0x0cc40714,0xfe6e00d1,0x2fde042c}},	//   _zzri, वभूम, نگه_, _estg_,
   {{0x929d007f,0x00000000,0x00000000,0x00000000}},	//   _koło, --, --, --,
   {{0x6f1b1003,0x28c40034,0xeb990291,0x69df8b29}},	//   phuc, _लॉगि, јим_, _asqe,
   {{0xbfb40f36,0xd2500068,0x4421014b,0xba3b01cb}},	//   _رحمت, _آنے_, izh_, zaïe,
   {{0x4e780391,0xdca5120a,0x7de7001c,0x7dc40076}},	//   _احمد_, _дали, _دسام, _فتوك,
   {{0xdc6900d3,0x00000000,0x00000000,0x00000000}},	//   _калд_, --, --, --,
   {{0x186a10ab,0x869a0d1d,0x00000000,0x00000000}},	//   рави_, итат_, --, --,
   {{0x7c2d0d2a,0x81d00033,0x2a4b0174,0x00000000}},	//   _ƙirƙ, ষিত_, ụhọ_, --,
   {{0x7ae4a195,0xd7f8002d,0x44210325,0x637a0154}},	// [b740] _iait, ţă_, ezh_, _kůng,
   {{0x7ae4a196,0x69c402a1,0x2f1820ed,0x8c3c013c}},	//   _hait, _iqie, _méga_, bağd,
   {{0x7ae452ad,0x7af60c96,0x6b5d00fd,0x7b2b02c6}},	//   _kait, _knyt, léga, dřuj,
   {{0x7ae40a00,0x74130037,0xfaff023b,0x7af602c3}},	//   _jait, بوما, hmën_, _jnyt,
   {{0x7ae4a197,0x69c60068,0x6282a198,0x6b5d00fd}},	//   _mait, ntke, rcoo, néga,
   {{0x7ae4a090,0x62821ca4,0x45d900c1,0xfba90096}},	//   _lait, scoo, _פֿרא, _किंम,
   {{0xea0100de,0x6b5d42d7,0x6f1900f0,0x7af607ee}},	//   _đậu_, héga, _blwc, _onyt,
   {{0x7ae4a199,0x3da6004d,0x98a300c6,0x00000000}},	//   _nait, ороб, miją_, --,
   {{0xaf0733c6,0x69c402a1,0x98a300c6,0x00000000}},	//   تقيم_, _nqie, liją_, --,
   {{0x7af600a1,0xad260037,0x85f7006e,0x40961372}},	//   _anyt, تربو, קציע_, _фрат,
   {{0x7ae4a19a,0x98a30138,0x747b006e,0x6f19030a}},	//   _bait, niją_, יניג, _flwc,
   {{0x7ae40a62,0x74ca04f8,0x25b200d4,0x3f8e0027}},	//   _cait, स्तृ, kryl_, mpfu_,
   {{0x7ae4a19b,0xfce62569,0x00000000,0x00000000}},	//   _dait, _модо, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2db009d,0x7ae42198,0x46880174,0x37072c3b}},	//   _नसल्, _fait, _ọtị_, очав,
   {{0x7ae4a19c,0xba3ba19d,0xab280859,0x98a300c6}},	//   _gait, raïb, _моја_, diją_,
   {{0x690b05fe,0xaded0187,0xdb020146,0xd8cb0a29}},	// [b750] _qües, जियन_, nulý, _кынд_,
   {{0x929d00a5,0x7ae40a00,0x6abd5cfe,0x98a300c6}},	//   _poło, _zait, lgsf, fiją_,
   {{0x7ae402e8,0xb4ab00a5,0x98a300c6,0x00000000}},	//   _yait, _गयी_, giją_, --,
   {{0x6abd1842,0x44211175,0x8cca0034,0xd8380031}},	//   ngsf, rzh_, त्तो, úče_,
   {{0x68e50084,0x237f08a9,0x823400cd,0x5eb90033}},	//   _kahd, _čuju_, ورها, _আসলে,
   {{0x673b02e6,0x68e5a19e,0x29030085,0x00000000}},	//   čuju, _jahd, njja_, --,
   {{0xa2953ad2,0x68e5a19f,0x98a301b3,0x657d07ee}},	//   _наві, _mahd, ciją_, _hush,
   {{0x657da1a0,0xdfce00cd,0x68e5007b,0x00000000}},	//   _kush, ايي_, _lahd, --,
   {{0x7ae4a1a1,0xc3320142,0x2d8d0350,0x00000000}},	//   _rait, _נומ_, upee_, --,
   {{0x7ae4a1a2,0x68e559d5,0x657d8f6f,0x80b406ea}},	//   _sait, _nahd, _mush, _обух,
   {{0x7ae42805,0xfaff023b,0x657d9acd,0xe572006e}},	//   _pait, rmën_, _lush, ײַז_,
   {{0x657501c2,0x2fc70124,0x2f180113,0xfaff0216}},	//   _lizh, mtng_, _téga_, smën_,
   {{0x657d219c,0x7ae42306,0x68e50188,0x98a300c6}},	//   _nush, _vait, _bahd, ziją_,
   {{0x5fbf030b,0x7ae437d8,0x29030052,0x6b5d014b}},	//   _एमाल, _wait, gjja_, réga,
   {{0x7ae4a1a3,0x657d0364,0x69c6a1a4,0xf8632b16}},	//   _tait, _aush, stke, евро,
   {{0x657d8f75,0x691000bc,0x2903010a,0x7ae403ea}},	//   _bush, _näev, ajja_, _uait,
   {{0xf1da00a5,0x68e5a1a5,0x7abb00ca,0x65750052}},	// [b760] _मैंन, _fahd, _הצפו, _bizh,
   {{0x657da1a6,0xd5af048f,0x6b56016d,0x98a300c6}},	//   _dush, افل_, dági, tiją_,
   {{0x3c2101e9,0xa87b00a1,0x387a044c,0x2fc705db}},	//   _eгvv_, _לאיר, _igpr_, jtng_,
   {{0x657da1a7,0x98a3013f,0x2b81a1a8,0xf7460aec}},	//   _fush, riją_, _móc_, _хемо,
   {{0x657da1a9,0xaac1030b,0x98a30138,0x673b0f1c}},	//   _gush, ष्टक, siją_, čujt,
   {{0x28c03245,0x6455025b,0x2d8200b6,0xf8c00473}},	//   श्चि, _fyzi, íkem_, श्चय,
   {{0x04432d7b,0xbbda030b,0x2b810023,0xb4b8278e}},	//   _зерн, _बनेक, _nóc_, छली_,
   {{0x543b00a1,0x671c0c16,0x657d03e3,0xadf4008d}},	//   _העלא, नसिक_, _yush, дпиш,
   {{0x43430058,0x657d008c,0xe12600f6,0x00000000}},	//   _четв, _xush, _емаи, --,
   {{0x2b810023,0x00000000,0x00000000,0x00000000}},	//   _bóc_, --, --, --,
   {{0xdbf1030b,0x2b8100de,0x69c00428,0x0cc408c0}},	//   _přát, _cóc_, àmen, वभौम,
   {{0x60c416a2,0x7c4201d3,0x636300bc,0x290c02c3}},	//   đimu, _ātrā, rõng, ödan_,
   {{0x6abd032e,0x00000000,0x00000000,0x00000000}},	//   rgsf, --, --, --,
   {{0xb4ab00a5,0x61ed01d4,0xb4e6000d,0x67d5294a}},	//   _गये_, çilə, भयो_, могу,
   {{0x2b810019,0xd7f8625b,0xb9052397,0x3157006e}},	//   _góc_, пут_, _नस_, פילן_,
   {{0x443f02e6,0x7d0aa1aa,0x68e50078,0x657d2db0}},	//   _ću_, _hofs, _wahd, _push,
   {{0x1bea0c13,0x68e5a1ab,0x657d5b9b,0x6aad05bd}},	// [b770] टिवल_, _tahd, _qush, _idaf,
   {{0x04670562,0xe61f0150,0x798da1ac,0xdb028116}},	//   птем, _ffôn_, _itaw, buló,
   {{0x69100006,0xedd9030b,0x1e18049d,0x238100c6}},	//   _päev, _भन्छ, धनुष_, _vėjo_,
   {{0x657da1ad,0x6b560161,0x3d230139,0x636300bc}},	//   _tush, tági, _kéwù_, kõne,
   {{0xbebd00c6,0x798d02a1,0x7d0a041c,0x00000000}},	//   kiūr, _jtaw, _oofs, --,
   {{0xdb1b0084,0xe4e400d6,0x798d0239,0x6b56037a}},	//   lttä, _пісн, _mtaw, rági,
   {{0x2054013d,0xd006008f,0x00000000,0x00000000}},	//   нтър, деще_, --, --,
   {{0xdb1b00c2,0x6aada1ae,0x6b56037a,0x798d6113}},	//   nttä, _ndaf, pági, _otaw,
   {{0x798d1071,0x2b81a1af,0x2d9956e5,0x6289431b}},	//   _ntaw, _sóc_, èse_, _ifeo,
   {{0xee36868a,0xb4ab030b,0x6aad05bd,0x691000aa}},	//   ьны_, _गयो_, _adaf, _jäet,
   {{0x3c6502ec,0x798da1b0,0x7c240022,0xcb6a23b9}},	//   ьког, _ataw, _ƙira, жане_,
   {{0x2b810023,0x6b5d01f9,0xcf270076,0x00000000}},	//   _vóc_, ségn, _عراي, --,
   {{0x80c4030b,0xc6120033,0x1dc10285,0x6aad00eb}},	//   _रामे, _সেনা_, _शमित, _ddaf,
   {{0x2b810028,0x3ebf05fe,0x3d230139,0x69100f06}},	//   _tóc_, lgut_, _déwù_, _näet,
   {{0x798d2645,0xa3dc03b3,0x6f0b039f,0x00000000}},	//   _etaw, _तैं_, _kogc, --,
   {{0x3ebfa1b1,0x2c0a030b,0x7b060072,0xaa4f0174}},	//   ngut_, ाहरू_, _lóuz, ụgụt,
   {{0xf50a1bf9,0x8c3c2ddc,0x00000000,0x00000000}},	// [b780] онал_, mağa, --, --,
   {{0xb4b800a5,0x3ce7a1b2,0x34d800a3,0x00000000}},	//   छले_, _janv_, ड़ेद, --,
   {{0x6f0b01cb,0x00000000,0x00000000,0x00000000}},	//   _oogc, --, --, --,
   {{0xdb090430,0x6f0b063d,0x00000000,0x00000000}},	//   ardæ, _nogc, --, --,
   {{0xb5fb0146,0x316a1d54,0x00000000,0x00000000}},	//   _vzác, ошко_, --, --,
   {{0x26c061b9,0x29187d1c,0x00000000,0x00000000}},	//   lgio_, nkra_, --, --,
   {{0x2bdda1b3,0xadc30139,0x7d0a02ac,0x6f0ba1b4}},	//   _फैला, _ipẹj, _rofs, _bogc,
   {{0xef9100cd,0x6910007a,0x26c0a1b5,0x00000000}},	//   ایند, _käes, ngio_, --,
   {{0x8c3c0092,0x2918a1b6,0x6b8d00c4,0x00000000}},	//   dağa, kkra_, _čaga, --,
   {{0x6b5d04ea,0x5edb0033,0x7d0a023b,0x9ffa0037}},	//   tégo, ভাগে, _qofs, _وراء_,
   {{0xdb1b0d64,0xccf8030b,0x798d00a5,0x34b700a1}},	//   yttä, dmět_, _staw, ופים_,
   {{0x7bc80a9f,0xef690076,0x00000000,0x00000000}},	//   rtdu, _فإنه_, --, --,
   {{0xff2700bf,0xdb1b0052,0xa3e50e4c,0x00000000}},	//   _تبلی, lutë, _बैन_, --,
   {{0xfc2f0979,0x7e627405,0x3ea4a1b7,0x00000000}},	//   احی_, _izop, lamt_, --,
   {{0xba3ba1b8,0x36d55bee,0x9be6004d,0xdb1b0052}},	//   caïn, новр, _цілк, nutë,
   {{0x26c00020,0x6d5aa1b9,0x8cca1c05,0xadc30065}},	//   ggio_, llta, त्रो, _apẹj,
   {{0x798da1ba,0xc61200c7,0x16340927,0x6d5aa1bb}},	// [b790] _utaw, _সেবা_, ветя, olta,
   {{0x29180149,0x6d5a010a,0x00000000,0x00000000}},	//   ckra_, nlta, --, --,
   {{0xa7751756,0x6d5a19da,0x317f0381,0x691000bc}},	//   _плоч, ilta, _suuz_, _väet,
   {{0xae0e0fef,0x6595153d,0x6d5a5427,0x7e620372}},	//   िहान_, _паму, hlta, _ozop,
   {{0xf1a70cc0,0xa159947a,0x00000000,0x00000000}},	//   френ, паду_, --, --,
   {{0x25a92ddc,0xa2db00b6,0xd59a00ca,0x2f1101cd}},	//   msal_, _नसक्, _מבשל, _lágt_,
   {{0x25a9a1bc,0x44250e9f,0x7e62063d,0x691000b7}},	//   lsal_, _ål_, _azop, _käer,
   {{0x6d5aa1bd,0x2616009d,0xf364002d,0x00000000}},	//   elta, पैकी_, _атун, --,
   {{0x98a30138,0xee397e1f,0x25a9a1be,0x3ebfa1bf}},	//   siję_, яни_, nsal_, rgut_,
   {{0xb69b022b,0x271c07ad,0x25a9a1c0,0x00000000}},	//   _goâv, _नत्र_, isal_, --,
   {{0xc4d200c1,0x25a90491,0xed5900e7,0x7e62063d}},	//   נגט_, hsal_, juže_, _ezop,
   {{0x6d5a0049,0xed59042d,0x25a90b12,0x441a00ca}},	//   alta, duže_, ksal_, פורס,
   {{0x6b56016d,0x776d037a,0x88e40033,0x8c3c0847}},	//   xágu, dmax, মাসক, rağa,
   {{0x291e4ce5,0x8c4501a0,0x7f5ba1c1,0x8d65448a}},	//   óta_, _пеле, lluq, _явле,
   {{0x9d1a00c1,0x46f63d7b,0x7c842efb,0xc052006e}},	//   _מוסט, нчат, _руче, ָזן_,
   {{0x7c2d0044,0x66e34a6f,0x2918a1c2,0xeab20076}},	//   _ƙarf, лоса, skra_, _صعب_,
   {{0xea0100ef,0x26c03b21,0x05662636,0x377504d9}},	// [b7a0] _đầu_, rgio_, еван, тырс,
   {{0x7d7a006e,0x6910007b,0x2ca5a1c3,0x779400d1}},	//   פרעג, _väes, nald_, _لیسا,
   {{0x389b0130,0x25a900f9,0x395f01c2,0x6b8b044c}},	//   _מיינ, asal_, ɓus_, _îngă,
   {{0xfe670dd0,0x2ca58d53,0x96ba03c5,0x00000000}},	//   _مد_, hald_, _عاجز_, --,
   {{0xa3e50251,0x3ce0063c,0x2ca53229,0x6d5a0212}},	//   _बैठ_, _कसले_, kald_, ylta,
   {{0x672403ec,0x2ca501cd,0xdb1b0052,0x1c0f0336}},	//   lhij, jald_, tutë, ाहाल_,
   {{0x4ac6009d,0x7e626a51,0xe29a00f3,0x201a0031}},	//   _वाढव, _szop, _нав_, ápi_,
   {{0x6d43a1c4,0x6724007e,0x00000000,0x00000000}},	//   _ajna, nhij, --, --,
   {{0x2ca502fe,0xb146074b,0xa3e80c8c,0x3ea40709}},	//   fald_, _знал, बिक_, ramt_,
   {{0x3ea412ab,0xdb1b0052,0x61e25eab,0x00000000}},	//   samt_, putë, mwol, --,
   {{0xe571006e,0x9f4c00d4,0x6d5aa1c5,0x00000000}},	//   יַט_, _hrdí_, rlta, --,
   {{0xa4fd000c,0x25a90188,0xd00f001c,0x661600ce}},	//   _उच्च_, ysal_, _دلم_, kyyk,
   {{0x2ca501bf,0x298b008f,0xdb1b0094,0x61e21d7f}},	//   bald_, ясно_, nuté, nwol,
   {{0x63be0094,0x398603a8,0x00000000,0x00000000}},	//   kupn, _dôs_, --, --,
   {{0x67d43967,0x9848008f,0x63be169c,0x61e202db}},	//   лору, еята_, jupn, hwol,
   {{0x63be005a,0x61e2a1c6,0x25a9a1c7,0x7bcf007f}},	//   dupn, kwol, tsal_, ńcuc,
   {{0x25a924da,0x7c2d01c2,0xf6530cc8,0x00000000}},	// [b7b0] usal_, _ƙarg, ائز_, --,
   {{0x2edd0789,0x7d1a00aa,0xf9900037,0x61e201cb}},	//   _मस्त, nkts, _ابي_, dwol,
   {{0x25a9a1c8,0x0fdc01e4,0x00000000,0x00000000}},	//   ssal_, _मनगढ, --, --,
   {{0x67240ab2,0x25a9030b,0x62750037,0x6b5601f9}},	//   chij, psal_, نهائ, lágr,
   {{0xdd860504,0x6664013d,0x5f040d77,0xe5c72766}},	//   _خو_, _бърз, वान्_, _ясно,
   {{0x78a70559,0xccf800b6,0x7bd80922,0x00000000}},	//   najv, změr_, _opvu, --,
   {{0x7c28031a,0x63be0167,0x2ca58a95,0x22950037}},	//   jzdr, cupn, vald_, _للأس,
   {{0x25660257,0x2ca5a1c9,0x63b80220,0x61e24434}},	//   rôle_, wald_, ávne, bwol,
   {{0x62841711,0x2ca507ee,0x62990027,0x00000000}},	//   žioc, tald_, mbwo, --,
   {{0x2f115346,0x61e4026a,0x256600fc,0x00000000}},	//   _págs_, çile, pôle_, --,
   {{0x8c451a53,0x00000000,0x00000000,0x00000000}},	//   тене, --, --, --,
   {{0x2b16008f,0x39860131,0xdb0900b3,0x1ee70a85}},	//   тьор, _pôs_, nsdè, _سوتی_,
   {{0xb5fb0103,0x6aa60063,0x0b43018a,0x6f0904e9}},	//   _szán, rakf, рнян, mjec,
   {{0x6fd80378,0x9e64258b,0xaca30294,0x6f091f63}},	//   _महमू, _свід, _kpọk, ljec,
   {{0xea010028,0x61e200a5,0x98a352c3,0x672401cb}},	//   _đấu_, zwol, рисе, thij,
   {{0x66040a00,0x2eed0063,0x6b83a1ca,0x6f1b0365}},	//   txik, ndef_, _iung, nkuc,
   {{0x6724a1cb,0x6d41a1cc,0x6b83a1cd,0x06830290}},	// [b7c0] rhij, onla, _hung, ргун,
   {{0x6b83a1ce,0x6724023f,0x63be0579,0x6d41a1cf}},	//   _kung, shij, tupn, nnla,
   {{0x6d41a1d0,0x6b83a1d1,0x68fe028d,0x7984a1d2}},	//   inla, _jung, _inpd, _huiw,
   {{0x6b8393b6,0x6441a1d3,0x63be015c,0x61e26113}},	//   _mung, _žlic, rupn, twol,
   {{0x9c7c0618,0x6f091b36,0xaca30174,0x6b830d18}},	//   leče, djec, _apọk, _lung,
   {{0x61e20150,0x6aa4a1d4,0x854700c6,0x6d4101cb}},	//   rwol, _leif, _plėš, jnla,
   {{0x03a33b4c,0x6b83a1d5,0xb4dea1d6,0x6363007a}},	//   _висо, _nung, ढ़ी_, sõna,
   {{0x04431e11,0xdb1b00fd,0x3ea204c8,0xd46700ae}},	//   _тесн, puté, úkt_, _рисе_,
   {{0x91e34cb0,0x5d540cba,0x3eb90037,0x6b83024a}},	//   _коте, лкит, ósta_, _aung,
   {{0xb0c94f3a,0x8c3c0555,0x00000000,0x00000000}},	//   _रायग, bağl, --, --,
   {{0x9c7c0ea3,0x6b83a1d7,0x6b5da1d8,0x6f09a1d9}},	//   ječe, _cung, légi, bjec,
   {{0x6b83a1da,0xddcf2bcb,0x79840113,0x6d41a1db}},	//   _dung, žešk, _buiw, anla,
   {{0x645ca1dc,0x6aa4a1dd,0x7def0103,0xb0c90b42}},	//   _lyri, _deif, rősö, _रामग,
   {{0x7984057a,0xa13d03a8,0x00000000,0x00000000}},	//   _duiw, _gwŷd, --, --,
   {{0xf7731790,0x28d23245,0x6b83a1de,0x6b56137f}},	//   لار_, द्धि, _gung, rágr,
   {{0x6aa400eb,0x62800167,0x99e40031,0x27fe0212}},	//   _geif, _ngmo, žňav, åtna_,
   {{0x657c06a8,0x79840044,0x7aed00f9,0x645c020e}},	// [b7d0] _birh, _guiw, _iaat, _ayri,
   {{0x7aeda1df,0x6b8328e6,0xe5c41009,0xb8670781}},	//   _haat, _yung, јсто, _لاجو,
   {{0x7aeda1e0,0x6b831f72,0x5ea80033,0x389a00ca}},	//   _kaat, _xung, _গানে, _איתנ,
   {{0x7c2401c2,0x00000000,0x00000000,0x00000000}},	//   _ƙirj, --, --, --,
   {{0x7aed122e,0x6f092acb,0x69cf3edc,0x2249026a}},	//   _maat, vjec, ntce, çak_,
   {{0x645c38d5,0x7aeda1e1,0x1bf405d4,0xa0690a51}},	//   _fyri, _laat, ेमाल_, нала_,
   {{0x6f0937f6,0xb60300d4,0x272700fe,0x69cf01ff}},	//   tjec, skáč, _cõng_, htce,
   {{0x765d02fd,0x6b83a1e2,0x7aeda1e3,0x6e29a1e4}},	//   _kysy, _rung, _naat, tzeb,
   {{0x6aa4a1e5,0x6b8314a5,0xdce30d62,0x6f0901ee}},	//   _reif, _sung, _sinđ, rjec,
   {{0x6b830979,0x61e9a1e6,0x6e29043f,0x6f090268}},	//   _pung, _isel, rzeb, sjec,
   {{0xb5fb0068,0x7aed0517,0xfaa66804,0x3dcd043f}},	//   _szál, _baat, лано, stew_,
   {{0x7aed39b8,0x6b83020b,0x69cf13ea,0x00000000}},	//   _caat, _vung, ftce, --,
   {{0x3f850918,0x9c7ca1e7,0x6b8323af,0x7aed008c}},	//   _hulu_, veče, _wung, _daat,
   {{0x6b83a1e8,0x92df0081,0x2f180018,0x3f85a1e9}},	//   _tung, তায়_, _régi_, _kulu_,
   {{0xc81502ec,0x7aed9c47,0x3f851711,0x9c7c0128}},	//   аєть, _faat, _julu_, teče,
   {{0x7bc1a1ea,0x61e9a1eb,0x3f8500a4,0xeccf1e05}},	//   mulu, _osel, _mulu_, त्रफ,
   {{0x7bc1a1ec,0x765d02e0,0x645ca1ed,0x166663df}},	// [b7e0] lulu, _cysy, _syri, увам,
   {{0xb4de09d0,0x7aed3165,0x9c7c2f54,0x3f8500c2}},	//   ढ़े_, _zaat, seče, _oulu_,
   {{0x7bc1a1ee,0x9c7ca1ef,0x657c0084,0x61e94a05}},	//   nulu, peče, _virh, _asel,
   {{0x645c3173,0x6b5d384d,0x7bc100ae,0x636300aa}},	//   _vyri, tégi, iulu, sõnn,
   {{0x7bc1a1f0,0x657c00f9,0x765d0150,0xc6120081}},	//   hulu, _tirh, _gysy, _সেরা_,
   {{0x7bc15e80,0x645c01b3,0x3f8575d6,0xdce300d9}},	//   kulu, _tyri, _bulu_, _minē,
   {{0x7bc1a1f1,0xd5471807,0x61e9a1f2,0x6b5d01f9}},	//   julu, _спре_, _esel, ségi,
   {{0x3f8503b4,0x7bc1a1f3,0x60c80513,0x6d58a1f4}},	//   _dulu_, dulu, _wcdm, _skva,
   {{0x7aed2550,0x2ba60285,0xf26a00ae,0xd33501b3}},	//   _raat, कीना, _чиал_, _тэры,
   {{0x7aeda1f5,0x7bc1a1f6,0x2dd70037,0x9c7c906d}},	//   _saat, fulu, ابية_, ječc,
   {{0x7bc1496a,0x7aeda1f7,0x3f85a1f8,0xdeef0d4f}},	//   gulu, _paat, _gulu_, _лы_,
   {{0xb5fb00fb,0x7aed0694,0x317e02a7,0x6da600c9}},	//   _szám, _qaat, _hitz_, _бида,
   {{0x7aed8ca9,0x3f85a1f9,0xa2cc28fb,0x00000000}},	//   _vaat, _zulu_, _हान्, --,
   {{0x7bc16a21,0x6d580087,0x7aeda1fa,0x2727007a}},	//   bulu, _ukva, _waat, _mõne_,
   {{0x7aeda1fb,0x7bc1a1fc,0xc7b80109,0x273f007b}},	//   _taat, culu, лёт_, jänä_,
   {{0xcb6900cd,0x765d0084,0x7bcf00ae,0x28b102d5}},	//   _جمعه_, _pysy, ăcut, _जयकि,
   {{0xdb1b0146,0x4ca70033,0x3ea60381,0xb8db0033}},	// [b7f0] nutí, _খাতু, _meot_, _ইউ_,
   {{0x765d0094,0x00000000,0x00000000,0x00000000}},	//   _vysy, --, --, --,
   {{0x765d00a5,0x61e93079,0xb97a00ca,0x0467a1fd}},	//   _wysy, _ssel, _שנתי, утам,
   {{0x92eb00e3,0x14c7009d,0x317e01ff,0xdb1b7c4d}},	//   عراق_, _लावण, _aitz_, kutí,
   {{0x7bc1a1fe,0x3f85a1ff,0xa3e50fef,0x693601d3}},	//   zulu, _sulu_, _बैर_, zņem,
   {{0xf77f0b88,0x7bc1a200,0x1fb53715,0x61e9a201}},	//   _hiç_, yulu, асир, _vsel,
   {{0x6b5d00fd,0x7bc100ae,0x2af5009f,0x7e0d00b6}},	//   légu, xulu, इयाँ_, ाङ्ग_,
   {{0xd34309e5,0x7bc1a202,0xdcf8a203,0x61e909a1}},	//   _افری, vulu, _divč, _tsel,
   {{0x2bdd0034,0xb5fb0103,0xfaff0052,0xdb0800d2}},	//   _फैजा, _száj, hmës_, álík,
   {{0x7bc147d5,0x3f85a204,0x6ffc044c,0x00000000}},	//   tulu, _tulu_, _băcă, --,
   {{0x30840080,0x237f0154,0xa2cc000d,0x236d022e}},	//   _المف, _kiuj_, _हाम्, _khej_,
   {{0x7bc1a205,0x2901a206,0xb5fb033d,0x4ac60096}},	//   rulu, _anha_, _vzáj, _वाळव,
   {{0x7bc1a207,0xfe9a0054,0x99e40031,0x2913a208}},	//   sulu, _סיסמ, ľňov, _boxa_,
   {{0x82760130,0xa96a0235,0x291320df,0x7c8722be}},	//   יערע_, тига_, _coxa_, _суде,
   {{0xa3e51488,0x225f2743,0xbd680b1b,0x07a61d57}},	//   _बैल_, _lyuk_, _срце_, рабн,
   {{0x273f0084,0xd91009e5,0x6fd80409,0x7b2b03e3}},	//   vänä_, _کیس_, _महसू, nƙul,

   {{0xb5fb0139,0x29130072,0x2ca7a209,0x225f0113}},	// [b800] _ayáb, _foxa_, _kend_, _nyuk_,
   {{0x33f6364a,0x26cb013d,0x2ca7a20a,0x9c7c0433}},	//   ичес, _ecco_, _jend_, leča,
   {{0x2ca7a20b,0x225f0167,0x7c2401c2,0x3958a20c}},	//   _mend_, _ayuk_, _ƙiri, mors_,
   {{0x28d2000c,0x48ee030b,0x225f03a9,0x98b80138}},	//   द्रि, इएको_, _byuk_, torė_,
   {{0x273f007b,0x317e0062,0xdb0202c3,0x00000000}},	//   sänä_, _pitz_, mslä, --,
   {{0x3958a20d,0xc05a00d6,0xd12f0781,0xc1560284}},	//   nors_, кій_, ومن_, шњењ,
   {{0xf8b300a1,0x443e42ca,0x98b1020a,0xddea001c}},	//   קשה_, _ät_, liză_, چرخه_,
   {{0x9c7c1010,0x39580257,0xdb022104,0x317e042c}},	//   ječa, hors_, nslä, _witz_,
   {{0x60ea30cc,0x3958a20e,0x2a60023e,0xcd06a20f}},	//   _имам_, kors_, _nyib_, ачни,
   {{0x3958027e,0x644300a5,0x2eef0090,0x6ffc00ae}},	//   jors_, źnie, _eagf_, _păcă,
   {{0x395816c8,0x2ba60034,0x7c2d0044,0x291313a9}},	//   dors_, _कौशा, _ƙara, _roxa_,
   {{0xee3a0d62,0x2ca71183,0x00000000,0x00000000}},	//   _ине_, _eend_, --, --,
   {{0x8d9400e3,0x3958a210,0x27fa0124,0x6ab60150}},	//   _التش, fors_, _arpn_, _ddyf,
   {{0xf77f00dd,0x6ca300e5,0x6fca00b7,0x6726033c}},	//   _siç_, _дръж, संपू, _alkj,
   {{0x6f02a211,0x228d0139,0xf77f0233,0xfaff0216}},	//   _knoc, _jókó_, _piç_, umës_,
   {{0x6c7b0105,0xfaff023b,0x37043ae5,0xdb020212}},	//   _באופ, rmës_, очув, gslä,
   {{0x2913002b,0xfaff0216,0x395834d2,0x228d0139}},	// [b810] _toxa_, smës_, bors_, _lókó_,
   {{0x2901a212,0x3958a213,0x6b5d269b,0x672609af}},	//   _unha_, cors_, régu, _elkj,
   {{0x236d023e,0x656e009c,0x6f026a84,0x00000000}},	//   _phej_, _dhbh, _onoc, --,
   {{0x1fcc0081,0x2b59a214,0x8505009f,0x6f020174}},	//   লবাস, nosc_, राहट_, _nnoc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f02a215,0x36df0174,0x93970076,0x1ae30033}},	//   _anoc, _ịpụọ_, _نجرا, যায়া,
   {{0x2ca7a216,0xd37b00ae,0x63be0995,0x00000000}},	//   _rend_, _ача_, crpn, --,
   {{0x2ca700a1,0x85051244,0x26c90239,0x6f027e2e}},	//   _send_, रावट_, ngao_, _cnoc,
   {{0x9c7c02dd,0xa1942d7b,0xdb02004d,0xa2cc00b6}},	//   veča, _матч, nslå, _हात्,
   {{0x0d827a8f,0x6f0248b8,0x61fb12cc,0x00000000}},	//   яльн, _enoc, _irul, --,
   {{0x2ca7a217,0x3958a218,0x9c7c4f2f,0x7f8500e3}},	//   _vend_, vors_, teča, _الصن,
   {{0x6f02a219,0x61fba21a,0x2ca70313,0x39580313}},	//   _gnoc, _krul, _wend_, wors_,
   {{0x9c7c0039,0x3958a21b,0x3ead0856,0x0a3a004b}},	//   reča, tors_, maet_, учны_,
   {{0xfd480174,0x9c7ca21c,0xdb020f05,0x00000000}},	//   _memọ, seča, dslå, --,
   {{0x9c7c000d,0x7d03a21d,0x7d1c3557,0x2b5902cd}},	//   lečn, _inns, örse, bosc_,
   {{0xdc3903e5,0x3958a21e,0x86992d89,0xa6860752}},	//   _aħħa, sors_, итут_, слад,
   {{0x9c7c0074,0x7ae601e8,0xa3ca009d,0x39580664}},	// [b820] nečn, mekt, ळून_, pors_,
   {{0x69c60060,0x63b80220,0x98b1020a,0xdb1b0094}},	//   muke, ávno, riză_, vrté,
   {{0x69c6a21f,0x61fba220,0xe73a1a0c,0x941800a7}},	//   luke, _arul, _бен_, _yerə_,
   {{0x61fb93c5,0x6b5d014b,0x00000000,0x00000000}},	//   _brul, légr, --, --,
   {{0x9c7c6d32,0x7ae602a7,0x69c6a221,0x023a06cf}},	//   ječn, iekt, nuke, دثات_,
   {{0x28db000c,0x9c7c0146,0x9f982e91,0x7ae6a222}},	//   म्पि, dečn, авку_, hekt,
   {{0xdfd000e3,0x64a3180b,0x69c6a223,0x74160470}},	//   ذية_, _хаса, huke, _اوزا,
   {{0x7d031909,0x61fb028d,0x69c6a224,0x7c2d0022}},	//   _anns, _frul, kuke, _ƙarn,
   {{0xa63b00c1,0x4226038f,0x7ae6a225,0x69c6921f}},	//   ָגיר, _удав, dekt, juke,
   {{0xdce30138,0x69c6a226,0x50463d78,0xdceb00c6}},	//   _minė, duke, _лезб, _mugė,
   {{0x7ae66ab7,0x628500b6,0x3ead00f9,0x2cac00f0}},	//   fekt, ěhov, baet_, radd_,
   {{0x09bf0081,0x8e860037,0x6b8100ac,0xdcf801d3}},	//   েবসা, _الإه, _ịgba, _divā,
   {{0xc3330054,0x941800a7,0x69c6a227,0x00000000}},	//   פוש_, _verə_, guke, --,
   {{0x7e62a228,0x00000000,0x00000000,0x00000000}},	//   _iyop, --, --, --,
   {{0x0d3b004f,0xd6dba229,0x7ae623ad,0x77640072}},	//   _תגוב, лта_, bekt, flix,
   {{0xf7700192,0x7ae601e8,0x69c6a22a,0xdb1b0161}},	//   فاق_, cekt, buke, butá,
   {{0xe6670e58,0xb505000f,0xdb240018,0xc5390f2e}},	// [b830] ство, रालय_, _írás, апах_,
   {{0x6d488c2a,0x6aaf0076,0xdb0217d2,0x00000000}},	//   nnda, lacf, rslå, --,
   {{0x6d48a22b,0x1aec0033,0x68e759f3,0xadea00bc}},	//   inda, টারে_, mejd, _जैसन_,
   {{0x61fb01cb,0x6d5a7236,0x321d007f,0xc2c40037}},	//   _prul, hota, tywy_, كيمي,
   {{0x6d5aa22c,0x21790dd8,0x80c41592,0x7e62695c}},	//   kota, айды_, _राखे, _nyop,
   {{0x68e71419,0x65941d57,0x9c7ca22d,0xdceb02a1}},	//   nejd, _хару, večn, _itgħ,
   {{0x7ae6a22e,0xb9260129,0x6d5aa22f,0xdfce00e3}},	//   yekt, _agwọ_, dota, نيو_,
   {{0x6d48a230,0xef193b4c,0x9c7c000d,0x672d1114}},	//   enda, рми_, tečn, nhaj,
   {{0x6b8a02dc,0x6d480088,0x3ead01df,0x7ae601ce}},	//   _aufg, fnda, raet_, vekt,
   {{0x6d5aa231,0x9c7c1b30,0x69c69df9,0x6d48004d}},	//   gota, rečn, vuke, gnda,
   {{0x5fdd0e52,0x9c7c03f1,0x63710222,0x64410dd9}},	//   _महिल, sečn, gång, _žlij,
   {{0x6d48a232,0x2fc700bf,0x69c67397,0xdb1b0094}},	//   anda, mung_, tuke, tutá,
   {{0x6d5aa233,0x2fc7a234,0x6b5d025a,0xa2cc05cd}},	//   bota, lung_, tégr, _हास्,
   {{0x6d5aa235,0x69c600d6,0x7f5b016d,0x7d03a236}},	//   cota, ruke, louq, _unns,
   {{0x2fc7a237,0x3cee02e8,0x69c60201,0x272700aa}},	//   nung_, _असते_, suke, _sõna_,
   {{0x7f4954ca,0x28db0be4,0x291e00aa,0xdb1b0844}},	//   nneq, म्बि, ötab_, putá,
   {{0x68e70021,0xf09f00ef,0x2fc7a238,0xb0c90096}},	// [b840] bejd, _đàn_, hung_, _रांग,
   {{0x2fc706dd,0x61e4008e,0x637101df,0xf53f0212}},	//   kung_, çilm, hånd, _svår_,
   {{0x2fc71a47,0x13ea00d3,0x753e0634,0x672d49c4}},	//   jung_, рмей_, ripz, bhaj,
   {{0x672da239,0xe1fa2f93,0xc7b30089,0x6d5a9e67}},	//   chaj, иге_, _קבר_, zota,
   {{0x6d480102,0x6d5a0051,0xa3e600c3,0x00000000}},	//   ynda, yota, _भनक_, --,
   {{0x6b842a94,0xf8aa0251,0x2fc701bf,0x6d5a01e9}},	//   _liig, करिय, fung_, xota,
   {{0x6d5aa23a,0x6d483229,0xa2da0034,0x4fc602b7}},	//   vota, vnda, नभद्, іска,
   {{0x68e700a5,0x6724a23b,0x6d5aa23c,0x3f82003e}},	//   zejd, nkij, wota, öku_,
   {{0xf77300a1,0x6d5aa23d,0x1ee800cd,0x628d0a39}},	//   וקה_, tota, لوژی_, žaoc,
   {{0x6d48a23e,0x2366023b,0xa3ce02d5,0x20ca3c03}},	//   unda, lloj_, _शमा_, _خبري_,
   {{0x6d5aa23f,0x6724a240,0x6d48a241,0xe61f0019}},	//   rota, kkij, rnda, _ngôn_,
   {{0x6d5aa242,0x67243b0b,0x2bdb046e,0x78a2007e}},	//   sota, jkij, _बहरा, _đova,
   {{0x6d5aa243,0x3f8c006d,0x9f4c00e3,0xb5fb0032}},	//   pota, _hudu_, _ordú_, _ayán,
   {{0x3f8ca244,0x6d5a008a,0x0e8e0174,0x637117d2}},	//   _kudu_, qota, _gịrị_, måne,
   {{0x29050555,0x63710b97,0x76ab4e5c,0xfe6d0018}},	//   ıla_, låne, итав_, _لگی_,
   {{0x7d18a245,0x9f4c0037,0x672401cb,0xa3e5278e}},	//   _hovs, _ardú_, gkij, _बैग_,
   {{0x672da246,0x7bc800ad,0x2fc701bf,0x80cd0034}},	// [b850] rhaj, ludu, zung_, सलमे,
   {{0x672d068d,0xf09f0028,0x85050f35,0x6aad022b}},	//   shaj, _đào_, राइट_, _heaf,
   {{0x80c43245,0x3eb9013f,0xa2cc0285,0xba3b014b}},	//   _राजे, ųsti_, _हाश्, maïq,
   {{0x7d18a247,0x80cd0d29,0xdceb1820,0x672400e7}},	//   _lovs, _साहे, _čiči, ckij,
   {{0x2fc7a248,0x7bc82822,0x673d0090,0x7985024a}},	//   wung_, hudu, _imsj, _kihw,
   {{0x2fc73cfb,0x3f8c1a36,0x7bc84375,0xa99c0266}},	//   tung_, _budu_, kudu, סבור,
   {{0x63710149,0xe8d900de,0x2fc701bf,0x0e8e0174}},	//   tånd, _quỹ_, uung_, _rịrị_,
   {{0x2fc7a249,0x3f8c1a7b,0x7bc8a24a,0xc6120081}},	//   rung_, _dudu_, dudu, _সেটা_,
   {{0x2fc7a24b,0x6b840006,0x2d9900dd,0x6289039f}},	//   sung_, _riig, ëse_, _igeo,
   {{0x2fc70706,0xee360138,0x3f8c0139,0x6aad030a}},	//   pung_, яны_, _fudu_, _aeaf,
   {{0x3f8c0044,0x798d0239,0x7bc8a24c,0x46cb030b}},	//   _gudu_, _auaw, gudu, िलाह,
   {{0x09e65cb1,0x1bec167f,0x612f0170,0xdb0200f2}},	//   помн, _जनरल_, _bølg, nslø,
   {{0xb0d2303f,0xa2d32a45,0x6ed00e52,0x7ed4110a}},	//   _सामग, _डान्, _धातु, _آزما,
   {{0xfe7000bf,0x14c7009d,0x6df20037,0x6f192de6}},	//   _شدن_, _लागण, _أكوا, _howc,
   {{0xab991be8,0x6724a24d,0x7bc80367,0x6aada24e}},	//   _اختر_, tkij, cudu, _feaf,
   {{0x6d41a24f,0x612f05a3,0xfaff00dd,0x753c08c5}},	//   lila, _følg, llën_, _smrz,
   {{0x6724a250,0x5bdb0469,0x6443003e,0x9c7c0dd9}},	// [b860] rkij, _बहुव, únin, ječj,
   {{0x6d41a251,0x79850169,0x272e01cd,0x9a3b00d7}},	//   nila, _gihw, _sýnd_, _לתפק,
   {{0x3d0c009f,0x2ec700c3,0x64a30aec,0x7af6a252}},	//   ़ाते_, _रफ़्त, хаха, _kayt,
   {{0x6d419f9f,0xeb9600c1,0x3f8c4050,0x6f190036}},	//   hila, לדער_, _rudu_, _nowc,
   {{0x291aa253,0x6d41a254,0x7bc8940f,0x877b0142}},	//   _kopa_, kila, zudu, _לאטי,
   {{0x25a06d5f,0x291a0084,0x3f8c3285,0xadf2034c}},	//   mpil_, _jopa_, _pudu_, _अनबन_,
   {{0xc4480814,0x23660995,0x291a037a,0x80cd1a09}},	//   _بیان_, ploj_, _mopa_, _सारे,
   {{0x57fb00ca,0x0eea00a9,0x7bc8a255,0x6d411570}},	//   מלצו, ськи_, vudu, eila,
   {{0x7d182052,0x4ac60096,0x3f8c0d19,0x6f19a256}},	//   _povs, _वाजव, _wudu_, _dowc,
   {{0x6aada257,0x7bc80706,0x3f8c0022,0xa3c30179}},	//   _seaf, tudu, _tudu_, _एटम_,
   {{0x1e8623e3,0x6db508bb,0xd12f06f6,0xb09b0089}},	//   _елем, _aşağ, _حمل_, _היבר,
   {{0x9c7c00b6,0x212c009c,0x7af6026d,0x00000000}},	//   lečk, _hldh_, _cayt, --,
   {{0xc33300a1,0xc88200a7,0x7bc81577,0x00000000}},	//   תור_, əşə_, sudu, --,
   {{0x256f00aa,0x9c7ca258,0x673d01cb,0xbebd00c6}},	//   küla_, nečk, _smsj, nkūn,
   {{0xd1480028,0xf99f06a3,0xaac6009d,0x36d5004d}},	//   yễn_, spè_, _वाचक, мовр,
   {{0x8f9b00f5,0xf09f00de,0x798d010a,0x64910087}},	//   מילי, _đàm_, _tuaw, zžič,
   {{0x9f5e023b,0x2bc422a0,0xdb0200f3,0x00000000}},	// [b870] _artë_, लंका, vslø, --,
   {{0xf994193b,0x9c7ca259,0x612f052f,0xed59015c}},	//   _ארץ_, ječk, _køle, tuži_,
   {{0x4427a25a,0x25a00009,0xdb0200f2,0x9c7c023c}},	//   án_, apil_, tslø, dečk,
   {{0x394300d9,0xaabf1492,0x99990034,0x673d003e}},	//   lijs_, ्लिक, mysł_, _umsj,
   {{0x6d414e58,0x6f19030a,0x7c2d0022,0x44210063}},	//   yila, _rowc, _ƙark, syh_,
   {{0x6d41a25b,0x394300d9,0x9c7c033b,0xe4c50281}},	//   xila, nijs_, rečj, _تصحی,
   {{0x213e023b,0xdb0200f3,0x00000000,0x00000000}},	//   _dmth_, pslø, --, --,
   {{0x6fcf009d,0x6d41a25c,0x39431b05,0x62890415}},	//   संबं, wila, hijs_, _ugeo,
   {{0x3f860154,0x00000000,0x00000000,0x00000000}},	//   _diou_, --, --, --,
   {{0x7af601d4,0x68f70188,0x63830065,0xfe42004d}},	//   _sayt, _naxd, _fìnì, тньо,
   {{0x291a0081,0x7af6a25d,0x3943735f,0x3b1b0090}},	//   _ropa_, _payt, dijs_, _boqq_,
   {{0x7af600a7,0x291a40ee,0xf1d12fc2,0x63b8025b}},	//   _qayt, _sopa_, _समान, ávni,
   {{0x6d41a25e,0xdb1b02fd,0x68f7486a,0x291aa25f}},	//   pila, yttö, _baxd, _popa_,
   {{0x61e40740,0x612f0939,0x6d411321,0xbf8a00fe}},	//   çili, _føle, qila, _đoản_,
   {{0xb8f60454,0x67030294,0x2d8f00ca,0x25740364}},	//   _हा_, _ọkai, _huge_, näle_,
   {{0x2d870565,0x66e32290,0x00000000,0x00000000}},	//   _hine_, коса, --, --,
   {{0xb5fb0018,0x2d8f00fd,0x6db500a7,0x25a002c6}},	// [b880] _szár, _juge_, _uşağ, upil_,
   {{0x3eafa260,0xc8ca00cd,0x25a0a261,0x7c2d01c2}},	//   _legt_, _بودن_, rpil_, _ƙarh,
   {{0x25a034c9,0x9c7c69ed,0xd7e232d1,0x2d87a262}},	//   spil_, večk, _पहिच, _mine_,
   {{0xfbc509c3,0x2bc51432,0xccf802c6,0x1aec0033}},	//   _विनम, _विना, zdě_, টাকে_,
   {{0x3cee009d,0xb0d2009f,0xd00f001c,0x2d9d0027}},	//   _असले_, _सादग, یله_, _ntwe_,
   {{0x332d0449,0xcf9a0831,0x2d8700d7,0x61ed04a8}},	//   _elex_, оји_, _nine_, çala,
   {{0x3994070a,0x9c7c025b,0x3d112301,0x2d8f0e78}},	//   _läs_, rečk, ताने_, _auge_,
   {{0x2d8f0022,0x2d8749b3,0xadf4001f,0x00000000}},	//   _buge_, _aine_, епиш, --,
   {{0x2d870012,0xc6200081,0x9c7c41d2,0x2d8f00c4}},	//   _bine_, _নেতা_, meči, _cuge_,
   {{0x2d87a263,0x9c7c02dd,0x2b400472,0x2d8f005f}},	//   _cine_, leči, _amic_, _duge_,
   {{0x2d8705a3,0x69c0a264,0x69c6a265,0xdb020131}},	//   _dine_, ámen, erke, mplê,
   {{0x2d873477,0x80da022d,0x7e260084,0x39430126}},	//   _eine_, प्रे, _одеж, wijs_,
   {{0x2d874820,0x9f45084e,0x69c0004b,0x00000000}},	//   _fine_, _oplê_, šmen, --,
   {{0x3eaf0ab2,0x2d87006d,0x00000000,0x00000000}},	//   _zegt_, _gine_, --, --,
   {{0x39435791,0x2bc5009f,0xc1db00b6,0x2d8f042c}},	//   rijs_, _विया, _मङ्ग, _zuge_,
   {{0x9c7c0292,0x2d87a266,0x3d0c00aa,0xd6e800ae}},	//   ječi, _zine_, ़ावे_, мфул_,
   {{0x2d8701e8,0xe7844d40,0x7bda0084,0x55752fad}},	// [b890] _yine_, туро, lttu, егат,
   {{0x2bc50a08,0x88c60081,0xe46b007b,0xdb04030a}},	//   _विमा, শ্বক, ошел_, _gwnâ,
   {{0x7c2d0044,0x7bda464e,0x00000000,0x00000000}},	//   _ƙari, nttu, --, --,
   {{0x32552863,0x2b080034,0xe81c009f,0x25c4020e}},	//   нвер, षाएँ_, नहरा_, ürlü_,
   {{0x2bc50b2b,0x332d5a7f,0xa1eb0037,0x3eaf0d87}},	//   _विभा, _vlex_, تراك_, _regt_,
   {{0x70c902e8,0x80da0569,0x7d1c0ce3,0x78b5007e}},	//   रलेल, प्ले, örsl, nazv,
   {{0x2a690172,0x13f41bc1,0x9c7c0141,0x00000000}},	//   _lyab_, _изря, beči, --,
   {{0x2d87a267,0x69c60c2e,0xdea40504,0x00000000}},	//   _sine_, yrke, نیمی, --,
   {{0x2a690197,0x78b50b14,0x6ff300a7,0x3f9e06b0}},	//   _nyab_, kazv, _məcə, _ettu_,
   {{0x6e9f02d5,0x28df0455,0x3ea2026a,0xa3c30034}},	//   _ग्रु, _पॉलि, ıkta_, _एटा_,
   {{0x2d87a268,0x69b2007a,0xcb6a5ddf,0x9f4c00d4}},	//   _vine_, _अबही, зане_, _hrdý_,
   {{0x2d87a269,0xdd950fe9,0x201800ee,0x929d007f}},	//   _wine_, _зады, _ària_, _poły,
   {{0xed4e51ef,0x2d87a26a,0x5e2702a3,0x6f0b019f}},	//   _бо_, _tine_, _تعاق, _ingc,
   {{0x2eed1507,0x2a690383,0x2d870441,0x00000000}},	//   leef_, _dyab_, _uine_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6378255c,0x2c1c00b6,0x2a6905aa,0x7bcf007f}},	//   míng, महरू_, _fyab_, ńcus,
   {{0x7ae46db1,0x9c7ca26b,0x63784103,0x69da020a}},	// [b8a0] _ibit, veči, líng, ătes,
   {{0x63710212,0x2eed029a,0xb5fb0094,0x00000000}},	//   våna, heef_, _vzáp, --,
   {{0x20c906ae,0x5ef405e4,0x6f0b0201,0xb0c944ba}},	//   _राजध, ्यम्_, _ongc, _राजग,
   {{0xeb9207a6,0x290701b9,0x3d1100b7,0x00000000}},	//   אָס_, _ònar_, ताडे_, --,
   {{0x9c7c09ba,0x2a6901fa,0x00000000,0x00000000}},	//   reči, _xyab_, --, --,
   {{0x41d102d5,0x7bda003e,0xdfd008ba,0x7b2b0d2a}},	//   _समरस, yttu, ليت_, nƙur,
   {{0x50b70080,0x7ae43dd0,0xfbc75f34,0x2d990072}},	//   ردود_, _obit, _حت_, ísen_,
   {{0x26d202c9,0x20d22ebd,0x80d20ff9,0x2eed18f0}},	//   ngyo_, _सावध, _ठावे, geef_,
   {{0xdb023421,0x020600d6,0x657e020d,0xa13502c6}},	//   mplè, _язан, omph, _šňůr,
   {{0x7ae4a26c,0xe7b10034,0x6f0b0201,0x00000000}},	//   _abit, _जबलप, _engc, --,
   {{0x7ae4009c,0x63ae0167,0x6c541aad,0x7bda0450}},	//   _bbit, _jwbn, ткну, uttu,
   {{0xf09f0019,0xbacf0081,0x7bdaa26d,0x7ae401b9}},	//   _đài_, িজ্ঞ, rttu, _cbit,
   {{0x6ea61a09,0x63780072,0x7bda01ce,0x6ff3013c}},	//   _ट्यु, mínd, sttu, _rəcə,
   {{0x7ae40283,0x00000000,0x00000000,0x00000000}},	//   _ebit, --, --, --,
   {{0x272e0088,0xc6a707c8,0x6ed70096,0xb8e900aa}},	//   _sýna_, ерзи, _यामु, _लए_,
   {{0xf77302a3,0x7b2b0022,0x63780072,0x6443007f}},	//   ااس_, rƙus, nínd, źnik,
   {{0x27350222,0x61260088,0x2a6900f9,0xe8d90023}},	// [b8b0] _lång_, _eðli, _uyab_, _quỳ_,
   {{0x7afd55e3,0x7aef59bb,0x48ab0084,0x2727007a}},	//   ldst, lect, _этим_, _mõni_,
   {{0x98c40d64,0x320448a0,0xd40400c2,0x9fbb0033}},	//   _ссыл, _army_, ляци, _অঙ্গ,
   {{0xe8d90023,0x31654056,0xa3b4007f,0x00000000}},	//   _tuỳ_, _sklz_, _फ़िर_, --,
   {{0x69dda26e,0x7aef0012,0x7afd2088,0x6378002b}},	//   ntse, iect, idst, dínd,
   {{0xa0693778,0xe61f0019,0x69dda26f,0xf9940341}},	//   мала_, _ngôi_, itse, ארס_,
   {{0x2bc5009f,0x62960b88,0xb0d200a3,0xdb1b00f2}},	//   _विधा, ıyor, _सारग, butø,
   {{0x7aef0fe4,0x7afd4b6d,0x69dd49d7,0x69cf019f}},	//   ject, jdst, ktse, kuce,
   {{0x69dda270,0x2eed1044,0xa195008f,0x6723020a}},	//   jtse, reef_, _разч, _înju,
   {{0xdb02a271,0x69cfa272,0x69c00220,0x27350856}},	//   mplé, duce, ámem, _hånd_,
   {{0x27350222,0x7aef17fc,0x7afd0126,0x69dd24e7}},	//   _gång_, fect, fdst, etse,
   {{0x69dd32c5,0x63780042,0x61e903a9,0x00000000}},	//   ftse, cínd, _kpel, --,
   {{0x2f180103,0x69cf015c,0x69dda273,0xfe9a00d7}},	//   _négy_, guce, gtse, _חינמ,
   {{0x7afd18f0,0xa02100aa,0x61e92d76,0x6378a274}},	//   adst, _ööse, _mpel, míne,
   {{0x69dd0505,0x18677b37,0x6378a275,0x290c0511}},	//   atse, вари_, líne, ıda_,
   {{0xed5900e9,0xc6c30d47,0xcf9200c1,0x69cfa276}},	//   drži_, ийск, שטן_, buce,
   {{0xb0d2009f,0x6d43010a,0x6378285b,0x69cf5354}},	// [b8c0] _सालग, _kmna, níne, cuce,
   {{0x61ed003d,0x657e5411,0x5ea80033,0xc4cc1e05}},	//   ħall, umph, _গাছে, ालेख,
   {{0xf6510068,0x273501df,0x6b5d0103,0x6d430154}},	//   لئے_, _bånd_, végz, _mmna,
   {{0x776d03be,0x7d0d01c2,0xfe67770e,0x8c1a006e}},	//   clax, _ɗasa, _ند_, וועי,
   {{0x80da0033,0x27350212,0x6d43a277,0x15430a29}},	//   _যোগ্, _sång_, _omna, _ӂерм,
   {{0xb5fb0065,0x64a344aa,0x6fd60285,0xf484001c}},	//   _ayáw, _вара, _यमदू, _مازی,
   {{0x1543634f,0x7aef0eb8,0x63bc00cc,0x61e96d49}},	//   _терм, yect, _uvrn, _epel,
   {{0x7aef4b1f,0xd0070291,0x63787c16,0x6d43063d}},	//   xect, ђење_, fíne, _amna,
   {{0xe0da0cb8,0x7aef01af,0x28d31c0a,0xd1860036}},	//   _ова_, vect, _तालि, _алай,
   {{0x217612dd,0x69cf08a9,0x273502c3,0x00000000}},	//   _рубр, vuce, _tång_, --,
   {{0x7aef59bb,0x20051912,0xdeef00d3,0x00000000}},	//   tect, _grli_, _кы_, --,
   {{0x69cf0257,0x69dda278,0x7afd4fb5,0x6d43209b}},	//   tuce, ttse, udst, _emna,
   {{0x7aef0788,0x9c7c033b,0x61e90063,0x69dd32a7}},	//   rect, veču, _xpel, utse,
   {{0x69dd7f26,0x27352ca7,0xdc550103,0x00000000}},	//   rtse, _måne_, ئریک, --,
   {{0x6d482027,0x7aef411b,0x69dd0658,0x273501df}},	//   mida, pect, stse, _låne_,
   {{0x6d4808ec,0x69dd0364,0x69cf7bea,0x7764015e}},	//   lida, ptse, puce, goix,
   {{0xb0d288ba,0x65940110,0xdb1b0212,0x7c280178}},	// [b8d0] _सांग, иату, rrtä, lydr,
   {{0x6d48132d,0x6b810294,0xb4cd0096,0x5f4406c0}},	//   nida, _ịgha, ळले_, ịghị_,
   {{0x61e9a279,0xf48700d3,0xe9df119e,0xe3b00037}},	//   _spel, туан, ltú_, قرن_,
   {{0xfaff00dd,0x6d48a27a,0xe3b000e3,0xc2c400e3}},	//   ndë_, hida, ترك_, ليمي,
   {{0x6b8d019c,0xe9dfa27b,0x672d2a36,0x320b3a89}},	//   _miag, ntú_, mkaj, بتاً_,
   {{0xf1d53db8,0x30750084,0x6d48a27c,0xe4f9006e}},	//   डंबन, луйс, jida, _אפֿש,
   {{0x62860146,0x998202c6,0xa0660aa8,0x00000000}},	//   _úkon, zyků_, лаша_, --,
   {{0x6b8d18c4,0xdb020257,0xe1f300cd,0x672d37b9}},	//   _niag, pplé, _پسر_, nkaj,
   {{0x6d4895c1,0x90e70bf4,0xa1940cba,0x61e95ee1}},	//   fida, _لسان, _вауч, _upel,
   {{0xee363e93,0x5ba900d5,0x9cf500ae,0x672d1c33}},	//   унь_, нком_, учиш, hkaj,
   {{0x6b8da27d,0x672da27e,0x20050036,0xe8d900fe}},	//   _biag, kkaj, _urli_, _huỷ_,
   {{0x7d1a023e,0x672d0234,0x20df0f8f,0x6d4802ac}},	//   ajts, jkaj, प्रध, aida,
   {{0xfce50097,0x2bc50861,0x6b8d3f1f,0x7c2d0044}},	//   _боло, _विवा, _diag, _ƙars,
   {{0x6d480b0b,0x6f1b04a3,0x8276006e,0x6e2901c2}},	//   cida, ljuc, טערע_, myeb,
   {{0x80db0285,0x00000000,0x00000000,0x00000000}},	//   _नाने, --, --, --,
   {{0x3d111349,0x6b8d019c,0x80cd045f,0x6f1d042c}},	//   तावे_, _giag, _साझे, ösch,
   {{0xa3b60336,0x6e2903b4,0x635c0631,0xe57a04b3}},	// [b8e0] चीन_, nyeb, nčne, еза_,
   {{0xdff303a2,0xfd9e0129,0xd9100470,0x850e0179}},	//   _आनंद_, _jụọ_, _بیس_, साइट_,
   {{0x6ab6008e,0xfd9e0129,0x6f1b015c,0xceb900b6}},	//   _keyf, _mụọ_, kjuc, kař_,
   {{0x6d48a27f,0xe73a02fd,0xe29a1ef0,0xdcf416a2}},	//   zida, _чем_, хад_, _čači,
   {{0x6d48a280,0x69c00031,0xa8050042,0x00000000}},	//   yida, ámeh, poñé, --,
   {{0x6ab60088,0x66040193,0xfd9e0134,0x6e290270}},	//   _leyf, mvik, _nụọ_, dyeb,
   {{0x6d48132d,0x66042f1c,0x63a9050d,0x4034035f}},	//   vida, lvik, _čeng, рейс,
   {{0xcfe700e3,0x7c280094,0x6e3b042c,0x2efd041c}},	//   افيه_, vydr, fzub, _cawf_,
   {{0x10a62457,0x6604a281,0x6b8d0013,0x50d61a37}},	//   _бизн, nvik, _riag, _مزار,
   {{0x2bc50e19,0x6b8da282,0x23660197,0x7d1a023e}},	//   _विशा, _siag, looj_, ujts,
   {{0x2056a283,0x6d480610,0x4093054f,0x6b8da284}},	//   _стар, rida, _المر, _piag,
   {{0x6d48a285,0x2bc50179,0x6ab6033c,0x6e29010a}},	//   sida, _विरा, _ceyf, byeb,
   {{0x7c3a0068,0x6d48a286,0xfe720068,0x8d9e0134}},	//   sztr, pida, _ادا_, _fọọm_,
   {{0x6604713b,0x68fe05fe,0xe9dfa287,0xfd9e00ac}},	//   dvik, _capd, rtú_, _gụọ_,
   {{0xb8fd099d,0xe9df3618,0xf77326a0,0x3d110034}},	//   _डा_, stú_, مار_, तारे_,
   {{0x96f81a6d,0xfd9e0294,0x672d0239,0xd6d85e0d}},	//   лест_, _zụọ_, ukaj, лту_,
   {{0x799603e3,0x672d3137,0xf7700214,0x2d8e8d22}},	// [b8f0] _guyw, rkaj, ساف_, _kife_,
   {{0x672da288,0x45d403a0,0x6fea0092,0x00000000}},	//   skaj, софс, _məcb, --,
   {{0xa9260029,0x53a400e3,0xdb1b002b,0x6d4f020d}},	//   _dažā, مملك, esté, écai,
   {{0x2d8ea289,0x63784d6e,0xade5007a,0x7aff009e}},	//   _life_, vínc, _कहलन_, _jaqt,
   {{0xd5af00fb,0x7aff009e,0xe8d900de,0x66040146}},	//   _رہا_, _maqt, _quỷ_, cvik,
   {{0x2cf302e8,0x34943b2f,0x2d8ea28a,0xfbc50179}},	//   _असेल_, _гарр, _nife_, _विलम,
   {{0x60de06a3,0xfd9e00ac,0x25a900f9,0x2a7f0031}},	//   òpma, _rụọ_, lpal_, ľuby_,
   {{0x6d580580,0xcf250037,0x26090592,0x290401d3}},	//   _ajva, شرعي, सिपी_, ēmai_,
   {{0xed592de0,0xef160761,0x3d11030b,0xfd9e0294}},	//   кои_, рмы_, ताले_, _pụọ_,
   {{0x61fb89e7,0xd167013d,0xed4500d6,0x6378896d}},	//   _isul, _съби, рноп, mína,
   {{0x610b00d9,0x2d8e06a3,0x66040234,0x6e3b7e64}},	//   _vēlē, _dife_, zvik, szub,
   {{0x6b660231,0x8f9a00ca,0x3e5e0129,0x6a861da9}},	//   ркма, _סיני, ịta_, илна,
   {{0x3da70ac6,0x3eada28b,0x3f8f0188,0xfd9e0134}},	//   _среб, mbet_, _iigu_, _tụọ_,
   {{0xdca50f94,0x3eada28c,0xdb021f93,0x61fb005e}},	//   _таки, lbet_, mplí, _msul,
   {{0x186a0636,0x80da030b,0x290400b6,0x2366023e}},	//   тави_, प्टे, ěma_, yooj_,
   {{0xb6a64367,0x660400d6,0x612f02b6,0x7d1c0ce3}},	//   риал, tvik, _søll, örsv,
   {{0x66030012,0x68fe00a7,0x61fb06b0,0x5976007b}},	// [b900] опта, _tapd, _nsul, _выну,
   {{0x660453bb,0x3f8f042d,0x3ead01e8,0x49910470}},	//   rvik, _ligu_, hbet_, _ریفر,
   {{0x3cdd07e2,0x6604a28d,0x61fba28e,0x66e68e20}},	//   _खाने_, svik, _asul, _кона,
   {{0x78bca28f,0xf3c91f11,0xb34702a1,0x00000000}},	//   larv, ابله_, _naħħ, --,
   {{0x23bc0065,0x9ad40174,0x63a9215a,0x4a9b021e}},	//   _bájá_, _rịlt, _čene, דינג,
   {{0x78bc8832,0x2366023e,0x316702ef,0xfaff0052}},	//   narv, sooj_, gonz_, llët_,
   {{0x61fba290,0x3f8f01c2,0xb34702a1,0x18360142}},	//   _esul, _bigu_, _baħħ, יאַל_,
   {{0x6134009c,0x256f0103,0x232708f9,0x0eea004d}},	//   _dàla, vüli_, _коси_, тьки_,
   {{0xb5fb0018,0x3f8f01e9,0x3dcd0154,0x78bc32bf}},	//   _száz, _digu_, grew_, karv,
   {{0xdce1033b,0x61e24755,0x3f8f003e,0xdce3009e}},	//   bolč, mtol, _eigu_, _pinġ,
   {{0x3ead8295,0x25740149,0x273505e8,0x78bc6de9}},	//   bbet_, väll_, _låna_, darv,
   {{0x27f80150,0x61e20239,0x2d8e00ca,0x78b7a291}},	//   dwrn_, otol, _wife_, _sexv,
   {{0x61e2a292,0x9da7013d,0x2d966321,0x78bc3e5c}},	//   ntol, _къща_, _трес, farv,
   {{0x7aff008a,0x27030019,0x78bc0596,0x3cdd034c}},	//   _waqt, _ổn_, garv, _खाये_,
   {{0xd6db10f7,0xb5fb0018,0xad1b00ca,0x61e2007b}},	//   кта_, _nyár, _בוגר, htol,
   {{0x78bc09a1,0x20110206,0x00000000,0x00000000}},	//   aarv, _ázie_, --, --,
   {{0xdb020149,0x78bc3453,0xb5fb0139,0x6378002b}},	// [b910] tslö, barv, _ayár, xína,
   {{0x25a902fa,0x78bca293,0x929d0034,0x6abda294}},	//   rpal_, carv, _małe, lasf,
   {{0x4914074c,0xdb0202c3,0x61fb0172,0x68f5a295}},	//   दारो_, rslö, _ssul, mezd,
   {{0x69ce030b,0x25a90103,0xadf80557,0x5215007b}},	//   _तिमी, ppal_, ्टान_, йдет,
   {{0x877a004f,0x2901027f,0x10a508c3,0xfaff023b}},	//   _תארי, _kaha_, билн, llës_,
   {{0x2903a296,0xb34703e5,0xa2d31344,0xe0d8004d}},	//   ndja_, _saħħ, _डाक्, иві_,
   {{0x290171b9,0xb5fb0018,0xdb090088,0x61e2010a}},	//   _maha_, _gyár, nsdó, atol,
   {{0x81e600c7,0x6378025b,0x290174c5,0x4aa700b6}},	//   _বছর_, pína, _laha_, _क्लव,
   {{0xf2d20132,0x61fba297,0x68f50018,0x929d00a5}},	//   _מען_, _usul, kezd, _całe,
   {{0x68f5a298,0xdce303e5,0x3eada299,0x290186ec}},	//   jezd, _minħ, sbet_, _naha_,
   {{0x237f023e,0xab2a0221,0x69cf0381,0x00000000}},	//   _khuj_, гона_, erce, --,
   {{0x05c70096,0xdce70233,0x5e950076,0xa3cf09a1}},	//   _लिंब, ımıy, _الإط, _शिन_,
   {{0x8e8500e3,0x78bc9910,0x2901a29a,0xdce302a1}},	//   _الشه, tarv, _baha_, _ninħ,
   {{0x7d1c0222,0x29010027,0xdb0901cd,0x00000000}},	//   örst, _caha_, fsdó, --,
   {{0x290108fd,0xd94312e7,0x236d5cd4,0x27350212}},	//   _daha_, чери, _okej_, _såna_,
   {{0xdceb00bd,0x78bc20bc,0x7bc107ee,0x00000000}},	//   _bugħ, sarv, mslu, --,
   {{0x3bc301d4,0x2901009c,0x7bc17861,0x68f505db}},	// [b920] lıq_, _faha_, lslu, bezd,
   {{0x29010027,0x236d0031,0xba4902c6,0x69c4039f}},	//   _gaha_, _akej_, ulůž, _ivie,
   {{0x69c40181,0x7bc16bb6,0x4cba0142,0x00000000}},	//   _hvie, nslu, רמעג, --,
   {{0x61e28b3f,0x69c4013f,0x59af1bc3,0x29011206}},	//   ttol, _kvie, जीकर, _zaha_,
   {{0x237f023e,0x212505db,0x7ce1022b,0x00000000}},	//   _dhuj_, _bolh_, _kňrč, --,
   {{0x7bc1a29b,0x70d20096,0x6726533f,0x00000000}},	//   kslu, सलेल, _hokj, --,
   {{0x61e22ea6,0x443e2fe7,0x1fa31402,0x7bc18f4b}},	//   stol, _åt_, прыг, jslu,
   {{0x63780146,0x29030a13,0x3f840167,0x8356001c}},	//   míno, zdja_, ummu_, _اپرا,
   {{0x63780094,0x6b4f6ace,0x171b006e,0x8e140120}},	//   líno, _lògè, רופע, ідоц,
   {{0xccfa0291,0x69cf0580,0x7bc12b31,0x6a7f0139}},	//   ући_, vrce, fslu, _làfí,
   {{0x2901a29c,0x351b00c1,0x68f50d12,0x3fcb010d}},	//   _raha_, אוינ, vezd, _مدنی_,
   {{0x290100cd,0xa3e00861,0x44770142,0x00000000}},	//   _saha_, _दमन_, מעיל_, --,
   {{0x4f6500e3,0x69cfa29d,0xf2d300c1,0xbf655bce}},	//   _بالف, urce, הער_, _بدلو,
   {{0x69c49132,0x68e900e7,0x6f02009c,0x7bc100d4}},	//   _dvie, đedo, _haoc, bslu,
   {{0x3cdda29e,0x2903a29f,0x6eae0034,0x6d4aa2a0}},	//   _खाते_, rdja_, ीरपु, _imfa,
   {{0xdb090088,0x160502d5,0xe787022a,0x2b49039f}},	//   rsdó, रिलर_, суго, _umac_,
   {{0x2901007a,0x7aeda2a1,0x69c004d8,0x6a7f0065}},	// [b930] _taha_, _ibat, ámet, _dàfí,
   {{0xdb1b00e3,0x6f02152f,0x200c3ece,0x00000000}},	//   istí, _laoc, _ordi_, --,
   {{0x69c4151e,0x69c001d3,0xf3f900e5,0x00000000}},	//   _zvie, šmet, рнеш_, --,
   {{0x6f02015c,0xd2512ba0,0x7aed009e,0x67260381}},	//   _naoc, ونا_, _jbat, _gokj,
   {{0x6d4a0501,0x7aeda2a2,0x4cd00081,0x200ca2a3}},	//   _omfa, _mbat, ত্যু, _ardi_,
   {{0x7bc10630,0xdb1ba2a4,0x1c180034,0xdce101d3}},	//   yslu, nstâ, धमाल_, kolā,
   {{0x69a01362,0x7aeda2a5,0x237f891c,0x9162020b}},	//   _गंभी, _obat, _thuj_, _xử_,
   {{0x3eb90682,0x6d4a0a75,0xf838040a,0x200703f1}},	//   úst_, _amfa, מנות_, rvni_,
   {{0x200c16ba,0x00000000,0x00000000,0x00000000}},	//   _erdi_, --, --, --,
   {{0x7aed18b1,0x3bc301d4,0x7bc10305,0x613d022b}},	//   _abat, tıq_, tslu, _sèlf,
   {{0x69c439d2,0xc4d200ca,0x6f0201f7,0x200c05db}},	//   _svie, וגי_, _faoc, _grdi_,
   {{0xf8a9004f,0x7bc1a2a6,0x28dc000d,0xcb6a594b}},	//   _יש_, rslu, _बाहि, раме_,
   {{0x2bc520cd,0x7bc1a2a7,0x3ebfa2a8,0x67260629}},	//   _विका, sslu, maut_, _rokj,
   {{0x7aed0b4a,0x7bc1611f,0x67260381,0x613d0154}},	//   _ebat, pslu, _sokj, _wèlf,
   {{0x273c0080,0x2d9f025a,0x67260167,0x07a300c6}},	//   _líne_, lque_, _pokj, дасн,
   {{0x7d03a2a9,0x7aed0134,0x2a60006c,0x00000000}},	//   _hans, _gbat, _txib_, --,
   {{0x7d03a2aa,0x2d9fa2ab,0xa52602ec,0x69c40220}},	// [b940] _kans, nque_, омад, _uvie,
   {{0x2bed05d4,0x29040029,0x7d0358c2,0x7aed00dd}},	//   _जहां_, ēmas_, _jans, _zbat,
   {{0x7d03a2ac,0x320d0063,0x3ebf0034,0x0d3a006e}},	//   _mans, _arey_, kaut_, סגעב,
   {{0x7d03a2ad,0xdcb60d88,0x320d002b,0x63780e4b}},	//   _lans, _आज्ञ, _brey_, ríno,
   {{0x3ebf0124,0x26c0a2ae,0x7d0307ee,0xdb2101f9}},	//   daut_, maio_, _oans, áték,
   {{0x7d03a2af,0x26c0008f,0x25740084,0x320d489c}},	//   _nans, laio_, käli_, _drey_,
   {{0xdfd0054f,0x256f0068,0xe80d00a3,0x2d9f034f}},	//   رية_, rült_, हिया_, eque_,
   {{0x7d0332c2,0x03671778,0x26c00451,0x256f0103}},	//   _aans, _диск_, naio_, sült_,
   {{0x7d03a2b0,0x26001687,0x320da2b1,0x00000000}},	//   _bans, रिटी_, _grey_, --,
   {{0x7aed3bec,0x200c0087,0x644000a7,0x7f4b0372}},	//   _sbat, _trdi_, _əmin, _emgq,
   {{0x7d03a2b2,0x3ebf01bf,0x6f020335,0x635c66b8}},	//   _dans, baut_, _taoc, nčno,
   {{0x20110031,0x2d9f037a,0x6d4f020d,0x3ebf6338}},	//   _ázia_, bque_, écar, caut_,
   {{0xed5a4f07,0xda7b5a71,0x2d9f3caf,0x28dc02d5}},	//   _код_, рян_, cque_, _बाशि,
   {{0x6d4aa2b3,0x7d031bfa,0x41d20789,0x635c0e4b}},	//   _umfa, _gans, _सिनस, kčno,
   {{0x28dc2748,0x69c00072,0x6d5aa2b4,0xdb0200d8}},	//   _बारि, ámer, mnta, splá,
   {{0x4c3b0054,0x7aeda2b5,0x7d0306a3,0x26c01789}},	//   _כתוב, _ubat, _zans, gaio_,
   {{0x7d03a2b6,0xd49ba2b7,0x6d5aa2b8,0x3d0f009d}},	// [b950] _yans, аре_, onta, _थोडे_,
   {{0x6d5aa2b9,0x44f400d3,0x25a60037,0x00000000}},	//   nnta, мпус, íola_, --,
   {{0xa2f502ec,0x6d5aa2ba,0x273c0076,0xf4850103}},	//   зпеч, inta, _síne_, سائی,
   {{0x6595268e,0x26c00036,0x2cbc0120,0xdb1b015e}},	//   _наму, caio_, _levd_, nstà,
   {{0x8635006e,0x00000000,0x00000000,0x00000000}},	//   _זאָג_, --, --, --,
   {{0x6d5a023e,0x1fb500ae,0xdb1b00d4,0x635c05db}},	//   jnta, псир, vrtý, bčno,
   {{0xc9540341,0x7d03a2bb,0x8fa200ba,0x613d022b}},	//   ומס_, _rans, наще, _rèld,
   {{0xef19a2bc,0xf41200ca,0x25744880,0x2ca902c6}},	//   сми_, _אפל_, väli_, _řad_,
   {{0x7d03a2bd,0x3ebfa2be,0x28dc1677,0x30a758ad}},	//   _pans, raut_, _बालि, _древ,
   {{0x1c450243,0x6d5a04de,0x613d022b,0x3ebf20ed}},	//   зном, gnta, _bèle, saut_,
   {{0x7d0300f3,0xc4d200c1,0x2d9f17fc,0x929d0034}},	//   _vans, עגט_, sque_, _zała,
   {{0x2d99132d,0x6d5aa2bf,0x7d030283,0xf53f017a}},	//   íses_, anta, _wans, _stål_,
   {{0x7d03a2c0,0x6d5a01fa,0x26c0028d,0x81e90033}},	//   _tans, bnta, vaio_, যিক_,
   {{0x7d030939,0xdb1902c3,0x00000000,0x00000000}},	//   _uans, _avvä, --, --,
   {{0xb9250129,0x26c070e5,0xdb1b25a5,0x25ab0a4b}},	//   _hapụ_, taio_, bstà, _atcl_,
   {{0x660f02ef,0x030b009f,0x2d9da2c1,0x05c7007a}},	//   _brck, _सोलह_, _kuwe_, _लिखब,
   {{0x26c0013d,0x9ad30134,0x96631da9,0x6b8405bd}},	// [b960] raio_, _dịde, екте, _ihig,
   {{0x649a0ba3,0x26c0137f,0x69c6a2c2,0x2d9d8c18}},	//   стар_, saio_, mske, _muwe_,
   {{0x69c6a2c3,0x389b0130,0xa3b60ccb,0x929d0034}},	//   lske, _ליינ, चीं_, _sała,
   {{0x637800b6,0x2d9d029a,0xe3c9034f,0x929d007f}},	//   mínk, _ouwe_, _soñé_, _pała,
   {{0x2d9d040c,0x660f03d6,0x6d5aa2c4,0xdb02004d}},	//   _nuwe_, _grck, ynta, pplæ,
   {{0x98a40138,0x67241c54,0x9f5e0031,0x867b00ca}},	//   ėmė_, ljij, _isté_, _לרכו,
   {{0xb4ca53ee,0x6d5a023e,0xbef902d5,0x2cbc010a}},	//   ोली_, vnta, ्यून_, _revd_,
   {{0x91e644aa,0x6724a2c5,0xe80d09c4,0x69c6a2c6}},	//   _нобе, njij, हिता_, kske,
   {{0x69c640a3,0x7644a200,0x444401bf,0x3ebd0090}},	//   jske, nziy, lz_, _dewt_,
   {{0x6d5aa2c7,0x613d5f86,0x69c6a2c8,0x612f01df}},	//   unta, _pèle, dske, _sølv,
   {{0x44448f9c,0x3cdd0104,0xf1d21cff,0x4c94001f}},	//   nz_, _खारे_, _सिडन, ќинс,
   {{0x4444a2c9,0x6b84a2ca,0xdee60f00,0xe4570089}},	//   iz_, _chig, _ходи, לייט_,
   {{0x6b84025e,0x6e9300e3,0x3f9e9447,0x3e850257}},	//   _dhig, _كلما, _hutu_, rêté_,
   {{0x2bc50714,0x25f2007a,0xfbcf1aaa,0x6b8483a4}},	//   _विचा, ुबनी_, ختی_, _ehig,
   {{0xc8640131,0xa4270033,0x63a9007e,0x6b8407bc}},	//   етти, _মধ্য_, _čeno, _fhig,
   {{0x4444150d,0x7bda3d48,0x3f9e1114,0x6b840036}},	//   dz_, mutu, _mutu_, _ghig,
   {{0x7bda4207,0x4444a2cb,0x69c60103,0x3d110096}},	// [b970] lutu, ez_, cske, ताचे_,
   {{0x6b8403e3,0x272e003e,0x660f0218,0x2a5800ca}},	//   _zhig, _sýnt_, _vrck, _מבחן_,
   {{0x25f90067,0x9f5e0890,0xe5700adb,0x3f9e6cbd}},	//   _उनकी_, _esté_, اطق_, _nutu_,
   {{0x2bc502d5,0x5275002d,0x42552ce3,0x25ab0a4b}},	//   _विघा, мулу, ونار, _ttcl_,
   {{0x3f9e04a3,0x44440a00,0x7bdaa2cc,0xa3cf0abe}},	//   _autu_, az_, hutu, _शिव_,
   {{0x3f9e33f4,0x2d9d1183,0x00000000,0x00000000}},	//   _butu_, _ruwe_, --, --,
   {{0x444400a5,0x7bda0673,0x660d1abc,0x64e20096}},	//   cz_, jutu, lvak, _पातळ,
   {{0xee390cd7,0x273c0b66,0x4433061d,0xdb1b0146}},	//   жни_, _kína_, myx_, ystá,
   {{0x2b1c00b7,0x660da2cd,0x612f0ac1,0x4433a2ce}},	//   यासु_, nvak, _sølu, lyx_,
   {{0x6b840a75,0x7bdaa2cf,0x69c61def,0x273c003e}},	//   _shig, futu, vske, _mína_,
   {{0x7bdaa2d0,0x660d31e8,0x25740212,0x20350781}},	//   gutu, hvak, mält_, _تفاس,
   {{0x60c3a2d1,0x09e20081,0x929d00a5,0x69c6a2d2}},	//   lanm, যবসা, _mało, tske,
   {{0x612f01df,0x25fd08d4,0xba23004d,0xfce501ce}},	//   _følt, _रैली_, вдяк, _жоло,
   {{0x69c60f56,0x7bda9a26,0x6f09a2d3,0x673da2d4}},	//   rske, butu, ldec, _alsj,
   {{0x6d41a2d5,0x6b8401b5,0x7bda00ae,0x66e6084c}},	//   mhla, _thig, cutu, мова,
   {{0x6f091d02,0x629b0019,0x69c6a2d6,0x257401bf}},	//   ndec, _nguo, pske, hält_,
   {{0x09e200c7,0xfb870260,0xdb1b0088,0xd838033b}},	// [b980] যবহা, _تدوی, fstæ, šč_,
   {{0x444408d7,0x6378a2d7,0x6d410060,0xb4ca28fb}},	//   tz_, míni, nhla, ोले_,
   {{0xd91b0130,0x68fca2d8,0xf746a2d9,0x929d00a5}},	//   _וויל, merd, _жено, _cało,
   {{0x44440d03,0x68fc8f34,0x3f9e0559,0x00000000}},	//   rz_, lerd, _rutu_, --,
   {{0x4444a2da,0x6d41063f,0x9ad40294,0x7d080149}},	//   sz_, khla, _hịst, ydds,
   {{0x3f9e08a9,0x68fc013d,0x60c3a2db,0x4421a2dc}},	//   _putu_, nerd, ganm, bxh_,
   {{0xd0100adc,0x2b0e10ed,0x6d410cc2,0x63780037}},	//   الب_, ियाँ_, dhla, híni,
   {{0x7bda03cf,0x68fca2dd,0x6f0900b3,0x00000000}},	//   vutu, herd, gdec, --,
   {{0x10a602fd,0x68fca2de,0x60c30022,0x929d00a5}},	//   _жизн, kerd, banm, _zało,
   {{0x6d414450,0x7bdaa2df,0x3f9ea2e0,0x25740212}},	//   ghla, tutu, _tutu_, mäls_,
   {{0x68fca2e1,0x660d4121,0x0e8e00ac,0xe0430582}},	//   derd, zvak, _gịnị_, _инфи,
   {{0x7c4401ac,0x291a03be,0x2cb10511,0x612f01df}},	//   _đurđ, _anpa_, ızda_, _føls,
   {{0x7bda0006,0x6d4109f7,0x68fca2e2,0x23b50af0}},	//   sutu, bhla, ferd, _kújò_,
   {{0x6d4103d8,0x7bda39fb,0x68fca2e3,0xf7730470}},	//   chla, putu, gerd, چار_,
   {{0x273c0102,0x5c06013d,0xf7731629,0x212c009b}},	//   _sína_, _цяла, نار_, _modh_,
   {{0x60c3324e,0x39950139,0x660da2e4,0x2d8ca2e5}},	//   zanm, _bùsì_, tvak, lmde_,
   {{0x68fc649a,0xa3dc009d,0x63780161,0x60c3a2e6}},	// [b990] berd, णूस_, cíni, yanm,
   {{0x69dda2e7,0x660d1cea,0x273c025b,0x6f0930e6}},	//   muse, rvak, _vína_, zdec,
   {{0x69dda2e8,0x7bc8a2e9,0xdb1b34c9,0xfe080023}},	//   luse, nsdu, rstæ, _lữ_,
   {{0x4907033a,0x6d410146,0x60c372f4,0x273c04c8}},	//   िएको_, zhla, wanm, _tína_,
   {{0xfe0800ef,0x69dd6fb1,0x7afd002d,0x60c36206}},	//   _nữ_, nuse, iest, tanm,
   {{0x613d022b,0x6f090131,0x44210036,0xdb1b0e74}},	//   _bèla, wdec, pxh_, lstä,
   {{0x69dd1842,0x60c3a2ea,0x6f0901bf,0x6d41023e}},	//   huse, ranm, tdec, vhla,
   {{0x69dd95ce,0xdb1b1680,0x7afd0133,0x2d8c0a9f}},	//   kuse, nstä, jest, emde_,
   {{0x7afd7435,0x68e501f7,0x6d41a2eb,0x6f09a2ec}},	//   dest, _ochd, thla, rdec,
   {{0x69dda2ed,0xfe080019,0x0c2539f8,0xc90a0033}},	//   duse, _dữ_, емон, _রক্ত_,
   {{0x116a03ed,0x69dd00fd,0x3b090188,0xdb1b0212}},	//   _علمی_, euse, _baaq_, kstä,
   {{0x60c1a2ee,0xf4120130,0x9f470220,0x68e5a2ef}},	//   _helm, אפט_, ktné_, _achd,
   {{0x68fca2f0,0x69dd0006,0x60c1a2f1,0xdb1b0149}},	//   terd, guse, _kelm, dstä,
   {{0xf1b20054,0xfc311be8,0x9c82033b,0xfce51009}},	//   רסם_, _محب_, ščam, _чоко,
   {{0x60c134fb,0xdb1b042c,0x80a7023a,0x273c0503}},	//   _melm, fstä, _चलने, _dínn_,
   {{0x28dc05a7,0x68fca2f2,0x14e2009d,0xb5fb058a}},	//   _बाकि, serd, _पाहण, _exám,
   {{0x6996008d,0xcf920105,0x291a005c,0x98a62f11}},	// [b9a0] _прох, רטן_, _tnpa_, _пипе,
   {{0xec0900ef,0xe57700be,0x273c0065,0x200505db}},	//   _kế_, езу_, _gínn_, _osli_,
   {{0x491d007d,0x59d8009d,0x2b40141f,0x635c0117}},	//   मारो_, भंकर, _klic_, lčni,
   {{0x661ba2f3,0x442608a9,0xe9f90065,0xb857021e}},	//   _šuke, ćo_, _afẹ_, _טייפ_,
   {{0x2d8702dc,0x20050484,0x635c02dd,0x798e0239}},	//   _ohne_, _asli_, nčni, ombw,
   {{0x3f8602e5,0x7afda2f4,0xdb1b017a,0x59d35c52}},	//   _shou_, zest, mstå, _तिसर,
   {{0x22460018,0x333f91b5,0x3f8601fa,0x7afda2f5}},	//   szok_, _flux_, _phou_, yest,
   {{0x7afd0933,0x60c1007a,0x752e0090,0x800300c2}},	//   xest, _eelm, _hobz, учше,
   {{0xdb1b0c9b,0x60c115a8,0x26c2037d,0x916200de}},	//   nstå, _felm, _meko_, _từ_,
   {{0x60c101e8,0x7afda2f6,0x26c264f2,0x69dd1bc7}},	//   _gelm, west, _leko_, vuse,
   {{0x2b400291,0x7afd0707,0x69dd0415,0x2d8ca2f7}},	//   _blic_, test, wuse, rmde_,
   {{0x69dd05a7,0xec0900de,0x9f470146,0x3f5300ae}},	//   tuse, _dế_, ytné_, nţul_,
   {{0x7afd6a33,0xdb1b0212,0x60c1037a,0x6fa80033}},	//   rest, vstä, _yelm, _গিয়ে,
   {{0x7afda2f8,0x69dda2f9,0xe80d009d,0x60c10042}},	//   sest, ruse, हिला_, _xelm,
   {{0xd7f86cfb,0x69dd0d20,0xdb1b0f3a,0x7afd4287}},	//   нут_, suse, tstä, pest,
   {{0x26c23837,0x7d0aa2fa,0x69dda2fb,0x2b402ae3}},	//   _ceko_, _hafs, puse, _glic_,
   {{0xdb1b0924,0x7d0a00dd,0x752e0090,0x26c2a2fc}},	// [b9b0] rstä, _kafs, _bobz, _deko_,
   {{0xdb1b190f,0x1be41b11,0xfaff057a,0x046700d3}},	//   sstä, _कमाल_, leë_, нтем,
   {{0x9f47135f,0xec0900de,0x69d70285,0xdb1b02c3}},	//   stné_, _xế_, _बिडी, pstä,
   {{0xd6db0d64,0x60c1a2fd,0xd3240686,0x925900c2}},	//   _это_, _selm, льчи, мает_,
   {{0x39840149,0xa2cd09a0,0x5274107a,0x6d86003e}},	//   lösa_, दृष्, лушу, iðab,
   {{0x7d0a53ab,0x98b40335,0xd1840c10,0x26c20559}},	//   _nafs, čeći_, глій, _zeko_,
   {{0xe8140789,0x60c10343,0x48e90034,0xb8141492}},	//   डिया_, _velm, _जानो_, डियम_,
   {{0x27e70222,0x439400c2,0xa2cd1dae,0x60c1084e}},	//   _ännu_, _басс, दृश्, _welm,
   {{0x60c1a2fe,0x5f7600e3,0xfaff084e,0x3f8d015e}},	//   _telm, خميس_, deë_, rmeu_,
   {{0x29cd0038,0x635c033b,0x6aada2ff,0x613400b3}},	//   dľa_, včni, _afaf, _sàlv,
   {{0xcb6a1caa,0x2b40a300,0xd11e0b3f,0x29cd0031}},	//   дане_, _plic_, पारण_, eľa_,
   {{0x3cdd3aee,0xec0900fe,0x00000000,0x00000000}},	//   _खाके_, _vế_, --, --,
   {{0xee2e455b,0x613400ee,0x8f3600d7,0x00000000}},	//   _тн_, _vàlv, _שאנו_, --,
   {{0x49990d64,0x23d11362,0xec0900ef,0x48d00081}},	//   ется_, _हिंद, _tế_, িভ্র,
   {{0xdb080d79,0x929d00a5,0x8c421612,0x8c450b21}},	//   ólóh, _całk, _веще, _шеке,
   {{0x273c025b,0xdb1b0fbc,0x752e09ac,0x41d21e93}},	//   _víno_, tstå, _sobz, _सिलस,
   {{0xb6a300d3,0xf50a00d3,0x25fd0179,0x6f0ba301}},	// [b9c0] риул, мнал_, रौली_, _magc,
   {{0xdb1b09ce,0x1dd402e8,0x14e20096,0x6f0b0372}},	//   rstå, _दिसत, _पाळण, _lagc,
   {{0xd7ca00bf,0x26c2a302,0x15fe05a7,0x6fea00a7}},	//   _توجه_, _teko_, _उनकर_, _təci,
   {{0xdb1b0160,0xdceb01d3,0x490a17ad,0xccf800d2}},	//   pstå, _augļ, ायको_, jněn_,
   {{0xcb1300f5,0x6fbe00c7,0x7af6023b,0xe2970291}},	//   ילא_, _ইমেই, _mbyt, вац_,
   {{0xd12f00e3,0x27fa0167,0x6604a303,0x395824f9}},	//   يمن_, _kppn_, mwik, nirs_,
   {{0x7af60146,0xa87a00c1,0x237d01fa,0x6f0b019f}},	//   _obyt, ואַר, blwj_, _bagc,
   {{0x657ea304,0x35a7009f,0x831a02a3,0x3ce7022b}},	//   llph, _कूड़, _تقرر_, _acnv_,
   {{0x660407ac,0x71ea0037,0x613400ee,0x2b2109a1}},	//   nwik, _زفاف_, _bàlt, यासँ_,
   {{0x205611db,0x27fa05db,0xf26700ae,0x23c6074c}},	//   _итер, _oppn_, _риул_, _लबाद,
   {{0xbd060139,0x6aad04aa,0xa3b60096,0x28dc0ff9}},	//   _abéò, _pfaf, चीच_, _बाजि,
   {{0x99ae0081,0x6604a305,0xee3a0215,0xd83f033b}},	//   _কয়েক, kwik, _оне_, ščki_,
   {{0x7d0aa306,0x6d86003e,0x63782ce2,0x9f5e0231}},	//   _tafs, rðab, líns, _estã_,
   {{0x672f3b3a,0xf99f06a3,0x6f00026a,0x8c530281}},	//   _socj, twèb_, lemc, ائیا,
   {{0x63781d32,0x3cfb00ca,0x57a402c1,0x00000000}},	//   níns, _חלונ, ишта, --,
   {{0xd6d8067f,0x2a69023e,0x6aad0051,0x48e30033}},	//   кту_, _txab_, _ufaf, য়ের,
   {{0x69c0001f,0x66040270,0xa634004d,0x80b400bc}},	// [b9d0] âmet, gwik, анті, ुराइ,
   {{0xf8b708c0,0x7af684bf,0x7bda18f0,0x00000000}},	//   _अभिय, _zbyt, ortu, --,
   {{0x82b00174,0x09340037,0xc7ab0037,0x7afa0103}},	//   _ịnọg, _خريج, _تدخل_, őtte,
   {{0x6f000094,0x2d9c377c,0xbd050065,0x657e009c}},	//   jemc, _live_, _abẹ́, alph,
   {{0x66f60341,0xe4a700d3,0xccf802c6,0xdc010033}},	//   _גמרא_, _арбо, vněn_, এমএস_,
   {{0x6f0b0415,0x00000000,0x00000000,0x00000000}},	//   _sagc, --, --, --,
   {{0x7ff50adb,0x5ebe0033,0xdb0200f3,0x2eff2a99}},	//   استا, োলনে, pplø, teuf_,
   {{0x5334824d,0xaf05136c,0x6458007f,0x8e091c16}},	//   _кест, упил, ócił, енив_,
   {{0x7bda122e,0x63780131,0x2d9c18fe,0x2018003e}},	//   ertu, rínt, _bive_, _árin_,
   {{0x9f5e0990,0x7f42a307,0x6378a308,0xbd050032}},	//   _està_, _eloq, sínt, _gbẹ́,
   {{0x6f0b2112,0x7f424369,0x63780094,0xccf802c6}},	//   _tagc, _floq, cíns, mněl_,
   {{0x273502c3,0x00000000,0x00000000,0x00000000}},	//   _måns_, --, --, --,
   {{0x7bda18f0,0x9f47030b,0xa14200d9,0xdd8e0260}},	//   artu, ntní_, _šķie, توی_,
   {{0x2d9c00a1,0x3ead00b3,0x61fb083e,0x9f5e0206}},	//   _give_, lcet_, _mpul, _istá_,
   {{0x7d012566,0x186730cc,0x6d430036,0x00000000}},	//   mels, гари_, _ilna, --,
   {{0x290c02e6,0x7af60074,0x66049e9f,0x7c3c1484}},	//   žda_, _ubyt, twik, ørre,
   {{0x558a07c6,0x637800d4,0x05661bce,0x0686489f}},	// [b9e0] ебам_, zíns, гван, уган,
   {{0x660400bf,0x090605c7,0x27350160,0x7d01093e}},	//   rwik, _спон, _sånt_, nels,
   {{0x48e9009d,0x0d3a006e,0x41c602d5,0x61fba309}},	//   _जातो_, עגעב, रीनस, _apul,
   {{0xb7db00f5,0x7d01004d,0x613d05aa,0x6378a30a}},	//   _אקטי, hels, _dèlm, víns,
   {{0x7d010501,0x799e621b,0x6b460065,0x00000000}},	//   kels, _kipw, _kógb, --,
   {{0x64a392e0,0x7d01a30b,0x63787e6e,0xf48405bc}},	//   _гара, jels, tíns, _نازی,
   {{0x2d9c14b1,0x7d010c2e,0x61fb3262,0x613400b3}},	//   _rive_, dels, _epul, _bàlr,
   {{0x2dd400c2,0x6d433bd7,0xa6d60033,0x7bda00c4}},	//   ажир, _alna, ড্রয়, vrtu,
   {{0xd2662dd1,0x7d01a30c,0xdb1b0ac9,0x00000000}},	//   _скай, fels, mstø, --,
   {{0x7d010e9f,0x6378a30d,0x5d54246b,0x61e20138}},	//   gels, píns, ркот, muol,
   {{0x9f5e132d,0x443a02ac,0xaca40129,0x7ee60037}},	//   _está_, nyp_, _ntụz, _مكان,
   {{0x6d43a30e,0xdb1b00f2,0xe9f90023,0x543b0142}},	//   _elna, nstø, _ngả_, געטא,
   {{0x2d9c001f,0x7d011707,0x61e2013f,0xfc4300cd}},	//   _tive_, bels, nuol, لپیپ,
   {{0xdd8f0f43,0x7d01a30f,0x443a00d8,0xdb040154}},	//   _فون_, cels, kyp_, _lunè,
   {{0x273c0019,0x3f9d0044,0x6d480a02,0x6d5aa310}},	//   _kính_, _yiwu_, mhda, mita,
   {{0x61e2a311,0x8c1b0796,0x8b6700d1,0x00000000}},	//   kuol, _טווי, _حاتم, --,
   {{0x613d0c56,0x80ca0081,0x6b8da312,0xdb1b3229}},	// [b9f0] _sèlm, _রান্, _ihag, dstø,
   {{0x6d5a34d2,0x273c00de,0x6d4800fe,0xb4df0966}},	//   nita, _lính_, nhda, णले_,
   {{0x61fba313,0x02d00096,0x6d5a02ef,0x69cfa314}},	//   _spul, हणून, iita, lsce,
   {{0x6d5a7688,0x521507df,0x7d01a315,0x491d030b}},	//   hita, идет, zels, माको_,
   {{0x6d5a47b8,0x7d01a316,0x90c5013f,0x6b8d7fdc}},	//   kita, yels, абле, _mhag,
   {{0xdb0401e5,0x6d5a1734,0x2903a183,0x672d1271}},	//   _punë, jita, neja_, ljaj,
   {{0x7d0102fe,0x9f47000d,0xdb0417f9,0x273c00fe}},	//   vels, stní_, _funè, _bính_,
   {{0x7d0187f2,0x2903a317,0x61e252d7,0xcb140096}},	//   wels, heja_, buol, _तोंड_,
   {{0x6d5aa318,0x7d01a319,0x3f830029,0x2903a31a}},	//   fita, tels, ēju_, keja_,
   {{0x6d5aa31b,0x6d48a31c,0x6b8d0193,0x69cf2096}},	//   gita, ghda, _ahag, dsce,
   {{0x7d0102fe,0x6b8da31d,0x69dd24a9,0xaca30134}},	//   rels, _bhag, erse, _nwụk,
   {{0x7d0101be,0x6b8d0d0a,0x672d0517,0x6d480188}},	//   sels, _chag, jjaj, ahda,
   {{0x672d1a5d,0x6b8d0694,0x9f040068,0x6d5a34d2}},	//   djaj, _dhag, _دونو, bita,
   {{0x6d5aa31e,0x6d48064b,0x290368e7,0x186a004d}},	//   cita, chda, geja_, ваги_,
   {{0x63a702dd,0x6c7900c1,0x5c79006e,0x6b8d03ea}},	//   _nujn, _באַפ, _באַה, _fhag,
   {{0x6b8d0134,0x273c0032,0x7f490231,0x00000000}},	//   _ghag, _kíni_, nheq, --,
   {{0x4b7b00c1,0x7b0800d9,0x2903a31f,0x6aa402a4}},	// [ba00] _באקו, āstī, beja_, _igif,
   {{0xf53f3813,0x14c800cd,0x443aa320,0x613d05aa}},	//   _står_, اهای_, typ_, _dèlk,
   {{0x62890113,0x69c400bd,0xdb1b00f2,0x61e20134}},	//   _azeo, _hwie, tstø, wuol,
   {{0x55e633d0,0x6d5aa321,0x1bf600c1,0x69c44197}},	//   _комб, zita, יצער_, _kwie,
   {{0xdb1b038c,0x6d5a21e9,0x64a65c28,0x69c400bd}},	//   rstø, yita, _вага, _jwie,
   {{0x6d5aa322,0x415300d6,0xf8c60cce,0x61e2a323}},	//   xita, овіс, वरिय, ruol,
   {{0x6d5a1a23,0xf1d2009f,0x6aa425f6,0x61e206e7}},	//   vita, _सिकन, _ogif, suol,
   {{0x6d5aa324,0x61e23dbc,0xdefa0138,0x290387b7}},	//   wita, puol, тык_, zeja_,
   {{0x6d5aa325,0x6b8d02e0,0x23660ca7,0x6e3b0124}},	//   tita, _rhag, mnoj_, gyub,
   {{0x236603ce,0x69dd04a3,0x6b8da326,0x6aa42d3b}},	//   lnoj_, vrse, _shag, _agif,
   {{0x273c00ef,0x6d5a0780,0x2903a327,0xa3c991dd}},	//   _tính_, rita, veja_, लीप_,
   {{0x6d5a202c,0x63a0a328,0x69c400bd,0x60c8a329}},	//   sita, _jimn, _bwie, _hedm,
   {{0x2903a32a,0x69dda32b,0x7bc302a1,0x60c80154}},	//   teja_, urse, _ewnu, _kedm,
   {{0x5ba603fc,0x69c422a5,0x63a0a32c,0x6aa406b0}},	//   _криз, _dwie, _limn, _egif,
   {{0x6b8d0099,0x6d580193,0x60c80de9,0x69c4039f}},	//   _thag, _imva, _medm, _ewie,
   {{0x236600cc,0x63a716a2,0x2903a32d,0xa3c90251}},	//   jnoj_, _rujn, seja_, लीफ_,
   {{0x236603ce,0x672da32e,0xa3c90a50,0xeabf028d}},	// [ba10] dnoj_, rjaj, लीन_, mbù_,
   {{0x6441007a,0x764d0d27,0x63a0010b,0x4a7c00ca}},	//   _ülik, rzay, _aimn, _ברחב,
   {{0x69c44274,0x00000000,0x00000000,0x00000000}},	//   _zwie, --, --, --,
   {{0x236600e7,0xa3e60336,0x66161054,0x63a70218}},	//   gnoj_, पढ़_, bvyk, _vujn,
   {{0x628002ad,0x6d581026,0x63a00128,0xe9df0037}},	//   _cymo, _omva, _dimn, nrú_,
   {{0x2bac030b,0x6280a32f,0x3d16009f,0x613d03a9}},	//   _něco_, _dymo, _भोले_, _kèli,
   {{0xe9df00e3,0xb90c0294,0x23660106,0x60c80270}},	//   hrú_, _achụ_, bnoj_, _dedm,
   {{0x753500fb,0x236608a9,0xd5430065,0x6d58417b}},	//   _hozz, cnoj_, _fẹ́l, _amva,
   {{0x6d860088,0x7f4900dd,0x62800150,0x60c82084}},	//   rðan, rheq, _gymo, _fedm,
   {{0x63a01fe8,0x61e6320e,0x4154036a,0xd1b300d1}},	//   _zimn, _åkla, _двус, _هیچک,
   {{0x69c4a330,0x7535a331,0xeb9aa332,0x66160094}},	//   _swie, _mozz, лио_, zvyk,
   {{0xa3c92a45,0x63a003be,0x6fea0092,0x7aed007e}},	//   लीय_, _ximn, _təcr, _ccat,
   {{0x3da7a333,0x3ebf26f7,0x5f7400e3,0xe9df0037}},	//   _треб, mbut_, _بالر, grú_,
   {{0x4e7a0130,0x7535a334,0x23660106,0x7aeda335}},	//   _גאנצ, _nozz, znoj_, _ecat,
   {{0xa78608ba,0xa3c916f8,0x613d00ee,0x00000000}},	//   مشرو, लीम_, _cèli, --,
   {{0x69c4a336,0x6b6b00a5,0x7aed0037,0xe9df432f}},	//   _twie, lęgn, _gcat, brú_,
   {{0x236603ce,0x99d61a37,0x75351cb2,0xd62733fd}},	// [ba20] vnoj_, _اتبا, _bozz, боте_,
   {{0x6d41a337,0x4cd900c7,0x75350451,0x63a0a338}},	//   nkla, ব্রু, _cozz, _simn,
   {{0x236602e6,0xa5dd0034,0x75353ab5,0x63a00167}},	//   tnoj_, _पिथौ, _dozz, _pimn,
   {{0x60c82188,0x2b210034,0xd37900d6,0x9f470094}},	//   _sedm, याएँ_, ачі_, ytná_,
   {{0x26c03b93,0x236603ce,0xa2aa0789,0x6d41a339}},	//   mbio_, rnoj_, टशब्, kkla,
   {{0x236600e9,0x7535a33a,0x6d4101cb,0x62800094}},	//   snoj_, _gozz, jkla, _vymo,
   {{0x63a0a33b,0x6d410579,0x23660106,0x6280007f}},	//   _timn, dkla, pnoj_, _wymo,
   {{0x62800150,0x543b00c1,0x75350036,0xe36300d3}},	//   _tymo, _געלא, _zozz, _екси,
   {{0x160e034c,0x63a10113,0x6d41a33c,0x00000000}},	//   सिटर_, _èlna, fkla, --,
   {{0x3ebf019c,0x9ad30134,0xf1bf00b6,0x7aed0dfc}},	//   abut_, _tịke, ášen_, _scat,
   {{0xdefa02fd,0x308600e3,0x9f47025b,0xa5bba33d}},	//   _был_, _الاف, stná_, _gróf,
   {{0x613d0154,0x66df0139,0x00000000,0x00000000}},	//   _rèli, _màkà, --, --,
   {{0x6e960080,0x4427a33e,0x66df0139,0x161c08c0}},	//   _الشا, ̣n_, _làkà, निफर_,
   {{0x6d41a33f,0x3f84003d,0xd90f010d,0x273c003e}},	//   ckla, llmu_, ریج_, _mínu_,
   {{0xa89904a1,0x75350982,0x273c01cd,0x00000000}},	//   ркву_, _rozz, _línu_, --,
   {{0x6b460037,0x75350036,0xdb1b042c,0x7aed063d}},	//   _tóga, _sozz, nstü, _ucat,
   {{0xa5352249,0xf1b90ca7,0x75350987,0x54a70037}},	// [ba30] онач, _krše_, _pozz, محاف,
   {{0x3ebf02e7,0x98c71612,0x66df0139,0x00000000}},	//   zbut_, _усил, _bàkà, --,
   {{0x26c0008f,0x293800c1,0x2b4900dc,0x6355004d}},	//   bbio_, _לאזן_, _klac_, овжу,
   {{0xe2f901ce,0x291303be,0xd9ed0eeb,0x6d411b62}},	//   реді_, _haxa_, _जमात_, zkla,
   {{0x6d41a340,0x7535a341,0x2b4900c4,0x291301c8}},	//   ykla, _tozz, _mlac_, _kaxa_,
   {{0xa5bb0088,0x59dc3d34,0x2b49a342,0x661d06bc}},	//   _próf, _बिसर, _llac_, _irsk,
   {{0x6d412708,0xcfb40081,0x661d0a9e,0x6d86003e}},	//   vkla, _টিউন, _hrsk, rðal,
   {{0x63b80220,0x29130072,0x26cb007e,0x1dd40034}},	//   ívne, _laxa_, _jeco_, _दिखत,
   {{0x161c000f,0xee361736,0x3ebfa343,0x26cb0072}},	//   नियर_, жны_, rbut_, _meco_,
   {{0x661d03ab,0x26c00335,0x22642347,0xa5bba344}},	//   _mrsk, zbio_, šská_, _tróf,
   {{0xdb1b0653,0x2b4903a8,0x25a301cb,0x00000000}},	//   sstý, _blac_, _mijl_, --,
   {{0xa3e104dd,0x6e24a345,0xa2cd0034,0x26cb02c6}},	//   _दिन_, _šibe, दृच्, _neco_,
   {{0xa3c9009d,0x6d418288,0x2913448b,0x5f742ce3}},	//   लीत_, pkla, _baxa_, _عامر,
   {{0x07a607c8,0x8c4513c9,0x25a30381,0x00000000}},	//   жавн, _меле, _nijl_, --,
   {{0x475a1ce8,0xe73a80c5,0x18a30358,0x26cba346}},	//   арая_, аев_, дарм, _beco_,
   {{0x661d0b27,0x236d0087,0x26cb0036,0x2b491ac3}},	//   _brsk, _njej_, _ceco_, _glac_,
   {{0x80ca0081,0x291301e9,0x26cb24f9,0xdb04034f}},	// [ba40] _রাস্, _faxa_, _deco_, _juní,
   {{0x2d85a347,0x661d0335,0xf1e0045f,0x613d0113}},	//   nlle_, _drsk, _निबन, _kèlu,
   {{0x273c0088,0x2d85a348,0x386d0364,0xdb040206}},	//   _sínu_, ille_, ßert_, _luní,
   {{0x64990a11,0xa5bb0d4e,0x03260c79,0x613d0113}},	//   стур_, _bród, юден, _mèlu,
   {{0x6726a349,0x41b600c2,0xb77b006e,0xe1ef13c3}},	//   _inkj, цсет, _כאטש, نسو_,
   {{0x61430084,0x2bda0034,0xe476002d,0x26cb0350}},	//   меча, _भिला, _дубэ, _zeco_,
   {{0xaada110f,0xb4e60ed3,0xa5bb04c8,0x273c003e}},	//   _भयंक, फली_, _próg, _fínt_,
   {{0x236d00dd,0x6d860088,0x25a30381,0xf8c60961}},	//   _gjej_, rðam, _zijl_, वरुप,
   {{0xdb1b02e2,0xcd060392,0x28bfa34a,0x00000000}},	//   rstü, очни, ्रमि, --,
   {{0xdd9006f6,0x2b491821,0xdb1ba34b,0x63770134}},	//   عود_, _slac_, mpté, ụnta,
   {{0xf1b908a9,0x2b49a34c,0x46aa0096,0x613d00b3}},	//   _vrše_, _plac_, कशाह, _pèlv,
   {{0x8cba04f8,0x2d8500c2,0x201e00c2,0x2913026d}},	//   _श्रो, alle_, _irti_, _saxa_,
   {{0xf2d31b83,0xfd0f00bf,0xf8c61efb,0x26cba34d}},	//   וער_, رجی_, वरूप, _reco_,
   {{0x26cb065b,0x61e22ee8,0x6b460503,0x00000000}},	//   _seco_, irol, _hógl, --,
   {{0xa15700a1,0x7d087e39,0x78b00094,0x6d4a5453}},	//   קבלה_, meds, _živý, _ilfa,
   {{0x29130fdc,0x661d01ac,0x7d082059,0x9f5e0503}},	//   _waxa_, _prsk, leds, _astú_,
   {{0x291324b0,0x25a3029a,0x26cb00e8,0x00000000}},	// [ba50] _taxa_, _pijl_, _veco_, --,
   {{0x7d08017a,0x201e789c,0xbef80179,0xef19007f}},	//   neds, _orti_, ्जुन_, może_,
   {{0x61e200ee,0xfa34015a,0x25a30381,0x00000000}},	//   erol, _فرید, _vijl_, --,
   {{0x7d080021,0x80ca0081,0x661d042d,0xdb0b0212}},	//   heds, _রাষ্, _trsk, _utfä,
   {{0x201ea34e,0x2d85a34f,0x661d0324,0x20d5097a}},	//   _arti_, ylle_, _ursk, пійс,
   {{0x2b920220,0x201e0167,0x660d2bf4,0x7d0851c1}},	//   máce_, _brti_, mwak, jeds,
   {{0x25e309d0,0x236d0149,0x201e0357,0xd12e0076}},	//   टंकी_, _tjej_, _crti_, امى_,
   {{0x81aa00c7,0x15ef00bc,0x9f470216,0xdb040231}},	//   _খবর_, _चमार_, munë_, _puní,
   {{0x201e08d3,0x2d850428,0x613d47d6,0x80270018}},	//   _erti_, tlle_, _bèlt, _ڈرام,
   {{0x2d851b3f,0x613d00b3,0xc5f20327,0x660d024a}},	//   ulle_, _cèlt, עדי_, iwak,
   {{0x2d850933,0x00000000,0x00000000,0x00000000}},	//   rlle_, --, --, --,
   {{0x2d8503be,0x660d0201,0x6d4aa350,0xdb0415c1}},	//   slle_, kwak, _elfa, _tuní,
   {{0x7d08a351,0x4a43008f,0xed4e0feb,0xdb04020a}},	//   beds, еняв, _зо_, _punâ,
   {{0xfbd100e3,0x6f09008c,0xdce101d3,0x660d520f}},	//   _كتب_, leec, rolē, dwak,
   {{0xd823980d,0x613d00b3,0xeb9a0da5,0x1a6600d1}},	//   ндри, _hèls, _лик_, تیکی_,
   {{0xcc3a0130,0x38650076,0xdb1b014b,0x7c3c679d}},	//   _לעצט, úlra_, ypté, ärre,
   {{0xe7370e23,0xa5bb0065,0xa3c903a2,0x26e40179}},	// [ba60] чет_, _arób, लीस_, गलौर_,
   {{0x4583001f,0x61e264fc,0x00000000,0x00000000}},	//   егув, vrol, --, --,
   {{0x491509c4,0xe7eb000f,0x493b00ca,0x660d0172}},	//   _फोटो_, जूदा_, _הגיו, awak,
   {{0x7d080067,0x290a6950,0x291823ff,0xe5a607ba}},	//   zeds, leba_, ldra_, _ними,
   {{0x26d2a352,0x6f09008c,0xe5a63a1f,0x613d0154}},	//   mayo_, deec, _хиги, _nèls,
   {{0x61e20eb8,0xe4da0de1,0x26d2a353,0x290a01c2}},	//   rrol, _دوست_, layo_, neba_,
   {{0x28bf2183,0xd9d9030b,0x7d080400,0x9f98249c}},	//   ्रति, _भट्ट, veds, овку_,
   {{0x26d2a354,0x61e2050d,0x657ea355,0x64a3013f}},	//   nayo_, prol, loph, _часа,
   {{0x91e31f37,0x63aea356,0x290a1bbd,0x7d0813ea}},	//   _поте, _hubn, keba_, teds,
   {{0x290a3e25,0xb3e0009f,0x26d2a357,0xa3c90285}},	//   jeba_, _पटाख, hayo_, लीव_,
   {{0x7d086280,0x26d2661c,0x201e55b6,0x3a2003a9}},	//   reds, kayo_, _urti_, _arip_,
   {{0x657e1c51,0x26d2024a,0x613d0154,0x00000000}},	//   hoph, jayo_, _wèlt, --,
   {{0x63aea358,0x26d2a359,0xf1b9080e,0x657e65be}},	//   _lubn, dayo_, _krša_, koph,
   {{0xada30396,0x6d4a0167,0x290aa35a,0x2918084e}},	//   _зачл, _ulfa, geba_, gdra_,
   {{0xd6db85ab,0x657ea35b,0x660d0d2a,0x6cfb00ca}},	//   йта_, doph, wwak, _הפוס,
   {{0x2918a35c,0x26d21eb2,0x7bd800bd,0x48e903b3}},	//   adra_, gayo_, _ivvu, _जाको_,
   {{0xaac31b92,0x4ac307ad,0xae1f074c,0x290a5f1d}},	// [ba70] _व्यक, _व्यव, बियन_, beba_,
   {{0xa5bb1feb,0xd49ba35d,0x660d9618,0x290aa35e}},	//   _prób, бре_, rwak, ceba_,
   {{0x26d21ee3,0x660d0601,0xa5bb6a26,0x00000000}},	//   bayo_, swak, _bróc, --,
   {{0x1ddd00a5,0xf1b902ef,0x63ae033d,0x26d20188}},	//   _मिलत, _arša_, _dubn, cayo_,
   {{0xbef809d0,0x657e0201,0x63bc0154,0xdb020212}},	//   ्जैन_, boph, _etrn, pplö,
   {{0xf8bf1efb,0x657e019f,0x2bac00b6,0xdca60037}},	//   ्रिय, coph, _těch_, _لى_,
   {{0xe0d0177a,0x7bdc0103,0xdb0400d4,0x613d022b}},	//   ازه_, árul, _luná, _sèls,
   {{0x290a00a5,0x321f0019,0x39841680,0x2f540938}},	//   zeba_, _truy_, löst_, етьс,
   {{0x1ddd009d,0x63ae2a4b,0x6f09a35f,0x7bd806b0}},	//   _मिळत, _zubn, reec, _avvu,
   {{0x61e4a360,0x26d20060,0x7afd1044,0x1c451588}},	//   áile, zayo_, efst, дном,
   {{0x63aea361,0xeb9a002d,0x26d270ec,0x7afda362}},	//   _xubn, жин_, yayo_, ffst,
   {{0x657ea363,0x2901a364,0xe8c60285,0x26d23bbf}},	//   zoph, _abha_, वर्च, xayo_,
   {{0x7bd80361,0x657e4bdb,0x26d205bd,0x9f4703a9}},	//   _evvu, yoph, vayo_, juné_,
   {{0x26d28844,0x20050063,0xdb0401f9,0x7afd4fb5}},	//   wayo_, _kpli_, _duná, afst,
   {{0x26d23940,0x290aa365,0x2918a366,0x3b0b3eaf}},	//   tayo_, reba_, rdra_, becq_,
   {{0x7bc102a1,0x290aa367,0x63ae0357,0x61eb0537}},	//   mplu, seba_, _rubn, kugl,
   {{0x6b84023f,0x26d2803a,0x3a2000bf,0x24f6036a}},	// [ba80] _ikig, rayo_, _urip_, дчер,
   {{0x26d20060,0x61eb01ce,0xf507002d,0x00000000}},	//   sayo_, dugl, мнул_, --,
   {{0xe73a07f3,0x657ea368,0xa3c9009d,0x7bc15856}},	//   _ден_, roph, लील_, nplu,
   {{0x27e50038,0x728a2a6e,0xd62a0ab3,0x657e40c3}},	//   álne_, обег_, _доме_, soph,
   {{0x754900fb,0x2bac00b6,0x61eb14f3,0x6b840350}},	//   ászó, _věci_, gugl, _mkig,
   {{0xa5bb0034,0x7bc10381,0x51833ac9,0x00000000}},	//   _wróc, kplu, куща, --,
   {{0x6b640103,0x20050027,0x6b8406b0,0xa5bb0076}},	//   zőga, _cpli_, _okig, _tróc,
   {{0x4444262a,0x8e140c58,0x1e14116a,0xda0e0096}},	//   my_, едиц, емия, िबात_,
   {{0x753c0067,0x3ea20212,0xf1b905db,0x00000000}},	//   _korz, äkt_, _trša_, --,
   {{0x6b840c50,0xdb1ba369,0x4444a36a,0xe2a6003e}},	//   _akig, nstö, oy_, áðum_,
   {{0x44440c6f,0xdb1b00c2,0x753c2fcc,0x8c43001f}},	//   ny_, istö, _morz, веќе,
   {{0xa3e10b95,0x3a2600e7,0x44440231,0x7afd042c}},	//   _दिस_, _šopa_, iy_, ufst,
   {{0x44440897,0xc333028c,0x527b00c1,0x753c0126}},	//   hy_, דור_, ַנלא, _oorz,
   {{0x44440871,0x6e22a36b,0x753c00dc,0x6b840283}},	//   ky_, _irob, _norz, _ekig,
   {{0x80d300c7,0x6e220146,0x7afd042c,0x140d00a3}},	//   _সাম্, _hrob, pfst, _सनेह_,
   {{0xf7701a13,0x6e220113,0x7d18040f,0x00000000}},	//   لاق_, _krob, _havs, --,
   {{0x4444008a,0xddc90034,0xa5f80e20,0x6aad0079}},	// [ba90] ey_, czeń, мету_, _igaf,
   {{0x7d1a3d59,0x6d48a36c,0x4444262a,0x2b920031}},	//   ndts, nkda, fy_, máca_,
   {{0x4444446d,0xa3c909d0,0x36d50084,0x6f020031}},	//   gy_, लीं_, _понр, _oboc,
   {{0x9f470220,0x1635008f,0x6e22a36d,0x80c10285}},	//   stnú_, _земя, _orob, रुने,
   {{0x753ca36e,0x4444a36f,0x7d180149,0x91057595}},	//   _forz, ay_, _oavs, епле,
   {{0x44441643,0x61eb0995,0x41e00789,0xf1e028fb}},	//   by_, rugl, _निरस, _निरन,
   {{0x62861484,0x44440fc9,0x61eb1197,0x6f02009c}},	//   _økon, cy_, sugl, _bboc,
   {{0xee390b40,0x6e220150,0x61eb028d,0x673d5abd}},	//   зни_, _brob, pugl, _josj,
   {{0xe1f009b4,0x6e220234,0x673d0120,0x7985063d}},	//   _نسل_, _crob, _mosj, _okhw,
   {{0x31595d50,0x29cda370,0x63a90084,0x6aada371}},	//   _علاج_, dža_, _hien, _agaf,
   {{0x63a904f9,0x62891df6,0x6e22a372,0xdb040131}},	//   _kien, _hyeo, _erob, _junç,
   {{0xf0920089,0x6f020129,0x79854757,0x63a90078}},	//   _גנב_, _gboc, _akhw, _jien,
   {{0x63a9a373,0xdc3b06b8,0xfce50978,0x7bc1a374}},	//   _mien, _išče, _золо, splu,
   {{0x63a9a375,0x6f1b1da6,0x628952c0,0x7bc10fe8}},	//   _lien, lduc, _myeo, pplu,
   {{0x6e220067,0x6b46a376,0x2796013d,0xb8d8007a}},	//   _zrob, _lógi, ешар, _छल_,
   {{0x44440871,0x63a9a377,0xe7370245,0x6f1b1173}},	//   vy_, _nien, нес_, nduc,
   {{0x44440d1b,0x2b001a94,0x69cd0150,0x753ca378}},	// [baa0] wy_, ष्णु_, _gwae, _porz,
   {{0x649a08f9,0x63a9a379,0xdce10138,0x63b80031}},	//   птер_, _aien, rolė, ívno,
   {{0xdb1ba37a,0x63a9a37b,0x44447637,0x130a055b}},	//   rstö, _bien, uy_, зней_,
   {{0x444410d2,0x63a9255c,0x291a068d,0xdb1b8b9d}},	//   ry_, _cien, _hapa_, sstö,
   {{0x63a9a37c,0x44441670,0x6f1b01ee,0x6d48a37d}},	//   _dien, sy_, dduc, ykda,
   {{0x44442f29,0xa5bb0088,0x63a99a73,0xdb040396}},	//   py_, _krón, _eien, _funç,
   {{0x63a9a37e,0xa2e6008f,0xa2c70096,0x935a0012}},	//   _fien, _повд, ारख्, _ерау_,
   {{0x291aa37f,0xdb0b00d6,0x7d18a380,0x6f1903a8}},	//   _lapa_, _utfø, _savs, _cawc,
   {{0x62890113,0x52cc00b6,0x613d0113,0x6e220090}},	//   _gyeo, ारीस, _tèlp, _qrob,
   {{0x291aa381,0x63a90a00,0xd24f0037,0xd26300ae}},	//   _napa_, _zien, _انك_, _скуй,
   {{0x6d48a382,0x22460018,0x6f19a383,0x69cd0313}},	//   rkda, lyok_, _fawc, _swae,
   {{0x6e220990,0x6f02a384,0x63a9023e,0x59dc08d4}},	//   _trob, _uboc, _xien, _बिखर,
   {{0x291a18c4,0x7d1801e8,0x6e220181,0x22460018}},	//   _bapa_, _tavs, _urob, nyok_,
   {{0xa3e10b89,0x291aa385,0x29cda386,0x90d500fe}},	//   _दिल_, _capa_, rža_, _lòn,
   {{0x673d029b,0x1cb70105,0xa5bb0fb6,0xf77333c6}},	//   _posj, _אלול_, _crón, هار_,
   {{0x2d8c0149,0x7bda57eb,0x224600f9,0x2d9e8086}},	//   llde_, mstu, kyok_, lmte_,
   {{0x63a9a387,0x44230095,0xb50202d5,0x8f9b00ca}},	// [bab0] _rien, _srj_, र्भय_, לילי,
   {{0x628905e3,0x44230085,0x2246210a,0x7985405d}},	//   _ryeo, _prj_, dyok_, _ukhw,
   {{0x63a9a388,0x9cd70054,0x2d9e0cad,0x6e2409ac}},	//   _pien, גובה_, imte_, _šibl,
   {{0x7bdaa389,0x2d9e042c,0x490900b6,0xdb1902c6}},	//   istu, hmte_, ाजको_, _otví,
   {{0x63a9a38a,0x22460068,0x213e0054,0x291aa38b}},	//   _vien, gyok_, _both_, _yapa_,
   {{0x7bdaa38c,0x26c9a38d,0xa3cc0251,0xdb0401bf}},	//   kstu, lbao_, _शौक_, _zunä,
   {{0x63a9a38e,0x7bdaa38f,0x7f49023b,0x213e03c3}},	//   _tien, jstu, tkeq, _doth_,
   {{0x2d8c0a9f,0x61e43313,0x22460167,0x236601b6}},	//   elde_, šila, byok_, cioj_,
   {{0xb115016e,0x81bb0081,0x7bdaa390,0xc1150215}},	//   _имаш, _আটক_, estu, _имај,
   {{0x7bda057a,0x6b460653,0x63bb0218,0xdca5129e}},	//   fstu, _jógv, _čunj, капи,
   {{0x7bda3dac,0x15f302d5,0xd0110dce,0x31670063}},	//   gstu, इंडर_, _خلا_, minz_,
   {{0x291aa391,0x2d8c2e0a,0x2d9e1aab,0x00000000}},	//   _sapa_, alde_, amte_, --,
   {{0x291a9c19,0x3b1b009e,0x98d6004d,0x6d8601cd}},	//   _papa_, _daqq_, ківщ, gðas,
   {{0x3f8d4acf,0x7c650246,0x7bdaa392,0xfce57305}},	//   lleu_, _لاعل, bstu, _роко,
   {{0x48798196,0x5d7a006e,0x291a783c,0xbc190120}},	//   естя_, _קאצק, _vapa_, _цілі_,
   {{0x27e50181,0x1fe30081,0xcfe30033,0xddc901d3}},	//   álna_, _মহাস, _মহান, rzeņ,
   {{0x291aa393,0x07a310f7,0xdcfa00d9,0x661b0a39}},	// [bac0] _tapa_, ратн, lotā, _šukr,
   {{0x291a01b9,0x00000000,0x00000000,0x00000000}},	//   _uapa_, --, --, --,
   {{0x66e64460,0x213e7386,0xdcfa01d3,0x61fb039f}},	//   _иона, _roth_, notā, _aqul,
   {{0xf7460f00,0xa5bb0034,0x41e607bf,0x7c3e1e7d}},	//   _ремо, _król, віка, _àpre,
   {{0x6d8601cd,0x333f00fd,0x2d870031,0x236601b6}},	//   iðar, _doux_, _okne_, rioj_,
   {{0x7bdaa394,0xdcfa01d3,0x3f860a07,0x2b40259a}},	//   ystu, kotā, _skou_, _loic_,
   {{0xb50205a5,0x351b00a1,0xdfd000e3,0x929d0034}},	//   र्णय_, _קולנ, حيب_, _mały,
   {{0x2d8706a3,0xdcfa01d3,0x7bda2c28,0xc2240504}},	//   _akne_, dotā, vstu, _مکتو,
   {{0x7bda37fe,0x6b460065,0x00000000,0x00000000}},	//   wstu, _jógu, --, --,
   {{0xfe6f16cc,0x7bdaa395,0xdce10141,0xfaff0381}},	//   تدى_, tstu, bilč, giën_,
   {{0xc0a900e3,0x2d9e2ba3,0xa5bb0065,0xa0a6008f}},	//   _كامل_, rmte_, _aról, _ражд,
   {{0xe5020557,0x7bdaa396,0xd5e2048a,0x6d86003e}},	//   र्ति_, rstu, _पिंज, gðar,
   {{0x29042c0a,0x9b583eac,0x9f470220,0xa5bb0503}},	//   đman_, тият_, ntný_, _cról,
   {{0x6d860088,0x929d0034,0x3f84a397,0x6441015e}},	//   rðas, _cały, lomu_, _àlig,
   {{0x1b080033,0x7ac724f7,0xcd9700ca,0xed570291}},	//   ষয়ে_, _испе, _שדות_, _јој_,
   {{0x34cb201e,0x9f470220,0x6b460065,0x5c3700ca}},	//   िर्द, ktný_, _bógu, _ירון_,
   {{0x333fa398,0x26c909ac,0x387a1206,0x6e2405db}},	// [bad0] _roux_, rbao_, _expr_, _šibj,
   {{0xeaaa00c1,0x2d830a9e,0x69dd0407,0x8af000a7}},	//   _אױפֿ, čjeg_, msse, _eləd,
   {{0x2911a399,0x69dd2452,0x333f014b,0x3167042c}},	//   meza_, lsse, _poux_, vinz_,
   {{0x291161d2,0xd49820f9,0xdce14c84,0x6b460139}},	//   leza_, тру_, vilč, _fógu,
   {{0x80ca0081,0x61e40087,0x3f84a39a,0x69dda39b}},	//   _রাজ্, šiln, domu_, nsse,
   {{0x2911a39c,0xd5fa0054,0x69dda39d,0x98c608a9}},	//   neza_, _אפשר, isse, čući_,
   {{0x6142036a,0x3f8436d8,0xd3a700f6,0x6d86003e}},	//   сеща, fomu_, _арап, yðar,
   {{0x29113565,0x69dda39e,0x3f84a39f,0xdcfa00e8}},	//   heza_, ksse, gomu_, votā,
   {{0x2911164e,0x69dd0126,0x63b501c2,0x3f8d00ee}},	//   keza_, jsse, _huzn, rleu_,
   {{0xdcfa0029,0x80ca05cd,0x2911a3a0,0x69dd0073}},	//   totā, _स्पे, jeza_, dsse,
   {{0x63b508a9,0x69dd2b84,0x3f8452cd,0xfaff01c0}},	//   _juzn, esse, bomu_, riën_,
   {{0x3f84a3a1,0xa5bba3a2,0xaca30129,0xdcfa01d3}},	//   comu_, _pról, _ntụk, rotā,
   {{0x6d860102,0xee2e016a,0x69c60239,0x69dd687d}},	//   rðar, _ун_, upke, gsse,
   {{0x29113565,0xaca30129,0xa5bb033c,0x00000000}},	//   geza_, _atụk, _cróm, --,
   {{0x2d85a3a3,0x66e64233,0x69dd5264,0x63b50880}},	//   mole_, лова, asse, _nuzn,
   {{0x80ca0e19,0xfaff1044,0x2d85a3a4,0x9f470094}},	//   _स्ने, niël_, lole_, ytný_,
   {{0x2911a3a5,0xceb2040a,0x7ae40335,0xa5bb037a}},	// [bae0] beza_, מין_, _idit, _uról,
   {{0x2d85a3a6,0xd764001c,0x6e24033b,0xb4c01c05}},	//   nole_, _چندی, _šibk, ीरे_,
   {{0x69c400bd,0x2d850036,0x78fb00ca,0x00000000}},	//   _htie, iole_, _אליפ, --,
   {{0x2d850201,0x63b50ca7,0x69c4003d,0x31b905aa}},	//   hole_, _duzn, _ktie, _bèz_,
   {{0x61461456,0xdb040037,0x69c40090,0x00000000}},	//   леда, _bunú, _jtie, --,
   {{0x2d852c94,0x9f470206,0xca7b006e,0x80ca0033}},	//   jole_, rtný_, ענסט, _রাঙ্,
   {{0xa3e10782,0x9f4715f2,0x2d85a3a7,0x7ae4a3a8}},	//   _दिए_, stný_, dole_, _odit,
   {{0x20d8013f,0xdb190220,0x7ae45705,0x29112cd0}},	//   džių_, _otvá, _ndit, zeza_,
   {{0x70f60d74,0x80d300c7,0xbd6aa3a9,0x63a2a3aa}},	//   _مسائ, _সার্, ерне_, mmon,
   {{0x7ae4a3ab,0x2d85a3ac,0x5514009f,0xc05a00d3}},	//   _adit, gole_, ड़िए_, _прец_,
   {{0x261404dd,0x29117d87,0x4c94129e,0x69c45c48}},	//   नौती_, veza_, ринс, _atie,
   {{0x29118ba0,0xa3c90789,0x69dd3318,0x69c402a1}},	//   weza_, लीट_, tsse, _btie,
   {{0x2911a3ad,0x2d85a3ae,0x69dda3af,0xbdd400c2}},	//   teza_, bole_, usse, _толщ,
   {{0x2d85a3b0,0x6e935e51,0x63a2a3b1,0x69dda3b2}},	//   cole_, _الها, hmon, rsse,
   {{0x29112bf4,0x69c4a3b3,0x63a203a9,0x6db20034}},	//   reza_, _etie, kmon, _wład,
   {{0xa6db01cd,0x69c400bd,0x9f470a7f,0x69dd01ce}},	//   _boða, _ftie, trné_, psse,
   {{0x29118c94,0x61e40076,0x63b514f3,0x00000000}},	// [baf0] peza_, áill, _suzn, --,
   {{0x63a201b3,0x3a29028d,0x61eb0141,0x31b9022b}},	//   emon, _irap_, vrgl, _rèz_,
   {{0x3a2900f9,0x44274845,0x6b460037,0x80d30033}},	//   _hrap_, ín_, _tógt, _সাল্,
   {{0xd2510080,0x3a290abf,0x27ec0146,0x63a20103}},	//   ينا_, _krap_, ádne_, gmon,
   {{0xf1b9077e,0xe70409b4,0xa3c91362,0x3f510139}},	//   _krši_, _اسپی, लीज_, _báun_,
   {{0x98ba0029,0xa06902e1,0x63b5042d,0x63a27e04}},	//   _kopā_, кала_, _tuzn, amon,
   {{0x2d85013d,0x2f5528ca,0x7f42008a,0x200c002b}},	//   vole_, итис, _booq, _cpdi_,
   {{0x2d85a3b4,0xddc90034,0x6b460072,0xa3ea0ff9}},	//   wole_, cześ, _lógr, _मित_,
   {{0x00e500cd,0x7f42041c,0x00000000,0x00000000}},	//   _نتای, _dooq, --, --,
   {{0xa5bb034f,0xe8e00294,0x51871894,0x00000000}},	//   _prój, twọk_, _суба, --,
   {{0x66160034,0xeb9a2105,0x3a29a3b5,0xa3c90096}},	//   zwyk, кио_, _arap_, लीच_,
   {{0x34b20cce,0x60d701d3,0xcb6a085f,0xcd350103}},	//   _जल्द, šamī, таме_, ارکب,
   {{0xed4ea3b6,0x3a2900d7,0x69c402a1,0xde460103}},	//   _до_, _crap_, _qtie, _نیٹو_,
   {{0xa5bb0034,0x3a29a3b7,0x9ce70103,0x79874835}},	//   _trój, _drap_, _صوبے_, gojw,
   {{0x6d430e5c,0x7bc3005c,0x3a294b94,0x613d022b}},	//   _iona, _utnu, _erap_, _bèlz,
   {{0x6d430a00,0x70d1000d,0x6e24050d,0x3ebf6994}},	//   _hona, हरुल, _šibi, ncut_,
   {{0x0566a3b8,0x6b460080,0x6d431137,0x3a2990b6}},	// [bb00] аван, _fógr, _kona, _grap_,
   {{0xa3e1007f,0x89db00ca,0xa6db01cd,0x00000000}},	//   _दिख_, _שחיי, _voða, --,
   {{0xaaba0c8c,0xe502074c,0x6d43a3b9,0xdd0102c6}},	//   _इलाक, र्षि_, _mona, _štěp,
   {{0xb226002d,0xa3e7007b,0xd7640504,0x63a2a3ba}},	//   имел, рдца_, _چنگی, umon,
   {{0x70d1000d,0xf8da00c3,0xddc9007f,0x00000000}},	//   हरूल, _बजाय, rześ, --,
   {{0x63a2a3bb,0x26c0a3bc,0x2936006e,0x7c3c02c3}},	//   smon, lcio_, שאַן_, ärrk,
   {{0xd0100037,0x201a0036,0x63a2084e,0x320d047e}},	//   سلة_, ìpi_, pmon, _epey_,
   {{0x26c00cf9,0x6d4310f0,0x9c8218ed,0x6e2d0b18}},	//   ncio_, _aona, _účin, _šaba,
   {{0x6d43a3bd,0x6db20034,0x26c0a3be,0x443a016d}},	//   _bona, _słab, icio_, lxp_,
   {{0x6d430a62,0x5d5401c9,0x2b920146,0x442a1c74}},	//   _cona, скот, lách_, _krb_,
   {{0x34b700a1,0x6d43a3bf,0x69c0a3c0,0xaee80081}},	//   יפים_, _dona, ímen, ক্ষণ_,
   {{0x2b925348,0x6d430072,0x3a29023b,0x442a58e5}},	//   nách_, _eona, _prap_, _mrb_,
   {{0x6d43a3c1,0x4cd50081,0xee940018,0x6d9400ee}},	//   _fona, _দারু, _اداک, làam,
   {{0x6d43a3c2,0xc987016e,0x2b920146,0x442aa3c3}},	//   _gona, руми, hách_, _orb_,
   {{0xf1b90039,0x2b92025b,0xe79501f3,0x3a29a3c4}},	//   _vrši_, kách_, مارک, _wrap_,
   {{0x442d2782,0x6d43a3c5,0xf7730182,0x79870079}},	//   _če_, _zona, زاز_, sojw,
   {{0x61e40660,0x442aa3c6,0x6d43a3c7,0x2b920146}},	// [bb10] šilj, _arb_, _yona, dách_,
   {{0xa2c9000d,0x443a034f,0x6d5a00fe,0x58870138}},	//   हुन्, fxp_, nhta, _выма,
   {{0xdcf8030b,0x320d7c4a,0xf1cf0d88,0x442aa3c8}},	//   _skvě, _spey_, _सौजन, _crb_,
   {{0x26c0013d,0x442a00dc,0x925900c2,0x7c2a0350}},	//   ccio_, _drb_, лает_, _mrfr,
   {{0x442aa3c9,0x6d5a9c73,0x3ebf026a,0x6b8d0239}},	//   _erb_, khta, vcut_, _mkag,
   {{0xf4350012,0x45d44ef9,0x26d901ee,0x661d01b6}},	//   _легэ, _форс, _heso_, _issk,
   {{0x4425a3ca,0x442a00cc,0x3f690831,0x26d9a3cb}},	//   _él_, _grb_, лико_, _keso_,
   {{0xef191107,0x7c250088,0x6b8d7249,0x3cfc02ac}},	//   уми_, _áhri, _nkag, _acvv_,
   {{0xa5bb0076,0x2ee6030a,0x7c3a0324,0x3cd90f6b}},	//   _brói, _ddof_, extr, льню_,
   {{0x3ebf52c4,0x6b8d09b7,0x6d430092,0x987800cc}},	//   scut_, _akag, _qona, _ušća_,
   {{0x40950080,0x6d43a3cc,0x6db20034,0x2b920094}},	//   _الار, _vona, _płac, láci_,
   {{0xa3ea1677,0x6d43a3cd,0x26d9039f,0x764d083e}},	//   _मिस_, _wona, _neso_, kyay,
   {{0x6d43a3ce,0x5ea50081,0x7c2a0364,0x427900c1}},	//   _tona, _গ্রে, _erfr, ראָג,
   {{0x6d5a16cc,0x2c5700a7,0x41cf02d5,0xd99a00d1}},	//   chta, hədə_, सीएस, انست_,
   {{0x26d9a3cf,0x2c570092,0x25b9028d,0x07ba0076}},	//   _beso_, kədə_, _ausl_, اهرة_,
   {{0x2efd02ac,0x00000000,0x00000000,0x00000000}},	//   _jcwf_, --, --, --,
   {{0x64430222,0x442a2102,0x2b920244,0xf7430396}},	// [bb20] änin, _srb_, vách_, чето,
   {{0x26c0a3d0,0xd9100103,0x61e47035,0x2b9200d4}},	//   scio_, _تیس_, šilk, dáci_,
   {{0x2b92025b,0xe2ca1a6d,0xa2aa099d,0x26c0167e}},	//   tách_, глед_, जेन्, pcio_,
   {{0xd0480092,0x2bb700ae,0x764d02a4,0xe73aa3d1}},	//   _gedə, _căci_, byay, _сем_,
   {{0x67245a7b,0x2b920146,0xaeff0033,0x764d0079}},	//   mdij, rách_, ্যাণ_, cyay,
   {{0x64a61728,0xdb0b0364,0x3ce7007e,0x6724a3d2}},	//   _гага, _zufä, _ndnv_, ldij,
   {{0x629b0174,0x3dc63aab,0x26d9a3d3,0x2b920146}},	//   _ezuo, _stow_, _yeso_, pách_,
   {{0xc7b300ca,0x2c570092,0x26d9002b,0x6604a3d4}},	//   הבה_, cədə_, _xeso_, otik,
   {{0x660481f5,0xa5bb00e3,0x03a301a0,0x50d6001c}},	//   ntik, _prói, _хито, _هزار,
   {{0x67240096,0x6b8d00bb,0x66043b64,0x61e23f71}},	//   hdij, _skag, itik, msol,
   {{0x69b2000f,0x66040084,0x974300cb,0xf1b900d4}},	//   _इंजी, htik, šćiv, _zuš_,
   {{0x6d5aa3d5,0x672400e7,0x764d4c94,0x61e200bc}},	//   shta, jdij, yyay, osol,
   {{0x26d900e5,0x4e9609f4,0x539b006e,0x0a6b09b9}},	//   _reso_, _اشار, טיטו, урни_,
   {{0x7c3e1527,0x69b002d5,0x6ab60103,0x61e22fa2}},	//   _àpro, ंदगी, _egyf, isol,
   {{0x26d95a9a,0x66043809,0x2c5700a7,0x776d0072}},	//   _peso_, etik, yədə_, tiax,
   {{0xd6d82d7b,0x6b8d179a,0x764da3d6,0x201e37e5}},	//   йту_, _ukag, tyay, _msti_,
   {{0xf77004f4,0x6604019c,0x248d01d3,0x26d90383}},	// [bb30] راف_, gtik, _ņem_, _veso_,
   {{0x2b920244,0x764da3d7,0x61e20e37,0x201e4b2a}},	//   váci_, ryay, dsol, _osti_,
   {{0xf994040a,0x61e20683,0x26d95d28,0x66047600}},	//   _מרץ_, esol, _teso_, atik,
   {{0xdb190149,0x66040124,0x59d0077d,0x00000000}},	//   _utvä, btik, तीकर, --,
   {{0x4cde0f71,0x6d580068,0x2c5701d4,0x614508d8}},	//   _মানু, _olva, rədə_, жела,
   {{0x60da0072,0x6e2d1523,0x2c5700a7,0x2b9200d4}},	//   _cetm, _šabo, sədə_, ráci_,
   {{0x5edd0033,0x7f9e0052,0x60daa3d8,0x14280120}},	//   _যাবে, zëqe, _detm, _літо_,
   {{0x6d58a3d9,0xf1b913e8,0x61e22c29,0x335800ae}},	//   _alva, _tuš_, bsol, _ласэ_,
   {{0x201e6f2a,0x9f5c030b,0x80ca16f8,0xbd39004d}},	//   _esti_, ctví_, _स्वे, аїні_,
   {{0x80d30081,0x60da0092,0xbc840023,0x6724004b}},	//   _সাক্, _getm, ườn, zdij,
   {{0xca297c04,0x6604a3da,0x69d602ac,0x8c45038f}},	//   _שם_, ztik, _swye, цене,
   {{0x6d580c86,0x66040109,0x60da01cb,0x00000000}},	//   _elva, ytik, _zetm, --,
   {{0xfce511f7,0x8d740100,0x67245dca,0x60da0367}},	//   _доло, _کانا, vdij, _yetm,
   {{0xa3ea0d0b,0x0d8436bf,0x61e40076,0x66040117}},	//   _मिल_, _елін, áili, vtik,
   {{0x1b0f0081,0x96c706c0,0x61e201f9,0xdb190383}},	//   িয়ে_, _ụfọd, zsol, _ouvè,
   {{0x6604a3db,0xdc3b007e,0x67241db9,0x236f0052}},	//   ttik, _ašće, udij, jigj_,
   {{0x88d90033,0x7c3c02c3,0x00000000,0x00000000}},	// [bb40] _তারক, ärrv, --, --,
   {{0x3a201331,0x672412f7,0x00000000,0x00000000}},	//   _isip_, sdij, --, --,
   {{0x0326117a,0x29181aa3,0xf746a3dc,0x29370327}},	//   жден, mera_, _дено, _ואין_,
   {{0x29187d0f,0x60da0990,0x96b900c2,0x00000000}},	//   lera_, _setm, _гуру_, --,
   {{0x61e2166f,0x60da00b7,0x26d2596b,0x931c0033}},	//   usol, _petm, mbyo_, ণালয_,
   {{0x61e2a3dd,0xdb0b0149,0xe4da33e7,0x201e0085}},	//   rsol, _utfö, _خوست_, _psti_,
   {{0x6f09a3de,0x2918a3df,0x60da00dd,0xd8d7006e}},	//   ffec, iera_, _vetm, קוקט_,
   {{0x2918a3e0,0x9c7c0d95,0x3f8f0063,0x61eda3e1}},	//   hera_, nače, _ckgu_, šala,
   {{0x2918a3e2,0x63bca3e3,0x3f9800e8,0x00000000}},	//   kera_, _hurn, ēru_, --,
   {{0xa06a013d,0x0caa09b9,0x9c7c2c06,0x00000000}},	//   _каза_, итни_, hače, --,
   {{0x63bca3e4,0x3a200167,0x201e0147,0x00000000}},	//   _jurn, _asip_, _usti_, --,
   {{0x63bc2675,0x25eb0789,0xa5bb00a5,0x9c7c0128}},	//   _murn, _चिली_, _krót, jače,
   {{0x320600f9,0xdb19014b,0xda2208c0,0x9c7c0213}},	//   ntoy_, _juvé, मिगत_, dače,
   {{0x29183304,0xe6d306eb,0x09bd0033,0xdb0400da}},	//   gera_, तर्ज, _অবদা, _bunó,
   {{0xd6db28b9,0xa8992cdd,0x36d516bd,0x27f805db}},	//   ита_, скву_, зобр, gurn_,
   {{0x27ed60d1,0x2d8ca3e5,0xc6140033,0x9c7c25d1}},	//   čen_, lode_, সিনা_, gače,
   {{0x291872fc,0xe4cb0177,0x63bc01ff,0xe81d007a}},	// [bb50] bera_, لبان_, _aurn, _पनवा_,
   {{0x2d8c74bc,0xa5bb0042,0xd7fb0012,0x63bca3e6}},	//   node_, _asóc, _кум_, _burn,
   {{0x9c7c0039,0xf8b100cd,0x29010449,0x497404a1}},	//   bače, _سکس_, _icha_, _ілюс,
   {{0x2d8c5695,0x63bca3e7,0xe3b836bf,0x290101ff}},	//   hode_, _durn, ібі_, _hcha_,
   {{0x2d8c526d,0x332402a1,0xdb19014b,0x00000000}},	//   kode_, _damx_, _cuvé, --,
   {{0xe8b92010,0x63bc119b,0x88d90033,0x00000000}},	//   _आलोच, _furn, _তাঁক, --,
   {{0x63bc51a4,0xb4d70f42,0xa5bb8074,0x29010a4b}},	//   _gurn, सरी_, _erót, _mcha_,
   {{0xd00e0080,0x63680b73,0x2918a3e8,0x2b9202c6}},	//   الي_, _друг_, zera_, náct_,
   {{0x2901a3e9,0x236d08d3,0x63bca3ea,0x6f093f77}},	//   _ocha_, _imej_, _zurn, rfec,
   {{0x9c7c14f3,0x290138cc,0x6f093072,0x2918a3eb}},	//   zače, _ncha_, sfec, xera_,
   {{0x317a00c1,0x31560142,0x00000000,0x00000000}},	//   _פרעמ, _ציען_, --, --,
   {{0x2901a3ec,0xe50b00c3,0x2918a3ed,0xe45600c1}},	//   _acha_, स्ति_, wera_, פירט_,
   {{0xa9241054,0x442600fe,0x00000000,0x00000000}},	//   ížov, ̉o_, --, --,
   {{0x27f800a1,0x7afd04e2,0x29180062,0x00000000}},	//   turn_, agst, uera_, --,
   {{0x2918a3ee,0x2007715b,0x2901850b,0x475a0109}},	//   rera_, ntni_, _dcha_, брая_,
   {{0xb8f3007d,0x63ba1f84,0x2901a3ef,0xf7430e06}},	//   _ह्_, _étni, _echa_, несо,
   {{0x63bca3f0,0x9c7c0106,0x26d20124,0xe4d60037}},	// [bb60] _surn, rače, rbyo_, كتاب,
   {{0x63bca3f1,0x200707c0,0x3324022e,0x27f8003e}},	//   _purn, ktni_, _samx_, purn_,
   {{0xd252001c,0x9c7c0147,0x3f8d0072,0xa5bb0653}},	//   کنش_, pače, koeu_, _brós,
   {{0x2d8c04a3,0xa5bba3f2,0x09230033,0x387f0233}},	//   zode_, _prót, মাণু_, ğurt_,
   {{0x61ed0087,0x2007a3f3,0x63bc01c2,0x0cdb00aa}},	//   šaln, etni_, _wurn, _मजूम,
   {{0xf8bea3f4,0x3206a3f5,0x67260381,0x00000000}},	//   ्डिय, rtoy_, _hakj, --,
   {{0x2d8c00e9,0x64a6273f,0x8af000a7,0x232a35c1}},	//   vode_, _хава, _aləm, _лови_,
   {{0x64490511,0x547b00ca,0xa5bb6b93,0x9f47023c}},	//   çmiş, _הטלו, _grós, trná_,
   {{0x798e023f,0x6726a3f6,0x00000000,0x00000000}},	//   kobw, _makj, --, --,
   {{0x7c860d6f,0x67263530,0x2cb80b81,0x2b9201f9}},	//   зуме, _lakj, ørd_, kács_,
   {{0x9c7ca3f7,0xbae10081,0xdeef00d3,0xd00f1b71}},	//   dačc, _ভাবছ, _пы_, _ملل_,
   {{0x29015efd,0xaca30174,0x7afd01d3,0x8ccc0521}},	//   _scha_, _gwọk, ugst, _द्रो,
   {{0xdb0400de,0x60cb0103,0x6f02039f,0x656e0372}},	//   _khiê, _élmé, _icoc, _ombh,
   {{0x6e2212e6,0x3c5800d3,0x6db2007f,0x798e06b0}},	//   _isob, _милэ_, _kłam, gobw,
   {{0xd90f00bf,0x7d1aa3f8,0x6726029a,0x80e10033}},	//   نیک_, mets, _bakj, _নাম্,
   {{0x95d9008f,0x6d4a084e,0x656e6204,0x6c7b00ca}},	//   ждат_, _hofa, _ambh, _לאופ,
   {{0x59b71bed,0xf1d700c7,0x7aed02a7,0x6d4aa3f9}},	// [bb70] _इंटर, _সম্ভ, _idat, _kofa,
   {{0xdb040028,0xb4d70f42,0xb4c9009d,0x2901a3fa}},	//   _nhiê, सरे_, ैरे_, _ucha_,
   {{0xa5bb003e,0x9cd700ca,0xbb1b014b,0x3d0e00a4}},	//   _prós, פואה_, boît, त्ये_,
   {{0x7d1a8d6d,0x27e50220,0xfaff023b,0x6d4aa3fb}},	//   hets, álnu_, ngë_, _lofa,
   {{0x7d1aa3fc,0x6e223683,0x00000000,0x00000000}},	//   kets, _nsob, --, --,
   {{0x7d1a0292,0xdb040019,0x6f020072,0x67267362}},	//   jets, _chiê, _acoc, _zakj,
   {{0x7aed2436,0x6e2221e9,0x672600dc,0x00000000}},	//   _odat, _asob, _yakj, --,
   {{0x3eb9038c,0x2007a3fd,0x0dc91cb1,0x7aed6579}},	//   øst_, rtni_, олий_, _ndat,
   {{0x200728f4,0x61e40080,0x6adc0081,0x6d4aa3fe}},	//   stni_, áilt, _ভালো, _bofa,
   {{0x7aeda3ff,0x7d1a023f,0x6d4a704e,0x61e9a400}},	//   _adat, gets, _cofa, _ivel,
   {{0x69cda401,0x6e2210df,0x61e400c6,0x00000000}},	//   _atae, _esob, šilt, --,
   {{0x61e900d6,0x4431042c,0xbf6707e8,0x2b9201f9}},	//   _kvel, _mrz_, _عداو, vács_,
   {{0x7d1a070a,0x7aed02ad,0x6d4a0360,0x6db2007f}},	//   bets, _ddat, _fofa, _złam,
   {{0x25ee000f,0x6d4a02ad,0x7aed28fd,0xb4d73d34}},	//   ेंसी_, _gofa, _edat, सरो_,
   {{0x672601c0,0x7aed00bd,0x46cb00ac,0x798e18fe}},	//   _pakj, _fdat, _ụtọ_, robw,
   {{0x61e9a402,0x2b05349d,0x798e02a4,0xfedb0033}},	//   _ovel, _वायु_, sobw, _ধাঁধ,
   {{0x6726029a,0x25f50034,0x4431a403,0xe96a0b36}},	// [bb80] _vakj, एंगी_, _arz_, _маил_,
   {{0x443101ac,0x44230063,0xa5bb0610,0x3f800138}},	//   _brz_, _bsj_, _prór, čiui_,
   {{0x67269c94,0x61e93e80,0x44236165,0x61ed02ef}},	//   _takj, _avel, _csj_, šall,
   {{0x9c7c02e6,0x65c65bc5,0xa2c91e05,0x7f4b063d}},	//   nača, _обма, हुल्, _nogq,
   {{0xa3de05d4,0xdb040028,0x61e90095,0x4cde0033}},	//   _दौर_, _phiê, _cvel, _মাসু,
   {{0x6f020451,0x656e0201,0x61e9a404,0x00000000}},	//   _scoc, _umbh, _dvel, --,
   {{0xd5ad0018,0x4431028d,0x9c7c02ef,0x442c020d}},	//   _اہل_, _grz_, kača, _éd_,
   {{0x9c7c00e9,0x6d4a00f2,0x7c3e1e7d,0x6e2202ac}},	//   jača, _sofa, _àpri, _psob,
   {{0xdb040028,0xb0cf009d,0x9c7c0477,0x6d4aa405}},	//   _thiê, _स्वग, dača, _pofa,
   {{0x657e0037,0xab640034,0x00000000,0x00000000}},	//   nnph, óżni, --, --,
   {{0x7d1aa406,0xfa130081,0xcf8f001f,0x69cd360c}},	//   rets, িয়াল_, _ај_, _stae,
   {{0xee3a0ff8,0x7d1a348a,0x9c7c031a,0x61e900fd}},	//   _мне_, sets, gača, _yvel,
   {{0xf2d30130,0x6d4a068d,0x5eac0081,0x7d1aa407}},	//   כער_, _tofa, _ট্রে, pets,
   {{0x9f4e0076,0xf1b80090,0x7d1a0216,0x00000000}},	//   irfí_, _jiġ_, qets, --,
   {{0x9c7c0f39,0xa5bb0065,0xa3ea02d5,0x75270103}},	//   bača, _aróp, _मिग_, _rajz,
   {{0xb4d7009d,0x25b8009c,0x44230167,0x6e2d0e94}},	//   सर्_, _airl_, _rsj_, _šabi,
   {{0x3a320313,0x69cd0239,0xfaff084e,0x69b930a8}},	// [bb90] _gryp_, _utae, biër_, _एंटी,
   {{0x15f302e8,0xd49b1055,0xc7c71469,0x00000000}},	//   ेंबर_, оре_, _осми, --,
   {{0x752701e5,0xf48500d0,0x61e98ace,0xdb16001c}},	//   _vajz, رائی, _svel, _biyè,
   {{0x3d0e3751,0xb866001c,0x45d5018a,0xdb1b3c09}},	//   त्ते_, _ساپو, _помс, mptó,
   {{0xe5c400c2,0xeb9200c1,0x44310034,0xe8e0020b}},	//   _ассо, אָג_, _wrz_, _hiều_,
   {{0xa0a50e21,0x25b8a408,0xe8e000de,0x44239cbf}},	//   налд, _girl_, _kiều_, _tsj_,
   {{0x1fb50aeb,0x44230063,0xdb160154,0xd00e0286}},	//   нсир, _usj_, _fiyè, ملو_,
   {{0x26c96181,0xa295224a,0x00000000,0x00000000}},	//   ncao_, _забі, --, --,
   {{0x61e9a409,0xe8e000de,0xfce518c6,0x2bd700bc}},	//   _uvel, _liều_, нопо, _भौजा,
   {{0x653a00c1,0x1c45004d,0x7c230062,0x7d090284}},	//   ִערד, еном, _psnr, чног_,
   {{0xeb9a1cf2,0xab2aa2bc,0x9c7c007e,0x15f3007f}},	//   зин_, пона_, tača, ेंडर_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb69b044c,0x00000000,0x00000000,0x00000000}},	//   _scân, --, --, --,
   {{0x9c7c0094,0xdb1900d3,0x00000000,0x00000000}},	//   mačn, _cuvâ, --, --,
   {{0x9c7ca40a,0xfbc6000d,0x2bc61c83,0x7b96004d}},	//   lačn, _रूपम, _रूपा, _приї,
   {{0x28d004f8,0xa5bb0396,0xe8e000fe,0x39583360}},	//   _त्रि, _próp, _diều_, skrs_,
   {{0x61ed1386,0x9c7c02e6,0x7ae6a40b,0x24f625a9}},	// [bba0] šalj, načn, makt, ечер,
   {{0x6aa40201,0x26cb0036,0x26c90231,0x00000000}},	//   _izif, _efco_, acao_, --,
   {{0x66e61a18,0xdb160032,0xa3db009d,0x6b8400e7}},	//   _пона, _aiyé, ढील_, _kjig,
   {{0x9c7c025b,0xdb1603a9,0x26c90131,0x0ebb00a4}},	//   kačn, _biyé, ccao_, _उलगड,
   {{0x9c7c07c0,0x00000000,0x00000000,0x00000000}},	//   jačn, --, --, --,
   {{0x6fc701e8,0x6b842461,0x9c7c00d4,0x7ae6a40c}},	//   _sıca, _ljig, dačn, hakt,
   {{0x64a3a40d,0x7ae6a40e,0xb4dc5dda,0x00000000}},	//   _бара, kakt, ठरी_, --,
   {{0x44440078,0x232700ae,0x6b840361,0x8c250033}},	//   mx_, _поси_, _njig, যমান_,
   {{0x9c7c1b30,0x4444a40f,0x6aa47541,0x00000000}},	//   gačn, lx_, _nzif, --,
   {{0xc0aa1a37,0x4444a410,0x916200fe,0x5d541676}},	//   _فاضل_, ox_, _dự_, ткот,
   {{0x7ae6a411,0x44441da1,0xdbdb037a,0x6aa445f3}},	//   fakt, nx_, _báñe, _azif,
   {{0x44448d19,0xdd2f02c6,0x9c7c103b,0x7ae64b79}},	//   ix_, _měři, bačn, gakt,
   {{0xf99f06a3,0xc333040a,0xa3e70be5,0x99460206}},	//   stèm_, אור_, _मौन_, _kôň_,
   {{0x2b840587,0x6b840129,0x44440078,0xd90f0470}},	//   rıca_, _ejig, kx_, حید_,
   {{0x6aa43944,0x97a733ca,0x7b06007b,0xe895007b}},	//   _ezif, ерал, ättö, тавь,
   {{0x7ae6a412,0x7c9b00f5,0x44440078,0x2905003d}},	//   cakt, _משוג, dx_, żla_,
   {{0x44444330,0x80e10033,0xceb900d2,0x00000000}},	// [bbb0] ex_, _নাস্, peře_, --,
   {{0x6d5aa413,0x44445a3b,0x6b9da414,0x9c7c0146}},	//   nkta, fx_, llsg, načo,
   {{0x9c7c025b,0xa5bb002b,0xf4870cb0,0xdbdb1ba6}},	//   začn, _isóm, хуан, _yáñe,
   {{0x68e70018,0x290323ff,0xdbe30065,0x527500d3}},	//   lajd, lgja_, _déèt, кулу,
   {{0x22580084,0x9c7c0146,0x44440a23,0x6d5a09ad}},	//   ницы_, xačn, ax_, kkta,
   {{0x865a09c1,0x2903866a,0x7ae641a8,0x660da415}},	//   _חדשי, ngja_, zakt, mtak,
   {{0xe8e00028,0x660da416,0x7ae6004d,0x91620023}},	//   _hiểu_, ltak, yakt, _sự_,
   {{0xee3942d1,0x672da417,0xe8e00028,0x9c7ca418}},	//   дни_, ndaj, _kiểu_, tačn,
   {{0x0d8512e7,0x33844b34,0x7ae61e81,0x63a935f2}},	//   клин, _сурв, vakt, _ihen,
   {{0xb2743a7a,0x9c7c0074,0x41b503ed,0x7ae6005a}},	//   _слуш, račn, _شمار, wakt,
   {{0x80ca0e28,0x63bb0051,0x9c7c0220,0x660da419}},	//   _स्टे, _kiun, sačn, htak,
   {{0x9c7c07c0,0x628c0034,0x25640103,0x63bb0239}},	//   pačn, żnoś, _zöld_, _jiun,
   {{0x63bba41a,0x63a900f0,0x61eb066a,0x1d090284}},	//   _miun, _mhen, nsgl, _жели_,
   {{0x7ae64d9b,0x290323ff,0xdb0ba41b,0x673d02a1}},	//   sakt, ggja_, _bufó, _ansj,
   {{0x66e61e20,0x660d02a7,0x77640372,0x59be00c3}},	//   кова, etak, thix, _एंकर,
   {{0x660da41c,0xe8e00028,0xd5c300aa,0x00000000}},	//   ftak, _biểu_, _वंशज, --,
   {{0x660d5a89,0x7bc3a41d,0xaa464922,0x7e6901bf}},	// [bbc0] gtak, _hunu, _репл, nzep,
   {{0x63a91a45,0x4444a41e,0x7bc30010,0x7ae41b6f}},	//   _ahen, tx_, _kunu, _heit,
   {{0x444410af,0x660da41f,0x998064ed,0x62890072}},	//   ux_, atak, _križ_, _axeo,
   {{0x7bc3a420,0x4444a421,0x63a9507c,0x7ae4a422}},	//   _munu, rx_, _chen, _jeit,
   {{0x7ae4a423,0x63bb7db7,0x63a94fd0,0x444402a1}},	//   _meit, _diun, _dhen, sx_,
   {{0x7ae4a424,0x7e69a425,0xae1c034c,0x629b030a}},	//   _leit, dzep, _बैगन_, _dyuo,
   {{0x7bc3a426,0x63bb77df,0x69c424e7,0xb97b0089}},	//   _nunu, _fiun, _luie, ונסי,
   {{0x63bba427,0x03a602d8,0x63a92843,0x7ae47ae5}},	//   _giun, _рибо, _ghen, _neit,
   {{0xf7730054,0x9c7c025b,0x2366023e,0xaca30134}},	//   יקה_, tačo, mhoj_, baịl,
   {{0x7bc3a428,0x63a9a429,0x6d48023e,0x63bb0350}},	//   _bunu, _zhen, ujda, _ziun,
   {{0x7ae402d6,0x6d5aa42a,0x68e7a42b,0xaf062124}},	//   _beit, rkta, vajd, _апел,
   {{0x3f8001b3,0x7ae40091,0x16dc009d,0x7bc3a42c}},	//   čius_, _ceit, बरोब, _dunu,
   {{0x3ea00080,0x7ae416c2,0x7e690034,0x7c3e00e7}},	//   _áit_, _deit, czep, _šprd,
   {{0xbea3231c,0x7bc3a42d,0x69c400ee,0x660d1724}},	//   _тачк, _funu, _duie, vtak,
   {{0x7ae46391,0x7bc31084,0x212c01e5,0x68e7a42e}},	//   _feit, _gunu, _madh_, rajd,
   {{0x2d9e26b4,0x3d0e009d,0x61ed7689,0x7ae4a42f}},	//   llte_, त्रे_, šali, _geit,
   {{0x63bb008f,0x63a900f0,0x69c41b27,0x7bc30044}},	// [bbd0] _riun, _rhen, _guie, _zunu,
   {{0x63a9a430,0x7ae402dc,0x63bb022c,0x212ca431}},	//   _shen, _zeit, _siun, _nadh_,
   {{0x2d9e10f0,0xd49b660c,0x660da432,0x63a9a433}},	//   ilte_, фра_, stak, _phen,
   {{0x7ae40933,0xe8e00028,0x2d9e01bf,0x4ae30be4}},	//   _xeit, _tiểu_, hlte_, परिव,
   {{0x63bb0010,0x21750ef1,0x212ca434,0x61e0030a}},	//   _viun, лукр, _badh_, _cwml,
   {{0x3f860383,0x212c01b9,0x4a5c00ca,0x63a91890}},	//   _ajou_, _cadh_, ודדו, _when,
   {{0xd4980fe9,0x68e54881,0x10150037,0x212c01ec}},	//   _арт_, _mehd, ابتد, _dadh_,
   {{0x68e50084,0x7bc3a435,0xd1050f78,0x212c03ea}},	//   _lehd, _runu, _रावण_, _eadh_,
   {{0xa3e70d0b,0x7bc3a436,0x79950193,0x6df20037}},	//   _मौत_, _sunu, kozw, مكيا,
   {{0x7ae4a437,0x7bc3a438,0x14aa0096,0x69c4009c}},	//   _seit, _punu, _करमण, _ruie,
   {{0x7ae4a439,0x7bc37de9,0x3b0a17df,0x9c7c0357}},	//   _peit, _qunu, нено_, lačj,
   {{0xa2aa0e28,0x69c4a43a,0x4e3513c3,0x00000000}},	//   जेक्, _puie, _معتز, --,
   {{0x7ae40102,0x69c40fd7,0x68e500e7,0xe8e000de}},	//   _veit, _quie, _behd, _liễu_,
   {{0x7ae496ac,0x7bc3a43b,0xfce55a65,0xdb19052f}},	//   _weit, _tunu, _соко, _nuvæ,
   {{0x7ae402ad,0x00000000,0x00000000,0x00000000}},	//   _teit, --, --, --,
   {{0xfbd20054,0x69c40350,0x0f2100a3,0x00000000}},	//   _פתח_, _tuie, _मसोस_, --,
   {{0x3667a43c,0x00000000,0x00000000,0x00000000}},	// [bbe0] гато_, --, --, --,
   {{0x04461b48,0x00000000,0x00000000,0x00000000}},	//   лезн, --, --, --,
   {{0x98a8000d,0xf8a8000d,0x212c0441,0x6fbf00c3}},	//   _गरिए, _गरिय, _radh_, _लंगू,
   {{0x25e80455,0xb8271b60,0x7c3e1c9d,0xe8e000fe}},	//   _चौथी_, _союз_, _ápre, _diễu_,
   {{0x5b7b00c1,0x2d9e00f3,0x00000000,0x00000000}},	//   ערנא, ylte_, --, --,
   {{0xa5bb002b,0x31340686,0x2936006e,0x23660052}},	//   _apóf, рекр, ראַן_, shoj_,
   {{0xfaff00dd,0xe8e0020b,0x2d824691,0x00000000}},	//   dhën_, _giễu_, ékem_, --,
   {{0x442a04de,0x9f543457,0x4438a43d,0x3df48063}},	//   _isb_, рвич, _irr_, азис,
   {{0x6ce61acf,0x99890220,0x442aa43e,0x00000000}},	//   ліне, _hrať_, _hsb_, --,
   {{0x98ba0154,0xf28b0142,0x621b0142,0x2fc5078e}},	//   _anpč_, _אָבֿ, _אומק, _fulg_,
   {{0x9c7c00e9,0xe7b416e2,0x2cb80149,0x5597006e}},	//   mačk, ंगाप, ärd_, רדיע_,
   {{0x442a4b5d,0xda350084,0x4fa3008f,0x26c200d1}},	//   _msb_, аемы, _лихв, _ngko_,
   {{0xed5a1d2f,0x442a01af,0x629e0034,0x79950875}},	//   _под_, _lsb_, ępow, tozw,
   {{0x9c7c00e9,0x4438a43f,0xceb30341,0x442a01ce}},	//   načk, _orr_, _פיס_, _osb_,
   {{0x442aa440,0xb6d20294,0xd7f800d3,0x37aba441}},	//   _nsb_, _ọgọs, лут_, етан_,
   {{0xf40a0081,0x7c2aa442,0x9c7c2a4b,0x387e2e92}},	//   রবার_, _isfr, hačk, útra_,
   {{0x68e55644,0x442a0665,0x557505c7,0x3a2900a6}},	// [bbf0] _tehd, _asb_, агат, _usap_,
   {{0x9c7c08a9,0x0467007e,0x3f8403e3,0x99890206}},	//   jačk, лтем, hnmu_, _brať_,
   {{0x9c7c025b,0x752e01c2,0x998000c6,0x824b0103}},	//   dačk, _dabz, _erių_, کشاف_,
   {{0xd4984171,0x442aa443,0x4911521f,0x9259007b}},	//   уру_, _dsb_, द्रो_, кает_,
   {{0x81c700d9,0x442a003e,0x05db0034,0x394101cb}},	//   klēš, _esb_, मीखब, _knhs_,
   {{0x9c7ca444,0x752e01c2,0x2fc5037a,0xfaff0052}},	//   gačk, _gabz, _pulg_, xhën_,
   {{0xf8b5009f,0x44253411,0xa1560291,0xdfce5bce}},	//   ंधिय, _èl_, рају_, ويو_,
   {{0xbe39004d,0x4cde0033,0x00000000,0x00000000}},	//   вчої_, _মাগু, --, --,
   {{0x9c7c6361,0x3eb9a445,0x62345153,0x672f0216}},	//   bačk, äst_, _лету, _macj,
   {{0x8d552277,0x3f840808,0xa5bb00b3,0x64412fd7}},	//   ртич, anmu_, _aróz, _àlis,
   {{0xcb6a0020,0xe8e00028,0x3b863c76,0x603c044c}},	//   ване_, _hiệu_, илог, _cămă,
   {{0x661d7165,0xfaff00dd,0xe8e000fe,0x61ed004b}},	//   _opsk, shën_, _kiệu_, šalu,
   {{0x6db200a5,0x7c2a0161,0x00000000,0x00000000}},	//   _płat, _esfr, --, --,
   {{0x39410154,0xa2aa0034,0xdb1900b7,0x00000000}},	//   _cnhs_, जेट्, _auvä, --,
   {{0xb8ce1c37,0x661d282c,0xe8e00028,0xe7e109c3}},	//   _और_, _apsk, _liệu_, गीला_,
   {{0x2b40a446,0x92e70a43,0x00000000,0x00000000}},	//   _unic_, পলু_, --, --,

   {{0xc4e600c2,0x442a081d,0xe8e00023,0x4438a447}},	// [bc00] ижай, _ssb_, _niệu_, _srr_,
   {{0x845a4f8c,0x752e9119,0x442a2c2a,0x6db20034}},	//   крет_, _qabz, _psb_, _ułat,
   {{0x9c7c0106,0xb4d60067,0x07a6205c,0x186a08f9}},	//   vačk, _सभी_, _ванн, _рани_,
   {{0xdb160139,0x00000000,0x00000000,0x00000000}},	//   _jiyà, --, --, --,
   {{0x2d820018,0x9c7c00d4,0xdb1b00fd,0x6724a448}},	//   ékek_, tačk, mptô, meij,
   {{0x442aa449,0xe8e000de,0x44380087,0x99890094}},	//   _tsb_, _diệu_, _trr_, _trať_,
   {{0x9c7c00e9,0x6b5f00dd,0x44381430,0x442a70a9}},	//   račk, _dëgj, _urr_, _usb_,
   {{0x03d700a1,0xd1380034,0xe81e009f,0x9c7c45ca}},	//   _כולם_, _skąd_, _पहना_, sačk,
   {{0x9c7c87b9,0x70f61823,0xa5bb0065,0x63a287aa}},	//   mači, _نسائ, _aróy, mlon,
   {{0x9c7ca44a,0x21a600ae,0x40960284,0x6e39030a}},	//   lači, _тизм, _крет, _drwb,
   {{0x63a2028d,0xa5bb15bf,0x69d6010a,0x4c94037e}},	//   olon, _próz, _atye, синс,
   {{0x9c7c3b31,0x66040313,0x6db20034,0x64410072}},	//   nači, kuik, _płas, _álie,
   {{0xda780077,0x63a2028d,0x9d181300,0x672f0034}},	//   аяр_, ilon, _болт_, _racj,
   {{0x7af600a5,0x63a20201,0x9c7c0559,0x603c020a}},	//   _edyt, hlon, hači, _tămă,
   {{0x63a20335,0x6db20067,0x9c7c00cc,0xd7c900cd}},	//   klon, _włas, kači, اوره_,
   {{0x501b0054,0x9c7c0995,0xd6d81229,0xadc30032}},	//   כולו, jači, иту_, _atẹj,
   {{0x63a2a44b,0xd84302c6,0xdc3b00bd,0x9c7ca44c}},	// [bc10] dlon, dičů_, _iġġe, dači,
   {{0x3cec00e7,0xdce802c6,0x63a2007f,0x00000000}},	//   nadv_, vidě, elon, --,
   {{0xd5b8031e,0xf9900076,0x317c02db,0x00000000}},	//   рст_, _تبي_, divz_, --,
   {{0x9c7c03ce,0x63a28a45,0xbd050032,0x27fe0031}},	//   gači, glon, _adẹ́, átne_,
   {{0x661da44d,0xa1593e9a,0x569400d6,0x964700c6}},	//   _upsk, ладу_, _мают, _тэнд,
   {{0x63a2a44e,0x27fe230b,0xfaff0216,0x00000000}},	//   alon, štne_, dhëm_, --,
   {{0x63a2a44f,0x256401bf,0xdc3b003d,0x7bce167e}},	//   blon, _köln_, _oġġe, íbul,
   {{0x438500e3,0x9c7c037d,0x6458007b,0x335800ae}},	//   _الرق, cači, ävie, _касэ_,
   {{0x335800d3,0x00000000,0x00000000,0x00000000}},	//   _татэ_, --, --, --,
   {{0x4d6591e5,0xdc3b009e,0x7c3e2281,0x7f42039f}},	//   сков, _aġġe, _špra, _enoq,
   {{0x3f58016d,0xdb0401b9,0x7f1933c2,0x67240350}},	//   _céus_, _phià, _білу_, yeij,
   {{0x291a00dc,0x3f58015e,0x8e3900b9,0x491a00b7}},	//   _sbpa_, _déus_, _مستر_, म्नो_,
   {{0x3f9d0129,0x00000000,0x00000000,0x00000000}},	//   _ikwu_, --, --, --,
   {{0x2bcf136b,0xe503033a,0x9c7c08c5,0xb4d6007a}},	//   _संपा, _लागि_, zači, _सभे_,
   {{0x6d431e81,0x98a60f50,0x186708f9,0x6e2972b3}},	//   _inna, сиве, бари_, lweb,
   {{0x6f09a450,0x7c3c02b6,0x7c3e0072,0x290c0034}},	//   ngec, ærre, _ápra, żda_,
   {{0x6e29a451,0x63a20141,0x00000000,0x00000000}},	// [bc20] nweb, vlon, --, --,
   {{0x66040a9f,0x3f580113,0x6e2902ac,0x00000000}},	//   ruik, _yéus_, iweb, --,
   {{0x63a200a6,0x6e293388,0x9c7c3b97,0x66043ba3}},	//   tlon, hweb, tači, suik,
   {{0xaca30294,0xd24f00cd,0x3f9d0174,0x68eea452}},	//   _atịk, کنه_, _nkwu_, labd,
   {{0x9c7c6dce,0x63a2a453,0xdb0d0113,0x7d080212}},	//   rači, rlon, _dhaè, ygds,
   {{0x290a026e,0x63a20660,0x3f9d0134,0x9c7c0559}},	//   ngba_, slon, _akwu_, sači,
   {{0x657e0201,0x6e2902ac,0x9c7ca454,0x00000000}},	//   miph, eweb, pači, --,
   {{0x6d432fe3,0x657e0201,0x3f58016d,0x2d9c00dc}},	//   _anna, liph, _réus_, _skve_,
   {{0xa5bb0b0b,0x2cea2983,0x68ee0063,0x93430dd8}},	//   _próx, льно_, kabd, _энте,
   {{0x3f9d00ac,0x657e0060,0x68ee0063,0x6d430231}},	//   _ekwu_, niph, jabd, _cnna,
   {{0xfaff01e5,0xaf0a0814,0x80a61b49,0x459b00c1}},	//   shëm_, _مقام_, _امان, רסיע,
   {{0x6d4360d8,0x657ea455,0x7b670245,0x6e29a456}},	//   _enna, hiph, стое, bweb,
   {{0x5e5a1a37,0xbc670260,0xdbe20072,0x7bda0036}},	//   _حجاج_, لمین_, _véñe, sptu,
   {{0xfbcf0421,0x7bdaa457,0xdd90096a,0x29180537}},	//   بتی_, pptu, _توت_, gfra_,
   {{0x115b00c1,0xdbe20042,0x2bcf00b7,0x9848007b}},	//   נדלע, _téñe, _संया, бята_,
   {{0x28d91e9f,0x443f0559,0xf77300d1,0x6db2007f}},	//   _ब्रि, _ču_, ساز_, _złap,
   {{0x29050013,0x7bca0239,0x657e0372,0x7aefa458}},	// [bc30] òlas_, _hufu, fiph, mact,
   {{0x7bcaa459,0x6aada45a,0x657e0415,0x65b0007b}},	//   _kufu, _izaf, giph, jähd,
   {{0x59d40018,0xa5bb0328,0x321f084e,0x7aef00b3}},	//   _وغیر, _apóc, _spuy_, oact,
   {{0x1dc80557,0x25640149,0x7aef2cd5,0x7bca3304}},	//   रदात, _höll_, nact, _mufu,
   {{0x2bcf4972,0x657e36e4,0x7bca01b2,0xe2990b1b}},	//   _संभा, biph, _lufu, јал_,
   {{0x6b8d015c,0x657ea45b,0xdb0d00cd,0x45d43283}},	//   _ljag, ciph, _dhaé, _хорс,
   {{0xb4e52a24,0x7aef029a,0x6b8da45c,0x00000000}},	//   नरी_, kact, _ojag, --,
   {{0x27e50181,0x987c0089,0x6e29010a,0x9c7c28f9}},	//   álny_, טרוק, tweb, naču,
   {{0x7aefa45d,0x6aad0169,0x6f091c6b,0x69dd0381}},	//   dact, _nzaf, rgec, jpse,
   {{0x6b8da45e,0x6e294479,0x8d5900d3,0x7bca3e6b}},	//   _ajag, rweb, ршит_, _bufu,
   {{0x3a20a45f,0x1b4a1121,0x8b261061,0x6aada460}},	//   _spip_, азни_, одне, _azaf,
   {{0xeaba0451,0x2007a461,0xe51900c0,0x920d0efd}},	//   ийн_, muni_, न्ति_, _समाज_,
   {{0x2007a462,0x657e0201,0x6b8d1cb0,0x645e007f}},	//   luni_, yiph, _djag, zypi,
   {{0x6aada463,0x7bcaa464,0x6b8d06b0,0x1d0600d3}},	//   _dzaf, _fufu, _ejag, _деши_,
   {{0x2007a465,0x291813c8,0x7bcaa466,0x68eea467}},	//   nuni_, rfra_, _gufu, rabd,
   {{0xa3cd00a3,0x68eea468,0x00000000,0x00000000}},	//   रदन_, sabd, --, --,
   {{0x20071e28,0xe57a10f7,0x25640149,0x64430149}},	// [bc40] huni_, аза_, _föll_, ånin,
   {{0x2007a469,0x645ea46a,0x7bc400aa,0x6aa403a5}},	//   kuni_, typi, _hiiu, _iyif,
   {{0x2007a46b,0x657e4e9d,0x212700e7,0x42ca3b21}},	//   juni_, riph, denh_, аген_,
   {{0xe73a0084,0x2007a46c,0x657e0060,0x9f5c00b6}},	//   _тем_, duni_, siph, prvé_,
   {{0x914a336f,0x27ed0039,0x65b0007b,0x9c7c0206}},	//   ичка_, ćene_, tähd, lačt,
   {{0xaca30e62,0x661601df,0x20073a09,0x7aef00d3}},	//   _atọk, mtyk, funi_, zact,
   {{0x64a31d57,0x2007a46d,0xdb0f025b,0x7aef008c}},	//   _жара, guni_, ždéh, yact,
   {{0x7bca0169,0x799c9282,0x7aef33c4,0x2c4e00a7}},	//   _rufu, horw, xact, qədi_,
   {{0xc7b37c04,0x799c092f,0xed8a4177,0x6616013f}},	//   ובה_, korw, исок_, ntyk,
   {{0x661601b3,0x2007068d,0xdb0d0257,0x067b0089}},	//   ityk, buni_, _chaî, ינפל,
   {{0x2007013d,0x6aad0034,0x7bc4009c,0x1ee8001c}},	//   cuni_, _szaf, _biiu, _هوای_,
   {{0x661676b2,0x6aa405bd,0x00000000,0x00000000}},	//   ktyk, _byif, --, --,
   {{0x799ca46e,0x64480072,0x6aa405bd,0xdcfa01d3}},	//   forw, _ádif, _cyif, notī,
   {{0x7aef2a56,0x7bcaa46f,0x69dd32a7,0x7c3e002b}},	//   sact, _tufu, rpse, _ápro,
   {{0x2fcc0154,0xa5bb0131,0x6aa4063d,0x6d58078e}},	//   _judg_, _osór, _eyif, _iova,
   {{0x2bcf0e72,0x27fe1515,0x69dd5024,0x00000000}},	//   _संता, átna_, ppse, --,
   {{0x2007597c,0xef1922a5,0x66f42e9e,0x799c02a4}},	// [bc50] zuni_, niża_, ьпту, borw,
   {{0x6d582461,0x2007a470,0x7d1a0364,0x7aeda471}},	//   _jova, yuni_, nfts, _heat,
   {{0x6d58a472,0x7aed063f,0x49b8001c,0x6eca00b6}},	//   _mova, _keat, _بايد_, ाखाँ,
   {{0x6d58a473,0x2007198d,0x7aed0154,0x8c1b0327}},	//   _lova, vuni_, _jeat, שואי,
   {{0x69c5a474,0x614546aa,0x7aed372f,0x00000000}},	//   _kihe, зела, _meat, --,
   {{0x6d580565,0x2007a475,0x41290114,0xaca30134}},	//   _nova, tuni_, соко_, _stọk,
   {{0xfbc609c3,0x2bc6009d,0xe0421aad,0x00000000}},	//   _रंगम, _रंगा, енщи, --,
   {{0xd343110a,0x6e220037,0x4423a476,0x69c54311}},	//   _تفری, _bpob, _ipj_, _lihe,
   {{0xc3321541,0x6b9d002b,0x75350cea,0x6d588f4b}},	//   _און_, dosg, _kazz, _bova,
   {{0x61e9818f,0x44230167,0xceb900b6,0x1d090291}},	//   _iwel, _kpj_, neři_, љени_,
   {{0x75356cdb,0x6d58678b,0x6aa402e7,0x44230332}},	//   _mazz, _dova, _syif, _jpj_,
   {{0x61e9a477,0x69c502fd,0x7aed03e9,0x66166bd3}},	//   _kwel, _aihe, _ceat, ytyk,
   {{0x799ca478,0x4423005c,0x69c55f7f,0xf1c3003d}},	//   torw, _lpj_, _bihe, poġġ_,
   {{0x753503e5,0x6d5803ab,0x61e981fe,0x2d820018}},	//   _nazz, _gova, _mwel, éket_,
   {{0x7aed0054,0x25640149,0x69c51e28,0x44313360}},	//   _feat, _följ_, _dihe, _nsz_,
   {{0x6f1b8c79,0x7aed03dc,0x69c501ff,0x6d580381}},	//   nfuc, _geat, _eihe, _zova,
   {{0x7535a479,0x69c50090,0x61e90174,0x799c0a4b}},	// [bc60] _bazz, _fihe, _nwel, porw,
   {{0xaa3b00a1,0x7535008f,0x66160ee8,0x69c502a4}},	//   _פתיח, _cazz, rtyk, _gihe,
   {{0x6616931c,0x61e9a47a,0x65ab042c,0x03261c16}},	//   styk, _awel, mühl, зден,
   {{0x69c59b8f,0x6448003d,0x4431a47b,0x61e906b0}},	//   _zihe, _ġdid, _dsz_, _bwel,
   {{0x753518ba,0xe51900aa,0x64411d90,0x69c5a47c}},	//   _fazz, न्हि_, _álin, _yihe,
   {{0x75358d3a,0x660412d2,0x61e9a47d,0x395a033c}},	//   _gazz, mrik, _dwel, _jops_,
   {{0x61e9a47e,0x6d5860e3,0x442c06a3,0x7c240a39}},	//   _ewel, _rova, _èd_, _ćiro,
   {{0x7535006d,0x6d58a47f,0x09e20033,0x00000000}},	//   _zazz, _sova, _বিনা, --,
   {{0x61e902e0,0x7aeda480,0x6d584fd4,0xe8e00028}},	//   _gwel, _reat, _pova, _chịu_,
   {{0x64482e00,0x63ae0138,0x7aeda481,0x7bcd0095}},	//   _àdis, šinė, _seat, _čaur,
   {{0x7aeda482,0xe7be009d,0x6604a483,0x9b957ef2}},	//   _peat, ्दाप, hrik, динц,
   {{0x6604a484,0xa3e43613,0x2366a485,0x491a023a}},	//   krik, पीए_, nkoj_, म्सो_,
   {{0x6d58199c,0x65ab01bf,0x69c52501,0x6b9d44f7}},	//   _tova, fühl, _pihe, rosg,
   {{0x6604134d,0xdb0d11e0,0x7aeda486,0x395a0133}},	//   drik, _ciaò, _weat, _cops_,
   {{0x7aeda487,0x75350f2f,0x36d51676,0x69c5a488}},	//   _teat, _razz, добр, _vihe,
   {{0x27ff25ed,0x2d9ea489,0x97a400ae,0x2366023e}},	//   čun_, lote_, ерул, jkoj_,
   {{0x7535008f,0x2d8ca48a,0x69c50673,0x6604a48b}},	// [bc70] _pazz, onde_, _tihe, grik,
   {{0x2d9ea48c,0x2fc6a48d,0x44230063,0xdb0d0076}},	//   note_, _liog_, _ppj_, _mhaí,
   {{0x2d8c4a28,0x66041d4b,0xf9900037,0x61e91190}},	//   inde_, arik, _حبي_, _swel,
   {{0x2bcf349d,0x753545be,0x2366023e,0xe1f1001c}},	//   _संसा, _wazz, gkoj_, نست_,
   {{0xb90a00ef,0xe1f801b6,0x75350f9a,0x45d405af}},	//   _nghệ_, згі_, _tazz, _пояс,
   {{0x09e20081,0x2d8c01c0,0x2d9ea48e,0x1a9c006e}},	//   _বিমা, jnde_, jote_, זידע,
   {{0x2d9ea48f,0x2b4901ff,0xd404007b,0x61e90090}},	//   dote_, _onac_, _пяти, _wwel,
   {{0x2d8ca490,0x236604a3,0x53340012,0x6d5c4478}},	//   ende_, ckoj_, _пест, öran,
   {{0x09e20f71,0x88c50081,0xee36013f,0xdb0d0072}},	//   _বিভা, ্রিক, дны_, _chaí,
   {{0x2d9ea491,0xe81e00a5,0x9e640037,0x2b490131}},	//   gote_, _पहला_, عاين, _anac_,
   {{0x2fc6009c,0x61fc01d3,0x26d90381,0x00000000}},	//   _fiog_, _ārli, _ofso_, --,
   {{0x2d8c0337,0x09e20033,0xc8e682d0,0x2bee007f}},	//   ande_, _বিবা, कर्म_, _आबरू_,
   {{0x2bcf1e9f,0x2d9e1be4,0x00000000,0x00000000}},	//   _संवा, bote_, --, --,
   {{0x2d9e08f6,0xdb0d002b,0x2b490036,0x27fe0094}},	//   cote_, _diañ, _enac_, átno_,
   {{0x07a60581,0x236d1643,0x2b494466,0x3f8d0428}},	//   давн, _olej_, _fnac_, oneu_,
   {{0x6604a492,0x29040702,0xdcfa0877,0x68e10345}},	//   trik, şma_, mitā, ılda,
   {{0xdcfa0029,0x27ed02e6,0x07a32787,0x80a40034}},	// [bc80] litā, ćena_, татн, _चुने,
   {{0x6604a493,0x59833b4f,0xfaff0216,0x236d00d8}},	//   rrik, _альб, nkën_, _alej_,
   {{0x6604a494,0x23660995,0xdcfa01d3,0x236d0052}},	//   srik, tkoj_, nitā, _blej_,
   {{0x491a033a,0x2ca7a495,0x2d9e0239,0xdb16020d}},	//   म्रो_, _mynd_, zote_, écèd,
   {{0x236d023e,0x2366023b,0x2d9e756f,0xdb04033c}},	//   _dlej_, rkoj_, yote_, _bhiú,
   {{0x236600e9,0x2d9ea496,0xdb0400da,0x00000000}},	//   skoj_, xote_, _chiú, --,
   {{0x2d9ea497,0x65638776,0xdb040037,0xe4c31894}},	//   vote_, önhe, _dhiú, _айри,
   {{0x2d9e0051,0x934328ce,0x236d0087,0x9326001c}},	//   wote_, _инсе, _glej_, _ترسن,
   {{0x2d9ea498,0xdb040503,0x00000000,0x00000000}},	//   tote_, _fhiú, --, --,
   {{0x2d8ca499,0xdb0d037a,0x61e23f43,0x3eb904c8}},	//   unde_, _riañ, mpol, ýsta_,
   {{0xcfa90018,0x2d8c0364,0xdcfa01d3,0x00000000}},	//   _کالم_, rnde_, gitā, --,
   {{0xa5bb5d81,0xdb0d0131,0x61e296d8,0x00000000}},	//   _apól, _thaí, opol, --,
   {{0x61e20184,0xfaff0052,0x7bdc00d4,0x7e9a0076}},	//   npol, dhët_, írub, _بنشر_,
   {{0x3f845594,0x2ca702ad,0x61e20036,0xdb0d0072}},	//   limu_, _fynd_, ipol, _viañ,
   {{0x58d42064,0xb8d702e8,0x6d4a361a,0xdcfa01d3}},	//   тост, _जर_, _infa, citā,
   {{0x65ab85b3,0x3f84a49a,0xa03700ca,0x61e2a49b}},	//   rühm, nimu_, ואלה_, kpol,
   {{0xa3e70e50,0x35b5a49c,0x60da0364,0x00000000}},	// [bc90] _मौज_, ебар, _oftm, --,
   {{0x3f84068d,0x236d0117,0x00000000,0x00000000}},	//   himu_, _slej_, --, --,
   {{0x3f84a49d,0x236d0d62,0x68f503e0,0x96c00285}},	//   kimu_, _plej_, mazd, लेबॉ,
   {{0x14df4972,0xdb04033f,0x61e29ac7,0x3f84a49e}},	//   _प्रण, _shiú, fpol, jimu_,
   {{0xdb16025a,0xdb040441,0x69d80117,0x3f84a49f}},	//   écéd, _chiù, _čvek, dimu_,
   {{0x660d73b6,0x6d5c0212,0x291101fa,0xdb040441}},	//   muak, öral, ngza_, _dhiù,
   {{0x61e22039,0x10a224e9,0x660d5ef7,0x603300a7}},	//   apol, лишн, luak, _kəmə,
   {{0x6d4aa4a0,0xdcfa00d9,0x3f8433b6,0xdb0401ec}},	//   _anfa, vitā, gimu_, _fhiù,
   {{0x2ca70f05,0x3f8da4a1,0xdb0401f7,0x68f5a4a2}},	//   _synd_, rneu_, _ghiù, kazd,
   {{0x68f52ac2,0x128a00d0,0x98a301d3,0x645a015e}},	//   jazd, _عملی_, zejā_, _àtic,
   {{0x1ae70081,0x660d02fa,0x09e20033,0x672d0a4b}},	//   _কাজে_, huak, _বিধা, keaj,
   {{0x6d4aa4a3,0xdcfa00d9,0xfaff023b,0x25860065}},	//   _enfa, ritā, dhës_, _kílè_,
   {{0xfbcf02d5,0x7f4b019f,0x672d586e,0x00000000}},	//   _सूरम, _ingq, deaj, --,
   {{0xdcfa00d9,0x20070451,0x68f50103,0x61fb198d}},	//   pitā, orni_, gazd, _mvul,
   {{0x2d85a4a4,0x61e20087,0xd7be009d,0xdd8e00d1}},	//   mile_, zpol, ्दलच, _دوو_,
   {{0x2d85a4a5,0x61e227cd,0xc7a30161,0x00000000}},	//   lile_, ypol, гиск, --,
   {{0x660d0062,0xfbac02d5,0x7f4b02ac,0x61e20062}},	// [bca0] guak, _टीएम, _mngq, xpol,
   {{0x2d85a4a6,0x3f846cd3,0xba9b03c2,0xfaff0052}},	//   nile_, zimu_, _מספי, shët_,
   {{0xdcfa002d,0x61fba4a7,0x13060396,0x7c243360}},	//   lită, _avul, езем, _ćirk,
   {{0x2d850060,0x25860032,0x4aa50285,0x200705db}},	//   hile_, _bílè_, _गुडव, drni_,
   {{0x2d85067d,0x57be0557,0xdcfa00ae,0x8b0800b6}},	//   kile_, ्दीह, nită, _zpří,
   {{0x1ae700c7,0x61e4002d,0x61e2a4a8,0x7f4b063d}},	//   _কাছে_, ţilo, rpol, _angq,
   {{0x2d85a4a9,0x443e82a4,0x1dd500c3,0x61fb48d3}},	//   dile_, _ét_, _डूबत, _evul,
   {{0x7c3e0018,0x2d8500bc,0x50230037,0x00000000}},	//   _ápri, eile_, افيك, --,
   {{0x3f8416da,0x2d85a4aa,0x63a2a4ab,0xfaff0052}},	//   rimu_, file_, moon, zhës_,
   {{0x3f84a4ac,0x63a21e0b,0x2d859b35,0x2007831e}},	//   simu_, loon, gile_, brni_,
   {{0x4c940b22,0xfaff0052,0x68f500e7,0xa3e402d5}},	//   тинс, xhës_, vazd, पीच_,
   {{0x63a20283,0xe0df0019,0x6b860270,0xa3d31024}},	//   noon, _đòi_, gikg, _हंस_,
   {{0x2d852849,0xb5100ff9,0x63a2010a,0x00000000}},	//   bile_, ालाय_, ioon, --,
   {{0x2d85a4ad,0x63a2a4ae,0x6d4aa4af,0x4aa50e28}},	//   cile_, hoon, _unfa, _गुणव,
   {{0x27ed02e6,0xb8e915e4,0x63a250f4,0x2bac0d61}},	//   ćeno_, _ऋण_, koon, _टीका,
   {{0x25a102e2,0x63a2a4b0,0x660da4b1,0x2cb10233}},	//   wohl_, joon, tuak, üzde_,
   {{0xfaff00dd,0x63a221c7,0xdcfa00ae,0xf4850103}},	// [bcb0] shës_, doon, cită, ھائی,
   {{0x200e2acb,0xd2511ac9,0x6d9c0233,0x00000000}},	//   kufi_, ینا_, _uçağ, --,
   {{0x63a2a4b2,0x4427a4b3,0x61fb040f,0x798702a4}},	//   foon, ïn_, _svul, mijw,
   {{0x2d85a4b4,0x63a25c55,0x2007033b,0xdb160154}},	//   zile_, goon, vrni_, _chyè,
   {{0x61e00063,0x2d85019f,0xdb04029a,0x660d0372}},	//   _ctml, yile_, _skië, quak,
   {{0x798702a4,0x2d85a4b5,0x3a290154,0xe7e800b6}},	//   nijw, xile_, _mpap_, टीका_,
   {{0x200e0193,0x63a2a4b6,0xdcfa020a,0x00000000}},	//   gufi_, boon, zită, --,
   {{0xc01c00de,0x2007023b,0x63a2041c,0x9f5c0094}},	//   _hước_, rrni_, coon, trvá_,
   {{0xe3b00391,0x2d852840,0x2901a4b7,0x798702a4}},	//   _طرف_, tile_, _odha_, kijw,
   {{0x4d653ad2,0x1c4526bc,0xdcfa00d3,0x29010124}},	//   тков, вном, vită, _ndha_,
   {{0x2d85a4b8,0xeb9a54d5,0x3a29a4b9,0x3b0a1a57}},	//   rile_, дин_, _apap_, мено_,
   {{0x2d85a4ba,0x00560105,0xdcfa020a,0x3d1306eb}},	//   sile_, _בשעת_, tită, _दावे_,
   {{0xeaf20251,0x3f7a00c1,0x3b00023b,0xff50153b}},	//   _अजीत_, _קאנס, _vdiq_, _دخل_,
   {{0xc01c00ef,0xdcfa00d3,0xdce80138,0x63a243e1}},	//   _nước_, rită, didė, zoon,
   {{0x98a61d12,0x63a22ca2,0x2901009c,0xdcfa044c}},	//   тиве, yoon, _ddha_, sită,
   {{0x57be030b,0x9a6a0037,0x00000000,0x00000000}},	//   ्देह, _يمثل_, --, --,
   {{0x7c2400e9,0x6b845b99,0xc01c0028,0x96631edc}},	// [bcc0] _ćiri, _imig, _bước_, акте,
   {{0x63a29e0c,0xc01c00de,0x9c120e62,0x00000000}},	//   woon, _cước_, _mọnd, --,
   {{0x63a2a4bb,0x80c70081,0x1c0906ed,0x9f4e0052}},	//   toon, রুত্, _विफल_, ënës_,
   {{0x91e61b4d,0x69cb7fbc,0x00000000,0x00000000}},	//   воде, _éger, --, --,
   {{0x63a2a4bc,0x25640088,0x82330037,0x25b8009c}},	//   roon, _sölu_, لروا, _thrl_,
   {{0x63a2a4bd,0x42d20033,0x00000000,0x00000000}},	//   soon, ারেশ, --, --,
   {{0x63a2156e,0xf99300ca,0x00000000,0x00000000}},	//   poon, ברג_, --, --,
   {{0x442aa4be,0x753ca4bf,0x65b001bf,0x200e2b5b}},	//   _ipb_, _harz, zähl, rufi_,
   {{0x753ca4c0,0x443800dc,0x442a080e,0xd2a7002d}},	//   _karz, _hsr_, _hpb_, _акте_,
   {{0x6b84386c,0xc01c0023,0xd24f0076,0x753e01ff}},	//   _amig, _xước_, _بنك_, ndpz,
   {{0x753c1763,0x2175672f,0x45080033,0x09e20033}},	//   _marz, _сутр, র্থক_, _বিষা,
   {{0x44383b03,0x65b001bf,0xf41300a1,0xdce100d9}},	//   _msr_, wähl, ספר_, rklā,
   {{0x80c700c7,0xed5a008f,0x70000129,0x6f020036}},	//   রুদ্, _оод_, _ịche, _idoc,
   {{0x6b84a4c1,0x753c00a5,0x44380b14,0x09e20081}},	//   _emig, _narz, _osr_, _বিশা,
   {{0x97a70084,0xd7f8002d,0x79870193,0xc01c0023}},	//   врал, кут_, rijw, _rước_,
   {{0x24b80081,0x25fe08d4,0x753ca4c2,0x09e20033}},	//   জশাহ, _लिखी_, _aarz, _বিরা,
   {{0xc7c800c2,0xa3be00c3,0x45d4235c,0xa5f831ef}},	// [bcd0] тыре_, ुआई_, иотс, кету_,
   {{0x1c09152c,0x69350235,0xf4d10033,0x6aad0372}},	//   _विमल_, _сноу, ির্ব, _iyaf,
   {{0xdce8013f,0x7bcd013f,0x02cb009f,0x753ca4c3}},	//   sidė, _kiau, िश्न, _darz,
   {{0x2125005c,0x42750231,0x6aad779b,0x386c0170}},	//   _sblh_, лгес, _kyaf, ødre_,
   {{0x753ca4c4,0xc01c0023,0x6b7c0266,0x442a0381}},	//   _farz, _tước_, וראנ, _epb_,
   {{0x7c3804a3,0x6f023a74,0x7bcd0138,0x7c2a2c18}},	//   _osvr, _adoc, _liau, _opfr,
   {{0xc95400f5,0x2576052f,0x673d03df,0x9c120174}},	//   ימס_, _sælg_, _kasj, _sọnd,
   {{0xee391b4d,0x753c00a5,0xb4c10251,0x673d029a}},	//   ени_, _zarz, ुशी_, _jasj,
   {{0x673d4725,0x63a9a4c5,0x63bb52d9,0x7c2a009c}},	//   _masj, _iken, _ihun, _apfr,
   {{0x6f020174,0x2576052f,0x6b84a4c6,0x27fe0087}},	//   _edoc, _vælg_, _smig, štni_,
   {{0x9f050e5a,0x63bb0019,0x6aad628f,0xc4b100c3}},	//   _موضو, _khun, _ayaf, _झरोख,
   {{0x673d02ec,0x6aad21e9,0x7bcd67a5,0x2bba0037}},	//   _nasj, _byaf, _ciau, عادة_,
   {{0x7bcd005c,0x6aad05bd,0x63a90a4b,0x63bba4c7}},	//   _diau, _cyaf, _mken, _mhun,
   {{0x6447026a,0x6aad0154,0x7bcd01ff,0xfce21d62}},	//   _orji, _dyaf, _eiau, _лошо,
   {{0x63a9a4c8,0x6aad10df,0x673d05c2,0xbd9a006e}},	//   _oken, _eyaf, _basj, _אױסט,
   {{0x63a97d0a,0xe737a4c9,0x63bb0019,0x753ca4ca}},	//   _nken, лес_, _nhun, _sarz,
   {{0x644301c5,0x753ca4cb,0x7e691a78,0x4438a4cc}},	// [bce0] ænin, _parz, nyep, _ssr_,
   {{0x201802b9,0x63a9a4cd,0x491b0789,0x63bb35a7}},	//   _årig_, _aken, _बायो_, _ahun,
   {{0x63bb0a1b,0x753c851b,0x69d6a4ce,0x649a1ba7}},	//   _bhun, _varz, _huye, хтар_,
   {{0x63bba4cf,0xe29a01b3,0x753c0034,0x69d669f8}},	//   _chun, нае_, _warz, _kuye,
   {{0x63bba4d0,0x753ca4d1,0xa68303fb,0x69d603e3}},	//   _dhun, _tarz, _гляд, _juye,
   {{0x64a63f4f,0x63a9a4d2,0x673d0268,0x7af65952}},	//   _бага, _eken, _zasj, _leyt,
   {{0x629c0067,0x802600cd,0x69d6a4d3,0x442a010f}},	//   _środ, ارتم, _luye, _upb_,
   {{0xb4c0000f,0x7af651d3,0x63bb03ea,0x6724a4d4}},	//   ँधी_, _neyt, _ghun, nfij,
   {{0xa2cb072d,0x44448295,0xa5bb00e3,0xe2975ddd}},	//   _तृप्, lv_, _spói, _бат_,
   {{0x444401bb,0xa3d30067,0x71d700a1,0x7bcd013f}},	//   ov_, _हूँ_, _עובד_, _siau,
   {{0x4ac7007d,0x6aad1a47,0xdb550084,0x69d601c2}},	//   रेनव, _syaf, авны, _auye,
   {{0x4444a4d5,0x63a90063,0x69d6a4d6,0x63bb0216}},	//   iv_, _xken, _buye, _xhun,
   {{0xc3330054,0x291a01b9,0xb69b00ae,0x69d6037a}},	//   זור_, _bcpa_, _adân, _cuye,
   {{0x69d600fe,0x6aada4d7,0x67dc0154,0x90d5020b}},	//   _duye, _vyaf, _sčja, _làn,
   {{0xa3d300a5,0x4444a4d8,0x673da4d9,0x7af6022b}},	//   _हूं_, jv_, _pasj, _feyt,
   {{0x673d0052,0x213e0a9a,0x90d500fe,0x69d600fc}},	//   _qasj, _lath_, _nàn, _fuye,
   {{0x44440197,0xc9871372,0xa3da0251,0x2abb026e}},	// [bcf0] ev_, _буни, _डूब_, _dàbí_,
   {{0x63bba4da,0x63a9a4db,0x213ea4dc,0x776d0188}},	//   _shun, _sken, _nath_, skax,
   {{0x3d1c3d34,0xd6d100e3,0x63bba4dd,0x673d029a}},	//   _माने_, _وقد_, _phun, _tasj,
   {{0xb5191349,0x90d500fe,0x00000000,0x00000000}},	//   न्जय_, _càn, --, --,
   {{0x444401bb,0x69d600fe,0x213ea4de,0x90d500fe}},	//   av_, _xuye, _bath_, _dàn,
   {{0x3f86a4df,0x213e9df4,0xa5930260,0xd0092efb}},	//   _amou_, _cath_, _اگرچ, веке_,
   {{0x213e009b,0x70520037,0x63bb1224,0x00000000}},	//   _dath_, قنوا, _thun, --,
   {{0x63a919dd,0x63bb08f0,0x6f65008f,0x2c7b0139}},	//   _uken, _uhun, рвиз, _ládé_,
   {{0x660da4e0,0x4421a4e1,0x7af62326,0x213e0150}},	//   nrak, lth_, _reyt, _fath_,
   {{0x0c250077,0x213ea4e2,0x4421a4e3,0x69d60079}},	//   амон, _gath_, oth_, _ruye,
   {{0x442100a1,0x69d60449,0xdcfa00e8,0x7e7b3e99}},	//   nth_, _suye, entē, szup,
   {{0x4421a4e4,0x1ee700cd,0x660d01d3,0x6e39023e}},	//   ith_, _صوتی_, krak, _tswb,
   {{0xeb973edd,0x7ae98a14,0x69d600de,0xdd950fe9}},	//   рия_, ñeta, _quye, _кады,
   {{0xfce50291,0x7af62b7c,0xdb04009c,0x660da4e5}},	//   _токо, _weyt, _chiò, drak,
   {{0x9d1a0089,0x660da4e6,0x2c7b0032,0x52b20403}},	//   _יוסט, erak, _dádé_, _जर्स,
   {{0x44213d38,0x69d600de,0xa6e6372a,0x65b04880}},	//   dth_, _tuye, ржал, pähk,
   {{0x44211a2e,0x44440d7d,0x672401c0,0xe73700c2}},	// [bd00] eth_, wv_, rfij, шет_,
   {{0xe57722ff,0x79fb040a,0x4444a4e7,0x2fcf00f3}},	//   азу_, _שליח, tv_, _ligg_,
   {{0x68fca4e8,0x4444006c,0x2abb0649,0x213ea4e9}},	//   mard, uv_, _tàbí_, _rath_,
   {{0x7794a4ea,0x68fc0390,0x4444a4eb,0x6d410085}},	//   _ایرا, lard, rv_, hdla,
   {{0x80ad00c7,0x2d870113,0x1603030b,0x38bc0139}},	//   টেম্, _omne_, _लिएर_, _fárí_,
   {{0x2918a4ec,0x333f00fd,0x213e0167,0x2b4015d3}},	//   ngra_, _eaux_, _qath_, _laic_,
   {{0x333f8646,0x21670291,0x6d41472d,0x00000000}},	//   _faux_, рији_, ddla, --,
   {{0x68fc55a9,0x9316015a,0xab620233,0x212002c6}},	//   hard, _خورش, çüle, řih_,
   {{0x68fca4ed,0x27ed00e9,0x2fcfa4ee,0x602a00a7}},	//   kard, ćeni_, _digg_, _qəmb,
   {{0x68fc0542,0x5d661824,0x2d8700dc,0x65b00364}},	//   jard, ртиз, _cmne_, fähi,
   {{0x2cb80bab,0x10a600d6,0x660d316d,0x68fc55ab}},	//   ård_, _тижн, zrak, dard,
   {{0x2d871484,0x80ad0081,0x68f756a2,0xbb9400c2}},	//   _emne_, _চলচ্, _sexd, жающ,
   {{0x68fca4ef,0x491b007a,0x00000000,0x00000000}},	//   fard, _बादो_, --, --,
   {{0xac180f1e,0x44217828,0x68fca4f0,0x9e651aaa}},	//   _боку_, yth_, gard, _دامن,
   {{0x2bd03f50,0xb8681e6e,0x2b4001b5,0x2fcf17d4}},	//   _संचा, ајте_, _faic_, _yigg_,
   {{0x2d8ca4f1,0x8b6700d0,0x291800e3,0x36d55559}},	//   lide_, _خاتم, agra_, соар,
   {{0x7afd0302,0x7bd80222,0x76b933ed,0x442100ca}},	// [bd10] mast, _huvu, улар_, wth_,
   {{0x7afd6957,0x7bd8a4f2,0x2d8ca4f3,0xe4e700d6}},	//   last, _kuvu, nide_, ріан,
   {{0x65ab02e2,0x95c80b9e,0x660da4f4,0x7ebf00c6}},	//   führ, рута_, srak, _išpū,
   {{0x7afda4f5,0x4421260b,0xa3b402ec,0x7bd82ac5}},	//   nast, rth_, обхі, _muvu,
   {{0x075600a1,0x7bd80084,0x2d8ca4f6,0xb6040f5f}},	//   _הסרט_, _luvu, kide_, _мярк,
   {{0x7afd8a81,0x463a0130,0x442100d7,0xdb1f014b}},	//   hast, _געשע, pth_, _piqû,
   {{0x333f0257,0x65ab01bf,0x6d41023e,0x2d8ca4f7}},	//   _taux_, bühr, vdla, dide_,
   {{0x7afd8c38,0x29180542,0x2d8c0371,0x67070296}},	//   jast, zgra_, eide_, षणिक_,
   {{0x7afda4f8,0x2d8ca4f9,0x68fca4fa,0x528500e3}},	//   dast, fide_, yard, _الذك,
   {{0x8d550c58,0x2d8c00ac,0x7bd8a4fb,0x30a72ff8}},	//   стич, gide_, _buvu, _крев,
   {{0xbb460084,0x6d41a4fc,0xcb6a2e57,0xdca52dc8}},	//   бенк, rdla, гане_, сани,
   {{0x7afd01ce,0xe45600c1,0x3d1c0378,0x316501bf}},	//   gast, צירט_, _माथे_, _holz_,
   {{0x2d8c02a7,0x139a00c1,0x68fc0d63,0x00000000}},	//   bide_, רברע, tard, --,
   {{0x2d8ca4fd,0x3f8da4fe,0xdbe30065,0x7afd00aa}},	//   cide_, lieu_, _déòt, aast,
   {{0x2b400049,0x4807060b,0x3d1c1101,0x2918003e}},	//   _taic_, йерн_, _माते_, rgra_,
   {{0xea5a0cb8,0x316501ad,0x68fca4ff,0x5fa700a4}},	//   _број_, _lolz_, sard, खविल,
   {{0x09e20081,0x7ae4a500,0x68fc3f43,0xe4d60076}},	// [bd20] _বিকা, _ifit, pard, متاب,
   {{0x3f8da501,0x68fc12b9,0x00000000,0x00000000}},	//   hieu_, qard, --, --,
   {{0xd8d70130,0xa5bb10d9,0x07a6333f,0x0fd6007f}},	//   _לויט_, _após, _ганн, _ढूंढ,
   {{0x798e0283,0xdce300b6,0x2d8ca502,0x7ae4009e}},	//   libw, _plně, zide_, _jfit,
   {{0x65ab01bf,0x7ae4a503,0x3f8da504,0x00000000}},	//   rühr, _mfit, dieu_, --,
   {{0x645800c2,0xa3d30442,0xdb06a505,0x3d1300c3}},	//   ävis, _हूक_, llkä, _दागे_,
   {{0x7afd8795,0x2d8ca506,0x7ae4020a,0xe57701b6}},	//   yast, vide_, _ofit, _узр_,
   {{0x2d8c2039,0x7bd80384,0x7ae4a507,0x38c3269b}},	//   wide_, _ruvu, _nfit, léré_,
   {{0x7afd7113,0x2d8c007a,0x511a0103,0x7bd8007b}},	//   vast, tide_, _مزاح_, _suvu,
   {{0x867b004f,0x7afd1566,0x716500e3,0x7ae4023f}},	//   טרפו, wast, _والك, _afit,
   {{0xdeef147c,0x2d8ca508,0xb09a004d,0x798e0172}},	//   _ны_, ride_, _стає_, dibw,
   {{0x2d8c26df,0x3f8d0428,0xcae302d5,0x005700ca}},	//   side_, cieu_, कुंड_, _לשבת_,
   {{0x2d8c7dff,0x256f026a,0x6da600ae,0xfe4600ae}},	//   pide_, _yılı_, _лида, _ындо,
   {{0x7bd8a509,0x7ae40653,0x7afda50a,0x3eb95867}},	//   _tuvu, _efit, sast, üste_,
   {{0xe814007d,0x38c300fd,0x7ae400f0,0x3cfe00c4}},	//   तूला_, déré_, _ffit, matv_,
   {{0x89d9001c,0x00000000,0x00000000,0x00000000}},	//   _پودر_, --, --, --,
   {{0x38c3020d,0x798e170c,0x07080981,0x00000000}},	// [bd30] féré_, bibw, صيلي_, --,
   {{0x67d5013f,0x7d1aa50b,0x38c3014b,0x798e05bd}},	//   _sąju, ngts, géré_, cibw,
   {{0xe4350979,0xa2cb22a0,0x36d567cb,0x00000000}},	//   تفاد, तेन्, _монр, --,
   {{0xdfc60037,0x8c1b0796,0x31650141,0x6e22039f}},	//   _زي_, רואי, _solz_, _oqob,
   {{0x27ed0106,0x38c3a50c,0x3f8d0428,0x31657ae6}},	//   ćenu_, béré_, vieu_, _polz_,
   {{0x3cfe0b14,0x00000000,0x00000000,0x00000000}},	//   jatv_, --, --, --,
   {{0x212c00f9,0xdb06045e,0xfaff0052,0x7f4200fe}},	//   _dbdh_, soké, nkës_, _baoq,
   {{0x798e0a15,0x00000000,0x00000000,0x00000000}},	//   zibw, --, --, --,
   {{0x63ab00e9,0x332d2df7,0x212c009c,0x9f910094}},	//   mogn, _ibex_, _fbdh_, _uší_,
   {{0x63aba50d,0x98ba00d9,0x61e9a50e,0x44310a39}},	//   logn, _lapā_, _itel, _kpz_,
   {{0x61e91386,0x55ac006e,0x443103a9,0x65670031}},	//   _htel, רייַ, _jpz_, _mojh,
   {{0x224d0154,0xcaca08c3,0x6d5c0212,0x65b00302}},	//   _krek_, игне_, örar, läht,
   {{0x798e0283,0x61e900bd,0x443101ff,0xa2dc06e4}},	//   tibw, _jtel, _lpz_, _फलस्,
   {{0x2eff6c27,0x65b0a50f,0x3cfe0036,0x61e9a510}},	//   lauf_, näht, catv_, _mtel,
   {{0x7ae403e5,0x798ea511,0x44310141,0x684302c6}},	//   _tfit, ribw, _npz_, vídá,
   {{0x6d43a512,0x6f1b0496,0x46ea0a51,0x61e9a513}},	//   _hana, nguc, рдан_, _otel,
   {{0x05665d18,0x61e9a514,0x63ab0036,0x6736003e}},	// [bd40] ован, _ntel, dogn, reyj,
   {{0x6d43a515,0xa5bb0cc8,0xfaff0052,0x65b0007b}},	//   _jana, _spór, skët_, jäht,
   {{0x224da516,0x2eff0364,0xe72a00ae,0x3d1c0096}},	//   _arek_, kauf_, _конд_, _मासे_,
   {{0x6d43a517,0xfe670c5e,0x224da518,0x232a67cb}},	//   _lana, _قد_, _brek_, роди_,
   {{0x224d01dc,0x38c3269b,0xc44833e7,0x20050141}},	//   _crek_, péré_, _گیان_, _avli_,
   {{0x6d43a519,0x7bcf0146,0x6604a51a,0x2d990328}},	//   _nana, íbuz, msik, ésel_,
   {{0x657e0080,0x61e90084,0x66049397,0x3cfe00c4}},	//   mhph, _etel, lsik, vatv_,
   {{0x6d430694,0x69c70ea3,0x644e3660,0x63aba51b}},	//   _aana, zmje, _irbi, cogn,
   {{0x6604949a,0x224d023b,0x6d43a51c,0x20050367}},	//   nsik, _grek_, _bana, _evli_,
   {{0xa2a3099d,0x657e0023,0x660413ce,0x10560018}},	//   _छुट्, nhph, isik, _وضاح,
   {{0x6d4303ce,0x0cde026e,0x00000000,0x00000000}},	//   _dana, _bẹrẹ_, --, --,
   {{0x9e66003f,0x6d431909,0x61e90120,0x3cfe020a}},	//   _واشن, _eana, _ytel, satv_,
   {{0x6d43a51d,0x4e961a37,0x628218ef,0x6f0001c2}},	//   _fana, _بشار, nzoo, mamc,
   {{0x6d43a51e,0x27350019,0x6f00a51f,0x644ea520}},	//   _gana, _ấn_, lamc, _orbi,
   {{0xf7730f43,0x69c700dd,0x9848013d,0x478b882a}},	//   وار_, rmje, оята_, асам_,
   {{0xa5bb0065,0x69c70fa3,0x6f00024a,0xfaff0216}},	//   _apóp, smje, namc, rkës_,
   {{0x6b8da521,0x6d4333ac,0x66042b72,0x63ab01df}},	// [bd50] _imag, _yana, gsik, vogn,
   {{0x6d43a522,0x09e20081,0x344b0fa5,0x66e10139}},	//   _xana, _বিচা, ичен_, _bákó,
   {{0x63ab5480,0x6fca02d5,0x917b00fe,0x6f00484a}},	//   togn, ागां, hệ_, kamc,
   {{0x224da523,0x883a00a1,0xb8660113,0x6f000357}},	//   _prek_, _פתרו, _راپو, jamc,
   {{0x644e7588,0x65b031e8,0x63aba524,0x41e406cf}},	//   _erbi, täht, rogn, وسوف,
   {{0x63ab013d,0xd24e00b1,0x224d0313,0x657ea525}},	//   sogn, انو_, _vrek_, chph,
   {{0x6d43a526,0x6b8d162f,0xddc900a5,0xf9940796}},	//   _rana, _omag, rzeż, ורס_,
   {{0x61e952b1,0x65b0007b,0x224d0158,0x6e3b0169}},	//   _ttel, säht, _trek_, twub,
   {{0x6d43a527,0x2eff02e2,0x61e9a528,0xe3b00192}},	//   _pana, rauf_, _utel, _شرف_,
   {{0x0d82489d,0x6b8d4593,0x2eff0332,0x6d434828}},	//   ельн, _amag, sauf_, _qana,
   {{0x6d4341cb,0x3d1c000f,0xc17200ca,0xff530037}},	//   _vana, _मारे_, _רחב_, _يخص_,
   {{0x6d43a529,0xeb9a4a54,0x65b001bf,0x660432ad}},	//   _wana, сим_, nähr, ysik,
   {{0x6d43a52a,0x34b80557,0xee2e1dc6,0x64480072}},	//   _tana, _अर्द, _ян_, _ádiv,
   {{0xdce31b30,0x6b8d47d1,0x6d430749,0xfe7900d2}},	//   _konč, _emag, _uana, ncům_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x660437e7,0xab6600d6,0x65b00364,0xe51e0ff9}},	//   tsik, _хвил, jähr, _पाहि_,
   {{0x644e1386,0xfbd30054,0xdce31d67,0xf99f2239}},	// [bd60] _srbi, _אתה_, _lonč, grès_,
   {{0x6b8d7a6d,0x7bd6a52b,0x628201fa,0x480a872f}},	//   _zmag, _hiyu, vzoo, _леон_,
   {{0x65b001bf,0x7bd6a52c,0xf8db00ca,0x764f03a8}},	//   fähr, _kiyu, _לחימ, _ercy,
   {{0x7bd603e3,0x6282029a,0xf99f0113,0x00000000}},	//   _jiyu, tzoo, brès_, --,
   {{0x7d01a52d,0x7bd63fbf,0x4b4d006e,0x7bc401b9}},	//   kals, _miyu, יגאַ, _mhiu,
   {{0x40341bb8,0x7d01a52e,0x7bd6a52f,0xdce305db}},	//   декс, jals, _liyu, _bonč,
   {{0x64a33b4c,0x644ea530,0x628201fa,0x7d01487c}},	//   _зара, _urbi, szoo, dals,
   {{0x5ea500c7,0x232708c3,0xdce3080e,0x7bd69c6c}},	//   খেছে, _носи_, _donč, _niyu,
   {{0x6f000d2a,0x80a60470,0x2cba00e7,0x46be00b6}},	//   ramc, _کمان, _špd_, ्धिह,
   {{0x6b8da531,0xc2431068,0x7bd60d2a,0xdce30f0e}},	//   _smag, _янук, _aiyu, _fonč,
   {{0x7bd698e3,0xe6b907ad,0x00000000,0x00000000}},	//   _biyu, _आर्ज, --, --,
   {{0x7bc4a532,0x7d01007a,0x7bd61a3a,0xdce80233}},	//   _chiu, aals, _ciyu, ğlıy,
   {{0x7d010029,0x2aab0e38,0x602a0092,0x7bd60c23}},	//   bals, стно_, _məmm, _diyu,
   {{0x5e570054,0xd90f037f,0x82770130,0x7c3703be}},	//   _מידע_, دید_, לעכע_, ñarí,
   {{0x2c820032,0x6d581173,0x68fe366c,0x7bc41909}},	//   _dédé_, _inva, _depd, _fhiu,
   {{0x6b8da533,0x7bd60124,0xf99f2740,0x7bc4a534}},	//   _umag, _giyu, très_, _ghiu,
   {{0x2c8200fc,0x00000000,0x00000000,0x00000000}},	// [bd70] _fédé_, --, --, --,
   {{0x65b001bf,0x261c009f,0x2c820139,0x7bd60027}},	//   währ, मढ़ी_, _gédé_, _ziyu,
   {{0x2903a535,0x6b9d3e9f,0x7bd6a536,0xf8c11f88}},	//   maja_, onsg, _yiyu, _एरिय,
   {{0xf99f536d,0x6b9d86ae,0x69dfa537,0xdce30234}},	//   près_, nnsg, _kuqe, _ronč,
   {{0x2d990068,0xdce302dd,0x61455222,0x21691087}},	//   ések_, _sonč, дела, жили_,
   {{0x7aff00b3,0x69d70090,0xdce37a80,0x764d76e6}},	//   _leqt, _jixe, _ponč, mvay,
   {{0x7d01a538,0x7ae60212,0x00000000,0x00000000}},	//   vals, yckt, --, --,
   {{0x2903a539,0x69d736a2,0x6d580c56,0xe7bf521f}},	//   haja_, _lixe, _anva, ्षिप,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2903a53a,0x7bc4a53b,0xdce36ca6,0x7bd614bf}},	//   jaja_, _shiu, _tonč, _siyu,
   {{0x7d010b81,0xd7bf009d,0xe7bf0096,0x7bd65a3f}},	//   rals, ्षाच, ्षाप, _piyu,
   {{0x6d584682,0x69d705fe,0x61fb0174,0x3e830113}},	//   _enva, _aixe, _kwul, _cèté_,
   {{0x69d708fc,0x7d01a53c,0x1d091a57,0xe51e01e4}},	//   _bixe, pals, _дели_, _पालि_,
   {{0x2903216d,0x69df0188,0xed5900d3,0x6e293ea1}},	//   gaja_, _duqe, _фок_, mteb,
   {{0x69d703be,0x66e606d5,0xb9064e2e,0xd6f50081}},	//   _dixe, доба, _फल_, _ছাড়া_,
   {{0x61fb1883,0x69c50103,0x635e00ae,0x69df00bd}},	//   _owul, _ehhe, _mănâ, _fuqe,
   {{0x6e29a53d,0x2903a53e,0x75464171,0xb8d5030b}},	// [bd80] nteb, baja_, мназ, _छु_,
   {{0x290303ce,0xf1e10cce,0xb3470090,0x00000000}},	//   caja_, _पढ़न, _leħħ, --,
   {{0x53e502ec,0x395a00e5,0x61fb2712,0x2007007e}},	//   еціа, _inps_, _awul, jsni_,
   {{0x6e29a53f,0xb347009e,0x00000000,0x00000000}},	//   kteb, _neħħ, --, --,
   {{0x6d48043a,0x91e3007b,0x00000000,0x00000000}},	//   ydda, воче, --, --,
   {{0xc6930130,0xc1a8009d,0x257602b6,0x26c20062}},	//   _יאר_, गवेग, _mælk_, _izko_,
   {{0x61fb9673,0x6e29a540,0x443e0383,0x6616084e}},	//   _ewul, eteb, _èt_, lryk,
   {{0x602a00a7,0x6e2913ea,0x00000000,0x00000000}},	//   _həmk, fteb, --, --,
   {{0x6e2904a7,0x6616a541,0x6d5801c8,0x00000000}},	//   gteb, nryk, _pnva, --,
   {{0x23660106,0x3eb801d3,0x64480072,0x98b1442c}},	//   ljoj_, ārt_, _ádis, neză_,
   {{0x29030660,0x6d4884a3,0x61e01842,0xe06a0037}},	//   vaja_, rdda, _huml, _بإذن_,
   {{0x236604a3,0x69d70090,0x61e0a542,0xb9230174}},	//   njoj_, _sixe, _kuml, barụ_,
   {{0x29030329,0x61e025fa,0x69d75ad8,0x6b9d0212}},	//   taja_, _juml, _pixe, rnsg,
   {{0x6616a543,0x6d580345,0x61e0a544,0x00000000}},	//   dryk, _unva, _muml, --,
   {{0x69d708a8,0x80d00081,0x5ba74057,0x2c74026e}},	//   _vixe, _স্ত্, _ориз, _dúdú_,
   {{0x316ca545,0x36d52dc8,0x00000000,0x00000000}},	//   _lodz_, еобр, --, --,
   {{0x672d5556,0x98bf0092,0x9c120134,0x69d70072}},	// [bd90] rfaj, ırıb_, _tọsd, _tixe,
   {{0x2d9e2b89,0x3324009c,0xd5bb04a1,0x201ca546}},	//   nnte_, _acmx_, іса_, kuvi_,
   {{0x2d9ea547,0x7995655f,0x6e297b2d,0x26c201ff}},	//   inte_, mizw, zteb, _ezko_,
   {{0x79951b24,0x2d9e0364,0x23660052,0x6616007f}},	//   lizw, hnte_, gjoj_, bryk,
   {{0x6fc50314,0x290100aa,0x61e0a548,0xc6a7125f}},	//   nóce, _keha_, _cuml, _црни,
   {{0x349561f5,0xc1050037,0x60250ff5,0x645a0206}},	//   _загр, روبي, едка, _štie,
   {{0x25a61b59,0xe05700cd,0x2fc601b5,0xdce301d3}},	//   éole_, بیات_, _bhog_, _nonā,
   {{0x2d9e5a9a,0x6e298a94,0x2fc601b9,0x29010167}},	//   ente_, tteb, _chog_, _leha_,
   {{0xee365577,0x799562a0,0x2fc601dc,0x64480072}},	//   ены_, kizw, _dhog_, _ádir,
   {{0x316c00a5,0xdb060146,0x29013137,0xdcfa00e8}},	//   _godz_, doká, _neha_, ditē,
   {{0x6e29a549,0x236d00e7,0x2b4901ee,0x00000000}},	//   steb, _koej_, _baac_, --,
   {{0x2b4900b3,0xdb066564,0xdb0f00ee,0x00000000}},	//   _caac_, foká, nocè, --,
   {{0x29015856,0x2b4901ee,0x00000000,0x00000000}},	//   _beha_, _daac_, --, --,
   {{0x7995a54a,0xdca564e9,0x2901a54b,0x551e30a8}},	//   gizw, _пали, _ceha_, _पाइए_,
   {{0x2b490036,0x0d1600ca,0x00000000,0x00000000}},	//   _faac_, _טקסט_, --, --,
   {{0x66161484,0x61330367,0xf74322ff,0x00000000}},	//   tryk, lılı, лесо, --,
   {{0xe61a4f03,0xdb0d0072,0x7dec00c1,0x79955e0a}},	// [bda0] яда_, _ghañ, ַקאַ, bizw,
   {{0x61330511,0x66162a28,0xfaff0052,0x61e0a54c}},	//   nılı, rryk, njën_, _ruml,
   {{0x61e0a54d,0x69cea3cd,0x00000000,0x00000000}},	//   _suml, mmbe, --, --,
   {{0x237f002d,0x25fb0378,0x201c0239,0x02060c79}},	//   _cluj_, _लौकी_, vuvi_, ездн,
   {{0x69cea54e,0x6133008b,0x2d9ea54f,0xcb13021e}},	//   ombe, kılı, ynte_, רלד_,
   {{0x602a01d4,0x00000000,0x00000000,0x00000000}},	//   _həmi, --, --, --,
   {{0xe5a30c58,0x69cea550,0x2d9e01df,0x613300a7}},	//   _сири, imbe, vnte_, dılı,
   {{0x2fc6023e,0x79950060,0x7bde00fd,0x201c0131}},	//   _qhog_, zizw, _épui, ruvi_,
   {{0x79951632,0x929d0034,0x2b49008c,0x656ea551}},	//   yizw, _pełe, _raac_, _kobh,
   {{0x44380096,0xdb06045e,0x2d9e0036,0x2b49008c}},	//   _kpr_, voká, unte_, _saac_,
   {{0x2cb83229,0x44380113,0x2d9e0364,0xbfa800ae}},	//   ærd_, _jpr_, rnte_, _оӂие_,
   {{0x1e861824,0x44380194,0x290100dc,0x656e1ab6}},	//   _плем, _mpr_, _seha_, _lobh,
   {{0xdb0f0a43,0x2901061d,0x79952bff,0x61330233}},	//   nocé, _peha_, tizw, bılı,
   {{0x613303a3,0x6f02a552,0x656e3c7a,0x00000000}},	//   cılı, _heoc, _nobh, --,
   {{0x79950549,0xd838004b,0xd8770286,0x25870032}},	//   rizw, нэт_, راسب, _lílù_,
   {{0x6d4a02ad,0x602a01d4,0x7995348a,0x656e0441}},	//   _hafa, _cəmi, sizw, _aobh,
   {{0x6d4a9532,0x29010006,0xc8f5013d,0x44387276}},	// [bdb0] _kafa, _teha_, _изпъ, _apr_,
   {{0x6d4aa553,0x4438005c,0x656e0a02,0x491b030b}},	//   _jafa, _bpr_, _cobh, _बाटो_,
   {{0x6d4a34cd,0x7646a554,0x656ea555,0x3cfb0142}},	//   _mafa, _esky, _dobh, פלאנ,
   {{0x613307d1,0x6d4aa556,0x4438a557,0x656e009c}},	//   zılı, _lafa, _dpr_, _eobh,
   {{0x613307aa,0x7aed05bd,0x656e0503,0xa2d400b6}},	//   yılı, _mfat, _fobh, _बृद्,
   {{0x6d4aa558,0x3d1c2183,0x613301d4,0x4438023f}},	//   _nafa, _मागे_, xılı, _fpr_,
   {{0x6f020076,0xccf802c6,0xa1560284,0x7aeda559}},	//   _beoc, dbě_, тају_, _ofat,
   {{0x645500bd,0x7aed0169,0x6f02033c,0x6d4a026d}},	//   _irzi, _nfat, _ceoc, _aafa,
   {{0x0ea902ec,0x6f02a55a,0x61331f8a,0x6d4aa55b}},	//   ький_, _deoc, tılı, _bafa,
   {{0x7aed0ea2,0x6d4aa55c,0x673f023b,0x645aa55d}},	//   _afat, _cafa, heqj, _átic,
   {{0x613307d1,0xdca523c3,0x6d4a4387,0x6f02009c}},	//   rılı, тани, _dafa, _feoc,
   {{0x6455005f,0x1eea0068,0x753e01e9,0x7ff40037}},	//   _mrzi, _قومی_, zepz, _إسلا,
   {{0x6d4aa55e,0x61330587,0x4a43008f,0xa6db01cd}},	//   _fafa, pılı, аняв, _faði,
   {{0x6d4aa55f,0x6455028d,0x602a00a7,0x6447084e}},	//   _gafa, _orzi, _səmi, _osji,
   {{0xbbe800e3,0x7aed00f0,0x2d8502c6,0x656e1ab6}},	//   _كريم_, _ffat, mhle_, _robh,
   {{0x6d4aa560,0x6d210251,0x7d03a561,0x44380169}},	//   _zafa, _माँग_, _hens, _rpr_,
   {{0x7d0302a4,0x64551114,0x44387bd3,0x6d4a08c2}},	// [bdc0] _kens, _arzi, _spr_, _yafa,
   {{0x645502e6,0x7d030709,0x2d85a562,0x2258033b}},	//   _brzi, _jens, nhle_, _črk_,
   {{0x7d03790e,0x602a01d4,0x00000000,0x00000000}},	//   _mens, _təmi, --, --,
   {{0x59bc000d,0x645502c8,0x66e600ae,0x443805db}},	//   ोगकर, _drzi, _шома, _vpr_,
   {{0x6d2105d4,0x6455a563,0x81cb0081,0x6b9d1e6c}},	//   _मांग_, _erzi, রআন_, érgi,
   {{0x2abd33c3,0x25fb00c3,0x7d03a564,0x09df0033}},	//   lábú_, _लौटी_, _nens, বীকা,
   {{0xccf802c6,0x7f4b0372,0x2bdd0442,0x66e609a1}},	//   vbě_, _bagq, _नंगा, _कलाक_,
   {{0x6724a565,0x6d4aa566,0x27fe0031,0xfaff0052}},	//   ngij, _safa, átny_, gjël_,
   {{0x7d03a567,0x63a2a568,0xa3c700aa,0x6d4a023b}},	//   _bens, mnon, _उठत_, _pafa,
   {{0x7aed002d,0x6d4a3b3b,0x44440188,0xe7e50034}},	//   _sfat, _qafa, ow_, कदमा_,
   {{0x351b00c1,0xfe6f110a,0x251b0089,0x63a2a569}},	//   ווינ, مدی_, וויא, onon,
   {{0x63a2a56a,0x6d4a5f1d,0x444400a4,0x76440193}},	//   nnon, _wafa, iw_, kwiy,
   {{0x6d4aa56b,0x7d0301bf,0x6d340077,0x2d8501ec}},	//   _tafa, _fens, _белф, bhle_,
   {{0xf2d307a6,0x7d03a56c,0x2d850363,0x6e20a56d}},	//   יער_, _gens, chle_, mumb,
   {{0x29cf00bd,0x63a2a56e,0x6e209117,0x6fc51ba6}},	//   _bżar_, knon, lumb, lóca,
   {{0x7d08a56f,0x7aeda570,0x444400f0,0x63a20113}},	//   lads, _ufat, dw_, jnon,
   {{0x6e20630c,0x4444a571,0x7bde0036,0x645500c4}},	// [bdd0] numb, ew_, _èpub, _srzi,
   {{0x7d08038b,0x27130019,0x645a0031,0x04f41b60}},	//   nads, ện_, _štia, изую,
   {{0x6e20628a,0x98ba00b6,0x83190103,0x44440172}},	//   humb, _mapě_, فقار_, gw_,
   {{0x6e209295,0x3d1c02e8,0x63a2a572,0x671d17ff}},	//   kumb, _माझे_, gnon, _फाटक_,
   {{0x6e20466b,0x471a00a1,0x602a00a7,0x768700ae}},	//   jumb, _אורג, _məmu, _рынж,
   {{0x644716cf,0x660da573,0x6e20a574,0xdca60037}},	//   _tsji, msak, dumb, _هى_,
   {{0x7d037b49,0x80ad0081,0x645500ae,0x660da575}},	//   _rens, য়েন্, _urzi, lsak,
   {{0x2f5402fd,0x6e203663,0x3ea02102,0x660d71c2}},	//   атьс, fumb, _žita_, osak,
   {{0x442126f7,0x6e2063c6,0x00000000,0x00000000}},	//   luh_, gumb, --, --,
   {{0x4d65276f,0xfd110076,0xbc19004b,0xa2d042d4}},	//   уков, حجة_, німі_, धधर्,
   {{0x442103b4,0x7d0301be,0xa3c7000f,0xeb9a0a7c}},	//   nuh_, _vens, _उठा_, еин_,
   {{0x7d03a576,0x660da577,0x4fa400d6,0x6e200b1a}},	//   _wens, ksak, _києв, bumb,
   {{0x2d8b025a,0x44212da3,0xed4e7ef2,0x7d08a578}},	//   èces_, huh_, _ло_, bads,
   {{0x44210484,0x660d8d82,0xfe9a006e,0x09e311cc}},	//   kuh_, dsak, _אינמ, сорн,
   {{0x6d41a579,0xa6db0102,0x4421005a,0xe73a5fa3}},	//   mela, _maðu, juh_, нев_,
   {{0x6d41a57a,0x44210484,0x8a9600bf,0x2eed8157}},	//   lela, duh_, _مشخص, ncef_,
   {{0x67240b38,0x660d8f03,0x6b84a57b,0xa7a72dfb}},	// [bde0] rgij, gsak, _ilig, укта_,
   {{0x85061482,0x76440027,0x00000000,0x00000000}},	//   اوان, rwiy, --, --,
   {{0x444426f1,0x44211bd6,0x290a5211,0x660d0da3}},	//   uw_, guh_, maba_, asak,
   {{0x290aa57c,0x6e208cf3,0x6d41a57d,0x44440d7b}},	//   laba_, yumb, hela, rw_,
   {{0x6d41a57e,0x63a2a57f,0x69de1ea4,0x6b84001c}},	//   kela, rnon, _kipe, _mlig,
   {{0x44211bd6,0x6b840472,0x6e20600a,0x63a28382}},	//   buh_, _llig, vumb, snon,
   {{0x6d41a580,0x4421005c,0x6e20019b,0x290aa581}},	//   dela, cuh_, wumb, iaba_,
   {{0xa85700a1,0x6f090072,0x1e14028d,0xf3ca001c}},	//   ריקה_, gaec, амия, _سبزه_,
   {{0x6d41a582,0x290a8b47,0x7d080973,0x25760b81}},	//   fela, kaba_, tads, _fælt_,
   {{0x6b84a583,0x01d752c6,0x26190251,0x6b9622d4}},	//   _alig, _موقع_, यूटी_, _amyg,
   {{0x290a5adb,0x6e2084a5,0x7d0820a8,0x660d6d15}},	//   daba_, sumb, rads, zsak,
   {{0x7d080284,0x660d2005,0x6e20a584,0x44ea0033}},	//   sads, ysak, pumb, গরিক_,
   {{0x6d414a02,0x6b8401b5,0x442100e7,0x7d08a585}},	//   bela, _dlig, zuh_, pads,
   {{0x2905054f,0x6b84a586,0x290aa587,0x69de02e6}},	//   úla_, _elig, gaba_, _cipe,
   {{0x69de0d17,0x4cd20081,0x97a72312,0x6b84863d}},	//   _dipe, _দ্রু, грал, _flig,
   {{0x4c130246,0x6b840218,0x602a00a7,0x69de0076}},	//   _ابوس, _glig, _həms, _eipe,
   {{0x442100cd,0x98a503a3,0xdb0f4280,0x461515af}},	// [bdf0] wuh_, ılı_, nocí, شوار,
   {{0x290a10d9,0x44210496,0x7afd02e2,0x628b033b}},	//   caba_, tuh_, lbst, vzgo,
   {{0x7bcd0197,0x660da588,0xf8b90789,0x44210167}},	//   _khau, ssak, _इडिय, uuh_,
   {{0x44210496,0x6d41a589,0x660da58a,0x69dea58b}},	//   ruh_, zela, psak, _zipe,
   {{0x442126f7,0x7bdf0472,0x6d410201,0x201c0036}},	//   suh_, _miqu, yela, ervi_,
   {{0x4421a58c,0x6d410f61,0x6edb00d9,0x7bdf188c}},	//   puh_, xela, _jābū, _liqu,
   {{0xddcb013f,0x98b800ae,0x00000000,0x00000000}},	//   žiūr, meră_, --, --,
   {{0xee390318,0x290aa58d,0x7bdfa58e,0x68fc0995}},	//   вни_, zaba_, _niqu, zbrd,
   {{0x6d415102,0x63bba58f,0x52380241,0x201c028d}},	//   tela, _ikun, _مسلح_, arvi_,
   {{0x290aa590,0x6b96a591,0x6b848ca6,0x7afd042c}},	//   xaba_, _smyg, _slig, ebst,
   {{0x30a70747,0x69dea592,0x63a902ec,0x7bdf0161}},	//   _срав, _ripe, _kjen, _biqu,
   {{0x7bcd04ea,0xeb9aa593,0x6d41a594,0x63bb03e5}},	//   _chau, тим_, sela, _jkun,
   {{0x63a9a595,0x7bcda596,0x7bdf0328,0x63bb0a4b}},	//   _mjen, _dhau, _diqu, _mkun,
   {{0x63bb0124,0x7bdf0042,0x63a90357,0xb60700bd}},	//   _lkun, _eiqu, _ljen, _miġġ,
   {{0x63bba597,0x7bdfa598,0x9c130174,0x98b800ae}},	//   _okun, _fiqu, _kọmu, deră_,
   {{0x63a9a599,0x290a0a2a,0x63bba59a,0x59b4030b}},	//   _njen, saba_, _nkun, ंकहर,
   {{0x7ae4092f,0xaa460978,0x290aa59b,0x69dea59c}},	// [be00] _igit, _тепл, paba_, _tipe,
   {{0x63a94ca5,0x929d00a5,0x63bb0584,0x7bdf4466}},	//   _ajen, _pełn, _akun, _épur,
   {{0x799c21e9,0x99860470,0x00000000,0x00000000}},	//   mirw, _ملکو, --, --,
   {{0x63a90268,0x7bdf05fe,0x799c0283,0x5c36006e}},	//   _cjen, _xiqu, lirw, ירען_,
   {{0x42540037,0x98b800ae,0x7ae40113,0x996200e8}},	//   إنتر, beră_, _mgit, _mūžu_,
   {{0x63a901c5,0x799c3834,0x63bb6d19,0xf1aa0037}},	//   _ejen, nirw, _ekun, خاصه_,
   {{0x64a30138,0x50660077,0x63a902b6,0x161e02d5}},	//   _дара, ртла, _fjen, यंकर_,
   {{0x63a96abe,0x7ae4a59d,0x799c0193,0x394301d3}},	//   _gjen, _ngit, hirw, zejs_,
   {{0x7bcd01fa,0x799c01e2,0x9f450032,0x00000000}},	//   _rhau, kirw, _mulè_, --,
   {{0x7bdf2f87,0x7bcda59e,0x201c0a13,0x63a90357}},	//   _siqu, _shau, prvi_, _zjen,
   {{0xdeef29c2,0xfe180693,0x40960f8d,0x7bcd006c}},	//   _мы_, _दिवस_, _трат, _phau,
   {{0x7bcd01fa,0x63a9003d,0x81cb0033,0x00000000}},	//   _qhau, _xjen, _রূপ_, --,
   {{0xc33300a1,0x7bdf0472,0x798501fa,0x602a0092}},	//   חור_, _viqu, _plhw, _təms,
   {{0x7ae403f3,0x799c01e2,0x7bdf00b3,0xcbe600ae}},	//   _egit, girw, _wiqu, _кции,
   {{0x7bcd0d7d,0x7bdf8825,0x37070f0c,0x3f86a59f}},	//   _thau, _tiqu, ичав, _klou_,
   {{0x386d2c0a,0xb8cf00c3,0x7bcd0131,0x00000000}},	//   ćer_, _कश_, _uhau, --,
   {{0x6b8703ed,0xfaff023b,0x799c21e9,0x85150120}},	// [be10] _مشکل, mbë_, birw, ймає,
   {{0x63a90995,0x6b9d02c9,0x398d0065,0x799c05bd}},	//   _sjen, lisg, _dósù_, cirw,
   {{0xaab812eb,0x63a908c5,0x04671f65,0x48ab00d3}},	//   _مدیر_, _pjen, штам, _штим_,
   {{0x6b9da5a0,0x98b800ae,0xdce300c4,0x6cd9006e}},	//   nisg, seră_, _tonć, אַנצ,
   {{0x63a95a21,0x4ec10081,0x98b800ae,0x926b008f}},	//   _vjen, _উল্ল, peră_, ържа_,
   {{0x3f8600b3,0x6b9d019c,0x61454c82,0x0cde0af0}},	//   _alou_, hisg, сека, _gẹgẹ_,
   {{0x63a91a08,0x3f86057a,0x998905db,0x1b1f0033}},	//   _tjen, _blou_, _opaž_, য্যে_,
   {{0x63bb1f6e,0x63a976d3,0x3f86a5a1,0x1f65194c}},	//   _ukun, _ujen, _clou_, ским,
   {{0x799c0193,0x332d0143,0x98b86392,0x6b9d5926}},	//   yirw, _icex_, merą_, disg,
   {{0x51740080,0x417418a9,0xa3cb17ff,0x7ae40013}},	//   _والأ, _والس, _रीत_, _sgit,
   {{0x3b0a24e9,0x61e9a5a2,0xe7c70557,0x4433496c}},	//   лено_, _huel, लताप, ntx_,
   {{0x61e90010,0x80d00081,0x3fc900cd,0x63b9a5a3}},	//   _kuel, _স্ক্, _صدای_, nown,
   {{0xeb971a14,0x61e1a5a4,0x799c0198,0xa2cb0096}},	//   сия_, _kill, tirw, तेच्,
   {{0x645a0f39,0x61e1a5a5,0x61e9a5a6,0x60c100c2}},	//   _štim, _jill, _muel, _kylm,
   {{0x63b90d1b,0xdca22249,0x61e10fda,0x7dc60102}},	//   kown, _наши, _mill, iðsl,
   {{0x61e11842,0x799c1e59,0x9f4503a9,0x7ae40079}},	//   _lill, sirw, _bulé_, _ugit,
   {{0x63b9a5a7,0x06ca01b6,0x9f456165,0x61e90634}},	// [be20] down, угай_, _culé_, _nuel,
   {{0xd910037f,0xd46a19ff,0xab5b0345,0x00000000}},	//   _زیر_, лизе_, nlün, --,
   {{0x224d0154,0xdce10138,0x74130037,0xdb0fa5a8}},	//   _asek_, rklė, كولا, locá,
   {{0x61e1a5a9,0x61e901e9,0x2ab50174,0x00000000}},	//   _aill, _buel, ụbe_, --,
   {{0x61e1a5aa,0x61e90a43,0x20050090,0xd9fa0bf5}},	//   _bill, _cuel, _awli_, ्ठित_,
   {{0x61e903f3,0x61e1a5ab,0x3c310146,0x2005030a}},	//   _duel, _cill, káv_, _bwli_,
   {{0x61e1a5ac,0x01330080,0x44333b03,0xdfd0012b}},	//   _dill, سعود, ctx_, ويت_,
   {{0x63b900a5,0x644e008a,0x645c3763,0x2005030a}},	//   cown, _isbi, _irri, _dwli_,
   {{0x61e1a5ad,0x00000000,0x00000000,0x00000000}},	//   _fill, --, --, --,
   {{0x61e1a5ae,0x61ef0257,0x644e00e7,0xf99f06a3}},	//   _gill, _écla, _ksbi, nsèt_,
   {{0xb5fb0b0b,0x61e90a00,0xe0850037,0xdb0f00b3}},	//   _gráf, _zuel, _وجمي, tocà,
   {{0x60db00c1,0x61e901c2,0x255f00e8,0x61e1a5af}},	//   _עקאנ, _yuel, _zālē_, _zill,
   {{0x61e1047e,0x6b9d0441,0xfaff0052,0x753c007f}},	//   _yill, risg, rbë_, _obrz,
   {{0x645c02a7,0x61e1008a,0xe81d0789,0x644e0b14}},	//   _orri, _xill, _फिदा_, _osbi,
   {{0x65750871,0x644e02ef,0xfd650174,0x2d8c1ac3}},	//   _rozh, _nsbi, hetụ, mhde_,
   {{0x2d9ea5b0,0x27e203e3,0x7d0a003e,0x0a6b085f}},	//   lite_, _cikn_, _hefs, _брои_,
   {{0x645ca5b1,0x55750a3a,0xdb0f0072,0x2d9e1ac3}},	// [be30] _arri, огат, cocá, oite_,
   {{0x994d0138,0xdb1d0076,0x61e91022,0xe4cb001c}},	//   ržų_, ilsí, _ruel, هبان_,
   {{0x61e914e2,0x58d50497,0x63b93df5,0x00000000}},	//   _suel, _фонт, town, --,
   {{0x61e13c19,0x2d9ea5b2,0x44330090,0xfbc9034d}},	//   _sill, hite_, rtx_, रतिम,
   {{0x2d9e08a1,0x61e9188c,0x645c156a,0x63b900a5}},	//   kite_, _quel, _erri, rown,
   {{0x61e96117,0x61e13d42,0x2d9e011d,0x644e00e7}},	//   _vuel, _qill, jite_, _fsbi,
   {{0x395300ec,0x7dc601ab,0x947500cd,0x645802c3}},	//   _maxs_, rðsl, _بگذا, åvit,
   {{0x53342240,0x61e1510b,0x224d0eac,0x61e91c24}},	//   _нест, _will, _tsek_, _tuel,
   {{0x61e1a5b3,0x2d9e092f,0xb5fb0103,0x2d870220}},	//   _till, fite_, _drág, _plne_,
   {{0x2d9e00c9,0x161e000f,0xb5fb0b0b,0x61e1a5b4}},	//   gite_, यूटर_, _tráf, _uill,
   {{0x5baa074b,0xb5fba5b5,0x2ef50d72,0x7f1900d1}},	//   иком_, _frág, _дзер, _نياز_,
   {{0x3c31025b,0xb5fb0146,0x2c5700ae,0x0cde0032}},	//   ráv_, _krád, _văd_, _bẹbẹ_,
   {{0x2d9ea5b6,0xab5b0e63,0x34c60176,0x7c24009c}},	//   bite_, mlül, _वर्द, _āire,
   {{0x80d00081,0x3f8d0161,0xdb0f0328,0x2d8c009c}},	//   _স্ট্, lheu_, rocá, chde_,
   {{0x765d00dd,0x00000000,0x00000000,0x00000000}},	//   _arsy, --, --, --,
   {{0xfbc3008f,0xfaa6227c,0x00000000,0x00000000}},	//   _общо, _майо, --, --,
   {{0xb6a623a3,0x6f0b0103,0xf50a10a6,0xd62a5574}},	// [be40] циал, _megc, инал_, розе_,
   {{0x644e02ef,0x26c20138,0x7bc6a5b7,0xdd2500c6}},	//   _psbi, _vyko_, llku, _lūži,
   {{0x66e61ad5,0x2db600c1,0xe73a0aa8,0x00000000}},	//   _мона, קלען_, _кен_, --,
   {{0x89360018,0xd62a0291,0xdce100e8,0x6f0b0372}},	//   _اٹھا, _коме_, eklī, _negc,
   {{0xdce302c6,0x3f8d0052,0xbb3b006e,0x3636001c}},	//   _poně, dheu_, שעני, _برجس,
   {{0x753c00e9,0xd01a3f1d,0x201a016d,0x645c0027}},	//   _ubrz, афи_, ápio_, _trri,
   {{0xcc240081,0x645c0a00,0x2d9ea5b8,0x7d0a354e}},	//   _বন্ধ_, _urri, vite_, _refs,
   {{0x2d9ea5b9,0xfc460363,0x93fb028c,0xfaff0052}},	//   wite_, šíku_, _כללי, njët_,
   {{0xe29a00c9,0x21a64367,0xdcfa00b6,0x7d18034f}},	//   _таа_, _диам, chtě, _pdvs,
   {{0x660901e8,0x7bc618f0,0x00000000,0x00000000}},	//   _çeke, elku, --, --,
   {{0x7d0a0088,0x80a6001c,0x60cd03e3,0xb5fb00d2}},	//   _vefs, _بمان, ƙama, _zrád,
   {{0x3f8da5ba,0x291a0027,0xb5fb01cd,0x00000000}},	//   cheu_, _adpa_, _hráe, --,
   {{0x7fd70132,0x7d0a4305,0xe8e30966,0x39530072}},	//   _וואס_, _tefs, पश्च, _paxs_,
   {{0x27fa005c,0x15f102d5,0x6fea007f,0x28b61203}},	//   _btpn_, _अंबर_, _pęch, _आँखि,
   {{0x6d487a1a,0x67d51aad,0x7af603a8,0x00000000}},	//   meda, зову, _ffyt, --,
   {{0x4917033a,0x7c280194,0x44210579,0x765d0124}},	//   _भएको_, mudr, vrh_, _prsy,
   {{0x3f8400a4,0xd6db1aad,0x41ca277c,0xf1ca00ec}},	// [be50] ikmu_, ртв_, ितास, ितान,
   {{0x6d48a5bb,0x4421a5bc,0x45d4510e,0x00000000}},	//   neda, trh_, доус, --,
   {{0x29111596,0x2903a5bd,0xd5b8224a,0xab5b7f09}},	//   maza_, mbja_, ісу_, hlüm,
   {{0x29117d87,0x69c7a5be,0x6d48007a,0xb5fb0579}},	//   laza_, llje, heda, _prád,
   {{0x6d48a5bf,0x291a0063,0x7dc60653,0x0204013f}},	//   keda, _ydpa_, rðsj, дзін,
   {{0x6d4803ce,0x88df00c7,0x29117255,0x764da5c0}},	//   jeda, _ব্যক, naza_, mway,
   {{0x764d0201,0x6d48a5c1,0x60100308,0xfaff023b}},	//   lway, deda, _rómá, njës_,
   {{0x2911a5c2,0xb5fb00e3,0x623561a4,0x69c700e7}},	//   haza_, _trád, _небу, hlje,
   {{0x2911a5c3,0x764d5d6f,0x60b50018,0x00000000}},	//   kaza_, nway, _کمائ, --,
   {{0x61fb4b10,0x69c703c6,0x2911a5c4,0x764d01c2}},	//   _itul, jlje, jaza_, iway,
   {{0x29110d2a,0x69c70357,0x63ab0988,0x7c280144}},	//   daza_, dlje, ongn, gudr,
   {{0x291100d3,0x09b402d5,0x764d8ba8,0x09b6274c}},	//   eaza_, ंक्य, kway, ृत्य,
   {{0xed590636,0x69c700e7,0x2911a5c5,0x63ab03dc}},	//   _гол_, flje, faza_, ingn,
   {{0x29112161,0x6e290033,0x6d4855a7,0x290c17eb}},	//   gaza_, mueb, ceda, úda_,
   {{0xfaff0052,0x7c284726,0x00000000,0x00000000}},	//   gjës_, cudr, --, --,
   {{0x61fb3165,0xe81d09c3,0xa3cb009f,0x2ab50129}},	//   _otul, _फिरा_, _रील_, ụba_,
   {{0x69c719d0,0x6fc50396,0x291118b1,0x2903436a}},	// [be60] blje, góci, baza_, bbja_,
   {{0x2a60a5c6,0xe6170c10,0x69c700e7,0x63ab0085}},	//   _irib_, яду_, clje, engn,
   {{0x98160678,0x61fb3eb7,0xc8c00789,0x2a601f54}},	//   _عبدا, _atul, _एडिट, _hrib_,
   {{0x225f00f3,0x764d0517,0x6d48007f,0x48f600b6}},	//   _bruk_, bway, zeda, ्रको_,
   {{0x11542917,0x6d48a5c7,0x6fc53536,0x7d1c9e0a}},	//   дклю, yeda, cóci, órsk,
   {{0x225f0934,0xb5fb0088,0x63aba5c8,0x7dc6003e}},	//   _druk_, _fráb, angn, rðsk,
   {{0x6d48a5c9,0x61fb52f2,0x044361a9,0x395801d3}},	//   veda, _etul, _перн, idrs_,
   {{0x291102a4,0x7c28a5ca,0x6d48a5cb,0x645b0034}},	//   zaza_, vudr, weda, śció,
   {{0x6d48a5cc,0xb5fb0143,0x661600f3,0x29110366}},	//   teda, _tráe, nsyk, yaza_,
   {{0x63a2a5cd,0x6d480313,0xb5fb0094,0xb81d00c3}},	//   lion, ueda, _hrác, _फिलम_,
   {{0xfe6f1e49,0xdb06025b,0xab5b026a,0x2911039f}},	//   ندی_, soký, slüm, vaza_,
   {{0x63a2a5ce,0x291163c1,0x764da5cf,0x799e0154}},	//   nion, waza_, yway, _ampw,
   {{0x6d48a5d0,0x62829f11,0x764d1ffb,0x291134f0}},	//   peda, nyoo, xway, taza_,
   {{0x63a2a5d1,0x2a600154,0x2d85a5d2,0x00000000}},	//   hion, _drib_, ckle_, --,
   {{0x2911a5d3,0x63a2a5d4,0xb5fb10d9,0x2903a5d5}},	//   raza_, kion, _orác, rbja_,
   {{0x69c720e4,0x15f105d4,0x764da5d6,0xf773046b}},	//   slje, _अंदर_, tway, راز_,
   {{0x63a20085,0x2911a5d7,0x672d006d,0x6b8d5a57}},	// [be70] dion, paza_, rgaj, _ilag,
   {{0x26c701d3,0x6fc50034,0xb5fb0143,0x764d26df}},	//   āno_, róci, _arác, rway,
   {{0x6b8d01be,0x80c20081,0x61fba5d8,0x63a2a5d9}},	//   _klag, ষেত্, _stul, fion,
   {{0xf65f052f,0x4905030b,0xf8b20327,0xb5fb0e4b}},	//   _træ_, वरको_, _ישי_, _vráb,
   {{0x2d850034,0xb5fb037a,0x00000000,0x00000000}},	//   ykle_, _drác, --, --,
   {{0x6b8d0428,0xab5b0233,0x90c52503,0x00000000}},	//   _llag, rmüy, мбле, --,
   {{0x63a200a5,0x645a1197,0x6b8da5da,0x62826e7b}},	//   bion, _štiv, _olag, ayoo,
   {{0x225fa5db,0x6b8d0134,0x7e640995,0xaca30134}},	//   _truk_, _nlag, _šipa, naụl,
   {{0xe3b00177,0x61fb0051,0x00000000,0x00000000}},	//   _صرف_, _utul, --, --,
   {{0x6b8da5dc,0x6e290890,0xac850265,0x4c852458}},	//   _alag, rueb, дгол, длов,
   {{0x1b4a078b,0x00000000,0x00000000,0x00000000}},	//   озни_, --, --, --,
   {{0xfaa601b6,0x6b8d009c,0x15ed02d5,0xa2d402d5}},	//   дамо, _clag, जदार_, बेक्,
   {{0x6e2902cd,0x2a60003d,0x00000000,0x00000000}},	//   queb, _qrib_, --, --,
   {{0x63a2a5dd,0x57b6009d,0xa3d41b11,0x6b8da5de}},	//   zion, ंव्ह, _सीन_, _elag,
   {{0x6b8da5df,0x394a680b,0x00000000,0x00000000}},	//   _flag, rebs_, --, --,
   {{0x63a226e0,0x2905003e,0x2a60a5e0,0x2b4000b3}},	//   xion, ðlar_, _trib_, _ubic_,
   {{0x2a600113,0x7bc4024a,0xe61a00c2,0xab5b026a}},	// [be80] _urib_, _ikiu, юда_, zlük,
   {{0x63a200a5,0x62820051,0x6616056b,0x6b8d0117}},	//   wion, vyoo, rsyk, _zlag,
   {{0x63a205d0,0xb5fb0146,0x66164562,0x7bc40172}},	//   tion, _prác, ssyk, _kkiu,
   {{0x27f718ed,0x42ca0b21,0xab5b013c,0xe2ca1c47}},	//   žené_, оген_, vlük, олед_,
   {{0xd0410092,0xb5fb00b6,0x6fc5016d,0x81c90033}},	//   _izlə, _vrác, nócu, োদন_,
   {{0x14b70096,0x628283ce,0x00000000,0x00000000}},	//   _अडचण, ryoo, --, --,
   {{0x03a612d3,0xb5fba5e1,0x63a200a5,0x7bc4010a}},	//   _живо, _trác, pion, _okiu,
   {{0xab5b0233,0x226902c6,0x00000000,0x00000000}},	//   rlük, átký_, --, --,
   {{0x03a300d3,0x7ae90542,0x91a60174,0x6b8d009c}},	//   _рито, žetk, gwọ_, _rlag,
   {{0x6b8d3de7,0xe1660190,0x7bc40239,0xe1230058}},	//   _slag, _تدري, _akiu, _амфи,
   {{0x6b8d78d3,0xe046004d,0x30860781,0x69dc05db}},	//   _plag, _інди, _تلاف, dmre,
   {{0x0a6b10b8,0xa3c01e93,0x7646084e,0x2a660141}},	//   орги_, ुति_, _opky, _šoba_,
   {{0xfe7202fc,0x61e80d1f,0xed5a12e7,0x6b8da5e2}},	//   _جدا_, _kidl, _мод_, _vlag,
   {{0x7dcf038c,0x7bc4010a,0x657c45d5,0x7e620139}},	//   løsn, _ekiu, _norh, _irop,
   {{0x61e8a06e,0xdc3e00e8,0x6b8d2d0b,0x63a000bd}},	//   _midl, rģēt, _tlag, _ommn,
   {{0x7e620b97,0x6d58a5e3,0x6b8d02e6,0x6d5a04f6}},	//   _krop, _hava, _ulag, ldta,
   {{0x6d58a5e4,0x4ad3007d,0x7aeda5e5,0x7bdd02c3}},	// [be90] _kava, _सरिव, _igat, mmsu,
   {{0xca4800cd,0x6d5aa5e6,0x36d400d3,0x7e620350}},	//   _کلیه_, ndta, тоур, _mrop,
   {{0x6d580051,0x3c380103,0x69c5019f,0x00000000}},	//   _mava, név_, _ikhe, --,
   {{0x61e8009c,0xc7970103,0x00000000,0x00000000}},	//   _aidl, _کھڑا_, --, --,
   {{0x657c0170,0x645a02e6,0x61e8003d,0x7aed01af}},	//   _forh, _štit, _bidl, _mgat,
   {{0x6d585de7,0x20554cc3,0xdb1d0212,0x7f42015e}},	//   _nava, етир, llsä, _aboq,
   {{0x61e80f20,0x7e620af0,0x7aed0bf6,0x69c50113}},	//   _didl, _arop, _ogat, _mkhe,
   {{0x7aeda5e7,0xa4d402ec,0x9980007f,0x6d583846}},	//   _ngat, _росі, _zwiń_, _aava,
   {{0x6d58a5e8,0xe4e32373,0x61e8a5e9,0x0ea91aad}},	//   _bava, _कृति_, _fidl, який_,
   {{0x6d58a5ea,0x7aeda5eb,0x777d022e,0xc8fb02d5}},	//   _cava, _agat, _losx, ्रोम_,
   {{0x6d58a5ec,0x00000000,0x00000000,0x00000000}},	//   _dava, --, --, --,
   {{0x69c5519a,0x2d8e22da,0x644702a1,0x00000000}},	//   _akhe, _elfe_, _mpji, --,
   {{0xbe872761,0x6d58028d,0x7e62a5ed,0x7c3a0036}},	//   _تجاو, _fava, _grop, attr,
   {{0x6d58a5ee,0x7aeda5ef,0x0cde0139,0x602a013c}},	//   _gava, _egat, _kẹlẹ_, _rəmz,
   {{0x18673dba,0x6e3b1d0c,0xf7461b60,0x6d430090}},	//   нари_, ltub, нево, _ibna,
   {{0x6d58138d,0x9f46008f,0x7bc40051,0x69c5958a}},	//   _zava, _cioè_, _ukiu, _ekhe,
   {{0xcf9200c1,0x6e3b67b2,0x6d5854f8,0x3ea0003e}},	// [bea0] אטן_, ntub, _yava, _þitt_,
   {{0x09060d9b,0x6d5825b0,0xd91000d1,0x00000000}},	//   _япон, _xava, _خیس_, --,
   {{0x03260208,0x657c02e2,0x399b00c1,0x3f8f8ab6}},	//   еден, _vorh, _זייד, _olgu_,
   {{0xb5fb0018,0x61e8a5f0,0x6e3b085c,0x9f4910fe}},	//   _irán, _sidl, ktub, _òkès_,
   {{0x71a602e3,0x657ca5f1,0x0cac0861,0xa1582101}},	//   надз, _torh, _चश्म, далу_,
   {{0x64a6067f,0x7e6402ef,0x3f8fa5f2,0xdb1da5f3}},	//   _зага, _šipo, _algu_, rosé,
   {{0xb0da0f35,0x395a00ca,0xdce300e8,0x00000000}},	//   येंग, _maps_, _monē, --,
   {{0xdb1d025a,0x395a007a,0x6d583f43,0x63a000f9}},	//   posé, _laps_, _sava, _ummn,
   {{0x6d58a5f4,0x61e805a3,0x6e3b02c9,0x29060023}},	//   _pava, _tidl, gtub, _đoan_,
   {{0x40964bac,0x721b040a,0x6d581a4a,0x7aed0441}},	//   _прет, _מומח, _qava, _sgat,
   {{0x6fc546b4,0x6e3ba5f5,0x6d584b2a,0x00000000}},	//   tóct, atub, _vava, --,
   {{0x6d58a5f6,0x60c4026a,0x317e0634,0xd5be007f}},	//   _wava, ğimd, _hotz_, ्तुओ,
   {{0x6d5819d1,0x7e622939,0x2fc601af,0xb5fb06f0}},	//   _tava, _urop, _ikog_, _arán,
   {{0xf2d307a6,0xa02402e2,0xdee30012,0xb5fb0244}},	//   טער_, _größ, _сочи, _brán,
   {{0xda1d04a9,0x8d5b00a1,0x6fc50610,0xb5fb5bef}},	//   _भटकत_, _זכוי, mócr, _crán,
   {{0x0aeb0cd2,0x7aeda5f7,0x317e036d,0x36d517ab}},	//   _عربي_, _ugat, _lotz_, вобр,
   {{0x66040a69,0x9f46028d,0x8aa4022a,0xdcf813be}},	// [beb0] gpik, _cioé_, _брэд, _lovč,
   {{0xb5fba5f8,0x64550103,0x69c5019f,0x7c280f6f}},	//   _frán, _pszi, _ukhe, ordr,
   {{0x26e200c7,0xdcf802e6,0x645a02dd,0xb5fba5f9}},	//   গুলো_, _novč, _štir, _grán,
   {{0xae210490,0x00000000,0x00000000,0x00000000}},	//   _मिलन_, --, --, --,
   {{0xe1f80565,0x6e3b2379,0xdb088d62,0x2bb601d3}},	//   егі_, xtub, élék, nāca_,
   {{0x61455861,0x25a50088,0x00000000,0x00000000}},	//   тека, _öll_, --, --,
   {{0x29135a60,0x94d424ec,0x1fb515a7,0xf77f0233}},	//   _mexa_, _борц, ксир, _koç_,
   {{0xfe450396,0x6d8d037a,0x883c00ca,0x20e50d2a}},	//   внио, _cúan, פתחו, rɓi_,
   {{0x236d0031,0xdb0f0052,0x7c280b8e,0x00000000}},	//   _inej_, ancë, erdr, --,
   {{0x6e3ba5fa,0x29130167,0x39940364,0x2a6605db}},	//   rtub, _nexa_, _käse_, _šobo_,
   {{0x6e3ba5fb,0x66040634,0xdcf80154,0x317a006e}},	//   stub, zpik, _govč, _קרעמ,
   {{0x395aa5fc,0x661d0357,0x6ff101d3,0xdb060052}},	//   _saps_, _ovsk, _nāci, mikë,
   {{0xeb9707f4,0xed4ea5fd,0x2d9900fd,0x6f09024a}},	//   тия_, _ко_, èses_, mbec,
   {{0x2fcd44ff,0x7d1ca5fe,0x41c100c3,0x6e290113}},	//   lleg_, órst, शकिस, mreb,
   {{0x6f09025b,0x661d0160,0xdb060052,0xa3c12337}},	//   obec, _avsk, nikë, ँवा_,
   {{0x2fcda5ff,0x810d2231,0xeafa0470,0x6f0913c5}},	//   nleg_, हरुख_, _غربت_, nbec,
   {{0xb8c9149b,0x6609173c,0x00000000,0x00000000}},	// [bec0] _खे_, _çekl, --, --,
   {{0x66040096,0xb5fb0019,0x6d41a600,0x62990034}},	//   rpik, _trán, nfla, dzwo,
   {{0x6604a601,0x74130190,0x6e29a602,0xb5fb321f}},	//   spik, لولا, hreb, _hrál,
   {{0x69cea603,0xb5fb030b,0xdcf80a39,0x6604007b}},	//   llbe, _král, _rovč, ppik,
   {{0x27e0a604,0x2fcd00f3,0x29182a9a,0x6d4101ce}},	//   mmin_, dleg_, oara_, kfla,
   {{0x2918a605,0xf50300c2,0x2fc62452,0x4a9b006e}},	//   nara_, _взро, _skog_, וינג,
   {{0x656e0049,0xe5a328f1,0xa2ce0251,0x6e294f43}},	//   _inbh, _тири, _तरक्, ereb,
   {{0x27e01013,0x2fcd00f3,0x69ce3341,0xb5fb1f20}},	//   nmin_, gleg_, hlbe, _orál,
   {{0x291893ac,0x6e290f39,0x6d41a606,0x27e000ce}},	//   kara_, greb, ffla, imin_,
   {{0x2918a607,0x27e0a608,0x6d41177e,0x2bb60a84}},	//   jara_, hmin_, gfla, vāca_,
   {{0x27e01a27,0x6f0993ea,0x29130072,0x6fc50143}},	//   kmin_, bbec, _rexa_, rócr,
   {{0x29130933,0x6e2905b4,0x27e0a609,0x69ce0d87}},	//   _sexa_, breb, jmin_, elbe,
   {{0x27e0a60a,0x2918a60b,0x6fc52ad4,0x6e29002b}},	//   dmin_, fara_, pócr, creb,
   {{0x2918a60c,0x7dc6003e,0x6ff100e8,0x00000000}},	//   gara_, rðss, _sāci, --,
   {{0x28f814fa,0x291303be,0xc3130033,0xdb1d1de1}},	//   тесь_, _vexa_, _হাসি_, losí,
   {{0xe4e31827,0xb5fb04c8,0x3c770266,0x656e0503}},	//   _कृषि_, _frál, _יתום_, _anbh,
   {{0x2918a60d,0x645a0631,0x6ff100d9,0xdb1d1ed4}},	// [bed0] bara_, _štip, _vāci, nosí,
   {{0x29182a2b,0x6609026a,0x27e0209e,0x99555cac}},	//   cara_, _çekm, amin_, _скоц,
   {{0x80a202e8,0x6ec9000d,0x95c80152,0x60cd0022}},	//   _केले, _हुनु, тута_, ƙami,
   {{0x9f810088,0x2bc9007f,0x27eb3d56,0x92392348}},	//   jóð_, रतटा, _uicn_, ечку_,
   {{0x1308004d,0x6d410178,0x201e0117,0x2fcd004d}},	//   тній_, yfla, _avti_, vleg_,
   {{0x6e2918ec,0xdb0600dd,0xdb1d0018,0x237f06a3}},	//   vreb, tikë, dosí, _wouj_,
   {{0x2fcda60e,0x14c700cd,0x32060270,0x34950291}},	//   tleg_, _شهری_, apoy_, _савр,
   {{0x6e29545e,0x2918a60f,0xdb06023b,0x236d0167}},	//   treb, zara_, rikë, _unej_,
   {{0x2918a610,0x2fcd00f3,0xab5b01bf,0xdb1d0103}},	//   yara_, rleg_, hlüs, gosí,
   {{0x6e29a611,0x27e0a612,0x2fcda613,0xdb0d003e}},	//   rreb, zmin_, sleg_, _skað,
   {{0x29183371,0x6d4152a8,0xb4b10034,0x51841d57}},	//   vara_, rfla, _ओशो_, _тута,
   {{0x29183cd2,0xb5fb97a9,0xe81d00c3,0x6e29a614}},	//   wara_, _arám, _फिजा_, preb,
   {{0x2918a615,0x9d4501b6,0x290503a3,0x6d410364}},	//   tara_, _белд, ılan_, pfla,
   {{0xed560b31,0x21f9001c,0xf1a6023a,0xab5b042c}},	//   _бош_, _mèh_, कोपन, flüs,
   {{0x2918a616,0xb5fb6c72,0xf99f0c56,0xe61f016d}},	//   rara_, _drám, nsèy_, _avô_,
   {{0x2918a617,0x2bbb34fd,0x7c3c05fe,0x3f8d0085}},	//   sara_, _उदया, àrre, nkeu_,
   {{0x7bc6a618,0xb5fb0076,0xf99f03a9,0x00000000}},	// [bee0] moku, _frám, mpèn_, --,
   {{0x1a9b0130,0x2918a619,0xc885008b,0xb5fb89c9}},	//   _נייע, qara_, _başı_, _kráj,
   {{0xef190067,0x07a64c46,0x0d16006e,0x1d16006e}},	//   każ_, _банн, רקעט_, רקער_,
   {{0x4426199c,0x7bc60201,0xef190034,0x4ad80096}},	//   čo_, noku, jaż_, _ठराव,
   {{0xef1900a5,0x69650470,0x06751aad,0x8cca023a}},	//   daż_, _صدیق, _куря, _सुनो,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc6a61a,0x443e1175,0xdd4106b0,0xdcf801d3}},	//   koku, _ët_, _eŋŋi, _novā,
   {{0x201e0085,0x2d8300c2,0x083b006e,0x7dcf00f2}},	//   _vvti_, öjen_, געקל, løsh,
   {{0x01360604,0x35d9009f,0xdb16022b,0xb24400d2}},	//   _معاد, _बीड़, _ijyè, íždě,
   {{0xd65700a1,0x3b0060a7,0xc8850491,0x7e6d049c}},	//   ניית_, _afiq_, _yaşı_, _šapc,
   {{0x3a200072,0x00000000,0x00000000,0x00000000}},	//   _avip_, --, --, --,
   {{0x7bc623d1,0x00000000,0x00000000,0x00000000}},	//   goku, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0600ce,0x00000000,0x00000000,0x00000000}},	//   enkä, --, --, --,
   {{0x7bc60c7a,0x00000000,0x00000000,0x00000000}},	//   boku, --, --, --,
   {{0x7d1aa61b,0x291e01cd,0x00000000,0x00000000}},	//   lats, ótar_, --, --,
   {{0xb5fb0fb6,0x00000000,0x00000000,0x00000000}},	// [bef0] _trám, --, --, --,
   {{0x7d1aa61c,0x21f903a9,0xfaff0216,0x00000000}},	//   nats, _rèh_, lcë_, --,
   {{0xd5b84170,0x32040063,0x69c7a61d,0x54553bba}},	//   уст_, _atmy_, moje, рвет,
   {{0x7d1aa61e,0xfaff00dd,0x2a69a61f,0x69c7a620}},	//   hats, ncë_, _krab_, loje,
   {{0x7d1aa621,0x768700d3,0x2b490503,0x00000000}},	//   kats, _сынж, _mbac_, --,
   {{0x7bc68ac0,0x7d1a4feb,0xef1900a5,0xe1f0001c}},	//   zoku, jats, waż_, سسه_,
   {{0x7bc6660d,0x7d1aa622,0x99592347,0x2b49015e}},	//   yoku, dats, kážu_, _obac_,
   {{0x82f800e3,0x4433a623,0xd34600cd,0x7205a624}},	//   _مركز_, mux_, _نیمه_, _نورم,
   {{0x39940222,0x69c7a625,0x2a69006c,0x92b70f36}},	//   _läsa_, koje, _nrab_, _صحرا,
   {{0x7d1a6e12,0x20070088,0x7bc60502,0xb5fb0065}},	//   gats, ppni_, woku, _arák,
   {{0x5f7400bf,0xeb9a1a67,0x7bc6748f,0x69c7031a}},	//   _گالر, вин_, toku, doje,
   {{0x2b490178,0x6d8d2773,0x00000000,0x00000000}},	//   _cbac_, _kúak, --, --,
   {{0x7d1aa626,0x6f1ba627,0x61ee026a,0xf2130033}},	//   bats, mauc, _ünlü, _সমুহ_,
   {{0x6f1ba628,0x69c70117,0x3a20005c,0x2a6902b6}},	//   lauc, goje, _vvip_, _drab_,
   {{0xdca20870,0x7bc6068d,0xa3d51362,0x63ab0124}},	//   _маши, poku, हता_, kign,
   {{0xcc3a00c1,0x44330078,0x63ab008c,0x224d0abd}},	//   _סעפט, dux_, jign, _opek_,
   {{0x44330257,0x24f6002d,0x9f4c0850,0x6bc20294}},	// [bf00] eux_, ачер, _judá_, ọasụ,
   {{0xf2130081,0xf507002d,0x69c7037a,0x6b84036b}},	//   _সমূহ_, инул_, coje, _hoig,
   {{0x224d3142,0x7afb4160,0xdb0401f9,0x00000000}},	//   _apek_, žute, _amié, --,
   {{0x7d1aa629,0x212502e7,0x05160081,0x232a680a}},	//   zats, _adlh_, ালের_, тоди_,
   {{0x443353bd,0x06e40081,0x7d1aa62a,0x3f82003e}},	//   aux_, _ফ্রি, yats, ökum_,
   {{0x443302a1,0xa5073e1c,0x6b960150,0x6b84a62b}},	//   bux_, _вера_, _llyg, _loig,
   {{0x7d1a6361,0x224d1ca0,0xdb1d0103,0x6b9600f0}},	//   vats, _epek_, őzés, _olyg,
   {{0x7d1aa62c,0x63ab028d,0x628b0150,0x9fae00b6}},	//   wats, cign, bygo, _tří_,
   {{0x7d1aa62d,0xb3550018,0x69c70a3d,0x539b0289}},	//   tats, _دینا_, yoje, _סימו,
   {{0xddc200a5,0x71ea09b4,0xb5fb2347,0x6b840441}},	//   _społ, _شفاف_, _dráh, _aoig,
   {{0x7d1a37db,0x1b190084,0x6f1b67d5,0x9f450036}},	//   rats, лжны_, bauc, _lulù_,
   {{0x7d1aa62e,0x80bf06ed,0x6f1b0e4d,0x6b84152f}},	//   sats, _लुटे, cauc, _coig,
   {{0x6b84a62f,0x69c70eaf,0x37cc0081,0xfaff023b}},	//   _doig, toje, লগার, rcë_,
   {{0x66090b88,0x63ab1405,0xe3be020e,0x644e0381}},	//   _çeki, zign, ğıya_, _opbi,
   {{0x6b960fbc,0x69c73e75,0x97a758ff,0x628b00a5}},	//   _flyg, roje, арал, zygo,
   {{0x2a69009e,0x8aa70217,0x27ef003e,0x69c7a630}},	//   _trab_, _врод, ögn_, soje,
   {{0x69c708c6,0x63aba631,0x645c00cd,0x7bcd0a69}},	// [bf10] poje, vign, _asri, _ikau,
   {{0x443302a1,0x55740315,0x6ec900aa,0x00000000}},	//   tux_, огут, _हँसु, --,
   {{0x224da632,0x63aba633,0x6b84034f,0x7d18026a}},	//   _spek_, tign, _yoig, _mevs,
   {{0x44331b41,0x00000000,0x00000000,0x00000000}},	//   rux_, --, --, --,
   {{0xd6db34dc,0x644e00e7,0x63ab3b4e,0x6f1b6818}},	//   _што_, _epbi, rign, vauc,
   {{0x7d180f1c,0x0eff02d5,0x628ba634,0x6f0203a8}},	//   _nevs, ईड्स_, rygo, _afoc,
   {{0x04950080,0x6f1b1fc5,0x63ab028d,0xa2b3052c}},	//   _الأح, tauc, pign, _अशक्,
   {{0x7bcd01bb,0x28b800a1,0x63680508,0x6d4a0364}},	//   _nkau, יפוש_, _круг_, _abfa,
   {{0x6f1ba635,0x22941c17,0xceb900b6,0xb5fb0076}},	//   rauc, _дитя, kaře_, _brái,
   {{0x7bcda636,0x6f1ba637,0x6b84a638,0x6e22166d}},	//   _akau, sauc, _soig, _dvob,
   {{0x30a726fd,0x6b84a639,0x2005003d,0x34c50034}},	//   _трав, _poig, _utli_, _वडोद,
   {{0x69de01e5,0xf98900f5,0x4421a63a,0x63a900b6}},	//   _shpe, _אר_, ish_, _jmen,
   {{0x63a9a63b,0xeab20068,0x69c10146,0x63a30103}},	//   _mmen, سٹس_, člen, énny,
   {{0x63bba63c,0x63a963eb,0x442353ff,0xb5fb0076}},	//   _ljun, _lmen, _ovj_, _grái,
   {{0xb9006abb,0x63a9a63d,0x442100dd,0x6c350781}},	//   _तर_, _omen, jsh_, _افعا,
   {{0x07a31b48,0xc7a33164,0x63bba63e,0x4bfa00ca}},	//   пасн, писк, _njun, _גלקס,
   {{0x75d6450f,0x00000000,0x00000000,0x00000000}},	// [bf20] ميرا, --, --, --,
   {{0x63bba63f,0x63a9a640,0x44210052,0x649a24f7}},	//   _ajun, _amen, fsh_, лтер_,
   {{0x130a002d,0x291a4bcd,0x00000000,0x00000000}},	//   гней_, _iepa_, --, --,
   {{0xe29a0f5f,0x63a9a641,0x031a25a1,0x77940504}},	//   лае_, _cmen, اتات_, _بیرا,
   {{0x291aa642,0x63a902a1,0x270300fe,0x63bba643}},	//   _kepa_, _dmen, _ổng_, _djun,
   {{0x63a9a644,0x55e324d3,0x6f020451,0x39940220}},	//   _emen, _нояб, _sfoc, _mäso_,
   {{0x6e22174d,0xe04a00cd,0x50661894,0x7d180c89}},	//   _svob, اشته_, стла, _revs,
   {{0x44442c03,0x291a60d1,0xb5fb00e3,0x7764a645}},	//   mt_, _lepa_, _srái, ndix,
   {{0xa3d505d4,0x76442862,0x877b006e,0x7d180117}},	//   हतर_, ntiy, ראפי, _pevs,
   {{0x63a90038,0x7bcda646,0x7bdf00dd,0x4444019e}},	//   _zmen, _skau, _shqu, ot_,
   {{0xe6d50bd9,0xdb55007b,0x6aa60033,0x7d180120}},	//   _दर्ज, овны, _গুলো, _vevs,
   {{0x44440632,0x7e64a647,0x63a99309,0x6f190178}},	//   it_, _šipu, _xmen, _gewc,
   {{0x4444a648,0xb5fba649,0x2aab0291,0x00000000}},	//   ht_, _trái, утно_, --,
   {{0x444469d5,0x398f00aa,0x44214887,0x98b800c6}},	//   kt_, _küsi_, ysh_, nerė_,
   {{0x4444a64a,0x291aa64b,0x6f0d00d3,0xbc67001c}},	//   jt_, _depa_, _încâ, _همون_,
   {{0x291a0139,0x6d48286f,0x06150686,0xd7f8075f}},	//   _eepa_, lfda, ждаю, сур_,
   {{0xa3cc007d,0xaa59264b,0x76448a00,0x63a9010a}},	// [bf30] रकन_, _типу_, gtiy, _rmen,
   {{0x44447571,0x63a95136,0x63bb0149,0x44211066}},	//   ft_, _smen, _sjun, tsh_,
   {{0x44446ab7,0x490f000d,0x7dcf02b6,0x280800d2}},	//   gt_, _त्यो_, møst, ětné_,
   {{0x69d50364,0x291a0072,0x7dcf0170,0x44211bc8}},	//   llze, _zepa_, løst, rsh_,
   {{0x444485af,0x60c40367,0x44211341,0x00000000}},	//   at_, şiml, ssh_, --,
   {{0x290300a5,0x4444a64c,0x291a0131,0x21694159}},	//   ncja_, bt_, _xepa_, рики_,
   {{0x4444a64d,0x93e90037,0x63bb007e,0xaf9906ea}},	//   ct_, _نفسك_, _tjun, итих_,
   {{0xdfd10080,0x63bb1f12,0x63a9a64e,0x6445a64f}},	//   بيع_, _ujun, _umen, mthi,
   {{0x64450013,0x290300a5,0x660da650,0x6d48039f}},	//   lthi, kcja_, npak, ffda,
   {{0x225f01dc,0x6445a651,0xb5fb01cd,0xb65c0142}},	//   _isuk_, othi, _fráv, רדזש,
   {{0x6445a652,0x7e640307,0xb5fb0161,0x06ad0033}},	//   nthi, _šipt, _gráv, _কুমি,
   {{0x61fb13e3,0x64458359,0x660da653,0x7e6b00e7}},	//   _kuul, ithi, kpak, _trgp,
   {{0x61fb007a,0xb69b00d3,0x64459680,0x4444a654}},	//   _juul, _sfân, hthi, zt_,
   {{0x6445a655,0x225f02e7,0x44441c04,0x660d21a4}},	//   kthi, _msuk_, yt_, dpak,
   {{0x61fb13e9,0xbc1900f3,0x6fea0034,0x4444a132}},	//   _luul, _тілі_, _ręcz, xt_,
   {{0x444416f4,0x65751f7b,0x2903007f,0x6b9d042c}},	//   vt_, _anzh, acja_, chsg,
   {{0x660d152a,0x44443e95,0x2d87a656,0x291a03a9}},	// [bf40] gpak, wt_, _kone_, _tepa_,
   {{0x4444a657,0x7644a658,0xd91009b4,0x224200aa}},	//   tt_, rtiy, _سیر_, _äkki_,
   {{0x4444a659,0x3958a65a,0x7644a65b,0xe45a159a}},	//   ut_, mers_, stiy, рже_,
   {{0x395801be,0xa3d4000f,0x76444228,0x61fba65c}},	//   lers_, _सीख_, ptiy, _buul,
   {{0x2a60009e,0xdd1c00d4,0x7644008c,0x6445756f}},	//   _jsib_, váži, qtiy, athi,
   {{0xb5fb0871,0x3958a65d,0x64a600c6,0x61fb008a}},	//   _práv, ners_, _дага, _duul,
   {{0x4444003d,0xcf9a0831,0x395842cc,0x7f4911bc}},	//   qt_, ији_, iers_, ffeq,
   {{0x26110ed3,0x395800a1,0x61fb008c,0x2d876a0b}},	//   दीकी_, hers_, _fuul, _aone_,
   {{0x61fb0694,0x395840e9,0xe297198a,0x6609026a}},	//   _guul, kers_, _дат_, _çekt,
   {{0x2d980067,0xb5fb025b,0x39580078,0x00000000}},	//   óre_, _tráv, jers_, --,
   {{0x39583199,0x2246905a,0xe4fb00c1,0x2d872dcf}},	//   ders_, ltok_, יפיש, _done_,
   {{0xb5fb0074,0xddc20029,0x236600dd,0xdb0f0052}},	//   _krát, _droš, ndoj_, micë,
   {{0x2d87a65e,0x395875ae,0x290c008b,0x2246a65f}},	//   _fone_, fers_, ıdan_, ntok_,
   {{0x395843e9,0x6445585c,0x13b71b11,0x2d8700ca}},	//   gers_, ythi, _अद्भ, _gone_,
   {{0x37ab1a0c,0x6ca3008f,0xb0ca0034,0xd7fb1087}},	//   атан_, _оръж, िथिग, руг_,
   {{0x2246a660,0x660d2096,0x6445023e,0x7dcf01df}},	//   ktok_, tpak, vthi, søst,
   {{0x2b59002d,0xd50b300f,0x1a650504,0x660d58b5}},	// [bf50] mesc_, لغان_, _عیسی_, upak,
   {{0x660da661,0x2246a662,0x2b59a663,0xdb0615bf}},	//   rpak, dtok_, lesc_, miká,
   {{0x4375123a,0x61fba664,0xdb06768a,0xc8d20b95}},	//   зулт, _suul, liká, _दुपट,
   {{0x6445a665,0x2b59002d,0x660da666,0x61fb0329}},	//   rthi, nesc_, ppak, _puul,
   {{0x27e9a667,0x6445a668,0xdb06a669,0x22463d82}},	//   mman_, sthi, niká, gtok_,
   {{0x27e9a66a,0x6b9d023b,0xb5fba66b,0xdb0f0216}},	//   lman_, ërgj, _drát, ficë,
   {{0x76590740,0x2d9ea66c,0xb5fb002b,0x22460031}},	//   şayı, dhte_, _usáb, atok_,
   {{0x27e9a66d,0x3958a66e,0x61fb28d1,0x2d87a66f}},	//   nman_, zers_, _tuul, _sone_,
   {{0x28d20d0b,0xb5fba670,0x2d871ffc,0x395800a1}},	//   _दुनि, _grát, _pone_, yers_,
   {{0xddc20d94,0x27e9a671,0xdb061e6f,0xdbd70673}},	//   _proš, hman_, diká, hääl,
   {{0xb5fb0074,0x27e90f8e,0x1b200081,0x3958a672}},	//   _krás, kman_, _ভাবে_, vers_,
   {{0x27e906a3,0xdb064729,0x395875ae,0x06c40033}},	//   jman_, fiká, wers_, ্ধতি,
   {{0x27e9a673,0x3958501b,0x3861005c,0xa3cc17ff}},	//   dman_, ters_, _ashr_, रकत_,
   {{0x2d9ea674,0xdca523a3,0xaca300ac,0x3958a675}},	//   chte_, _нали, _ahụi, uers_,
   {{0x22460018,0x2b5900d3,0xddc22b73,0x7d7a00ca}},	//   ztok_, besc_, _uroš, _לנסו,
   {{0x3958a676,0x27e92f75,0xab9a00bf,0x2fcd0934}},	//   sers_, gman_, _دختر_, noeg_,
   {{0x41cb0a30,0x39583199,0xa3c12f8f,0xf1cb00b6}},	// [bf60] िवास, pers_, ुवन_, िवान,
   {{0x27e9a677,0xfaff023b,0xa3a9023a,0x00000000}},	//   aman_, ndën_, गोस_, --,
   {{0x27e9030a,0xdb0f00b3,0xc61d0033,0x044a0077}},	//   bman_, ficè, ধূলা_, спек_,
   {{0xb5fba678,0x69cea679,0xdb0f0052,0x7dd4015e}},	//   _prát, lobe, vicë, ràsi,
   {{0x23660218,0xb5fb0143,0x3f9f6221,0x00000000}},	//   rdoj_, _drás, dhuu_, --,
   {{0xb5fb135f,0x473600bf,0x69cea67a,0x22467d1c}},	//   _vrát, _برگز, nobe, rtok_,
   {{0x34a70752,0xdb06045e,0xb5fb8f3d,0x2246a67b}},	//   _евро_, ziká, _frás, stok_,
   {{0xc9180b94,0xb5fba67c,0x69ce7a16,0x6edd397e}},	//   थरुम_, _trát, hobe, _परशु,
   {{0xed580038,0x2d9e7fab,0x443aa67d,0x2b5900ae}},	//   teľ_, thte_, lup_, vesc_,
   {{0x27e906a3,0xd9c602d5,0x4c94166f,0xad250421}},	//   zman_, लकोट, диос, ورپو,
   {{0x27e9a67e,0x69ce15fe,0x2b5900d3,0xdb0f0072}},	//   yman_, dobe, tesc_, licé,
   {{0x2d9e074a,0xa3e2009f,0xdb062e16,0x27e9781a}},	//   shte_, _नीम_, tiká, xman_,
   {{0x2b59002d,0x27e906a3,0xdfa508ba,0xdbd7007b}},	//   resc_, vman_, _تحلي, vääl,
   {{0x7e62a67f,0x23de05d4,0x2b59002d,0x69ce0283}},	//   _isop, _फीसद, sesc_, gobe,
   {{0xa3be34d8,0xa3cc000d,0xfce30291,0xa3dc0296}},	//   ीका_, रका_, _пољо, डता_,
   {{0x6d5aa680,0x443a10f3,0x1cbb00a1,0x00000000}},	//   leta, dup_, _למוע, --,
   {{0xd6db0978,0x9f4c0181,0x27e97100,0xb5fb0065}},	// [bf70] ств_, _budú_, rman_, _arár,
   {{0x6d5a03f3,0x27e90383,0x69ce3062,0x7bcf00d3}},	//   neta, sman_, cobe, locu,
   {{0x44270f07,0x27e906a3,0x443a048e,0x96f9020a}},	//   én_, pman_, gup_, _мент_,
   {{0x6d5aa681,0x245e030b,0x27e996da,0x31650364}},	//   heta, _dům_, qman_, _salz_,
   {{0x6d5a63d1,0xe6670109,0x2fcd0185,0xb5fb813d}},	//   keta, _этно, voeg_, _vrás,
   {{0xb90b0139,0x2d8a56eb,0x443a0085,0x00000000}},	//   _adiẹ_, öbel_, bup_, --,
   {{0x6d5aa682,0x7e62026e,0x95080018,0x00000000}},	//   deta, _asop, _رہنے_, --,
   {{0x69cea683,0x389c0341,0xa3a9009f,0x7bcf020a}},	//   zobe, מיונ, गोश_, jocu,
   {{0x200c01d4,0x7e620018,0x69ce66ba,0x3165016d}},	//   _etdi_, _csop, yobe, _talz_,
   {{0xa3d500a5,0x6d5a1173,0xd65800ca,0xa3a91115}},	//   हतक_, geta, ליחת_, गोर_,
   {{0x656702dd,0x69ce0a39,0xdcf802c6,0x2fcd751c}},	//   _majh, vobe, _hově, poeg_,
   {{0x2d9ca684,0x7bcf0072,0xdea10103,0x00000000}},	//   _elve_, gocu, _لیبی, --,
   {{0x6d5aa685,0x65a002e2,0xdce30078,0xab5b013c}},	//   beta, _höhe, _kanċ, nlüy,
   {{0x9f5e4043,0x6d5aa686,0x443aa687,0x6455a688}},	//   _että_, ceta, yup_, _opzi,
   {{0x69cea689,0x65a00103,0x6e3b6ec9,0xe9df0206}},	//   robe, _jöhe, luub, ptún_,
   {{0xe61a7464,0x69cea68a,0xdce30090,0xdb060233}},	//   жда_, sobe, _lanċ, dikç,
   {{0x60c401e8,0x69ce1ce4,0x645517b1,0xdcf802c6}},	// [bf80] ğimi, pobe, _apzi, _nově,
   {{0xca3700a1,0x60c40367,0xe6de007f,0xa3b00e28}},	//   _קניה_, şimi, _मरीज, टोन_,
   {{0x07a606c4,0xa97b00ca,0x7dd400ee,0x00000000}},	//   _жанн, _ואיכ, màst, --,
   {{0x6d5aa68b,0x443aa68c,0x7dd400b3,0x6e3ba68d}},	//   zeta, rup_, làst, kuub,
   {{0x6d5aa68e,0xd250006f,0x925a0602,0x7c3a042c}},	//   yeta, انت_, تشار_, zutr,
   {{0x6d5a266e,0x6e3b0188,0xdce30090,0x67240063}},	//   xeta, duub, _canċ, laij,
   {{0x6d5aa68f,0xa3d90b89,0x443a023b,0x61ea1f53}},	//   veta, _ठीक_, qup_, rmfl,
   {{0x6d5aa690,0x7e620113,0xdb06007b,0x6e3b0361}},	//   weta, _psop, nikä, fuub,
   {{0xb146002d,0x63a2a691,0x00000000,0x00000000}},	//   _онал, mhon, --, --,
   {{0x60cd03a3,0x672401cb,0x200c0063,0xaad20034}},	//   şama, haij, _ttdi_, _सड़क,
   {{0x6d5a0b6a,0x75370054,0x7bcfa692,0xc04900fe}},	//   reta, ואיד_, tocu, _mướn_,
   {{0x69c0025a,0x6ec95e07,0x7c3a134d,0x988100e8}},	//   émen, _हुकु, rutr, rīļa_,
   {{0x6d5aa693,0x7bcf23e9,0xc4db030b,0xeda6007e}},	//   peta, rocu, _भर्ख, _ошко,
   {{0x7c3aa58c,0x7bcf2c68,0x6d4300da,0x00000000}},	//   putr, socu, _gcna, --,
   {{0x63a2067d,0xb5fb104a,0x9848008f,0x4bdb0037}},	//   khon, _aráp, мята_, _وبعد_,
   {{0x1b1900c7,0x7e6d031a,0xab5b026a,0x7c282c28}},	//   _থাকে_, _šapi, ylüy, msdr,
   {{0x63a200cd,0x656701fa,0x7c28a694,0x55750a7c}},	// [bf90] dhon, _pajh, lsdr, нгат,
   {{0xd9e306ed,0x99540220,0x6b8d02ac,0x63a21183}},	//   _गठित_, _päť_, _hoag, ehon,
   {{0x656701fa,0x7c28a695,0xddc2007f,0x7bc8020d}},	//   _vajh, nsdr, _spoś, éjug,
   {{0xa3a90067,0xd6d00018,0x63a2a696,0xdb06026a}},	//   गों_, اقے_, ghon, rikç,
   {{0x6b8da697,0xdcf800b6,0x7d0a49fb,0x3cfc010a}},	//   _moag, _pově, _offs, _ogvv_,
   {{0xe045171b,0xa0691b9d,0x00000000,0x00000000}},	//   енки, зака_, --, --,
   {{0x442a01cb,0x00000000,0x00000000,0x00000000}},	//   _gvb_, --, --, --,
   {{0x9e65246b,0xdbd7032c,0x2bbb3e2a,0x0e650b1b}},	//   евид, _jääh, _उदगा, екин,
   {{0xa3cc110f,0xa3be009d,0x7bc700c4,0x7c2818f0}},	//   रकर_, ीकर_, čkul, esdr,
   {{0x4c852636,0x3f82003e,0xac85831a,0x00000000}},	//   елов, ökur_, егол, --,
   {{0xe57207a6,0x3f150084,0x6e3b0283,0x672f0357}},	//   אַר_, _здес, suub, _odcj,
   {{0xfe71110a,0x27f9a698,0xcf27001c,0x4c82004d}},	//   _مدت_, _nisn_, _آراي, улюв,
   {{0xc332028c,0x661d023e,0x998400b6,0x45e30032}},	//   נוך_, _nwsk, émů_, _díẹ̀_,
   {{0xc212193b,0x6e290201,0x67240350,0x00000000}},	//   רהם_, mseb, waij, --,
   {{0xa3c1a699,0x9f5e022b,0x8d740281,0x6e290a1f}},	//   ुवा_, _butè_, _جانا, lseb,
   {{0x6f090332,0x442a04d4,0x6d41a69a,0x1ae667c3}},	//   ncec, _rvb_, lgla, _пойм,
   {{0x29050702,0x6e29a69b,0xdce31ca7,0x97c300a9}},	// [bfa0] ılar_, nseb, _manč, уйте,
   {{0x6d41a69c,0x65a00092,0xdce30335,0x7ae40060}},	//   ngla, _söhb, _lanč, _izit,
   {{0x63a2a69d,0xb5fb0143,0x6d41a69e,0x98b800c6}},	//   thon, _usán, igla, merį_,
   {{0x248602e6,0x8c1a00a1,0xb5fb0146,0x69dc489a}},	//   ćom_, פוני, _tráp, llre,
   {{0x45240033,0x6e2902b6,0xe2970284,0xf99f03a9}},	//   _পাঠক_, jseb, нац_, mpèr_,
   {{0x63a2a69f,0x6e290087,0x442a0023,0x7ae40239}},	//   shon, dseb, _tvb_, _mzit,
   {{0x63a2a6a0,0xb882030b,0xdce30087,0x67c50138}},	//   phon, _říjn, _banč, lėja,
   {{0x69dc39c0,0xdd250138,0x7bd60361,0xa85700ca}},	//   hlre, _rūši, _nkyu, תיקה_,
   {{0x7ae435fe,0x67c50138,0x6b8d00ae,0x9f4f02a1}},	//   _nzit, nėja, _roag, _digà_,
   {{0x7bd6083e,0x7bc40239,0x6d41a6a1,0x7c283ea1}},	//   _akyu, _ajiu, ggla, tsdr,
   {{0xb5fb0065,0x7ae43f74,0xdcba008f,0xd19700ca}},	//   _asál, _azit, ящи_, _רכבי_,
   {{0x67c50138,0x291800e1,0x7c28a6a2,0x2d830212}},	//   kėja, ebra_, rsdr, öjer_,
   {{0xdfcf00bf,0x4e930260,0x7c28004d,0x61faa6a3}},	//   _اين_, _مشور, ssdr, _kitl,
   {{0x67c5013f,0xdb0f0161,0x6c5400c2,0x7bd6083e}},	//   dėja, micí, _акку, _ekyu,
   {{0xb90904a9,0xdb0f0fb6,0x61fa25c0,0x7ae4a6a4}},	//   _बर_, licí, _mitl, _ezit,
   {{0x61fa23ff,0x2602007a,0x657c0150,0xca49001c}},	//   _litl, _वंशी_, _anrh, _قلعه_,
   {{0xdb0fa6a5,0x39150f30,0xfc450146,0x2918a6a6}},	// [bfb0] nicí, _импр, žíte_, bbra_,
   {{0x28d20179,0x7bdda6a7,0x61fa009e,0x9f5e00d4}},	//   _दुवि, llsu, _nitl, _duté_,
   {{0xe3be07d1,0xe5c40ebf,0x430e0134,0xc95200ca}},	//   ğına_, усто, _ịpị_, _דמי_,
   {{0x04c800e3,0xe3be08bb,0x6e290150,0x6d410128}},	//   روني_, şına_, yseb, zgla,
   {{0x21693967,0x61faa6a8,0x614500d3,0x6d4100f0}},	//   дили_, _bitl, вела, ygla,
   {{0x23690106,0xd8380b27,0x61fa025b,0xdb0f0146}},	//   žaj_, šče_, _citl, dicí,
   {{0xdce36508,0xa066013d,0x61faa6a9,0xa493010d}},	//   _panč, ваща_, _ditl, _حیات,
   {{0x39940149,0x776da6aa,0x6d41023e,0x61fa0037}},	//   _häst_, ndax, wgla, _eitl,
   {{0x764d3645,0x6f090449,0x2d8e0131,0x61fa028a}},	//   ntay, rcec, _bofe_, _fitl,
   {{0x6e291268,0x30a7125c,0x61fa0270,0xfe4200d6}},	//   rseb, _прев, _gitl, шньо,
   {{0x6e29a6ab,0xdce3a6ac,0xe6de1cff,0x7ae401f9}},	//   sseb, _bonġ, _मर्ज, _szit,
   {{0x39940222,0x6d41a6ad,0x09da009d,0x7e6d00cc}},	//   _läst_, sgla, णत्य, _šapu,
   {{0x98b800c6,0x98b00357,0xdb0f1497,0x29181e8f}},	//   terį_, _čađe_, ficâ, tbra_,
   {{0x67c50138,0xdb060094,0x21270023,0x7bdd00aa}},	//   vėja, nikú, nanh_, alsu,
   {{0x3f8f007a,0x29186b46,0xd823180b,0x5ed30033}},	//   _kogu_, rbra_, идри, দেশে,
   {{0x212700de,0x764d8643,0x67c50138,0x7bc4024a}},	//   hanh_, ftay, tėja, _ujiu,
   {{0x3f8f02e6,0x39940222,0x764d68bd,0x7ae4628e}},	// [bfc0] _mogu_, _bäst_, gtay, _uzit,
   {{0xa80601a0,0x67c5013f,0x3f8fa6ae,0x44f6001c}},	//   _изол, rėja, _logu_, نساز,
   {{0x499b0796,0x764d77d7,0x0326004d,0xdb060094}},	//   _חשיב, atay, вден, dikú,
   {{0x3f8f084f,0x78a30092,0x61ca1fb4,0x764d008c}},	//   _nogu_, _ünva, ाक्ष, btay,
   {{0x425400ab,0x60cd020e,0xdb0f0231,0x00000000}},	//   انتر, şaml, licã, --,
   {{0x657c02e0,0x7f950b0b,0xa3e2121d,0x39940149}},	//   _unrh, _máqu, _नीर_, _gäst_,
   {{0x93462249,0x3f8f0995,0x61faa6af,0x33f60012}},	//   _инве, _bogu_, _vitl, _ачас,
   {{0x2d8e031a,0x61fa01d0,0x25e60e4c,0xdb0f75f4}},	//   _sofe_, _witl, _जीती_, ticí,
   {{0x3f8f01e9,0xa3c12171,0x00000000,0x00000000}},	//   _dogu_, ुवर_, --, --,
   {{0x61fa043e,0xb5fb0139,0x2ca900b6,0x33240090}},	//   _uitl, _asáj, _řada_, _hemx_,
   {{0x7e6d0880,0x00000000,0x00000000,0x00000000}},	//   _šapt, --, --, --,
   {{0x316c00e7,0x3f8f044c,0x2bca0285,0x764d01ee}},	//   _hadz_, _gogu_, रवगा, ytay,
   {{0xa5bb4cf5,0x75e30174,0xee94001c,0x7f950231}},	//   _kvót, ọzir, _حداک, _cáqu,
   {{0x3f8f0052,0xdee36ab4,0x5e5700d7,0x6db90206}},	//   _zogu_, _точи, _סיוע_, rňac,
   {{0x59f8002d,0x0322009f,0x316c0f5a,0x60e602c6}},	//   теря_, मराह_, _madz_, _úsmě,
   {{0xb8db0aa6,0x764da6b0,0xddd90154,0x97a4002d}},	//   _आइ_, ttay, _apwň, арул,
   {{0x8bb41dec,0xd7f80d0f,0xeb1f178d,0x2b4900b3}},	// [bfd0] _خصوص, тур_, परीत_, _icac_,
   {{0x6b9d3994,0x764d9768,0x21270023,0x9f9a00bc}},	//   lksg, rtay, xanh_, _hääl_,
   {{0x764d38bd,0xdce300d9,0x29010129,0xf9920327}},	//   stay, _kanā, _igha_, _הרי_,
   {{0x6b9da6b1,0x9f4c037a,0x317e0062,0x3204033c}},	//   nksg, _mudó_, _antz_, _bumy_,
   {{0xdb1d1f84,0x6b9d01c0,0xf9900470,0xdce300e8}},	//   losó, iksg, _طبی_, _manā,
   {{0x644a05fe,0xa5bb00a5,0x1a9c0a41,0x00000000}},	//   àfic, _dwóc, וידע, --,
   {{0x65a000a7,0xe0550037,0x27eb00fe,0xdb1d00bc}},	//   _köhn, اختب, _khcn_, fosü,
   {{0x69d5a6b2,0x439400c2,0x6d5c00bc,0x6b9d0381}},	//   hoze, _касс, õran, jksg,
   {{0x69d5a6b3,0x32040891,0x2901a6b4,0x3f8f007e}},	//   koze, _gumy_, _ogha_, _vogu_,
   {{0x63b9a6b5,0x2fc60113,0x6b9d029a,0x67c50138}},	//   liwn, _ejog_, eksg, kėjo,
   {{0x7ddd00cd,0x75eb0367,0xdb0f00b3,0x628f0231}},	//   nèsi, müzd, ficà, _àcob,
   {{0x290106c0,0x29cd0181,0x9f4c034f,0x67c500c6}},	//   _agha_, hľad_, _dudó_, dėjo,
   {{0x539a0130,0x6f1b15be,0x200500a6,0xff04008f}},	//   גירו, mbuc, _huli_, _тяхн,
   {{0x186a013d,0x2005a6b6,0x8c452155,0x2fdf0078}},	//   наги_, _kuli_, _беке, llug_,
   {{0xc4be0081,0x2b4900b3,0xdb1d002b,0x21250090}},	//   _অর্জ, _fcac_, gosó, _melh_,
   {{0x2005a6b7,0x6f1b02e2,0xdb0f0131,0x7ddd30ea}},	//   _muli_, nbuc, ricã, dèsi,
   {{0x2005a6b8,0x69d5a6b9,0xe57a43cb,0x80da0285}},	// [bfe0] _luli_, boze, нза_, _पुने,
   {{0xc966942b,0x98780094,0xdb1d0072,0xfe1b0f35}},	//   _свой, láče_, bosó, पीएस_,
   {{0x26cb061d,0x2005001c,0xdb0f3536,0xe3be008b}},	//   _exco_, _nuli_, licá, şıma_,
   {{0xa22a0e38,0x7c2e46b4,0x42caa6ba,0x2fdf022e}},	//   ежда_, ábri, нген_, jlug_,
   {{0x758400bf,0x212500e7,0x84e6009f,0x6e3b01c2}},	//   _پیام, _belh_, _करवट_, jrub,
   {{0x27e0a6bb,0x20050a15,0xb4260e5a,0x67261f6d}},	//   llin_, _buli_, _معرو, _hekj,
   {{0x66061d2d,0x27e0a6bc,0x64a63daf,0x2fdf5ac6}},	//   _hukk, olin_, _сава, flug_,
   {{0x6606a6bd,0xa0670303,0x69d547ef,0x5f942277}},	//   _kukk, ѓања_, zoze, риит,
   {{0x244e025b,0x28db04f8,0x6e3ba6be,0x6606007b}},	//   lým_, _मुनि, grub, _jukk,
   {{0xa3b006ed,0x6606083e,0xdb0f24c7,0xdce300d9}},	//   टोर_, _mukk, dicá, _sanā,
   {{0x244e0897,0x660670a8,0x2005a6bf,0xdce300d9}},	//   ným_, _lukk, _guli_, _panā,
   {{0x656e1519,0xdb0f2027,0x69d53165,0x67260087}},	//   _labh, ficá, woze, _nekj,
   {{0x244e0146,0x69d501e9,0x660601a5,0xe7f807d5}},	//   hým_, toze, _nukk, ंगना_,
   {{0x645ca6c0,0xf2d30130,0x244e18ed,0x2005006d}},	//   _opri, מער_, kým_, _yuli_,
   {{0x69d5a6c1,0xddc20087,0x67260120,0x6299007f}},	//   roze, _krož, _bekj, zywo,
   {{0x2a690197,0x7ddd02f1,0xe7c50033,0x27e09f79}},	//   _tsab_, vèsi, ্ষ্য, glin_,
   {{0x645c29b0,0x2a691098,0xa9c70e25,0x656e1c4a}},	// [bff0] _apri, _usab_, _مزدو, _babh,
   {{0xd8380b27,0x656e0a62,0x2d9e0e74,0x6606a6c2}},	//   šča_, _cabh, nkte_, _dukk,
   {{0x2d9e9878,0x27e0a6c3,0xddc20087,0x6d4a2ad7}},	//   ikte_, blin_, _orož, _mcfa,
   {{0xae04055e,0xb7675276,0x932715f8,0x656e152f}},	//   रदान_, _стой, اران, _eabh,
   {{0x2005a6c4,0xfdf60251,0x920701d3,0x660606b0}},	//   _suli_, ीदास_, klāš, _gukk,
   {{0x656e10f0,0xe2961121,0x2005a6c5,0x6f02a6c6}},	//   _gabh, раш_, _puli_, _agoc,
   {{0xa0a501b6,0x10a51166,0x6e223cc2,0xddc20094}},	//   райд, рийн, _awob, _brož,
   {{0xe3b00f43,0x6e3b0146,0x7f752c22,0xddc95eb7}},	//   _فرق_, trub, рукц, dveš,
   {{0xdb0601e5,0x44230197,0x6f1b02db,0xddc83360}},	//   shkë, _hwj_, rbuc, _šošk,
   {{0x20053cd8,0xdcf80029,0x442301fa,0x6e3b635d}},	//   _tuli_, _novē, _kwj_, rrub,
   {{0xb17a00c1,0xa17a00c1,0x6e3b0212,0xab5ba6c7}},	//   _שטער, _שטעט, srub, rnün,
   {{0xddc2013f,0x765da6c8,0x2d9e1044,0x6e3b12ff}},	//   _grož, _opsy, akte_, prub,
   {{0x7ff40241,0x4423006c,0x8f9a00a1,0x6e220150}},	//   _اسلا, _lwj_, _שיני, _gwob,
   {{0x2d9e3114,0x27e07753,0x6606a6c9,0x3f8d031a}},	//   ckte_, wlin_, _rukk, ljeu_,
   {{0x66064e5f,0xa3d52b8a,0xd706016e,0x656e02bc}},	//   _sukk, सका_, изви, _rabh,
   {{0x244e0c01,0x656ea6ca,0x660612ea,0x3f9f346f}},	//   vým_, _sabh, _pukk, nkuu_,

   {{0x28db007d,0x27f26ae7,0xb69b00d3,0x27e00703}},	// [c000] _मुठि, rmyn_, _sfâr, rlin_,
   {{0x244e025b,0x1a9b0341,0xdb04029a,0x645c00bd}},	//   tým_, _סייע, _olië, _ppri,
   {{0x4423006c,0xb466a6cb,0x261a02d5,0x6726003e}},	//   _cwj_, ркел, मीजी_, _tekj,
   {{0xa3b000a5,0x244e0579,0x6606a6cc,0x656e0201}},	//   टों_, rým_, _tukk, _wabh,
   {{0x656e003b,0x2d9e13c8,0x98a301d3,0x7527800c}},	//   _tabh, ykte_, majā_, _fejz,
   {{0xfe080028,0x442301fa,0x76440010,0x77640428}},	//   _nữa_, _fwj_, muiy, leix,
   {{0xdb0401c0,0xf1a900cd,0xddc279dc,0x6db90094}},	//   _clië, دانه_, _prož, tňan,
   {{0x4444a6cd,0x77640990,0x6e220c56,0x98a301d3}},	//   mu_, neix, _pwob, najā_,
   {{0x4444a6ce,0xfe0800de,0xb5fb0032,0x4423023e}},	//   lu_, _bữa_, _aráy, _zwj_,
   {{0x4444a6cf,0x4423006c,0x3d160096,0x00000000}},	//   ou_, _ywj_, पुढे_, --,
   {{0xb5fb0074,0x2d9e4bd8,0x4423023e,0x98a301d3}},	//   _práz, rkte_, _xwj_, kajā_,
   {{0xa3cc000c,0x4444a6d0,0x9ffa0037,0x6e220027}},	//   रकट_, iu_, _شراء_, _twob,
   {{0x776405fe,0x6fb30037,0x7e790150,0x387a0027}},	//   deix, _بمنا, _grwp, _arpr_,
   {{0x6b5c052f,0xa5bb0139,0x1cba0037,0x65a0042c}},	//   _pågæ, _awón, _لاعب_, _böhm,
   {{0xa3d60ef8,0x7764015e,0x75270141,0xddc2007f}},	//   हवा_, feix, _rejz, _mroż,
   {{0x776405fe,0x4423023e,0x3cfb00a1,0xf7700037}},	//   geix, _rwj_, _בלונ, واق_,
   {{0x4444a6d1,0xf1b80090,0x776f00fe,0x76440350}},	// [c010] eu_, _omġ_, _vacx, guiy,
   {{0x6d481098,0x444430df,0x4431013f,0xdcea0095}},	//   ngda, fu_, _pvz_, _lafč,
   {{0x444443b5,0x5455474e,0x442301fa,0x7ddda6d2}},	//   gu_, свет, _qwj_, mèst,
   {{0xb4e70ded,0x69c702dd,0x442301fa,0xdfc60037}},	//   _परी_, lnje, _vwj_, _ري_,
   {{0x4444a6d3,0x75274f69,0x4df60fef,0x672d582b}},	//   au_, _tejz, ँगाई_, maaj,
   {{0xdca6054f,0x672d0084,0x4423006c,0x44317926}},	//   _فى_, laaj, _twj_, _tvz_,
   {{0x6d480124,0x3f9f00c2,0x7d030072,0x9f5e00b3}},	//   dgda, tkuu_, _rgns, _butà_,
   {{0xfe080019,0xfaff023b,0x6445a6d4,0x69c702fb}},	//   _sữa_, ndës_, muhi, hnje,
   {{0x3ead00cc,0x3f9f008a,0x6445a6d5,0x660d039f}},	//   uzet_, rkuu_, luhi, nqak,
   {{0xcda90979,0x518408d9,0x4c691312,0x69c708a9}},	//   اهده_, _муха, гион_, jnje,
   {{0x69c715f4,0x644537b7,0x672da6d6,0x6ab211d7}},	//   dnje, nuhi, kaaj, ीप्र,
   {{0xe0d00241,0x672d6e59,0x929d007f,0x09b200a4}},	//   _غزل_, jaaj, _zgła, ुच्य,
   {{0xed59235c,0x4444a6d7,0xb5fb002b,0x98a300e8}},	//   _бол_, zu_, _fráx, vajā_,
   {{0x4444a6d8,0x69c71271,0x64457180,0x7d0302c3}},	//   yu_, gnje, kuhi, _ugns,
   {{0x77640e9c,0x68e9030b,0x98a300d9,0xe73a5fa3}},	//   teix, ředn, tajā_, лев_,
   {{0x81cd00c7,0x81bf00c7,0x6445a6d9,0xd838033b}},	//   রতি_, ীতি_, duhi, ščo_,
   {{0x4444a6da,0x77640472,0x46ea0095,0xd9461d5c}},	// [c020] wu_, reix, удан_, _лепи,
   {{0x6b960188,0x69c714f3,0x128800d1,0x7e6902ac}},	//   _hoyg, cnje, یمای_, iwep,
   {{0x644500a6,0x69de00ac,0x7ae901d3,0x7e690415}},	//   guhi, _ikpe, ļete, hwep,
   {{0x7e69339e,0x9f5d0065,0x6b840090,0x00000000}},	//   kwep, _fiwé_, _jnig, --,
   {{0x4444a6db,0x6d4822d4,0xdb06a6dc,0x91e62440}},	//   su_, ygda, likó, боде,
   {{0xa97a00c1,0xe9df0037,0x25b8033b,0x65a000a7}},	//   ראַכ, ltúr_, _umrl_, _möhk,
   {{0xfaff01e5,0x443e0028,0x6b84026e,0xdb0600a5}},	//   ndër_, _ít_, _onig, nikó,
   {{0x69c7191d,0xe9df4df5,0x00000000,0x00000000}},	//   znje, ntúr_, --, --,
   {{0xa3d50455,0x2a6001fa,0x62860087,0x63a2a6dd}},	//   सकर_, _npib_, _škof, mkon,
   {{0x6b840694,0x69de0294,0x224600f9,0x7ddd00b3}},	//   _anig, _nkpe, muok_, dèss,
   {{0xcb043ad1,0xd12f0214,0x69c709ac,0xe9df1137}},	//   रखंड_, _سمن_, vnje, ktúr_,
   {{0x63a2a6de,0x69de0167,0xa5bb0032,0xd90f015a}},	//   nkon, _akpe, _awól, کید_,
   {{0xddc200d9,0x69c701ac,0xb5fb0042,0x672d00c2}},	//   _esoš, tnje, _tráx, vaaj,
   {{0x6b84a6df,0x67c50138,0xfe3700c1,0x6445a6e0}},	//   _enig, mėji, _פרוי_, yuhi,
   {{0x63a2a240,0x97a706c4,0xb4e7099d,0x672da6e1}},	//   kkon, брал, _परे_, taaj,
   {{0xaada2a24,0x69de00ac,0x68e900b6,0x8aa7013f}},	//   _युवक, _ekpe, ředo, _грод,
   {{0x69c7a6e2,0x67c5013f,0xdb0d01e8,0x63a20429}},	// [c030] pnje, nėji, _amaç, dkon,
   {{0x7aed03f3,0x6445a6e3,0x672d289c,0xec0900de}},	//   _izat, tuhi, saaj, _mến_,
   {{0x672d7de3,0x93190037,0x63a2a6e4,0x75eb013c}},	//   paaj, لقاء_, fkon, güza,
   {{0x63a29081,0x6445a6e5,0x67c5013f,0x672d008c}},	//   gkon, ruhi, kėji, qaaj,
   {{0xe1f100cd,0x6445a6e6,0x91050aad,0xec090023}},	//   وست_, suhi, опле, _nến_,
   {{0x64458de7,0x67c50138,0x80151300,0x63a20e22}},	//   puhi, dėji, офиц, akon,
   {{0x299c00ca,0x63a278bc,0xa2d92014,0x00000000}},	//   רסומ, bkon, _फुर्, --,
   {{0xee390cd7,0x2d98a6e7,0xec0900de,0x7bdf063d}},	//   ани_, ören_, _bến_, _nkqu,
   {{0xa3e2009d,0x63a95b08,0xe2932c9a,0xd2510781}},	//   _नीट_, _ilen, _عذر_, _زنا_,
   {{0x31342edd,0x6b96047e,0x7bcd00ce,0xdb1d01dc}},	//   _неур, _soyg, _ajau, lisè,
   {{0x63a9626f,0x7aed02a4,0x63bb0167,0xdce3007e}},	//   _klen, _azat, _kmun, _manć,
   {{0xf98909c1,0x22402cea,0x67c50138,0x06fb0034}},	//   _בר_, šike_, bėji, ्शाव_,
   {{0x79970124,0x63a99036,0x63bb0361,0xd35600ca}},	//   _boxw, _mlen, _mmun, חירי_,
   {{0x63a9a6e8,0xdca50ce5,0x63a24b5e,0x7aed2aea}},	//   _llen, _мали, zkon, _dzat,
   {{0x929d0067,0x63a2135f,0x63a9a6e9,0x63bba6ea}},	//   _ogło, ykon, _olen, _omun,
   {{0x6b8402ad,0xec0900de,0x9f4600de,0x22460124}},	//   _unig, _yến_, _khoá_, yuok_,
   {{0xe617453b,0xa2d9201e,0x63a29ec8,0xf1a90e28}},	// [c040] жду_, _फुल्, vkon, कसान,
   {{0x63bba6eb,0x63a970a8,0xba9b00ca,0x9b460281}},	//   _amun, _alen, _כספי, _انکو,
   {{0x130a17b9,0xb5fb0094,0x63a9a6ec,0x9987020a}},	//   аней_, _spác, _blen, şiţa_,
   {{0x69dca6ed,0x63a91ea1,0x65a007ee,0x9f4c0131}},	//   lore, _clen, _möhi, _judô_,
   {{0x63a2a6ee,0x7f9c00b3,0x84e6074c,0xb5fb01f9}},	//   rkon, _xéqu, _करकट_, _csás,
   {{0x63a2a6ef,0x63bba6f0,0x67c50138,0x7ae405bd}},	//   skon, _emun, vėji, _myit,
   {{0x628641f9,0xe5710130,0xbfaa1773,0x98ba026a}},	//   _škod, _אַן_, итие_, _kapı_,
   {{0xdfd00080,0x69dca6f1,0x20026dc3,0xe29a01b3}},	//   عية_, hore, öki_, _каб_,
   {{0x69dc092f,0x7ae4a6f2,0x80da0096,0x3167a6f3}},	//   kore, _nyit, _पुरे, benz_,
   {{0x929d0067,0x69dc0081,0xdd9a079c,0x161f2ebd}},	//   _zgło, jore, рши_, मीटर_,
   {{0x7ae42b0d,0xdb1d025a,0x63bb02ad,0x7f9c04c1}},	//   _ayit, lisé, _ymun, _séqu,
   {{0x212c0052,0x7ae402a4,0x67c50138,0x98a3007f}},	//   _hedh_, _byit, pėji, nają_,
   {{0xdb1d48b7,0x7ae40193,0x200c0117,0xdce300c6}},	//   nisé, _cyit, _hudi_, _manę,
   {{0x200c006d,0x7e6233e4,0x7aed00d4,0xf1bc00d2}},	//   _kudi_, _ipop, _vzat, ्चिन,
   {{0x200c0da3,0xa3bc009d,0x98a30034,0xf1d2023a}},	//   _judi_, ेचा_, kają_, _तदनन,
   {{0x31670364,0x7e620167,0x200ca6f4,0x6d5aa6f5}},	//   zenz_, _kpop, _mudi_, lfta,
   {{0x69dca6f6,0x1ab402fd,0x7bdda6f7,0x7aeda6f8}},	// [c050] bore, _объя, mosu, _uzat,
   {{0xb5fb0065,0x38610063,0x8b350018,0x63bb0052}},	//   _asár, _tphr_, _بڑھت, _smun,
   {{0x63a9a6f9,0x33191536,0x00000000,0x00000000}},	//   _plen, біля_, --, --,
   {{0x98a30034,0x00000000,0x00000000,0x00000000}},	//   gają_, --, --, --,
   {{0x443302a1,0x31670364,0x787502c6,0xdb7c006e}},	//   ssx_, tenz_, bývá, ינאכ,
   {{0x3f86022b,0x1e0402d5,0x628f2e00,0x7bdda6fa}},	//   _anou_, रदोष_, _àcom, hosu,
   {{0x7e62a6fb,0x316701bf,0x98ba026a,0xa2bb00b6}},	//   _apop, renz_, _yapı_, _शेर्,
   {{0x63bba6fc,0x69dc0995,0x645701fa,0x98a3007f}},	//   _umun, zore, mtxi, cają_,
   {{0xdd911e49,0x69dca6fd,0x3dce05aa,0xdb1d00e1}},	//   فوظ_, yore, _bjfw_, cisé,
   {{0xc05b0a8d,0x41b50391,0x212c0113,0x661b0233}},	//   _від_, _عمار, _gedh_, _çuku,
   {{0x6575a6fe,0x320d22d4,0x200c008c,0x7ae4007b}},	//   _mazh, _huey_, _gudi_, _syit,
   {{0x7bdd4f84,0x320d0063,0x6d5aa6ff,0x3f860154}},	//   gosu, _kuey_, afta, _gnou_,
   {{0x7c95001c,0x3a99007b,0x67c500c6,0x00000000}},	//   زشگا, отрю_, nėju, --,
   {{0xceb200c1,0x200ca700,0xa2cc0403,0x98a3007f}},	//   _איד_, _yudi_, तपत्, zają_,
   {{0x69dca701,0x2d87a702,0xe7f8009d,0x7e7b0088}},	//   rore, _inne_, ंगला_, lvup,
   {{0x4c3a00a1,0xdb1d0018,0x7bdd044c,0x67c500c6}},	//   _התקב, yisé, cosu, kėju,
   {{0x69dc2a1e,0x00000000,0x00000000,0x00000000}},	// [c060] pore, --, --, --,
   {{0x67c50138,0x98a30034,0x7abb00ca,0xdb1d00fd}},	//   dėju, wają_, _לצפו, visé,
   {{0x399b0341,0x999b00a1,0x765600c2,0x98a3007f}},	//   _הייד, _הביט, styy, tają_,
   {{0x200ca703,0xdb1d416f,0x320d00e1,0xec0900fe}},	//   _rudi_, tisé, _buey_, _nếm_,
   {{0x200c28be,0x6286211b,0x98a30034,0x5213004d}},	//   _sudi_, _škob, rają_, едіт,
   {{0xdb1d20cc,0x6724a704,0x5bbe06c0,0x00000000}},	//   risé, lbij, ọchị_, --,
   {{0x7e62a705,0x7bdd9b44,0x00000000,0x00000000}},	//   _spop, yosu, --, --,
   {{0x442a0085,0x27e200dc,0x200c0095,0x6724029a}},	//   _iwb_, _jkkn_, _vudi_, nbij,
   {{0x442a9b9d,0x7bdd005f,0xdd1b0206,0x00000000}},	//   _hwb_, vosu, _dážd, --,
   {{0x200c2782,0x4444019e,0x644300d9,0xaf120174}},	//   _tudi_, or_, šnie, _aụtụ,
   {{0x442a02e7,0x7bdda706,0x76447f43,0x1bd5004c}},	//   _jwb_, tosu, hriy, доня,
   {{0x44444f4e,0x2d87a707,0x68e9030b,0x920201d3}},	//   ir_, _enne_, ředk, žāda,
   {{0x44440e78,0x6724a708,0x7644a709,0x7e625fe7}},	//   hr_, dbij, jriy, _upop,
   {{0x7644a70a,0x44448dc1,0x6280007e,0x7bdd4553}},	//   driy, kr_, _mrmo, sosu,
   {{0xaf120174,0x444411af,0x971a0174,0xec090023}},	//   _fụtụ, jr_, _ọdụd, _yếm_,
   {{0x6280a70b,0x44444d2f,0x00000000,0x00000000}},	//   _ormo, dr_, --, --,
   {{0x44380257,0x442aa70c,0xdb1da70d,0x3a2903a9}},	// [c070] _avr_, _awb_, lisï, _uwap_,
   {{0x645703e5,0x4444a70e,0x44383155,0xb60601d3}},	//   ttxi, fr_, _bvr_, jošā,
   {{0x657501e5,0x442a214b,0xf99200a1,0x4444a70f}},	//   _vazh, _cwb_, _סרט_, gr_,
   {{0x32050031,0x61e10052,0x21310234,0xb6020072}},	//   _sily_, _skll, _žzh_, ñáro,
   {{0x27e901b5,0xd25b3006,0x78a10212,0x32050a7f}},	//   mlan_, сце_, älvf, _pily_,
   {{0x27e9a710,0x4444a711,0x442a01fa,0xfa7800a1}},	//   llan_, br_, _fwb_, פעות_,
   {{0x442a03e3,0x32050146,0x27e945e6,0xd4980cfc}},	//   _gwb_, _vily_, olan_, _ерт_,
   {{0x27e91281,0x2240031a,0xd8380146,0x753c05db}},	//   nlan_, šika_, áči_, _zdrz,
   {{0x66070505,0xc2c40037,0x27e9a712,0x62800141}},	//   _kijk, _كيفي, ilan_, _grmo,
   {{0x672403ce,0x27e9a713,0xd8380087,0x442a023e}},	//   zbij, hlan_, šči_, _ywb_,
   {{0x442a0d7d,0x27e9a714,0x673d2392,0x7e7b4880}},	//   _xwb_, klan_, _odsj, svup,
   {{0x66070ab2,0xfc3f18ed,0x547a00a1,0x200600de}},	//   _lijk, čí_, קטרו, _gioi_,
   {{0xeb97453b,0x5f05004b,0xfd4e0294,0x8db500d6}},	//   фия_, _ўзла, _jenụ, _оскі,
   {{0x7644a715,0xb5fb2a44,0x4444a716,0x2ca900b6}},	//   vriy, _spán, yr_, _řadu_,
   {{0x661d22bb,0x67240126,0xeb9a002d,0x65a000a7}},	//   _atsk, tbij, _мик_, _möht,
   {{0x7644a717,0x27e9a718,0x2fcd0178,0x752ea719}},	//   triy, glan_, nneg_, _sebz,
   {{0x44442fda,0x6724a71a,0x442a022e,0x7644008a}},	// [c080] wr_, rbij, _swb_, uriy,
   {{0x272c00ef,0x27e9a71b,0x4444089d,0x7644a71c}},	//   ến_, alan_, tr_, rriy,
   {{0x4444540d,0x27e9a71d,0x442a023e,0x660701c0}},	//   ur_, blan_, _qwb_, _dijk,
   {{0x44444348,0x76442b5d,0x27e901b5,0x660fa71e}},	//   rr_, priy, clan_, _fuck,
   {{0x27e0a71f,0x660f0364,0x6445a720,0x1217450f}},	//   moin_, _guck, arhi, وتوث_,
   {{0x442a01bb,0x644304d8,0x443800ae,0x29cd0220}},	//   _twb_, ánic, _tvr_, eľaj_,
   {{0x660fa721,0x00000000,0x00000000,0x00000000}},	//   _zuck, --, --, --,
   {{0x660701c0,0x27e07fa8,0x69cea722,0xab5b042c}},	//   _zijk, noin_, hnbe, nnüt,
   {{0xaf120129,0x6ac800e2,0xb5fb291d,0x8d6a1009}},	//   _bụrụ, रपोर, _opál, ојна_,
   {{0x27e9a0ba,0x68e900b6,0x69ce029a,0xf1aa001c}},	//   zlan_, ředi, jnbe, _باره_,
   {{0x27e9a723,0x27e0007b,0xdb0401cd,0x6f1903a8}},	//   ylan_, koin_, _smið, _ffwc,
   {{0x69cea724,0x61eaa725,0xf0b700c1,0x201e04d6}},	//   enbe, llfl, _קלאר_, _itti_,
   {{0x27e9906e,0x672f007e,0x6d5c00bc,0x27e0a726}},	//   vlan_, _recj, õras, doin_,
   {{0x442131c9,0x660fa727,0x0cd42a61,0xddc900b6}},	//   yph_, _ruck, _полю, kteř,
   {{0x27e90068,0x66070126,0x27e00167,0x660f4f2d}},	//   tlan_, _rijk, foin_, _suck,
   {{0x2fc40090,0x224605f1,0x660f516e,0x5fde00c3}},	//   nimg_, krok_, _puck, मविल,
   {{0x35f5014d,0x3ea4793d,0x332600fc,0x672f0117}},	// [c090] епар, nymt_, dbox_, _vecj,
   {{0x2d9c0472,0x660f0a39,0x201e00c2,0x3326020d}},	//   _jove_, _vuck, _otti_, ebox_,
   {{0x27e901be,0xb7d50032,0x2d9c00ca,0x660782aa}},	//   plan_, _aṣel, _move_, _vijk,
   {{0x2d9ca728,0x66070126,0x4421651e,0x27e0a729}},	//   _love_, _wijk, rph_, coin_,
   {{0x201e54ae,0x661d13f8,0xdcef02ef,0xdb0600c2}},	//   _atti_, _utsk, _čeča, sikö,
   {{0x018b00c2,0xdb1d3536,0x00000000,0x00000000}},	//   ющей_, disí, --, --,
   {{0x647400c2,0x201e00b3,0xafe5227c,0xc0e20859}},	//   _игру, _ctti_, нокл, лошк,
   {{0x80be009d,0xb4ab0336,0xe0d00286,0x0eca00aa}},	//   _वेळे, गनी_, جزه_, ापंड,
   {{0x201e01e8,0xaf120294,0x63a4007b,0x69ce084e}},	//   _etti_, _pụrụ, öine, ynbe,
   {{0x2fcd02ad,0x30a70161,0x00000000,0x00000000}},	//   sneg_, _орев, --, --,
   {{0xdca558ad,0x6ac8022d,0xfbc641f3,0x2d9c0a5f}},	//   хани, रप्र, ебно, _dove_,
   {{0x7f840080,0xdb041097,0xb5fb0244,0xcc240103}},	//   _للمن, _aliá, _spál, کریٹ,
   {{0x27e000c2,0x1a660103,0x65a0042c,0x764d024a}},	//   voin_, ریدی_, _möhr, juay,
   {{0xe9df003e,0x2018145c,0x00000000,0x00000000}},	//   trúa_, _éric_, --, --,
   {{0x69ce9112,0x7bcf023e,0x27e0a72a,0x2918119e}},	//   rnbe, bncu, toin_, rcra_,
   {{0x2d9c03ce,0xe61a3cee,0xb90800aa,0xc3250033}},	//   _zove_, зда_, _बड_, মৃতি_,
   {{0x7bc6a72b,0x764d0314,0x366730cc,0x2b4000e7}},	// [c0a0] miku, guay, нато_, _idic_,
   {{0x7bc627ad,0x27e0025a,0x3f9d0139,0x2d9c03be}},	//   liku, soin_, _lowu_, _xove_,
   {{0xe8990068,0x75d30037,0x65a000a7,0x7bc6024a}},	//   _ہمیں_, ديلا, _böhr, oiku,
   {{0x7bc6a72c,0x224601af,0x80da030b,0x260d00d8}},	//   niku, trok_, _पुगे, _džob_,
   {{0x41e6059b,0xdb1d016d,0x799e02ac,0x7e7d0537}},	//   ніка, lisã, _kopw, æspl,
   {{0xd83802dd,0xdb1d3906,0x7bc6a72d,0x2ca52084}},	//   šču_, visí, hiku, kyld_,
   {{0x232a42d1,0x7bc663c1,0x00000000,0x00000000}},	//   _нови_, kiku, --, --,
   {{0x2d9ca72e,0xedc80f8f,0x2246a72f,0x7bc60051}},	//   _sove_, िच्छ, prok_, jiku,
   {{0x7bc6a730,0x2d9c0087,0x00000000,0x00000000}},	//   diku, _pove_, --, --,
   {{0x2ca502b6,0x2b400027,0xa2d9115b,0x00000000}},	//   fyld_, _adic_, _फुट्, --,
   {{0x7bc6a731,0x3a202c1d,0x00000000,0x00000000}},	//   fiku, _atip_, --, --,
   {{0x7bc65f28,0x443a00f9,0x6815007f,0xdb1d00f3}},	//   giku, isp_, _sądo, nnsø,
   {{0x69da00b6,0x75f00031,0x2d9c1842,0x9ad30294}},	//   čten, väzn, _tove_, jịta,
   {{0xddd90154,0x7c940037,0x7bc60313,0x2ca5066a}},	//   _apwņ, _للتص, aiku, byld_,
   {{0x7bc6a732,0x28db0f53,0xbd1700ca,0x00000000}},	//   biku, _मुखि, _אחוז_, --,
   {{0x17f80037,0x00000000,0x00000000,0x00000000}},	//   فرقة_, --, --, --,
   {{0x6b8d008a,0xe61300e3,0x65a00364,0x75eb00a7}},	// [c0b0] _inag, اشر_, _röhr, lüzi,
   {{0x7c3aa733,0x6b8d0113,0xddc90a39,0x00000000}},	//   ostr, _hnag, zvež, --,
   {{0x69c708c5,0xdb1d001f,0x776d0072,0x6b8d7fb8}},	//   mije, cisã, peax, _knag,
   {{0x69c748d1,0x7c3a4d2f,0xa5bb0139,0x798901c2}},	//   lije, istr, _awót, ɓewa,
   {{0xdb0f08ec,0xfe080028,0xaf120294,0xa5650018}},	//   licó, _hữu_, _rụpụ, _لگان,
   {{0x69c703ce,0x7c3aa734,0xa0690095,0x443aa735}},	//   nije, kstr, дака_, bsp_,
   {{0x7c3a6999,0x7bc61621,0xdb0f0072,0x00000000}},	//   jstr, yiku, nicó, --,
   {{0x7c3a1af1,0xa5bb0103,0xc6240033,0x6b8da736}},	//   dstr, _utób, _পিতা_, _nnag,
   {{0x7bc6a737,0x2a69022e,0x69c7a738,0x32552a84}},	//   viku, _npab_, kije, _швар,
   {{0x0d821211,0x6b8da739,0x7c3aa73a,0x4c858519}},	//   альн, _anag, fstr, влов,
   {{0x69c71cb4,0x7c3a2566,0x40357f94,0xb5fb0065}},	//   dije, gstr, _реес, _apák,
   {{0xdb1d0396,0x61e36504,0x799e5db9,0xdb0f0072}},	//   visã, lonl, _sopw, dicó,
   {{0x7bc67a5a,0x7c3a002d,0x6b8d010a,0x733a006e}},	//   riku, astr, _dnag, וערס,
   {{0x7c3aa73b,0x69c7042d,0x7bc6a73c,0xdb040428}},	//   bstr, gije, siku, _lliç,
   {{0x29cd1528,0x6e3b04c8,0xfe0800fe,0x7bc6a73d}},	//   džad_, lsub, _cữu_, piku,
   {{0x6f1b063f,0x6a86002d,0x6b8da73e,0x6fb1023a}},	//   ncuc, _алиа, _gnag, जसिं,
   {{0x69c702e6,0x61e300c2,0x64430088,0x69262922}},	// [c0c0] bije, konl, ánin, _импа,
   {{0x69c702e6,0x75d300e3,0xca3700a1,0x61e3a73f}},	//   cije, ليقا, _שניה_, jonl,
   {{0x61e3a740,0x644316ac,0x00000000,0x00000000}},	//   donl, šnin, --, --,
   {{0xdb0f0428,0x61e30036,0x07a6001f,0x63060401}},	//   licò, eonl, _рамн, نوال,
   {{0x7c3aa741,0x63a903e5,0x61e30511,0x864318a2}},	//   zstr, _ċent, fonl, _княж,
   {{0x61e30c23,0x7c3a08b2,0x415300d6,0x201a0161}},	//   gonl, ystr, ивіс, ípio_,
   {{0x2eca397e,0xddc90034,0x7c3a0381,0xd3420103}},	//   ाप्त, steś, xstr, _نہای,
   {{0x657ca742,0x7c3a17d2,0x245c1054,0x1f740036}},	//   _harh, vstr, mím_, улия,
   {{0x6e3b2839,0x657ca743,0x245c0146,0x61e300fc}},	//   gsub, _karh, lím_, bonl,
   {{0x6b8d03ce,0x7c3a0acb,0xa2bb0455,0x657ea744}},	//   _snag, tstr, _शेट्, ndph,
   {{0x245c0871,0x69c70480,0x63a0a745,0x62825a0c}},	//   ním_, vije, _komn, lvoo,
   {{0xa3d520cd,0xfe460cb0,0x6e3b9680,0x6f1b0036}},	//   िचय_, _андо, bsub, ccuc,
   {{0xfe721e49,0xec0a00ef,0x7af60067,0xf77303ed}},	//   _خدا_, _nếu_, _czyt, یار_,
   {{0x63a049c4,0x7c3aa746,0x7bc4010a,0x6e2d0233}},	//   _lomn, pstr, _emiu, _çaba,
   {{0x69c702e6,0x628635b5,0x245c025b,0xb7d50065}},	//   rije, _škol, jím_, _aṣal,
   {{0x245c025b,0x657c01c5,0x63a0019f,0xdb0f0d5a}},	//   dím_, _aarh, _nomn, ricó,
   {{0x62820ab2,0x69c70fa3,0x61e30511,0x657c0150}},	// [c0d0] jvoo, pije, yonl, _barh,
   {{0xa5bb0065,0xdc4200b6,0x61e3483a,0x7aeda747}},	//   _awór, _léče, xonl, _iyat,
   {{0x657c1a1e,0x63a04670,0x61e3007b,0x62821183}},	//   _darh, _bomn, vonl, evoo,
   {{0x27ff0649,0x6e22a748,0x7aed083e,0x7f42150c}},	//   _òun_, _otob, _kyat, _ndoq,
   {{0x63a0a749,0x657ca74a,0x628201d0,0x6e22a74b}},	//   _domn, _farh, gvoo, _ntob,
   {{0xec0a0028,0x245c0146,0x7f4200e1,0x7aed2ae7}},	//   _hết_, bím_, _adoq, _myat,
   {{0xec0a00ef,0x61e3a74c,0x245c0618,0x6e22a581}},	//   _kết_, ronl, cím_, _atob,
   {{0x61e30018,0xec0a0019,0x7ff50397,0x63a003e3}},	//   sonl, _yếu_, دستا, _gomn,
   {{0x7aed1084,0x6f1b15d4,0x69c51044,0x657c061d}},	//   _nyat, rcuc, _omhe, _yarh,
   {{0x6e3ba74d,0xb5fb0037,0xdb0d00fd,0x6f1b037a}},	//   rsub, _bpái, _plaî, scuc,
   {{0x7535785e,0x6e3ba74e,0x7aed9bd0,0xc1040037}},	//   _mezz, ssub, _ayat, _نوكي,
   {{0x7aed0ab1,0x69c500f0,0x75353fd9,0x6e3b01cb}},	//   _byat, _amhe, _lezz, psub,
   {{0x7aed0193,0x245c00b6,0x29cd0b14,0xdb0f00b3}},	//   _cyat, zím_, džab_, ticò,
   {{0x9d55110a,0x99d600e3,0x2bc6009f,0x2d9830c1}},	//   _صنعت, اتحا, _लगवा, öret_,
   {{0x1867a74f,0x6443a750,0xa3e3099d,0xf7462c37}},	//   лари_, ánil, नका_, лево,
   {{0x245c030b,0x657ca751,0x7aed0350,0xdb0f015e}},	//   vím_, _sarh, _fyat, sicò,
   {{0x657c5b4d,0xa6860138,0x7aeda752,0x05661caa}},	// [c0e0] _parh, ылад, _gyat, лван,
   {{0x245c0343,0x63a03c2f,0x3ea00013,0x9ad30134}},	//   tím_, _somn, _àite_, pịra,
   {{0xe73a180b,0x80a800c7,0x63a08077,0x98a61e11}},	//   _пен_, _কেন্, _pomn, _сине,
   {{0x644a0428,0x245ca753,0x99990138,0x62821cab}},	//   àfiq, rím_, busų_, tvoo,
   {{0x245c0897,0x442301e5,0x657ca754,0xa2940f1e}},	//   sím_, _etj_, _tarh, ралі,
   {{0x62820934,0x91e300c2,0x3f8f0201,0x245c0e51}},	//   rvoo, боче, _angu_, pím_,
   {{0x98a7150a,0x62827d74,0xf1a900cd,0x6e221691}},	//   čića_, svoo, خانه_, _stob,
   {{0x6d438316,0x7535010a,0x63a00350,0x320c4084}},	//   _adna, _zezz, _uomn, _widy_,
   {{0xb5fb266d,0xae43001c,0x00000000,0x00000000}},	//   _spái, مپيو, --, --,
   {{0x3f8fa755,0x7aed02a4,0x660e00bd,0x00000000}},	//   _engu_, _ryat, _jibk, --,
   {{0x7aed17b6,0x628f1275,0x660e02a1,0xd0120076}},	//   _syat, _àcor, _mibk, _الص_,
   {{0xce350103,0x317e01c8,0x660e05db,0x69c5009c}},	//   _چونک, _hatz_, _libk, _smhe,
   {{0x2fc60124,0x395a0154,0x628600c4,0xec0a020b}},	//   _imog_, _bcps_, _škoj, _rết_,
   {{0x7aed7bdc,0xa5bba043,0x70020174,0x660e02a1}},	//   _vyat, _atón, _ọcha, _nibk,
   {{0xb76701b6,0x75350036,0x69b6009f,0xdcf82a22}},	//   лтай, _rezz, _उतरी, _kavč,
   {{0x6443a756,0x75350078,0x317e01c8,0x7aed0154}},	//   ánim, _sezz, _latz_, _tyat,
   {{0x7535013d,0xec0a00de,0x260d0307,0x44231649}},	// [c0f0] _pezz, _vết_, _džon_, _stj_,
   {{0x64430660,0x4423a757,0x6e240052,0x69c5a758}},	//   šnim, _ptj_, _çibu, _umhe,
   {{0xec0a0019,0x75350451,0xe8950077,0xddc9026a}},	//   _tết_, _vezz, _тань, hteş,
   {{0xf1ed007f,0x00000000,0x00000000,0x00000000}},	//   _चीज़_, --, --, --,
   {{0x672d74b2,0xab5b00bc,0x00000000,0x00000000}},	//   mbaj, riüh, --, --,
   {{0x644a132d,0x21692da1,0x60253c97,0x2fc60124}},	//   áfic, тики_, адка, _amog_,
   {{0xdb1d0102,0xf77f01e8,0x112800d6,0xdcf874b7}},	//   nnsó, _kaç_, уючи_, _bavč,
   {{0xf77f00b3,0xfe45125f,0x660e05db,0xe3b33160}},	//   _jaç_, анио, _zibk, _ارس_,
   {{0xee360963,0x764da759,0xdcf802dd,0x9f5e0018}},	//   аны_, nray, _davč, _autó_,
   {{0x237f0197,0x62890167,0xc69200ca,0x5e56001c}},	//   _hauj_, _ireo, קאי_, گلیس_,
   {{0xab2a36c9,0x237f022e,0x764d60a7,0x72040182}},	//   кона_, _kauj_, hray, _اولم,
   {{0x99910106,0x2d980149,0xdb0d24c7,0xe45600c1}},	//   _čašu_, örer_, _amañ, סירט_,
   {{0x237f022e,0x672d516e,0xef0e044b,0xdb0d009c}},	//   _mauj_, dbaj, _фм_, _smaò,
   {{0x237f006c,0x764d002b,0x6e290ac9,0x6d430231}},	//   _lauj_, dray, mpeb, _udna,
   {{0x6443084f,0x52d1009d,0x776402a1,0xac160831}},	//   šnij, तपुस, tfix, _коју_,
   {{0x764da75a,0x672d43b3,0x200f9988,0x31d205d6}},	//   fray, gbaj, _jigi_, _तद्ध,
   {{0x764d1d0d,0x77b80072,0x25a3007e,0x200fa75b}},	// [c100] gray, _níxe, _bojl_, _migi_,
   {{0x77642fe6,0x672d010a,0x00000000,0x00000000}},	//   sfix, abaj, --, --,
   {{0x6289a75c,0x14c800cd,0xddcb01d3,0x764d0188}},	//   _areo, دهای_, _apgū, aray,
   {{0x764da75d,0x317e01bf,0xb4e6074c,0x62894842}},	//   bray, _satz_, _पडी_, _breo,
   {{0x6289a75e,0x02060084,0x25a300bd,0x66290094}},	//   _creo, аздн, _fojl_, čský,
   {{0x77b8002b,0x27f2a75f,0x62899542,0x200f0d4a}},	//   _díxe, llyn_, _dreo, _aigi_,
   {{0x64a60f6a,0x03965961,0x9f440575,0xdcf80141}},	//   _тава, _края, lomé_, _pavč,
   {{0x224904a3,0x237f023e,0x27f2a760,0x77b8002b}},	//   šaka_, _gauj_, nlyn_, _fíxe,
   {{0xa3e30101,0x62330396,0x62895c99,0xddc20094}},	//   नकर_, _меѓу, _greo, _apoš,
   {{0xcd062264,0x200f0088,0x504607ed,0x237f0063}},	//   ични, _eigi_, _вежб, _zauj_,
   {{0xdd9701b3,0x200f06a3,0xe7fb030b,0x9df7013f}},	//   ршы_, _figi_, ्षमा_, рнэт_,
   {{0x200f39fb,0x237f022e,0xdb24003e,0xee860138}},	//   _gigi_, _xauj_, örðu, _выко,
   {{0xddc22174,0x27f21849,0x00000000,0x00000000}},	//   _epoš, dlyn_, --, --,
   {{0x261a000f,0xf77f0587,0x394d01bf,0x7c28502c}},	//   _बढ़ी_, _saç_, ßes_, ppdr,
   {{0x69d5042c,0xdb04009c,0x764d008c,0xa5bb0503}},	//   rnze, _mliù, wray, _dtól,
   {{0x644304fa,0x57b43140,0x98b100ae,0x248d574a}},	//   šnik, обст, ează_, _čem_,
   {{0x2cac02ad,0x237f45e8,0x60150138,0x764d008c}},	// [c110] lydd_, _rauj_, _išme, uray,
   {{0xeb9f1484,0x764d7d40,0x2d9e023b,0xdb1d007b}},	//   ljø_, rray, njte_, sisä,
   {{0x2cac02ad,0x237f022e,0x764d4bdb,0x6289009c}},	//   nydd_, _pauj_, sray, _sreo,
   {{0x77b89954,0x96c20455,0x764d03a9,0x237f023e}},	//   _píxe, _रेकॉ, pray, _qauj_,
   {{0x59bb0635,0x27e9059f,0x9f4a02c6,0xb5fb033c}},	//   _उतार, moan_, ámým_, _bpát,
   {{0xc69200c1,0x27e9a761,0x2cac0149,0x628900ae}},	//   _זאך_, loan_, kydd_, _vreo,
   {{0x237f01fa,0xa4d4004d,0xa0a56f46,0x00000000}},	//   _tauj_, _дорі, сайд, --,
   {{0x27e9a762,0x62890080,0x2cac0150,0x63ad00aa}},	//   noan_, _treo, dydd_, öand,
   {{0xddc20087,0xe3b000e3,0x6ad1397e,0xdb04009c}},	//   _spoš, _غرف_, सपोर, _fliù,
   {{0x2cac0150,0x27e9a763,0xdb04009c,0x200f2b78}},	//   fydd_, hoan_, _gliù, _wigi_,
   {{0x27e902a7,0xec0a0019,0x200f9988,0x2cac0150}},	//   koan_, _bếp_, _tigi_, gydd_,
   {{0x5f77177a,0xb5fb00b6,0xa5bb01cd,0x6e290ac9}},	//   _خاطر, _zpát, _stól, ppeb,
   {{0x27e901e9,0xa5bba764,0x75f80294,0x00000000}},	//   doan_, _atóm, ụzir, --,
   {{0x6fde01d3,0x2fcd5e3b,0x7c9511f7,0x00000000}},	//   rīce, lieg_, _гриц, --,
   {{0x3ead0018,0xddc20087,0xe7e431f4,0xb4e617ff}},	//   lyet_, _upoš, ककला_, _पडे_,
   {{0x27e9a765,0x27950d85,0x00000000,0x00000000}},	//   goan_, ошур, --, --,
   {{0x3ead0533,0x27f253ca,0x07a3364c,0x00000000}},	// [c120] nyet_, rlyn_, чатн, --,
   {{0x8b0800a5,0x27f253ca,0x29cd033b,0x9f44020d}},	//   _cięż, slyn_, lžan_, romé_,
   {{0xb4b20521,0xb5fb0139,0x64a000cb,0x3d3a006e}},	//   टने_, _apás, _ošiš, רגעס,
   {{0x69cea766,0xec0a0028,0xd36f0076,0x27e903a9}},	//   libe, _xếp_, فهم_, coan_,
   {{0xdb04009c,0x00000000,0x00000000,0x00000000}},	//   _pliù, --, --, --,
   {{0x3ead0fa0,0x91e38084,0x644320df,0xe9df003e}},	//   dyet_, поче, ânic, trúi_,
   {{0xe4da0de1,0x26c00036,0x00000000,0x00000000}},	//   _صورت_, lzio_, --, --,
   {{0xdbf1030b,0x00000000,0x00000000,0x00000000}},	//   _příb, --, --, --,
   {{0x2cac02e0,0x26c0a767,0xa3d5063e,0xe7fb397e}},	//   wydd_, nzio_, िचर_, ्षता_,
   {{0x27e901e9,0xec0a0023,0x69ce2d17,0x5be102d5}},	//   zoan_, _sếp_, jibe, नव्व,
   {{0x6e220134,0x69ce0062,0x27e911b9,0x2fcd76b2}},	//   _dịọk, dibe, yoan_, bieg_,
   {{0x5f7606fa,0x2cac02ad,0x26c001e9,0x22400b18}},	//   _دائر, rydd_, kzio_, šiku_,
   {{0xcb034ff1,0x2cac0150,0x69ce4e21,0x9b58008f}},	//   रेंड_, sydd_, fibe, щият_,
   {{0x3d940131,0x8b08030b,0x27e903a9,0x69cea768}},	//   _фикр, _stří, woan_, gibe,
   {{0x27e9a769,0x788302c6,0xfdf700ca,0x4ac500aa}},	//   toan_, dívá, _הצגת_, _लइकव,
   {{0x9f5d0154,0x58d4004d,0xba195432,0xbebd0144}},	//   _chwè_, чост, _پيدا_, rbūv,
   {{0x95391031,0x27e9a76a,0x56940120,0x7bcf2bd6}},	// [c130] изат_, roan_, патт, micu,
   {{0x6d5aa76b,0x7bcfa686,0x69cea76c,0x27e9a76d}},	//   ngta, licu, cibe, soan_,
   {{0x442716b4,0xb5fba76e,0x26c00634,0x6d5a00c6}},	//   ën_, _spás, azio_, igta,
   {{0x7bcfa76f,0x3ead013c,0x7e62039f,0x00000000}},	//   nicu, yyet_, _oqop, --,
   {{0xe2990f99,0x3cea009f,0x6b7c006e,0x00000000}},	//   рал_, _घुसे_, טראנ, --,
   {{0xa2cd0454,0x7bcfa770,0x3a29022b,0x3eada771}},	//   _देण्, hicu, _mtap_, vyet_,
   {{0xe1f0177a,0x2fcd0364,0x7e62063d,0x7bcf0169}},	//   رسه_, tieg_, _aqop, kicu,
   {{0x6d5aa772,0x69cea773,0xce49036a,0x7bcf008c}},	//   egta, zibe, азие_, jicu,
   {{0x69cea774,0x7bcf1173,0x6286830e,0x2fcda775}},	//   yibe, dicu, _škov, rieg_,
   {{0x69ce3255,0xfc45025b,0xdcf800d9,0x2b4955f5}},	//   xibe, žíme_, _savā, _adac_,
   {{0x3a292a2b,0x2fcd10a4,0xdca5129c,0xa5bb0032}},	//   _atap_, pieg_, цани, _atók,
   {{0x7c2d0b18,0x765603e3,0x7bcfa776,0x6d5a3acc}},	//   _čard, yuyy, gicu, agta,
   {{0x29cd04eb,0x00000000,0x00000000,0x00000000}},	//   ržan_, --, --, --,
   {{0x63b800d9,0x395e058f,0x1d09075f,0x00000000}},	//   īvni, üts_, _кели_, --,
   {{0x3a294cb1,0x7bcfa777,0x673f023b,0xa7aa09b9}},	//   _etap_, bicu, faqj, аква_,
   {{0x69cea778,0xa6db0088,0x7f5b019f,0x260d00c4}},	//   sibe, _meðf, nguq, _užoj_,
   {{0xd5b20037,0x6fde00e8,0x69cea779,0xe9da0ed7}},	// [c140] وفر_, nīca, pibe, _вкп_,
   {{0x6b84007a,0x64577a08,0x26c000e5,0x2ca900b6}},	//   _haig, fuxi, rzio_, _řady_,
   {{0x07a60d47,0x6b9601b3,0x649a0cfc,0x6b84a77a}},	//   _данн, _knyg, штар_, _kaig,
   {{0x77b8002b,0x7afb0034,0x61fd00e8,0x75f00206}},	//   _fíxa, żute, _īsla, väzu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b8402bc,0x7bcfa77b,0x236d0090,0x28cf0285}},	//   _laig, zicu, _ebej_, _हेडि,
   {{0x2d85a77c,0x29cd00e7,0x628f0042,0xdb1d0212}},	//   ddle_, džal_, _ácon, mnsö,
   {{0x4444a77d,0x753c3c94,0x6b84a77e,0x442a00a4}},	//   ms_, _herz, _naig, _itb_,
   {{0x764474a1,0x7bcf03a9,0xdb0da77f,0x63a2a780}},	//   nsiy, vicu, _ilaç, mjon,
   {{0x63a28c3c,0x78a10222,0x3f820244,0x442a0167}},	//   ljon, älvk, žku_, _ktb_,
   {{0x6b84a781,0x3a2901a2,0x753ca782,0x64430094}},	//   _baig, _stap_, _merz, šniv,
   {{0x7644a783,0x63a245e1,0x6b84a287,0x69de07c0}},	//   ksiy, njon, _caig, _ajpe,
   {{0x7bcfa784,0xaac5a785,0x6b84a786,0x4444a787}},	//   ricu, _लेखक, _daig, hs_,
   {{0x4444a788,0x7bcf013d,0x29cd04a3,0x6b84010a}},	//   ks_, sicu, ržao_, _eaig,
   {{0x4444a789,0x6b8410f0,0x97a7106b,0x7bcfa78a}},	//   js_, _faig, орал, picu,
   {{0x6280042d,0x5bc40037,0x6b845e38,0x2e20022b}},	//   _osmo, _يقول, _gaig, _kòf_,
   {{0x4444a78b,0x753c9c75,0x44380150,0xa6db0088}},	// [c150] es_, _berz, _awr_, _meðg,
   {{0x4444a78c,0x67247e8f,0x6b84a78d,0x9f440a7f}},	//   fs_, acij, _zaig, domí_,
   {{0x444424b9,0x753c01bf,0x62800a00,0x442aa78e}},	//   gs_, _derz, _asmo, _ctb_,
   {{0x987a0130,0x63a281cd,0x443800f0,0x656e009c}},	//   _פארט, gjon, _dwr_, _ebbh,
   {{0x44446ecf,0x798508d3,0x442a01e9,0xe6640a52}},	//   as_, _kahw, _etb_, _отро,
   {{0xe7f9007d,0x4444a78f,0x7985a790,0x442aa791}},	//   ंतवा_, bs_, _jahw, _ftb_,
   {{0x4444a792,0x6286a793,0x661d0939,0xc5f200a1}},	//   cs_, _škot, _husk, _נדל_,
   {{0x661502a7,0xb4d7152c,0x63a200a5,0x661da794}},	//   _hizk, ापी_, cjon, _kusk,
   {{0x63bb4189,0xd14b0688,0x661da795,0xd2510e25}},	//   _ilun, _نشان_, _jusk, _سنا_,
   {{0x6b84713d,0x6b960222,0x7bcda796,0x63a9057a}},	//   _saig, _snyg, _amau, _hoen,
   {{0x6b84007a,0x752501bf,0x98b800d9,0x6445a797}},	//   _paig, ichz, karā_, nshi,
   {{0x2d8303f1,0x6445a798,0x63a900c2,0x76440188}},	//   žje_, ishi, _joen, ysiy,
   {{0xed4e3e0c,0x798502e8,0x63a90185,0x644505ff}},	//   _по_, _bahw, _moen, hshi,
   {{0x63a203e5,0x63bba799,0x764403a3,0x6615a79a}},	//   zjon, _llun, vsiy, _nizk,
   {{0x63bba79b,0x6d41a79c,0x6b84a79d,0x63a20072}},	//   _olun, mala, _taig, yjon,
   {{0x6d41a79e,0x7644a79f,0x444457bc,0x661d0429}},	//   lala, tsiy, vs_, _busk,
   {{0x4444a7a0,0x661502a7,0xe7370084,0x442a2f22}},	// [c160] ws_, _bizk, яет_, _stb_,
   {{0x6d411c04,0x63bba7a1,0x7644a7a2,0x44380d19}},	//   nala, _alun, rsiy, _pwr_,
   {{0x4444a7a3,0x661d786f,0x753ca7a4,0x764401d4}},	//   us_, _eusk, _verz, ssiy,
   {{0x6d41a7a5,0x661d1114,0x7644a7a6,0xae1b009f}},	//   hala, _fusk, psiy, नदान_,
   {{0x4444a7a7,0x753ca7a8,0x63a9a7a9,0x63a2a7aa}},	//   ss_, _terz, _doen, rjon,
   {{0x63a2a7ab,0x6d410f8b,0x63bba7ac,0x7af600c2}},	//   sjon, jala, _elun, _myyt,
   {{0x6d41a7ad,0x44447a26,0xa5bb0139,0x3c210088}},	//   dala, qs_, _atów, _nóv_,
   {{0x7ae40072,0x661501e9,0x63a90634,0x63bb0312}},	//   _oxit, _zizk, _goen, _glun,
   {{0x7ae4023b,0xa5bb0af0,0x661d0188,0x6d4a01ff}},	//   _nxit, _awóy, _xusk, _pdfa,
   {{0xfe6f2ba0,0xf1b914f3,0x63a901c0,0x6ce60138}},	//   ادي_, _puše_, _zoen, зіме,
   {{0x7ae40042,0x213e01ec,0x7985001c,0x00000000}},	//   _axit, _ieth_, _rahw, --,
   {{0x7985a7ae,0x9f5d0065,0x69dca7af,0xb09b0289}},	//   _sahw, _diwó_, enre, _ליבר,
   {{0x6d41a7b0,0xe61f00de,0x201e0027,0xf0b00018}},	//   bala, _trôi_, _huti_, _سیکھ,
   {{0x201ea7b1,0x6445a7b2,0x291a00dc,0x673da7b3}},	//   _kuti_, yshi, _cgpa_, _sesj,
   {{0x661da7b4,0x213e22d4,0x7ae43198,0x6615171d}},	//   _susk, _meth_, _exit, _rizk,
   {{0x201ea7b5,0x213e0013,0x77b80042,0x22465511}},	//   _muti_, _leth_, _díxo, ksok_,
   {{0x25aa02ad,0x6445a7b6,0x201ea7b7,0x6615649a}},	// [c170] _bobl_, wshi, _luti_, _pizk,
   {{0x64450201,0x63bb030b,0x77b803be,0x63a97c85}},	//   tshi, _slun, _fíxo, _soen,
   {{0x63a92feb,0x63bba7b8,0xb4d702d5,0x75250364}},	//   _poen, _plun, ापे_, rchz,
   {{0x6d41a7b9,0x661da7ba,0x7bdda7bb,0x6445a7bc}},	//   zala, _tusk, nnsu, rshi,
   {{0x6d41a200,0x213e02ad,0x628606e6,0x6445a7bd}},	//   yala, _beth_, _škor, sshi,
   {{0x63a904ee,0x6443a7be,0x201ea7bf,0x29cd02ef}},	//   _woen, ánis, _buti_, džak_,
   {{0x6d41a7c0,0x63a90305,0x201ea7c1,0x213ea7c2}},	//   vala, _toen, _cuti_, _deth_,
   {{0x6d41a7c3,0x201e491a,0x98b800d3,0x63bb74b5}},	//   wala, _duti_, lară_, _ulun,
   {{0x6d41a7c4,0x3f860ea4,0xaca30174,0x22460103}},	//   tala, _daou_, plịm, csok_,
   {{0xe2900602,0x98b800ae,0x0c2500d3,0x77f90034}},	//   _حذف_, nară_, ммон, ंतुक_,
   {{0x7af60084,0x61e40076,0x201e35c3,0x00000000}},	//   _syyt, éile, _guti_, --,
   {{0x6d4137a6,0x333f04ea,0x6015013f,0x7af600c2}},	//   sala, _jeux_, _išmo, _pyyt,
   {{0x6d41822d,0x201e00cc,0x00000000,0x00000000}},	//   pala, _zuti_, --, --,
   {{0x6d41a7c5,0xe61f0220,0xe81f009f,0x321f037a}},	//   qala, _osôb_, _मंशा_, _muuy_,
   {{0x7e69a7c6,0x6443044c,0x00000000,0x00000000}},	//   ltep, ânil, --, --,
   {{0x9b4600cd,0x7af600c2,0x7a370294,0x7ae401c8}},	//   _کنکو, _tyyt, ụtag, _txit,
   {{0x2d87a7c7,0x25aa02ad,0x99e600c2,0xa2cd0fef}},	// [c180] _kane_, _pobl_, _ожид, _देल्,
   {{0x2d872db0,0x6e2d0233,0xdb04009c,0x98b8044c}},	//   _jane_, _çabu, _fliò, gară_,
   {{0x2d87a7c8,0x48060379,0x27180134,0x999b00ca}},	//   _mane_, _опов, _ọnu_, _וביט,
   {{0x333f025a,0xf626016c,0x201e1ee5,0x3205a7c9}},	//   _ceux_, _одмо, _ruti_, _ahly_,
   {{0x333f04ea,0x213e0150,0x25aa00e7,0x201e0aa9}},	//   _deux_, _peth_, _tobl_, _suti_,
   {{0x201e2839,0x2d87a401,0x3a200063,0xd12f08ba}},	//   _puti_, _nane_, _muip_, لمه_,
   {{0x232a00d6,0x333f00fd,0x3f86022b,0x00000000}},	//   _мови_, _feux_, _paou_, --,
   {{0x7e6901ce,0x2d87a079,0x00000000,0x00000000}},	//   ftep, _aane_, --, --,
   {{0x8e143b2f,0x2d87740f,0x7c2d01ac,0x7e690a9f}},	//   ндиц, _bane_, _čara, gtep,
   {{0x2d87a7ca,0x201ea7cb,0x00000000,0x00000000}},	//   _cane_, _tuti_, --, --,
   {{0x333f0257,0x2d875878,0x2cb8a7cc,0x6143192f}},	//   _yeux_, _dane_, árd_, _реха,
   {{0xdb0424c7,0xbb9400c2,0x2b400e8b,0x00000000}},	//   _aliñ, вающ, _ceic_, --,
   {{0xc333040a,0x3a20009c,0x98ba022b,0xbda60037}},	//   כור_, _cuip_, _depč_, _يحتو,
   {{0x2d87006d,0xdb1d09a1,0x00000000,0x00000000}},	//   _gane_, lisü, --, --,
   {{0x2006a7cd,0x98b8020a,0x9cf4004d,0x2b404d2f}},	//   _khoi_, vară_, _язкі, _feic_,
   {{0x2d87a7ce,0x64430131,0xdb1d00bc,0xde8800fe}},	//   _zane_, ânim, nisü, _kị_,
   {{0x28cf000d,0xde880174,0x98b800d3,0x443f0220}},	// [c190] _हेरि, _jị_, tară_, _ňu_,
   {{0xde8800fe,0x00000000,0x00000000,0x00000000}},	//   _mị_, --, --, --,
   {{0x333f025a,0x600522a6,0x81e40081,0xdb04a7cf}},	//   _peux_, lóme, নতা_, _goiâ,
   {{0x69d5078c,0xa5bb0af0,0x98b800ae,0x2b4000b3}},	//   lize, _atót, sară_, _xeic_,
   {{0x333f025a,0x600504d8,0x9ad30174,0x7e69a7d0}},	//   _veux_, nóme, sịfa, xtep,
   {{0x69d5a7d1,0x663a0142,0x00000000,0x00000000}},	//   nize, _מעשׂ, --, --,
   {{0x6f020027,0x1fb500d3,0x00000000,0x00000000}},	//   _azoc, еспр, --, --,
   {{0xde8800ef,0xc91802f8,0x2d87a7d2,0x7e69743f}},	//   _bị_, וחות_, _sane_, ttep,
   {{0x2d87a7d3,0x3eb95d1b,0xc175013d,0x2a69023e}},	//   _pane_, ást_, _плащ, _nqab_,
   {{0xde8838cd,0x69d50e94,0x2b402e6a,0x2d87013c}},	//   _dị_, jize, _seic_, _qane_,
   {{0x6f02181e,0xc5f2040a,0xf1b90d62,0x2d87a7d4}},	//   _ezoc, רדי_, _guša_, _vane_,
   {{0x2d87006d,0x00000000,0x00000000,0x00000000}},	//   _wane_, --, --, --,
   {{0xde8838cd,0x2d87a7d5,0x69d50103,0x2b4001d3}},	//   _gị_, _tane_, fize, _veic_,
   {{0x69d545a9,0xbed600c1,0x629d014b,0x00000000}},	//   gize, _אונז_, _àsou, --,
   {{0x98b80138,0xa2d60386,0x26fa00a8,0x00000000}},	//   karą_, _मेन्, ्ध्र_, --,
   {{0x200d57b0,0x00000000,0x00000000,0x00000000}},	//   nmei_, --, --, --,
   {{0x69d5398e,0x6005037a,0xaffa006e,0x00000000}},	// [c1a0] bize, cóme, פּלי, --,
   {{0x69d52d43,0x273e00fe,0x00000000,0x00000000}},	//   cize, ắn_, --, --,
   {{0x19b70105,0x7dc400ee,0xf746007b,0xdb1d0231}},	//   _נפטר_, _fòsf, _пено, cisó,
   {{0xd8d700c1,0x753b0095,0x00000000,0x00000000}},	//   _טויט_, _đuze, --, --,
   {{0x200602ad,0xf1b928fc,0x85740018,0x9ad30134}},	//   _rhoi_, _suša_, _لگائ, rịga,
   {{0x27e03f1b,0x7c2da7d6,0x00000000,0x00000000}},	//   lnin_, _čarn, --, --,
   {{0x27e023a4,0xc5ec1b79,0x64580161,0x6f020103}},	//   onin_, जकीय_, ávid, _szoc,
   {{0xb4ac1349,0x27e0a7d7,0x645ea7d8,0x657ea7d9}},	//   गही_, nnin_, mupi, leph,
   {{0x645e8369,0x69d50193,0x27e0a7da,0x00000000}},	//   lupi, yize, inin_, --,
   {{0xde880028,0x657ea7db,0x6282112f,0x27e023a4}},	//   _vị_, neph, mwoo, hnin_,
   {{0xa5bb0d1b,0xa6db0102,0x645e5b42,0x200600de}},	//   _któr, _meða, nupi, _thoi_,
   {{0x6282a7dc,0x20552cbf,0xdb1d0161,0x657e019f}},	//   owoo, _штур, visó, heph,
   {{0x27e01eda,0x628203ee,0xfbdf016d,0x657e2b43}},	//   dnin_, nwoo, rnê_, keph,
   {{0xa6db0088,0xc98440c9,0x60050328,0x3c5800ae}},	//   _neða, луси, róme, _жикэ_,
   {{0xf80772bd,0x657e08f0,0x645ea7dd,0x27e001cd}},	//   ечан, deph, jupi, fnin_,
   {{0x27e004c8,0x3cfb00a1,0x645ea7de,0x62828413}},	//   gnin_, _מלונ, dupi, kwoo,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [c1b0] --, --, --, --,
   {{0xa5bb0139,0xdb1d0034,0x78a10212,0x2d8c029a}},	//   _atór, pisó, älvs, ndde_,
   {{0x6e221a28,0x645ea7df,0x2d8c004d,0x00000000}},	//   _luob, gupi, idde_, --,
   {{0x62820126,0x62353490,0x7f420231,0x00000000}},	//   fwoo, веду, _neoq, --,
   {{0x6282040c,0xaab3397e,0xdd010234,0x6e2200c6}},	//   gwoo, ुनिक, _čuča, _nuob,
   {{0x98b80138,0xe2960aec,0xe7fb00b6,0x2d8c0381}},	//   sarą_, таш_, ्षका_, jdde_,
   {{0x4425002d,0xdcf800c6,0x645ea7e0,0x00000000}},	//   _îl_, _tavę, cupi, --,
   {{0x889c00c1,0x02d20789,0x2d9c0154,0x4431a7e1}},	//   לבוי, _देवभ, _anve_, _itz_,
   {{0x200d00d3,0x26c90051,0x44312bcb,0x5274001c}},	//   rmei_, nzao_, _htz_, _مالز,
   {{0x442301bb,0x64580138,0x6e2200c6,0x2d957014}},	//   _kuj_, švie, _duob, трис,
   {{0x27e07f43,0x44239e32,0x27f201c2,0x274600c6}},	//   ynin_, _juj_, yoyn_, lūnų_,
   {{0x4423a7e2,0x2d9c9c4f,0x2d8c0172,0x224900c4}},	//   _muj_, _enve_, adde_, šaku_,
   {{0xf4120130,0x4423022e,0x2e470139,0x27e00141}},	//   יפט_, _luj_, _dìfá_, vnin_,
   {{0xaf0400d6,0x44311b03,0xddc202c6,0x3f8d00b3}},	//   _спіл, _otz_, _zpož, ldeu_,
   {{0xd9430950,0x44230197,0x186709b9,0x3f9d0381}},	//   реси, _nuj_, кари_, _knwu_,
   {{0x6d434c43,0x3f8d0bfe,0x27e0a7e3,0xc0520266}},	//   _hena, ndeu_, unin_, יזל_,
   {{0x6d433e83,0x27e0a7e4,0x4423646c,0x0566013d}},	// [c1c0] _kena, rnin_, _auj_, кван,
   {{0xa5bba7e5,0x6d4303ec,0x27ed3e75,0x645e36dd}},	//   _stór, _jena, čena_, tupi,
   {{0x6d4326f7,0x4423a7e6,0x224d06a3,0x3f9d0134}},	//   _mena, _cuj_, _avek_, _onwu_,
   {{0x628215b9,0x4423023e,0x657ea7e7,0x7c2301b9}},	//   twoo, _duj_, seph, _munr,
   {{0x02d2000c,0x2d8c00f3,0x27460138,0x0ed00f42}},	//   _देशभ, ydde_, gūnų_, _तेंड,
   {{0x62820f89,0x3f9d0134,0x657e0415,0xf1b95b37}},	//   rwoo, _anwu_, qeph, _dušo_,
   {{0x64a31361,0x04432f24,0x62821cab,0x442303a9}},	//   _кара, _весн, swoo, _guj_,
   {{0x6282030a,0xfff80504,0xa85700ca,0x291e0233}},	//   pwoo, رکات_, דיקה_, ıtay_,
   {{0x6d43a7e8,0x661ca7e9,0x4423006c,0x6fde01d3}},	//   _bena, _kirk, _zuj_, nīci,
   {{0x6d43a7ea,0x68e9002d,0x661ca7eb,0x3f9d0174}},	//   _cena, şedi, _jirk, _enwu_,
   {{0x6d434653,0x23b60006,0x4423023e,0x224d02ef}},	//   _dena, _अकाद, _xuj_, _zvek_,
   {{0x799e05aa,0x7c230139,0xdcf802c6,0xab5b042c}},	//   _anpw, _dunr, _zavě, chül,
   {{0xdfcf3345,0x7c230085,0x7dc401b9,0xdce100c6}},	//   _بين_, _eunr, _pòsd, kelė,
   {{0x6d43a7ec,0x7c23026e,0x661c0821,0x6fde01d3}},	//   _gena, _funr, _nirk, dīci,
   {{0x7e601ca0,0x8a1800d3,0x29050f63,0xdce10138}},	//   lump, торс_, åla_, delė,
   {{0xa5bb08a8,0x4423a7ed,0x6d43a7ee,0x661c009c}},	//   _atóp, _ruj_, _zena, _airk,
   {{0x387a0027,0x644e0b85,0x55751da9,0x6b9f039f}},	// [c1d0] _eppr_, _avbi, лгат, _inqg,
   {{0x6b8d63ab,0x6d43009e,0x442301fa,0x27460138}},	//   _haag, _xena, _puj_, vūnų_,
   {{0x6b8d3b2e,0x661ca7ef,0x7e6008dd,0x67d52383}},	//   _kaag, _dirk, hump, _бону,
   {{0xa3cd0034,0x69c700f2,0x6b8d5d92,0x443100c4}},	//   षों_, lhje, _jaag, _vtz_,
   {{0x6d48a7f0,0x7e6096aa,0xa2cd030b,0x661c557c}},	//   kada, jump, _देख्, _firk,
   {{0x4423a7f1,0x6b8d7d74,0x661c5fe4,0x764da7f2}},	//   _tuj_, _laag, _girk, msay,
   {{0x6adf07e2,0x44310062,0xab5b042c,0x00000000}},	//   नपुर, _utz_, thül, --,
   {{0x6d435dba,0x661c7b2d,0x6b8da7f3,0x224d0062}},	//   _sena, _zirk, _naag, _tvek_,
   {{0x224d1386,0x3f8d2b2a,0x6d48a7f4,0x7e606344}},	//   _uvek_, rdeu_, fada, gump,
   {{0x6289a7f5,0x3f8d54c1,0xa1941894,0x00000000}},	//   _iseo, sdeu_, _кауч, --,
   {{0x69c701e5,0x6b8d0517,0x6fde01d3,0xcb6a20f9}},	//   dhje, _baag, zīci, нане_,
   {{0x4e95006f,0x6d436581,0x764da7f6,0x7e600372}},	//   _مشتر, _wena, ksay, bump,
   {{0x6d432d96,0xee2e1ae2,0x6d48a7f7,0x7e6004d8}},	//   _tena, _ын_, bada, cump,
   {{0x7bc601e5,0x6d430ece,0xdb040231,0x29cd0144}},	//   shku, _uena, _loiç, džas_,
   {{0xc8b50138,0x6b8d6dd3,0xbca80037,0x29cd00e8}},	//   асты, _faag, _لديك_, ežas_,
   {{0x6b8d787e,0xd24501f9,0xab66125c,0x00000000}},	//   _gaag, _وچ_, _свил, --,
   {{0x661c11c2,0x764d0fa0,0x7bc41093,0xdce10138}},	// [c1e0] _pirk, gsay, _iliu, telė,
   {{0x598641c0,0xf9925c4d,0x6b8d9207,0x64a63a62}},	//   _слоб, _طبخ_, _zaag, лаза,
   {{0x661c7f1d,0x29cd0268,0x5a1700ca,0x62890328}},	//   _virk, ržat_, _תקין_, _aseo,
   {{0x661c02dc,0x6d480b0b,0x926a455b,0x929d00a5}},	//   _wirk, zada, ерка_, _czło,
   {{0x6d48486a,0xbb3b0266,0xe297947a,0x7bc49fc9}},	//   yada, געני, лац_, _mliu,
   {{0x7bc40472,0x6d487653,0x644e00e7,0xa6db003e}},	//   _lliu, xada, _tvbi, _meðl,
   {{0x7bc4755b,0x65c3a7f8,0xa5070e05,0x6289039f}},	//   _oliu, _убра, _бера_, _eseo,
   {{0x6d48a7f9,0x60054c36,0x68150034,0xdfd002fc}},	//   wada, tóma, _sądz, تيب_,
   {{0x6d48284f,0xda040096,0x6b8d0188,0x394aa7fa}},	//   tada, ळतात_, _raag, kabs_,
   {{0x7bc4a7fb,0x6b8da7fc,0xc27b006e,0x7bd606b0}},	//   _aliu, _saag, _ארמי, _amyu,
   {{0x7e60a7fd,0x6b8d1098,0x7bc4a7fe,0x61fa01ff}},	//   sump, _paag, _bliu, _iktl,
   {{0x764d0256,0x7e605903,0x7bc401ec,0x629d002b}},	//   ysay, pump, _cliu, _ásoc,
   {{0x6d48a7ff,0x8f9b00f5,0x7bc401b9,0x69c75458}},	//   pada, _רידי, _dliu, thje,
   {{0x6b8da800,0x6d48a801,0x7bd60172,0x7bc418fd}},	//   _waag, qada, _emyu, _eliu,
   {{0x6b8d0694,0x4dfb0054,0x7bc40527,0x69c7a802}},	//   _taag, _רפוא, _fliu, rhje,
   {{0x69c700dd,0x764d1114,0xdc9b00a1,0x8aa72813}},	//   shje, tsay, _טיול, _брод,
   {{0x2d8ea803,0xdb1d00e3,0xb4bd030b,0x672d44a2}},	// [c1f0] _kafe_, bhsá, इन्_, rcaj,
   {{0x9967113f,0xb8db0081,0x29cd12b8,0x764da084}},	//   _стил, _আই_, ržas_, rsay,
   {{0xb60400a9,0x2d8e03e3,0x764d96df,0x62890063}},	//   сятк, _mafe_, ssay, _sseo,
   {{0x321e0154,0x61fa013c,0x64580206,0x764d0233}},	//   _aity_, _aktl, ávia, psay,
   {{0x21690cf5,0x60150357,0x201d0113,0xe1f1450f}},	//   вили_, _ušmi, _riwi_, يست_,
   {{0x321ea804,0x20554444,0xdce801d3,0x2d8e0172}},	//   _city_, атир, nedē, _nafe_,
   {{0x24980072,0xdb1d00aa,0xd6c70033,0x00000000}},	//   _grrm_, misõ, _এশিয, --,
   {{0xdb1d00bc,0xa2460103,0x00000000,0x00000000}},	//   lisõ, _چینل_, --, --,
   {{0xdee53457,0xe3b0048f,0x200300d9,0x69c50161}},	//   ропи, _عرف_, ēji_, _olhe,
   {{0x201d283d,0x7bc800d9,0x2d8e51e4,0x00000000}},	//   _wiwi_, ījum, _cafe_, --,
   {{0x7bc40138,0x2d8e5ce9,0xa6db003e,0x201da805}},	//   _pliu, _dafe_, _seðl, _tiwi_,
   {{0x69c5a806,0x00000000,0x00000000,0x00000000}},	//   _alhe, --, --, --,
   {{0x6da508f9,0x2ba80d61,0x69a20d7e,0x2d8e0231}},	//   _вила, गाबा, खाली, _fafe_,
   {{0x8cb50020,0xed590647,0x3f8fa807,0x69c501b9}},	//   _всич, _рок_, _hagu_, _clhe,
   {{0x7aed001f,0x4dda00ca,0x7bd6010a,0x15f403b3}},	//   _exat, _בחסו, _tmyu, अवसर_,
   {{0x69c50103,0x3f8f00bc,0xfaff0052,0x7dc401b9}},	//   _elhe, _jagu_, rfër_, _iòsa,
   {{0x2d8e0d2a,0x3f8fa808,0x7aed039f,0xf1c500a4}},	// [c200] _yafe_, _magu_, _gxat, वसान,
   {{0x399a07a6,0x3f8fa809,0x8af001d4,0x7dc4022b}},	//   _ייִד, _lagu_, _edəc, _kòsa,
   {{0x03260eec,0x98a633d0,0xfaff0052,0x546a163d}},	//   аден, _тине, ngën_, таем_,
   {{0x69dca80a,0x3f8f7bf5,0x7dc401b9,0x78a800bc}},	//   lire, _nagu_, _mòsa, ädvu,
   {{0x69dc00e3,0x0cc100c3,0x6fa9136b,0x23660216}},	//   oire, शनुम, कानं, rgoj_,
   {{0x69dca80b,0xf50a333f,0xdb1d2226,0x51f704a1}},	//   nire, _англ_, cisõ, анію_,
   {{0x25f52b8a,0x3f8f00f9,0x7dc401f7,0x741600d1}},	//   ्तरी_, _bagu_, _nòsa, _نوسا,
   {{0x69dca80c,0x443aa80d,0xf1b8009e,0x2d8e4b88}},	//   hire, mpp_, _diġa_, _safe_,
   {{0x69dca80e,0x3f8f02e7,0x317a09b4,0x9df80b91}},	//   kire, _dagu_, _لحاظ_, лнит_,
   {{0x69dca80f,0x2d8e0052,0x00000000,0x00000000}},	//   jire, _qafe_, --, --,
   {{0x30860391,0x6adf16f8,0x60050610,0x69dc091a}},	//   _خلاف, नप्र, cómo, dire,
   {{0x6fb30037,0x98a3007f,0x2d8e563a,0x00000000}},	//   _وملا, ncją_, _wafe_, --,
   {{0x69dca810,0x9b58013d,0x2fc60bb6,0x2d8e0d2a}},	//   fire, шият_, _ilog_, _tafe_,
   {{0x69dca811,0x645e7a52,0x00000000,0x00000000}},	//   gire, krpi, --, --,
   {{0x2ee80081,0xed57372d,0xdb1d0161,0x98170037}},	//   _পরিষ, _тој_, visõ, لبرا,
   {{0x3f84a812,0x69dca813,0x61f804e9,0x97a4002d}},	//   nemu_, aire, hovl, орул,
   {{0x69dca814,0x61f80335,0x7c2d09ac,0x3b0900a7}},	// [c210] bire, kovl, _čari, _uzaq_,
   {{0x3f84068d,0x7bdd4dba,0x27070861,0x69dca815}},	//   hemu_, lisu, _शरीर_, cire,
   {{0x442700ef,0xe4750303,0x3f84a816,0x61f8a817}},	//   ên_, слењ, kemu_, dovl,
   {{0x889a028c,0xb9280174,0xdb1d00bc,0xeb9f0537}},	//   _עברי, kwuọ_, sisõ, lløb_,
   {{0x3f8f5a01,0x3f845b33,0x2bba009f,0xddc900ae}},	//   _ragu_, demu_, _उकसा, nteţ,
   {{0x2b492dd0,0x2fc60270,0x61f80995,0x7bdd9b07}},	//   _leac_, _alog_, govl, hisu,
   {{0x2fc632b8,0x7bdda818,0x3a29005c,0x3f8fa819}},	//   _blog_, kisu, _luap_, _pagu_,
   {{0xdce10029,0xf1d92647,0x2fc6a81a,0x3f84a81b}},	//   selī, _भगवन, _clog_, gemu_,
   {{0xef1902fd,0x5fa90034,0x69dca81c,0x929d0034}},	//   ыми_, काबल, yire, _byłe,
   {{0x69dc002b,0x3f8f03a9,0x7dc4a81d,0x00000000}},	//   xire, _wagu_, _pòsa, --,
   {{0xc8d602d5,0x2fc6a81e,0x3f8400c4,0x409500d1}},	//   _डेंट, _flog_, bemu_, _دلار,
   {{0x7bdda81f,0x69dca820,0x3f84a821,0x3a29034f}},	//   gisu, wire, cemu_, _buap_,
   {{0x3a290085,0x69dca822,0x37cd0033,0x3ea9173c}},	//   _cuap_, tire, রচার, _çat_,
   {{0x6e3ba823,0xfe70001c,0x29010063,0x00000000}},	//   mpub, _زده_, _byha_, --,
   {{0x2d85a824,0xa3e7009d,0x69dc2a9a,0x07a6249b}},	//   mele_, यचा_, rire, бавн,
   {{0x2d85a825,0x0b46007e,0x236d022e,0x2cb80149}},	//   lele_, _унин, _ncej_, ärde_,
   {{0xb8ff245a,0xbb3b0130,0x6e3ba826,0x2c710103}},	// [c220] _दे_, _געפי, npub, lád_,
   {{0x2d85a827,0x9986054f,0x3f845b31,0xa2b802d5}},	//   nele_, _الدو, zemu_, ्नस्,
   {{0xf1b90995,0xe45a0cc5,0x2d85020a,0x61f800d4}},	//   _guši_, уже_, iele_, vovl,
   {{0x2d85a828,0xdcfa020a,0x443a2b58,0xddc202c6}},	//   hele_, letă, rpp_, _dvoř,
   {{0x2d85a829,0x61f80087,0x02d20f35,0x3f841420}},	//   kele_, tovl, _देखभ, vemu_,
   {{0x2d85a82a,0x2fc6a82b,0x7bdd2e60,0x64a61603}},	//   jele_, _slog_, zisu, _лага,
   {{0x2d85a82c,0xd010029e,0x61f8a82d,0x3f849a26}},	//   dele_, ولت_, rovl, temu_,
   {{0x9a2900fe,0x2d8518f0,0x00000000,0x00000000}},	//   _lươn_, eele_, --, --,
   {{0x7bdd08a0,0x25ef0b89,0x61f81197,0xe2974906}},	//   visu, _आदमी_, povl, _лат_,
   {{0x442a0197,0x7bdd05bd,0x44380090,0x2b4901b9}},	//   _kub_, wisu, _ktr_, _seac_,
   {{0xfe6f1e49,0x3a2909a4,0xb5fb00c1,0x3f840167}},	//   ودی_, _suap_, רליכ, pemu_,
   {{0xdb0d0088,0x442a4cd4,0x2fc61197,0xf1b90335}},	//   _blað, _mub_, _ulog_, _ruši_,
   {{0x442aa82e,0x2d85a82f,0x15fa417a,0x7bdda830}},	//   _lub_, bele_, ्तार_, risu,
   {{0xf2d30130,0x2d85a831,0x44380085,0x6ca614e4}},	//   לער_, cele_, _otr_, _гриж,
   {{0x442a01fa,0xeb9f052f,0x4438a832,0x0bd50037}},	//   _nub_, rløb_, _ntr_, _ويتح,
   {{0x7bdd0090,0x603101d3,0x628002ac,0x59a700b6}},	//   qisu, _jāma, _opmo, खाहर,
   {{0x442aa833,0x6d4aa834,0x95d90832,0x78c6015c}},	// [c230] _aub_, _kefa, адат_, _čuvš,
   {{0x7c2a35c2,0x6d4a5e4e,0xfbdf016d,0xf1b90141}},	//   _kufr, _jefa, liê_, _tuši_,
   {{0xd49b00c6,0x7c2a1d49,0x62800138,0x7d7b0266}},	//   ыра_, _jufr, _apmo, רנבו,
   {{0x442aa835,0x2d85a836,0x1ab00081,0x78a80727}},	//   _dub_, zele_, _চেয়া, ådve,
   {{0x2d8540fa,0x27e9295d,0x6d580d94,0x6f0200ac}},	//   yele_, mnan_, _odva, _nyoc,
   {{0x867a0089,0xddc200b6,0x2d854a39,0x7c38031a}},	//   _דרשו, _tvoř, xele_, _otvr,
   {{0x2d85a837,0x3dce0081,0x27e97e02,0x442aa838}},	//   vele_, িচাল, onan_, _gub_,
   {{0x27e9a839,0xdbf2033a,0x2d859c10,0x6d5826a4}},	//   nnan_, _přís, wele_, _adva,
   {{0x2d85a83a,0x27e9048e,0x6d4aa83b,0x7c2a01bf}},	//   tele_, inan_, _befa, _aufr,
   {{0x6d4aa83c,0x6e3b01d3,0x798702a4,0x7c2a0b58}},	//   _cefa, rpub, jejw, _bufr,
   {{0x6d4aa83d,0x6e3ba83e,0x2d85a83f,0x1d091121}},	//   _defa, spub, rele_, рени_,
   {{0x2d85a840,0x6d58a841,0xd9b40179,0x2c71a842}},	//   sele_, _edva, ुस्ट, rád_,
   {{0xeb9707f4,0x4a43582a,0x8af00092,0x27e901af}},	//   ция_, мняв, _edən, dnan_,
   {{0x8c452de0,0x6d4aa843,0x7b3e0034,0xfeb85f34}},	//   _деке, _gefa, dłuż, _دامت_,
   {{0x6d41a844,0xab5b0740,0x290c0ec9,0x9a290023}},	//   mbla, mkün, åda_, _vươn_,
   {{0x442a3595,0x27e98e9c,0x29040029,0x6d4aa845}},	//   _rub_, gnan_, āma_, _zefa,
   {{0x3ebf0d17,0x7c2a031f,0x6d410441,0x44386b54}},	// [c240] nyut_, _zufr, obla, _str_,
   {{0x442a0197,0x7c242bc4,0x27e99f30,0x7d038832}},	//   _pub_, _hiir, anan_, _kyns,
   {{0x7c240837,0x442a0197,0x6e23a846,0x98a30034}},	//   _kiir, _qub_, _minb, kcję_,
   {{0x13068a2f,0x395a00f9,0x3ebf0270,0x6e23a847}},	//   озем, _hdps_, kyut_, _linb,
   {{0xc7b309c1,0x7c240d79,0x6d41a848,0x27e00878}},	//   _חבר_, _miir, kbla, miin_,
   {{0x442aa849,0x1a9b0130,0x4a9b00c1,0x27e0a84a}},	//   _tub_, יינע, יינג, liin_,
   {{0x61eda84b,0x6d4aa84c,0x21670831,0x3160026a}},	//   éala, _refa, цији_, ğiz_,
   {{0x6d410a43,0x6e2ba84d,0x27e0a84e,0xb60200b6}},	//   ebla, _bugb, niin_, řáda,
   {{0x7c2a0951,0x44241c3d,0x3f9800b6,0xa5bb0065}},	//   _sufr, _iim_, ěru_, _atóy,
   {{0x27e0025e,0x6d410ac9,0x27e9a84f,0x442400a1}},	//   hiin_, gbla, znan_, _him_,
   {{0x27e0897d,0x7c24008a,0x6e23a850,0x4424a851}},	//   kiin_, _biir, _dinb, _kim_,
   {{0x6d4a02ad,0x6e2379ce,0xddc9020a,0xa067002d}},	//   _wefa, _einb, preş, _фаца_,
   {{0x4424a852,0x6d41a853,0x7c242592,0x27e0a854}},	//   _mim_, bbla, _diir, diin_,
   {{0x4424a855,0x6d58a856,0x69ce22d4,0x7d0302ce}},	//   _lim_, _udva, ghbe, _fyns,
   {{0x7c3802e6,0x61fd0682,0x27e0a857,0x7c24008a}},	//   _utvr, _ísle, fiin_, _fiir,
   {{0x44249fbd,0x395a02a1,0x27e0a858,0x61ea0364}},	//   _nim_, _edps_, giin_, hnfl,
   {{0x27e9a859,0x395a0231,0x7bd60216,0x9f4405b4}},	// [c250] rnan_, _fdps_, ëzue, lomó_,
   {{0xd49b0012,0x27e9a85a,0x69ce23a8,0x645500dc}},	//   ире_, snan_, chbe, _pvzi,
   {{0x27e92e9b,0x27e0a85b,0x7b3e007f,0x681c0154}},	//   pnan_, biin_, służ, _nōdw,
   {{0x44240197,0x78fa00a1,0xab5b0364,0x7c24008c}},	//   _cim_, _לפתו, chüt, _xiir,
   {{0x4424a85c,0x80d30067,0xe2990423,0x6d4100eb}},	//   _dim_, _भेजे, сал_, ybla,
   {{0x6e2ba85d,0x76ba0054,0x30790076,0x00000000}},	//   _rugb, _המשפ, محبة_, --,
   {{0x4424a85e,0x671f0557,0x7dc400ee,0x2458002d}},	//   _fim_, _मृतक_, _còsm, _марь_,
   {{0x6e230634,0xa5bb016d,0xa2d609c4,0x98b414f3}},	//   _sinb, _atóx, _मेक्, žeću_,
   {{0x600511ce,0x72050018,0x7d033502,0x6d4104dc}},	//   nómi, _فورم, _syns, tbla,
   {{0x44242ed1,0xd1b80e25,0x7c24862e,0x6d41a85f}},	//   _zim_, _والا_, _siir, ubla,
   {{0x7c244207,0x442401bb,0x6d4147f5,0xab2a1eac}},	//   _piir, _yim_, rbla, йона_,
   {{0x6d4161a8,0x4424006c,0x6e2ba860,0x395a0095}},	//   sbla, _xim_, _tugb, _sdps_,
   {{0x74c300c7,0x80b10f62,0x27e000c2,0x6e23a861}},	//   ্পিউ, _अपडे, viin_, _tinb,
   {{0x8e0800d6,0xab5b0018,0x7c243560,0xf1b9a862}},	//   _днів_, lkül, _wiir, _gušt_,
   {{0x27e002fd,0x7c2454ab,0x18a3065c,0xc7a61cda}},	//   tiin_, _tiir, нарм, пивк,
   {{0x69ce1a4a,0xd6da00d1,0xa6db01cd,0x00000000}},	//   shbe, موزش_, _leðu, --,
   {{0x27e0a863,0xc0760023,0xab5b0364,0xa3c506eb}},	// [c260] riin_, _bướm_, rhüt, एसई_,
   {{0x4424a864,0x27e0676d,0x1a9b00c1,0x4a9b0089}},	//   _sim_, siin_, _פייע, _פייג,
   {{0xa3e7009d,0x442426c4,0xc32a00e3,0x6b96a865}},	//   यचं_, _pim_, مكان_, _kayg,
   {{0x7c2e0161,0x7bc6a866,0x27e0008c,0x442402a1}},	//   íbri, nkku, qiin_, _qim_,
   {{0x442401bb,0x6d5c0018,0xd0560092,0xf1940686}},	//   _vim_, órak, əcək, диль,
   {{0x1df70b95,0x44240db1,0x6b96008c,0x3ea019db}},	//   ुतोष_, _wim_, _layg, _šito_,
   {{0x4424a867,0x9ad30134,0x00000000,0x00000000}},	//   _tim_, tịka, --, --,
   {{0x672201d3,0x67360034,0x32070034,0xb60202c6}},	//   žoju, ncyj, alny_, žádo,
   {{0x9f5f001f,0x69de80d6,0x00000000,0x00000000}},	//   cluí_, _ompe, --, --,
   {{0x60e70088,0x3eb94249,0x9ad30174,0x9f44037a}},	//   ármá, ästa_, sịka, tomó_,
   {{0x673600a5,0x3157006e,0x00000000,0x00000000}},	//   kcyj, _זיבן_, --, --,
   {{0x69de0a88,0xdb0d0231,0x6b9601ee,0x6fd606cf}},	//   _ampe, _joaç, _cayg, _عزائ,
   {{0x5fa91860,0xada62cc1,0x6b96026d,0x00000000}},	//   कारल, _надл, _dayg, --,
   {{0x64b500b6,0x7bc600ce,0x00000000,0x00000000}},	//   _hřiš, akku, --, --,
   {{0x2905003e,0xa3be00bc,0x64b502c6,0x7dc40154}},	//   æla_, ेसा_, _křiš, _lòsk,
   {{0x69de06b0,0x60053210,0x7bc603bd,0x00000000}},	//   _empe, tómi, ckku, --,
   {{0xe6641d2e,0x66f40a29,0xf1be023a,0x7bcd01ff}},	// [c270] етхо, епту, ्सान, _ilau,
   {{0x7bcda868,0x69de0113,0x6736007f,0x00000000}},	//   _hlau, _gmpe, acyj, --,
   {{0x7bcda869,0x6fe800b6,0x6b96026a,0x32070094}},	//   _klau, pěch, _yayg, vlny_,
   {{0xdfc600e3,0x69c70120,0xdb0d0231,0x28d6097c}},	//   _شي_, lkje, _coaç, _डेटि,
   {{0xdb0d0161,0xd6846d70,0xfe0c009f,0x768400ae}},	//   _doaç, _пурп, हतास_, _пырж,
   {{0x69c700f3,0x27ed0106,0x7bcd5f08,0xc69200ca}},	//   nkje, čenu_, _llau, _שאם_,
   {{0xa6db0088,0x8464008f,0x29380266,0x7bcd0572}},	//   _veðu, _пъте, לאגן_, _olau,
   {{0xee3927c6,0x439400c2,0xa2470018,0x7e690350}},	//   они_, _пасс, _فیصل_, tuep,
   {{0x63a93bb1,0x64dd02d5,0x69c700f3,0xab5b4f4c}},	//   _inen, _मधुश, kkje, rkül,
   {{0xa2b20067,0xf1a42b8a,0x6b9601e8,0x7bcd0138}},	//   _आपत्, _गोपन, _sayg, _alau,
   {{0x7bcd48b0,0x63bb0c56,0x61e3a86a,0x9d0b0081}},	//   _blau, _koun, minl, রশ্ন_,
   {{0x63bb0c56,0x61e3a86b,0x3b0a87d6,0x69c701c0}},	//   _joun, linl, жемо_, ekje,
   {{0x63a90b27,0x7bc60084,0x63bb3ab7,0x7e69a86c}},	//   _mnen, rkku, _moun, quep,
   {{0x7bcd0332,0x61e3a86d,0x63a401d3,0x63bba86e}},	//   _elau, ninl, ķini, _loun,
   {{0x63a97a70,0xabf600a9,0xd7c90bf5,0xe7fa0285}},	//   _onen, _очищ, रसंच, ंवला_,
   {{0x63bba86f,0x7bcd4634,0x63a9a870,0x7bc800e8}},	//   _noun, _glau, _nnen, ījus,
   {{0x61e303a3,0xe7df030b,0xfe79030b,0x8cc50034}},	// [c280] kinl, _नगरप, ntů_, ानको,
   {{0x63a90726,0x044600c2,0x2bcc148e,0x69c70381}},	//   _anen, дежн, ासवा, ckje,
   {{0x61e3a871,0x6d5c0037,0x63bb00ca,0x929d007f}},	//   dinl, órai, _boun, _było,
   {{0x63bb0054,0xfe79000d,0x838300c2,0x3ce000aa}},	//   _coun, ktů_, выше, _ओइसे_,
   {{0x63a900c4,0x61e3a872,0x8c1b0eda,0x00000000}},	//   _dnen, finl, קוני, --,
   {{0x61e30088,0xc0aa029e,0x63a9a873,0xdcf800c6}},	//   ginl, قابل_, _enen, _gavė,
   {{0x63bba874,0xf1b803e5,0x64b5030b,0x9f910139}},	//   _foun, _jiġi_, _přiš, _káè_,
   {{0x63bb0154,0xdb0400b3,0x00000000,0x00000000}},	//   _goun, _joió, --, --,
   {{0xf1b803e5,0x61e3a875,0x00000000,0x00000000}},	//   _liġi_, binl, --, --,
   {{0x7bcd2d41,0x63a90220,0x6005003e,0xab5b09a1}},	//   _slau, _znen, dómu, rküm,
   {{0x7bcda876,0x61fd0682,0xd12f06f6,0x63bba877}},	//   _plau, _ísla, _ضمن_, _youn,
   {{0xaec61a57,0x2014007f,0xf45700ca,0x00000000}},	//   _обел, ócić_, ויטר_, --,
   {{0x501b00c1,0x7bd6023b,0xecde00a4,0x00000000}},	//   _וואו, ëzua, _फेरफ, --,
   {{0x7c66046b,0x7bcd005c,0xc9841e11,0xe807007f}},	//   _قابل, _wlau, куси, _वीजा_,
   {{0x2d8ca878,0x69c700f3,0x80e00033,0x9f8a0065}},	//   mede_, rkje, _পুত্, _kùà_,
   {{0x2d8ca879,0x69c702ec,0x0cca030b,0x7bdf0415}},	//   lede_, skje, ानीम, _umqu,
   {{0x63a9005c,0x7dcd003e,0x63bb7192,0x61e3071d}},	// [c290] _rnen, _húsa, _roun, yinl,
   {{0x2d8ca87a,0xaa8800cd,0x63bb4b72,0x9e7700ca}},	//   nede_, _کنیم_, _soun, וגמה_,
   {{0x5f05000d,0x63bba87b,0x61e3a87c,0x00000000}},	//   _हुन्_, _poun, vinl, --,
   {{0xe6670465,0x2d8ca48a,0x7dcd6d26,0x6f9e0285}},	//   _отго, hede_, _músa, _खोलू,
   {{0xa2af009d,0x61e3a87d,0x2d8c51d6,0xa29400d6}},	//   ंमध्, tinl, kede_, каці,
   {{0x2d8ca87e,0x40950058,0xd2440012,0xaad0023a}},	//   jede_, ерит, тэци, हनतक,
   {{0x63bb0c56,0x2d8ca87f,0x61e3a880,0x00000000}},	//   _toun, dede_, rinl, --,
   {{0x61e30587,0xb4bd1f77,0x63a933ba,0x00000000}},	//   sinl, ेनी_, _unen, --,
   {{0x2ec900e2,0x2d8ca881,0xa3be1024,0x61e3406d}},	//   िनेत, fede_, ेसर_, pinl,
   {{0x2d8ca882,0xc69200a1,0x61e31a4a,0x1c450686}},	//   gede_, נאי_, qinl, нном,
   {{0xfe79030b,0x4431a883,0x2c78231d,0x3b09013c}},	//   stů_, _juz_, géd_, _ayaq_,
   {{0xeb9a1bb8,0x224d8a45,0xfe7902c6,0x7dcd109d}},	//   чим_, _kwek_, ptů_, _dúsa,
   {{0x2d8ca884,0x44310d9f,0x4ae00096,0x5ac74a30}},	//   bede_, _luz_, _पेशव, елям_,
   {{0xf2d207a6,0x2d8ca885,0x3e790c56,0x395e0257}},	//   נעם_, cede_, mèt_, ûts_,
   {{0x3e7902f1,0x3eb500d3,0x4431a886,0x997d01d3}},	//   lèt_, ţetă_, _nuz_, kāņu_,
   {{0xc5fa0c38,0x224d0517,0x7e7b0350,0x00000000}},	//   ्त्य_, _owek_, otup, --,
   {{0x3e790c56,0x6b84a887,0x4431044c,0x00000000}},	// [c2a0] nèt_, _ibig, _auz_, --,
   {{0xf1b803e5,0x24f6002d,0xe4d70103,0x44310847}},	//   _tiġi_, нчер, کومت_, _buz_,
   {{0x224d0332,0x290e0103,0x8ca2007f,0xe73a007e}},	//   _awek_, _áfa_, गियो, _нен_,
   {{0xe9f900ef,0x3e7906a3,0xa6db003e,0x2d8ca888}},	//   _trả_, kèt_, _veðr, zede_,
   {{0xa294116d,0x3d06007a,0x2d8c026a,0x224d0167}},	//   талі, _सुने_, yede_, _cwek_,
   {{0xcb1300c1,0x76445a9d,0x2d8c0537,0x798ea889}},	//   אלד_, mpiy, xede_, nebw,
   {{0x6005003e,0x6b84a88a,0x4fc60636,0x6fde00e8}},	//   jóms, _obig, еспа, lūci,
   {{0xdfd00080,0x2d8c0bb6,0x3e7906a3,0x4444019e}},	//   شيخ_, wede_, fèt_, mp_,
   {{0x2d8c06a7,0x44440f56,0x3ea2003e,0x798e0283}},	//   tede_, lp_, íkt_, kebw,
   {{0x998908a9,0x6b84a88b,0x4444019e,0x44313ed0}},	//   _staž_, _abig, op_, _yuz_,
   {{0x2d8ca88c,0x44440383,0x7e7b0270,0x9f440052}},	//   rede_, np_, atup, nimë_,
   {{0x4444a88d,0x2d8ca88e,0x6aa46afa,0x6fce009c}},	//   ip_, sede_, _brif, _fùca,
   {{0x2d8ca88f,0x44440227,0x6aa4009c,0x7b1e0031}},	//   pede_, hp_, _crif, _náuč,
   {{0x6aa43813,0x6b841cc7,0x7dcd0088,0x7de603a9}},	//   _drif, _ebig, _húsn, _désè,
   {{0x444456a2,0x6a141f0d,0x6aa40361,0x4cde0033}},	//   jp_, умру, _erif, _নুরু,
   {{0x6aa4a890,0x6b840d79,0xc17401c2,0x00000000}},	//   _frif, _gbig, ɗɗe_, --,
   {{0xb9081024,0x645c25f9,0x798e8c18,0x444440e9}},	// [c2b0] _मे_, _avri, bebw, ep_,
   {{0xd0560092,0x6b9d2084,0x4431078e,0x6b84007f}},	//   şbəx, ldsg, _puz_, _zbig,
   {{0xf1b803e5,0xb4bd59f2,0x98b80138,0x89dc0327}},	//   _jiġu_, ेने_, darė_, _מחזי,
   {{0x6b9d26c4,0xf8b60796,0x636b013c,0x00000000}},	//   ndsg, _ספרי_, dönü, --,
   {{0x44447c07,0x6b9d1044,0x075600ca,0x41be0eeb}},	//   ap_, idsg, _בסרט_, ्संस,
   {{0xc0e507f3,0x4431a891,0xeb9f00f3,0xe4532519}},	//   колк, _tuz_, rmøy_, _مضر_,
   {{0x2ec91d7d,0xe1f00192,0xf1b8009e,0x6fce009c}},	//   िन्त, حسن_, _niġu_, _sùca,
   {{0x6445a892,0x3e790c56,0x6b9d8e10,0x5ee20033}},	//   mphi, tèt_, jdsg, _পড়ে,
   {{0x603100d9,0x3f8d0313,0x7e7b024a,0x00000000}},	//   _māmi, reeu_, utup, --,
   {{0x3e790c56,0x7e7ba893,0xe5300092,0x6445a894}},	//   rèt_, rtup, _müğə, ophi,
   {{0xcb6a1441,0xbebd013f,0x644500b3,0x3e793d7f}},	//   мане_, ncūz, nphi, sèt_,
   {{0x6aa440a1,0x798ea895,0xa3d70034,0xdb040062}},	//   _prif, webw, ाफट_, _soiñ,
   {{0x6ec41b49,0xb5fb00d4,0x00000000,0x00000000}},	//   _متوق, _kvád, --, --,
   {{0x200da896,0x44442861,0x27e200ec,0xdce10034}},	//   llei_, yp_, _smkn_, zglę,
   {{0x4444a897,0x6e2d0036,0x2e470065,0xdd8e0037}},	//   xp_, _èabb, _fífò_, _ذوي_,
   {{0xa2b20454,0x6fde01d3,0x3ea000e7,0x7dcd0031}},	//   _आपल्, tūci, _šiti_, _kúso,
   {{0x78a501c5,0x444400dc,0x8c1b00ca,0x7bdd0052}},	// [c2c0] _erhv, wp_, _קופי, ërue,
   {{0x64a634e6,0x08c60dde,0x69d53f15,0x76440270}},	//   каза, _абон, chze, rpiy,
   {{0x44444589,0x200da898,0xe8f700d3,0x62890231}},	//   up_, klei_, _алэ_, _apeo,
   {{0x39580472,0x44441063,0x7dc400ee,0x7e69a899}},	//   lars_, rp_, _hòst, krep,
   {{0x98b80138,0x7dc40154,0xdb1d2271,0x00000000}},	//   tarė_, _kòst, cksä, --,
   {{0x395843ce,0x4444a89a,0x7e69a89b,0xda0209c3}},	//   nars_, pp_, drep, लकित_,
   {{0x645c0268,0x55e308f9,0x6289039f,0x9f4403a9}},	//   _uvri, _торб, _epeo, limé_,
   {{0x28ba09c4,0x27f2a89c,0x6fe70113,0x39580a84}},	//   _उपनि, nnyn_, _rècè, hars_,
   {{0x7e69872c,0xb226013f,0x3958a89d,0x8fa30b1b}},	//   grep, _амал, kars_, рање,
   {{0x224658a3,0x20e3009d,0x71a31807,0x27010023}},	//   mpok_, _केवळ_, _кауз, ỗng_,
   {{0x5fa3007d,0x1da602e8,0x3958410f,0x22460900}},	//   _खोवल, _कोणत, dars_, lpok_,
   {{0x39535257,0x7dcd0e67,0x9f910065,0x7d0a084e}},	//   _sexs_, _húsl, _jáì_, _vyfs,
   {{0x2004006d,0x7dc4009c,0x6b8f00e7,0x6b9d032e}},	//   momi_, _bòst, recg, rdsg,
   {{0x3958a89e,0x3cfd009f,0x2004a89f,0x3c5800d3}},	//   gars_, _रुके_, lomi_, _зикэ_,
   {{0xf807470d,0xd90f00cd,0x98c400c2,0x61eda8a0}},	//   вчан, تید_, астл, éali,
   {{0x2d9ca8a1,0x2004a8a2,0x2618048a,0x2d9e9b88}},	//   _have_, nomi_, _बीबी_, ldte_,
   {{0xa3b604dd,0x2d9ca8a3,0xb4bd0179,0x3d062f8f}},	// [c2d0] जान_, _kave_, ेन्_, _सुते_,
   {{0x2d9e5c05,0x7c2d6040,0x68ee00e3,0x2d9ca8a4}},	//   ndte_, _hiar, ándá, _jave_,
   {{0x7c2d0051,0x6594a8a5,0x2d9c02b6,0x3f8600b6}},	//   _kiar, раху, _mave_, _obou_,
   {{0x2d9ca8a6,0xdb0402a8,0x7c2d05e0,0x2004a8a7}},	//   _lave_, _uniã, _jiar, jomi_,
   {{0x2004129d,0x7c2da8a8,0xb60402c6,0xa1891c0e}},	//   domi_, _miar, _svář, ебла_,
   {{0x3f86a8a9,0x2d9c84d8,0x27e92bd4,0x2d9ea8aa}},	//   _abou_, _nave_, lian_, jdte_,
   {{0x7c2d01e9,0x205401b6,0x7e69033c,0x3169020e}},	//   _oiar, атыр, wrep, ğaz_,
   {{0x7e694bbb,0x3ea65d86,0xd3a44be7,0x2d9e42f2}},	//   trep, _brot_, _круп, edte_,
   {{0x200da8ab,0x51f914fa,0x3ea60085,0xe3b0046b}},	//   rlei_, _знаю_, _crot_, _ظرف_,
   {{0x442da8ac,0xb5fb025b,0xef1600c6,0x27e9159b}},	//   _hie_, _uvád, ымы_, hian_,
   {{0x27e927ca,0x442da8ad,0x7c2da8ae,0x1bea08c3}},	//   kian_, _kie_, _biar, едни_,
   {{0x442d01b3,0x27e91bd6,0x7c2da0a5,0x2004a8af}},	//   _jie_, jian_, _ciar, comi_,
   {{0x27e9a8b0,0x442da8b1,0x660568a8,0xd37a00c1}},	//   dian_, _mie_, kohk, ערשט,
   {{0x2d9ca8b2,0x442da8b3,0x3f9d0372,0x00000000}},	//   _gave_, _lie_, _hawu_, --,
   {{0xa3b6000f,0x27e9a8b4,0x66050808,0x7c2da8b5}},	//   जाम_, fian_, dohk, _fiar,
   {{0x442d0d08,0xb8dc0d1b,0x27e927ca,0x7c2d013d}},	//   _nie_, _आप_, gian_, _giar,
   {{0xe61a04e6,0x39585ae2,0xa3d732c9,0x26c900f9}},	// [c2e0] еда_, pars_, िसन_, gyao_,
   {{0x7c2da8b6,0x2bcc1101,0x27e9061d,0x9f4400fd}},	//   _ziar, ासका, aian_, rimé_,
   {{0x27e96493,0xdd5600c1,0x20040ece,0x442da8b7}},	//   bian_, רבעט_, yomi_, _bie_,
   {{0x7c3ea8b8,0x2ca70b33,0x69ce0313,0x3f9d063d}},	//   _épre, _mrnd_, lkbe, _nawu_,
   {{0x442d02d7,0xa3b60f78,0x799e0bb6,0x66052058}},	//   _die_, जाब_, _kapw, bohk,
   {{0x442d0665,0x69ce833b,0x00000000,0x00000000}},	//   _eie_, nkbe, --, --,
   {{0x442d0012,0x799e0124,0x3f9d1b99,0x00000000}},	//   _fie_, _mapw, _bawu_, --,
   {{0x09d10e52,0xaa860074,0x442d85e8,0x2d9ca8b9}},	//   _हत्य, _zvýš, _gie_, _save_,
   {{0x7c2d0a6c,0x6441023b,0x661c00f9,0x2d9c9dcb}},	//   _riar, _çlir, _khrk, _pave_,
   {{0x442da8ba,0x7c2d0df8,0x200463c1,0x27e93a0d}},	//   _zie_, _siar, somi_, zian_,
   {{0x442d0134,0x645ea8bb,0x3f9d02ac,0xa5b70327}},	//   _yie_, nspi, _fawu_, אליק_,
   {{0xdce303a3,0x61eaa8bc,0x27e9a8bd,0xa3ba17ad}},	//   _canı, lifl, xian_, आउट_,
   {{0xdce30f28,0x7c2da8be,0x2d9c4f1d,0x2b59288f}},	//   _danı, _viar, _tave_, rasc_,
   {{0x27e9a8bf,0xa3ab1488,0x799e0090,0x7c2d0034}},	//   wian_, _कोन_, _capw, _wiar,
   {{0x248d02e6,0x7c2da8c0,0x37ab1719,0x3f9d0022}},	//   _ćemo_, _tiar, нтан_, _yawu_,
   {{0x645ea8c1,0x69ce1cab,0x69c00231,0x00000000}},	//   dspi, akbe, êmer, --,
   {{0x27e927ca,0x442d0294,0x645e3502,0x356b2383}},	// [c2f0] rian_, _rie_, espi, ерен_,
   {{0x442da8c2,0x6d5aa8c3,0x27e92c5c,0x3eb90084}},	//   _sie_, nata, sian_, ästi_,
   {{0xdce30702,0x27e95367,0x442d3f1f,0x7cd300a7}},	//   _yanı, pian_, _pie_, tərə,
   {{0x6d5aa8c4,0xd4980077,0xdce30092,0xa3df0034}},	//   hata, ыру_, _xanı, धों_,
   {{0xe299320c,0x6d5a9450,0x442da8c5,0x49b81e49}},	//   тал_, kata, _vie_, _شاید_,
   {{0x442d0b5e,0x6a6c0088,0x6b9f003d,0x3f9d0a40}},	//   _wie_, _höfð, _laqg, _sawu_,
   {{0x442d118a,0x7d1c0088,0x3f9d010a,0x31580076}},	//   _tie_, ýrsl, _pawu_, اجهة_,
   {{0x442d0313,0x225f0234,0x6b9f02a1,0xbfc5016d}},	//   _uie_, _tvuk_, _naqg, рбик,
   {{0x6d5a318c,0x8db5097a,0x9f980065,0x00000000}},	//   fata, асні, _méè_, --,
   {{0x0d8221f4,0xdce301e8,0x629b07ac,0xd9df0034}},	//   ольн, _sanı, _isuo, नफोट,
   {{0x6fd50072,0x6b9f0078,0x3207a8c6,0x5f95085f}},	//   _cácc, _baqg, mony_, _виет,
   {{0x6d5a0270,0x7dcd50d6,0x3207262a,0x8b26387c}},	//   aata, _kúsk, lony_, идне,
   {{0x6d5a08a7,0x7bdd023b,0xa3b60e19,0x799e47e7}},	//   bata, ërua, जात_, _papw,
   {{0x6d5a6f5e,0x320712b1,0x68466f46,0x9f910065}},	//   cata, nony_, инга, _háà_,
   {{0xdce30390,0x69ce1cab,0xfca80037,0x9f980af0}},	//   _tanı, rkbe, _مايو_, _béè_,
   {{0x32078872,0x6ed51bc3,0x799e0350,0x69ce02c3}},	//   hony_, मैथु, _wapw, skbe,
   {{0x1b0d00c7,0x2b4d08a8,0x32075374,0x8af00092}},	// [c300] সেবে_, ñece_, kony_, _edər,
   {{0x2d855ca6,0x7bc400bc,0x9f910065,0xd9460284}},	//   nfle_, _hoiu, _láà_, _њени,
   {{0x3ea90a39,0x7bc401ff,0x00000000,0x00000000}},	//   _šatl_, _koiu, --, --,
   {{0x6d5aa629,0x9f910649,0x7dcd04c8,0x6e3b0415}},	//   zata, _náà_, _búsk, kqub,
   {{0x3207632d,0x645ea8c7,0x61eaa8c8,0x98b1007f}},	//   fony_, sspi, tifl, rczą_,
   {{0xf8ba09c4,0x64a636bf,0x6abb0364,0x7bc478c2}},	//   _उपाय, _кага, äufi, _loiu,
   {{0x6d5aa8c9,0x61ea5aa0,0x9f910065,0x1bf806eb}},	//   vata, rifl, _báà_, ीवाल_,
   {{0x6d5a9366,0x61eaa8ca,0xbfa700c2,0x443800c4}},	//   wata, sifl, атье_, _iur_,
   {{0x6d5aa8cb,0x44381424,0x3207317d,0xe2974587}},	//   tata, _hur_, bony_, _кат_,
   {{0x4438a8cc,0x63a0a8cd,0x61ed00e3,0x62820313}},	//   _kur_, _hamn, éalt, mtoo,
   {{0x6d5aa8ce,0x63a0a8cf,0x62828415,0x44384d42}},	//   rata, _kamn, ltoo, _jur_,
   {{0x4438a8d0,0x6d5aa8d1,0x63a000f3,0x7bc4009c}},	//   _mur_, sata, _jamn, _coiu,
   {{0x6d5a07ac,0x443819b2,0x63a00188,0x3a740243}},	//   pata, _lur_, _mamn, оляр,
   {{0xa2a741f2,0x4438004f,0x6d5aa8d2,0x24810133}},	//   चित्, _our_, qata, ythm_,
   {{0x443802d6,0x6d5800d9,0x195816c0,0x2904008b}},	//   _nur_, _ieva, расы_, şman_,
   {{0x63a20018,0x63a0a8d3,0x3207a8d4,0x9f980139}},	//   jdon, _namn, zony_, _béé_,
   {{0x44384d38,0x6d58007a,0x63a2a8d5,0x9f8a0139}},	// [c310] _aur_, _keva, ddon, _bùú_,
   {{0x63a200e5,0x3207762c,0x6d581e31,0x4438a8d6}},	//   edon, xony_, _jeva, _bur_,
   {{0x4438003b,0xd49b013d,0x32070139,0x7995a54a}},	//   _cur_, ъра_, vony_, mezw,
   {{0x6d58768c,0x69c502e2,0x63a2a8d7,0x63a00332}},	//   _leva, _hohe, gdon, _camn,
   {{0x7cca01d4,0xa3ab02e8,0x69c5a8d8,0x6fd50143}},	//   lərd, _कोण_, _kohe, _náca,
   {{0x7c3825f9,0x799591c5,0x6d583f1f,0xa75901d3}},	//   _ouvr, nezw, _neva, šķīg,
   {{0x44380514,0x32070067,0x6282a664,0x25f60f8f}},	//   _gur_, rony_, atoo, ्वरी_,
   {{0x628271d6,0x63a2a8d9,0xe3b30e25,0x9f910139}},	//   btoo, cdon, _برس_, _báá_,
   {{0x443802d6,0x79958ac0,0x7dcd0088,0xdee506ea}},	//   _zur_, kezw, _húsi, сопи,
   {{0x6d580b88,0x69c5728e,0x7e620128,0x7bc42843}},	//   _ceva, _nohe, _dvop, _soiu,
   {{0x6d58a8da,0x63a0a8db,0x6bd60076,0x201d039f}},	//   _deva, _yamn, متحر, _thwi_,
   {{0xe9f90028,0x69d70042,0xeb9f00f2,0x7cca013c}},	//   _trẻ_, _alxe, dløs_, dərd,
   {{0xed4e225a,0x69c5a8dc,0x9f910139,0x7766020b}},	//   _но_, _bohe, _gáá_, _rdkx,
   {{0x6d581d19,0x69c500ee,0xed59188d,0x799566ba}},	//   _geva, _cohe, _сок_, gezw,
   {{0x69c5a8dd,0x63a20a60,0xab5b5867,0x7bc4044c}},	//   _dohe, ydon, rkür, _toiu,
   {{0x4438a8de,0x6fce009c,0x6d58019f,0x69d701ff}},	//   _rur_, _cùch, _zeva, _elxe,
   {{0x44381729,0x6282008a,0x6ff300ae,0x63a0a8df}},	// [c320] _sur_, xtoo, găci, _ramn,
   {{0x63a0a8e0,0x7cca0092,0x6282006c,0x69c50178}},	//   _samn, bərd, vtoo, _gohe,
   {{0xb8ed00c7,0x69dc152f,0xe00707d5,0x9743007e}},	//   _শে_, mhre, शवाद_, _šćek,
   {{0x53e5004d,0x6d9e0090,0x6282a8e1,0x8c36006e}},	//   оціа, _iħaż, ttoo, צטנס_,
   {{0x63a209cd,0x63a001fa,0x443803e3,0x69c502a4}},	//   rdon, _vamn, _wur_, _yohe,
   {{0x4438a8e2,0x63a2a8e3,0x6282a8e4,0x4a9b021e}},	//   _tur_, sdon, rtoo, טינג,
   {{0x443815b9,0x6d58a8e5,0x6282a8e6,0x63a00d94}},	//   _uur_, _reva, stoo, _tamn,
   {{0x7995a8e7,0x6d431570,0x62820381,0x6d410227}},	//   zezw, _afna, ptoo, ecla,
   {{0x6d580291,0x7c382e78,0x7cca0092,0x63b30579}},	//   _peva, _suvr, zərd, šení,
   {{0xdd9a08f9,0x6d4301ff,0x6e390381,0x7cca013c}},	//   уши_, _cfna, _duwb, yərd,
   {{0x69c500aa,0x69dc0037,0x5bb9008f,0x6d580b85}},	//   _rohe, dhre, алня_, _veva,
   {{0x4426a8e8,0x69c5005c,0x6d430088,0x6d41a8e9}},	//   nmo_, _sohe, _efna, acla,
   {{0x6d58a8ea,0x79950384,0x4426a8eb,0x69dc0076}},	//   _teva, tezw, imo_, fhre,
   {{0x6abb00c7,0x69dca8ec,0x2fc6043e,0x395a2441}},	//   উনলো, ghre, _hoog_, _ceps_,
   {{0x58d42357,0x2fc6178f,0x4426a8ed,0x79950193}},	//   порт, _koog_, kmo_, rezw,
   {{0x442615f4,0x36d508d8,0x2fc60188,0x69c51594}},	//   jmo_, ообр, _joog_, _wohe,
   {{0x2fc6a8ee,0x69dc0a02,0x6b8da8ef,0x4426a8f0}},	// [c330] _moog_, bhre, _ibag, dmo_,
   {{0x69dca8f1,0x2fc6022e,0x98a30367,0x6aad0169}},	//   chre, _loog_, sajı_, _iraf,
   {{0x6d9e03e5,0x6b8d0113,0x6aad003e,0x073500e5}},	//   _għaż, _kbag, _hraf, _меню,
   {{0xedb510ed,0x6d41058a,0x2fc6006c,0x4426a8f2}},	//   _अच्छ, zcla, _noog_, gmo_,
   {{0x6b8d421b,0x601e023b,0x00000000,0x00000000}},	//   _mbag, këmb, --, --,
   {{0x4426a8f3,0x764da8f4,0x4a5c0266,0x6b8d010a}},	//   amo_, mpay, נדוו, _lbag,
   {{0xdb0d03be,0xf1c90139,0xc8c90034,0xa2a70179}},	//   _moañ, _aláì_, रहिट, चिह्,
   {{0x7a200149,0x5fa30fef,0x6aada8f5,0x4426008c}},	//   möte, _खोखल, _oraf, cmo_,
   {{0xa3b6269c,0xee360761,0x2fc607b4,0x764d06a3}},	//   जार_, оны_, _doog_, npay,
   {{0x27080028,0x6b8d18b1,0xb8010081,0x27ed00b6}},	//   ởng_, _abag, ্ষিত_, čeny_,
   {{0x6d41a8f6,0x6b8d0172,0x00000000,0x00000000}},	//   rcla, _bbag, --, --,
   {{0xab2a3974,0xdb040037,0x6d41a8f7,0x6a8601b6}},	//   иона_, _iniú, scla, олма,
   {{0x69dc50dc,0x15fb1492,0x2b4d0487,0x6b8d0113}},	//   thre, ्वार_, ñeca_, _dbag,
   {{0x6aada8f8,0x4426013f,0x7a201b8d,0xdb0d0072}},	//   _draf, zmo_, köte, _coañ,
   {{0x4426a8f9,0x75e901d4,0xe73a1ada,0x2fc6022e}},	//   ymo_, _gözə, иев_, _yoog_,
   {{0xe73702fd,0x6b8d4eac,0x2fc6008a,0x69dc04c8}},	//   жет_, _gbag, _xoog_, shre,
   {{0x764d2447,0x69dca8fa,0x00000000,0x00000000}},	// [c340] gpay, phre, --, --,
   {{0x9f4d084e,0x0566013f,0x00000000,0x00000000}},	//   fieë_, івен, --, --,
   {{0xa3b602f0,0x2456001c,0x9f4d0313,0x00000000}},	//   जाल_, زنشس, gieë_, --,
   {{0xccf200ca,0x00000000,0x00000000,0x00000000}},	//   וכב_, --, --, --,
   {{0x25a3003d,0x2fc68e37,0x7dcd01cd,0x442001d3}},	//   _fajl_, _roog_, _húsu, ķi_,
   {{0x442659ba,0x7d060067,0x3dc7022b,0x2fc602ac}},	//   smo_, ększ, _nonw_, _soog_,
   {{0xfd070068,0xd4670084,0x2fc6a8fb,0x30a31402}},	//   _آج_, _мире_, _poog_, дрыв,
   {{0xef1900a5,0xb4d605cd,0x4426008c,0x00000000}},	//   leży_, िनी_, qmo_, --,
   {{0x6fdc025a,0xa3d72a06,0xb5fb1f20,0x2fc6a8fc}},	//   _néce, िसर_, _ovál, _voog_,
   {{0x6b8d008f,0x06cd0081,0x5c740a99,0xdb160139}},	//   _sbag, _রেডি, плот, _foyú,
   {{0x2fc6022e,0x6aad0d62,0x601e0052,0x212a01b9}},	//   _toog_, _sraf, rëmb, _àbh_,
   {{0x6aad00ae,0x764d00f9,0x6ff3020a,0x6fe8007f}},	//   _praf, ypay, făcu, kści,
   {{0x6fe800a5,0x6448a8fd,0x6aad00a7,0xb4d600b6}},	//   jści, _édif, _qraf, िनु_,
   {{0x6fdc025a,0x7c3ea8fe,0x1e3301b3,0x81cc0033}},	//   _déce, _épro, _жніў, শোর_,
   {{0x68e201c2,0x6fe8007f,0xe9190120,0x6b8d27fc}},	//   _ƙoda, eści, сові_, _tbag,
   {{0x6b8da8ff,0x00000000,0x00000000,0x00000000}},	//   _ubag, --, --, --,
   {{0x6aad0051,0xf40200ae,0x764d00dc,0xa3ab0851}},	// [c350] _uraf, inţă_, upay, _कोष_,
   {{0x2901022e,0x764da900,0xdcea026a,0x7a2009ab}},	//   _txha_, rpay, _hafı, töte,
   {{0xd37100e3,0xa3b60285,0x00000000,0x00000000}},	//   فها_, जां_, --, --,
   {{0xa3ab0067,0x3cfb00c1,0x9f4d057a,0xa3e6049d}},	//   _कोश_, סלאנ, rieë_, योल_,
   {{0xd34600d1,0x61451052,0xfbd400d7,0x00000000}},	//   سیله_, пела, ותף_, --,
   {{0xe57009b4,0xfa7800a1,0x1a9c00c1,0x614540a9}},	//   _لطف_, קעות_, יידע, чека,
   {{0xdd1c0220,0x98780995,0xdcfa00c6,0x00000000}},	//   yšši, ršće_, metė, --,
   {{0xa3b605d6,0xa3b20096,0x3dc7022b,0x00000000}},	//   जाः_, _झोप_, _sonw_, --,
   {{0xfe710037,0x518700c6,0x2baf0285,0xeb9f00f3}},	//   ردة_, _мужа, _जोधा, vløp_,
   {{0x6fdc025a,0x6fd50094,0xf402020a,0x00000000}},	//   _réce, _zácl, anţă_, --,
   {{0xcb091723,0x1d09a901,0xe05731bb,0xfbdf0313}},	//   _על_, сени_, _بیعت_, fhê_,
   {{0x290401e8,0x6fe8007f,0xfbdf02ac,0x00000000}},	//   şmak_, yści, ghê_, --,
   {{0xeb970624,0x7dcda902,0x7d180031,0xdcfa00c6}},	//   чия_, _búst, _časť, ketė,
   {{0x7dcd0072,0xbea251ad,0xaec402b7,0x200d2d13}},	//   _cúst, _чашк, _юбіл, loei_,
   {{0x291e320e,0xa3e6009f,0x00000000,0x00000000}},	//   åta_, योँ_, --, --,
   {{0xfbdf0161,0x2d820103,0x75e00103,0x7d1ca903}},	//   chê_, őket_, _közg, ürse,
   {{0x7c2412e6,0xddc9044c,0x00000000,0x00000000}},	// [c360] _ihir, creţ, --, --,
   {{0x7dcd61bf,0x80ae0789,0x49940018,0x6fe8007f}},	//   _gúst, ंटमे, _تیسر, rści,
   {{0xc953193b,0xd91009b4,0xb4d64255,0x200d72ca}},	//   _אמת_, _شیر_, िने_, koei_,
   {{0xa3e60d1b,0x93433457,0x3eaf2441,0x200d0131}},	//   यों_, енце, _orgt_, joei_,
   {{0x27e0a904,0x6fd500b6,0x741300cd,0x644100d1}},	//   mhin_, _václ, روها, _élin,
   {{0x27e02846,0x7c2400f9,0x6e2d009c,0x00000000}},	//   lhin_, _lhir, _èabh, --,
   {{0x7c240178,0x76490233,0x00000000,0x00000000}},	//   _ohir, _çeyr, --, --,
   {{0xdfd00080,0x27e0a905,0x289700ca,0x200d0062}},	//   ئية_, nhin_, פדפן_, goei_,
   {{0x27e002fd,0x442402e2,0xa3e65433,0xb4ac009f}},	//   ihin_, _ihm_, योः_, _कछु_,
   {{0x7c2480c1,0x27ff21b8,0x657e7cda,0xa0a64d95}},	//   _ahir, čuni_, ngph, _назд,
   {{0x3d0610e9,0x2b4d034f,0x6e23009c,0x7c2403d3}},	//   _सुखे_, ñeco_, _dhnb, _bhir,
   {{0x7dcd6e42,0xdddb103b,0xddc900ae,0xafe31942}},	//   _súst, rtuš, treţ, _похл,
   {{0x7c24a906,0x27e052d8,0x601e0052,0x9b24001f}},	//   _dhir, dhin_, cëma, ефрл,
   {{0x7c24010a,0x80a100c3,0x00000000,0x00000000}},	//   _ehir, _कैडे, --, --,
   {{0x69d501bf,0x27e001bf,0x7c241ab6,0x44245411}},	//   rkze, fhin_, _fhir, _ohm_,
   {{0x2d8c0db8,0x7c24a907,0x27e080f0,0xbd1700d7}},	//   lfde_, _ghir, ghin_, _מחוז_,
   {{0xa3b600aa,0x2d8c0a88,0x59a80285,0xba6b0076}},	// [c370] जाई_, ofde_, _छोकर, _احبك_,
   {{0x06140084,0x44242ce8,0x27e00188,0x2a69007e}},	//   едую, _ahm_, ahin_, _ivab_,
   {{0xf8d1000f,0xd9182e9e,0xdb160383,0x27e02e35}},	//   _हथिय, _нью_, _anyè, bhin_,
   {{0x27e006a3,0xf1b80090,0x7c240052,0x7a200212}},	//   chin_, _anġ_, _xhir, möta,
   {{0x59d104f8,0xdcfa00c6,0x248d0357,0x00000000}},	//   _सकार, petė, _ćemu_, --,
   {{0x644a255c,0xe7d52326,0x2d8c01c0,0x76ba00ca}},	//   ífic, _yığı, jfde_, _ומשפ,
   {{0x6e2d0036,0x69be0096,0x200d01c8,0x00000000}},	//   _èabi, शाती, toei_, --,
   {{0x2d8c1044,0x7ddf016d,0xd259022b,0x3ebf01ff}},	//   efde_, _mêse, _twņ_, txut_,
   {{0xc91a167f,0x236d0087,0xa28200cd,0x200da908}},	//   _धर्म_, _idej_, _لینو, roei_,
   {{0x7dcda909,0x7c24a90a,0x27e0023b,0xddc902ef}},	//   _rúss, _shir, zhin_, freš,
   {{0x601e023b,0xa3b80018,0x7c240a4b,0xfce503c8}},	//   sëma, _ظاہر_, _phir, фоно,
   {{0x30780308,0x2d8c0f5a,0x27e00216,0x00000000}},	//   _رحمة_, afde_, xhin_, --,
   {{0xbdf80068,0x06cd0081,0x3ce902c6,0xe7d5071d}},	//   _کرنا_, _রেসি, _živě_, _sığı,
   {{0x75e00068,0x2fdd02a1,0xdb060103,0x3f8d00b3}},	//   _köze, _hlwg_, ndké, lfeu_,
   {{0x27e0a90b,0x7c24a90c,0x236d05db,0x2b4903a8}},	//   thin_, _thir, _odej_, _ffac_,
   {{0x6fdc01dc,0x61440032,0x26c001ff,0x27e001ff}},	//   _kéca, _kìló, txio_, uhin_,
   {{0xb4d6030b,0x27e0a90d,0x44240b14,0x95ca00ae}},	// [c380] िन्_, rhin_, _rhm_, олаб_,
   {{0x27e0a90e,0x6fdc0257,0x442400a4,0x7bc608a9}},	//   shin_, _méca, _shm_, ljku,
   {{0xe73a0465,0x4424a90f,0x799ca910,0x27e024f9}},	//   _мен_, _phm_, merw, phin_,
   {{0xd36f0080,0x799ca911,0x75e0071d,0x7e7b8647}},	//   لهم_, lerw, _sözd, kuup,
   {{0xaaa7030b,0xdb040072,0xddc91c54,0x91e652fc}},	//   खिएक, _baié, zreš, моде,
   {{0x799ca912,0x9f460364,0x6aa40a4b,0x6b84009c}},	//   nerw, _bloß_, _msif, _lcig,
   {{0x6b842cea,0x224d026a,0xe3660291,0x320e0c6f}},	//   _ocig, _etek_, _окви, rofy_,
   {{0x77640428,0x3ead2df3,0x44249d69,0x799ca913}},	//   naix, fvet_, _uhm_, herw,
   {{0xcebb01d4,0x799c50c4,0xe246177a,0x44444fed}},	//   _şərh_, kerw, _آخري, lq_,
   {{0x7dcd00c7,0x6b840072,0xddc9138c,0x236d033b}},	//   _búsq, _acig, treš, _zdej_,
   {{0x057700a1,0x75e0a914,0x44448a50,0xdb0a0146}},	//   וגים_, _közb, nq_, čným,
   {{0x69dea915,0x44440188,0x6fd50a7f,0x6fdc014b}},	//   _alpe, iq_, _nách, _féca,
   {{0x753c0034,0x799c25e1,0x6b8401b9,0x3ead007e}},	//   _ogrz, ferw, _dcig, cvet_,
   {{0xa3ab2e04,0x20140067,0x799c0198,0xddc9a916}},	//   _कोई_, ścią_, gerw, preš,
   {{0x6aa40201,0xd6fb0033,0x874c0134,0x6d4a009e}},	//   _esif, _আরো_, _ọdịg, _iffa,
   {{0xdc2b00cd,0x69dea917,0x656e01b9,0x2905003d}},	//   _بسته_, _elpe, _adbh, ħla_,
   {{0x644e0b4b,0x444403e5,0x799ca918,0x645c00bd}},	// [c390] _atbi, eq_, berw, _awri,
   {{0x645c0150,0x6b9d018f,0x394711bc,0x799c0027}},	//   _bwri, lesg, _üns_, cerw,
   {{0x79850113,0x77642e84,0x224d5383,0x7bcd0995}},	//   _ichw, baix, _stek_, _koau,
   {{0x77647278,0x644100fd,0x6b9d8563,0x3ead3b69}},	//   caix, _élim, nesg, yvet_,
   {{0x44440188,0x645c43c3,0x69de007b,0x224d0090}},	//   aq_, _ewri, _ylpe, _qtek_,
   {{0x7ff507d9,0x6fd50094,0x27ff0660,0x6fdc020d}},	//   کستا, _zách, čunu_, _réca,
   {{0x44441b59,0x261802d5,0x6565019f,0x1c0f03b3}},	//   cq_, _बीटी_, mahh, सवाल_,
   {{0x799c13f9,0x6d4a3e3f,0x7e7b0357,0x7bcda919}},	//   zerw, _affa, tuup, _noau,
   {{0x63bb54c1,0xcdf5163d,0x799c0027,0x7cca00a7}},	//   _inun, ечны, yerw, fəro,
   {{0x7bdfa91a,0x644804d4,0x63a9a91b,0x7dcd0143}},	//   _alqu, _édic, _haen, _cúsp,
   {{0x3ead02dd,0x63a9a91c,0x799c1063,0x00000000}},	//   svet_, _kaen, verw, --,
   {{0xff530391,0x6d4aa91d,0x799ca91e,0x63a96493}},	//   _شخص_, _effa, werw, _jaen,
   {{0x799ca91f,0x63a9a920,0x7cca00a7,0xe8030c9c}},	//   terw, _maen, lərl, रचना_,
   {{0x63a9007a,0x69c100aa,0x7bdf6165,0x2be20336}},	//   _laen, ölep, _elqu, _पतवा,
   {{0x799c01a6,0x63bba921,0x98aa07aa,0x6445023e}},	//   rerw, _onun, tabı_, jqhi,
   {{0x07a380c8,0x799ca922,0x63a9a923,0x7985a924}},	//   ласн, serw, _naen, _echw,
   {{0xd7073e28,0x7cca0092,0x80a10cce,0x6aa44100}},	// [c3a0] енте_, hərl, _कैसे, _usif,
   {{0x9f5d0174,0xe61754e0,0xf0a50023,0x98aa071d}},	//   _akwü_, еду_, _đàng_, sabı_,
   {{0x63a9030a,0x6fd5034f,0x4444026d,0x628b02ac}},	//   _baen, _tách, uq_, etgo,
   {{0x6fd5386c,0x63a90e36,0x6565a925,0x444425c3}},	//   _fáci, _caen, aahh, rq_,
   {{0xa3e60851,0x798502ad,0xdbc7007a,0x63a9462c}},	//   योग_, _ychw, _tööl, _daen,
   {{0x6445023e,0x59c302d5,0x645c00f0,0x7cca00a7}},	//   bqhi, शायर, _twri, fərl,
   {{0x66032cbf,0x644e0222,0x63a92f0e,0xc95300a1}},	//   _спра, _utbi, _faen, נמה_,
   {{0xb4be3087,0x3a3a86ec,0x63a93ef4,0x7c3e464f}},	//   ेही_, _lipp_, _gaen, _épri,
   {{0x25aa3360,0x680500c6,0x00000000,0x00000000}},	//   _kabl_, nėda, --, --,
   {{0x7cca0253,0x63a9a926,0x71ea0981,0x00000000}},	//   bərl, _zaen, _عفاف_, --,
   {{0x67fb00c2,0x63a9a927,0x6b9d1bf0,0x7fd6004d}},	//   näjä, _yaen, tesg, _піді,
   {{0x798502d6,0x680500c6,0x00000000,0x00000000}},	//   _schw, kėda, --, --,
   {{0x6b9da928,0x2be200c3,0xd00f0568,0xdd920286}},	//   resg, _पतरा, _الن_, _موش_,
   {{0x6d4aa929,0xdb0417eb,0xa2c10096,0x3ea600c2}},	//   _uffa, _anió, लमत्, _isot_,
   {{0x2d9ea92a,0x4e1700ca,0x00000000,0x00000000}},	//   mete_, _רחוב_, --, --,
   {{0x2d9e1d91,0x6565005c,0x7bdf037a,0x7c8308f9}},	//   lete_, wahh, _ulqu, _суше,
   {{0xb8c806ed,0x63a9a92b,0x24984835,0x656501c2}},	// [c3b0] _खै_, _raen, _aprm_, tahh,
   {{0x63a9a92c,0x26c7005f,0x3954030b,0xaa64013d}},	//   _saen, ćno_, časí_, _стък,
   {{0xf1bf0028,0x63a9a92d,0xe1f100cd,0x6fdc002b}},	//   _đá_, _paen, یست_, _néco,
   {{0xe8d6004f,0x2d9ea92e,0x6fd52bb5,0xa8560327}},	//   _יותר_, hete_, _táci, _שירה_,
   {{0x63a900aa,0xa3b6009f,0xa2c10096,0x36d40208}},	//   _vaen, जाज_, लमध्, _бояр,
   {{0x63a9a92f,0x4b3800c1,0xf99400c1,0x7dd6078e}},	//   _waen, ׂראל_, ָרק_, _fâsi,
   {{0x2d9ea930,0x63a9a931,0x628b3987,0x91e21aad}},	//   dete_, _taen, stgo, роще,
   {{0x6fdc04ea,0x7e69007a,0x63bba932,0x7cca013c}},	//   _déco, tsep, _unun, rərl,
   {{0x6fdc132d,0x2d9ea933,0xdee53340,0xd13b00ae}},	//   _técn, fete_, топи, _ехе_,
   {{0x7e693c9d,0x6fdc020d,0x6fd500d4,0x3f86044c}},	//   rsep, _féco, _nácv, _ecou_,
   {{0x3ea600d9,0x2d8b0034,0x00000000,0x00000000}},	//   _esot_, ęce_, --, --,
   {{0xe73f00de,0x3a3a0167,0x31671925,0x7e6900bc}},	//   _ngõ_, _sipp_, lanz_, psep,
   {{0x2d9ea934,0x00000000,0x00000000,0x00000000}},	//   bete_, --, --, --,
   {{0x2d9e0074,0x2fcfa935,0x31670364,0x4ce00033}},	//   cete_, _hogg_, nanz_, _ফখরু,
   {{0x98b800d9,0xfce51eac,0x442f0188,0xdca500ae}},	//   mbrī_, _шоко, kmg_, _райи,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d5033a,0x3667013d,0x3a3aa936,0x8ca9000c}},	// [c3c0] ाउन_, като_, _tipp_, टिको,
   {{0x7a7b00f5,0x67fb02fd,0x2fcf02ec,0x6805013f}},	//   _קריס, täjä, _logg_, rėda,
   {{0x80a10034,0xb4be09a1,0xdb04009c,0x69dc0365}},	//   _कैले, ेहे_, _gniò, mkre,
   {{0xdb0406f9,0x6fdca937,0x7c3e0451,0x69dc5cfe}},	//   _unió, _réco, _èpre, lkre,
   {{0x6fdc025a,0x69dc042d,0x2d9ea938,0x25aaa939}},	//   _décl, okre, yete_, _tabl_,
   {{0xa13c00e8,0x3167042c,0xcad700ca,0x00000000}},	//   _kaķi, ganz_, כונת_, --,
   {{0x75e0026a,0x2ca7020b,0x00000000,0x00000000}},	//   _göza, _nsnd_, --, --,
   {{0x2d9ea93a,0x27e20063,0x0877006e,0x2fcf0503}},	//   wete_, _jlkn_, דעקט_, _cogg_,
   {{0x7d1d0092,0xc2435e66,0x69dca93b,0x31670027}},	//   əssi, _внук, kkre, banz_,
   {{0xf77f026a,0x2b40a93c,0x00000000,0x00000000}},	//   _ilçe_, _agic_, --, --,
   {{0xdfd20421,0x69dca93d,0x8ca9023a,0x6ca3007b}},	//   _پيش_, dkre, टिगो, аряж,
   {{0x40ab0068,0xdb04002b,0x8fa60396,0x69dc1cab}},	//   _زخمی_, _aniñ, _јаде, ekre,
   {{0x6ab600f0,0xdd940450,0x2b40030a,0x929d007f}},	//   _cryf, _балы, _dgic_, _były,
   {{0xc33300a1,0x69dc67c9,0x6ab6084e,0x00000000}},	//   יור_, gkre, _dryf, --,
   {{0x7c8646af,0x6d5a0216,0xd83b013f,0x69c3022b}},	//   _руле, mbta, дэа_, _ònem,
   {{0x3f8432c3,0x5fc50096,0x6d5a00c6,0xdce101d3}},	//   ngmu_, वायल, lbta, zglī,
   {{0x6ab6a93e,0x6fdc00fd,0x02be007f,0xd8380138}},	// [c3d0] _gryf, _récl, ्होन, тэр_,
   {{0x69dc0ec6,0xa3e500c3,0xdc000096,0x00000000}},	//   ckre, _फतह_, ोकॅड_, --,
   {{0xdb1d007a,0x601e023b,0x61f80106,0x31670bb2}},	//   rksõ, rëmj, divl, vanz_,
   {{0x7bdd0e22,0x80b805d6,0x2fc001ec,0x00000000}},	//   nksu, ्मने, _òigh_, --,
   {{0xe3b000cd,0x81ac0033,0x3167a249,0xaca30134}},	//   ترل_, গান_, tanz_, tiịm,
   {{0x6fd51946,0x2fcf0036,0x2089448a,0xbbd03516}},	//   _láct, _sogg_, ейки_, _हक्क,
   {{0x2edb030b,0x2610009d,0x31674a6a,0x5184423e}},	//   यन्त, तकरी_, ranz_, руча,
   {{0xfe79030b,0xa3ab0034,0x61f80f5a,0x7bdd01cb}},	//   trů_, _कोच_, aivl, jksu,
   {{0xee390465,0x0ccb0bba,0x327901f9,0x00000000}},	//   нни_, ाह्म, _سماج_, --,
   {{0x2b400072,0x2b9e00fe,0x92581412,0x41b700c3}},	//   _sgic_, _ắc_, _рафт_, _आफिस,
   {{0xd084007b,0x00000000,0x00000000,0x00000000}},	//   _вычи, --, --, --,
   {{0x5bde02d5,0xb5fb00d4,0x50da0142,0x61e600c6}},	//   मसेव, _kvás, _אקעא, _įkli,
   {{0x69dca93f,0xe73f058f,0x00000000,0x00000000}},	//   tkre, _eaõk_, --, --,
   {{0x6fd5016d,0x7bdd2e13,0x6ab60f5a,0x00000000}},	//   _vácu, aksu, _vryf, --,
   {{0x27e2061d,0xdd8e001c,0x6fd50143,0xdb040231}},	//   _plkn_, _روي_, _fáct, _baiã,
   {{0x61f808a9,0x69dc3de7,0x6ab6a940,0xb6a6007e}},	//   zivl, skre, _tryf, либл,
   {{0x857a03fc,0x25a10364,0x69c85995,0x00000000}},	// [c3e0] есет_, fehl_, ödes, --,
   {{0x2d85a941,0x80b30251,0x29040092,0xe9a60291}},	//   ngle_, ंटाइ, şmaq_, _саоп,
   {{0x61f82222,0xdcea3360,0x629b0fe9,0x7e7b05db}},	//   vivl, ćiće, _apuo, hrup,
   {{0xb5fb00b6,0xa4f40096,0x130a10e0,0x00000000}},	//   _svát, _आधीच_, нней_, --,
   {{0x9f4400dd,0x61f8a942,0x6d5a0188,0xa3b502d5}},	//   shmë_, tivl, ybta, _जफर_,
   {{0x7e7ba943,0xf12600d6,0xd9f60be5,0x00000000}},	//   drup, льйо, ुचित_, --,
   {{0x61f828fc,0xa50a00d3,0x201f02a0,0x7e7b0381}},	//   rivl, _чева_, flui_, erup,
   {{0xddcb00e7,0x7646083e,0x4fd40d81,0x75e001f9}},	//   _ćiši, _kuky, ржит, _közo,
   {{0x7e7b0b97,0x73063d00,0x63a225a6,0x7cca00a7}},	//   grup, _спаз, meon, məri,
   {{0x7cca025c,0x211a00e3,0x27130019,0x76460517}},	//   ləri, _كتاب_, ệng_, _muky,
   {{0x7c661823,0x7646a944,0x4c940b2c,0xdb04003e}},	//   داخل, _luky, шинс, _snið,
   {{0x201f001f,0x00000000,0x00000000,0x00000000}},	//   clui_, --, --, --,
   {{0x7646010a,0x7e7b00b3,0x7f42039f,0x64410231}},	//   _nuky, crup, _igoq, _éliv,
   {{0x7cca0092,0xcee90018,0x63a200da,0xf402044c}},	//   həri, _جرمن_, heon, liţă_,
   {{0x6fd504d8,0xe919004d,0x63a21888,0xb5fb0956}},	//   _táct, тові_, keon, _ovár,
   {{0xb8860161,0x76460517,0x0ea80034,0x69c81762}},	//   _suíç, _buky, _कनाड, öder,
   {{0x311b099d,0x7c2da945,0x6fc5009d,0x5fc5009d}},	// [c3f0] _पुनः_, _ihar, वातं, वातल,
   {{0x7c2d01b9,0x62820172,0x00000000,0x00000000}},	//   _hhar, duoo, --, --,
   {{0x7c2da946,0x7cca0092,0x06d60033,0xd3710037}},	//   _khar, fəri, _সেদি, قها_,
   {{0x43951502,0x7c2d2de6,0x63a2a947,0x83670214}},	//   радс, _jhar, geon, ادال,
   {{0x27e91519,0x7c2d4637,0x75e00018,0x98b10491}},	//   mhan_, _mhar, _közl, mazı_,
   {{0x27e9265b,0xf67a0341,0x2be2046e,0x867a00ca}},	//   lhan_, _באשמ, _पत्थ, _ברשו,
   {{0xc0e50423,0x7c2d0a00,0x22580087,0x7e620065}},	//   ройк, _ohar, _črke_, _awop,
   {{0x27e9a948,0x201f00d3,0x64550634,0x7c2d4500}},	//   nhan_, ului_, _itzi, _nhar,
   {{0x442d38cd,0x6fdc00fd,0xdce101d3,0x64470239}},	//   _ihe_, _méch, dalā, _huji,
   {{0x64471ee3,0x443fa949,0x7c2d2cd0,0x201f00d3}},	//   _kuji, _hiu_, _ahar, slui_,
   {{0x7c2da94a,0x443fa94b,0x1d0911b7,0x6567a94c}},	//   _bhar, _kiu_, тени_, _mejh,
   {{0x7c2d9437,0x64470010,0x443fa94d,0x6d5c01ab}},	//   _char, _muji, _jiu_, ðrar,
   {{0xed4e6a72,0x7c2d9a56,0xaa4602ec,0x1615143d}},	//   _мо_, _dhar, регл, तकार_,
   {{0x442d0396,0x2fcd02e6,0x7c2d701c,0x656700b6}},	//   _lhe_, ljeg_, _ehar, _nejh,
   {{0x7a2002e2,0x7c2d09f7,0x67e3007a,0xa96702e1}},	//   nöti, _fhar, _sõja, риса_,
   {{0x7c2da94e,0x27e91098,0x2fcd0039,0x290c03e5}},	//   _ghar, ghan_, njeg_, ħda_,

   {{0x05660870,0x63a201af,0x6fdc0257,0x656741c2}},	// [c400] иван, veon, _déch, _bejh,
   {{0x75e00dea,0xdb0403be,0x443f01b9,0x056700b6}},	//   _gözl, _gaiá, _aiu_, říně_,
   {{0xb97b0054,0x7663030b,0x27e9a94f,0x442da950}},	//   _בניי, _čtyř, bhan_, _bhe_,
   {{0x442d7131,0x27e9a951,0x443f0472,0x6447a952}},	//   _che_, chan_, _ciu_, _duji,
   {{0x442d5790,0x443f0472,0x63a20037,0x31c6013d}},	//   _dhe_, _diu_, reon, искв,
   {{0x27e01114,0xc5690068,0x63a2a953,0x442d49f5}},	//   lkin_, _محفل_, seon, _ehe_,
   {{0x443f2b5c,0xb5fb035d,0x442d01f7,0x63a2a954}},	//   _fiu_, _tvár, _fhe_, peon,
   {{0x27e0a955,0x442da956,0x443fa957,0x7e6206a3}},	//   nkin_, _ghe_, _giu_, _pwop,
   {{0x41aa2549,0x27e0a958,0x257c0139,0xf402020a}},	//   _иван_, ikin_, _gálà_, riţă_,
   {{0x7c2da959,0x6440a95a,0x2d8a026a,0x64470167}},	//   _shar, _himi, übe_, _yuji,
   {{0x27e0a95b,0x2702a95c,0xa5b700c1,0x7c2d65b2}},	//   kkin_, लपुर_, בליק_, _phar,
   {{0x75e00390,0x6440a95d,0x7e620383,0xe4f90d77}},	//   _sözl, _jimi, _twop, ्पति_,
   {{0x6440a95e,0x27e002ef,0x6fdc095d,0x6d5c026a}},	//   _mimi, dkin_, _réch, ırab,
   {{0x27e00a00,0x6fdc00fd,0x661c02ef,0x27e902c9}},	//   ekin_, _séch, _nkrk, whan_,
   {{0x27e9a95f,0x98480020,0x6c840080,0x7c2da960}},	//   than_, ията_, _العم, _thar,
   {{0x6440a961,0x7c2da962,0x27e03b99,0xf7730308}},	//   _nimi, _uhar, gkin_, غاز_,
   {{0x443fa963,0x06cd0081,0x442d023e,0x6447a964}},	// [c410] _riu_, _রেজি, _rhe_, _suji,
   {{0x6fdc4026,0x442d0054,0x27e9692c,0x64470d17}},	//   _déci, _she_, shan_, _puji,
   {{0xf8b1172a,0x443f013d,0xb4e1009d,0xfa3400e3}},	//   _عکس_, _piu_, धने_, _بريد,
   {{0x98a10028,0x64471d50,0x442d01fa,0x6440a965}},	//   _nghĩ_, _vuji, _qhe_, _cimi,
   {{0x443f8e91,0xe29900d3,0x644701c2,0x479a00ca}},	//   _viu_, уал_, _wuji, _גירס,
   {{0x64476a89,0x6aad0051,0x764d0092,0x776d008c}},	//   _tuji, _msaf, mqay, laax,
   {{0x442da966,0x645501e9,0x00000000,0x00000000}},	//   _the_, _utzi, --, --,
   {{0x6440a967,0x917800de,0x442da78e,0x6f04a968}},	//   _gimi, _với_, _uhe_, _žica,
   {{0xa1590097,0xfe710037,0x3eb9a969,0x764da96a}},	//   _базу_, أدب_, íst_, nqay,
   {{0x3f530065,0x27e002a7,0x6440a96b,0x3f7700de}},	//   ṣu_, zkin_, _zimi, ểu_,
   {{0x6440a96c,0x6aad5046,0x6441a96d,0xcb6aa96e}},	//   _yimi, _asaf, _élis, лане_,
   {{0x644001ee,0x70b30285,0x00000000,0x00000000}},	//   _ximi, ंटील, --, --,
   {{0xdfb814ea,0x00000000,0x00000000,0x00000000}},	//   _خالص_, --, --, --,
   {{0x6d4300a6,0x6fdc0257,0xdddb003d,0xed564cc3}},	//   _ugna, _réci, ntuż, _лош_,
   {{0x27e00084,0xc8b50ab3,0x6aad0372,0xdce300c6}},	//   tkin_, осты, _esaf, _kenč,
   {{0x30da006e,0xdce30154,0x999a02c6,0x27e0a96f}},	//   אַמע, _jenč, _tipů_, ukin_,
   {{0x27e0a970,0x7bc40bb6,0x6440a971,0x915e00fe}},	// [c420] rkin_, _iniu, _rimi, _lắm_,
   {{0x64400a5f,0xc9aa17aa,0xdce30d12,0x64480154}},	//   _simi, _свое_, _lenč, _édik,
   {{0xc7a6064f,0x6440a972,0x7bd6026a,0x776d0188}},	//   _линк, _pimi, _koyu, baax,
   {{0x201d0027,0xdb040231,0x3207007f,0x00000000}},	//   _nkwi_, _caiç, enny_, --,
   {{0x644089a5,0x9f910088,0xe296001f,0x8c1b0289}},	//   _vimi, _ráð_, среќ, נוני,
   {{0xd46a0dd0,0x201d039f,0x64400169,0xdb040231}},	//   _محرم_, _akwi_, _wimi, _uniõ,
   {{0x64400707,0xdce305db,0x00000000,0x00000000}},	//   _timi, _benč, --, --,
   {{0xa8570054,0x61ea01af,0x6440004c,0x7bd6039f}},	//   זיקה_, shfl, _uimi, _noyu,
   {{0x88ce0033,0x4375001f,0x7a202f1c,0x00000000}},	//   রনিক, _фуст, lötu, --,
   {{0x6b8da973,0x2d990103,0x29f201d3,0x9f44034f}},	//   _scag, ősen_, iņas_, timó_,
   {{0x7bd603a3,0x25f008d4,0xfbc4009d,0xddc90fee}},	//   _boyu, _इतनी_, षांम, brež,
   {{0x7bd62f20,0xac191231,0x6aad0231,0x00000000}},	//   _coyu, рому_, _psaf, --,
   {{0xa3d016e2,0x6448028d,0x7bd6071d,0x00000000}},	//   _वचन_, _èdif, _doyu, --,
   {{0x2d570084,0x776d008c,0x69ca022b,0x00000000}},	//   _лишь_, waax, _òfel, --,
   {{0x7c3f0451,0xfc4900de,0x37560129,0x06d60033}},	//   _èpro, _hận_, _ọdụ_, _সেলি,
   {{0xf77002a3,0x6aad0044,0x00000000,0x00000000}},	//   ّال_, _tsaf, --, --,
   {{0x6aad0010,0x34e1030b,0x9f460381,0x3207a974}},	// [c430] _usaf, पन्द, _aloë_, ynny_,
   {{0x9967686c,0xfc4900fe,0x00000000,0x00000000}},	//   _утил, _mận_, --, --,
   {{0xfc490023,0x67d500ae,0x69c55f18,0x22580141}},	//   _lận_, _дону, _inhe, _črka_,
   {{0x7cca0092,0x69d7002b,0x78fa00ca,0x798903e3}},	//   lərs, _hoxe, _כפתו, ɗewa,
   {{0x3abc006e,0xdce31d80,0x00000000,0x00000000}},	//   ָמונ, _renč, --, --,
   {{0xd4e70aad,0x51870084,0xdce3762e,0x95cb02d8}},	//   _люби, суда, _senč, _сума_,
   {{0x628600f3,0x00000000,0x00000000,0x00000000}},	//   _åkon, --, --, --,
   {{0xfc4900de,0x40320396,0xb0680037,0x69d700ee}},	//   _bận_, мејс, حصول_, _loxe,
   {{0xdce30284,0xfc490019,0x69c51044,0xe1670f98}},	//   _venč, _cận_, _onhe, _هداي,
   {{0x7bd6008e,0x69d74074,0xfc49020b,0x7a20a975}},	//   _soyu, _noxe, _dận_, nött,
   {{0xddc90206,0x2cae00d4,0x7a400af0,0x00000000}},	//   prež, _csfd_, _látì, --,
   {{0x7bd601d4,0x69c5a976,0xeaba12d1,0x2d8e033c}},	//   _qoyu, _anhe, айм_, _ecfe_,
   {{0x81ac0081,0x2b17034c,0x69d7a977,0xbe6900ae}},	//   গার_, _धुआँ_, _boxe, _талж_,
   {{0xfce50274,0xed5936c9,0x69d70072,0x6fdc014b}},	//   _моло, _ток_, _coxe, _décu,
   {{0xd94318e4,0x186a162b,0x7bd600a7,0x00000000}},	//   дери, раби_, _toyu, --,
   {{0x3ea9025b,0x7bc400d3,0x69c50c2e,0xb8d20179}},	//   _šaty_, _uniu, _enhe, _टन_,
   {{0x2fc00037,0xb5fb026e,0x00000000,0x00000000}},	// [c440] _óige_, _iwáj, --, --,
   {{0x6fdc167e,0x7c26304c,0x75e00103,0x00000000}},	//   _héct, llkr, _közi, --,
   {{0xdd7a0130,0xfecf0081,0xb8ff0033,0xd8760781}},	//   שטעל, িনিধ, _দে_, _باخب,
   {{0x0326a978,0xdb060216,0x81b30033,0x00000000}},	//   оден, jekë, টাফ_, --,
   {{0xdc3700c1,0x77910018,0x386d0218,0x81b30033}},	//   קאנט_, _سیلا, ćere_, টান_,
   {{0x6f040995,0x644103a9,0x7c26042c,0x845a0c58}},	//   _žico, _èlin, hlkr, _врат_,
   {{0x7cca00a7,0x00000000,0x00000000,0x00000000}},	//   hərr, --, --, --,
   {{0x645e00c2,0x6fdc266c,0x30170037,0x00000000}},	//   mppi, _néct, يتية_, --,
   {{0x442642e2,0x3eaf0023,0x3ebd03a8,0x00000000}},	//   mlo_, _csgt_, _crwt_, --,
   {{0x4426a979,0xfc490019,0x6fdc0257,0x645e00c2}},	//   llo_, _vận_, _récu, oppi,
   {{0x6fdca97a,0xa3ae009d,0x44263d37,0x321c0094}},	//   _sécu, _कसा_, olo_, movy_,
   {{0x4426a97b,0xfc490019,0x7a200103,0x321c0e43}},	//   nlo_, _tận_, zött, lovy_,
   {{0x4426a97c,0x62823447,0x2fc60270,0x7cca013c}},	//   ilo_, nroo, _inog_, tərs,
   {{0x44265496,0x9e6500bf,0x321c0146,0x6fdc020d}},	//   hlo_, _راهن, novy_, _vécu,
   {{0x6282029a,0xdcf80233,0x7cca013c,0x9f462419}},	//   hroo, _tavı, rərs, _aloé_,
   {{0x44260095,0x7df900b6,0x2d8c04e3,0x00000000}},	//   jlo_, yňsk, lgde_, --,
   {{0x4426a97d,0xdce300d9,0x2d8c04e2,0x321c0146}},	// [c450] dlo_, _ienā, ogde_, kovy_,
   {{0x4426a97e,0x2d8c3813,0x69c5a97f,0x6282019e}},	//   elo_, ngde_, _unhe, droo,
   {{0x2fc603ce,0x321c025b,0x2d8c276e,0x7a20a980}},	//   _onog_, dovy_, igde_, rött,
   {{0x628202ac,0x00000000,0x00000000,0x00000000}},	//   froo, --, --, --,
   {{0xa75600a1,0x628204e2,0xb2ab1728,0x2a690167}},	//   _משרד_, groo, ртеж_, _jwab_,
   {{0x4426a981,0x216609f2,0x8cab02d5,0x6458002b}},	//   alo_, пиши_, _जनलो, ívic,
   {{0x4426a982,0x62820e8e,0xdb0a0146,0x316c0231}},	//   blo_, aroo, čném, _dedz_,
   {{0x6282a983,0xa295084c,0x2d8c1cab,0x0e65107a}},	//   broo, _набі, egde_, пкин,
   {{0x6d5c04a8,0x321c0e4b,0x00000000,0x00000000}},	//   ıran, bovy_, --, --,
   {{0x271a00de,0x4c8504fd,0x2d8c0212,0x321c00d4}},	//   ỏng_, плов, ggde_, covy_,
   {{0x236d022e,0x2a690113,0xeaf600b7,0x2904020e}},	//   _keej_, _awab_, ीप्त_, şmaz_,
   {{0xeb9a1476,0x2d8c0db1,0x2b490042,0x224d0063}},	//   щим_, agde_, _cgac_, _kuek_,
   {{0x236d0197,0x67ea0088,0x9c7c00d4,0x64480231}},	//   _meej_, _nýja, vyče, _édiv,
   {{0xceb21b83,0x236d0d7d,0x985600d6,0x645e00c2}},	//   _ניו_, _leej_, зташ, yppi,
   {{0x4426a984,0xdca20d47,0x75e00018,0x7cca00a7}},	//   ylo_, _защи, _közv, sərr,
   {{0x236d01bb,0x6282a985,0x68436a40,0xdb040558}},	//   _neej_, yroo, енса, _maiú,
   {{0x4426353b,0x3ead1183,0xe7377b30,0x2c0b0103}},	// [c460] vlo_, nwet_, зет_, _دعوی_,
   {{0x44260188,0x2245009c,0x00000000,0x00000000}},	//   wlo_, _nilk_, --, --,
   {{0x89db040a,0x4426a986,0xdb060103,0x224d0062}},	//   _החיי, tlo_, deké, _auek_,
   {{0x62823beb,0x44262eec,0xd46900e3,0x224d0063}},	//   troo, ulo_, تحكم_, _buek_,
   {{0x44261149,0xf1c7009d,0x224d171d,0x321c0a7f}},	//   rlo_, लांन, _cuek_, tovy_,
   {{0x98b808fd,0x44264fd4,0x6282446e,0x62860f63}},	//   ları_, slo_, rroo, _åkom,
   {{0x6282084e,0x321c023c,0x30a3007b,0x3ead0537}},	//   sroo, rovy_, ерыв, ewet_,
   {{0x644e002d,0x6282a987,0x661e0660,0x6aa40036}},	//   _iubi, proo, lopk, _opif,
   {{0x644ea988,0x63a003a9,0x656e1a3a,0xddcf05db}},	//   _hubi, _ibmn, _kebh, _šešo,
   {{0x644e0a2a,0x672600f3,0x2d8c1507,0x236d022e}},	//   _kubi, _mykj, ugde_, _zeej_,
   {{0x236d0d7d,0x6fdc025a,0x2d8c04e2,0x98b80367}},	//   _yeej_, _décr, rgde_, karı_,
   {{0x644e01a6,0x656e3388,0x661e82aa,0x2d820233}},	//   _mubi, _lebh, hopk, şke_,
   {{0x644ea989,0xdfcf0037,0x98b803e0,0x7764008c}},	//   _lubi, _حين_, darı_, dbix,
   {{0x645ca98a,0x656e019f,0x195800c6,0x644ea98b}},	//   _otri, _nebh, зары_, _oubi,
   {{0x59f8a98c,0x644ea98d,0x775a0134,0x645c0090}},	//   черя_, _nubi, _ọfụf, _ntri,
   {{0x98b80e26,0x00000000,0x00000000,0x00000000}},	//   garı_, --, --, --,
   {{0x35b54a4e,0x95d917e9,0x644e014b,0x656e019f}},	// [c470] мбар, одат_, _aubi, _bebh,
   {{0x644e0198,0x236d022e,0x99670dd8,0x3c320031}},	//   _bubi, _seej_, _этил, ráve_,
   {{0x644e2a00,0x236d01fa,0x63a00167,0x224d0afe}},	//   _cubi, _peej_, _bbmn, _suek_,
   {{0x236d01fa,0x645c0076,0x22451b9e,0x6edc00b6}},	//   _qeej_, _dtri, _silk_, यहाँ,
   {{0x9239205c,0xfc4900fe,0xdb0601f9,0x656e063d}},	//   очку_, _rậm_, teké, _febh,
   {{0xed4600cd,0x656e3441,0xcb14006e,0xd87403a9}},	//   _لپ_, _gebh, עלס_, _تایب,
   {{0x644e02e6,0x236d022e,0x6d470995,0x6fdc020d}},	//   _gubi, _teej_, žjak, _récr,
   {{0x6d5803ee,0x56000081,0x7e7d5991,0x7ff500cd}},	//   _afva, ্তৃক_, áspo, بستا,
   {{0x644e2855,0x764702a4,0x656e019f,0xddc205db}},	//   _zubi, _kijy, _yebh, _dvož,
   {{0x63ab269e,0x644ea98e,0x628b4d91,0x645c01df}},	//   legn, _yubi, mugo, _ytri,
   {{0x6448025a,0x628ba98f,0x644e4022,0x3ead1570}},	//   _édit, lugo, _xubi, swet_,
   {{0x27340102,0xddc233db,0xcfab0602,0x98b800a7}},	//   _júní_, _gvož, _دائم_, xarı_,
   {{0x62998082,0x0f560054,0x628b0d1f,0x75e00018}},	//   ntwo, _חינם_, nugo, _közt,
   {{0xbea24402,0xa2b00096,0x76470079,0x997d00e8}},	//   _рашк, _आईस्, _nijy, tāšu_,
   {{0x628b12f5,0x200d0231,0xaa430846,0x98b8020e}},	//   hugo, onei_, терл, tarı_,
   {{0x764f0875,0x5d44006e,0x656e0201,0x63ab0357}},	//   _bucy, _אָפּ_, _sebh, jegn,
   {{0x644e0977,0x645ca990,0xcf920130,0x386d084f}},	// [c480] _subi, _stri, כטן_, ćera_,
   {{0x644ea991,0x764f0169,0xe57a0138,0x98b80847}},	//   _pubi, _ducy, ізе_, sarı_,
   {{0x7647022b,0x7c24083e,0xb4e81024,0x661e0031}},	//   _dijy, _kkir, यने_, ropk,
   {{0x656ea992,0x63aba993,0xd90d0018,0x53e5004d}},	//   _webh, gegn, _ایف_, нціа,
   {{0x656e6417,0x66840260,0x628b3c0c,0x764f02a4}},	//   _tebh, _سیال, gugo, _gucy,
   {{0x644ea994,0x200da995,0x645c02a1,0x00000000}},	//   _tubi, enei_, _ttri, --,
   {{0x7c24a996,0x63ab9a6e,0x645ca997,0x92ce0033}},	//   _okir, begn, _utri, শনে_,
   {{0xdfd00080,0x628ba00f,0xd7d1009d,0x7c2400ac}},	//   اية_, bugo, हायच, _nkir,
   {{0x25b86b54,0x7c3f0036,0x76470169,0x44240565}},	//   _karl_, _èpri, _yijy, _ikm_,
   {{0x7c246586,0x200d00ae,0x25b801ce,0x395aa998}},	//   _akir, anei_, _jarl_, _nfps_,
   {{0x6448a999,0x4424a99a,0x6e28a99b,0x00000000}},	//   _édis, _kkm_, rldb, --,
   {{0x44247694,0xa2c20d61,0xddc2033b,0x7c3600f0}},	//   _jkm_, लिप्, _uvož, _chyr,
   {{0x200490c9,0x44246815,0x6b9d4e8d,0x6e930076}},	//   mimi_, _mkm_, rfsg, _للنا,
   {{0x2004a99c,0x7c240a15,0x6abd0537,0x395a00ee}},	//   limi_, _ekir, rvsf, _cfps_,
   {{0x26c24055,0xa3ae0096,0x76470079,0xdb160154}},	//   _arko_, _कसं_, _rijy, _layè,
   {{0x2d9e8f26,0x27f203a8,0x236618c5,0x26c20357}},	//   lfte_, ghyn_, jboj_, _brko_,
   {{0x98af0702,0x26c2015c,0x63aba99d,0x80c00557}},	// [c490] ınız_, _crko_, vegn, विडे,
   {{0x2004a99e,0x6eb1009f,0xa2c20d7a,0x05c900c3}},	//   himi_, _अनसु, लिन्, राइब,
   {{0x2004a99f,0x81c60033,0xe759004d,0x3c320206}},	//   kimi_, ৎসা_, _нині_, láva_,
   {{0x628ba9a0,0x2004a9a1,0xb5fb0037,0x629901bf}},	//   tugo, jimi_, _stád, ttwo,
   {{0x27e906ee,0x63ab1484,0x81d80081,0xe94512eb}},	//   mkan_, regn, াসন_, _ترکی,
   {{0x27e9236d,0x63ab0ea0,0x628ba9a2,0x9f980088}},	//   lkan_, segn, rugo, _séð_,
   {{0x54541af2,0x63ab013d,0x27e97de3,0x65944a3b}},	//   _авст, pegn, okan_, _шару,
   {{0x27e9a9a3,0x2004a9a4,0x66050d17,0x628b0009}},	//   nkan_, gimi_, lihk, pugo,
   {{0x27e9578c,0x200d1360,0x5215004d,0xdcea0154}},	//   ikan_, rnei_, _здат, _defč,
   {{0x27e91268,0xee361736,0x6d4e2c0a,0x3c320220}},	//   hkan_, нны_, žban, dáva_,
   {{0x27e9a9a5,0x2004023b,0x6ab80557,0x7c2400f9}},	//   kkan_, bimi_, इट्र, _pkir,
   {{0xca290054,0x66052fc5,0x2004a9a6,0x645a020d}},	//   _הם_, hihk, cimi_, _étie,
   {{0x27e9a9a7,0x00000000,0x00000000,0x00000000}},	//   dkan_, --, --, --,
   {{0x67e3007a,0xb8660246,0xdb160139,0x00000000}},	//   _mõju, فارو, _jayé, --,
   {{0x27e9005a,0xa3c105a5,0x6605063f,0x18a31249}},	//   fkan_, ्ञा_, dihk, ларм,
   {{0x27e9090a,0x7c241a78,0x25b800fd,0xfaff0052}},	//   gkan_, _ukir, _sarl_, mbën_,
   {{0xd7c40096,0x225f2cf8,0xb4e850a4,0x25b8078e}},	// [c4a0] _लोणच, _ntuk_, यन्_, _parl_,
   {{0x2004a9a8,0x27e946c3,0x6605061d,0x6e210150}},	//   zimi_, akan_, gihk, nolb,
   {{0x27e903b4,0x4424005c,0x64495a44,0x225f061d}},	//   bkan_, _pkm_, _biei, _atuk_,
   {{0xe29a1b48,0xd5c90782,0x27e9070a,0xd36f0037}},	//   зад_, राउज, ckan_, مهم_,
   {{0x2004a9a9,0xd32314fa,0x66052fc5,0xdb1600ee}},	//   vimi_, льши, bihk, _bayé,
   {{0x69de3ff5,0x2a6000dc,0x200453ed,0xdb210206}},	//   _jope, _mtib_, wimi_, ätéh,
   {{0x2004a9aa,0x26c067a5,0x672200d9,0x64490bf8}},	//   timi_, lvio_, ļoju, _fiei,
   {{0x69dea9ab,0x4424a9ac,0x0443336f,0x9f44007b}},	//   _lope, _ukm_, _бесн, yhmä_,
   {{0x2004a9ad,0x26c0737d,0x69dea9ae,0x00000000}},	//   rimi_, nvio_, _oope, --,
   {{0xdd900241,0x69dea029,0x2004a9af,0x6e213d82}},	//   جود_, _nope, simi_, golb,
   {{0x6f665905,0x4ac302e8,0x2d9e357f,0x27e90188}},	//   _звез, शिभव, rfte_, ykan_,
   {{0xcfaf0081,0x3c320031,0x785500c6,0x27e90062}},	//   কাউন, táva_, _sąvo, xkan_,
   {{0x81b30f71,0x2bb209c3,0x69de00f0,0xb4ad007f}},	//   টার_, _जसरा, _bope, _कन्_,
   {{0x69dea9b0,0x3c320618,0x26c00234,0x61ea0d87}},	//   _cope, ráva_, dvio_, nkfl,
   {{0x27e91268,0x69dea9b1,0x66059525,0x386d02ef}},	//   tkan_, _dope, vihk, ćero_,
   {{0x69de0063,0xf77304f4,0x082800d3,0x00000000}},	//   _eope, طار_, ецуи_, --,
   {{0x27e91268,0xf6530b05,0x660502e7,0x69de01af}},	// [c4b0] rkan_, ائر_, tihk, _fope,
   {{0x27e903b4,0x984ba9b2,0x6d5aa9b3,0x7bdf0428}},	//   skan_, _няма_, ncta, _hoqu,
   {{0x27e903b4,0x225f043e,0x66050167,0x9c7c0094}},	//   pkan_, _stuk_, rihk, zyčn,
   {{0x6605117e,0x69de0087,0x987a0341,0x27e90063}},	//   sihk, _zope, _קארט, qkan_,
   {{0x6449a9b4,0x7bdfa9b5,0x32670291,0xdb1606aa}},	//   _viei, _moqu, хтев, _payé,
   {{0x7bdfa9b6,0x1e1a00a5,0x81450103,0x00000000}},	//   _loqu, नकोष_, نچان, --,
   {{0x70bd04dd,0xd3a7059b,0x80bd0789,0x81b30081}},	//   ्मेल, _прап, ्में, টাল_,
   {{0x442b0023,0x6d4e0995,0x7bdfa9b7,0x9c7ca9b8}},	//   _óc_, žbal, _noqu, tyčn,
   {{0xee392249,0x22841211,0x225f02e7,0x75e00018}},	//   мни_, _бухг, _utuk_, _közp,
   {{0x645a08ec,0x63bba9b9,0x6577023b,0x7bcda9ba}},	//   _étic, _haun, naxh, _anau,
   {{0x63bb0109,0xa80608bb,0x7bdf0d5a,0x90991d0b}},	//   _kaun, lmış, _boqu, _цвет_,
   {{0x63bb336d,0x32071fe8,0x7bdfa9bb,0x69dea9bc}},	//   _jaun, liny_, _coqu, _sope,
   {{0x63bba9bd,0xa80608bb,0x3861033c,0x64c50559}},	//   _maun, nmış, _athr_, lčić,
   {{0x32071fe8,0x26c00451,0x63bba9be,0x7bcd13d0}},	//   niny_, vvio_, _laun, _enau,
   {{0x64c5005f,0x44c10138,0x7bdf00b3,0x6fb80096}},	//   nčić, _nė_, _foqu, _आसमं,
   {{0xb8da1362,0x63bb265b,0xa8060233,0xb6070090}},	//   _आई_, _naun, kmış, _loġġ,
   {{0x32070146,0xf4170033,0x7e7b37ac,0x00000000}},	// [c4c0] kiny_, ়তার_, nsup, --,
   {{0xe7375b74,0x3207025b,0x64c502ef,0x7bdf0143}},	//   теу_, jiny_, kčić, _zoqu,
   {{0x320718ed,0x26c0016d,0x64c50218,0x7bdf11bc}},	//   diny_, svio_, jčić, _yoqu,
   {{0x7bdf00b3,0x7e7b4880,0x63bba9bf,0x130a1855}},	//   _xoqu, ksup, _caun, мней_,
   {{0x63bb6a2e,0x32071d4f,0x80040174,0x92b30076}},	//   _daun, finy_, ịakọ_, لحوا,
   {{0xa3ae009f,0x7e7b02c3,0xb5fb0206,0x00000000}},	//   _कसक_, dsup, _vtác, --,
   {{0xc95300a1,0xfc4a0019,0x629b0036,0x00000000}},	//   סמה_, _hậu_, _equo, --,
   {{0x63bb0138,0x00000000,0x00000000,0x00000000}},	//   _gaun, --, --, --,
   {{0x7bdf1094,0x6d4e00cb,0x7e7b259e,0x320706f7}},	//   _roqu, žbam, gsup, biny_,
   {{0x63a2a9c0,0x63bb006d,0x7bdf6e38,0xdbd60032}},	//   lfon, _zaun, _soqu, _gùús,
   {{0x7bdf275a,0x0cd00081,0xfc4a0023,0x63bba9c1}},	//   _poqu, ান্ত, _lậu_, _yaun,
   {{0x68e700d4,0x00000000,0x00000000,0x00000000}},	//   vyjd, --, --, --,
   {{0x80c009d0,0xb4df007f,0xfc3fa9c2,0x00000000}},	//   विवे, _तथ्_, rmí_, --,
   {{0x7a32052f,0xfc3f00b6,0x7ae002c3,0x7e62a9c3}},	//   sætn, smí_, ämta, _itop,
   {{0x7bdf49aa,0xdb04002b,0xa80603e0,0x3a3a0231}},	//   _toqu, _baió, zmış, _dhpp_,
   {{0x7bcda9c4,0xdb04002b,0x0eb609c3,0x81d80033}},	//   _unau, _caió, _अनाड, াসি_,
   {{0x63bb1335,0xfc4a0019,0x19590109,0xc98700d3}},	// [c4d0] _raun, _cậu_, _папы_, _иуни,
   {{0x7c2fa9c5,0xb5fb0139,0x63a218f0,0x2b5e02c6}},	//   llcr, _awár, efon, ětce_,
   {{0x32070074,0xb90800c7,0x63bb6fd4,0x63a2a9c6}},	//   viny_, _মে_, _paun, ffon,
   {{0x7e62a9c7,0xa8060491,0x64c50106,0xc43501f9}},	//   _otop, tmış, včić, اکست,
   {{0x3207025b,0x2ba50af1,0x7e623053,0x63bb007b}},	//   tiny_, ग्या, _ntop, _vaun,
   {{0xa80603e0,0x6d4e0a9e,0x63bb52a4,0x40952657}},	//   rmış, žbaj, _waun, грит,
   {{0x7e620933,0x63bba9c8,0x32072907,0xa4d40120}},	//   _atop, _taun, riny_, _корі,
   {{0x7e7ba9c9,0x81b30081,0x64c500cb,0x657503e3}},	//   tsup, টাই_, rčić, _hezh,
   {{0xfc4a0028,0x32070244,0x65750085,0x64550a4b}},	//   _mật_, piny_, _kezh, _huzi,
   {{0x645529f7,0xfc4a0023,0x80c01dae,0x628b015c}},	//   _kuzi, _lật_, विशे, mrgo,
   {{0xeb9a1a9c,0xd131114c,0x7e7b4976,0x6575a9ca}},	//   нин_, _اما_, ssup, _mezh,
   {{0x6575023b,0x442f0072,0x7ff401f3,0x7e7b058f}},	//   _lezh, nlg_, _پسما, psup,
   {{0x61e1a9cb,0x6da51d18,0x64550f4c,0xada500c2}},	//   _koll, _била, _luzi, _балл,
   {{0x61e10084,0x090500c7,0x657500d4,0x64550154}},	//   _joll, _শুধু_, _nezh, _ouzi,
   {{0xfc4a0028,0x64557e1b,0x99e40094,0x2c4601d3}},	//   _bật_, _nuzi, šňov, _mēdz_,
   {{0x61e1a9cc,0xfc4a00fe,0x00000000,0x00000000}},	//   _loll, _cật_, --, --,
   {{0x7c26a9cd,0x64555b11,0x6575a9ce,0x6b8401ff}},	// [c4e0] mokr, _auzi, _bezh, _idig,
   {{0x61e119d6,0x645501e2,0x63a22791,0xa2c21e18}},	//   _noll, _buzi, wfon, लिस्,
   {{0x399b00c1,0x65750090,0x6455001f,0x35c9009f}},	//   _אייד, _dezh, _cuzi, राज़,
   {{0x24860181,0x25f00096,0xfc4a00fe,0x7794010d}},	//   čom_, _इतकी_, _gật_, _خیرا,
   {{0x0cb01c83,0xc6940130,0x91e60686,0x64480036}},	//   _जन्म, _דאָ_, лоде, _èdim,
   {{0x61e11fb7,0x2fcf0f2a,0x6455a9cf,0x7c260094}},	//   _coll, _angg_, _fuzi, hokr,
   {{0xee0900c7,0x6455a9d0,0x7c26a9d1,0x61e1a9d2}},	//   রকাশ_, _guzi, kokr, _doll,
   {{0xd25200cd,0x6b84083e,0xdb040072,0x764e0027}},	//   _هنر_, _ndig, _laiñ, _hiby,
   {{0x61e1a9d3,0x224c005c,0x3df423c3,0x644200c2}},	//   _foll, _tidk_, изис, mmoi,
   {{0x57e102e8,0x61e1a9d4,0x6b84a9d5,0x644200c2}},	//   _नव्ह, _goll, _adig, lmoi,
   {{0x8066124c,0xc22300cd,0xf066041f,0xb5fb006e}},	//   _свеж, _اکنو, _скеп, גליכ,
   {{0x764ea9d6,0xab6203a3,0x4426a9d7,0x6442a9d8}},	//   _liby, şünd, noo_, nmoi,
   {{0x61e107d1,0x6b8402ad,0xeb071675,0xdb060220}},	//   _yoll, _ddig, учно, teká,
   {{0x764e0193,0x5a34004d,0xe80200aa,0x61e100b3}},	//   _niby, йнят, रोसा_, _xoll,
   {{0x4426a9d9,0x7c860360,0xd7d10285,0xdcea078e}},	//   koo_, _суле, हालच, _defă,
   {{0xb8dd8380,0x44261b3f,0x6455a9da,0xdb0605f1}},	//   _इन_, joo_, _ruzi, seká,
   {{0x4426a9db,0xfc4a0028,0x55752c13,0x6455a9dc}},	// [c4f0] doo_, _vật_, игат, _suzi,
   {{0xdb0401c8,0x764e03a8,0x00000000,0x00000000}},	//   _gaiñ, _ciby, --, --,
   {{0x38c900d0,0xfc4a00de,0x44b5002d,0x764e0150}},	//   _شادی_, _tật_, рбес, _diby,
   {{0x61e1a9dd,0x44260694,0x628b0786,0x56950077}},	//   _soll, goo_, trgo, _камт,
   {{0x61e13763,0x60c800da,0x645a0482,0x7afd042c}},	//   _poll, _ardm, _étin, nzst,
   {{0x6455600a,0xaca40af0,0x200602fa,0x764e0361}},	//   _tuzi, _asọy, _amoi_, _giby,
   {{0x4426a9de,0x61e14779,0x1fb523b8,0x00000000}},	//   boo_, _voll, аспр, --,
   {{0x3fe5032d,0x61e10703,0x4426041c,0x776d008c}},	//   ржив, _woll, coo_, nbax,
   {{0x63a9a9df,0x764e05bd,0xa024042c,0x60c80365}},	//   _iben, _yiby, _stöß, _erdm,
   {{0x67ea00b6,0x61e10063,0xe7d10034,0xdb060233}},	//   _výji, _uoll, हाँप, lekç,
   {{0xee3600d3,0xdb04002b,0xcb6a14f2,0xa3bc750e}},	//   рнэ_, _raiñ, кане_, _असम_,
   {{0x92d70081,0xdce800d2,0x00000000,0x00000000}},	//   ানী_, ladě, --, --,
   {{0x63a900cd,0x6e674487,0x67f80139,0x776d31ed}},	//   _mben, _стеж, _jíje, dbax,
   {{0xb5fba9e0,0xfe701f11,0x7e69a9e1,0x7c260103}},	//   _stán, _رده_, mpep, sokr,
   {{0x7c263fc8,0x63a9a9e2,0x4426a9e3,0xd94626b8}},	//   pokr, _oben, yoo_, реви,
   {{0x4426a9e4,0x764e0512,0x6442014b,0x63a985e8}},	//   xoo_, _siby, xmoi, _nben,
   {{0x44263851,0xa6651374,0x7e69084e,0x00000000}},	// [c500] voo_, مطلو, npep, --,
   {{0x63a9a9e5,0xb8dc0033,0x28ea00ae,0xfdf5023a}},	//   _aben, _আপ_, _адоп_, इसिस_,
   {{0xb5fba9e6,0x63a900bd,0x44265f35,0x00000000}},	//   _itál, _bben, too_, --,
   {{0xb5fb0018,0x03a6430b,0xa87b00c1,0x8755008f}},	//   _után, ридо, _באטר, _гърц,
   {{0x442663ae,0xdce3030b,0x764e04de,0x00000000}},	//   roo_, _peně, _tiby, --,
   {{0x4426025e,0x63a97403,0x80aa0081,0x645a020d}},	//   soo_, _eben, কিস্, _étio,
   {{0x442600c2,0xdb0f1de1,0x25aa0231,0x00000000}},	//   poo_, recé, _ibbl_, --,
   {{0x4fc6559f,0x7afd4bdc,0x67f8037a,0x63a90032}},	//   рска, yzst, _fíje, _gben,
   {{0x7e6907ac,0x7e6d04a8,0x386d14f3,0x386a0231}},	//   gpep, _çapl, ćeri_, hpbr_,
   {{0x7f860103,0x00000000,0x00000000,0x00000000}},	//   _چلان, --, --, --,
   {{0xddc905db,0x00000000,0x00000000,0x00000000}},	//   bsež, --, --, --,
   {{0x7afd0364,0x00000000,0x00000000,0x00000000}},	//   tzst, --, --, --,
   {{0x8fa300ae,0xbea31782,0x9ce60033,0x00000000}},	//   _фаче, _мацк, খছেন_, --,
   {{0x7afd5c07,0x00000000,0x00000000,0x00000000}},	//   rzst, --, --, --,
   {{0xfc640177,0xf8073778,0x9c7c0138,0x201899c6}},	//   _اختی, ачан, kyči, _íris_,
   {{0x25aa026e,0xe80202d5,0x69da6a47,0x3f8602c6}},	//   _abbl_, रोला_, öter, _jdou_,
   {{0x7c2da9e7,0x67ea0088,0x6284013f,0xa3da007f}},	// [c510] _ikar, _nýju, šioj, ़ान_,
   {{0x63a9005c,0x6f0d00c4,0xd84300d2,0x00000000}},	//   _sben, _žack, dačů_, --,
   {{0x090500c7,0x7c2d00bd,0x00000000,0x00000000}},	//   _শুরু_, _kkar, --, --,
   {{0x97a70379,0xdb16037a,0x3f866e92,0x68e802c3}},	//   _трол, _hayá, _ndou_, ädde,
   {{0xfc4a0023,0xdb06026a,0x7c2da9e8,0x6235001f}},	//   _mập_, rekç, _mkar, беду,
   {{0xfc4a0028,0xa4d5097a,0x00000000,0x00000000}},	//   _lập_, _логі, --, --,
   {{0x92d700c7,0x7c2da9e9,0x601e01d3,0x490d02d5}},	//   ানে_, _okar, zīme, _डेमो_,
   {{0x43940084,0xc918028c,0x325503a0,0x7c2da9ea}},	//   _масс, יחות_, _гвар, _nkar,
   {{0x442d38cd,0x443fa9eb,0xa3bc0096,0xfaff023b}},	//   _ike_, _ihu_, _असत_, jzë_,
   {{0x7c2da9ec,0x6e284f88,0x7e692977,0x079202c6}},	//   _akar, godb, rpep, _čímž_,
   {{0x443f0028,0xdb06a9ed,0x661701ff,0xfc4a020b}},	//   _khu_, ndkö, inxk, _bập_,
   {{0xb5fb0618,0xfc4a0028,0x26cb0036,0x6e9500ae}},	//   _stál, _cập_, _orco_, _гиду,
   {{0x442da9ee,0xeb97013d,0xfc4a0023,0x200d15e7}},	//   _mke_, щия_, _dập_, miei_,
   {{0x7c2d0a00,0x200d0a34,0x237d0197,0x433a006e}},	//   _ekar, liei_, hawj_, טערב,
   {{0x442da9ef,0x443f0129,0x7c9500e3,0x291e026a}},	//   _oke_, _ohu_, _العص, çta_,
   {{0x2fdf0291,0x442d38cd,0x200d0012,0x443f0019}},	//   njug_, _nke_, niei_, _nhu_,
   {{0xed1607d9,0xe61a02fd,0xe7e9009f,0x26cb0090}},	// [c520] _نہیں_, гда_, _टकरा_, _crco_,
   {{0x442da9f0,0x443f0129,0xcb1300ca,0x200d2a9a}},	//   _ake_, _ahu_, _מלח_, hiei_,
   {{0xa9bb0089,0x92d70081,0x75e00103,0x2ba502d5}},	//   _גזיר, ানো_, _közz, ग्वा,
   {{0x443fa9f1,0x037a2ba0,0xa6df0033,0x645a5b86}},	//   _chu_, احات_, _নেওয়, _étim,
   {{0x1db702d5,0x217802e3,0x200d15e7,0x81b30033}},	//   _असंत, айлы_, diei_, য়ান_,
   {{0x442da9f2,0x27e0a9f3,0x3ea00084,0x443f47a3}},	//   _eke_, ljin_, _äiti_, _ehu_,
   {{0x657e0060,0x845900d3,0x200d00ae,0xdb1f0052}},	//   maph, _врут_, fiei_, _paqë,
   {{0x74161850,0x27e0a9f4,0x657e0060,0x5f940476}},	//   _اورا, njin_, laph, циит,
   {{0x644002fd,0xfc4a00fe,0x920500e8,0x6e2820a8}},	//   _ihmi, _rập_, _spāņ, todb,
   {{0xf1a900bf,0x22f700a1,0xf2e700cd,0x628da9f5}},	//   _نامه_, _הזמן_, _دکمه_, šaoc,
   {{0xa3bc02e8,0x705603ef,0x6282008a,0x11d70037}},	//   _असा_, _انصا, lsoo, _دولة_,
   {{0x27e06c1e,0x200d5cac,0x442d028d,0xdfd00037}},	//   jjin_, ciei_, _xke_, _زيت_,
   {{0x6282a9f6,0x6e280087,0x657e019f,0x45000033}},	//   nsoo, podb, kaph, ্থিক_,
   {{0x62820139,0x998300b6,0x27e00167,0xac7305bc}},	//   isoo, rojů_, ejin_, _کاوش,
   {{0x16d107e2,0xfc4a00ef,0x37ab5cf7,0xdb16037a}},	//   सम्ब, _tập_, лтан_, _vayá,
   {{0x27e0023b,0x7c2da9f7,0x237d01fa,0xdb0f2ebe}},	//   gjin_, _ukar, xawj_, lecí,
   {{0x36d40cfc,0x44c80491,0x2bd609a0,0xf77f0231}},	// [c530] потр, _ağ_, धारा, _coça_,
   {{0x443f38fa,0x9b9500bf,0x442da9f8,0x657e0060}},	//   _shu_, _الکت, _ske_, gaph,
   {{0x2bdd0557,0xe7c40386,0x443f804d,0x442d00ec}},	//   यापा, _लोकप, _phu_, _pke_,
   {{0x6282112f,0x437473d1,0xdb0f016d,0x200d0afd}},	//   fsoo, пушт, mecâ, xiei_,
   {{0x6282a9f9,0x657e0201,0x200d0606,0x26cb05db}},	//   gsoo, baph, viei_, _urco_,
   {{0xa2ba0789,0x237d023e,0x657e0415,0x67460031}},	//   _एनर्, sawj_, caph, ňujú,
   {{0x443fa9fa,0x200d002d,0x80c00640,0x91bf0174}},	//   _thu_, tiei_, विगे, _atụ_,
   {{0x442d00d6,0x4fe90399,0x62820188,0x0e650975}},	//   _uke_, рмин_, bsoo, окин,
   {{0x200d45c0,0x2bdd063c,0x2a6901fa,0xdb0f0328}},	//   riei_, याना, _ntab_, fecí,
   {{0x200d0a34,0xac8506b2,0xdb040231,0x320e00d7}},	//   siei_, огол, _maiô, cify_,
   {{0xab5b6225,0x200d2972,0x2a6903a8,0x1ddb0096}},	//   rdün, piei_, _atab_, बाबत,
   {{0xeb9a0207,0x1b4a09b8,0x657e246c,0x3ed513c3}},	//   шим_, изни_, zaph, _وقار,
   {{0xce6b4ab5,0x7cff0065,0x201d02a4,0xdee51360}},	//   _сред_, _báré, _ijwi_, _фоли,
   {{0x0dcb0831,0x64480451,0xd7f10023,0xf77f016d}},	//   _људи_, _èdiv, ễn_, _roça_,
   {{0x2a6901e9,0x9c65001c,0x75e0020e,0xf65f02b6}},	//   _etab_, _بهبو, _gözy, _fræk_,
   {{0x6ecd030b,0xf77f0231,0xab5b6abc,0xc7b20076}},	//   तिपु, _poça_, ndül, بّر_,
   {{0xe57a0114,0x7bd6023f,0x27e09532,0x060a0831}},	// [c540] иза_, _inyu, rjin_, анак_,
   {{0x7bd601fa,0x64402acb,0x67f80103,0x7cff0065}},	//   _hnyu, _shmi, _díja, _gáré,
   {{0x2eb61827,0xdddb08a9,0xd9467943,0x78ad00b6}},	//   _अन्त, kruž, _фени, čová,
   {{0x2bdd0f82,0x926a3fee,0xd36f00e3,0x657e019f}},	//   याया, арка_, نهم_, saph,
   {{0xdddb8387,0x7bc4a9fb,0x2bac4255,0x320ea9fc}},	//   druž, _maiu, ट्या, tify_,
   {{0x628239b2,0x657e0201,0xdbdd0139,0xdce30a39}},	//   rsoo, qaph, _dáùs, _lenđ,
   {{0xfbca030b,0x2bdd0403,0x62827c85,0x80bd00b6}},	//   ियाम, यामा, ssoo, _वैदे,
   {{0x657ca9fd,0xeeaa8b4f,0x7bc412f5,0x645c044c}},	//   _herh, аток_, _naiu, _iuri,
   {{0xdefa3dbc,0x645c2e1c,0xdde300d3,0xcf260037}},	//   рый_, _huri, ârşi, غربي,
   {{0x645ca9fe,0x50d6006f,0x614600d3,0x7bd64e2a}},	//   _kuri, _وزار, _деза, _anyu,
   {{0x26c900e9,0xdb0f04d8,0x657c01e8,0x645ca9ff}},	//   zvao_, recí, _merh, _juri,
   {{0x645caa00,0xb5fb02c6,0x61e8aa01,0x00000000}},	//   _muri, _pták, _hodl, --,
   {{0x2bdd000c,0x657c0149,0x61e8574c,0x63a000dc}},	//   याबा, _oerh, _kodl, _mcmn,
   {{0x81d80033,0x645caa02,0x7bd613c2,0x628e01d3}},	//   াসক_, _ouri, _enyu, _ābol,
   {{0xf65f052f,0x61e81670,0x77930281,0x00000000}},	//   _træk_, _modl, ویدا, --,
   {{0xcb0b0747,0x3e6006a3,0x68e802c3,0x61e8039f}},	//   _вход_, _kòt_, ädda, _lodl,
   {{0x657c03b4,0x645caa03,0x81b30033,0x6ecd023a}},	// [c550] _berh, _auri, য়াত_, तियु,
   {{0xdce1013f,0x2bac0034,0x35b4120a,0x645caa04}},	//   galė, ट्ठा, мбур, _buri,
   {{0x3e6014b1,0x69d71b26,0x645c0133,0x00000000}},	//   _lòt_, _inxe, _curi, --,
   {{0x6b9d73dc,0x645caa05,0x69c5aa06,0x69c7aa07}},	//   ngsg, _duri, _hahe, ldje,
   {{0xa3bc04dd,0x657caa08,0x21692549,0x69c5aa09}},	//   _असर_, _ferh, били_, _kahe,
   {{0x69c7aa0a,0x645c2a7e,0x61e8aa0b,0x69c500bc}},	//   ndje, _furi, _codl, _jahe,
   {{0x29038c7e,0x758203ed,0x645caa0c,0x69c5aa0d}},	//   nzja_, _سینم, _guri, _mahe,
   {{0x69c5aa0e,0xb5fb030b,0x765d00dc,0x3e6005aa}},	//   _lahe, _stáh, _kusy, _bòt_,
   {{0x645caa0f,0x3e60022b,0x61e800f0,0x7bc4aa10}},	//   _zuri, _còt_, _fodl, _raiu,
   {{0x645caa11,0x765d0da3,0xc3320341,0x69c5aa12}},	//   _yuri, _musy, _טון_, _nahe,
   {{0x645caa13,0x00000000,0x00000000,0x00000000}},	//   _xuri, --, --, --,
   {{0xe672008e,0x69d724df,0x75f3026a,0xb5fb0037}},	//   _ölçü, _anxe, _hızı, _dtái,
   {{0x69c5aa14,0x75f301e8,0x765d00dc,0x61e8aa15}},	//   _bahe, _kızı, _nusy, _yodl,
   {{0xcefd008e,0x7c270087,0xa9671756,0xee380c10}},	//   ığın_, čkra, зира_, _дні_,
   {{0x69c502e2,0x31af03a3,0xf7721823,0xa3bc66d3}},	//   _dahe, mızı_, فاء_, _असल_,
   {{0x69d71390,0xb8e4022d,0x645c02a4,0x69c701c0}},	//   _enxe, _एन_, _ruri, adje,
   {{0xa3df0d0b,0x645caa16,0xdb9b03c2,0x657c3611}},	// [c560] तान_, _suri, _הספר, _perh,
   {{0x2c612299,0x31af1f8a,0x3c320579,0x765d8cf4}},	//   _kód_, nızı_, rávu_, _dusy,
   {{0x657c0d50,0x6fbd244d,0x645c01ee,0x76550383}},	//   _verh, ्यां, _quri, _dizy,
   {{0x2c61470e,0xe3636e90,0xa3e702d5,0x645caa17}},	//   _mód_, екци, मॉल_, _vuri,
   {{0x61e828f9,0x657c529f,0x645c1114,0x60c1005c}},	//   _podl, _terh, _wuri, _aslm,
   {{0x26c27bdb,0xb5fb0143,0x22bd0154,0xd259021a}},	//   _isko_, _cuád, _dňk_, іці_,
   {{0x645c0006,0x777d006c,0xf1a9001c,0x61e80128}},	//   _uuri, _yesx, تانه_, _vodl,
   {{0x3e6002f1,0x22bd02f1,0x6299654e,0x289b0a41}},	//   _pòt_, _fňk_, buwo, ציפא,
   {{0xb5fb00e3,0x2903003d,0x61420065,0x00000000}},	//   _stái, zzja_, _bílí, --,
   {{0x720600d0,0xf1aa00cd,0xa3da0ed3,0x3e6002f1}},	//   _عوام, _داره_, ़ाव_, _vòt_,
   {{0x2c6100e3,0x644843bd,0xdc3f00b6,0xdb0f0072}},	//   _cód_, _èdis, síčn, decá,
   {{0xa3df0096,0x23663177,0xaab900b6,0xdb0f015e}},	//   ताय_, ncoj_, इबलक, tecà,
   {{0x69c53334,0x6abd01c0,0x6b9d032e,0xfe466e52}},	//   _pahe, uwsf, rgsg, _ендо,
   {{0x225906a3,0xa3b32235,0x765daa18,0xf77f016d}},	//   _èske_, _जॉन_, _rusy, _poço_,
   {{0x69c505a7,0xa3bc02e8,0x26c202a7,0x28f80084}},	//   _vahe, _असं_, _asko_, перь_,
   {{0x2d9e5c05,0x69c5aa19,0xe80d0096,0x76550383}},	//   lgte_, _wahe, _सगळा_, _sizy,
   {{0x69c5226c,0x6565aa1a,0x6b8daa1b,0x2d9e04e2}},	// [c570] _tahe, tchh, _idag, ogte_,
   {{0x2d9e41ed,0x317e01bf,0x2fc600f9,0xdcf8aa1c}},	//   ngte_, _netz_, _laog_, _levč,
   {{0x765539a1,0x7a323e59,0x6565042c,0x1dae0bba}},	//   _vizy, rætt, rchh, ज्यत,
   {{0x7a3201c5,0xe3b300e3,0x76550034,0x656513c5}},	//   sætt, عرض_, _wizy, schh,
   {{0xa3df4d14,0x38c702c6,0x6fbd07ad,0xb2ab00e5}},	//   ताब_, bírá_, ्यसं, стеж_,
   {{0xf77f01d4,0x75f30092,0x7c2f00da,0xa2c20179}},	//   _heç_, _qızı, hocr, लिज्,
   {{0x63b900a5,0x2fc60270,0xf77f00a7,0xdb060537}},	//   pewn, _baog_, _keç_, sekø,
   {{0xa0091e56,0x6b8d6698,0xb4e92a29,0xdcf8007e}},	//   تقبل_, _ndag, यही_, _cevč,
   {{0xa3da00a5,0xdcf80234,0x7c2f5809,0x00000000}},	//   ़ार_, _devč, docr, --,
   {{0xee360138,0x6b8daa1d,0x64480036,0x2d9e042c}},	//   мны_, _adag, _èdir, ggte_,
   {{0xdb1d2317,0x628400c6,0x00000000,0x00000000}},	//   ndsæ, šiot, --, --,
   {{0x442f005f,0xe7d80081,0x2ef5249c,0x28d10285}},	//   nog_, _সত্য, _озер, हिनि,
   {{0xee2e4d40,0x6fda0789,0x6b8d0361,0xef0e282f}},	//   _ан_, भारं, _ddag, _рм_,
   {{0x442faa1e,0x7d280018,0x6b8d010a,0xdce801d3}},	//   hog_, épsé, _edag, gadē,
   {{0x442f02e6,0xd9ff04a9,0xeb9f01df,0xc7a600e5}},	//   kog_, _उतरत_, giøs_, мивк,
   {{0xdb1605e6,0x3f9f0239,0xfaff0216,0x442f01f3}},	//   _mayú, nguu_, rbër_, jog_,
   {{0xe73702fd,0x442f02ad,0xf41300c7,0xdb0f016d}},	// [c580] дет_, dog_, িকার_, pecá,
   {{0xa3b30f35,0x7a3202b6,0xfa970266,0x3dc7022b}},	//   _जॉब_, ræts, _קדיש_, _janw_,
   {{0xdce10029,0xc486002d,0xfaff00dd,0x628900e7}},	//   dalī, флек, ncën_, _aveo,
   {{0x442f03ce,0xb4ae000f,0x225f0124,0xf77f01e8}},	//   gog_, _कही_, _buuk_, _geç_,
   {{0x26c20a56,0x2d9e02b6,0xc17a004d,0xdcf805db}},	//   _usko_, ygte_, оїй_, _revč,
   {{0xb5fb025b,0xeb9f0856,0xbbca0e52,0xddc20117}},	//   _stáv, niør_, ियुक, _otoš,
   {{0x442fa01f,0xe5a35e41,0xa2c202c6,0x35a35b74}},	//   bog_, _шири, लिङ्, _шарг,
   {{0x442f001c,0x232aaa1f,0xab5b03e0,0xc0e70076}},	//   cog_, _доби_, rdük, ظفين_,
   {{0x2bdd13b4,0xfbdd0403,0x3dc703a8,0xdcf805db}},	//   यासा, यासम, _banw_, _vevč,
   {{0xdd9026a0,0xdb0f20df,0x20180103,0x3dc7030a}},	//   دود_, lecç, őri_, _canw_,
   {{0x559700f5,0x2d9eaa20,0x91e300d3,0x3dc70154}},	//   ודיע_, rgte_, _шофе, _danw_,
   {{0x225f0479,0xdb0f0231,0x00000000,0x00000000}},	//   _yuuk_, necç, --, --,
   {{0xa3df0454,0x81b300c7,0xb4bb0592,0x6ab90179}},	//   तात_, য়ার_, _अन्_, इबेर,
   {{0x3f84aa21,0xfd0f00d0,0x442faa22,0x2bdd052c}},	//   lamu_, اجی_, zog_, याहा,
   {{0x195804d9,0xa9340879,0xcec80028,0x442faa23}},	//   дары_, верш, _hộ_, yog_,
   {{0x3f84aa24,0x442f023e,0xeb9f01df,0xdb0e00d4}},	//   namu_, xog_, riøs_, škát,
   {{0x442f00e9,0xf77f023b,0x2a60009c,0xba3b00ee}},	// [c590] vog_, _veç_, _guib_, juïg,
   {{0x3f84a06f,0xcec80019,0x442f00f0,0x2bdd09c4}},	//   hamu_, _mộ_, wog_, यावा,
   {{0x3f842826,0xcec80028,0x628908a9,0xdb0f0161}},	//   kamu_, _lộ_, _sveo, fecç,
   {{0x3f84aa25,0xfc4a0023,0xb5fb0503,0x61f801d0}},	//   jamu_, _bậy_, _atát, ekvl,
   {{0x3f8429f7,0xfc4a00de,0x644b057e,0xcec80023}},	//   damu_, _cậy_, rmgi, _nộ_,
   {{0x442f8efa,0xfc4a0019,0x21690686,0x00000000}},	//   sog_, _dậy_, чики_, --,
   {{0x20550b73,0x236004eb,0x442f01ac,0x81b30081}},	//   нтир, žija_, pog_, য়াল_,
   {{0xcec800ef,0xa2ba2a24,0x4439aa26,0x3f84aa27}},	//   _bộ_, _शैक्, _ós_, gamu_,
   {{0xef193e04,0x15f322a3,0xdb1d160c,0xcec80023}},	//   ями_, _आकार_, ndsä, _cộ_,
   {{0x645a0428,0xba3b00b3,0x00000000,0x00000000}},	//   _ètic, nuïd, --, --,
   {{0x3f8463c1,0xfc4a00fe,0xc1e60103,0x9b0601c2}},	//   bamu_, _zậy_, _سکول_, ɗuƙi_,
   {{0xc4d200c1,0x26c00150,0xfaff0052,0xc6230033}},	//   אגט_, ywio_, rcën_, _বীমা_,
   {{0x539a00ca,0x501a006e,0x3dc7022b,0x00000000}},	//   הירו, _צונו, _tanw_, --,
   {{0x6da50cc6,0x1d09aa28,0xbea241c8,0x00000000}},	//   _чика, _нели_, _сашк, --,
   {{0xb4ae0da9,0xd8261756,0xba3b05fe,0x2d853475}},	//   _कहे_, едви, duïd, male_,
   {{0x6d4302e6,0x2d8586f3,0xdbdd0065,0x66e60c3f}},	//   _izna, lale_, _dáós, ноба,
   {{0x7c2437dc,0x2bdd2125,0x3855008f,0xdb060103}},	// [c5a0] _ijir, यारा, търс, nekü,
   {{0x2d85aa29,0x3f84aa2a,0x2bac034d,0x3861042c}},	//   nale_, zamu_, ट्रा, _fuhr_,
   {{0xdb06007a,0xdb0f0161,0xddd80154,0xdbdc0065}},	//   hekü, tecç, _divň, _káàb,
   {{0x0326160b,0x2d85aa2b,0xb5fb030b,0xff470981}},	//   нден, hale_, _stát, _مخ_,
   {{0xc7b300a1,0xba3b0428,0xdb0f016d,0x7d0606f0}},	//   _גבר_, buïd, recç, _kéré,
   {{0xfc4a0028,0x2d8500bc,0x3f842c4a,0xcec80023}},	//   _vậy_, jale_, wamu_, _rộ_,
   {{0x2d85aa2c,0x154302a0,0x3f84aa2d,0xa3ea2a6e}},	//   dale_, _берм, tamu_, _едва_,
   {{0x7c245080,0xf65f02b6,0xbbca023a,0x7d060139}},	//   _njir, _træt_, ियोक, _léré,
   {{0x3f84aa2e,0x24170105,0xfe6f03ed,0x6d43aa2f}},	//   ramu_, _נחמן_, یدی_, _azna,
   {{0x3f842d30,0x63a2aa30,0x7c240010,0x00000000}},	//   samu_, lgon, _ajir, --,
   {{0x3f8402e7,0x2bdd2a45,0xdbdc0139,0x6ab92c5f}},	//   pamu_, याला, _báàb, इब्र,
   {{0x63a2aa31,0x68f5013f,0x3861374f,0xb4ae074c}},	//   ngon, vyzd, _ruhr_, _कहै_,
   {{0x7f420415,0x63a201af,0xdcf801d3,0xdbdc0065}},	//   _uzoq, igon, _devā, _dáàb,
   {{0x2d85aa32,0x7c2400ac,0x7d060257,0x9f5d022b}},	//   cale_, _ejir, _céré, _alwè_,
   {{0x7d06aa33,0x2c860032,0xdbdc0032,0xb5fb0131}},	//   _déré, _dídá_, _fáàb, _otár,
   {{0x7c24023b,0x7e620ae3,0xdb1d0052,0xba3b00ee}},	//   _gjir, _kuop, nesë, duïe,
   {{0xa3da05d4,0x63a2aa34,0x7e62007b,0xa3df00a4}},	// [c5b0] ़ाई_, dgon, _juop, तास_,
   {{0x63a26405,0x7d06020d,0x7c3d45d9,0x00000000}},	//   egon, _géré, llsr, --,
   {{0xd3710fb7,0xb7d90068,0xd49b1fb3,0x7e6200c2}},	//   لها_, _ہوگا_, яра_, _luop,
   {{0x63a2aa35,0x2d85aa36,0x30af0081,0xdb1d0052}},	//   ggon, zale_, কিৎস, jesë,
   {{0x2d85aa37,0x27e90968,0x7d0600d1,0xb5fb033c}},	//   yale_, mjan_, _yéré, _dtár,
   {{0xe1f800c6,0xb5fb016d,0xa3df03b3,0xba3b00b3}},	//   нгі_, _etár, ताह_, buïe,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d85764e,0xdb1d0052,0x201f044c,0x79871e4a}},	//   wale_, gesë, unui_, hajw,
   {{0x32555be9,0x1e8201b6,0x27e9aa38,0x6449039f}},	//   _авар, алым, ijan_, _ihei,
   {{0x7c36aa39,0xa3df3542,0x27e9007b,0x644901b9}},	//   _skyr, ताव_, hjan_, _hhei,
   {{0xeb9a188d,0xfbdd0980,0x4e950018,0x64490350}},	//   мин_, यांम, رشکر, _khei,
   {{0x0f150084,0x88c00081,0x7d06020d,0x2d858f51}},	//   _имею, _উপলক, _séré, sale_,
   {{0xa3b305cd,0x64490a6c,0x27e9201a,0x628baa3a}},	//   ज्य_, _mhei, djan_, nsgo,
   {{0xaa46008f,0x2d85019f,0x27e9037a,0x645b009c}},	//   тегл, qale_, ejan_, _liui,
   {{0x6d431670,0x6449007b,0x7c2402ac,0x28b900d3}},	//   _uzna, _ohei, _tjir, нутэ_,
   {{0x2fcd462c,0x27e9aa3b,0x73ec0081,0x7c24aa3c}},	//   ndeg_, gjan_, _কষ্ট_, _ujir,
   {{0x3eadaa3d,0x9f4f05fe,0x9663007e,0x6f090036}},	// [c5c0] ntet_, _algú_, икте, nzec,
   {{0x6b8400ca,0x3ead02e2,0xd90d12eb,0x628b68f2}},	//   _heig, itet_, _کیف_, dsgo,
   {{0x6449328f,0x26cf0222,0x6b8401b9,0x69de0634}},	//   _bhei, ågor_, _keig, _inpe,
   {{0x6449aa3e,0x3eadaa3f,0x6b8401b3,0xe29a007e}},	//   _chei, ktet_, _jeig, дад_,
   {{0x64490a21,0x23600087,0x645b033c,0x6b84aa40}},	//   _dhei, žijo_, _diui, _meig,
   {{0x6b84aa41,0x3ead53d3,0xb5fb034f,0x80ce00c3}},	//   _leig, dtet_, _huán, थिले,
   {{0x6449006b,0xdb1d0052,0x3ead042c,0x00000000}},	//   _fhei, tesë, etet_, --,
   {{0x6449117b,0x3ead0e9f,0x765c0193,0xb4de0096}},	//   _ghei, ftet_, _hiry, तमी_,
   {{0xa3df0b7f,0x3f9808bb,0x3ead052f,0x765c5d9e}},	//   तार_, ğru_, gtet_, _kiry,
   {{0x27e900bd,0xa3da08d4,0x2004023b,0xa8060491}},	//   zjan_, ़ाक_, shmi_, llığ,
   {{0x6b84aa42,0xf1a900cd,0xd59b00a1,0x659b00a1}},	//   _beig, _ساله_, וביל, וייק,
   {{0xa80608bb,0x765caa43,0x69de06a3,0x69ce0b7c}},	//   nlığ, _liry, _anpe, edbe,
   {{0x6b84aa44,0xddc97a2d,0x79870051,0x6f09aa45}},	//   _deig, speš, tajw, czec,
   {{0x5a340a67,0x765c05bd,0x69ce18ef,0x7d0d00d2}},	//   инят, _niry, gdbe, _řase,
   {{0x27e9aa46,0xa806026a,0xaa582917,0x97a7105b}},	//   tjan_, klığ, тиру_, крал,
   {{0xb5fb09b3,0xf7730602,0x69de4bec,0x7af2023b}},	//   _cuán, شار_, _enpe, ëjtë,
   {{0x64491a33,0x27e932f5,0x35b50b21,0x765caa47}},	// [c5d0] _rhei, rjan_, лбар, _biry,
   {{0x6b8402e2,0x6449aa48,0xfc3f0037,0x645b009c}},	//   _zeig, _shei, llí_, _siui,
   {{0xa3df0abe,0x290a00a5,0x2baa009d,0x7bcd00f9}},	//   ताल_, czba_, _कामा, _kaau,
   {{0x3eadaa49,0x7b080511,0x765caa4a,0x00000000}},	//   ytet_, _örtü, _eiry, --,
   {{0x02a75be3,0xe299aa4b,0x877a0327,0xfc3f0076}},	//   трем, хал_, _ראשי, ilí_,
   {{0x7d150220,0x785c0995,0xb6da00c1,0x765c0172}},	//   úzsk, _učvr, _אַלט, _giry,
   {{0x64494f4e,0xa3ab02d5,0xdb04009c,0x5f18007f}},	//   _thei, _खाप_, _dbiù, _बेब्_,
   {{0x3ead0c2e,0xb4c11e9f,0x44d31912,0x798501c2}},	//   ttet_, ्टी_, _ić_, _lehw,
   {{0xdbdd0088,0xf1a72fd4,0xfc3f00b6,0x63a904ff}},	//   _ráðs, _арен, dlí_, _icen,
   {{0x3ead0e78,0x41c006ed,0x6b84aa4c,0x7bdf769f}},	//   rtet_, _एसएस, _seig, _anqu,
   {{0x3ead3e92,0xed580181,0x6b84aa4d,0x25a50088}},	//   stet_, teľa_, _peig, _öllu_,
   {{0x3ead8a94,0x7d1c0037,0x63a900b3,0x9f4d007b}},	//   ptet_, úrsa, _jcen, tkeä_,
   {{0xfbaa000d,0xa3ab05e4,0x6b84aa4e,0xa806008b}},	//   _काठम, _खान_, _veig, nlış,
   {{0x6e920080,0x5e9200e3,0x6b847c06,0xbf3600c1}},	//   _الوا, _الوط, _weig, _גאנץ_,
   {{0x63a9069a,0xfc3f0080,0x6b84013f,0x3e690019}},	//   _ocen, blí_, _teig, _hút_,
   {{0x765c0842,0xfc3f0037,0x3e69823c,0xb5fb00fe}},	//   _siry, clí_, _kút_, _quán,
   {{0x66e317aa,0x464a0058,0x00000000,0x00000000}},	// [c5e0] бота, езан_, --, --,
   {{0xfdfc07e2,0x63a99795,0xb4c117ff,0xa50a036f}},	//   एसएस_, _acen, ्टू_, неза_,
   {{0xa3df0714,0xa8060491,0xb4de058f,0x66fa01d3}},	//   तां_, tlığ, तमे_, _sākā,
   {{0x289b006e,0x765c4c93,0x3775002d,0x00000000}},	//   _איטא, _wiry, _вырс, --,
   {{0xa806008e,0x3e690019,0x8c1b00ca,0x753c0034}},	//   rlığ, _nút_, עוני, _wyrz,
   {{0xb5fb00d8,0x00000000,0x00000000,0x00000000}},	//   _utáp, --, --, --,
   {{0x66032820,0xdb1d0068,0xab5b07aa,0x2baa0096}},	//   _упра, resé, ndür, _काढा,
   {{0xb4d0009d,0xa3df87bf,0x3e6900de,0x3a3a0167}},	//   वटी_, ताः_, _bút_, _lkpp_,
   {{0x3e6900fe,0x8d860077,0x2d98002b,0xc326021a}},	//   _cút_, лунд, óreo_, _смак,
   {{0x3207000d,0xb5fb0037,0x6f1d0076,0x60cd007f}},	//   chny_, _nuál, úsca, łama,
   {{0x0ce200c7,0x236902e6,0x7bcd39c1,0x459b006e}},	//   মন্ত, žaje_, _paau, עסטע,
   {{0xac1914fa,0xdb550084,0xdcfa00c4,0x3e6900da}},	//   тому_, ивны, hatć, _fút_,
   {{0xdd92001c,0x3e6900fe,0xdb1d00f2,0xc2f80a43}},	//   _هوش_, _gút_, ndsø, _আইডি_,
   {{0xc3330054,0xfc3f0146,0xb5fb058a,0xa7fb01ff}},	//   מור_, slí_, _cuál, _miñe,
   {{0x3a3a0167,0xa7fb0072,0xb5fb05f1,0x00000000}},	//   _dkpp_, _liñe, _duál, --,
   {{0xc8643703,0x7bdf701c,0x8ae7004d,0x3f860383}},	//   стри, _unqu, _біол, _jeou_,
   {{0xa3e8000f,0xa7fb0314,0x06150c4a,0x9a272eb5}},	// [c5f0] बान_, _niñe, адаю, _معدن,
   {{0x2bdd2301,0x25b8009c,0x65954785,0x7d0403e3}},	//   याका, _cbrl_, ражу, _ƙish,
   {{0xb4c11492,0x6d5e0094,0x354707bf,0x00000000}},	//   ्टे_, _úpad, ухав, --,
   {{0xd9e30ccb,0xa7fb01ff,0x00000000,0x00000000}},	//   खावत_, _biñe, --, --,
   {{0xc7d800e5,0xa2e5007e,0x00000000,0x00000000}},	//   _смях_, ролд, --, --,
   {{0x40951e54,0xa7fb08a8,0x3e690019,0xdce801d3}},	//   арит, _diñe, _rút_, gadī,
   {{0x69ad0ec3,0x3e690023,0x44d300c4,0x854400ae}},	//   _जानी, _sút_, _uć_, _гэте,
   {{0xb275064c,0xdb160154,0x00000000,0x00000000}},	//   _влаш, _mayò, --, --,
   {{0x4fe600ae,0x24912d5a,0x9e650215,0xa7fb01ff}},	//   рмын_, _hvzm_, јвод, _giñe,
   {{0xed5940b2,0x5fa72171,0xfe42004d,0x3e6900fe}},	//   коп_, _गावल, жньо, _vút_,
   {{0x9d452dd8,0x0c2602a0,0xa7fb01ff,0x2cae014b}},	//   ренд, имон, _ziñe, _cqfd_,
   {{0x3f890102,0x26d90451,0x60dc003e,0x3e69020b}},	//   _þau_, _orso_, _árma, _tút_,
   {{0xeb975559,0xdb16037a,0xaa46166f,0x00000000}},	//   шия_, _rayó, иемл, --,
   {{0x602101d3,0x6da21ac8,0x00000000,0x00000000}},	//   dēmi, _диша, --, --,
   {{0x26cb0314,0x2d870451,0xf7720308,0x1d060c79}},	//   _asco_, _iene_, قاء_, _вещи_,
   {{0xb8de00aa,0xab5b026a,0x2d870e98,0x2fcf023c}},	//   _इह_, rdür, _hene_, _jagg_,
   {{0xb4de1d96,0x2d87aa4f,0x46a614da,0x61e1007e}},	// [c600] तम्_, _kene_, разв, _onll,
   {{0xe5773967,0x2d870754,0xe8fa00d3,0x00000000}},	//   изу_, _jene_, _ало_, --,
   {{0x2d870106,0x399b00c1,0xdce800d9,0x26cb028d}},	//   _mene_, _בייד, vadī, _esco_,
   {{0xa7fb0cda,0x2d87aa50,0x61e1403a,0x7c2623ff}},	//   _piñe, _lene_, _anll, nnkr,
   {{0xe7fb04dd,0xa3e809c3,0x213e00f0,0x2d870381}},	//   _एकता_, बाब_, _syth_, _oene_,
   {{0xa7fb04d8,0x25aa0124,0x4094001c,0xdb1d0ac9}},	//   _viñe, _ucbl_, ملتر, rdsø,
   {{0xf99300a1,0xdce801d3,0x91f50023,0x55bb00ca}},	//   קרה_, radī, _tín, _שמלו,
   {{0x44c80390,0x61e15059,0x3205aa51,0x2b5f00e7}},	//   _iş_, _enll, _elly_, žuci_,
   {{0xa3ab1e5e,0x539b0054,0x2d87aa52,0xa3cf000f}},	//   _खात_, _שימו, _bene_, _वोट_,
   {{0x2d87aa53,0x644202fd,0x78be00d6,0x6b9603a9}},	//   _cene_, lloi, _oppv, _adyg,
   {{0xd5d90130,0x44265988,0x7d0d1114,0x2d87aa54}},	//   אַרש, ono_, _ƙasa, _dene_,
   {{0x4426aa55,0xef1a11d9,0x92d80081,0xaca30065}},	//   nno_, _име_, াহী_, _gbọi,
   {{0x4426aa56,0x545713b6,0x2d87aa57,0x78be0227}},	//   ino_, יסטן_, _fene_, _appv,
   {{0x4426aa58,0xedd308ba,0x2d87aa59,0x7e6d0131}},	//   hno_, _ويند, _gene_, _éapa,
   {{0x2d8caa5a,0xe7fb009d,0x4426aa5b,0xb7fb4275}},	//   made_, _एकदा_, kno_, _एकदम_,
   {{0x442615f4,0x2d8c30bf,0x2d874a40,0x3c320094}},	//   jno_, lade_, _zene_, kávy_,
   {{0x44263e75,0xac070260,0x44c85b66,0x2d87013c}},	// [c610] dno_, _مذکو, _aş_, _yene_,
   {{0x2d8caa5c,0x4426aa5d,0x7afd00c2,0x2d870042}},	//   nade_, eno_, myst, _xene_,
   {{0x2a6901bb,0x00000000,0x00000000,0x00000000}},	//   _huab_, --, --, --,
   {{0x4426aa5e,0x2d8caa5f,0x2a6901fa,0x2d9800a5}},	//   gno_, hade_, _kuab_, órej_,
   {{0x2d8caa60,0xf2c7013d,0x60da5657,0x2a69023e}},	//   kade_, рсен, _artm, _juab_,
   {{0x2d8c4bf8,0x2a690d7d,0x2006aa61,0x1308004d}},	//   jade_, _muab_, _aloi_, шній_,
   {{0x2d8caa62,0x2a6901fa,0x2fcf028d,0xc198004d}},	//   dade_, _luab_, _pagg_, ртії_,
   {{0x442608a9,0x2d87920e,0x7afdaa63,0xe2ab0068}},	//   cno_, _sene_, kyst, _لائن_,
   {{0xee3908c3,0x63bb1084,0x2d872037,0x2d8caa64}},	//   лни_, _ibun, _pene_, fade_,
   {{0x2d8c9b96,0x2d8700dd,0x20068bed,0xdb1d01f9}},	//   gade_, _qene_, _eloi_, gesí,
   {{0x2d8755ae,0x00000000,0x00000000,0x00000000}},	//   _vene_, --, --, --,
   {{0xc0b200de,0x26c91c35,0xdbd60065,0x2d87084e}},	//   _lưới_, kwao_, _gùìs, _wene_,
   {{0x2a690197,0x63bbaa65,0x3a380212,0x7c26aa66}},	//   _cuab_, _mbun, torp_, rnkr,
   {{0x7f3a07a6,0x499902fd,0x2a6901bb,0x5d8500e3}},	//   _גענו, ится_, _duab_, _الثل,
   {{0x4426aa67,0x63bb0863,0xd9460231,0xef19007f}},	//   yno_, _obun, севи, rażu_,
   {{0x6607015c,0x7afd0220,0x63bb0174,0x5baa0183}},	//   _aljk, byst, _nbun, _ским_,
   {{0x7bc6068d,0x66e3972b,0x7afdaa68,0x26c90350}},	// [c620] meku, пота, cyst, gwao_,
   {{0x7bc6aa69,0x442600a5,0xc0b20019,0xe819250d}},	//   leku, wno_, _cưới_, नोबा_,
   {{0xc0b20028,0x78be5429,0x69ad270a,0x09f700a1}},	//   _dưới_, _uppv, _जाती, _המים_,
   {{0x4426aa6a,0x7bc6007a,0x2d8caa6b,0x2a69023e}},	//   uno_, neku, zade_, _yuab_,
   {{0x2ca53700,0x2a6901fa,0x64420503,0x321c02c6}},	//   huld_, _xuab_, rloi, tivy_,
   {{0x3c320871,0x41e200a5,0x798eaa6c,0x7bc6aa6d}},	//   rávy_, पाइस, nabw, heku,
   {{0x7afd0d1b,0xa3e80d0b,0x64a3aa6e,0x236903ce}},	//   zyst, बाद_, _нара, žaja_,
   {{0x4fc60084,0x2ca5aa6f,0x798e0193,0x661e23d4}},	//   сска, duld_, habw, lipk,
   {{0x2d8caa70,0xdb1d0018,0x7e7b2783,0x798ea56d}},	//   tade_, tesí, gpup, kabw,
   {{0x63bb04eb,0x27370019,0x7afd1402,0xa7fb03be}},	//   _zbun, ủng_, vyst, _miña,
   {{0xa7fb08a8,0x2d8c9936,0x7bc6aa71,0x7afd31f7}},	//   _liña, rade_, feku, wyst,
   {{0x7afd1e55,0x2d8caa72,0x7bc60051,0x2a69006c}},	//   tyst, sade_, geku, _puab_,
   {{0xa3ab0e72,0x2d8caa73,0xa7fb0890,0x2a6901fa}},	//   _खास_, pade_, _niña, _quab_,
   {{0x7afdaa74,0xdb040072,0x2a69023e,0x2bd90e1f}},	//   ryst, _abió, _vuab_, _बोरा,
   {{0x7bc6aa75,0x661e0085,0x1959013f,0x59f800e5}},	//   beku, dipk, равы_, щеря_,
   {{0x2a69022e,0x7bc6a0b0,0x26c90a4b,0x00000000}},	//   _tuab_, ceku, twao_, --,
   {{0x798e0193,0x35f50379,0x68e80212,0xfbd00037}},	// [c630] babw, опар, äddr, _ستي_,
   {{0x7c2d8cb9,0xd56772e0,0xa7fb01ff,0x00000000}},	//   _hjar, стап, _diña, --,
   {{0x38620063,0x7c2d0088,0x69c7aa76,0xddc20141}},	//   _fikr_, _kjar, meje, _otož,
   {{0x69c70537,0x7f42063d,0x291100e7,0x6e3aaa77}},	//   leje, _oyoq, mzza_, hotb,
   {{0x6d4e0031,0xc0b20023,0xa7fb01c8,0x7c2d024a}},	//   ýbaj, _tưới_, _giña, _mjar,
   {{0x7bc6aa78,0x69d5aa79,0x69c765ee,0x04c933e7}},	//   zeku, ndze, neje, _پوري_,
   {{0xb5fb1cf3,0x7bc61fde,0x92e90081,0x2baa0efd}},	//   _otáz, yeku, মনে_, _काला,
   {{0x63bb5fd2,0xfaff00dd,0x2ca50126,0x2bd9aa7a}},	//   _ubun, ncës_, vuld_, _बोला,
   {{0x443faa7b,0x442daa7c,0x6e3aaa7d,0x3f8d002b}},	//   _iku_, _ije_, fotb, raeu_,
   {{0xa19426d0,0x7c2d26f7,0x69c7aa7e,0x69d580e9}},	//   _науч, _ajar, jeje, jdze,
   {{0x7c2d354e,0x1ee700bf,0x442d02dd,0xfbc610f7}},	//   _bjar, _گوشی_, _kje_, обно,
   {{0x2baa009d,0x7e7b16f9,0x92bd0033,0x443f0350}},	//   _काळा, ppup, েমী_, _jku_,
   {{0x7bc639ad,0x69c70018,0x7c2daa7f,0x798e0435}},	//   reku, feje, _djar, tabw,
   {{0x7bc695ce,0x69c7aa80,0x201f013f,0x200d016d}},	//   seku, geje, liui_, lhei_,
   {{0x443faa81,0x442daa82,0x7bc6aa83,0x7c2d0088}},	//   _oku_, _oje_, peku, _fjar,
   {{0x442d66b6,0xfc3239d9,0x200d0161,0x201f013f}},	//   _nje_, _تحت_, nhei_, niui_,
   {{0xe61a251e,0xc60500c7,0x661e2048,0xe7fb05a7}},	// [c640] ада_, োচনা_, tipk, _एकरा_,
   {{0x443f26f7,0x442daa84,0xe5a315c3,0x7c2d00dd}},	//   _aku_, _aje_, дифи, _zjar,
   {{0x7e63aa85,0xec13001c,0x201f00c6,0x661eaa86}},	//   _minp, _روید, kiui_, ripk,
   {{0x66e626d0,0xa7fb08a8,0x661e7199,0x6d430178}},	//   _дома, _tiña, sipk, _myna,
   {{0x442daa87,0xf77300cd,0xa3ab149b,0x443f03a9}},	//   _dje_, _تاپ_, _खार_, _dku_,
   {{0x442daa88,0x443faa89,0x6d4308bb,0xddc22a1e}},	//   _eje_, _eku_, _oyna, _stož,
   {{0x154300d3,0x0ef40efb,0xdcf802c6,0xe47600d3}},	//   _жерм, ेन्स_, _devě, _фугэ,
   {{0x8ca304dd,0x442d4f65,0xdfda008f,0x78fb006e}},	//   _कमजो, _gje_, рък_, יפצו,
   {{0x6d4314ca,0x7e631df6,0x7e6d0231,0xddc20141}},	//   _ayna, _binp, _éapl, _vtož,
   {{0x6e2822d4,0x7e63023e,0x6d4387f2,0x7c2d611c}},	//   undb, _cinp, _byna, _sjar,
   {{0x6d4301b7,0x69c7aa8a,0xdb1d00b6,0xa3df0096}},	//   _cyna, veje, desá, ताच_,
   {{0x200daa8b,0x69ad0096,0x7ee60037,0xf77f016d}},	//   chei_, _जाही, _وكان, _onça_,
   {{0x69c7aa8c,0x6e3a0103,0x7d0401c2,0x31790103}},	//   teje, potb, _ƙiss, _őszi_,
   {{0x1fbc0081,0x7e630009,0x69d500d9,0x998300c6}},	//   _অফিস, _ginp, udze, vojų_,
   {{0x69c7aa8d,0x2905aa8e,0x6d430178,0x22be01d3}},	//   reje, ála_, _gyna, lākā_,
   {{0x7c2d39a0,0x9983013f,0x69c78edb,0x7e6301c8}},	//   _ujar, tojų_, seje, _zinp,
   {{0x356b0a7c,0x70c607d5,0x22be01d3,0xfaff0052}},	// [c650] арен_, लबुल, nākā_, rcës_,
   {{0x2bb13952,0x64400167,0x6b8d0037,0x78a70052}},	//   _झाडा, _akmi, _heag, pujv,
   {{0x6b8d0d17,0x05ac023a,0x00000000,0x00000000}},	//   _keag, _चारब, --, --,
   {{0x7c3daa8f,0x00000000,0x00000000,0x00000000}},	//   nosr, --, --, --,
   {{0x6b8daa90,0x2369033b,0x201f00c6,0x00000000}},	//   _meag, žajo_, viui_, --,
   {{0x7e6b01b3,0xbb3c006e,0x6b8d973b,0xa06932df}},	//   _rugp, בעדי, _leag, бака_,
   {{0xc5f202f8,0x7e630139,0x7e6baa91,0x442d3e08}},	//   _אדם_, _rinp, _sugp, _tje_,
   {{0xd3e30177,0x443faa92,0x6b8d00d3,0xa7fb03be}},	//   _تقری, _uku_, _neag, _miño,
   {{0x7e630af0,0xa3e80abe,0x201f0138,0xe165001c}},	//   _pinp, बार_, riui_, _فضای,
   {{0xee360084,0x443daa93,0xa3ab0caf,0x201f00c6}},	//   знь_, low_, _खाँ_, siui_,
   {{0xa7fb14e2,0x7e63aa94,0x443d01ee,0x6b8d09ff}},	//   _niño, _vinp, oow_, _beag,
   {{0x7e63aa95,0x6d4373c9,0x6b8d009c,0x22be01d3}},	//   _winp, _vyna, _ceag, bākā_,
   {{0x6d4300a5,0x6b8d01b5,0xdee52249,0xdb1d03be}},	//   _wyna, _deag, _холи, tesá,
   {{0x443d2039,0xddc300d9,0x6d430381,0xdb1d0c89}},	//   how_, _minū, _tyna, kesæ,
   {{0xdb1d0146,0x6b8d4cb6,0x443daa96,0x00000000}},	//   resá, _feag, kow_, --,
   {{0x4c9a00a1,0xf1c70146,0x27e6120d,0x661c6f61}},	//   _השקע, _hráč_, ñon_, _smrk,
   {{0x6fbd0f65,0x443d59dd,0x00000000,0x00000000}},	// [c660] व्यू, dow_, --, --,
   {{0x6569026a,0x7bd6aa97,0x6e212e35,0x64590381}},	//   _şehr, _hayu, nilb, emwi,
   {{0x14c800cd,0x6b8d010a,0x45460037,0x7d010324}},	//   تهای_, _yeag, أناق, nyls,
   {{0x68e1052f,0x443daa98,0x6e217f59,0x27f90a39}},	//   ælde, gow_, hilb, _gosn_,
   {{0x7bd6aa99,0x26c20063,0x91fc00e8,0x0ca80b3a}},	//   _mayu, _upko_, _diān, _कम्म,
   {{0x7bd6aa9a,0x6e210f8e,0x00000000,0x00000000}},	//   _layu, jilb, --, --,
   {{0xbfa30023,0xddc20138,0x443d13e2,0x00000000}},	//   _tiề, _nuoš, bow_, --,
   {{0x443daa9b,0x22be01d3,0x7bd60735,0x00000000}},	//   cow_, tākā_, _nayu, --,
   {{0x6b8da7a4,0x6e212e7f,0x28ce2014,0x628903a8}},	//   _reag, filb, _हैसि, _gweo,
   {{0xddcb0b88,0x7bd606a8,0xdd900281,0x1c1f0285}},	//   ğişt, _aayu, خود_, मोनल_,
   {{0x61e8aa9c,0x7bd6aa9d,0x6b8d00aa,0xaf360281}},	//   _indl, _bayu, _peag, _کرات,
   {{0x10160391,0x61faaa9e,0xa7fb034f,0xab5ba6c7}},	//   _عباد, _hotl, _riño, nfüg,
   {{0x7bd6aa9f,0x319f01d3,0xa3b40285,0x00000000}},	//   _dayu, bāzē_, _ञान_, --,
   {{0xaa6404f5,0xa7fb1de7,0x18050bd9,0x5fbc023a}},	//   етск, _piño, रस्व_, ्जवल,
   {{0x6b8d4450,0x61faaaa0,0x443d0188,0x877a0129}},	//   _teag, _motl, yow_, _ọwụw,
   {{0xb8e53b30,0x7bd63049,0xa7fb03be,0x61fa00f9}},	//   _एह_, _gayu, _viño, _lotl,
   {{0x47341bb8,0x45d500ae,0x5bc90179,0xc56b0286}},	// [c670] ентс, моас, िजीव, محال_,
   {{0x443daaa1,0x2d8eaaa2,0xf8ae0421,0x7bd601c2}},	//   wow_, _jefe_, دکی_, _zayu,
   {{0xf9fc00a1,0x2d8e022b,0x443daaa3,0x7bd6294f}},	//   _להזמ, _mefe_, tow_, _yayu,
   {{0x61e897ab,0x4ab117ff,0x320c0085,0x7bd6008c}},	//   _andl, _जमाव, _aldy_, _xayu,
   {{0xe3b00fba,0x7d0d01c2,0x443daaa4,0x5fda00c3}},	//   ارم_, _ƙask, row_, _मोइल,
   {{0xe819007d,0x443d55f1,0xa9250031,0x0cad0065}},	//   नोरा_, sow_, poľč, _jiṣẹ_,
   {{0x69d7aaa5,0x1dd709c3,0x999802c6,0xa3ab00a4}},	//   _maxe, _भोगत, zorů_, _खाऊ_,
   {{0x69d748d6,0xddc2013f,0x61e82021,0x6284020a}},	//   _laxe, _ruoš, _endl, ţioa,
   {{0x7bd61114,0x3e72002d,0x6e214012,0xef1935c8}},	//   _rayu, _cât_, tilb, юми_,
   {{0x7bd6948b,0x61fa0212,0x7ae2033b,0xddc20138}},	//   _sayu, _gotl, _šoto, _puoš,
   {{0x7bd6048e,0x3f84005c,0x23720138,0x2d8e013c}},	//   _payu, bbmu_, žyje_, _defe_,
   {{0xea010019,0x6e21aaa6,0x999800b6,0x3c1a01b3}},	//   _đạt_, silb, torů_, іўня_,
   {{0x2d8e0f20,0xa3ab0f53,0x81d00081,0x69d70188}},	//   _fefe_, _खाई_, ষার_, _baxe,
   {{0x2d8e0d2a,0x186a0859,0x2baa32f7,0x7bd6aaa7}},	//   _gefe_, жави_, _काका, _wayu,
   {{0xd9430f32,0x7bd66e1d,0x2bd91bc3,0x2d852198}},	//   вери, _tayu, _बोका, mble_,
   {{0x7b070103,0x00000000,0x00000000,0x00000000}},	//   örté, --, --, --,
   {{0x69d70d21,0x00000000,0x00000000,0x00000000}},	// [c680] _faxe, --, --, --,
   {{0x2d850c56,0x2d8e03be,0x7d0d0022,0x3f8f01ab}},	//   nble_, _xefe_, _ƙash, _legu_,
   {{0x2d8526de,0x61fa679b,0x136a032d,0x00000000}},	//   ible_, _rotl, ошли_, --,
   {{0x3f8faaa8,0x2bc10e28,0x61fa05db,0x00000000}},	//   _negu_, ष्पा, _sotl, --,
   {{0xab5b02dc,0xe297098a,0x00000000,0x00000000}},	//   rfüg, дач_, --, --,
   {{0xc5d5059b,0x273e0139,0x2d850095,0x3f8f09a1}},	//   _пісь, _ẹnì_, jble_, _aegu_,
   {{0x61faaaa9,0x6d4700bc,0xf5060077,0x2d8e022b}},	//   _votl, üjal, _ўзбо, _refe_,
   {{0xf8b300a1,0xa3ab2373,0x2d85037a,0x00000000}},	//   דשה_, _खाए_, eble_, --,
   {{0xf65f01c5,0xdbdd0139,0x3f8f63e5,0x61fa0120}},	//   _især_, _dáìs, _degu_, _totl,
   {{0x6282aaaa,0x61e8aaab,0xdce302a1,0x3f8f058f}},	//   mpoo, _undl, _senġ, _eegu_,
   {{0xa3d20789,0xae1d074c,0xb4bc0096,0x628200aa}},	//   _वसा_, योधन_, _अहो_, lpoo,
   {{0xb5fb058a,0x69d70188,0x3f8f0139,0x2d85aaac}},	//   _juár, _saxe, _gegu_, able_,
   {{0xfc3f0037,0x6282225b,0xdddb00a7,0x2d854f2d}},	//   roí_, npoo, qquş, bble_,
   {{0x7e7d2ba9,0x257533c3,0x2d8e00c4,0x00000000}},	//   íspe, _múló_, _uefe_, --,
   {{0xa3de02f0,0x00000000,0x00000000,0x00000000}},	//   तया_, --, --, --,
   {{0x23dd02e8,0x7a2902ef,0xa3b31c83,0x7b6701a0}},	//   _नोंद, džte, ज्ञ_, _отпе,
   {{0xa3e83516,0x00000000,0x00000000,0x00000000}},	// [c690] बाई_, --, --, --,
   {{0xa2dd00c3,0x00000000,0x00000000,0x00000000}},	//   पिस्, --, --, --,
   {{0x79950201,0x7d0d03e3,0xf1d9023a,0xd49b423e}},	//   mazw, _ƙasi, _योगन, юра_,
   {{0x628400d9,0x799503e1,0xc6a70a54,0xdcf8007e}},	//   ģion, lazw, _орги, _jevđ,
   {{0x62840012,0xc2cb00bf,0x3f8f0479,0x2bc1490a}},	//   ţion, تبال_, _regu_, ष्या,
   {{0xa2f90da9,0x2cac004d,0x624d0072,0x3f8f4533}},	//   ्नौज_, kudd_, cúol, _segu_,
   {{0xab5b00a7,0xd49813a4,0xc8d80285,0x00000000}},	//   rdüy, _орт_, डिएट, --,
   {{0xdb0d002b,0x2bc11e05,0xb5fb034f,0x00000000}},	//   _acaí, ष्मा, _guár, --,
   {{0x0e6511cc,0x79954102,0x442f1049,0xe2350291}},	//   нкин, kazw, mng_, _знањ,
   {{0x273e011b,0xac85198a,0x272c00ef,0x442f2a0b}},	//   ững_, нгол, ếng_, lng_,
   {{0x442faaad,0x3f8f5c8a,0x00000000,0x00000000}},	//   ong_, _tegu_, --, --,
   {{0x442faaae,0xfaa6147c,0xf3f9078e,0x80276e50}},	//   nng_, намо, _biţi_, _غرام,
   {{0x442faaaf,0xef0e0870,0x200faab0,0x62991183}},	//   ing_, _см_, _ilgi_, nswo,
   {{0x442f01af,0x2fcdaab1,0x799555f2,0x6f1d0558}},	//   hng_, leeg_, gazw, úscu,
   {{0x3ead0085,0x442f0ece,0x00000000,0x00000000}},	//   luet_, kng_, --, --,
   {{0xad1a0054,0x2fcd023e,0xf3f9020a,0x80a71d69}},	//   _מוצר, neeg_, _fiţi_, _घटने,
   {{0xe7370084,0xcfd90081,0x7bc4016d,0x79952767}},	// [c6a0] еет_, থাপন, _ibiu, bazw,
   {{0x7ae402a7,0x2bc12183,0xb5fb9be2,0xfbc100b6}},	//   _irit, ष्ठा, _suár, ष्ठम,
   {{0x69dc5842,0x600e01b9,0x25a6020e,0x629902ac}},	//   mdre, _lùma, ğol_, eswo,
   {{0x69ceaab2,0x69dc2a9b,0x442f604e,0x24860031}},	//   lebe, ldre, gng_, ďom_,
   {{0x2fcd01d0,0x3ead0120,0x629902ac,0x490800b6}},	//   deeg_, juet_, gswo, सनको_,
   {{0x442f72ae,0x69dc790c,0x69ceaab3,0x4a9b0089}},	//   ang_, ndre, nebe, לינג,
   {{0x62821d36,0x69dcaab4,0x03a69b8d,0x442f00f9}},	//   spoo, idre, _пиво, bng_,
   {{0x7ae4aab5,0x69ceaab6,0x69dc00f0,0x6033020a}},	//   _orit, hebe, hdre, tăma,
   {{0x61eb0068,0xcf260080,0x69ceaab7,0x3ead054e}},	//   állí, عربي, kebe, guet_,
   {{0x4426aab8,0xba3b1020,0xa3e880d0,0x69dc029a}},	//   lio_, nuït, बाक_, jdre,
   {{0x7ae40a00,0x69dcaab9,0x7c26aaba,0x26d200f0}},	//   _arit, ddre, fikr, hwyo_,
   {{0x1beb0851,0x8cb10034,0x2cac004d,0x69dc7d2d}},	//   टाइल_, _अमरो, rudd_, edre,
   {{0x7ae4aabb,0x69ceaabc,0x79950875,0x69dc0acb}},	//   _crit, febe, tazw, fdre,
   {{0x4426aabd,0x7ae4aabe,0x69ceaabf,0x69dcaac0}},	//   hio_, _drit, gebe, gdre,
   {{0x4426aac1,0x7ae4862e,0xba3b0428,0x07e7207e}},	//   kio_, _erit, duït, нцам,
   {{0x23691fce,0x67d4842e,0x69dcaac2,0x00000000}},	//   žaji_, лосу, adre, --,
   {{0x442616ea,0x7ae4237a,0x4c542729,0xab6900bd}},	// [c6b0] dio_, _grit, _حضور, _bużż,
   {{0x69ce00c9,0x442f02ad,0x2fcd023e,0x7bcf59ee}},	//   cebe, wng_, zeeg_, lecu,
   {{0x4426aac3,0xdcf800d9,0xd4e42a6e,0x629b0451}},	//   fio_, _ievē, люци, _svuo,
   {{0xf1d900e2,0x4426374b,0x7ae402fd,0xe7fb0d0d}},	//   _योजन, gio_, _yrit, _एकटा_,
   {{0x442f02e7,0xa7fb037a,0x6abd13ea,0xed46015a}},	//   rng_, _niñi, ntsf, _چپ_,
   {{0xc6920130,0x7c2602f1,0x2fcd0185,0x442faac4}},	//   _דאך_, zikr, weeg_, sng_,
   {{0x6299aac5,0x7bcf02a4,0x8c3d008b,0x200f00f9}},	//   sswo, kecu, luğu, _plgi_,
   {{0x44262218,0xa2d500c3,0x6abd1f60,0x387c01f9}},	//   cio_, _मैथ्, ktsf, _évre_,
   {{0x7bcf2eee,0x53346f46,0x69dc2e5f,0x6d4f007f}},	//   decu, _бетт, ydre, ęcam,
   {{0x7ae401e5,0x2fcd01bb,0x69ad055c,0x7d090831}},	//   _rrit, seeg_, _जागी, дног_,
   {{0x6d4a02e0,0x7c26013f,0xa2d511d7,0x7ae4013f}},	//   _cyfa, tikr, _मैत्, _srit,
   {{0x6abd1489,0x69c53388,0xab2a0f1e,0x6d4a00f0}},	//   ftsf, _abhe, дома_, _dyfa,
   {{0x69ceaac6,0x7e6aaac7,0x68e102b6,0x7c2621ab}},	//   tebe, _fifp, ældn, rikr,
   {{0x4426aac8,0x8c3d0390,0x7c2624b8,0xf1c4397e}},	//   zio_, duğu, sikr, ल्पन,
   {{0x69ce16da,0x7ae40054,0x290c025b,0x69dc4201}},	//   rebe, _writ, áda_, rdre,
   {{0x69ce067d,0x4426aac9,0xea010028,0x386b8163}},	//   sebe, xio_, _đất_, _cicr_,
   {{0xcf920130,0x7c24aaca,0xba3b05fe,0x81a90081}},	// [c6c0] יטן_, _imir, tuït, গ্য_,
   {{0x44260150,0x00000000,0x00000000,0x00000000}},	//   wio_, --, --, --,
   {{0x44265939,0x7c2402ef,0xba3b00ee,0x00000000}},	//   tio_, _kmir, ruït, --,
   {{0x8c3d020e,0x03a60036,0xba3b00ee,0x00000000}},	//   buğu, тидо, suït, --,
   {{0xc7b309c1,0x7c2406c0,0x3860aacb,0x8c3d026a}},	//   _דבר_, _mmir, mmir_, cuğu,
   {{0x4426aacc,0xa15898c8,0x38600092,0x00000000}},	//   sio_, налу_, lmir_, --,
   {{0xa7fb01ff,0x00000000,0x00000000,0x00000000}},	//   _siñi, --, --, --,
   {{0x4fd42b94,0x4fc648c7,0x69a20096,0x9f5d0113}},	//   ужит, тска, कृती, _kowè_,
   {{0x8d860636,0x09aa0081,0x62660231,0x4424163f}},	//   кунд, খ্যা, _аваа, _imm_,
   {{0x7c24aacd,0x5fae009d,0x602706a3,0xacf800d3}},	//   _amir, _टाकल, _pèmè, еноу_,
   {{0x7bcf044c,0x00000000,0x00000000,0x00000000}},	//   tecu, --, --, --,
   {{0xa3e8033a,0x6abd0e3e,0x44240063,0x6d4a0e4b}},	//   बाट_, ttsf, _jmm_, _vyfa,
   {{0x7bcf00ae,0x7c24009e,0x7bddaace,0x7a290138}},	//   recu, _dmir, rdsu, ežta,
   {{0x7c240a15,0x7bcfaacf,0x6abd040f,0x386b00f0}},	//   _emir, secu, rtsf, _sicr_,
   {{0xef1900a5,0xb4d110e9,0x44240078,0x69c51d66}},	//   daży_, _वने_, _omm_, _vbhe,
   {{0x3d0e0d75,0x6e280335,0x2ee605db,0x36d56804}},	//   ानीं_, lidb, _krof_, лобр,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [c6d0] --, --, --, --,
   {{0x80b80081,0xa5670260,0x28ce00aa,0x6e280106}},	//   _আনন্, ندان, _हैकि, nidb,
   {{0xd3715e51,0xdb0daad0,0xd5b800e5,0x3ce500a3}},	//   مها_, _ibañ, ъст_, टिये_,
   {{0xfbdf016d,0x7640003e,0x601502c6,0x68e80537}},	//   ndê_, _ímyn, _káme, ædde,
   {{0x59c01388,0xeabf0451,0xa3e81024,0x8c1c021e}},	//   श्वर, ntù_, बाज_, וואי,
   {{0x26d900c9,0x2fc600f9,0x6e28080e,0xddc3020a}},	//   _isso_, _abog_, jidb, _minţ,
   {{0x04676c6e,0x74f70103,0xfbab0033,0x601500d8}},	//   _атам, _جہاز_, গ্যত, _láme,
   {{0xdb1d00f2,0x442402a1,0x6033020a,0x00000000}},	//   besø, _gmm_, rămo, --,
   {{0x2f543e04,0x60150220,0xfe450396,0x9f5d00cd}},	//   итьс, _náme, лнио, _kowé_,
   {{0x7c240995,0x8ca40b7f,0xaded3212,0x645b009c}},	//   _smir, _किशो, जाइन_, _hhui,
   {{0x3860aad1,0xd00e0d7f,0x00000000,0x00000000}},	//   ymir_, زلی_, --, --,
   {{0x26d9085f,0x6e95016d,0xf65f0565,0x00000000}},	//   _osso_, _биду, _spæl_, --,
   {{0x645b1519,0x8f9a00a1,0x2ee6aad2,0x7d0d01c2}},	//   _mhui, _ניסי, _grof_, _ƙass,
   {{0x2fc600e9,0xad240281,0xddc3020a,0x00000000}},	//   _zbog_, اریو, _dinţ, --,
   {{0x07a604c9,0x2fdd01bb,0x26cb00dc,0x3860aad3}},	//   лавн, _kawg_, _apco_, tmir_,
   {{0x2fdf0124,0x200d6f3d,0x26cb2a99,0x00000000}},	//   ndug_, nkei_, _bpco_, --,
   {{0x6f09aad4,0x6015037a,0x6f1b02db,0x00000000}},	// [c6e0] nyec, _gáme, nzuc, --,
   {{0x645b0174,0x44249726,0xa7630ed7,0x00000000}},	//   _ahui, _smm_, скуд, --,
   {{0x6b96aad5,0x645b117b,0x6015025b,0x26d9008f}},	//   _keyg, _bhui, _záme, _esso_,
   {{0x645b445f,0x69deaad6,0x290a0138,0x3cf86a47}},	//   _chui, _hape, myba_, ärvi_,
   {{0x645b10f0,0x244e0618,0x14170037,0xdddb02c6}},	//   _dhui, nými_, دينة_, zpuš,
   {{0x27e0aad7,0x69de37c9,0x6b96041c,0xa3e40e50}},	//   ldin_, _jape, _leyg, _भोर_,
   {{0x69deaad8,0x2fdd01fa,0x645b0091,0x6e282f54}},	//   _mape, _bawg_, _fhui, vidb,
   {{0x27e0aad9,0x69deaada,0x244e025b,0xa6db01cd}},	//   ndin_, _lape, kými_, _eyðu,
   {{0x26c00150,0x60e0013f,0x27e0577f,0x09db0033}},	//   ntio_, _žymė, idin_, দাতা,
   {{0x60151e6f,0x290a0138,0x27e000c2,0x7d080313}},	//   _cámb, kyba_, hdin_, tyds,
   {{0x85f70130,0x6e28aadb,0x3d0e0034,0x27e0235a}},	//   אציע_, ridb, ानें_, kdin_,
   {{0x6ee60190,0x6e28042d,0x290a0138,0x60daaadc}},	//   _مستل, sidb, dyba_, _istm,
   {{0x27e0aadd,0x34d100c0,0xdddb0a9e,0x6f1b0034}},	//   ddin_, _सन्द, spuš, czuc,
   {{0xeabf00e5,0x2fdd023e,0x394709af,0x23ab0139}},	//   rtù_, _zawg_, _ønsk_, _kòjà_,
   {{0x69de0096,0x2fdd0197,0x7d7b006e,0x0ed8030b}},	//   _dape, _yawg_, _אנוו, _बैतड,
   {{0x6c8300e3,0xf7730192,0x6015002b,0x3a750221}},	//   _اليم, صار_, _táme, _клир,
   {{0x7bdf0036,0x69de0131,0x47340037,0x645b009c}},	// [c6f0] _iaqu, _fape, مركز, _rhui,
   {{0x6449782d,0x645b0099,0x60da00aa,0x69deaade}},	//   _skei, _shui, _ostm, _gape,
   {{0x6f1b028d,0x33750077,0x26c0aadf,0x645b0441}},	//   zzuc, агер, atio_, _phui,
   {{0xd564339a,0x69de07a8,0x7bdf8825,0x1e01009d}},	//   ступ, _zape, _jaqu, _लक्ष_,
   {{0x26c07e62,0x2fdd023e,0x93271f11,0x69deaae0}},	//   ctio_, _rawg_, دران, _yape,
   {{0x7bdf0257,0x6d5800d4,0x00850219,0x69de9740}},	//   _laqu, _ozva, алко, _xape,
   {{0x645baae1,0x2fdd0197,0x3d0e0034,0x80151011}},	//   _thui, _pawg_, ानों_, ифиц,
   {{0x7bdf0bfe,0x2fdd023e,0xa9280094,0x645b0b8c}},	//   _naqu, _qawg_, loží, _uhui,
   {{0xf1a728dc,0xcdf5055b,0xddcb00d9,0xee39380e}},	//   _брен, ачны, _augš, кни_,
   {{0x3ebfaae2,0x244e0074,0x27e0037d,0x6f1b0034}},	//   rtut_, vými_, zdin_, rzuc,
   {{0x69de850e,0x2fdd006c,0xd13100e3,0x22470090}},	//   _rape, _tawg_, _بما_, monk_,
   {{0x69deaae3,0x8c460b2c,0x244e0146,0x7bdf5eba}},	//   _sape, реме, tými_, _caqu,
   {{0x7bdf0bfe,0x63a40076,0x00000000,0x00000000}},	//   _daqu, óini, --, --,
   {{0xc332004f,0x244e4098,0x3ead0bc6,0x1dd9009d}},	//   קום_, rými_, mret_, _बघित,
   {{0x69deaae4,0x245c0146,0x7bdf6233,0x26c000f0}},	//   _vape, líme_, _faqu, wtio_,
   {{0x69de7b04,0x6ca40260,0x27e0664f,0x290a0138}},	//   _wape, _اصول, udin_, ryba_,
   {{0x27e0aae5,0xdce107d1,0x18671fbf,0xd707002d}},	// [c700] rdin_, malı, рати_, анте_,
   {{0xe617255e,0x26c0aae6,0xe5a60012,0xb60702a1}},	//   аду_, rtio_, рижи, _naġġ,
   {{0x224706a3,0x799caae7,0x3ead1710,0x27e000f9}},	//   donk_, marw, hret_, pdin_,
   {{0xdce107aa,0x3ead4f65,0x799caae8,0x26c0aae9}},	//   nalı, kret_, larw, ptio_,
   {{0x3ead052f,0x245c0146,0x60da0063,0xdc37006e}},	//   jret_, jíme_, _sstm, סאנט_,
   {{0x5bd30abe,0x245c0244,0x3ead0c2e,0x799c006d}},	//   _तस्व, díme_, dret_, narw,
   {{0x64a340cd,0x05c6009d,0xdce10367,0x3eadaaea}},	//   _мара, र्णब, kalı, eret_,
   {{0x60150579,0x04430c58,0x799c53e3,0x6d5c01ab}},	//   _rámc, _десн, harw, ýram,
   {{0x7bdfaaeb,0x3ead4e2b,0x799ca536,0xdefa0fd6}},	//   _raqu, gret_, karw, тый_,
   {{0x59b2009f,0x9e061a21,0xb60700bd,0x799c01dc}},	//   _जागर, рчил, _gaġġ, jarw,
   {{0xa17b0341,0x799c006d,0x057700ca,0xfc401054}},	//   _סטאט, darw, יגים_, čín_,
   {{0x245c0146,0x3ead6c91,0x799798ca,0xdcfa00e8}},	//   bíme_, bret_, _sexw, latī,
   {{0x3ead823b,0x799c02ad,0x9c3873cd,0x00000000}},	//   cret_, farw, рпят_, --,
   {{0x799caaec,0x5d840037,0xdcea00bd,0x00000000}},	//   garw, _الغل, _nefħ, --,
   {{0x6d5800d9,0x6e3d0103,0xdce10367,0x6015003e}},	//   _uzva, ésbe, balı, _háma,
   {{0x20d80019,0xdce103e0,0x00000000,0x00000000}},	//   _mũi_, calı, --, --,
   {{0x799caaed,0xdcfa00e8,0x00000000,0x00000000}},	// [c710] barw, katī, --, --,
   {{0xb8dd0081,0x79a70e3a,0x63bb044c,0x799c0027}},	//   _ইন_, _трие, _scun, carw,
   {{0x69d5aaee,0x245c030b,0x601500d4,0xb60700bd}},	//   meze, zíme_, _láma, _raġġ,
   {{0x69d5aaef,0x25fb2fbd,0x3ead9fdd,0x225e0062}},	//   leze, लॉजी_, yret_, _ahtk_,
   {{0x17080018,0x60150094,0x00000000,0x00000000}},	//   _پہلی_, _náma, --, --,
   {{0x40952b99,0x245c025b,0x3ead0f01,0x4224004d}},	//   брит, víme_, vret_, одів,
   {{0x6b9daaf0,0xdce10511,0x224701d0,0x20d800fe}},	//   kasg, yalı, ronk_, _cũi_,
   {{0x293800a1,0x69d5aaf1,0x245c0146,0x893800ca}},	//   יאון_, heze, tíme_, ירוע_,
   {{0x69d5aaf2,0x601511ce,0x799c006d,0x6833003d}},	//   keze, _cáma, yarw, għdi,
   {{0x245c0220,0x69d50103,0x3ead0bb0,0x69c76e6b}},	//   ríme_, jeze, rret_, jfje,
   {{0xeb9a249b,0x61e1aaf3,0x245c0579,0xdce107aa}},	//   лин_, _iall, síme_, talı,
   {{0x61e1aaf4,0x6b9daaf5,0x799c006d,0x3eadaaf6}},	//   _hall, gasg, warw, pret_,
   {{0x61e1aaf7,0x799c006d,0x8e85aaf8,0xdce10587}},	//   _kall, tarw, _угле, ralı,
   {{0x61e1aaf9,0xd9b205cd,0x7d100103,0x320500fc}},	//   _jall, जलेट, öksé, _joly_,
   {{0xfbdf001f,0x799caafa,0x16d03ad1,0x487900ae}},	//   glês_, rarw, हब्ब, истя_,
   {{0x61e1006d,0x3205002b,0x600e01b5,0x799ca929}},	//   _lall, _loly_, _cùmh, sarw,
   {{0x69d5aafb,0x6b84766b,0x3f7a00c1,0x600e01ec}},	// [c720] beze, _ifig, אָבע, _dùmh,
   {{0x61e1aafc,0xe9da0095,0x49961da9,0x00000000}},	//   _nall, _ско_, _ушит, --,
   {{0xd9100814,0xdcfa00e8,0x18280421,0xd05a013c}},	//   _غیر_, vatī, _نقدی_, _ertə,
   {{0x61e1aafd,0xad3600c1,0xdb1d0103,0xdb0d00aa}},	//   _aall, זנעס_, yesü, _ebaõ,
   {{0x6a6002e2,0xdcfa01d3,0xa3a900b6,0xddc200c6}},	//   röff, tatī, _गएर_, _ruož,
   {{0x61e1aafe,0x27e201c2,0x320500d8,0x00000000}},	//   _call, _hakn_, _coly_, --,
   {{0x61e1aaff,0x845a29db,0xdcfa00d9,0x859b00a1}},	//   _dall, _брат_, ratī, _תשלו,
   {{0x61e1ab00,0x68e13e59,0xdb1d0103,0x6b5f0139}},	//   _eall, ældi, tesü, _jàgí,
   {{0x69d50018,0xc224001c,0xdcfa01d3,0x7de60077}},	//   yeze, _وکتو, patī, бінд,
   {{0x2d98ab01,0x61e11fdd,0xc27b00ca,0x5275044b}},	//   úre_, _gall, _ערבי, _футу,
   {{0x69d50018,0x59b200b6,0xdb1d3a9a,0xab5bab02}},	//   veze, _जाजर, sesü, rfüm,
   {{0x69d5ab03,0x61e1ab04,0xc605009d,0xdb04002b}},	//   weze, _zall, _शक्य_, _aciñ,
   {{0x69d5ab05,0x61e101c2,0x6b9dab06,0x940c00a7}},	//   teze, _yall, rasg, ülər_,
   {{0x61e1ab07,0x6b840131,0x7f3b006e,0x2006ab08}},	//   _xall, _efig, _געדו, _hooi_,
   {{0x69d5ab09,0x5d9b00a1,0x2d9e3475,0xddc80146}},	//   reze, _גבוה, mate_, vodň,
   {{0xb9010f53,0x69d5ab0a,0x2d9e2366,0x0855224a}},	//   _धन_, seze, late_, іваю,
   {{0x20060db8,0x69d5ab0b,0xd6d70033,0x79820134}},	// [c730] _mooi_, peze, সম্প, ọwad,
   {{0xdb0402e2,0x2d9e078c,0x7aedab0c,0x2006ab0d}},	//   _heiß, nate_, _irat, _looi_,
   {{0x93790a7c,0x4d7b00c1,0xe4d50397,0x2d9e00ae}},	//   абет_, ארבע, تقاد, iate_,
   {{0x61e1ab0e,0x7c2f002b,0x4cbb00c1,0x20060313}},	//   _sall, nicr, רמאג, _nooi_,
   {{0x81e200c7,0x61e1ab0f,0x7bcd03a9,0x32050133}},	//   ধান_, _pall, _mbau, _poly_,
   {{0x2d9eab10,0x61e18267,0x7aedab11,0x2089008f}},	//   jate_, _qall, _mrat, айки_,
   {{0x61e11a23,0x61ed03e3,0x2006166c,0xdcf800e8}},	//   _vall, ɓall, _booi_, _devī,
   {{0x20c16e1e,0x61e1a90a,0x60090b7b,0x1e85017b}},	//   rói_, _wall, рним_, олим,
   {{0x61e1ab12,0xd5c6000c,0x442fab13,0x6607023e}},	//   _tall, र्वज, mig_, _kojk,
   {{0x442fab14,0xfc400146,0x61e101b5,0x6b843ab5}},	//   lig_, čím_, _uall, _sfig,
   {{0x7aedab15,0x63a40102,0x6d4601e8,0x20e714f3}},	//   _arat, ðing, şkan, _uđi_,
   {{0x7aedab16,0x442fab17,0x2006159f,0x644bab18}},	//   _brat, nig_, _gooi_, nogi,
   {{0xab5b01bf,0x29050212,0x2d9eab19,0x6da53283}},	//   nfüh, älan_, bate_, _дила,
   {{0x2d9eab1a,0xe81c000c,0x2d81007a,0x442fab1b}},	//   cate_, नसभा_, _ühe_, hig_,
   {{0xa3b91e5e,0x442fab1c,0x63a9ab1d,0x5fdda29e}},	//   चला_, kig_, _oden, _मसाल,
   {{0x63a9ab1e,0x7aedab1f,0x6015ab20,0x442fab21}},	//   _nden, _frat, _mámo, jig_,
   {{0x442fab22,0x644b0150,0xaa7b0146,0x245c0220}},	// [c740] dig_, dogi, jvýh, jíma_,
   {{0x660700e7,0x442f015e,0x00000000,0x00000000}},	//   _cojk, eig_, --, --,
   {{0x442fab23,0x16000455,0x60151054,0x62890a06}},	//   fig_, लॉगर_, _námo, _ateo,
   {{0x2d9eab24,0x442fab25,0xab5b042c,0x34ba00c3}},	//   zate_, gig_, ffüh, _उमीद,
   {{0x2d9eab26,0x20060185,0x6aa80251,0x63a923b3}},	//   yate_, _rooi_, _कटोर, _dden,
   {{0xaab205d4,0x660701ac,0x63a9ab27,0xfe6709f4}},	//   _जिनक, _gojk, _eden, _زد_,
   {{0x442f03cb,0x2d9eab28,0x644b00ee,0xd01a02a0}},	//   big_, vate_, bogi, ифи_,
   {{0x63a4003e,0x644bab29,0x442f8c94,0x601530a1}},	//   ðind, cogi, cig_, _dámo,
   {{0x2d9eab2a,0x601c0018,0x81cf0081,0xdb040364}},	//   tate_, _néme, ষয়_, _reiß,
   {{0x70f65d50,0x63a900d4,0x20060063,0x273700fe}},	//   _وسائ, _zden, _wooi_, ầng_,
   {{0x7aed0441,0xdca3001f,0x200602ac,0x00000000}},	//   _srat, маќи, _tooi_, --,
   {{0x2d9eab2b,0x00000000,0x00000000,0x00000000}},	//   sate_, --, --, --,
   {{0x106900e3,0x60152347,0xaf3601c3,0x7aed0078}},	//   _احلى_, _zámo, _برات, _qrat,
   {{0x442f0ab2,0x644bab2c,0xdb0401bf,0x3ea600e7}},	//   zig_, zogi, _weiß, _ivot_,
   {{0x69c30b88,0x442f6f82,0x644bab2d,0x2d9c0090}},	//   _önem, yig_, yogi, _ieve_,
   {{0x2ee900e7,0x442fab2e,0x2d9c0120,0x660771a6}},	//   _šafi_, xig_, _heve_, _sojk,
   {{0x7aedab2f,0x7c2dab30,0x6607ab31,0x442f1ca4}},	// [c750] _urat, _imar, _pojk, vig_,
   {{0x442fab32,0x2d9c0117,0x644b00f0,0x00000000}},	//   wig_, _jeve_, wogi, --,
   {{0x442f31ae,0x7c2d0238,0x644bab33,0x59c40789}},	//   tig_, _kmar, togi, _लॉटर,
   {{0x2d9c9d26,0x601c06fc,0x245c003e,0x60151f20}},	//   _leve_, _lémb, tíma_, _rámo,
   {{0x442f355d,0x38690572,0x7c2dab34,0x25aa00e7}},	//   rig_, mmar_, _mmar, _fdbl_,
   {{0x442fab35,0x2d9cab36,0x3869ab37,0xab5b01bf}},	//   sig_, _neve_, lmar_, rfüh,
   {{0x442fab38,0xb8820c01,0xe4a413cb,0x7c2dab39}},	//   pig_, žíva, _орто, _omar,
   {{0x3869ab3a,0x63a901c5,0x20193e43,0xfc402347}},	//   nmar_, _uden, ósi_, čík_,
   {{0x442dab3b,0x443f0129,0x3869ab3c,0x2d9c028d}},	//   _ime_, _iju_, imar_, _beve_,
   {{0x7c2dab3d,0x8c0800c7,0x60150018,0x443f0095}},	//   _amar, _লগইন_, _támo, _hju_,
   {{0x2d9c2de0,0x442d00f9,0x443f007e,0x61ee00b3}},	//   _deve_, _kme_, _kju_, _óbla,
   {{0xca29004f,0x38690095,0xe61f0031,0x442d014b}},	//   _גם_, jmar_, _stôl_, _jme_,
   {{0x442dab3e,0x38690141,0x2d9cab3f,0x00000000}},	//   _mme_, dmar_, _feve_, --,
   {{0x7e680124,0x6033020a,0x00000000,0x00000000}},	//   cmdp, rămu, --, --,
   {{0xfe70172a,0x442dab40,0x443f0d79,0x25a10429}},	//   _شده_, _ome_, _oju_, dahl_,
   {{0x068636bf,0x201f1d51,0x601c00b3,0xbb46013f}},	//   зган, nhui_, _téme, _нейк,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [c760] --, --, --, --,
   {{0x442dab41,0xa3e43b30,0x443f0ae8,0x2d851848}},	//   _ame_, _भोज_, _aju_, ncle_,
   {{0x7c2d0150,0x442d3750,0x68e10537,0x00000000}},	//   _ymar, _bme_, ældt, --,
   {{0xe452177a,0x7c2dab42,0x38690072,0x394d020a}},	//   رضا_, _xmar, cmar_, şesc_,
   {{0xcfc300c7,0x201f0051,0xfbc10be4,0x2bc11c83}},	//   ্যান, dhui_, ष्टम, ष्टा,
   {{0x442d0857,0x443fab43,0x64a60426,0xf8b000df}},	//   _eme_, _eju_, _нага, _जटाय,
   {{0x2d9cab44,0x6724ab45,0x799e0154,0x442dab46}},	//   _reve_, lzij, _mepw, _fme_,
   {{0xd01000e3,0x93a90dce,0x853b0327,0xdfda008f}},	//   ئلة_, _واقف_, _הגלי, сък_,
   {{0x63a2198f,0xb2261c3e,0xe297020a,0x644300fd}},	//   maon, _емал, _нат_, énie,
   {{0xab5b6eee,0x63a2ab47,0x3f9d0032,0xf77fab48}},	//   ngüe, laon, _eewu_, _maça_,
   {{0x386903e3,0x442dab49,0xdce30233,0x656801ec}},	//   ymar_, _yme_, _benı, _ùdhd,
   {{0x63a228dd,0x25a101bf,0xbb9400c2,0x00000000}},	//   naon, zahl_, нающ, --,
   {{0x2d9c0396,0x601cab4a,0xc9051cff,0x6724ab4b}},	//   _teve_, _témb, रह्म_, jzij,
   {{0x26000e28,0x63a2033c,0x672448b1,0x58d5004d}},	//   राफी_, haon, dzij, могт,
   {{0x2600046e,0x63a2ab4c,0x799e05aa,0x3d2201dc}},	//   रानी_, kaon, _depw, _déwé_,
   {{0x7c2dab4d,0x63a2518a,0x25a10364,0x3869a236}},	//   _umar, jaon, wahl_, umar_,
   {{0xdce80702,0xf77f1f8d,0x25a11597,0x36d40095}},	// [c770] madı, _caça_, tahl_, нотр,
   {{0x442d0038,0xdce803a3,0x443f13f8,0xaab232f7}},	//   _sme_, ladı, _sju_, _जितक,
   {{0xf6500b05,0xb88300b6,0x442d2db1,0x443f0167}},	//   ائق_, říbr, _pme_, _pju_,
   {{0xf77f0396,0xd3710fb7,0x63a2ab4e,0xdce8008b}},	//   _faça_, نها_, gaon, nadı,
   {{0x27e9ab4f,0x443f0095,0x91e50110,0x2d852ab4}},	//   mdan_, _vju_, доле, ycle_,
   {{0x27e9ab50,0xdb1d0212,0x3f9d001c,0xdce804a8}},	//   ldan_, besö, _sewu_, hadı,
   {{0x94d40b2e,0x63a2118e,0xa4d400d6,0x443f0052}},	//   _порц, baon, _порі, _tju_,
   {{0x27e97e09,0x442dab51,0x63a201f7,0x443f405f}},	//   ndan_, _ume_, caon, _uju_,
   {{0x26c9ab52,0xdce80491,0x62790220,0x27e98f89}},	//   ntao_, dadı, _dňoc, idan_,
   {{0x27e90049,0x645902db,0xe165001c,0x910700ae}},	//   hdan_, llwi, _قضای, _нчед,
   {{0x6724003d,0x4d6500d6,0xc1050604,0x1d098d01}},	//   zzij, ьков, _توضي, цени_,
   {{0x3f1511b0,0x629b0134,0x443d0150,0x2d85ab53}},	//   _одес, _kwuo, nnw_, scle_,
   {{0x27e9ab54,0x260000b6,0x00000000,0x00000000}},	//   ddan_, रामी_, --, --,
   {{0xf77f7ae3,0xce6b261f,0x672400e7,0x9e64004d}},	//   _raça_, _уред_, vzij, _звід,
   {{0x63a2ab55,0x69cd0403,0x601c020d,0x27e90abd}},	//   yaon, द्धी, _héma, fdan_,
   {{0x27e98c41,0x6f160067,0x1dbd1c0a,0x998d08c5}},	//   gdan_, _życi, ्भवत, đeš_,
   {{0x63a29fe9,0xe5a61102,0x6724004b,0x00000000}},	// [c780] vaon, дизи, uzij, --,
   {{0x69cd0336,0x7ae40060,0x63a20010,0x64594385}},	//   द्दी, _isit, waon, elwi,
   {{0x1dcf0b94,0x63a2420f,0x9f420181,0xd9461c99}},	//   त्यत, taon, ľké_, _цени,
   {{0x69dc531b,0x9f420146,0x69ce1507,0xf77f0161}},	//   lere, žké_, lfbe, _taça_,
   {{0x926a1165,0x78bc0063,0x366a88b7,0x00000000}},	//   орка_, lurv, _мамо_, --,
   {{0x201d03ec,0x7ae40051,0x63a2ab56,0x6282008c}},	//   _alwi_, _msit, saon, rqoo,
   {{0x63a271a2,0x69dcab57,0x64430143,0x291d03e3}},	//   paon, iere, énic, _ƙwai_,
   {{0x69dcab58,0x7ae4ab59,0x00000000,0x00000000}},	//   here, _osit, --, --,
   {{0x69dc5ebe,0x6015025b,0xa1c614f2,0xdce800a7}},	//   kere, _zámk, _обад, vadı,
   {{0x69dc5bb6,0x601c025a,0x27e9ab5a,0x601500e3}},	//   jere, _déma, zdan_, _lámh,
   {{0x45b70054,0x27e9ab5b,0x7ae4ab5c,0x61faab5d}},	//   ופיל_, ydan_, _asit, _intl,
   {{0x61e80694,0x6280ab5e,0x63a0025b,0x27e9448b}},	//   _hadl, _kumo, _jemn, xdan_,
   {{0xdce8051d,0x6280ab5f,0x63a0026a,0x27e9ab60}},	//   radı, _jumo, _memn, vdan_,
   {{0x69dc1bb4,0x63a000d3,0x62805b4b,0x81b00033}},	//   gere, _lemn, _mumo, ট্র_,
   {{0x7ae44193,0x6280ab61,0x27e90092,0x61e81fab}},	//   _esit, _lumo, tdan_, _madl,
   {{0xb90705d4,0x63a000f3,0x59b102d5,0x61e8ab62}},	//   _मई_, _nemn, _जयवर, _ladl,
   {{0x69dcab63,0x27e9ab64,0xfc3f000d,0x61fa0a9f}},	// [c790] bere, rdan_, mní_, _ontl,
   {{0xfc3f033a,0x61e808a9,0x69dcab65,0xea010028}},	//   lní_, _nadl, cere, _đặt_,
   {{0x26c926dd,0x69c500ac,0x27e9ab66,0xfa340037}},	//   stao_, _iche, pdan_, _جريد,
   {{0xfc3fab67,0x27e90092,0x68e555ca,0x62803c25}},	//   nní_, qdan_, _ishd, _bumo,
   {{0x320c0b82,0x63a0ab68,0x6280850e,0x7ae40124}},	//   _body_, _demn, _cumo, _xsit,
   {{0xaab20067,0x11d90037,0x2600034d,0x7bdd1d03}},	//   _जिसक, سوعة_, राणी_, hesu,
   {{0x69c5068d,0xe0d10018,0x61e87898,0x3879007e}},	//   _mche, ازت_, _dadl, _kisr_,
   {{0x69dcab69,0xfc3f0363,0x61fa01bf,0x7bdd42a8}},	//   zere, jní_, _entl, jesu,
   {{0xfc3f033a,0x69dcab6a,0x7a22025a,0x69c5ab6b}},	//   dní_, yere, _hôte, _oche,
   {{0x6cea1362,0x69dcab6c,0x69c500ac,0x63a0ab6d}},	//   टिंग_, xere, _nche, _zemn,
   {{0x260002e8,0x69dc643b,0x60150610,0x6280037a}},	//   राती_, vere, _lámi, _zumo,
   {{0x69c5ab6e,0xeb9702fd,0x601c030b,0xdb04002b}},	//   _ache, нию_, _téma, _adiá,
   {{0x6015ab6f,0x81e20033,0x6d5803e0,0x4b5500e5}},	//   _námi, ধার_, _eyva, върт,
   {{0x69dc1597,0x7cf70139,0xdca51e6d,0xfc3f0031}},	//   uere, _ẹra, _заки, aní_,
   {{0xfc3f000d,0xc21200ca,0xd943125c,0x6d580138}},	//   bní_, נהל_, гери, _gyva,
   {{0x69c506c0,0x69dc3e92,0x7bddab70,0x7ae4007a}},	//   _eche, sere, cesu, _tsit,
   {{0x69dcab71,0xb9070f62,0x7ae4ab72,0x78bcab73}},	// [c7a0] pere, _मै_, _usit, surv,
   {{0x63a00012,0xf77f001f,0x6280ab74,0x260050a4}},	//   _semn, _faço_, _rumo, राधी_,
   {{0x399b193b,0x62801f8e,0x320c01b9,0x7a2200fd}},	//   _מייד, _sumo, _rody_, _côte,
   {{0x628000f9,0x1dcf05d6,0x61e8ab75,0x00000000}},	//   _pumo, त्तत, _sadl, --,
   {{0x81e90081,0x087700c1,0x61e8ab76,0x69cd097c}},	//   যান_, _רעכט_, _padl, द्वी,
   {{0x7bddab77,0xfc3f030b,0x7d0e052f,0x60e6282a}},	//   zesu, zní_, øbsk, ециз,
   {{0x320c0074,0xe64302ec,0x63a03fa3,0x7bddab78}},	//   _vody_, _серп, _temn, yesu,
   {{0xefb200cd,0x320c00a5,0xaa0d030b,0x61e8657c}},	//   ایشگ, _wody_, _सक्छ_, _wadl,
   {{0xfc3f033a,0xc2462c49,0x7bddab79,0x660eab7a}},	//   vní_, _знак, vesu, _kobk,
   {{0x7ed30037,0x660e0537,0x00000000,0x00000000}},	//   ازيا, _jobk, --, --,
   {{0xfc3f033a,0x7bddab7b,0xddc305db,0xaa7b00d4}},	//   tní_, tesu, _finž, jvýr,
   {{0x637607d1,0x69c5643b,0x6d580146,0x6abd00bc}},	//   _günü, _sche, _vyva, tusf,
   {{0xfc3f000d,0x69c557df,0x601c020d,0xdcea00c4}},	//   rní_, _pche, _hémo, čiđe,
   {{0xfc3f030b,0x673b007e,0x660e01ff,0xf77f8657}},	//   sní_, _žujo, _nobk, _paço_,
   {{0xfc3f0363,0x7bdd0673,0x378e0174,0x248d0357}},	//   pní_, pesu, _ọgọ_, _čemo_,
   {{0x601c025a,0x36d52b53,0x7bdd0052,0x0b520134}},	//   _mémo, кобр, qesu, ọkọl,
   {{0x2bc60a30,0x69c502f1,0xfc4000b6,0xaae70037}},	// [c7b0] _वाता, _tche, čít_, _أسبو,
   {{0x69c555ef,0x63a40088,0x163b0037,0x39153898}},	//   _uche, ðinn, أسرة_, _амор,
   {{0xe1ff00ef,0xd5b800c6,0x81e90033,0x2cbeab7c}},	//   _đó_, эст_, যাম_, nutd_,
   {{0x69cd039d,0x9f5f0088,0x6015002b,0x00000000}},	//   द्री, kkuð_, _támi, --,
   {{0xfbd305a5,0x2bd31efb,0x8627013f,0x00000000}},	//   ध्यम, ध्या, _зьве, --,
   {{0x1a9c00c1,0x601c014b,0xc882044c,0x660e01ee}},	//   לידע, _bémo, _fişă_, _gobk,
   {{0x2ee60185,0x628600d1,0xf1a801dc,0x8af0013c}},	//   _asof_, _ékon, راوه_, _ayəl,
   {{0x601cab7d,0x8f75036c,0x7f753961,0x660e0117}},	//   _démo, купі, купц, _zobk,
   {{0xa3e60096,0xdb0d0143,0x81d60033,0x81e90033}},	//   _बघत_, _ocañ, িয়_, যাব_,
   {{0x273e0028,0x6b8d0065,0xee3600c6,0x601c00fc}},	//   ắng_, _afag, кны_, _fémo,
   {{0x25a3ab7e,0x9d45007e,0xc5f20327,0x6aadab7f}},	//   _mejl_, тенд, בדי_, _avaf,
   {{0x3de10081,0x09ca05d6,0x27eb009c,0x25a30078}},	//   বাইল, िभ्य, _nacn_, _lejl_,
   {{0x8af0025c,0xdb060216,0xef0e4ead,0x683a00d2}},	//   _azər, makë, _тм_, hůdc,
   {{0xe3d50081,0x200f7a56,0xaf340dce,0xddc30078}},	//   _সোমব, _hogi_, _حرمت, _jinż,
   {{0xe9a36089,0x3ebf58a4,0x200fab80,0x5e560182}},	//   расп, luut_, _kogi_, _جلوس_,
   {{0xf77216c4,0x200f0018,0x6843576e,0xab5b5c07}},	//   لاء_, _jogi_, анса, rfür,
   {{0xe73700a0,0x3ebf0a9f,0x7bd60193,0x200f016d}},	// [c7c0] вет_, nuut_, _ibyu, _mogi_,
   {{0x64432299,0x200fab81,0xdb04016d,0x752902c6}},	//   énin, _logi_, _adiç, _řeza,
   {{0x26d99c41,0x27eb0154,0xab5bab82,0x00000000}},	//   _epso_, _facn_, ngün, --,
   {{0x7af612fb,0xb4d200a5,0x200f9993,0x260042d4}},	//   _kryt, _वही_, _nogi_, राही_,
   {{0x25a301c5,0x27e043a0,0x245c00b6,0x7bd60079}},	//   _fejl_, mein_, ními_, _mbyu,
   {{0x27e09463,0x80db00c7,0xdb040396,0x9fc30033}},	//   lein_, ভিন্, _ediç, ্যোগ,
   {{0x403405af,0x7af6013f,0x29184f84,0x64a30077}},	//   лекс, _lryt, nyra_, _васа,
   {{0x27e0ab83,0xaab20096,0x601c002b,0x200f037a}},	//   nein_, _जिंक, _vémo, _cogi_,
   {{0x291812d2,0x00000000,0x00000000,0x00000000}},	//   hyra_, --, --, --,
   {{0x44260303,0x7c862f00,0x601c26ed,0x27e05d41}},	//   lho_, куме, _témo, hein_,
   {{0x27e0ab84,0xa3e6009d,0x55bb00ca,0x2918023b}},	//   kein_, _बघा_, ומיו, jyra_,
   {{0x44260303,0x64420084,0x7af6ab85,0x3ebfab86}},	//   nho_, nnoi, _bryt, buut_,
   {{0x27e01567,0x34df5ed7,0x3fcb04c6,0xf1c90be5}},	//   dein_, _नन्द, _آدمی_, _रामन,
   {{0x3eb90220,0x200f01c2,0x7bd6083e,0x7af63706}},	//   áste_, _zogi_, _ebyu, _dryt,
   {{0x44260e7a,0x19582787,0x29185432,0x26d901ec}},	//   kho_, вары_, gyra_, _spso_,
   {{0x44260181,0xe7ed00aa,0x27e0ab87,0x7c260364}},	//   jho_, _चोखा_, gein_, chkr,
   {{0x4426517d,0x26c000f9,0x245c0146,0x1dcf023a}},	// [c7d0] dho_, guio_, cími_, त्वत,
   {{0x2fdf02e2,0x44260181,0xcfeb0081,0x9afa00ca}},	//   zeug_, eho_, কায়_, _נפתח,
   {{0x9f4f0212,0x27e0ab88,0x25a30537,0x6a140076}},	//   _ingå_, bein_, _vejl_, _خبير,
   {{0x4426ab89,0xbde50139,0x644200fd,0x27e001b9}},	//   gho_, _abẹ̀, gnoi, cein_,
   {{0x1dc20e72,0x59a7000d,0x200fab8a,0x67460031}},	//   _शांत, _औजार, _rogi_, čujú,
   {{0x78ba03ce,0x21693967,0x200f0113,0x6594065c}},	//   štve, нили_, _sogi_, _вару,
   {{0x205512d3,0x200f07ac,0x26000caf,0x4426019f}},	//   лтир, _pogi_, रारी_, bho_,
   {{0x4426ab8b,0xe3b0029e,0x63ad0088,0x2d8eab8c}},	//   cho_, _ورق_, ðand, _affe_,
   {{0x69d722e7,0xdb060052,0xddc30078,0x00000000}},	//   _obxe, rakë, _tinż, --,
   {{0x27e00a00,0x7bd60167,0x7d090291,0xbde50139}},	//   zein_, _sbyu, еног_, _gbẹ̀,
   {{0x7fd51caf,0x611300b6,0x06cf0033,0x6cc501b3}},	//   _білі, _dělá, রিটি, ыйна,
   {{0x2d8e1044,0xdb06231d,0x9ef50037,0x245c96ba}},	//   _effe_, laké, _مستش, tími_,
   {{0x27e02c70,0x2bd300c3,0xdd0304a8,0x00000000}},	//   vein_, ध्धा, ısıd, --,
   {{0x2918023b,0x7c26023b,0x3ead075b,0x27e002db}},	//   tyra_, shkr, mset_, wein_,
   {{0x3ead7a1a,0x291eab8d,0x44260146,0x27e0ab8e}},	//   lset_, áta_, yho_, tein_,
   {{0x1dcf1a94,0x58953051,0x7d1c038c,0x3f8d5c31}},	//   त्रत, ршру, ørse, nceu_,
   {{0x291e02e6,0x7c24ab8f,0x260017ff,0xdb06231d}},	// [c7e0] šta_, _ilir, राली_, kaké,
   {{0x3ead0084,0x44260090,0xdb0654fc,0x00000000}},	//   iset_, who_, jaké, --,
   {{0x4426ab90,0xe3ba3035,0xd41600c6,0x28090206}},	//   tho_, ебе_, льды, ätnú_,
   {{0x7bc664ea,0x3ead0d64,0x69c301e8,0x249700cd}},	//   ngku, kset_, _öner, انند_,
   {{0x4426ab91,0xf772110a,0x6442ab92,0x7c240113}},	//   rho_, _داد_, rnoi, _mlir,
   {{0x4426ab93,0x38604d9d,0xab5b0364,0x7c2400ee}},	//   sho_, llir_, dgül, _llir,
   {{0x44260e7a,0x60150102,0x764b0103,0x255900d3}},	//   pho_, _náms, égye, _артэ_,
   {{0x4fc6313c,0xb4fb0054,0x44260197,0x321c0094}},	//   уска, _אפלי, qho_, skvy_,
   {{0x74130241,0x442400aa,0x6704896a,0x3ead2e3e}},	//   _اوقا, _ilm_, रमिक_, gset_,
   {{0x442491ad,0x7c360154,0x00000000,0x00000000}},	//   _hlm_, _amyr, --, --,
   {{0xd65700a1,0x7c24009c,0x3860ab94,0x00000000}},	//   ריית_, _blir, klir_, --,
   {{0x60150074,0x7c24ab95,0x00000000,0x00000000}},	//   _dáms, _clir, --, --,
   {{0x2bc600a5,0xa3bc02d5,0x7d1c0ac9,0x00000000}},	//   _वारा, _आयन_, ørsb, --,
   {{0xa2cc000c,0x2c7b0065,0x7e6d028d,0x2d8eab96}},	//   _समन्, _bàdì_, _èapp, _uffe_,
   {{0xbd5500bf,0x195904d9,0xd7fb01b6,0x00000000}},	//   _پروژ, тавы_, нуа_, --,
   {{0x6e3a02b6,0x6d460233,0x7c2405d3,0x386001ab}},	//   litb, şkas, _glir, glir_,
   {{0xd5bb0f99,0x245c02c6,0x9635ab97,0x00000000}},	// [c7f0] есе_, nímu_, анац, --,
   {{0x442401c5,0x80db0033,0x00000000,0x00000000}},	//   _alm_, ভিত্, --, --,
   {{0x38603f40,0x44245102,0xb8670018,0x91fc01b9}},	//   blir_, _blm_, _ماحو, _ghāi,
   {{0x69c700f3,0x4424002b,0x3e6b004d,0x6abd0063}},	//   lgje, _clm_, møte_, orsf,
   {{0x44246ec5,0x81e90081,0xcfaa0033,0x9f460503}},	//   _dlm_, যাস_, ওলান, _baoí_,
   {{0xd05a0253,0x69c7ab98,0x44240092,0x44e50150}},	//   _istə, ngje, _elm_, _tŷ_,
   {{0x2bf5009f,0x4424023b,0x6e3a7088,0xfbc60179}},	//   इयां_, _flm_, ditb, _वालम,
   {{0x3eadab99,0xe3b3006f,0x2938021e,0x4439ab9a}},	//   tset_, _درس_, טאון_, _ös_,
   {{0x533506d5,0x60061119,0x672d0885,0x3f8dab9b}},	//   _теат, рным_, nzaj, rceu_,
   {{0x63abab9c,0x3ead36d1,0x3f8d001f,0x7c24001c}},	//   lagn, rset_, sceu_, _slir,
   {{0x3ead17d2,0x61e3ab9d,0x7c244ca5,0x9f420220}},	//   sset_, menl, _plir, ľká_,
   {{0x61e32599,0x60c39b28,0x63aba6e6,0x9f420094}},	//   lenl, munm, nagn, žká_,
   {{0x60c30587,0x20d10019,0x501a00a1,0xde0500d6}},	//   lunm, _hơi_, _שונו, _впли,
   {{0x672d3239,0x7a2b1001,0x61e3ab9e,0x99830138}},	//   dzaj, _lütf, nenl, dijų_,
   {{0x98a6171b,0x6d460abd,0x63ab0124,0x60c301c2}},	//   рибе, şkar, kagn, nunm,
   {{0x63ab02e6,0xa3d70251,0x7c243e2c,0x61e30364}},	//   jagn, ़्म_, _ulir, henl,

   {{0x63ab008f,0x6f1b0808,0x61e3ab9f,0x6b8400f9}},	// [c800] dagn, nyuc, kenl, _igig,
   {{0x645b3590,0x63060401,0x63ab00f9,0x4424047e}},	//   _akui, یوال, eagn, _slm_,
   {{0x20d10028,0x61e3aba0,0x20e70018,0x38600428}},	//   _nơi_, denl, _női_, plir_,
   {{0xe29a78ee,0x63ababa1,0x60c30044,0x6aa42767}},	//   вад_, gagn, dunm, _kwif,
   {{0xf1940084,0x9983013f,0x672d00a5,0x442400c4}},	//   биль, cijų_, czaj, _vlm_,
   {{0x61e3aba2,0x20d100de,0x6b8400e7,0x645b2241}},	//   genl, _bơi_, _lgig, _ekui,
   {{0x03a600d6,0x4424aba3,0x63ababa4,0x6b842bfe}},	//   _вибо, _tlm_, bagn, _ogig,
   {{0xdfda013d,0xdb0b01e8,0x63ab0ef0,0x4424407b}},	//   тък_, _çiçe, cagn, _ulm_,
   {{0xde880129,0xe61f00de,0x61e36ce8,0x2905615d}},	//   _bịa_, _muôn_, benl, ̣la_,
   {{0xe61f0028,0x20d602ec,0x6b847291,0x3eb80087}},	//   _luôn_, _відс, _agig, črt_,
   {{0x64930078,0x6e3a032e,0x691e00bd,0x00000000}},	//   _għid, ritb, _jħeġ, --,
   {{0xa3a90ed3,0x6f090042,0x6aa40079,0x691e00bd}},	//   _खड़ा_, bxec, _bwif, _mħeġ,
   {{0x6e940080,0x81e900c7,0x27f202ad,0x5e9400e3}},	//   _التا, যার_, ddyn_, _التط,
   {{0x6b844f4a,0x00000000,0x00000000,0x00000000}},	//   _egig, --, --, --,
   {{0x97a70058,0x69c7aba5,0xe61f00de,0x63ab5511}},	//   ирал, rgje, _buôn_, yagn,
   {{0x61e30b88,0x5d7b00ca,0x6b84010a,0x69c70120}},	//   zenl, _באוק, _ggig, sgje,
   {{0xf773172a,0x61e31016,0x63ababa6,0x95d95566}},	// [c810] زار_, yenl, vagn, лдат_,
   {{0x60c3aba7,0x645b0185,0x9983013f,0x6015aba8}},	//   yunm, _skui, rijų_, _lámp,
   {{0x228b00f3,0x63ababa9,0x99830138,0x672d0034}},	//   _søk_, tagn, sijų_, szaj,
   {{0x601c0257,0x20d10019,0x7aed0821,0x60c3026a}},	//   _fémi, _rơi_, _ksat, vunm,
   {{0x61e3512e,0xadf83ec9,0xc29312eb,0x7bcd03a8}},	//   tenl, ्ञान_, زیاب, _mcau,
   {{0x63ab4559,0x60c30d30,0x7c3d0124,0x2ff80103}},	//   sagn, tunm, hisr, یڈنگ_,
   {{0x260913b4,0x63ababaa,0x61e3abab,0x81e90081}},	//   साठी_, pagn, renl, যাল_,
   {{0x7aedabac,0x60c307aa,0x7bcd0197,0x13aa09b4}},	//   _osat, runm, _ncau, _منفی_,
   {{0x64590034,0xde8800ac,0x439400ae,0x7fe80037}},	//   mowi, _pịa_, _фаус, شريف_,
   {{0x6459abad,0x443dabae,0x2d83052f,0x60c300cd}},	//   lowi, liw_, øje_, punm,
   {{0x30850080,0x63a90694,0x7aed48dd,0x90990647}},	//   _الصف, _keen, _asat, _свет_,
   {{0x64590067,0x6281abaf,0x7aed02a1,0x443dabb0}},	//   nowi, _hilo, _bsat, niw_,
   {{0x7aed0068,0x63a9abb1,0x05c70096,0xd00e487a}},	//   _csat, _meen, _लांब, _سلو_,
   {{0x63a9abb2,0x628101c2,0x7aed00bd,0x7c3d1ac3}},	//   _leen, _jilo, _dsat, aisr,
   {{0xb4e6033a,0x7aed8592,0x64590034,0x601c42a6}},	//   _भने_, _esat, kowi, _sémi,
   {{0x765cabb3,0x6281abb4,0x9ac503e5,0x63a9404b}},	//   _skry, _lilo, fiċċ, _neen,
   {{0x645900a5,0x6615abb5,0x44f702a1,0x27f28d67}},	// [c820] dowi, _bozk, _aħ_, rdyn_,
   {{0x6281abb6,0xaca30294,0xd0f916f8,0x81e90033}},	//   _nilo, _ndịi, ्माण_, যাঁ_,
   {{0x63a9abb7,0x2e3a00c1,0x04468d77,0x661501ff}},	//   _been, נגענ, бежн, _dozk,
   {{0x6281abb8,0x3ebf6c3c,0xdc190034,0x63a9047b}},	//   _ailo, krut_, _błęd, _ceen,
   {{0x6281abb9,0x63a93beb,0x6d5c135f,0x05080033}},	//   _bilo, _deen, ýraz, লনের_,
   {{0x59db099d,0x765cabba,0x6281abbb,0x9f5d0065}},	//   म्पर, _ukry, _cilo, _lowó_,
   {{0x92e800c7,0x62812fc5,0x64590034,0x44f700bd}},	//   যমে_, _dilo, bowi, _għ_,
   {{0xde880174,0x63a920eb,0x3ebf00bd,0xf2e800cd}},	//   _dịn_, _geen, frut_, _نکته_,
   {{0x91fc009c,0x7a2b02db,0x00000000,0x00000000}},	//   _bhāt, _hüte, --, --,
   {{0x6281abbc,0x7bcd002d,0x63a9abbd,0x9e0600ae}},	//   _gilo, _scau, _zeen, счил,
   {{0xa3bc00a5,0xa3cf3ad1,0x9f4f06a3,0x63a94a16}},	//   _आया_, _शाम_, _lagè_, _yeen,
   {{0x7f860080,0x26c0084f,0x6281abbe,0x7a2b0233}},	//   _الإن, krio_, _zilo, _müte,
   {{0x7c3d00d1,0xd5a80b94,0xe043007b,0x62810201}},	//   risr, गराज, _энци, _yilo,
   {{0xab5babbf,0x6aa962c3,0x26c020e0,0x645900a5}},	//   ngüi, _कबीर, drio_, zowi,
   {{0x661512fb,0xde8800de,0x2019028d,0x9f5d0af0}},	//   _rozk, _xịn_, _ègià_, _fowó_,
   {{0x2c7b0b4b,0x7aeda568,0x26c0030a,0x3a3a033c}},	//   _līdz_, _tsat, frio_, _empp_,
   {{0x7aedabc0,0x5a35004c,0x98aa01d3,0xdce301d3}},	// [c830] _usat, _мнит, ākās_, _iznā,
   {{0x63a9abc1,0x644aabc2,0x09b30081,0xfc3f0146}},	//   _seen, éfin, ঞ্জা, lií_,
   {{0x26c011c4,0x6459abc3,0x443d06a8,0xdb160154}},	//   ario_, towi, tiw_, _adyè,
   {{0x8cc02674,0xaa7b0146,0xfc3f023c,0x00000000}},	//   _विनो, jvýz, nií_, --,
   {{0x64590067,0x248d0d94,0x63a90da0,0x25b80079}},	//   rowi, _čemu_, _veen, _fdrl_,
   {{0x40950b70,0x63a90185,0x56943b21,0x443d07ac}},	//   орит, _ween, _харт, siw_,
   {{0x64590d1b,0x6281abc4,0x63a9abc5,0x7a2b0364}},	//   powi, _vilo, _teen, _güte,
   {{0x682a030b,0x2eb528dc,0x62810113,0xde88020b}},	//   _týde, осос, _wilo, _vịn_,
   {{0x6281abc6,0xfc3f033d,0xdb1d00a2,0x63b402c6}},	//   _tilo, dií_, ngsä, řený,
   {{0x7fb900cd,0xfe4200d6,0x3f86022b,0x3ebfabc7}},	//   _چهار_, дньо, _egou_, rrut_,
   {{0x5f950c0d,0xfc3f025b,0x16c60abe,0x51f40037}},	//   _диет, fií_, _लम्ब, _عسكر,
   {{0x5f7409b4,0xfc3f0146,0x00000000,0x00000000}},	//   _کامر, gií_, --, --,
   {{0x62790031,0x69db02ef,0xe80d1981,0x00000000}},	//   _dňov, đuen, हाना_, --,
   {{0xa2cc06ec,0x5ebe00c7,0xb0dd277c,0x26c00a39}},	//   _समस्, ্বশে, _महाग, vrio_,
   {{0xf983268e,0xfc320076,0x8cc00c9c,0x65c00065}},	//   дгро, _يحب_, _वियो, _láhà,
   {{0x78ba2e48,0xfc3f135f,0x59db314f,0x601c39b6}},	//   štvo, cií_, म्बर, _fému,
   {{0x320554d2,0x7a2b0103,0x78a909ac,0xdb1d02c3}},	// [c840] _only_, _süte, ćeva, ggsä,
   {{0xa3dc0af1,0x26c0abc8,0x55e30636,0x959a00d3}},	//   त्न_, rrio_, моуб, ртау_,
   {{0xd3020179,0x25b805db,0xae56006e,0x26c00231}},	//   लम्ब_, _vdrl_, קסעס_, srio_,
   {{0xf8b3004f,0x26c00465,0x9cda006e,0x00000000}},	//   _קשר_, prio_, יקעפ, --,
   {{0x7cf70174,0x8cc000c3,0x7a2b042c,0x683a00d2}},	//   _ịru, _विभो, _wüte, hůdk,
   {{0x64a60870,0x236d007e,0x9f4f03a9,0xfc3f0094}},	//   _мага, _dzej_, _gagé_, zií_,
   {{0x628f72b1,0x3f8605b4,0x00000000,0x00000000}},	//   _écon, _pgou_, --, --,
   {{0xdfd0223e,0x920300aa,0xfbc600b6,0x784500c6}},	//   ريخ_, लाउज_, _वागम, tėvi,
   {{0x63a401cd,0xe2971a0c,0x11d604a1,0x00000000}},	//   ðinu, _мат_, _міжр, --,
   {{0xddd800e9,0xdb1dabc9,0x69da0789,0x601c00fd}},	//   _bivš, ngså, _पॉली, _rému,
   {{0x81460068,0x7cf70294,0xc27b00ca,0x7a310139}},	//   _بنان, _ọru, _כרמי, _lótù,
   {{0x2d870400,0xccf802c6,0x9f440113,0x00000000}},	//   _egne_, rvě_, hemé_, --,
   {{0xfc3f025b,0x447b00c1,0x7a2b03e0,0x9f4403a9}},	//   rií_, ינטע, _rütb, kemé_,
   {{0xfc3f0031,0xda1b00a4,0x2ca703a8,0x76a10139}},	//   sií_, _नकळत_, _fwnd_, _láyò,
   {{0x63a2abca,0x69de0167,0xfc3f0094,0x37ab22fb}},	//   kbon, _dbpe, pií_, итан_,
   {{0xa3dc0251,0x24840364,0xde88020b,0xd6db00ae}},	//   त्म_, _nimm_, _lịm_, итз_,
   {{0x36d402fd,0xc9876e90,0x298700d3,0x27e905db}},	// [c850] мотр, _муни, _мынг, _činč_,
   {{0x63a20b24,0xcfc20033,0x00000000,0x00000000}},	//   ebon, ্জিন, --, --,
   {{0x89da0018,0x83980174,0x5bc4001c,0x91c400aa}},	//   _اوپر_, _ịhụg, _عقیل, _राजै,
   {{0x63a2abcb,0x58fa006e,0x9f4f01dc,0xe67a00e8}},	//   gbon, _פּינ, _wagé_, āršā,
   {{0x27e9abcc,0x1b1d0081,0xc5e60033,0x00000000}},	//   mean_, _পেতে_, নাজপ, --,
   {{0x27e9abcd,0x171a0266,0xf679006e,0x63a2083e}},	//   lean_, _הושע, _לאָמ, abon,
   {{0x24840088,0x7d1c0856,0xd4980497,0x91fc01b9}},	//   _fimm_, ørsl, _мрт_, _phār,
   {{0x27e9abce,0xe7cb17ad,0x60092611,0x200600eb}},	//   nean_, िलिप, сним_, _cnoi_,
   {{0xee390ea0,0x63bb628f,0xe29300cd,0x26002301}},	//   йни_, _idun, _آذر_, राची_,
   {{0x27e90049,0x629b07ac,0xf1d20714,0x00000000}},	//   hean_, _ituo, _सायन, --,
   {{0xed59abcf,0x80a400e3,0x27e9abd0,0x24840167}},	//   сон_, _يمكن, kean_, _yimm_,
   {{0x644b0795,0xf0f9000f,0x27e90ca3,0x6e2a033c}},	//   nngi, ्मीद_, jean_, _elfb,
   {{0x27e989f6,0xf1d203a2,0xda070455,0x644babd1}},	//   dean_, _सामन, शांत_, ingi,
   {{0x81e90081,0x63a200f1,0x63bb0172,0x4efa00ca}},	//   যাক_, zbon, _ldun, _להנו,
   {{0x63bbabd2,0xa3bc1d72,0x2bd4030b,0x644b03a9}},	//   _odun, _आयल_, _थापा, kngi,
   {{0x27e9abd3,0x2bc6009d,0x63bbabd4,0x2c7b0138}},	//   gean_, _वाटा, _ndun, _būdu_,
   {{0x0cdb16e2,0x6f1600a5,0x995500b6,0xe81d0096}},	// [c860] _बहुम, _życz, _výši_, _नवरा_,
   {{0x63bb1098,0x63a273a7,0x27040034,0x644b0180}},	//   _adun, wbon, रमौर_, engi,
   {{0x27e90634,0x629b7680,0x3a3700d7,0x00000000}},	//   bean_, _atuo, _זרים_, --,
   {{0x69dc7761,0x27e9abd5,0x9f420220,0x644b027f}},	//   lfre, cean_, ľkú_, gngi,
   {{0x628f025a,0x63bb0517,0x249f007e,0x68310537}},	//   _écol, _ddun, _čume_, _bådf,
   {{0x69dcabd6,0x7ae42a49,0xfec30081,0x30a60291}},	//   nfre, _mpit, ্বাধ, прив,
   {{0x64a606d8,0x03a6282a,0x765e06a8,0x7a22020d}},	//   _хаба, _ниво, mopy, _côti,
   {{0x6ebd06ed,0x7d1c02ec,0x289b0089,0x81e90081}},	//   _शिशु, ørsm, זיקא, যাগ_,
   {{0x4426abd7,0x64425be5,0xb8010033,0x52764345}},	//   mko_, mioi, _একমত_, _فائز,
   {{0x4426abd8,0x27e90a00,0x824a029e,0x765e33aa}},	//   lko_, zean_, _اشرف_, nopy,
   {{0x69dcabd9,0x44267212,0xdb0f04d8,0x7ae4abda}},	//   dfre, oko_, macé, _apit,
   {{0x27e90a00,0xdb0f020d,0x61ea13ea,0x7ae4033c}},	//   xean_, lacé, lefl, _bpit,
   {{0x69dcabdb,0x4426abdc,0x765eabdd,0x05cc0034}},	//   ffre, iko_, kopy, ालाब,
   {{0x44260211,0xa3dc05cd,0x27e900d1,0xdb040610}},	//   hko_, त्त_, wean_, _adió,
   {{0xa3cc1e5e,0x69ce0e72,0x7ae4abde,0x44264710}},	//   लला_, _तारी, _epit, kko_,
   {{0xdc2b00bf,0x7c26227a,0x69ce084e,0x00000000}},	//   _دسته_, ckkr, agbe, --,
   {{0x4426abdf,0x7c2dabe0,0x35f510e8,0x644b01df}},	// [c870] dko_, _ilar, мпар, vngi,
   {{0x4426abe1,0x27e98350,0xa3cf1344,0x682a025b}},	//   eko_, sean_, _शाह_, _výda,
   {{0x7c2d09ce,0xb83524d3,0x7afd038c,0x61ea026a}},	//   _klar, _женщ, lvst, defl,
   {{0x644b054d,0x7bcf1003,0xc952040a,0x05740867}},	//   ungi, ngcu, _ימי_, رالد,
   {{0x386973bb,0x64930078,0x7c2d00d1,0xdb0f2a56}},	//   mlar_, _għin, _mlar, facé,
   {{0x44263689,0xdd860192,0x7c2d0472,0x628fabe2}},	//   ako_, _لو_, _llar, _écom,
   {{0x7c2d08f5,0xe61f0019,0x442612fa,0xfbbf09c4}},	//   _olar, _nuôi_, bko_, ्लाम,
   {{0x386908fd,0x44261904,0xb69b025a,0x6442100a}},	//   nlar_, cko_, _grâc, cioi,
   {{0x442d2f8d,0x443fabe3,0x69dc00f0,0x44ef0033}},	//   _ile_, _imu_, yfre, _টপিক_,
   {{0x386903e0,0x442dabe4,0x7a30032c,0x69dc73a0}},	//   hlar_, _hle_, _käte, xfre,
   {{0x3869abe5,0x7ae4abe6,0xa2c90455,0x442dabe7}},	//   klar_, _spit, हूर्, _kle_,
   {{0x38690b88,0xca2903c2,0x7a300212,0xe9f90032}},	//   jlar_, _דם_, _mäte, _iwẹ_,
   {{0x3869abe8,0x29010022,0x7c2d0113,0x442d024a}},	//   dlar_, _arha_, _dlar, _mle_,
   {{0x442dabe9,0x442603f3,0x68fc3fa8,0x64420036}},	//   _lle_, zko_, tvrd, zioi,
   {{0x442dabea,0x7a300222,0x443f0a15,0x69dcabeb}},	//   _ole_, _näte, _omu_, rfre,
   {{0x443fabec,0x38690b6a,0x3b00003d,0x442dabed}},	//   _nmu_, glar_, _triq_, _nle_,
   {{0xe61a0dc0,0x7ae402e6,0xf7432d64,0x64420084}},	// [c880] ода_, _upit, вето, vioi,
   {{0x442d2294,0x443fabee,0xf1d20b2b,0x7c2d0234}},	//   _ale_, _amu_, _साधन, _zlar,
   {{0x4426abef,0x3869abf0,0x442d0a8d,0x938a74c3}},	//   tko_, blar_, _ble_, осла_,
   {{0x44266c12,0x683102fe,0x442d4ec7,0x3869abf1}},	//   uko_, _rådg, _cle_, clar_,
   {{0x442d030b,0x61ea812d,0x644200c2,0x66292a6b}},	//   _dle_, tefl, rioi, áskó,
   {{0x442dabf2,0x20ee000d,0x443f0517,0x386096c1}},	//   _ele_, _při_, _emu_, loir_,
   {{0xc0e3372d,0x44267d30,0x64423655,0xdb061d4b}},	//   војк, pko_, pioi, lakä,
   {{0xd010054f,0x68e302e2,0x442dabf3,0x661cabf4}},	//   الة_, _ände, _gle_, _hork,
   {{0x661cabf5,0x5fbf06ed,0x6724023f,0x6440abf6}},	//   _kork, _एयरल, nyij, _immi,
   {{0x386908bb,0x20ee030b,0x442d5874,0x661cabf7}},	//   zlar_, _tři_, _zle_, _jork,
   {{0x3869978a,0x44fe013f,0x442dabf8,0x661cabf9}},	//   ylar_, _jį_, _yle_, _mork,
   {{0x3869abfa,0xd00f001c,0x26050c22,0xdb042dc1}},	//   xlar_, _پله_, _होनी_, _adiñ,
   {{0x6288abfb,0x3869abfc,0x661c057a,0xe80d049d}},	//   _kido, vlar_, _oork, हासा_,
   {{0x6831052f,0x3869030a,0x29010141,0x7afd0429}},	//   _måde, wlar_, _prha_, rvst,
   {{0x3869522f,0x6288abfd,0x644000bd,0xe8000251}},	//   tlar_, _mido, _ommi, _लोहा_,
   {{0x7c2d063d,0x6ce300d6,0x6288abfe,0x6f02abff}},	//   _ular, _ріше, _lido, _kroc,
   {{0x3869ac00,0x78a21386,0x6b8dac01,0x682a030b}},	// [c890] rlar_, _čove, _igag, _týdn,
   {{0x644068fc,0x09c60081,0xdcfa08bb,0x38690511}},	//   _ammi, শ্বা, latı, slar_,
   {{0x442d0472,0x3869ac02,0x2c72045e,0x80dd0592}},	//   _ple_, plar_, láda_, _महें,
   {{0x386901d4,0xdcfa07aa,0x6aad91dc,0x443f0167}},	//   qlar_, natı, _kwaf, _qmu_,
   {{0x6288ac03,0x661c1484,0x442d14b1,0x6b8d2375}},	//   _bido, _fork, _vle_, _mgag,
   {{0x661c923d,0x863500c1,0x644041ad,0x628820f2}},	//   _gork, _טאָג_, _emmi, _cido,
   {{0x6288ac04,0x22491197,0x69d70006,0xdcfa0491}},	//   _dido, đak_, _बानी, katı,
   {{0x443f316c,0x6b8dac05,0x62880042,0x442dac06}},	//   _umu_, _ngag, _eido, _ule_,
   {{0x3eb92f22,0xa3e50789,0x6aad01c2,0x3255224a}},	//   ést_, _बॉय_, _nwaf, _звар,
   {{0x6b8dac07,0x6f020091,0x78ba00cc,0xa2c4030b}},	//   _agag, _droc, štvi, _रित्,
   {{0x1d090114,0x6aadabbd,0xdcfa07e7,0x1b1d0033}},	//   чени_, _awaf, fatı, _পেলে_,
   {{0xce950465,0x6288042d,0x6aad0517,0xfc320037}},	//   _задъ, _zido, _bwaf, احد_,
   {{0x386004ea,0x2c720094,0x3f8200c6,0x6f0219ca}},	//   voir_, gáda_, žkur_, _groc,
   {{0xc332040a,0x6b8d53ed,0x4a75022a,0x6e280113}},	//   רוך_, _egag, выст, ckdb,
   {{0x3860ac08,0xdcfa00a7,0x6aadac09,0xf34e0134}},	//   toir_, batı, _ewaf, hụpụ_,
   {{0x661cac0a,0x7e610167,0x6b8d0172,0x2e350032}},	//   _sork, lolp, _ggag, _fùfù_,
   {{0x7bd60193,0x7a2b2326,0x386000fd,0x661cac0b}},	// [c8a0] _icyu, _kütl, roir_, _pork,
   {{0x68310bab,0x7af60035,0xa3e502d5,0x6b8dac0c}},	//   _råde, _isyt, _बॉब_, _zgag,
   {{0xf1c9099d,0x41c90e4c,0x62883fc4,0xe1c9063e}},	//   _राजन, _राजस, _rido, _राजघ,
   {{0x6288ac0d,0xe3b2029e,0x661c0054,0x1e1c0efd}},	//   _sido, ارا_, _work, _पक्ष_,
   {{0xe80d0b42,0x27e001c2,0xdbcd0139,0xf4870a85}},	//   हारा_, mfin_, _kóòw, رامی,
   {{0x8cc00789,0x7d03009c,0x00000000,0x00000000}},	//   _विलो, _orns, --, --,
   {{0xdcfa0702,0xa2cc06ed,0x62882e87,0x6abd0034}},	//   yatı, _समक्, _vido, _ऍट्र,
   {{0xf1d2007d,0x27e0ac0e,0xddcb00e7,0x9f4f00ee}},	//   _सावन, nfin_, _čiši, _bagà_,
   {{0x9cec0033,0x7d0310a5,0x00000000,0x00000000}},	//   _ওপেন_, _arns, --, --,
   {{0xd0100068,0x437513a4,0x7e610487,0x7bd60079}},	//   الک_, _руст, golp, _acyu,
   {{0x6f02ac0f,0x9f4f0231,0x6aad024a,0x5c75085f}},	//   _wroc, _pagã_, _swaf, клот,
   {{0x6f02ac10,0xe80037b3,0x61fa3382,0xd5cc007f}},	//   _troc, _लोला_, _hatl, ालुओ,
   {{0x7d0335a5,0x61faac11,0xdcfa0511,0x6fa61492}},	//   _erns, _katl, ratı, _ट्यू,
   {{0x7e61028d,0xb69b00ae,0x2c721054,0xfaff0216}},	//   colp, _brân, ráda_, rvë_,
   {{0xe80d009d,0x61faac12,0xa3c2014e,0xf80723d0}},	//   हाला_, _matl, ूला_, нчан,
   {{0xb9090d1b,0xdb0f02c6,0x61fa0325,0x6aad0453}},	//   _यह_, lací, _latl, _twaf,
   {{0x2ba73212,0xa2cc1e05,0x6aada738,0x0c740452}},	// [c8b0] _क्या, _समग्, _uwaf, _حدود,
   {{0x27e0ac13,0xb69b020a,0x321e109b,0x27f900ca}},	//   afin_, _frân, _noty_, _wasn_,
   {{0xbc680688,0x682300aa,0x92ad0033,0xb69bac14}},	//   _زمین_, _sõdu, _কমে_, _grân,
   {{0x320c0d54,0x00000000,0x00000000,0x00000000}},	//   _andy_, --, --, --,
   {{0x61fa7f93,0x321e00b6,0xdb0f02c6,0x00000000}},	//   _batl, _boty_, kací, --,
   {{0x321e01af,0x9f440428,0x9f4f0036,0x26c903e3}},	//   _coty_, demà_, _ragà_, mrao_,
   {{0x20552d06,0x9f420181,0x260e121d,0x7a3000aa}},	//   ктир, ľký_, ठारी_, _jäta,
   {{0x2605428a,0x260902d5,0x7a3033b9,0x9f4f00b3}},	//   _होती_, साकी_, _mäta, _pagà_,
   {{0x61faac15,0xf1a71278,0xa295004d,0x7e613f9b}},	//   _fatl, _зрен, _разі, tolp,
   {{0x26c900cc,0xdb0fac16,0x00000000,0x00000000}},	//   irao_, gací, --, --,
   {{0x7e616085,0x224700c6,0x7a3002c3,0x02d1ac17}},	//   rolp, mink_, _näta, _समुन,
   {{0x8c4600d3,0x61faa3f3,0x26c909ac,0x7a22020d}},	//   теме, _zatl, krao_, _nôtr,
   {{0x6d58037a,0xdb0fac18,0x12bf0033,0x00000000}},	//   _exva, bací, _ইহুদ, --,
   {{0xa2c4048a,0x26c9016d,0xdb0f0143,0x7d03ac19}},	//   _रिस्, drao_, cací, _trns,
   {{0x64d005d4,0xa9674cc3,0xa92700e8,0x00000000}},	//   _हमेश, вира_, _nožē, --,
   {{0x2c08000f,0xde8800de,0x7bd60169,0x66e63bbc}},	//   षाओं_, _dịu_, _ucyu, коба,
   {{0x18671588,0x27e0ac1a,0x26c90039,0x3f8f005c}},	// [c8c0] тати_, rfin_, grao_, _mggu_,
   {{0xa926198a,0xb69b001f,0x66e34cc3,0xe5a600ae}},	//   _адол, _trân, рофа, тижи,
   {{0xd49900d6,0x61faac1b,0x22470185,0x09b80033}},	//   ері_, _ratl, dink_, _জাপা,
   {{0xad1a0130,0xfbdf0019,0x68e30212,0x82a6004d}},	//   ווער, hiên_, _ända, вадж,
   {{0xe36332d3,0x61faac1c,0xe2971da3,0xe8e20378}},	//   акци, _patl, вач_, _पहुच,
   {{0x61faac1d,0x00000000,0x00000000,0x00000000}},	//   _qatl, --, --, --,
   {{0xdb0f5348,0xa2c40f35,0xd12f0190,0xe64300ba}},	//   vací, _रिव्, يمه_, _терп,
   {{0x1ee6015a,0x75230364,0xc95300ca,0x240700ae}},	//   نوعی_, änze, ימו_, _инси_,
   {{0x09b800c7,0x61faac1e,0x78a90039,0x9f4f266c}},	//   _জানা, _tatl, ćevi, _pagá_,
   {{0xde8800fe,0x00000000,0x00000000,0x00000000}},	//   _nịt_, --, --, --,
   {{0x68310212,0xdb0f0094,0x00000000,0x00000000}},	//   _låda, rací, --, --,
   {{0x8fa64070,0xbbbf00c3,0x41d250d7,0x00000000}},	//   _раде, ्लेक, _साँस, --,
   {{0x290c0212,0xde880023,0xdb0f00d4,0x6fd700a4}},	//   ådan_, _bịt_, pací, _यातू,
   {{0x2c5600d9,0x00000000,0x00000000,0x00000000}},	//   rāda_, --, --, --,
   {{0x6d450a7f,0x29056c04,0x00000000,0x00000000}},	//   _žhav, íla_, --, --,
   {{0x26c908a9,0xb88200d4,0xdb230103,0x00000000}},	//   trao_, žína, _نوعی, --,
   {{0x41d20336,0x7a2200fd,0xdb1d042c,0x00000000}},	// [c8d0] _सांस, _vôtr, ngsü, --,
   {{0x26c90231,0x7a3002c3,0x00000000,0x00000000}},	//   rrao_, _täta, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2c405d4,0xdb0f0161,0x7a3000bc,0x3e79014b}},	//   _रिश्, cacã, _jätn, mète_,
   {{0x3e790257,0x7a300212,0x69c1007f,0x2247ac1f}},	//   lète_, _mätn, ólew, tink_,
   {{0xde880023,0x69d50364,0x722b007b,0x00000000}},	//   _xịt_, ngze, ьцев_, --,
   {{0x09b800c7,0x21660905,0x3e790257,0xa0694a4e}},	//   _জামা, лиши_, nète_, нака_,
   {{0x224718f0,0x8bbf0403,0xbbbf00d2,0xddc800d2}},	//   sink_, ्लोअ, ्लोक, lidň,
   {{0x3e7900fd,0x00000000,0x00000000,0x00000000}},	//   hète_, --, --, --,
   {{0x96d50f35,0x7c3f0138,0x248d00fe,0x63b9ac20}},	//   यूयॉ, _įpra, _hiem_, lawn,
   {{0x248dac21,0x3f8f02fa,0xac8614fb,0xd7c30096}},	//   _kiem_, _tggu_, лгол, षणाच,
   {{0x229914b1,0x41dfac22,0x248d0078,0xfaa6ac23}},	//   _kèk_, प्रस, _jiem_, ламо,
   {{0xef0e1693,0x270d009d,0x200f003e,0xe456006e}},	//   _ум_, समोर_, _ingi_, רירט_,
   {{0xed593a7a,0x628f025a,0xa3e52235,0x6da22bcf}},	//   _пол_, _écou, _बॉस_, _лиша,
   {{0x6831711f,0x7d1c0170,0xde8800de,0x68fb0034}},	//   _såda, ørst, _vịt_, łudn,
   {{0xc2f900c7,0xf7722204,0x248dac24,0x1867328d}},	//   _আপনি_, ماء_, _niem_, гаси_,
   {{0x63b957e0,0xdb0f016d,0x229900d1,0xe7370fe3}},	// [c8e0] dawn, racã, _nèk_, гет_,
   {{0x3e799925,0xe8fa16a1,0x6aa41c35,0xf1d25660}},	//   bète_, _зло_, _itif, _साइन,
   {{0x200f415d,0x69db0a39,0x682a0206,0x63a4037a}},	//   _ongi_, đuet, _lýdi, ñino,
   {{0x44200682,0x229905aa,0x98160037,0x25a70555}},	//   ði_, _bèk_, _إبدا, ınla_,
   {{0x248d9fe8,0x27f20188,0x229901dc,0x934600ae}},	//   _diem_, meyn_, _cèk_, ынде,
   {{0x26d2ac25,0x27f2008c,0x22990113,0x200f00f3}},	//   muyo_, leyn_, _dèk_, _angi_,
   {{0xc31c0081,0x7bc40325,0x63b9007f,0x90e60981}},	//   _দেখি_, _odiu, bawn, استن,
   {{0xba01007d,0x27f21df2,0x229902f1,0xb97b021e}},	//   _ऊफ्फ_, neyn_, _fèk_, ענקי,
   {{0x26d249e4,0x229903a9,0x6aa40169,0xd33600d3}},	//   nuyo_, _gèk_, _ntif, _сэвы,
   {{0xf29700a1,0x6fa403a2,0x27f20188,0xe2970231}},	//   _עכבר_, _ग्रं, heyn_, _саф_,
   {{0x6aa4a281,0x51930308,0xa3bb0034,0x515600ae}},	//   _atif, _المذ, _आजम_, _стау,
   {{0xc0a90d74,0xf0b10018,0x26d2ac26,0xfbdf084e}},	//   _شامل_, _بیٹھ, kuyo_, enêr_,
   {{0x27f24628,0x261709c4,0x628f014b,0x00000000}},	//   deyn_, नामी_, _écot, --,
   {{0xad2600cd,0x693502a0,0x5a44002d,0x00000000}},	//   _مربو, ангу, бэса, --,
   {{0x195804d9,0x6aa40178,0x4e1100b6,0xdb0f00b3}},	//   гары_, _etif, तारै_, sacà,
   {{0x3e7900fd,0x27f2008c,0xfbdf0231,0x00000000}},	//   rète_, geyn_, rnês_, --,
   {{0x248d1cab,0x26d2198f,0x35b51525,0xb69b19f0}},	// [c8f0] _riem_, guyo_, ибар, _trâm,
   {{0x7aed6fd4,0x2d9e002d,0x3e79020d,0x3b090fd1}},	//   _ipat, ncte_, pète_, _iraq_,
   {{0xb65a0d79,0xfbdf0019,0x69c5ac27,0x44f50fe3}},	//   nrẹ́, hiêm_, _idhe, рпес,
   {{0x7aed00ac,0x81bc01d3,0x26d21ef8,0xe3b00037}},	//   _kpat, _slēp, buyo_, كره_,
   {{0x63b900a5,0x248d0220,0x26d2037a,0x7aed0090}},	//   rawn, _viem_, cuyo_, _jpat,
   {{0x248d00a5,0x6594ac28,0x7aed4686,0xe296302e}},	//   _wiem_, _гару, _mpat, шаш_,
   {{0x248d00d9,0x3b090124,0x00000000,0x00000000}},	//   _tiem_, _lraq_, --, --,
   {{0xaec51191,0x7aed3fa8,0x63ad04d8,0x2ba70d88}},	//   абил, _opat, ñand, कुमा,
   {{0x644bac29,0x2003030b,0xb3a90491,0x683102c3}},	//   migi, ěji_, ğıdı, _lådo,
   {{0x644bac2a,0xcee80037,0x7d090291,0xb3a9071d}},	//   ligi, ارين_, вног_, şıdı,
   {{0xed590636,0x6aa45cfe,0x7aedac2b,0x59dc17ff}},	//   тон_, _stif, _apat, _बाबर,
   {{0x69c5ac2c,0x644bac2d,0x5fdc0096,0x9f4600b3}},	//   _adhe, nigi, _यायल, _oboè_,
   {{0x683800b6,0x628f020d,0x7c3d0216,0x00000000}},	//   _jíde, _écos, ërra, --,
   {{0xa2cd06ec,0x644bac2e,0x27f2008a,0x26050cce}},	//   _सिन्, higi, weyn_, _होली_,
   {{0xa96a1d6e,0x69d70296,0x644bac2f,0x7aedac30}},	//   тива_, _बारी, kigi, _epat,
   {{0xa3e50789,0x644b82ad,0x26d20fa0,0x7a309764}},	//   _बॉल_, jigi, tuyo_, _täto,
   {{0x6e23ac31,0x6aa4ac32,0xde8800de,0x44f70154}},	// [c900] _konb, _utif, _kịp_, _aŧ_,
   {{0x09e400c7,0x3ebfac33,0x6283015c,0x27f26acd}},	//   _ফোরা, isut_, jmno, seyn_,
   {{0x644b0a6c,0x7c240dfb,0xbef22674,0x37e63f1d}},	//   figi, _koir, _अन्न_, _конг,
   {{0x644b0256,0x7aed013f,0x26d20009,0x3ebf00c2}},	//   gigi, _ypat, puyo_, ksut_,
   {{0x7c240441,0x69c1003e,0x7aed01cb,0x41b60037}},	//   _moir, ðleg, _xpat, لمشر,
   {{0x7c24ac34,0x6e230634,0xda19009f,0xd04300a7}},	//   _loir, _nonb, दायत_, munə,
   {{0x644bac35,0x26c00138,0xf34e0134,0x00000000}},	//   bigi, lsio_, nụzụ_, --,
   {{0x7c240257,0xb7bb0023,0x644bac36,0x7c3f00c6}},	//   _noir, _loãn, cigi, _įpro,
   {{0xe29a088c,0xfba70c16,0x4424ac37,0x6e23ac38}},	//   _раз_, _क्षम, _iom_, _bonb,
   {{0x4424ac39,0x26c000f0,0x7c241c5d,0x00000000}},	//   _hom_, isio_, _aoir, --,
   {{0x4424ac3a,0x7aedac3b,0x7c2407bc,0xde8800de}},	//   _kom_, _spat, _boir, _dịp_,
   {{0xdee61d1c,0x7c24ac3c,0x4424ac3d,0x7aed0167}},	//   _води, _coir, _jom_, _ppat,
   {{0x7c2402bc,0xa3ce00c3,0x2f0f003e,0x6e230154}},	//   _doir, _शयन_, rögð_, _fonb,
   {{0x4424ac3e,0xfba7201e,0x644b39af,0x6e23ac3f}},	//   _lom_, _क्रम, zigi, _gonb,
   {{0x7c24ac40,0x644b01a6,0x4424ac41,0xeabf028d}},	//   _foir, yigi, _oom_, ssù_,
   {{0x4424ac42,0x7c240013,0x59dc1cff,0x2c7b00e8}},	//   _nom_, _goir, _बाथर, _lūdz_,
   {{0x7aedac43,0x3ce9007e,0xdb0f0131,0x64930090}},	// [c910] _upat, _ćavi_, dacç, _lħit,
   {{0x69c5ac44,0x442445ac,0x644bac45,0x24980113}},	//   _udhe, _aom_, wigi, _burm_,
   {{0x4424ac46,0x78a9015c,0x00000000,0x00000000}},	//   _bom_, ćevs, --, --,
   {{0x3ea60496,0x68380610,0x2fc603a9,0x00000000}},	//   _otot_, _píde, _ndog_, --,
   {{0x4424ac47,0x81ae00c7,0xe8005a5f,0x9f5d03a9}},	//   _dom_, _কাজ_, _लोटा_, _gawè_,
   {{0x6838ac48,0x644bac49,0xc244224a,0xdb061054}},	//   _víde, sigi, онік, jaký,
   {{0x644b420f,0x4424610a,0x6283015c,0xb7bb0131}},	//   pigi, _fom_, rmno, _joão,
   {{0x2ba706eb,0x3ebfa6e9,0x4424ac4a,0x6e23ac4b}},	//   _क्ला, tsut_, _gom_, _sonb,
   {{0x6006055b,0x672dac4c,0x64492361,0x3ebf0dd8}},	//   сным_, nyaj, _imei, usut_,
   {{0x7c24a5a9,0x6e3aac4d,0xee360895,0x30e702ec}},	//   _soir, ghtb, йны_, _відб,
   {{0x2fd92761,0x4424006c,0x7c24ac4e,0x2c720018}},	//   _مواد_, _yom_, _poir, ládi_,
   {{0xca29004f,0x3ebf8635,0x26c06bcf,0x672dac4f}},	//   _אם_, psut_, ysio_, kyaj,
   {{0x6e230c56,0x7c240257,0x59dc0ded,0x201f0239}},	//   _tonb, _voir, _बादर, mjui_,
   {{0x6e3aac50,0xa2da05cd,0x09b80081,0xff50001c}},	//   chtb, _नमस्, _জাহা, _تخم_,
   {{0x7c2410f0,0x27eb01c2,0x64490072,0x00000000}},	//   _toir, _bbcn_, _omei, --,
   {{0x5eee2397,0x81ae0033,0x1cb600ca,0x9f5d0154}},	//   _अहम्_, _কাছ_, _פלפל_, _pawè_,
   {{0x4424ac51,0x7a3032d2,0x6f1d0f3a,0x87b901b6}},	// [c920] _rom_, _jätk, äsch, руст_,
   {{0x442409ce,0x6449555d,0x6ecf000d,0x26c0ac52}},	//   _som_, _amei, _दिनु, rsio_,
   {{0x44240d7d,0xdcea1386,0x26c00752,0x69fb0089}},	//   _pom_, čiće, ssio_, _גליק,
   {{0x746900d6,0xe29a00c6,0xf487010d,0x7e682347}},	//   арів_, гад_, مانی, zodp,
   {{0x4424ac53,0x2498ac54,0xdb0f0131,0x672d0027}},	//   _vom_, _wurm_, racç, cyaj,
   {{0x78a20292,0xc5d502ec,0x44246633,0x644901c2}},	//   _čovj, _місь, _wom_, _emei,
   {{0xa2c402d5,0xa0a30077,0x44249759,0x20dc007e}},	//   _रिक्, пшыл, _tom_, kšiš_,
   {{0x628f0451,0x7a2b0364,0x50b70037,0x00000000}},	//   _ècon, _hütt, حدود_, --,
   {{0x41e00187,0x7a2b00aa,0x6443ac55,0x63a20668}},	//   _नापस, _kütt, ënie, mcon,
   {{0x2a6a938f,0x68310c96,0x63a2ac56,0x38690072}},	//   jobb_, _rådm, lcon, zoar_,
   {{0xdd900dd0,0x7a2bac57,0x7c3d023b,0x40960037}},	//   بود_, _mütt, ërro, _الصر,
   {{0x63a2ac58,0x7e680103,0xfbab007b,0x00000000}},	//   ncon, sodp, ытой_, --,
   {{0x7e68025b,0x3ea607ac,0x3869078e,0x00000000}},	//   podp, _utot_, voar_, --,
   {{0x63a20063,0x2bdb22a3,0x25ad0218,0x6ab60178}},	//   hcon, _भावा, _đelo_, _dwyf,
   {{0x28d91362,0x63a200e5,0x487700e3,0xd90f1ac9}},	//   बंधि, kcon, مدرس, ریح_,
   {{0x98a50367,0x672d0027,0x2486ac59,0x2004ac5a}},	//   çlı_, tyaj, jmom_, ndmi_,
   {{0x63a2ac5b,0xf7732296,0xdb1f00c2,0xa2cd1bd2}},	// [c930] dcon, سار_, äväl, _सिध्,
   {{0x7a3002c3,0x28d90285,0x00000000,0x00000000}},	//   _näth, बंदि, --, --,
   {{0xadea007a,0x63a20381,0x29070231,0x649302a1}},	//   ज्यन_, fcon, _éna_, _rħis,
   {{0x69d8070a,0x337511fb,0x63a2019f,0x248600e7}},	//   _över, огер, gcon, gmom_,
   {{0x387e025a,0x7a2ba6c7,0x2be10442,0xab5b013c}},	//   ître_, _fütt, _कानू_, qaüd,
   {{0x27e902ad,0x24860220,0x63a2398a,0x644800c6}},	//   lfan_, amom_, acon, _įdie,
   {{0x66151523,0x2bbe046e,0x683102c3,0x645b0154}},	//   _inzk, ्णमा, _rådj, _tjui,
   {{0x2bdb0635,0x63a2013d,0x27e902f1,0x261708fa}},	//   _भाषा, ccon, nfan_, नावी_,
   {{0xee395c84,0xcdf52787,0x94160096,0x4394037e}},	//   ини_, очны, णारच_, _хаус,
   {{0x7bdf7276,0xa6e20088,0x63bb0313,0x926b0291}},	//   _acqu, æðin, _heun, _срба_,
   {{0xcb091723,0x63bb005a,0x61550018,0x66050188}},	//   _של_, _keun, _بنائ, idhk,
   {{0x63bb04ea,0x59dc02b0,0x645902f1,0x200301d3}},	//   _jeun, _बाहर, nnwi, ējis_,
   {{0xa3e1277c,0x41e00521,0x63bbac5c,0x27e900f0}},	//   _दान_, _नामस, _meun, dfan_,
   {{0x3ead366c,0x63bb0922,0x63a20072,0x7a30007b}},	//   mpet_, _leun, zcon, _käti,
   {{0x290cac5d,0x27e9ac5e,0x160d0251,0x9f4f028d}},	//   ída_, ffan_, _सफ़र_, _ragù_,
   {{0x59dc0789,0x670504f1,0x6ab6057a,0x7a2bac5f}},	//   _बावर, रिंक_, _twyf, _sütt,
   {{0x63a200e7,0xdb0d0161,0x464a0459,0x2c5601d3}},	// [c940] vcon, _reaç, азан_, jādi_,
   {{0xe6171830,0x63a297eb,0x6838015e,0x6281019f}},	//   оду_, wcon, _dída, _nhlo,
   {{0x69dcac60,0x63bb030a,0x7a3000ce,0xd4c60037}},	//   mgre, _beun, _näti, تغذي,
   {{0x69dc0e8a,0x6d410880,0x87d652c6,0x63bb279c}},	//   lgre, izla, _بغدا, _ceun,
   {{0x63a2ac61,0x6f0904eb,0x63bb7850,0x63ad0487}},	//   rcon, jvec, _deun, ñana,
   {{0x6281ac62,0x24860ca7,0x63a21a91,0x628f028d}},	//   _chlo, smom_, scon, _ècol,
   {{0x63a2029a,0x6ab71f88,0x2c720094,0x26174038}},	//   pcon, _अब्र, ládu_, नारी_,
   {{0x212000e9,0x3ec64c46,0x63bbac63,0x3ae407b0}},	//   ćih_, особ, _geun, köp_,
   {{0x316903e0,0x2be1278e,0x62812bc0,0x7c3d0216}},	//   ğaza_, _काबू_, _fhlo, ërrm,
   {{0x20020087,0x628103ea,0x63bb2e13,0xb69b044c}},	//   žki_, _ghlo, _zeun, _grâu,
   {{0xa3e1000f,0xafe602ec,0xc22300cd,0x27e90178}},	//   _दाम_, _можл, _تکنو, yfan_,
   {{0x09d302e8,0x1ee9001c,0x161102d5,0x69dc01cb}},	//   तल्य, جویی_, _डोनर_, egre,
   {{0xfad8008f,0x69dc6a55,0x1be1007a,0x00000000}},	//   одящ_, fgre, ग्गल_, --,
   {{0x69dcac64,0xa2cd022d,0xfc46003e,0x00000000}},	//   ggre, _सिस्, _þína_, --,
   {{0x26050067,0x7a3f030b,0xf84b246d,0x199454b5}},	//   _होगी_, vště, ачай_, даря,
   {{0x443d01fa,0x7a390139,0xdc2b001c,0x69d71d69}},	//   xhw_, _dìta, _خسته_, _बाकी,
   {{0x27e9ac65,0x3a3a0167,0x2617142e,0x2c720094}},	// [c950] rfan_, _flpp_, नाली_, gádu_,
   {{0x63bbac66,0x61f81d95,0x69dc7669,0x1a65001c}},	//   _seun, jevl, cgre, _ریزی_,
   {{0x682a0146,0x6f0900d4,0x61f8ac67,0x00000000}},	//   _výdr, zvec, devl, --,
   {{0x7bddac68,0x2901ac69,0x62811909,0x2c5601d3}},	//   ngsu, _isha_, _shlo, tādi_,
   {{0x78a2005f,0x628101ec,0x6831038c,0xe2a3020b}},	//   _čovi, _phlo, _rådh, _giữ_,
   {{0x2c5601d3,0xddda02c6,0xaad350d7,0x7a30ac6a}},	//   rādi_, potř, _तिनक, _päti,
   {{0x628f0451,0x63bb1cab,0x2c5600e8,0x00000000}},	//   _ècom, _teun, sādi_, --,
   {{0x6f090149,0x3ead020b,0x00000000,0x00000000}},	//   tvec, tpet_, --, --,
   {{0xef161ad1,0x69dc17ba,0xf1a70a54,0xed6302c6}},	//   змы_, ygre, _дрен, _mužů_,
   {{0xee390aec,0x6281ac6b,0x7a3001bf,0xfe42008f}},	//   сно_, _uhlo, _täti, еньо,
   {{0x29010169,0x69dc2452,0x00000000,0x00000000}},	//   _nsha_, vgre, --, --,
   {{0x3ead0d3e,0x32050146,0xaa7b00b6,0x6b810294}},	//   ppet_, _haly_, stýl, _ịgan,
   {{0x69dcac6c,0xc05200c1,0x207a0142,0x6d413e15}},	//   tgre, _אזא_, _פאנא, szla,
   {{0xc60a009f,0xddc105db,0x00000000,0x00000000}},	//   _होंठ_, bolš, --, --,
   {{0x61e101c2,0x3205ac6d,0x7d1c02c3,0x00000000}},	//   _mcll, _maly_, ärst, --,
   {{0x7a300149,0xb8f40640,0xfc3f0076,0xb9041cff}},	//   _nätv, _हट_, chí_, _नम_,
   {{0x29016e92,0x61f800a7,0xfc5700ca,0x00000000}},	// [c960] _esha_, yevl, _מבקש_, --,
   {{0xd6cf0604,0x00000000,0x00000000,0x00000000}},	//   اقل_, --, --, --,
   {{0x399b0105,0xb3a90702,0x999b00ca,0x7a2b00bc}},	//   _לייד, ğını, _לביט, _tütr,
   {{0xb3a908bb,0xdb160065,0x00000000,0x00000000}},	//   şını, _leyí, --, --,
   {{0x224c0167,0x320501ff,0x00000000,0x00000000}},	//   _pmdk_, _baly_, --, --,
   {{0xd5b22761,0xa2cd2c5f,0x68310f04,0x00000000}},	//   _سفر_, _सिर्, _rådi, --,
   {{0x490f2010,0x61f82eeb,0x764e02a4,0x463b006e}},	//   डियो_, revl, _imby, _פעלע,
   {{0x61f80106,0x8f46013d,0xf9930327,0x35e2074c}},	//   sevl, зход, ערה_, _पाड़,
   {{0xa3e50285,0xa3e1178c,0x00000000,0x00000000}},	//   _बॉट_, _दात_, --, --,
   {{0x2d9802ec,0x7bc00088,0x68380610,0x24840167}},	//   øre_, ðmun, _oído, _hhmm_,
   {{0xfc3f00e3,0xe0d20018,0x1ddd0592,0x00000000}},	//   thí_, _سزا_, _मारत, --,
   {{0x2fc00102,0x2c5601d3,0x628a49db,0x317b0142}},	//   _þig_, kādu_, lmfo, _פראמ,
   {{0x7afd0126,0x764e017a,0xaa7b0146,0x648300aa}},	//   uwst, _omby, stým, sõig,
   {{0x6f022b43,0x7de600d1,0x00000000,0x00000000}},	//   _isoc, _رستم, --, --,
   {{0x683800d2,0x00000000,0x00000000,0x00000000}},	//   _vídn, --, --, --,
   {{0xa2cd16e2,0x764e47fd,0x6e2a3155,0x940b1d72}},	//   _सिल्, _amby, _hofb, _सोंच_,
   {{0x387e00fd,0x7bcd01ff,0x00000000,0x00000000}},	// [c970] îtra_, _idau, --, --,
   {{0x2901023e,0x248400f9,0x6aadac6e,0x200600da}},	//   _tsha_, _ahmm_, _itaf, _laoi_,
   {{0xdb040088,0x2901ac6f,0xa8a400e5,0xa3e12172}},	//   _heið, _usha_, _пряк, _दाद_,
   {{0x44290682,0x628a0185,0x683800b6,0x200603dc}},	//   ða_, emfo, _jídl, _naoi_,
   {{0xfaff0314,0xfe780138,0x6aad02a1,0x15ab00e5}},	//   nwë_, klį_, _jtaf, _гъби_,
   {{0x24840167,0x6aad0239,0xd49b61f2,0xdb0401cd}},	//   _ehmm_, _mtaf, _гра_, _meið,
   {{0x6f02ac70,0xdb040102,0x20892a6e,0xadea02d5}},	//   _asoc, _leið, ойки_, _जॉइन_,
   {{0x7a3002e2,0x7bcd0172,0x6594002d,0x6aad06b0}},	//   _hätt, _ndau, _часу, _otaf,
   {{0x7a30007a,0x660724b5,0x6aad0dd5,0x2c210096}},	//   _kätt, _kajk, _ntaf, यानं_,
   {{0x7bcd0012,0xf1a7153d,0x7a30ac71,0x648300aa}},	//   _adau, _хран, _jätt, sõid,
   {{0x2006054f,0x660700e9,0x63a40088,0x6f028acf}},	//   _faoi_, _majk, þing, _esoc,
   {{0x7a300222,0x6607005f,0x6fd607aa,0xdb0401cd}},	//   _lätt, _lajk, rücü, _beið,
   {{0x8d770421,0x20240031,0x63a9417b,0x1c431c32}},	//   _کاشا, úsiť_, _mfen, тням,
   {{0x66072179,0x7a301531,0x68380072,0x00000000}},	//   _najk, _nätt, _pído, --,
   {{0x63a9ac72,0x6f0d73c9,0x6aad0415,0x26cf01f9}},	//   _ofen, _šach, _etaf, ágon_,
   {{0xf77218a9,0x2fdf0124,0x00000000,0x00000000}},	//   ناء_, ngug_, --, --,
   {{0x7a30070a,0x2fc0007a,0xb3a903e0,0xdeab03e3}},	// [c980] _bätt, _õige_, ğılı, _ƙiƙi,
   {{0x63a90032,0xaad3009d,0x66070dd9,0xb3a9020e}},	//   _afen, _तितक, _cajk, şılı,
   {{0x290400d9,0x248401b9,0xca3700d7,0x00000000}},	//   āmas_, _phmm_, _חניה_, --,
   {{0x25fa8dcf,0x66070634,0x3b120216,0x00000000}},	//   _उसकी_, _eajk, _kryq_, --,
   {{0x59d22cb6,0x7c3d023b,0x660774e8,0x82fa0d83}},	//   _तयार, ërri, _fajk, تراز_,
   {{0x27e0ac73,0x63a9ac74,0x2006ac75,0x68440032}},	//   lgin_, _efen, _saoi_, _fìdù,
   {{0x2c0e0067,0x63a93762,0x0ef80176,0x628aac76}},	//   ियां_, _ffen, ्ट्स_, rmfo,
   {{0x27e07698,0x6607ac77,0x161c009d,0x248400f9}},	//   ngin_, _zajk, नावर_, _uhmm_,
   {{0x644200e3,0x7a301d4b,0x6d550072,0x00000000}},	//   mhoi, _jäts, úzan, --,
   {{0x442658c3,0x6838025b,0xddc800a5,0xdb04003e}},	//   ljo_, _sídl, widł, _reið,
   {{0xb143002d,0x6aada6ec,0x4426887b,0x9f4f00b3}},	//   _инфл, _staf, ojo_, _bagó_,
   {{0x64420084,0x3cdf0034,0xbc4b004d,0x6f020076}},	//   nhoi, _कमरे_, ічне_, _tsoc,
   {{0xf0470177,0x44260161,0xa3e100c3,0x8ae40565}},	//   _تعلی, ijo_, _दास_, кірл,
   {{0xdb040088,0x27e00188,0x00000000,0x00000000}},	//   _veið, egin_, --, --,
   {{0x7a30070a,0xdb1d003e,0x8c670d5e,0x6d5c0037}},	//   _rätt, masí, _отид, úrad,
   {{0x7a3026af,0x27e0ac78,0x44260283,0x629d0036}},	//   _sätt, ggin_, jjo_, _èsog,
   {{0x44267eee,0x6aad0010,0x290c0149,0x660707c0}},	// [c990] djo_, _utaf, ådar_, _pajk,
   {{0xb3a903a3,0xdb06ac79,0x4426ac7a,0x00000000}},	//   ğımı, takö, ejo_, --,
   {{0xb3a9008e,0x63a9ac7b,0x7c2d0062,0x38c9015a}},	//   şımı, _pfen, _koar, _عادی_,
   {{0xa3fb0031,0xdb160154,0x7c2d01ff,0x44266e5d}},	//   ťaží_, _idyò, _joar, gjo_,
   {{0xe5c70c58,0x7c2d002d,0x66070d12,0x160a00a5}},	//   _осво, _moar, _tajk, _होकर_,
   {{0xdd860602,0x1308004d,0x4426346f,0xa3e100c3}},	//   _مو_, ьній_, ajo_, _दाव_,
   {{0x2eff1d49,0x4426033b,0x00000000,0x00000000}},	//   wwuf_, bjo_, --, --,
   {{0x6442ac7c,0xb91a0857,0x2c6401d4,0x2bdb009d}},	//   choi, _anyị_, kıda_, _भागा,
   {{0x443fac7d,0xe3740dd8,0x26c9016d,0x291e2caa}},	//   _ilu_, _алты, nsao_, ̣ta_,
   {{0x442d01aa,0x26c900de,0xdb1d0e2e,0x443f0372}},	//   _hoe_, isao_, gasí, _hlu_,
   {{0x442dac7e,0x7af6ac7f,0x443f1a47,0x7c2dac80}},	//   _koe_, _spyt, _klu_, _boar,
   {{0xb91a0134,0xcfe900cd,0x443f0113,0x442d00ca}},	//   _enyị_, _رفته_, _jlu_, _joe_,
   {{0x442dac81,0x7c2d00ae,0x3f9d0294,0x9f4f00ee}},	//   _moe_, _doar, _igwu_, _vagó_,
   {{0x442d0006,0x7a30ac82,0x443fac83,0x0f5600ca}},	//   _loe_, _räts, _llu_, _אינם_,
   {{0x7c2d0012,0x3da602ec,0x443fac84,0x27e0ac85}},	//   _foar, _якщо_, _olu_, tgin_,
   {{0x442d0a8d,0x02df0775,0x7b050084,0xdcf801d3}},	//   _noe_, _नमून, ättä, _uzvā,
   {{0x7bc62208,0x27e05fba,0x068601a0,0x4426033b}},	// [c9a0] maku, rgin_, еган, vjo_,
   {{0x7bc603b4,0x6b84ac86,0x7a300212,0x442d020b}},	//   laku, _izig, _väts, _aoe_,
   {{0x443fac87,0x644200e3,0x442d1d32,0x4426ac88}},	//   _blu_, thoi, _boe_, tjo_,
   {{0x44265789,0x3f9d0134,0x14d10635,0xab5b00bc}},	//   ujo_, _ngwu_, _हिरण, kaül,
   {{0x68e30222,0x442669e3,0x443fa71b,0x779409b4}},	//   _ändr, rjo_, _dlu_, _شیطا,
   {{0x443fac89,0x3f9d7cb8,0x64420673,0x7bc6ac8a}},	//   _elu_, _agwu_, shoi, haku,
   {{0x7bc67317,0x443f4c9d,0x64420037,0x96633a69}},	//   kaku, _flu_, phoi, _скре,
   {{0x38603374,0x68e301df,0x6b840129,0x2c640367}},	//   nnir_, _ånde, _ozig, yıda_,
   {{0x64406503,0x7bc6ac8b,0x09d80081,0x9c7d00e7}},	//   _ilmi, daku, দ্যা, stčk,
   {{0x7c2d07ba,0x443f00cc,0x3f9d06c0,0xead10139}},	//   _soar, _zlu_, _egwu_, _bẹnu_,
   {{0x7c2d00d3,0x38600088,0x7bc60350,0x6b84ac8c}},	//   _poar, knir_, faku, _azig,
   {{0x7bc62e60,0xead10065,0x09a90096,0x442d020b}},	//   gaku, _dẹnu_, कड्य, _xoe_,
   {{0x629aac8d,0x2aab2dfb,0x7c2d0956,0x3eaf0023}},	//   _kito, ятно_, _voar, _gtgt_,
   {{0x629aac8e,0x2c64008b,0xead10139,0x00000000}},	//   _jito, rıda_, _fẹnu_, --,
   {{0xa3e1034c,0x6b84a9eb,0x7bc64524,0x7c2dac8f}},	//   _दाल_, _ezig, baku, _toar,
   {{0x38600088,0x629aac90,0xc6a771af,0x7bc602a4}},	//   gnir_, _lito, ержи, caku,
   {{0x6443023b,0x7c3d0052,0x442dac91,0xe9f900fe}},	// [c9b0] ënim, ërru, _roe_, _cuả_,
   {{0x629aac92,0x6440ac93,0x443f2df3,0x442dac94}},	//   _nito, _almi, _slu_, _soe_,
   {{0x69c7ac95,0x442dac96,0x443fac97,0x26c9016d}},	//   maje, _poe_, _plu_, ssao_,
   {{0x69c7ac98,0x13a700bf,0x629a6bb4,0xe3b32ba0}},	//   laje, رنتی_, _aito, ارض_,
   {{0x629a1900,0x91e513f5,0x442d0231,0x260c1101}},	//   _bito, воле, _voe_, _डोकी_,
   {{0x69c7ac99,0x7bc61621,0x644080e0,0x442d0d4d}},	//   naje, zaku, _elmi, _woe_,
   {{0xa2cd0e52,0xfa1300c7,0x7bc6379b,0x443fac9a}},	//   _सिक्, _সকাল_, yaku, _tlu_,
   {{0x62880084,0x443fac9b,0x6458020d,0x6440009c}},	//   _ehdo, _ulu_, évit, _glmi,
   {{0x629aac9c,0x60061119,0x69c7067d,0x9e650b0a}},	//   _fito, тным_, kaje, квид,
   {{0x7bc69c74,0x629a9d72,0x69c7ac9d,0x7a300212}},	//   waku, _gito, jaje, _nätp,
   {{0x69c7ac9e,0x7bc63589,0x0d822983,0x6b840018}},	//   daje, taku, ильн, _szig,
   {{0x3f9d00ac,0x629aa60f,0x7d1c34cb,0x00000000}},	//   _ugwu_, _zito, årsa, --,
   {{0xde053084,0x38600154,0xdee522de,0x6724003d}},	//   _апли, vnir_, _роли, xxij,
   {{0xc3320054,0x7bc6ac9f,0x69c7aca0,0xada20b21}},	//   סום_, saku, gaje, _кашл,
   {{0x7bc68ed7,0x386001cd,0x929d007f,0xab5b00b3}},	//   paku, tnir_, _osło, naüj,
   {{0x200daca1,0x64430138,0x386001cd,0x6b8433c4}},	//   ndei_, ūnij, unir_, _tzig,
   {{0x38600102,0xe9f900ef,0xe5a62249,0xa2cd16f8}},	// [c9c0] rnir_, _quả_, визи, _सिग्,
   {{0x69c704a3,0x6838001f,0x386001cd,0x00000000}},	//   caje, _mídi, snir_, --,
   {{0x69d90130,0x629aaca2,0x6838aca3,0xdb1d0437}},	//   _אַרו, _rito, _lídi, masá,
   {{0x629aaca4,0x7794110a,0x6aa4aca5,0xdb1d182b}},	//   _sito, _میزا, _kuif, lasá,
   {{0x200d0dda,0x6aa400fd,0x2ba728fb,0x00000000}},	//   ddei_, _juif, कुटा, --,
   {{0x533341a4,0x95860db2,0x7bc400aa,0xdb1d4db1}},	//   решт, _алге, _leiu, nasá,
   {{0x257600cd,0x64580257,0x9c7d0335,0x2bb502d5}},	//   _شهرس, évis, luče, ंडमा,
   {{0x629aa5b9,0xdfd000e3,0x6d482347,0x69c7aca6}},	//   _wito, حية_, vzda, zaje,
   {{0x629aaca7,0x26c7005f,0x26170096,0x020637fa}},	//   _tito, ćnog_, नाची_, _изан,
   {{0x4375022c,0x629a0137,0x200d00ae,0x201d0178}},	//   _суст, _uito, adei_, _enwi_,
   {{0x69c70968,0x7bc4044c,0x6e3a0d87,0x27f202ac}},	//   vaje, _beiu, rktb, kfyn_,
   {{0xa3ea007d,0x6fa60096,0x26cf0103,0x69c70239}},	//   _माफ_, _ऑलिं, ágok_, waje,
   {{0xa3ea17ff,0xfe460d86,0x63ad037a,0x629d014b}},	//   _मान_, _индо, ñani, _ésot,
   {{0xaa64349e,0x6aa4aca8,0x00000000,0x00000000}},	//   атск, _duif, --, --,
   {{0x69c7792c,0x27f20150,0x3c5900d3,0x2c4f007f}},	//   raje, ffyn_, _пикэ_, zędy_,
   {{0x6ebf8380,0x69c7aca9,0xb8fb030b,0x63a00167}},	//   लीवु, saje, _डट_, _ngmn,
   {{0x81cd00c7,0x09d80081,0xc6a40058,0x6aa40428}},	// [c9d0] ষ্ট_, দ্ধা, архи, _guif,
   {{0x7c3d2295,0x7aed4ef6,0x657c030a,0xcb12021e}},	//   lksr, _iqat, _byrh, _פלי_,
   {{0x657c00f0,0x98aa00c6,0x978300d1,0x00000000}},	//   _cyrh, tybą_, _چیزه, --,
   {{0xccf30130,0x7a2b01bf,0xf34e0134,0x8d5b00ca}},	//   יכע_, _nütz, rụnụ_, וכבי,
   {{0x69c5005a,0x62358665,0x64580428,0x05230033}},	//   _kehe, леду, èvia, পনের_,
   {{0x683825b0,0x01650a52,0x657c5126,0x7aed02a1}},	//   _rídi, лкло, _fyrh, _mqat,
   {{0x69c5acaa,0x63a49f7f,0x320c0f0e,0x3f860154}},	//   _mehe, žina, _dady_, _azou_,
   {{0x69c5acab,0xead10649,0xa2db009f,0xa3ea1fbb}},	//   _lehe, _pẹlu_, _निप्, _माय_,
   {{0x200dacac,0xe8e10023,0x7aed00bd,0x6da50fe3}},	//   rdei_, _ướp_, _nqat, липа,
   {{0x41c73613,0x69c5acad,0x200dacae,0x7c3d029a}},	//   _रजिस, _nehe, sdei_, eksr,
   {{0x25eb007d,0x6ed8048a,0xdb1d0103,0x290f05aa}},	//   _चानी_, _मिथु, vasá, _ņgan_,
   {{0xdb040072,0x9f050018,0x00000000,0x00000000}},	//   _afiá, _موصو, --, --,
   {{0xa3e10aa6,0x69c5202c,0x628f0451,0xa2db06eb}},	//   _दाई_, _behe, _ècos, _निफ्,
   {{0x9c7d005f,0xa2db0c9c,0xdea1001c,0xfce51262}},	//   vuče, _निन्, _پیگی, _боко,
   {{0x69c54219,0xd9431d0b,0xa2ca0d77,0x7aed039f}},	//   _dehe, бери, _सौन्, _eqat,
   {{0x2b5500cd,0x69c51ef8,0x9c7d0335,0x649300bd}},	//   ایید_, _eehe, tuče, _għix,
   {{0x6459acaf,0x69c5acb0,0x27f2acb1,0xb8eb1203}},	// [c9e0] diwi, _fehe, rfyn_, _रौ_,
   {{0x69c5a8ab,0x9c7d01d9,0x1a06064f,0x3dd50033}},	//   _gehe, ruče, _спом, ত্রল,
   {{0x320c1fe8,0xa2c100a8,0x00000000,0x00000000}},	//   _rady_, रीस्, --, --,
   {{0x320c025b,0xf7460db2,0xf34e0174,0xda2200bc}},	//   _sady_, _бемо, bụlụ_, मावत_,
   {{0x4caa00c7,0x69c57cf1,0x7054001c,0x320c21cb}},	//   _কিছু, _yehe, ینتا, _pady_,
   {{0x35a3acb2,0x69c501e9,0x2d870095,0xe5a30036}},	//   _гарг, _xehe, _ozne_, _гири,
   {{0x320c0094,0x69c1003e,0x00000000,0x00000000}},	//   _vady_, ðlei, --, --,
   {{0x04430b73,0x660e0188,0xaa7b003e,0x320c007f}},	//   _лесн, _habk, ntýr, _wady_,
   {{0x320c030b,0x627b0034,0x44ee1054,0x00000000}},	//   _tady_, _słoń, lý_, --,
   {{0x1ef70080,0x9e061c16,0x660e008c,0x98ac02c6}},	//   اعية_, учил, _jabk, ádě_,
   {{0x44ee0618,0x69c5658a,0x2d983a94,0x9c7d08c5}},	//   ný_, _rehe, äre_, jučc,
   {{0x69c5acb3,0xa2db15e4,0x660eacb4,0x628f0036}},	//   _sehe, _निम्, _labk, _ècor,
   {{0x44ee0244,0xe45700c1,0x98aa013f,0x78a500e7}},	//   hý_, ריכט_, mybę_, _suhv,
   {{0xdd9400c6,0x8504030b,0x44ee1515,0x84f600b6}},	//   _калы, रबाट_, ký_, ीबाट_,
   {{0x61f5026a,0x69c50103,0x19958b6f,0x2bb50285}},	//   _özle, _vehe, равя, ंडदा,
   {{0x57b52ac1,0x44ee0146,0x36d50084,0x69c50bb1}},	//   рбат, dý_, иобр, _wehe,
   {{0x69c5acb5,0x660e5874,0xf9d500ae,0x00000000}},	// [c9f0] _tehe, _babk, _копэ, --,
   {{0x443d0194,0x81c201d3,0x4e1a00b6,0x660e041c}},	//   wkw_, šēja, बाटै_, _cabk,
   {{0x6459acb6,0x660e0188,0xc668001f,0x98aa00c6}},	//   tiwi, _dabk, уште_, kybę_,
   {{0xf34e0134,0x00000000,0x00000000,0x00000000}},	//   pụlụ_, --, --, --,
   {{0x660e022e,0x6459acb7,0x27eb0027,0x3ea60227}},	//   _fabk, riwi, _iccn_, _nuot_,
   {{0x6459acb8,0xa2c1000d,0xe80d030b,0x44ee0146}},	//   siwi, रीष्, ाएका_, bý_,
   {{0x90c2364a,0xdb0d002b,0x00000000,0x00000000}},	//   обще, _meañ, --, --,
   {{0x44d108a1,0x3ea60270,0xc0a80604,0x98aa00c6}},	//   mą_, _buot_, داول_, gybę_,
   {{0x41e70e5a,0x44d140f0,0x53473967,0x249f0063}},	//   _مساف, lą_, _схва, _iium_,
   {{0xee3957ff,0xee3602fd,0xdb0d0072,0x704b0139}},	//   тно_, ины_, _neañ, _dájọ,
   {{0x44d1acb9,0x248d0531,0x611c00d3,0x2167013f}},	//   ną_, _khem_, _călă, _стаг,
   {{0x5c563edd,0xed56400f,0x00000000,0x00000000}},	//   ртоф, рою_, --, --,
   {{0x4c67020f,0xfaa60138,0x00000000,0x00000000}},	//   риян_, раго, --, --,
   {{0x44d101b3,0x200facba,0x7f8400e3,0x6f1903a8}},	//   ką_, _hagi_, _الهن, _irwc,
   {{0x44d15b46,0x5d790130,0x611c020a,0x200facbb}},	//   ją_, _באַק, _gălă, _kagi_,
   {{0x44ee0871,0x44d152ce,0x200f0113,0x68439678}},	//   vý_, dą_, _jagi_, онса,
   {{0xe73702fd,0x2ca72e6e,0x237f006c,0x66e61f47}},	// [ca00] ает_, _hund_, _nyuj_, роза,
   {{0x200f10e3,0x44ee0074,0x248d00f9,0x2ca73b9b}},	//   _lagi_, tý_, _ahem_, _kund_,
   {{0x9c7d0039,0x44d113ff,0x89db00a1,0x4ca70033}},	//   luča, gą_, _בחיי, _কৌতু,
   {{0x44ee0871,0x2ca7074a,0x66e64e66,0x249f048e}},	//   rý_, _mund_, _кома, _cium_,
   {{0x63a43173,0xddc10087,0x291a2650,0x660e0d2a}},	//   žino, dolž, _hrpa_, _tabk,
   {{0xc8da009d,0x09d80081,0x3253004d,0x44d11c8a}},	//   _बटाट, দ্রা, овір, bą_,
   {{0x200f1268,0x3ea66a66,0xa3ea008f,0x44d10034}},	//   _bagi_, _suot_, _идва_, cą_,
   {{0x63ad0610,0x64a32ca3,0x768b0233,0x248d078e}},	//   ñant, _фата, rüye, _ghem_,
   {{0x9c7d0995,0x3ea6acbc,0x200f041c,0xb3a9026a}},	//   juča, _quot_, _dagi_, ğıtı,
   {{0x68fe02ec,0x9c7d08a9,0x2ca7acbd,0xa2db0085}},	//   _oppd, duča, _bund_, _नित्,
   {{0x2c720094,0x200facbe,0x2ca001ee,0x00000000}},	//   lády_, _fagi_, _biid_, --,
   {{0x200f7b2f,0x2ca0008c,0x3ea6acbf,0x00000000}},	//   _gagi_, _ciid_, _tuot_, --,
   {{0xab870f1e,0xba770037,0x44d16392,0xbf161ac9}},	//   рунк, لاست, zą_, _خوشب,
   {{0x2004acc0,0x6483007a,0x291a0085,0x200f0d2a}},	//   lemi_, võim, _brpa_, _zagi_,
   {{0x6cd409e5,0x22890181,0xdd8f1f11,0x2ca70154}},	//   _اقبا, núka_, _قوه_, _gund_,
   {{0x2004acc1,0x9c7d2f54,0x44d10138,0xdff80b7f}},	//   nemi_, buča, vą_, ्जिद_,
   {{0x44d100a5,0xcf9300c1,0xc60b0033,0x7b1900ae}},	// [ca10] wą_, ַטע_, রাসা_, _сопр_,
   {{0x44d116df,0x2004acc2,0xd9ee00aa,0x225c05db}},	//   tą_, hemi_, _जायत_, jivk_,
   {{0x2004acc3,0x248d0197,0xd0410092,0xe7ef0469}},	//   kemi_, _phem_, _evlə, _छापा_,
   {{0x44d116e0,0xdcef08a9,0x2004969c,0xa2db077d}},	//   rą_, žeći, jemi_, _निद्,
   {{0x77640465,0x44d140f0,0x2ee42461,0x2c720146}},	//   _държ, są_, jumf_, gády_,
   {{0x27e9acc4,0x21693967,0x44d140f0,0xe81b034c}},	//   lgan_, лили_, pą_, _पोता_,
   {{0x200f06ee,0x248dacc5,0x660502e7,0xd49b44f3}},	//   _pagi_, _them_, mehk, _ара_,
   {{0x27e926f7,0x6605005a,0x2ca702e2,0x1be600aa}},	//   ngan_, lehk, _rund_, _काइल_,
   {{0x200facc6,0x2ca7254e,0x27e9acc7,0x2be1087c}},	//   _vagi_, _sund_, igan_, _काजू_,
   {{0x27e9009c,0x2ca725cc,0xf1f80e27,0x200facc8}},	//   hgan_, _pund_, _نعمت_, _wagi_,
   {{0x200facc9,0x63b80161,0x20040372,0x80270103}},	//   _tagi_, _àaná, bemi_, _پرام,
   {{0x69d70042,0x200400b6,0x68380146,0x644b020b}},	//   _adxe, cemi_, _lídr, nhgi,
   {{0x660500dc,0xee2e15d6,0xa3ea5c65,0x70740037}},	//   kehk, _ен_, _मास_, _بالذ,
   {{0x9c7d005f,0x291a015c,0x3dcc0124,0x2ca7acca}},	//   ruča, _prpa_, cadw_, _tund_,
   {{0xd9430cfc,0x6e23876e,0x9c7d0335,0xceb400a7}},	//   пери, _innb, mučn, _çər_,
   {{0x27e949ee,0x7bd600f9,0x00000000,0x00000000}},	//   ggan_, _udyu, --, --,
   {{0x7c249d7a,0x81df0033,0x2bb50442,0x644a0052}},	// [ca20] _inir, ধ্য_, ंडरा, ëfim,
   {{0xa3ea00a5,0x27e90013,0x7ae6134a,0x7c366b12}},	//   _माह_, agan_, mukt, _hoyr,
   {{0x68fe070a,0xeafa037f,0x7ae6accb,0x2004accc}},	//   _uppd, _شرکت_, lukt, yemi_,
   {{0x69ceaccd,0x2c21000f,0x03260c79,0xe7ef1b11}},	//   labe, याएं_, йден, _छाया_,
   {{0x06b20081,0x26cf0018,0x7ae656ae,0xa3b700aa}},	//   _চিকি, ágot_, nukt, छड़_,
   {{0xfe67054f,0x9c7d03f1,0x66051613,0x629d028d}},	//   _رد_, jučn, cehk, _èsol,
   {{0x7c242256,0x2004acce,0xb3a90740,0x64b700e7}},	//   _onir, temi_, ğırı, _aćif,
   {{0x6d5caccf,0x09e10081,0x62832652,0x69ceacd0}},	//   úram, ম্পা, alno, habe,
   {{0x69cea68c,0x2004acd1,0x26d2259e,0x442444a2}},	//   kabe, remi_, nsyo_, _inm_,
   {{0x2004acd2,0x7c24acd3,0x6442acd4,0x27e901d3}},	//   semi_, _anir, lkoi, zgan_,
   {{0x667b0130,0x78bc030b,0x69ceacd5,0x3b000085}},	//   רטיק, jprv, dabe, _apiq_,
   {{0xdee60318,0x9c7d0433,0x6442007b,0x44240154}},	//   _годи, krče, nkoi, _jnm_,
   {{0x9c7d01d9,0xf1ac1bc3,0x7c2401ff,0xaa7b0031}},	//   bučn, _चलान, _dnir, jrýc,
   {{0x7c24acd6,0x69ceacd7,0xa2db261e,0x61ea1b87}},	//   _enir, gabe, _निस्, ngfl,
   {{0x27e900f0,0x644200c2,0x00000000,0x00000000}},	//   tgan_, kkoi, --, --,
   {{0x63a41197,0x25eb007a,0x38ae003e,0x6b820174}},	//   žinj, _चाही_, _dýr_, ịgas,
   {{0x69ceacd8,0x27e904af,0x9c7d0094,0x96351543}},	// [ca30] babe, rgan_, lučo, онац,
   {{0x69ce0328,0x7bcf1a47,0x6b8d12e1,0x27e9acd9}},	//   cabe, lacu, _izag, sgan_,
   {{0x4424acda,0x66052b29,0x6f09042c,0x7bcf037a}},	//   _bnm_, rehk, zwec, oacu,
   {{0x26cf0018,0x7bcfacdb,0xdd7b0266,0x6e2401c2}},	//   ágos_, nacu, נטאל, _ɗiba,
   {{0x38695bd1,0xa3ea2ebd,0x23290a54,0x00000000}},	//   mnar_, _मार_, роли_, --,
   {{0xe299176e,0x41e700d6,0x7bcfacdc,0x7a300364}},	//   шал_, сіда, hacu, _sätz,
   {{0x6443acdd,0xa2db00a4,0x7bcf05bd,0x00000000}},	//   ënis, _निव्, kacu, --,
   {{0x69ceacde,0x386923ff,0x7ae60124,0x7bcfacdf}},	//   zabe, nnar_, yukt, jacu,
   {{0x3869ace0,0x09e10081,0x69ce348b,0xdb1d0103}},	//   inar_, ম্যা, yabe, bbsé,
   {{0xc0cb40e1,0x3f8300d9,0x6f090364,0x2fcd00aa}},	//   _буде_, āju_, rwec, saeg_,
   {{0x6449533b,0x9c7d0d95,0x3869487c,0x3207ace1}},	//   _klei, ručn, knar_, meny_,
   {{0x69ce5502,0x32073236,0x7ae60a69,0x6b8d0027}},	//   wabe, leny_, tukt, _bzag,
   {{0x69ceace2,0xe04202ec,0x29010372,0x3869ace3}},	//   tabe, _інши, _apha_, dnar_,
   {{0x64493eb8,0x539a0327,0x98a6121c,0x2caa0037}},	//   _llei, יירו, живе, úidí_,
   {{0x69ceace4,0x6449ace5,0x6b8d02a7,0x3ce00034}},	//   rabe, _olei, _ezag, _किये_,
   {{0x69ceace6,0x3869753f,0x7c24996f,0x1ae600ae}},	//   sabe, gnar_, _unir, _доим,
   {{0xa2db077d,0x69ceace7,0x63a40138,0x29014063}},	// [ca40] _निष्, pabe, žink, _epha_,
   {{0x4424008a,0x09e10081,0x645b0037,0xf65f3229}},	//   _snm_, ম্বা, _amui, _svær_,
   {{0x6449ace8,0x4424005c,0x850600cd,0x25eb17e5}},	//   _blei, _pnm_, توان, _चारी_,
   {{0x9c83135f,0x64492f3f,0x4424028d,0x26d20270}},	//   _účto, _clei, _qnm_, psyo_,
   {{0x644202fd,0x442436da,0x3860008c,0xf9ab0154}},	//   rkoi, _vnm_, miir_, _àèò_,
   {{0xa2db06e4,0x6449ace9,0x6442acea,0x6b8405bd}},	//   _निर्, _elei, skoi, _myig,
   {{0x64490c09,0xf65f0088,0x7bcf04ff,0xf4840d83}},	//   _flei, _tvær_, yacu, _فاری,
   {{0x09b70a30,0x6449aceb,0x75210072,0x30770037}},	//   _अभ्य, _glei, _álza, يحية_,
   {{0x32070a7f,0x6b840c50,0xa3e70285,0x63ad0433}},	//   beny_, _nyig, पलर_, žanc,
   {{0xa3ea000f,0x386d042d,0x248600f3,0x32070891}},	//   _माँ_, čeri_, llom_, ceny_,
   {{0x644902fd,0x7bcf2f05,0x386907e7,0x6b8453dd}},	//   _ylei, tacu, ynar_, _ayig,
   {{0x9c7d0146,0x6b8402a4,0xe1650d5b,0xbbb518ff}},	//   ručo, _byig, _عدلي, ंडेक,
   {{0x25eb04a9,0x7e7a0106,0x24860220,0x386900f3}},	//   _चाली_, potp, ilom_, vnar_,
   {{0x6f022f48,0x7bcf034f,0xda7b1440,0x6abd2fa7}},	//   _ipoc, sacu, рям_, rpsf,
   {{0xa3ea00a5,0x2486042d,0x386925be,0x7bcf37f0}},	//   _मां_, klom_, tnar_, pacu,
   {{0x765c02ad,0x6f020294,0x3207033d,0x24860095}},	//   _amry, _kpoc, zeny_, jlom_,
   {{0x3869acec,0x24860220,0xf7732729,0x6b8d05bd}},	// [ca50] rnar_, dlom_, ذار_, _uzag,
   {{0xe81b007d,0xf1bf0019,0x38690795,0x2486305d}},	//   _पोरा_, _đáo_, snar_, elom_,
   {{0x6449aced,0xd49b0a7c,0x38692708,0x7bcd0167}},	//   _plei, ард_, pnar_, _keau,
   {{0x248608a9,0x3cfb00c1,0x44270037,0x6e3800f2}},	//   glom_, שלאנ, غراف, _lovb,
   {{0x64490185,0x069b00cd,0x3207acee,0x7bcd014b}},	//   _vlei, _نخست_, teny_, _meau,
   {{0x6aadacef,0x644900f0,0xe601007b,0x68310170}},	//   _muaf, _wlei, ävää, _rådy,
   {{0x3f8900e7,0x768b026a,0x66150634,0x3207acf0}},	//   _šau_, lüyo, _iazk, reny_,
   {{0x3207acf1,0x644900d3,0xe45facf2,0x661501e9}},	//   seny_, _ulei, _öö_, _hazk,
   {{0x63a9acf3,0x768b01e8,0x6615013f,0x9c7d0335}},	//   _igen, nüyo, _kazk, ručl,
   {{0x5bb61efb,0xfe710037,0x6615033b,0x6b8405bd}},	//   ूर्व, عدة_, _jazk, _ryig,
   {{0x7bcd0e6c,0x6615acf4,0x3eb900d9,0x63a90154}},	//   _beau, _mazk, ūst_, _kgen,
   {{0x801400d6,0x7bcd00d3,0x661569cb,0x768b0233}},	//   _офіц, _ceau, _lazk, küyo,
   {{0x7ff409b4,0x63a90051,0x7d1a023e,0x7bcdacf5}},	//   _آسما, _mgen, avts, _deau,
   {{0x3ebf0991,0xdb0f0080,0x25fd045f,0x66150634}},	//   mput_, ódái, र्मी_, _nazk,
   {{0x929d0067,0x660a0253,0x63a9acf6,0x8c4600ae}},	//   _usłu, _ölkə, _ogen, _неке,
   {{0x63a92713,0x63a43173,0x6aad010b,0x7bcd029a}},	//   _ngen, žini, _fuaf, _geau,
   {{0x6d410798,0x628108a9,0x3ebf0106,0x3860008a}},	// [ca60] lyla, _oklo, nput_, riir_,
   {{0x38600188,0xa59600c2,0x7e610072,0x9c7d0117}},	//   siir_, прещ, nilp, jučj,
   {{0x2c21009d,0xe9f900de,0x6d41acf7,0x0f0802d5}},	//   याचं_, _huế_, nyla, _वन्स_,
   {{0x3a3a3135,0x63a90072,0x62818076,0x6d5c0076}},	//   _hopp_, _cgen, _aklo, úrai,
   {{0x3ebf0095,0x937a1a37,0x3a3a186a,0x7e613851}},	//   jput_, حصار_, _kopp_, kilp,
   {{0x26c0acf8,0x63a940d6,0x2486161f,0x80d00081}},	//   mpio_, _egen, slom_, সংস্,
   {{0x2bed009d,0xf62311c0,0x40341612,0x6f02acee}},	//   _झालं_, _ядро, дейс, _spoc,
   {{0x6d41acf9,0x3a3a0212,0x63a9010a,0x00000000}},	//   dyla, _lopp_, _ggen, --,
   {{0x1be617ff,0x7bcd078e,0x3a3a00d8,0x00000000}},	//   _काजल_, _reau, _oopp_, --,
   {{0x932500bf,0x7bcdacfa,0x00000000,0x00000000}},	//   _ترفن, _seau, --, --,
   {{0xa3e002d5,0xc04f02ec,0x41bb00a1,0x44d80f0e}},	//   _दया_, _зі_, _הצבע, nč_,
   {{0xf044015a,0xddc801f9,0x64ac173c,0x00000000}},	//   _تعطی, ridő, _işid, --,
   {{0xa3ea0006,0x9c7d26dd,0x7e610083,0x7bcd014b}},	//   _माई_, lučk, bilp, _veau,
   {{0x8f9b00ca,0x7ae001f9,0xa2c10285,0x00000000}},	//   _הידי, ámta, रीट्, --,
   {{0x661502dd,0x26c701ac,0x6d41acfb,0x8ca6007f}},	//   _razk, ćnom_, cyla, _घंटो,
   {{0xb9050a30,0xf1bf0019,0xe8e000de,0x44f52ba4}},	//   _नि_, _đám_, _giọt_, vå_,
   {{0x2bc30b2b,0xb8f40e72,0x78a602ac,0x661501c8}},	// [ca70] _व्या, _सौ_, _dikv, _pazk,
   {{0x929d00a5,0x768b01e8,0x9f9d0161,0xddc800e7}},	//   _opła, rüyo, lção_, hodž,
   {{0x58d40084,0x9c7d15f4,0xddc800e7,0x6443016d}},	//   _поэт, jučk, kodž, ênio,
   {{0x9f9d00c9,0x27ed3229,0x9975007f,0x00000000}},	//   nção_, _øen_, _męża_, --,
   {{0x6615acfc,0x9f9d001f,0xddc80dd9,0x00000000}},	//   _tazk, ição_, dodž, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25fd009d,0x9c7d00cc,0x6281033b,0x569412d1}},	//   र्णी_, ručj, _vklo, _чарт,
   {{0x63a9acfd,0x78b80103,0xf994006e,0x1c1d007a}},	//   _ugen, _évve, ערק_, _बोलल_,
   {{0x7e6140b1,0x59bf167f,0x64ac00a7,0x00000000}},	//   tilp, ्रार, _eşid, --,
   {{0x628100e9,0x3ebfacfe,0x9f5d0139,0x9c7d0234}},	//   _uklo, rput_, _bawò_, vrča,
   {{0xac0a17e3,0x6f1b09ac,0x00000000,0x00000000}},	//   онна_, svuc, --, --,
   {{0x26c72c57,0x9c7d0106,0x7e613f9a,0x25fd277c}},	//   ćnoj_, trča, silp, र्ती_,
   {{0x6d41acff,0xa2c10096,0x78a614f3,0xe9f90023}},	//   syla, रीच्, _rikv, _quế_,
   {{0x9f9d0396,0xb69b020a,0x00000000,0x00000000}},	//   ação_, _spân, --, --,
   {{0xfaa3576e,0x3ea7039f,0xed5900d3,0xad250d5b}},	//   таро, _iint_, _фой_, _زرغو,
   {{0x9f9d001f,0xdb1d7c4d,0xe9f9020b,0x00000000}},	//   cção_, lasý, _tuế_, --,
   {{0x3a3a6aea,0x18670161,0xd7ef0037,0x3ea701f9}},	// [ca80] _topp_, фати_, شكل_, _kint_,
   {{0x2fcf00f3,0x26c0ad00,0xb9c60190,0xa5f70831}},	//   _legg_, rpio_, _تقدي, међу_,
   {{0x78a6005f,0x3ea750af,0x25fd063e,0xf8d2250d}},	//   _tikv, _mint_, र्धी_, _तबिय,
   {{0x26c030cf,0x3ea75aff,0x2d87057a,0x3ce00e4c}},	//   ppio_, _lint_, _myne_, _किसे_,
   {{0xd12f00cd,0x17c7004d,0x2d870313,0x648300aa}},	//   یمه_, _ігри_, _lyne_, võit,
   {{0x2d8b0d1b,0x9343013d,0xda0e5fbb,0x3f860167}},	//   ęcej_, ънче, ाजित_, _ryou_,
   {{0xaca40134,0xd5ad0068,0x2fcf009c,0xa6b00033}},	//   _afọi, _اہم_, _begg_, _ছবিট,
   {{0x8f462776,0x9c7d0995,0x3ea74f3f,0x3f1423b8}},	//   дход, ručk, _aint_, едис,
   {{0x3ea7ad01,0x69de033b,0xda0e0096,0x929d0034}},	//   _bint_, _odpe, ाजात_, _wpła,
   {{0x3eb91f84,0x648300bc,0x9f5d0154,0x9c7dad02}},	//   ísta_, sõit, _pawò_, muči,
   {{0x9c7d02e6,0x24840063,0x3ea7078e,0x00000000}},	//   luči, _kkmm_, _dint_, --,
   {{0x628a727a,0xdb210094,0xccf802c6,0x3eaf0537}},	//   llfo, štíh, rtě_, _fugt_,
   {{0x3ea70501,0xccf8000d,0x9f9d001f,0x9c7d013f}},	//   _fint_, stě_, rção_, nuči,
   {{0x69a000a4,0x7d1c2ca7,0x00000000,0x00000000}},	//   _गृही, årss, --, --,
   {{0x9f9d001f,0xd83f0220,0x2905014b,0x00000000}},	//   pção_, áčov_, ïla_, --,
   {{0xa3ea030b,0xdb2500ae,0x9c7dad03,0x764e0178}},	//   _माग_, ăpân, kuči, _alby,
   {{0x81e60081,0x672900e7,0x36d40d86,0xa03b006e}},	// [ca90] য্য_, _šejb, котр, קעמפ,
   {{0x2ca900da,0x9c7d004b,0xa5670452,0x00000000}},	//   _hiad_, duči, ودان, --,
   {{0xdcf80029,0x69d5ad04,0x69c7023b,0x67d51fdb}},	//   _izvē, maze, mbje, _пону,
   {{0x4429abc8,0x25eb007d,0x33755ac0,0x6483007a}},	//   ña_, _चाकी_, нгер, võis,
   {{0x38b50501,0xba7400cd,0x69c73733,0x93272ce3}},	//   _hår_, _سایت, obje, بران,
   {{0x7bdf0ca4,0x02e02171,0x69d535c3,0x611300a7}},	//   _ldqu, _निरभ, naze, _hələ,
   {{0x3ea7009c,0xa2db11c6,0xd1312eb5,0x7d1c003e}},	//   _rint_, _निक्, امع_, ærsl,
   {{0x3ea7ad05,0x2ca9023e,0x6594349e,0x38b50149}},	//   _sint_, _niad_, _расу, _mår_,
   {{0x69d50201,0xdb16003e,0x63bbad06,0x38b50b97}},	//   kaze, _neyð, _ifun, _lår_,
   {{0x69d5ad07,0xd9ee007a,0x77eb0179,0x69c70537}},	//   jaze, _जाइत_, टलुक_, jbje,
   {{0x38b50170,0x63a4013f,0x3ea76ab6,0x7690007b}},	//   _når_, žint, _vint_, käyn,
   {{0x3ea70126,0x2ca90441,0x6e2a0154,0x611300a7}},	//   _wint_, _ciad_, _enfb, _nələ,
   {{0x63bb781f,0x69d56072,0xe7e333dc,0x2d87ad08}},	//   _mfun, faze, गणना_, _wyne_,
   {{0x69d591c5,0xdb1601ab,0x200d01e9,0xaa7b0094}},	//   gaze, _deyð, leei_, brým,
   {{0x9c830087,0x63bb0502,0x611300a7,0x00000000}},	//   ščaj, _ofun, _bələ, --,
   {{0x160209c4,0x25fd1e93,0x63bbad09,0x22a60139}},	//   र्नर_, र्सी_, _nfun, _kíkì_,
   {{0xc0520341,0x69da3536,0x69d5019f,0xe3e50033}},	// [caa0] אזן_, ótes, baze, নভাব,
   {{0x38b534cb,0xe617ad0a,0x63bb6ccb,0xd91009e5}},	//   _får_, нду_, _afun, _پیر_,
   {{0x38b534cb,0x0446ad0b,0x24840063,0x1ab80033}},	//   _går_, нежн, _pkmm_, _জিয়া,
   {{0x611301d4,0x2937006e,0x2ba700c3,0x00000000}},	//   _gələ, _נאכן_, _गणमा, --,
   {{0xbb3b00c1,0x200d01e9,0x985500ae,0x338300e5}},	//   ּעצי, deei_, _ртэш, лушв,
   {{0x63bb4944,0xb4250281,0x3ce0007f,0x00000000}},	//   _efun, _یعقو, _किले_, --,
   {{0xa5072fec,0x63bb37d7,0x386200bc,0x00000000}},	//   _пера_, _ffun, _kmkr_, --,
   {{0x69c726dd,0xdfd000e3,0x64a340e4,0x6491004d}},	//   zbje, جية_, _баса, låin,
   {{0x64ac0b88,0x25fdad0c,0x7bdf01b9,0x2ca926ed}},	//   _eğit, र्वी_, _rdqu, _riad_,
   {{0x2ca90080,0x28e12f8f,0x63a4ad0d,0xf1c30031}},	//   _siad_, _फिलि, žins, čší_,
   {{0x8277006e,0x9e03004b,0xdb1601cd,0x4d98004d}},	//   _טעמע_, учыл, _seyð, ькою_,
   {{0xf1bf0023,0x38b50b85,0x00000000,0x00000000}},	//   _đái_, _rår_, --, --,
   {{0x38b50073,0xdb1d0103,0x6254009c,0x3d28010d}},	//   _sår_, vasó, _càog, ستگی_,
   {{0x63ad0fb6,0x16020557,0x629d0036,0x6d5c0042}},	//   ñanz, र्मर_, _èsot, úras,
   {{0x69d5ad0e,0x67d52cbf,0x2db700a1,0xdb1d4232}},	//   raze, кову, _אלון_, tasó,
   {{0x38b50d40,0x27470649,0x61130092,0x69d5ad0f}},	//   _vår_, _nínú_, _qələ, saze,
   {{0x8aa7036a,0x160206ed,0xdb1d0037,0x69d50161}},	// [cab0] _прод, र्भर_, rasó, paze,
   {{0x3b0901af,0xb71400c2,0x38b529fb,0x2b53028e}},	//   _ipaq_, ыдущ, _tår_, ıncı_,
   {{0x611301d4,0x63bb2359,0x7c2dad10,0x27470af0}},	//   _tələ, _pfun, _knar, _bínú_,
   {{0x7afd0934,0x7af200b6,0x9fb500b6,0x7c3f0090}},	//   otst, šetř, třík_, _joqr,
   {{0x7c2d0239,0x14741454,0x7c3f00bd,0x7aef0233}},	//   _mnar, دالج, _moqr, nuct,
   {{0xdd861e49,0x68e313b9,0x98be0138,0x25fd09c4}},	//   _نو_, _ånds, štą_, र्शी_,
   {{0x9c7d042d,0x7c2dad11,0x65940cc6,0x5505009f}},	//   luču, _onar, _бару, _रहिए_,
   {{0x63bb4958,0x7c2d0174,0x7afd0a1f,0x25fd0285}},	//   _ufun, _nnar, ktst, र्री_,
   {{0x442dad12,0xe803009d,0x200d20a3,0x1e950dfb}},	//   _ine_, ऱ्या_, reei_, крор,
   {{0x7aefad13,0x443f5268,0x7afd0709,0x200d01ff}},	//   duct, _hou_, dtst, seei_,
   {{0x443f0c56,0x2bc302e8,0x7afd01d0,0x442dad14}},	//   _kou_, _व्हा, etst, _kne_,
   {{0x443fad15,0x442dad16,0x7afd7761,0x7c2d009c}},	//   _jou_, _jne_, ftst, _cnar,
   {{0x443fad17,0x7afd0ac1,0x442d025b,0xa3ea2f74}},	//   _mou_, gtst, _mne_, _माघ_,
   {{0x443f2f1b,0x62838389,0xdee2268e,0x00000000}},	//   _lou_, nono, _тоши, --,
   {{0x442dad18,0x7afd2ba3,0x7c3f009e,0x62830231}},	//   _one_, atst, _foqr, iono,
   {{0x443fad19,0x442dad1a,0xb3a90491,0x6283ad1b}},	//   _nou_, _nne_, şıyı, hono,
   {{0x98a3062a,0xa686121c,0x7afd0381,0x9c7d00c4}},	// [cac0] рите, влад, ctst, guču,
   {{0x442dad1c,0x6283ad1d,0xfaa62863,0x443fad1e}},	//   _ane_, jono, _шапо, _aou_,
   {{0x443fad1f,0x64a60426,0x00000000,0x00000000}},	//   _bou_, важа, --, --,
   {{0xb60900d9,0x3d1900a5,0x443fad20,0x78be0294}},	//   _atšķ, _बनने_, _cou_, _ọkwọ_,
   {{0x442d1770,0xd36f00e3,0x443fad21,0x60c1010a}},	//   _dne_, يهم_, _dou_, _atlm,
   {{0xf506062a,0xfe671ea6,0x26c24072,0x00000000}},	//   _изго, _ضد_, _itko_, --,
   {{0x443fad22,0xd46a0b7b,0xd1300037,0x320e007f}},	//   _fou_, _живе_, صمة_, refy_,
   {{0x661c59ce,0x44fcad23,0x443fad24,0x442d01ec}},	//   _hark, mí_, _gou_, _gne_,
   {{0x661cad25,0x44fcad26,0x62834031,0x7afd0212}},	//   _kark, lí_, bono, xtst,
   {{0x443f0505,0x7c2d0b97,0x6283ad27,0xd9ee007d}},	//   _zou_, _snar, cono, _जागत_,
   {{0x661c8150,0x6440ad28,0x443f1723,0x44fc582f}},	//   _mark, _komi, _you_, ní_,
   {{0x7afd02ec,0x98aa013f,0x443f00ee,0x6440ad29}},	//   ttst, mybė_, _xou_, _jomi,
   {{0xee3a0036,0x44fc0031,0x7b64001f,0x7afd32c5}},	//   _онд_, hí_, атре, utst,
   {{0x6440ad2a,0x7afd091f,0x7aef6f73,0x09bf0f8f}},	//   _lomi, rtst, ruct, ्रेय,
   {{0x44fc000d,0x7aef1081,0x7afd612e,0x26c2ad2b}},	//   jí_, suct, stst, _atko_,
   {{0x44fc2b64,0x6440ad2c,0x7c2dad2d,0x7afd0364}},	//   dí_, _nomi, _unar, ptst,
   {{0x661c0652,0x443fad2e,0x63ad2102,0x6283ad2f}},	// [cad0] _bark, _rou_, žank, yono,
   {{0x443fad30,0x9c7dad31,0x6b8d0694,0x62833521}},	//   _sou_, ruču, _iyag, xono,
   {{0x443f346e,0x442d01b9,0x44fc3a31,0x661c0bb0}},	//   _pou_, _pne_, gí_, _dark,
   {{0x62839c09,0x6b8d083e,0x661c01ff,0x9c7d0117}},	//   wono, _kyag, _eark, drčk,
   {{0x661cad32,0x443fad33,0xfaff00dd,0x644000db}},	//   _fark, _vou_, ntë_, _domi,
   {{0x443fad34,0x3869a700,0x661cad35,0x44fcad36}},	//   _wou_, liar_, _gark, bí_,
   {{0xfaff0910,0x443f14b1,0x44fcad37,0x64ac008e}},	//   htë_, _tou_, cí_, _işin,
   {{0x442dad38,0x6440ad39,0xef19115a,0x6d484a7f}},	//   _une_, _gomi, еми_, dyda,
   {{0x6283ad3a,0xfaff00dd,0x6b8d35f2,0x6d5a8361}},	//   pono, jtë_, _nyag, ezta,
   {{0xc0cb00d3,0x64400206,0x26063613,0x91ca007f}},	//   _жуде_, _zomi, स्पी_, _स्पै,
   {{0x6b8d742b,0x644088ec,0x3869ad3b,0x00000000}},	//   _ayag, _yomi, kiar_, --,
   {{0xfaff00dd,0x6b8d01e2,0x80d00033,0x7d18078e}},	//   ftë_, _byag, সংখ্, _dsvs,
   {{0xdee522ee,0x44fc0363,0x6d5a0a00,0x3869ad3c}},	//   _соли, zí_, azta, diar_,
   {{0x6a860cfc,0x64b7007e,0x6b8d05aa,0x201d0066}},	//   улга, _aćim, _dyag, _hawi_,
   {{0x7c2f00e3,0x610a0092,0x201d3e5d,0x2d94008f}},	//   áirí, _gəld, _kawi_, _кръс,
   {{0x661cad3d,0x201d00bf,0x44fc0363,0x70d1030b}},	//   _sark, _jawi_, ví_, _सबैल,
   {{0x290501e8,0x201d5fb1,0x5baa00d6,0x9c7d0094}},	// [cae0] çlar_, _mawi_, _яким_, ručt,
   {{0x44fc0871,0x6440ad3e,0x661c9784,0x201d431b}},	//   tí_, _somi, _qark, _lawi_,
   {{0x661c3b19,0xd9460731,0x44fc3024,0x13ea0012}},	//   _vark, _сени, uí_, емей_,
   {{0x44fcad3f,0x629a00dd,0x661cad40,0x201d005c}},	//   rí_, _shto, _wark, _nawi_,
   {{0x661cad41,0x44fcad42,0x6d480034,0x81ab0033}},	//   _tark, sí_, zyda, কুম_,
   {{0x44fcad43,0x661c057c,0x98aa0138,0x5b7b006e}},	//   pí_, _uark, tybė_, ערסא,
   {{0x644002e6,0x6d560d2a,0x6d48020d,0x05272766}},	//   _tomi, _ƙyam, xyda, _йорк_,
   {{0x6440008f,0x6d481867,0x7690007b,0x7bd6063d}},	//   _uomi, vyda, käyk, _neyu,
   {{0x61f60037,0x6d4800f0,0xdb1d238c,0xd259022b}},	//   _مساء, wyda, lasö, _twņp_,
   {{0x386901e9,0x715a2135,0x6d48ad44,0x291aad45}},	//   ziar_, _прес_, tyda, _ospa_,
   {{0xdd94013f,0x5c7505cb,0x217635c1,0x127b006e}},	//   раны, илот, _суар, _טאמע,
   {{0x6d48ad46,0x201d12ff,0xc0ff00de,0xdd9701b6}},	//   ryda, _gawi_, _lướt_, ышы_,
   {{0x386940e2,0x6d5aad47,0x543b006e,0x6d483773}},	//   viar_, szta, געכא, syda,
   {{0xfaff01e5,0xc987282a,0x2486023e,0x67240880}},	//   rtë_, губи, hoom_, dvij,
   {{0xfaff00dd,0x672400d9,0xaa7b0146,0x201d019c}},	//   stë_, evij, krýv, _yawi_,
   {{0x6b8d0270,0x3d1958af,0xfaff0216,0x610a013c}},	//   _tyag, _बनते_, ptë_, _kəlb,
   {{0x386901ce,0xfaff023b,0x28e100bc,0xa8a40fe9}},	// [caf0] riar_, qtë_, _फिकि, ёрск,
   {{0x3869ad48,0xd01d0081,0x201f3397,0x7bd61b99}},	//   siar_, থায়_, zdui_, _zeyu,
   {{0x2cf20b2b,0x00000000,0x00000000,0x00000000}},	//   _अमोल_, --, --, --,
   {{0xe78728f1,0x69d7ad49,0x3eaead4a,0xc4352c31}},	//   _буго, _hexe, _lift_, جکست,
   {{0x201d0da3,0xb7da00a1,0x6724007e,0x00000000}},	//   _rawi_, _בקרי, cvij, --,
   {{0x201d0533,0x21690036,0x3abc021e,0x00000000}},	//   _sawi_, кили_, עמונ, --,
   {{0x2486ad4b,0x20551c4c,0x69d70161,0x201d00f9}},	//   boom_, итир, _mexe, _pawi_,
   {{0x9c7d02ef,0xdb1d00aa,0x7e78078e,0x00000000}},	//   brči, lasõ, _ajvp, --,
   {{0x7cc101d3,0x7bd6ad4c,0x00000000,0x00000000}},	//   _mēre, _reyu, --, --,
   {{0x399c0032,0x2eff0234,0x201d67e9,0x3eae1916}},	//   _jásí_, rtuf_, _wawi_, _cift_,
   {{0xa3e902d5,0xa11533ce,0x201dad4d,0x672902ef}},	//   _मया_, _خوات, _tawi_, _šejl,
   {{0x20d3020a,0x645a00c6,0x291a009c,0x26c91a3a}},	//   mţi_, _įtik, _rspa_, kpao_,
   {{0x308400e3,0x20d3002d,0xe8e000de,0x543a006e}},	//   _النف, lţi_, _kiệt_, דערא,
   {{0x2ba72ebd,0x6da50636,0x3eae4cda,0x20d3020a}},	//   _गणरा, _кила, _gift_, oţi_,
   {{0x20d3002d,0x290cad4e,0x69d7ad4f,0x6846008f}},	//   nţi_, ïda_, _dexe, анва,
   {{0x67240b4b,0x7ae90039,0xe8e00019,0x78af00e7}},	//   tvij, šeta, _liệt_, _cicv,
   {{0x16661111,0x291a016d,0x09e6235c,0x2486007e}},	// [cb00] авам, _wspa_, _копн, voom_,
   {{0x672401d3,0x9adb0266,0xd5eb0023,0xdb9b00ca}},	//   rvij, _שחיט, _địn, _בספר,
   {{0x6724053f,0x248618f0,0x321e0034,0x00000000}},	//   svij, toom_, _raty_, --,
   {{0x0326468d,0x321e0e43,0xe482071d,0x00000000}},	//   иден, _saty_, _öpüş, --,
   {{0xe8e00028,0x59da0cd5,0x69dc01e9,0x38bc0103}},	//   _biệt_, _बजार, oare, _hír_,
   {{0x69dcad50,0x2eed0150,0x24861c02,0x6ce50c22}},	//   nare, dref_, soom_, _किंग_,
   {{0xdb1f1f8d,0xe8e00019,0xddc80138,0x69dc3c3a}},	//   _seqü, _diệt_, sidū, iare,
   {{0x64591933,0x38bc6e81,0xf1060409,0x3fb40033}},	//   chwi, _mír_, _शहीद_, ঘর্ষ,
   {{0x20d3002d,0x25fd0976,0x610a0092,0x0dca73a0}},	//   aţi_, र्की_, _qəlb, куни_,
   {{0x38bcad51,0x62720034,0x98be00d2,0x00000000}},	//   _oír_, dłog, átě_, --,
   {{0x69d708a8,0x69dcad52,0x45b7006e,0x20d3020a}},	//   _rexe, dare, יפיל_, cţi_,
   {{0x98be000d,0x26060efd,0x4cb80081,0xaca70103}},	//   ště_, स्ती_, _আবদু, جھتے_,
   {{0x69dc032e,0x69d7ad53,0x38bc03a8,0x3eae0090}},	//   fare, _pexe, _aír_, _tift_,
   {{0x5ef3009d,0xdb1d0018,0x3b0000bd,0x6dc10174}},	//   ंढर्_, ncsé, _dqiq_, ịaru,
   {{0x69d708a8,0x7e7d034f,0x6e3c0149,0xa3e60096}},	//   _vexe, éspe, örbu, पणा_,
   {{0x0854004d,0x69d7008c,0x00000000,0x00000000}},	//   овсю, _wexe, --, --,
   {{0x7bdd7076,0x57a7008f,0x69d70fc0,0x00000000}},	// [cb10] masu, ршва, _texe, --,
   {{0x69dcad54,0xa3c90096,0x26c900c4,0x38bc033c}},	//   care, लुन_, rpao_, _fír_,
   {{0x25fd09c3,0x26c908a9,0x6459ad55,0xe4a71eb9}},	//   र्गी_, spao_, thwi, ардо,
   {{0x68f5008b,0xf1b802a1,0x64ac044c,0x29030216}},	//   muzd, _raġa_, _uşil, mtja_,
   {{0xda041376,0x290301f9,0x00000000,0x00000000}},	//   श्वत_, ltja_, --, --,
   {{0xf20708d1,0x7bddad56,0xd2640120,0x25fd00a3}},	//   рядо, hasu, окій, र्खी_,
   {{0xe8e000ef,0x7bddad57,0x2a5800a1,0x999a00d9}},	//   _việt_, kasu, שבון_, _kopš_,
   {{0x69dcad58,0x2eeda760,0x20d3002d,0x260f009f}},	//   zare, tref_, rţi_, ड़की_,
   {{0x69dcad59,0x7bdd5319,0xe8e000fe,0x999a0154}},	//   yare, dasu, _tiệt_, _rapō_,
   {{0x98c600cc,0xee390291,0x20d300ae,0x3b000090}},	//   _žuči_, уно_, pţi_, _rqiq_,
   {{0x4c862976,0x249fad5a,0x2901023e,0x29033b16}},	//   йлов, _khum_, _nqha_, jtja_,
   {{0x69dcad5b,0x7bdd977a,0xed56004d,0x00000000}},	//   ware, gasu, сою_, --,
   {{0x2245ad5c,0x249f0113,0x00000000,0x00000000}},	//   _kolk_, _mhum_, --, --,
   {{0x610a00a7,0x539a0266,0x69dc0b7e,0x00000000}},	//   _həla, טירו, uare, --,
   {{0x69dcad5d,0x7bdd1d81,0x7d1c0088,0xdca6430b}},	//   rare, basu, ærst, _лаки,
   {{0x69dc1075,0x7bddad5e,0x248d0134,0xa3c92397}},	//   sare, casu, _nkem_, लुम_,
   {{0x69dc290b,0xe7371c0e,0xc7a30002,0x78a40d76}},	// [cb20] pare, бет_, зитк, rmiv,
   {{0xcf920130,0x38bc00e3,0x69dcad5f,0x68f56c1a}},	//   לטן_, _tír_, qare, buzd,
   {{0xf1bf0028,0x25fe0f53,0x7ae400d6,0x186a036a}},	//   _đáp_, _लाठी_, _hvit, _бани_,
   {{0x249f09f7,0x7ae400f3,0xfd500065,0x981602fc}},	//   _chum_, _kvit, _aidọ, _ابدا,
   {{0x31cf0081,0xf77200e3,0x00000000,0x00000000}},	//   _রাজশ, _راح_, --, --,
   {{0x94160092,0x46a300d6,0xd6cf1f11,0x7bdd05bd}},	//   _əgər_, _наяв, _سقف_, zasu,
   {{0x7bdd22f5,0x293600c1,0x224502ac,0xab5b042c}},	//   yasu, מאַן_, _dolk_, nbür,
   {{0x8cd20f62,0xc5630ab3,0x7ae4033b,0xd138007f}},	//   _भौगो, _экск, _ovit, _rząd_,
   {{0x64a301b6,0x22450d4b,0x93431107,0x68f514f3}},	//   _хата, _folk_, _енте, zuzd,
   {{0x7bdd2826,0x7bc40172,0x2903003e,0x06cd0033}},	//   wasu, _afiu, ytja_, _লিমি,
   {{0x25fd06ed,0x7bdd03f3,0x2ca0009c,0x610a013c}},	//   र्टी_, tasu, _bhid_, _fəla,
   {{0x628aad60,0x68f5ad61,0x71594a13,0x2ca08892}},	//   lofo, vuzd, _трус_, _chid_,
   {{0x7ae4080e,0xab87169f,0x3f6700c2,0x78be0294}},	//   _cvit, сунк, _лицо_, _ọkpọ_,
   {{0x290317d7,0x7bdd60d8,0x09d90033,0x7ae900e7}},	//   ttja_, sasu, _তাহা, šeto,
   {{0x7bdd434b,0x1958013f,0x07e704d9,0x00000000}},	//   pasu, бары_, йцам, --,
   {{0x2ca0ad62,0x628aad63,0x2903ad64,0x4cf700ca}},	//   _ghid_, hofo, rtja_, _הזהב_,
   {{0x95d902d8,0x249fad65,0xaae70037,0x00000000}},	// [cb30] идат_, _rhum_, _اسبو, --,
   {{0x3a7513cb,0x249f00dd,0x95d8007b,0x00000000}},	//   _флор, _shum_, йдут_, --,
   {{0x628a01af,0x7d0d0d62,0x7ae41f54,0x69c50090}},	//   dofo, _ćask, _zvit, _ifhe,
   {{0xd37133c6,0x3cfb00c1,0x25fd1492,0x320c02ac}},	//   وها_, רלאנ, र्जी_, _abdy_,
   {{0x9239108f,0x212c0052,0x00000000,0x00000000}},	//   ичку_, _ardh_, --, --,
   {{0x610a00a7,0x2d9c00d4,0x00000000,0x00000000}},	//   _səla, _ozve_, --, --,
   {{0x224534d0,0x249f26a6,0x67291528,0xd49b0c3f}},	//   _volk_, _thum_, _šejh, _бра_,
   {{0xdb210220,0xaec503d9,0x237f0197,0x224518f0}},	//   _štýl, обил, _txuj_, _wolk_,
   {{0x2245ad66,0x26060d29,0x628a3001,0x91ca2172}},	//   _tolk_, स्वी_, bofo, _स्वै,
   {{0x386d0094,0x13de0033,0x25fd0176,0x7d090284}},	//   čery_, _ডায়, र्ची_, аног_,
   {{0xc5f2040a,0x1d093574,0x3ea50124,0xdca65e41}},	//   ודי_, шени_, rmlt_, жани,
   {{0x69c54f5c,0xb4fa00ca,0x6e3c5bd0,0x00000000}},	//   _afhe, ספרי, örbr, --,
   {{0x12d70033,0x69c5033c,0x00000000,0x00000000}},	//   _সমুদ, _bfhe, --, --,
   {{0x1e840565,0x769000c2,0x2fdfad67,0xfc3f0328}},	//   _елім, näyt, laug_, rmía_,
   {{0x8c4624f7,0x81ab0081,0xd82622de,0xceb2021e}},	//   _меке, কুর_, одви, _קיו_,
   {{0x7ae4ad68,0xab5b5867,0x00000000,0x00000000}},	//   _tvit, rbür, --, --,
   {{0x6e23ad69,0xaa7b003e,0x76900084,0x09d90033}},	// [cb40] _kanb, msýn, käyt, _তারা,
   {{0x6e230383,0x7c24ad6a,0x2fdf0120,0x7c261d79}},	//   _janb, _hair, haug_, ldkr,
   {{0x6e238d22,0xe3ba5cf7,0xab5b52ea,0x00000000}},	//   _manb, абе_, ncün, --,
   {{0x7c262271,0x6e23ad6b,0x7c2439bd,0x87b9224a}},	//   ndkr, _lanb, _jair, _гурт_,
   {{0x7c244765,0x2fdfad6c,0x4df900b6,0x00000000}},	//   _mair, daug_, ंलाई_, --,
   {{0x27e0ad6d,0x7c24ad6e,0xa90500cd,0x7aeb052f}},	//   lain_, _lair, _ببین, _ægte,
   {{0x61e80036,0x41c60efb,0x12d70033,0x6b510139}},	//   _vddl, रुषस, _সমৃদ, _kógú,
   {{0x6e2315b9,0x7c24873a,0x27e0ad6f,0x628a3c30}},	//   _aanb, _nair, nain_, sofo,
   {{0x6e23ad70,0x81ab0081,0x4426ad71,0x6b510065}},	//   _banb, কুল_, mdo_, _mógú,
   {{0x4424ad72,0x27e0ad73,0x64425a67,0xb50e009f}},	//   _ham_, hain_, ljoi, _सहाय_,
   {{0x4424ad74,0x6e23ad75,0x27e0ad76,0x7c24ad77}},	//   _kam_, _danb, kain_, _bair,
   {{0x44260133,0x7c24ad78,0xfe780138,0x6442ad79}},	//   ndo_, _cair, snį_, njoi,
   {{0x44249fbd,0x442609d3,0x27e03eff,0x7c242d74}},	//   _mam_, ido_, dain_, _dair,
   {{0x44245226,0x64420084,0x44261f41,0x6e23ad7a}},	//   _lam_, hjoi, hdo_, _ganb,
   {{0x7c24651c,0x4426ad7b,0x6b510139,0x6d5601c2}},	//   _fair, kdo_, _bógú, _ƙyau,
   {{0x44243cd6,0x7c240a76,0x27e0ad7c,0x4426ad7d}},	//   _nam_, _gair, gain_, jdo_,
   {{0x4426ad7e,0xb90204dd,0xd5bbad7f,0x387e231d}},	// [cb50] ddo_, _नौ_, асе_, étra_,
   {{0x7c24ad80,0x2fdf45e8,0xe6130037,0x68e1003e}},	//   _zair, zaug_, بشر_, álds,
   {{0x4424ad81,0x9c830117,0x7c2418c7,0x4426020b}},	//   _bam_, ščuj, _yair, fdo_,
   {{0x27e0ad82,0x660e01c8,0xfc3f5009,0x4426ad83}},	//   cain_, _ebbk, zmín_, gdo_,
   {{0x769000c2,0x083a006e,0x883a0289,0x00000000}},	//   täyt, _הערל, _התרו, --,
   {{0x76ba00ca,0x660e01ff,0x00000000,0x00000000}},	//   _למשפ, _gbbk, --, --,
   {{0x6e23ad84,0x4426ad85,0x2fdf023e,0xa3d50284}},	//   _ranb, bdo_, taug_, _новч,
   {{0x7cc10b4b,0x4424ad86,0x397c13b6,0x6e2306a3}},	//   _bērn, _gam_, יטונ, _sanb,
   {{0x6e23019c,0xdbd90088,0x7c24ad87,0x610a0092}},	//   _panb, væði, _rair, _həll,
   {{0x4424ad88,0x7c240084,0x27e00a00,0x2fdf023e}},	//   _zam_, _sair, zain_, saug_,
   {{0x44240d7d,0xfc3f025b,0x27e0ad89,0x64491044}},	//   _yam_, rmín_, yain_, _koei,
   {{0x4424006c,0x160b0789,0x6e23ad8a,0xf1cf09c4}},	//   _xam_, स्तर_, _wanb, _स्तन,
   {{0x7c24784c,0x64490934,0xeb9f01c5,0xdb08008e}},	//   _vair, _moei, lføj_, _ölüm,
   {{0x19b902ec,0x7c242d17,0x27e0ad8b,0x4426013f}},	//   жуть_, _wair, wain_, zdo_,
   {{0x7c240a62,0x4426aa67,0x27e0ad8c,0xd946025d}},	//   _tair, ydo_, tain_, чеви,
   {{0x7c241519,0x44260188,0xb3420555,0x18673bba}},	//   _uair, xdo_, şçil, паси_,
   {{0x27e0ad8d,0x44260117,0xe7374070,0x00000000}},	// [cb60] rain_, vdo_, пет_, --,
   {{0x17790a8d,0x44245809,0x27e0ad8e,0xea6400cd}},	//   ість_, _sam_, sain_, _آپدی,
   {{0x4424ad8f,0x27e0ad90,0x64493f79,0x69de7d2d}},	//   _pam_, pain_, _boei, _iepe,
   {{0x645b0514,0x4426ad91,0x69de41b0,0x746900d6}},	//   _clui, udo_, _hepe, орів_,
   {{0x64420d64,0x69de26f7,0x27f7025b,0x3860152f}},	//   rjoi, _kepe, šené_, mhir_,
   {{0x645b0ae8,0xf7880092,0x69de023b,0x44240034}},	//   _elui, _neçə_, _jepe, _wam_,
   {{0x4424ad92,0x69dead93,0x765c0139,0x644902ac}},	//   _tam_, _mepe, _ilry, _foei,
   {{0xdb160068,0x64495268,0x09b9009d,0x506600c6}},	//   _egyé, _goei, _आल्य, ятла,
   {{0xa41103a3,0x09e20081,0x386001c2,0x59be00b6}},	//   lığı_, _বানা, ihir_, ्डार,
   {{0x69de16a6,0x7ae90995,0xdbe50336,0x3ebd01cb}},	//   _nepe, šetk, कण्ड_, _duwt_,
   {{0x386006ee,0xfbe10033,0x610a013c,0xcfdb0033}},	//   khir_, _ভাবত, _kəlm, _ধারন,
   {{0x6ab503a2,0x00bb00a1,0x09c50096,0x69de0231}},	//   ंद्र, _המאמ, वड्य, _aepe,
   {{0x69de03ee,0x386082d7,0x7ac74dd2,0xcfaa0033}},	//   _bepe, dhir_, ясне, _গ্রন,
   {{0x69dead94,0xbd0103be,0x00000000,0x00000000}},	//   _cepe, ñéce, --, --,
   {{0x69de3594,0x1958004b,0x00000000,0x00000000}},	//   _depe, пары_, --, --,
   {{0xa4110702,0x386000da,0xfbc102d5,0x320001c2}},	//   dığı_, ghir_, _एलिम, ɗiye_,
   {{0xf77326a0,0x06b7015a,0x64491183,0x6e380381}},	// [cb70] رار_, سناک_, _roei, _knvb,
   {{0x645b04ee,0x69dead95,0x13d511d7,0xd0190034}},	//   _slui, _gepe, दर्भ, zeń_,
   {{0x38600049,0x645bad96,0x6449ad97,0x39a30139}},	//   bhir_, _plui, _poei, _désí_,
   {{0x3860688a,0x69de8310,0x765c0172,0x7bdf88be}},	//   chir_, _zepe, _elry, _jequ,
   {{0x7bdf00b3,0x6ab702a1,0x8c270033,0x00000000}},	//   _mequ, _kixf, যাপন_, --,
   {{0x7bdf0257,0x672dad98,0x200f0063,0xc293001c}},	//   _lequ, mvaj, _sbgi_, ریاب,
   {{0x672dad99,0xf497001c,0x64490023,0x00000000}},	//   lvaj, _فشرد, _toei, --,
   {{0x7bdf8270,0x610a0092,0x645b72d7,0x92f20233}},	//   _nequ, _gəlm, _ului, üğüm,
   {{0x2d9819b6,0x63bb9ad0,0xd9ed0714,0x00000000}},	//   üren_, _igun, _जयंत_, --,
   {{0x69c70357,0x6ab700bd,0x00000000,0x00000000}},	//   jcje, _nixf, --, --,
   {{0x61e3a4e0,0x7bdfad9a,0x160214e5,0x7cc101d3}},	//   manl, _bequ, र्टर_, _vēro,
   {{0x69de1268,0x61e3ad9b,0x9ce70068,0x7bdf0072}},	//   _sepe, lanl, _ہوتے_, _cequ,
   {{0x69dead9c,0xe8e00019,0x25fe07d5,0x09e20033}},	//   _pepe, _thịt_, _लाली_, _বাবা,
   {{0x672d2e48,0x61e370f3,0xeab20018,0xdeba00ca}},	//   dvaj, nanl, ئٹس_, _ומסל,
   {{0x3860ad9d,0x63bbad9e,0x672d0031,0x942300a7}},	//   thir_, _ogun, evaj, şvət_,
   {{0x63bbad9f,0xb8f605a7,0x61e3ada0,0x98a35cb1}},	//   _ngun, _हऽ_, hanl, висе,
   {{0x6f090558,0x61e357ad,0x69de3dfd,0x672d80b1}},	// [cb80] ntec, kanl, _tepe, gvaj,
   {{0x63bb1084,0x38606a22,0x6f09002b,0xa411026a}},	//   _agun, shir_, itec, tığı_,
   {{0x67291528,0x61e3ada1,0x9a3b00ca,0x6f09ada2}},	//   _šejt, danl, _ותיק, htec,
   {{0x68fcada3,0x6f09ada4,0x16021179,0x7bdf0231}},	//   murd, ktec, र्जर_, _xequ,
   {{0x6f09305d,0x290a0103,0x68fcada5,0x6e28ada6}},	//   jtec, ltba_, lurd, yddb,
   {{0x63bb03f3,0x7df906ed,0x61e3ada7,0x26d2019c}},	//   _egun, ्भोग_, ganl, mpyo_,
   {{0x200d0036,0x62810231,0x68fc028e,0xe8e000fe}},	//   ffei_, _djlo, nurd, _kiốt_,
   {{0xdfd00080,0x200200aa,0xf1b8009e,0xe8e0020b}},	//   دية_, üki_, _maġi_, _nhọt_,
   {{0x7bdf377e,0x41cf022d,0xb60702a1,0x61e3ada8}},	//   _requ, _स्वस, _feġġ, banl,
   {{0x3f980029,0x64ac0491,0x7bdfada9,0x20020034}},	//   āru_, _eşit, _sequ, żki_,
   {{0x7bdf132d,0xab5b0740,0x672d0087,0x68fc01c2}},	//   _pequ, rcüm, zvaj, jurd,
   {{0x68fc02ad,0x83fd0018,0xfbad0081,0x3a3a03e3}},	//   durd, _előf, _ক্ষত, _anpp_,
   {{0x92bc0081,0x6f0990cd,0x69c70357,0x00000000}},	//   _আবু_, ctec, tcje, --,
   {{0x8f9b00ca,0x68fc49ac,0x00000000,0x00000000}},	//   _וידי, furd, --, --,
   {{0x1994013d,0x69c7023b,0x00000000,0x00000000}},	//   варя, rcje, --, --,
   {{0x61e3071d,0x69c704e9,0x00000000,0x00000000}},	//   zanl, scje, --, --,
   {{0x61e303a3,0x59d04ff1,0x610a0092,0xe89400c2}},	// [cb90] yanl, _त्वर, _bəlk, тать,
   {{0x7afd6cc0,0xc5fb0037,0x68fc7e66,0x61e300a7}},	//   must, تعرض_, burd, xanl,
   {{0xb8f40f71,0x61e3adaa,0x3de30081,0x6c8409b4}},	//   _হয়_, vanl, _মামল, _سلیم,
   {{0x8c1c0130,0x61e3005c,0x6f09adab,0xb5a4004d}},	//   ַווי, wanl, ytec, труй,
   {{0x7afd9910,0x61e3adac,0x09e20081,0x78ad7936}},	//   nust, tanl, _বাতা, mmav,
   {{0x78adadad,0x62720034,0xfe0e00fe,0x00000000}},	//   lmav, słon, _sững_, --,
   {{0x61e3adae,0x7afd007a,0x85570018,0x6f090381}},	//   ranl, hust, _تیار_, wtec,
   {{0x61e306d7,0x63bbadaf,0x6f09adb0,0x10a23519}},	//   sanl, _ugun, ttec, лищн,
   {{0x61e3adb1,0xef160084,0xe811009d,0xfe0e00de}},	//   panl, емы_, ड्या_, _vững_,
   {{0x6f09adb2,0x7afd91ed,0x61e30092,0x68fc0491}},	//   rtec, dust, qanl, yurd,
   {{0x6f09adb3,0xc69200a1,0xd70b0081,0x68fc01f2}},	//   stec, ראי_, রিয়া_, xurd,
   {{0x6459adb4,0x68fc01df,0xf1bf0023,0x60c1009c}},	//   nkwi, vurd, _đáy_, _iulm,
   {{0x61e1adb5,0x60c16dfa,0x200a0092,0x00000000}},	//   _kell, _hulm, əbi_, --,
   {{0x60c1adb6,0x61e1adb7,0xf2d213b6,0x3e6002f1}},	//   _kulm, _jell, רעם_, _pòte_,
   {{0x61e101ce,0x60c1adb8,0xdb1d0103,0x7c9602f3}},	//   _mell, _julm, rcsá, _приц,
   {{0x21250da3,0xfbda0081,0x61e1adb9,0x60c1adba}},	//   _mslh_, _থাকত, _lell, _mulm,
   {{0xa5da0037,0xdb1d01f9,0x18673961,0x00000000}},	// [cba0] كبار_, pcsá, хати_, --,
   {{0x61e10020,0x78ad0451,0x68fc0634,0xa9264602}},	//   _nell, amav, purd, _здол,
   {{0x89db0327,0x60c10381,0x00000000,0x00000000}},	//   _מחיי, _nulm, --, --,
   {{0x5ed50081,0x00000000,0x00000000,0x00000000}},	//   _দিনে, --, --, --,
   {{0x61e10d63,0xe29a0c58,0x321c0031,0x2c050085}},	//   _bell, пад_, tevy_, ष्टं_,
   {{0x61e132b8,0x60c101e8,0x6726adbb,0x26c201ff}},	//   _cell, _bulm, _iskj, _iuko_,
   {{0x61e17131,0x26c2068d,0xe5a3028d,0x35a30fe3}},	//   _dell, _huko_, _бири, _барг,
   {{0x26c2092f,0x661e8e68,0x60c10188,0x64592e9c}},	//   _kuko_, lepk, _dulm, ckwi,
   {{0x7afd03be,0x61e1adbc,0x52c70033,0x00000000}},	//   xust, _fell, রীবৃ, --,
   {{0x61e102ad,0x3eb84313,0x7afd0d80,0x60c1028d}},	//   _gell, ört_, vust, _fulm,
   {{0x2d981484,0x764e76b6,0x26c2adbd,0x7afd0a9f}},	//   ære_, _moby, _luko_, wust,
   {{0x7afd13e3,0x61e1adbe,0xdb0401ff,0x32000022}},	//   tust, _zell, _agiñ, ɗiya_,
   {{0x26c2023f,0x61e1adbf,0x291e026a,0x60c10b12}},	//   _nuko_, _yell, çtan_, _zulm,
   {{0x7afd0302,0x764e265b,0x61e1003d,0x7f3b0266}},	//   rust, _noby, _xell, _מעדו,
   {{0x7afdadc0,0x29881456,0x1995008f,0x26c27320}},	//   sust, есто_, тавя, _auko_,
   {{0x26c20735,0xbca51374,0xdb0401c8,0x610a00a7}},	//   _buko_, _جمعي, _egiñ, _cəli,
   {{0x78ad5048,0x26c202ef,0x7afd00a7,0x610a00a7}},	// [cbb0] rmav, _cuko_, qust, _dəli,
   {{0xb8f70081,0x4b7c00ca,0x26cf01d3,0x7aedadc1}},	//   _সি_, _מאחו, īgo_, _ivat,
   {{0x61e1adc2,0x7aedadc3,0x764e109b,0xa3ce0174}},	//   _rell, _hvat, _doby, _ịbịa_,
   {{0x610a01d4,0x61e1984f,0x999a030b,0x4375adc4}},	//   _gəli, _sell, _např_, култ,
   {{0x60c100dd,0x44290181,0x645991d5,0x7cc101d3}},	//   _sulm, ľa_, rkwi, _pērk,
   {{0x60c17efa,0x442945ca,0x764e265b,0x61e1023b}},	//   _pulm, ža_, _goby, _qell,
   {{0x637301f9,0xddda00d2,0x00000000,0x00000000}},	//   _bűnö, entů, --, --,
   {{0x26c23223,0x7aedadc5,0x61e159af,0x610a00a7}},	//   _yuko_, _ovat, _well, _xəli,
   {{0x61e1adc6,0xef1900d6,0x09e20081,0x00000000}},	//   _tell, ємо_, _বাসা, --,
   {{0x2ca92f9c,0x9f5f15c9,0x60c1009c,0x61e11175}},	//   _ahad_, ngué_, _tulm, _uell,
   {{0x423600c1,0x2ca901f7,0x7aed7730,0x91ca007f}},	//   _שנעל_, _bhad_, _avat, _स्टै,
   {{0xed5600d6,0x9055313c,0x91fc01d3,0x6e2a01b9}},	//   тою_, _швец, _glāb, _eafb,
   {{0x7aed00cb,0x2ca901b9,0x00000000,0x00000000}},	//   _cvat, _dhad_, --, --,
   {{0x26c2adc7,0x2ca900e7,0xfaa60b9c,0x610a013c}},	//   _ruko_, _ehad_, таго, _səli,
   {{0xfbe100c7,0x2ca90a02,0x09b50081,0x2f0b0537}},	//   _ভারত, _fhad_, _জ্বা, løg_,
   {{0x249d01bb,0x26c200cc,0x764e12f5,0x2ca9adc8}},	//   jlwm_, _puko_, _soby, _ghad_,
   {{0x764e1fe8,0x2bd800b6,0x66e60392,0x610a013c}},	// [cbc0] _poby, _भ्या, тоза, _vəli,
   {{0x787b02fd,0x7ae903e5,0xd09900a7,0x00000000}},	//   tävä, ġett, rçən, --,
   {{0x7aed0039,0x661e231d,0x610a0092,0x27e20b6a}},	//   _zvat, repk, _təli, _tekn_,
   {{0x26c25f59,0x97da0076,0x787b007b,0x00000000}},	//   _tuko_, _تبدأ_, rävä, --,
   {{0x778300e5,0x27fd007f,0x2be30096,0x00000000}},	//   _вляз, ówne_, परता, --,
   {{0x98b800c6,0xdce902c6,0x6724adc9,0x00000000}},	//   tyrė_, áněn, mwij, --,
   {{0x672401c0,0x3e6001b9,0x6e2a01cd,0x15432cae}},	//   lwij, _nòta_, _rafb, _керм,
   {{0xc9530054,0x628f80b9,0xbbc10557,0x83fd0103}},	//   שמה_, _ícon, _एलेक, _előb,
   {{0xa49100bf,0xb2263574,0x67240126,0x7eb82b16}},	//   _اینت, _имал, nwij, нгис_,
   {{0x291a009d,0x7aed0559,0x00000000,0x00000000}},	//   _oppa_, _rvat, --, --,
   {{0x7aed752c,0x3e6001b9,0xd5fb0266,0xe04623b8}},	//   _svat, _còta_, ופיר, _инжи,
   {{0x6724adca,0x0179006e,0x9c7d004b,0x00000000}},	//   kwij, _אָנל, osči, --,
   {{0x291a00a4,0xfe6f001c,0xfb870077,0xab8707bf}},	//   _appa_, صدی_, тынн, тунк,
   {{0x25fe1fe6,0x6724029a,0x00000000,0x00000000}},	//   _लागी_, dwij, --, --,
   {{0x6f0026fa,0x2ca9adcb,0x67240381,0x644d00ce}},	//   lumc, _thad_, ewij, öaik,
   {{0x20040479,0x9c7d0138,0x4e0e030b,0x291a022b}},	//   ngmi_, ksči, त्रै_, _dppa_,
   {{0x6724adcc,0x291a0090,0x7aed0559,0x7c3fadcd}},	// [cbd0] gwij, _eppa_, _uvat, _inqr,
   {{0x7c2d31fc,0x7cc101d3,0x07080076,0x00000000}},	//   _haar, _sēri, ئيلي_, --,
   {{0x6f009532,0x9f5f0639,0x0b9400d1,0xf8c60206}},	//   humc, rgué_, _مجید, žéra_,
   {{0x7c2d32c2,0x6f00adce,0x5fb402d5,0x67240169}},	//   _jaar, kumc, ुशाल, bwij,
   {{0x27e9659a,0x610a0253,0x6f0000e7,0x7cc100e8}},	//   maan_, _məlu, jumc, _vēri,
   {{0xdd860080,0x7c2d8e5d,0x2c62025b,0x659500c6}},	//   _هو_, _laar, _móda_, _багу,
   {{0xc6920054,0x78bd01f9,0xf2040120,0x00000000}},	//   _האם_, _kisv, рячо, --,
   {{0x27e9adcf,0x7c2dadd0,0x34956a07,0x850401f9}},	//   naan_, _naar, _сабр, _خوفن,
   {{0x443f0d79,0xdd2e00b6,0xe3b32eb5,0x00000000}},	//   _inu_, měře, _ضرر_, --,
   {{0x27e9add1,0x442dadd2,0x83520068,0x7cc802c6}},	//   haan_, _hae_, _دھما, _věrn,
   {{0x27e9add3,0x7c2dadd4,0x2f0b01c5,0x442d001c}},	//   kaan_, _baar, søg_, _kae_,
   {{0x27e9add5,0x442dadd6,0x78bdadd7,0x7c2d008c}},	//   jaan_, _jae_, _nisv, _caar,
   {{0x442d1a2e,0x27e9388f,0x7c2d01aa,0x443f039f}},	//   _mae_, daan_, _daar, _mnu_,
   {{0x7c2f31fa,0x442dadd8,0x443f28eb,0x00000000}},	//   adcr, _lae_, _lnu_, --,
   {{0x443fadd9,0xc9550077,0x8cca04f8,0x7c2d008a}},	//   _onu_, атты, _संयो, _faar,
   {{0x27e97a7b,0x7c2dadda,0x6724addb,0x442daddc}},	//   gaan_, _gaar, twij, _nae_,
   {{0x98a358bd,0x7ae90220,0x78bd0036,0x7d01007e}},	// [cbe0] сите, šetr, _disv, luls,
   {{0x443faddd,0x67240505,0x3a2600c2,0x291a00dc}},	//   _anu_, rwij, _смог, _tppa_,
   {{0x69dc4c9a,0xae06121d,0x442dadde,0x27e92d81}},	//   mbre, _शासन_, _bae_, baan_,
   {{0x27e9addf,0x442dade0,0xe4d709b4,0x443f0167}},	//   caan_, _cae_, اونت_, _cnu_,
   {{0x442d0665,0x68e301c5,0xcec800de,0xb3760421}},	//   _dae_, _ændr, _mộc_, دداش,
   {{0x443fade1,0x69dc0b77,0x115408d8,0xcec800de}},	//   _enu_, nbre, иклю, _lộc_,
   {{0x6e2116f7,0x442d030a,0x96630110,0x7d01032e}},	//   delb, _fae_, _укре, juls,
   {{0x8cca018b,0x7d01283d,0x62830150,0x786300aa}},	//   _संबो, duls, anno, _kõva,
   {{0xd4670303,0x6440ade2,0x7c2dade3,0x7de604a1}},	//   _сите_, _inmi, _raar, лінд,
   {{0x7c2d1f5a,0x6e21ade4,0x5c140081,0x27e908d3}},	//   _saar, gelb, িযোগ_, zaan_,
   {{0x27e98366,0xa3e80e72,0x7c2dade5,0xf8b40096}},	//   yaan_, _मजा_, _paar, ंगाय,
   {{0x27e9025e,0x7c2d0694,0xdee601a0,0x26146eef}},	//   xaan_, _qaar, _боди, न्ती_,
   {{0x7c2d1f5b,0x27e9ab84,0x78bd00e5,0xeb0700c2}},	//   _vaar, vaan_, _risv, ычно,
   {{0x7c2d730d,0x27e983b8,0x69dc4c1e,0x61ea3156}},	//   _waar, waan_, gbre, nafl,
   {{0x27e9ade6,0x7c2dade7,0x64400305,0x48ab7ca9}},	//   taan_, _taar, _onmi, етам_,
   {{0x20ca0019,0x765e02ac,0x00000000,0x00000000}},	//   _mùi_, ekpy, --, --,
   {{0x6283872b,0x6d5a0018,0x69dc7810,0x78bdade8}},	// [cbf0] ynno, lyta, bbre, _visv,
   {{0x442dade9,0x2be3000f,0x6440adea,0x443fadeb}},	//   _sae_, परवा, _anmi, _snu_,
   {{0x27e9adec,0x7bcf008f,0x26140640,0x442d00b7}},	//   paan_, occu, न्धी_, _pae_,
   {{0x27e9008a,0x6288033b,0x7afdaded,0x6abeadee}},	//   qaan_, _ajdo, orst, _zipf,
   {{0x23af018b,0x7e7a063f,0x38690a6c,0x29030084}},	//   जेंद, kitp, mhar_, luja_,
   {{0x386900c9,0x26140c8c,0x442d00bf,0x6440adef}},	//   lhar_, न्दी_, _wae_, _enmi,
   {{0x291103f3,0x442dadf0,0x2903adf1,0x83fd0018}},	//   ntza_, _tae_, nuja_, _előa,
   {{0x443f00ac,0x3869adf2,0x29110a00,0x6d5aadf3}},	//   _unu_, nhar_, itza_, dyta,
   {{0x6e21adf4,0xf8bf0033,0xaec202e3,0x2903007b}},	//   telb, _mié_, обыл, huja_,
   {{0xee36adf5,0x63a9adf6,0x2903adf7,0x627200a5}},	//   ань_, _izen, kuja_, dłow,
   {{0xc05b02ec,0x6da50f08,0x4c860058,0x32cb00d6}},	//   _під_, рина, илов, _høy_,
   {{0x6e215530,0x3ef900ae,0x6abe0113,0x814c006e}},	//   selb, _андэ_, _sipf, _רעאַ,
   {{0x69dc4bbc,0x3869adf8,0x6e21adf9,0xdee50291}},	//   tbre, dhar_, pelb, _толи,
   {{0x26c404d4,0x6d5a17ba,0xb0c400c3,0x7d0134d2}},	//   _émoi_, byta, _लूँग, puls,
   {{0xdca60084,0x69dcadfa,0xcec80019,0x7afdadfb}},	//   _каки, rbre, _tộc_, arst,
   {{0xad1a00a1,0x3869adfc,0x8cca1362,0x63a9adfd}},	//   _יוצר, ghar_, _संतो, _ozen,

   {{0xd90d00bf,0xf77f44c3,0x27fd00a5,0x929d00a5}},	// [cc00] ویی_, _peça_, ówna_, _wpły,
   {{0x7df300af,0x45d61807,0x2903adfe,0x2abc0139}},	//   _आयोग_, рцат, buja_, _dábì_,
   {{0x386910f0,0xa52600d3,0x98a6adff,0xd9461b10}},	//   bhar_, рмед, _вине, _тени,
   {{0x7ae4023f,0x1d160130,0x20ca00de,0x00000000}},	//   _kwit, יקער_, _rùi_, --,
   {{0x61ea01cd,0x7ae40090,0x20ca00fe,0x2c620139}},	//   tafl, _jwit, _sùi_, _lódo_,
   {{0x63a930cb,0x64580034,0x7ae462a0,0xe2830a7c}},	//   _dzen, _ścią, _mwit, олчи,
   {{0x61ea4d7c,0x63a9ae00,0x361b006e,0xe72d00c6}},	//   rafl, _ezen, _שולד, _iššū,
   {{0x14d7028c,0x6440ae01,0x20ca00fe,0x09c30d7a}},	//   _כולל_, _unmi, _vùi_, _शल्य,
   {{0x7e7a00fc,0x32cb004d,0x63a90234,0x00000000}},	//   titp, _gøy_, _gzen, --,
   {{0x7afd15f4,0x6d5a0138,0x7bc400bd,0x38690a60}},	//   vrst, tyta, _agiu, zhar_,
   {{0x160b1492,0x2486042d,0x7ae4ae02,0xdd9400c6}},	//   स्टर_, onom_, _awit, саны,
   {{0x62987465,0x6d5aae03,0x248600f3,0x7ae40193}},	//   lovo, ryta, nnom_, _bwit,
   {{0x20110092,0x7afd1030,0x3ed40037,0x248606a8}},	//   əzi_, urst, _اقتر, inom_,
   {{0x6d5a00a5,0x61e88bdb,0xda7b249c,0x7ae4005c}},	//   pyta, _jedl, тям_, _dwit,
   {{0x61e80bab,0x3869003b,0x2bd80213,0x07e70277}},	//   _medl, thar_, _भ्वा, ицам,
   {{0x7cc10029,0x2903181b,0x386000a4,0x16190b95}},	//   _vērt, ruja_, gkir_, न्नर_,
   {{0x62987440,0x395f00d9,0xab5b0092,0x3869491b}},	// [cc10] kovo, ņus_, rcüs, rhar_,
   {{0x38694e88,0x61e802fe,0x1a650018,0x79810174}},	//   shar_, _nedl, _ایسی_, _ịwul,
   {{0x63a9ae04,0x91fc0029,0x7ae4ae05,0x69c56c0e}},	//   _szen, _plān, _zwit, _ighe,
   {{0xef1f01e8,0x24866d44,0x83fd0103,0x61e8058f}},	//   çük_, gnom_, _előn, _aedl,
   {{0x28c0000f,0x26140cf6,0x96f800ae,0x8c38006e}},	//   _शूटि, न्ही_, _кеят_, יטאס_,
   {{0x5ed50081,0x95cb0a99,0xb60400ae,0x60c8028a}},	//   _দিলে, _шума_, _мяск, _budm,
   {{0x25a50018,0x24862179,0x3207ae06,0x00000000}},	//   _áll_, bnom_, rgny_, --,
   {{0x6add00c7,0x644900d4,0x60c8041c,0x32cb00f3}},	//   _বিনো, álič, _dudm, _tøy_,
   {{0x62980146,0x63a9ae07,0x69c50129,0x60c801b9}},	//   bovo, _uzen, _oghe, _eudm,
   {{0x0e650265,0x69c5ae08,0x765502f1,0x6298905d}},	//   скон, _nghe, _jozy, covo,
   {{0x7ae400ca,0xfaff0052,0x386001cd,0x00000000}},	//   _swit, erë_, ykir_, --,
   {{0x81682458,0x69c5078e,0x00000000,0x00000000}},	//   _труб_, _aghe, --, --,
   {{0x2fdf001c,0xc5e80033,0x00000000,0x00000000}},	//   mbug_, _পাসপ, --, --,
   {{0x24860995,0xfbd80f62,0x2bd80386,0x69b300a4}},	//   znom_, _भ्रम, _भ्रा, _आणखी,
   {{0x291e05fe,0xa96702b3,0x7cc101d3,0x24866f90}},	//   ïta_, бира_, _vērs, ynom_,
   {{0xb8d07a0a,0x69c50134,0x7cd300ae,0xfc3f0094}},	//   _ओठ_, _eghe, _căre, smír_,
   {{0xe61a37f2,0x24860c0b,0x38608f96,0xcec800de}},	// [cc20] лда_, vnom_, rkir_, _lộn_,
   {{0x3860003e,0x1a06166f,0x629830a1,0x7c26227b}},	//   skir_, _упом, xovo, lekr,
   {{0xd91004c6,0x96b9263d,0x00000000,0x00000000}},	//   _تیز_, руту_, --, --,
   {{0xd49900d6,0x61e81c74,0x2eff2f66,0x24860124}},	//   арі_, _sedl, kruf_, unom_,
   {{0xa3c905d4,0x62988c23,0x27e0ae09,0x4df9030b}},	//   ोड़_, tovo, mbin_, ूलाई_,
   {{0x27e0976c,0xf2c501ce,0xcec800fe,0x00000000}},	//   lbin_, ісін, _bộn_, --,
   {{0x61e8ae0a,0x64a616c0,0x7c26ae0b,0x867b006e}},	//   _vedl, _гава, kekr, _ערלו,
   {{0x74160241,0x78a4541d,0x27e0581c,0x61e8ae0c}},	//   _دورا, nliv, nbin_, _wedl,
   {{0x33660c10,0x7c26526d,0x8f3413c7,0x00000000}},	//   _уваг, dekr, цепц, --,
   {{0x4426ae0d,0x78a4025b,0x2baf22e8,0x7ed30037}},	//   leo_, hliv, _घरबा, أزيا,
   {{0x78a473ed,0xe0da15de,0x869b0a41,0x61430836}},	//   kliv, _све_, רייז, _нефа,
   {{0x4426ae0e,0x7cd300d3,0x8c67268e,0x69c50036}},	//   neo_, _bărb, стод, _sghe,
   {{0x78a40146,0xddc8ae0f,0x28be00b7,0x27e0008c}},	//   dliv, midž, ्दनि, dbin_,
   {{0xfaff01e5,0x60c200e3,0x69c80220,0x27ed00b6}},	//   rrë_, _hiom, žden, _žen_,
   {{0x4426068d,0x7cd300d3,0xf77f0161,0x7c263348}},	//   keo_, _păre, _peço_, bekr,
   {{0x4426a9e8,0xc7d9141b,0x661c0234,0x660e01ff}},	//   jeo_, рмах_, _abrk, _acbk,
   {{0x442691ed,0x765500a5,0x9f4400ee,0x00000000}},	// [cc30] deo_, _pozy, namà_, --,
   {{0x67ff0032,0xe1332f54,0x60c210e4,0xc987168c}},	//   _bàjà, ščić_, _liom, _гуми,
   {{0x81e700c7,0x27e0006d,0x4426ae10,0x78a4ae11}},	//   _ভাল_, bbin_, feo_, bliv,
   {{0x2419055b,0xcec80023,0x73398063,0x60c2024a}},	//   роды_, _rộn_, изер_, _niom,
   {{0x7eaf004d,0x00000000,0x00000000,0x00000000}},	//   løpe, --, --, --,
   {{0x672f0dd9,0x7c26ae12,0xa8ed023a,0x00000000}},	//   _iscj, zekr, _जबाफ_, --,
   {{0x4426ae13,0x7cd300ae,0x91fc00e8,0x00000000}},	//   beo_, _mărc, _klāj, --,
   {{0x26c30890,0x60c2ae14,0x661c14f3,0x00000000}},	//   _hijo_, _ciom, _zbrk, --,
   {{0x60c2ae15,0x2fdf9627,0x62720034,0x248d01dc}},	//   _diom, rbug_, głos, _ijem_,
   {{0x248d0939,0x8cca1c83,0x26cb02a4,0x78a40e43}},	//   _hjem_, _संशो, _muco_, zliv,
   {{0x7cd300d3,0x248d00f3,0x26c3ae16,0xf3f900ae}},	//   _sărb, _kjem_, _mijo_, _alţi_,
   {{0x16190640,0x26d9ae17,0x8c460cc6,0x60c27054}},	//   न्तर_, _otso_, цеме, _giom,
   {{0x26d901fa,0x09c50081,0xeb970f0d,0x7afb031a}},	//   _ntso_, ্রনা, жия_, šutn,
   {{0xfce5016e,0x44260995,0x7fb60604,0x7c26ae18}},	//   _доко, zeo_, _ظهور_, sekr,
   {{0x78a40094,0x44261a3a,0x26d901ff,0x9f44034f}},	//   tliv, yeo_, _atso_, mamá_,
   {{0x248dae19,0x26cb028d,0x44260610,0x60c2037a}},	//   _njem_, _buco_, xeo_, _xiom,
   {{0x442600e9,0x27e0ae1a,0x07a3ae1b,0x2ca00270}},	// [cc40] veo_, rbin_, датн, _ikid_,
   {{0x78a40429,0x9f443072,0x249f0063,0x6a8600d3}},	//   sliv, namá_, _akum_, _флоа,
   {{0x4426ae1c,0x26c30081,0xfc3f0042,0x3cdd0096}},	//   teo_, _dijo_, llía_, कीचे_,
   {{0xf74661af,0xa5da2ebd,0x26cb002b,0x14170076}},	//   _демо, _प्रौ, _fuco_, قيمة_,
   {{0x26c32200,0x248d0052,0x60c203d3,0x249f05db}},	//   _fijo_, _djem_, _riom, _dkum_,
   {{0x4426ae1d,0x161904f8,0x60c2ae1e,0x248d037a}},	//   seo_, न्दर_, _siom, _ejem_,
   {{0x60c200e5,0x35a3ae1f,0xe5a30399,0xddc80580}},	//   _piom, _жарг, _жири, tidž,
   {{0x3ea50149,0x6563052f,0x26c300e7,0x9f54004d}},	//   ellt_, ønhe, _zijo_, звич,
   {{0xf8b3028c,0xfd62199b,0xddc83b1a,0x25aa274c}},	//   ושה_, _fitọ, ridž, _करुण,
   {{0xb5e80033,0x7bd60350,0xddc800c6,0xbbe3349f}},	//   _পাঁচ, _afyu, sidž, पर्क,
   {{0xa06a8dc3,0x60c20a6c,0xddc802ef,0x200fae20}},	//   _кажа_, _tiom, pidž, _fcgi_,
   {{0x2baf0096,0x2cb200eb,0x00000000,0x00000000}},	//   _घरदा, _chyd_, --, --,
   {{0x09e200c7,0x00000000,0x00000000,0x00000000}},	//   _বাজা, --, --, --,
   {{0x32d00019,0x9c130294,0x628a3d31,0x66e10032}},	//   _mày_, _nọve, nnfo, _lákò,
   {{0x58d45fdd,0x6e28ae21,0x628a2530,0x26cb1097}},	//   дост, medb, info, _suco_,
   {{0x2c0500a4,0x81ac0a43,0x83fd01f9,0x00000000}},	//   _वाटू_, _গলা_, _előj, --,
   {{0x32d0011b,0xa3de0442,0x61fa91b4,0x7d080537}},	// [cc50] _này_, _द्ध_, _odtl, luds,
   {{0x6e284bb7,0x249f1842,0x3a7512f8,0x26cb0344}},	//   nedb, _skum_, _хлор, _vuco_,
   {{0x7d0824d0,0x1bf20789,0x5fca0403,0x69d5007f}},	//   nuds, _अजमल_, ाखाल, mcze,
   {{0x81e700c7,0x32d00019,0x61fa0072,0x628a0381}},	//   _ভাই_, _bày_, _adtl, enfo,
   {{0x4c3c0130,0x932700cd,0x3ea5ae22,0x32d00023}},	//   יגאצ, تران, yllt_, _cày_,
   {{0x99910018,0x32d000de,0x6e280268,0xe8e00023}},	//   lező_, _dày_, jedb, _nhớt_,
   {{0xd24e00e3,0x823400e3,0x76470079,0x00000000}},	//   انى_, برنا, _injy, --,
   {{0x628a007e,0x249f00d1,0x786a00d8,0x672d024a}},	//   anfo, _ukum_, _kýva, owaj,
   {{0x9f440072,0xd25900e8,0x00000000,0x00000000}},	//   tamá_, _suņu_, --, --,
   {{0x670c09c3,0x3264008f,0x31353671,0x786aae23}},	//   िंतक_, _отхв, _незр, _mýva,
   {{0xcb090054,0xdca64d13,0x99910103,0x69d50034}},	//   _תל_, зани, kező_, dcze,
   {{0x69d500a5,0x672d89f5,0x3de30033,0xfaff0052}},	//   ecze, kwaj, _মাওল, jzës_,
   {{0x7052082c,0x20d10023,0x6e28ae24,0x5b35002d}},	//   _سنوا, _hái_, bedb, мэру,
   {{0xad250dce,0x09e20081,0xcd280e27,0x20d100fe}},	//   _فرعو, _বাঙা, حسین_, _kái_,
   {{0xd9431a77,0x6da233d6,0xa96700b4,0x672d007f}},	//   нери, _пиша, пира_, ewaj,
   {{0x786a0074,0xfc3fae25,0x20d10019,0x16190c38}},	//   _býva, llín_, _mái_, न्सर_,
   {{0x20d10019,0x3e6006a3,0x29035dca,0x83fd0103}},	// [cc60] _lái_, _sòti_, arja_, _elők,
   {{0x7c36026a,0x6a7002c3,0x20d100fe,0x00000000}},	//   _hayr, _säff, _oái_, --,
   {{0x4a5b00ca,0xfc3f0037,0x14260360,0x20d101cd}},	//   _הדיו, ilín_, здем, _nái_,
   {{0xc20e000f,0x136a004d,0x672d1cd1,0x290a19a2}},	//   _साहब_, йшли_, bwaj, muba_,
   {{0xe36308b8,0x09c500c7,0x7c360256,0x290aae26}},	//   нкци, ্রণা, _mayr, luba_,
   {{0x27f2989e,0x628a0328,0x20d10023,0x48e300b6}},	//   layn_, unfo, _bái_, टीको_,
   {{0x20d100ef,0x6e282af0,0x290a31a9,0x628a10a5}},	//   _cái_, vedb, nuba_, rnfo,
   {{0x64a31ac7,0x69d5ae27,0x27f2008a,0x7d082452}},	//   _заса, zcze, nayn_, vuds,
   {{0x213e02e0,0x290a0201,0x69d50034,0xe8e000fe}},	//   _wrth_, huba_, ycze, _phớt_,
   {{0x290a1a05,0x27f2008a,0x2903607c,0x20d1003e}},	//   kuba_, hayn_, yrja_, _fái_,
   {{0x7c360dea,0x20d10028,0x6e2802e6,0x29180220}},	//   _bayr, _gái_, redb, jtra_,
   {{0x7d08052f,0x6e28033b,0x672d0034,0x290aae28}},	//   ruds, sedb, ywaj, duba_,
   {{0xfc3f3062,0xe8e00023,0x27f20188,0x7c36008c}},	//   blín_, _thớt_, dayn_, _dayr,
   {{0x7c360f5a,0x7d080537,0xfe6f0037,0x290a5784}},	//   _eayr, puds, _مدى_, fuba_,
   {{0x290aae29,0x69d52fcc,0x8bec0033,0xdd8f004b}},	//   guba_, rcze, _কারন_, _чш_,
   {{0x2903023b,0x7c36026a,0x672d02a4,0x2b40ae2a}},	//   rrja_, _gayr, twaj, _fric_,
   {{0xcc3400e3,0x2b400234,0xe7ee0034,0x00000000}},	// [cc70] _سريع, _gric_, _ज़रा_, --,
   {{0x672d2293,0x290a8b03,0x786a0094,0x00000000}},	//   rwaj, buba_, _výva, --,
   {{0x290a614c,0x27f2008c,0xddc3044c,0x00000000}},	//   cuba_, bayn_, _monş, --,
   {{0x7c367653,0x09c50033,0x6b8217a0,0x27f2008c}},	//   _xayr, ্রদা, _žogi, cayn_,
   {{0x9f590511,0xe3b008ba,0x00000000,0x00000000}},	//   üsü_, هره_, --, --,
   {{0xa021026a,0x20f7044c,0x3f980345,0x00000000}},	//   _çöze, tăi_, ğrul_, --,
   {{0xe1f033c6,0x65942246,0xd12e0568,0x90b50284}},	//   اسه_, _зару, لمو_, мљиш,
   {{0x42770421,0x333f510d,0x00000000,0x00000000}},	//   _کارآ, _trux_, --, --,
   {{0x521544b2,0x290a0193,0x200d058f,0x335800ae}},	//   _одат, zuba_, rgei_, _еатэ_,
   {{0x20d10019,0xddc300ae,0x4d65ae2b,0x27f20491}},	//   _tái_, _conş, дков, zayn_,
   {{0x90e700bf,0xfc3fae2c,0x291807ee,0x62835244}},	//   _رسان, rlín_, xtra_, mino,
   {{0x645b201c,0xff510421,0x7c36008c,0x27f2008c}},	//   _joui, _لخت_, _qayr, xayn_,
   {{0x2018025c,0x6f09ae2d,0x25aa0d88,0x7c3600b3}},	//   əri_, quec, _कर्ण, _vayr,
   {{0x290a74a4,0x2918ae2e,0xc3320089,0x27f20188}},	//   tuba_, ttra_, דוך_, wayn_,
   {{0x64493eba,0xb8660103,0x29180072,0x00000000}},	//   _onei, وارو, utra_, --,
   {{0x6add0081,0x290aae2f,0x2b4001b5,0x2918ae30}},	//   _বিরো, ruba_, _tric_, rtra_,
   {{0x98a31f37,0x6283ae31,0x27f20188,0xf21300aa}},	// [cc80] тите, kino, rayn_, _ठाढ़_,
   {{0x27f22a7d,0x6449ae32,0xe9d700d3,0x00000000}},	//   sayn_, _anei, _окь_, --,
   {{0x6283ae33,0x645b4bd0,0x00000000,0x00000000}},	//   dino, _boui, --, --,
   {{0x81e70081,0x27f20188,0x645b020d,0x6449030a}},	//   _ভাগ_, qayn_, _coui, _cnei,
   {{0x645b020d,0x93cb0018,0x2d8201c2,0xc9570103}},	//   _doui, زانہ_, ̄ke_, _فلیش_,
   {{0xfe670979,0x38cb001c,0x645b009c,0x6449ae34}},	//   _شد_, _دایی_, _eoui, _enei,
   {{0xe5a60058,0x65c3013f,0x2ba5099d,0x645b6a46}},	//   _циви, _абра, _गुना, _foui,
   {{0xcec800ef,0x765cae35,0x2c620146,0x645b020d}},	//   _hội_, _hory, _kódu_, _goui,
   {{0x09b50081,0xd42600a7,0x2c6200d8,0x00000000}},	//   _জ্ঞা, ışdı_, _jódu_, --,
   {{0x6283250f,0x7cd300ae,0x5d541a2b,0xddc300a7}},	//   cino, _căro, екот, _qonş,
   {{0x765cae36,0x00000000,0x00000000,0x00000000}},	//   _mory, --, --, --,
   {{0x765c0380,0xcec80023,0xfc3f002b,0x00000000}},	//   _lory, _lội_, rlío_, --,
   {{0x8cca0104,0xa6db003e,0x2c750032,0x66ed00c3}},	//   _संको, _orða, _aúdù_, _चौंक_,
   {{0xb06103cf,0x9958030b,0x28a70034,0x765c039f}},	//   _ääre, láře_, _कीजि, _nory,
   {{0xcec800ef,0xf7730103,0x00000000,0x00000000}},	//   _nội_, ھار_, --, --,
   {{0xb8d700aa,0x995800b6,0x6e38ae37,0xf773001c}},	//   _छठ_, náře_, _havb, پار_,
   {{0xb8d61fbb,0x7bcd00d9,0x9c130134,0x645b020d}},	// [cc90] _ची_, _igau, _fọre, _roui,
   {{0x6283ae38,0x6449ae39,0xb9050081,0x765c0ac1}},	//   xino, _snei, _নি_, _cory,
   {{0xd49b490c,0x25de009f,0xcec800fe,0x645b014b}},	//   орд_, गड़ी_, _cội_, _poui,
   {{0xd5df0efb,0x05df00e2,0x7aed2f53,0x6283ae3a}},	//   _प्रज, _प्रब, _kwat, wino,
   {{0xe8df0028,0x38690044,0x765cae3b,0x2ba52f74}},	//   _khỏe_, mkar_, _fory, _गुमा,
   {{0x6e38ae3c,0x3869ae3d,0x7aed9c39,0x765c8505}},	//   _navb, lkar_, _mwat, _gory,
   {{0x6283ae3e,0x8cca0006,0x442b065b,0x64ca116e}},	//   rino, _संगो, _ºc_, िदृश,
   {{0x38690572,0x7bcd7698,0x6449ae3f,0x2f550ac6}},	//   nkar_, _ngau, _unei, етос,
   {{0x38691d15,0x7f42ae40,0x7aed0129,0x787100f3}},	//   ikar_, _croq, _nwat, _gåve,
   {{0x02cb0f8f,0x7bcd9740,0x63a9063d,0x386950e7}},	//   ादीन, _agau, _iyen, hkar_,
   {{0x7aed9b32,0xd0110018,0x3869ae41,0x261400b6}},	//   _awat, _ملا_, kkar_, न्टी_,
   {{0xeb9a5b3b,0x3e690181,0x63a90517,0x7aed21e9}},	//   зим_, _túto_, _kyen, _bwat,
   {{0x3869ae42,0x63a90079,0xbf67450f,0x6615007f}},	//   dkar_, _jyen, _تداو, _oczk,
   {{0x42790130,0x7aed022b,0x63a9728e,0x7bcd0372}},	//   לאָג, _dwat, _myen, _egau,
   {{0x48b62976,0xd8260a7c,0x63a9378a,0x765c0a4b}},	//   ещат, ндви, _lyen, _rory,
   {{0x786a0074,0x38696402,0x63a9ae43,0xddca022b}},	//   _vývo, gkar_, _oyen, _anfň,
   {{0x63a9a9f7,0x7c24023f,0x765c16d7,0x7aed3af6}},	// [cca0] _nyen, _ibir, _pory, _gwat,
   {{0xba7600bf,0xdb9b03c2,0x386901c2,0x765c008c}},	//   _ساخت, _מספר, akar_, _qory,
   {{0x7c2403e5,0x78714f94,0x63a90201,0x387202ac}},	//   _kbir, _såve, _ayen, phyr_,
   {{0x38690222,0x66e61b4d,0x78710572,0xcec800de}},	//   ckar_, _пома, _påve, _vội_,
   {{0x7c24ae44,0x3a3aae45,0x7cc201d3,0x3e72020d}},	//   _mbir, _kapp_, _bērz, _hâte_,
   {{0xcec80019,0x63a913e0,0x3a3a0212,0x6d43ae46}},	//   _tội_, _dyen, _japp_, _orna,
   {{0xfd070241,0x7c24ae47,0x66c90138,0x63a93944}},	//   _حج_, _obir, _užka, _eyen,
   {{0x7f4201d4,0x63a9052f,0xc95300ca,0xa8e800c3}},	//   _proq, _fyen, רמה_, टीएफ_,
   {{0x63060a09,0x26ca2621,0x63a96dbf,0x91fc009c}},	//   _سوال, _kibo_, _gyen, _blāt,
   {{0xdbfb084a,0x7c242bf4,0xe0ce0081,0x7aed02a4}},	//   ्ल्ड_, _abir, _রবীন, _rwat,
   {{0xdb160068,0xfc3f025b,0xdd9400c6,0x6d430480}},	//   _együ, slím_, таны, _crna,
   {{0x26ca2839,0x7f423536,0x2486007f,0xe8e000fe}},	//   _libo_, _troq, niom_, _nhốt_,
   {{0x6d43ae48,0xfbab1ad1,0x44240503,0x38690117}},	//   _erna, ятой_, _mbm_, vkar_,
   {{0x7c240a15,0x442400f9,0x26caae49,0x2ba50af1}},	//   _ebir, _lbm_, _nibo_, _गुणा,
   {{0x3e7200d3,0x3869028e,0x199400e5,0x6ca71d08}},	//   _câte_, tkar_, гаря, _приж,
   {{0x7aed2622,0xe8e00023,0x26ca007e,0x91fc01d3}},	//   _twat, _chốt_, _aibo_, _klās,
   {{0x7c2f0472,0x38690b6a,0x26ca5b42,0x7aed87cb}},	// [ccb0] mecr, rkar_, _bibo_, _uwat,
   {{0x3869ae4a,0x7c24011d,0x26ca008f,0x7c2f482b}},	//   skar_, _zbir, _cibo_, lecr,
   {{0x4424ae4b,0x9419236f,0xf77f0257,0x63a9019c}},	//   _bbm_, джет_, _reçu_, _syen,
   {{0x7c3d224d,0x6281030b,0x4424024a,0x6f1b0034}},	//   ndsr, _smlo, _cbm_, ytuc,
   {{0xa7fb22e7,0x27e9ae4c,0x26190eeb,0x7c3d2088}},	//   _coñe, mban_, _पापी_, idsr,
   {{0x78adae4d,0x26ca00f9,0x63a90051,0x7cc90034}},	//   llav, _gibo_, _vyen, _ośro,
   {{0x4095266a,0x24860b14,0x569474da,0x78ad0036}},	//   крит, biom_, _сарт, olav,
   {{0x27e90068,0x6f1b4820,0x7c3d02b6,0x3eac0381}},	//   nban_, ttuc, jdsr, eldt_,
   {{0x442fae4e,0x8ccb2dfd,0x6d5c69b0,0x63a9019f}},	//   meg_, _संजो, äran, _uyen,
   {{0x442f01ce,0x83fd0068,0x6f1b9bc8,0x78adae4f}},	//   leg_, _előt, rtuc, hlav,
   {{0x27e90068,0x26190abe,0x78adae50,0x301500d3}},	//   kban_, _पानी_, klav, _адер,
   {{0x442f0150,0x22490d2a,0x64590027,0x27e901f9}},	//   neg_, ɓaka_, njwi, jban_,
   {{0x207a00c1,0x51210006,0x907a00a1,0x78ad6c3d}},	//   _קאנא, _महुआ_, _קטני, dlav,
   {{0x6d430181,0x24860034,0x3e7200fd,0x442fae51}},	//   _trna, ziom_, _pâte_, heg_,
   {{0xc212040a,0x78ad003e,0x6f09ae52,0x26caa838}},	//   יהם_, flav, lrec, _ribo_,
   {{0x442f02e6,0x27e90018,0x7c2406e3,0x26ca0079}},	//   jeg_, gban_, _ubir, _sibo_,
   {{0x442f1aa8,0xbc1b00a1,0x2ee08457,0x6f0928c7}},	// [ccc0] deg_, _חופש, _çift_, nrec,
   {{0x6d412a6c,0x34ca0eeb,0x60cb02ac,0xaaba03c5}},	//   ovla, िद्द, _ligm, _تدبر_,
   {{0x27e9ae53,0x26ca0451,0x6f0901bf,0xe8e000fe}},	//   bban_, _vibo_, hrec, _thốt_,
   {{0x254108a1,0xa7fb0933,0x78adae54,0x442f00ed}},	//   _dėl_, _poñe, clav, geg_,
   {{0x26caae55,0x2c1a2171,0x3eac0430,0x6f094480}},	//   _tibo_, _भानू_, yldt_, jrec,
   {{0x6f091c28,0x5b7b00c1,0x442f00aa,0xd04c00a7}},	//   drec, ורנא, aeg_, əhət,
   {{0xcec8011b,0x4424001f,0x442fae56,0xeb9f01df}},	//   _một_, _tbm_, beg_, ngør_,
   {{0x442f04a3,0x656363bb,0x753700c1,0x6f09ae57}},	//   ceg_, änhe, _באלד_, frec,
   {{0x83fd0018,0x60cb00a6,0x6f09ae58,0x221629db}},	//   _elős, _digm, grec, _афер,
   {{0xa80603a3,0x290a0087,0x27e90103,0x91ba2729}},	//   ldığ, krba_, zban_, _قطار_,
   {{0x6f09002d,0x27e90103,0x78a400c2,0x7c2f0ac1}},	//   arec, yban_, koiv, tecr,
   {{0x6f09ae59,0xa80603a3,0x9ffa0bf4,0x59d5030b}},	//   brec, ndığ, _آراء_, _दलहर,
   {{0x6f093c9e,0xcec800de,0x9b58013d,0x7c3d40d6}},	//   crec, _bột_, вият_, rdsr,
   {{0x2be30067,0xc6080081,0xcec800de,0x442fae5a}},	//   _क्रं_, র্তা_, _cột_, zeg_,
   {{0x442f6db8,0x27e90068,0x2ba5034c,0xeb9f02b6}},	//   yeg_, tban_, _गँवा, ggør_,
   {{0x27e9ae5b,0x764e0383,0x61f800e7,0x60cb008c}},	//   uban_, _anby, havl, _xigm,
   {{0x442fae5c,0x2ca9084f,0x78adae5d,0x20d80037}},	// [ccd0] veg_, _ikad_, rlav, _léi_,
   {{0x78ad0964,0x27e90018,0x442f08c8,0xd5670565}},	//   slav, sban_, weg_, ктеп,
   {{0x442fae5e,0x7afd2085,0x56942cbf,0xb4cd09c3}},	//   teg_, lsst, шафт, रदे_,
   {{0x2541013f,0xfc3fae5f,0xb4bf0251,0x2911ae60}},	//   _vėl_, ndí_, ीदे_, muza_,
   {{0x442f536a,0x291105fb,0xe73d00b6,0xfc3f0037}},	//   reg_, luza_, _kříž, idí_,
   {{0x442fae61,0x7afd3180,0x6f09ae62,0xf679006e}},	//   seg_, isst, vrec, _טאָמ,
   {{0x291101da,0x68e20034,0x6f09211d,0xe73d02c6}},	//   nuza_, _łodz, wrec, _mříž,
   {{0x20d8052d,0x6f09ae63,0x83fd0018,0x7afd9d6b}},	//   _déi_, trec, _előr, ksst,
   {{0xb4bf1757,0x2911ae64,0x7afdae65,0xd13800c6}},	//   ँगी_, huza_, jsst, _esą_,
   {{0x7afd02fe,0x29111cd5,0x6f09411b,0xb06200c2}},	//   dsst, kuza_, rrec, _äänt,
   {{0x6f09ae66,0x60cb019c,0xa3d70ff9,0xa2d90285}},	//   srec, _tigm, _सला_, _फंड्,
   {{0x6703022d,0x6d411d17,0x2911ae67,0x6f09ae68}},	//   _लिंक_, rvla, duza_, prec,
   {{0x7afdae69,0x9c14619e,0x7cd300d3,0x05c300b6}},	//   gsst, _fọnt, _mări, वेतब,
   {{0x2911ae6a,0xa80607aa,0x78710bc6,0x00000000}},	//   fuza_, zdığ, _råva, --,
   {{0x69dc025a,0x29119004,0xa8060555,0x6e9205bc}},	//   rcre, guza_, ydığ, _دلوا,
   {{0x61f808a9,0x69dcae6b,0x7afd2bf6,0x1ddf0096}},	//   zavl, scre, bsst, पुरत,
   {{0x290a02ef,0xcec800fe,0x3ea500ee,0x78a400ce}},	// [cce0] srba_, _tột_, oolt_, roiv,
   {{0x261902e8,0x2911ae6c,0xe6173967,0x7ae471d7}},	//   _पाणी_, buza_, лду_, _itit,
   {{0x0446ae6d,0xa80600a7,0x291105bd,0x78a40350}},	//   лежн, tdığ, cuza_, poiv,
   {{0x3ea54192,0x32d90154,0x7ae4007e,0x00000000}},	//   holt_, _bèy_, _ktit, --,
   {{0xa80607aa,0x57fb00ca,0x3ea5ae6e,0x7cd3078e}},	//   rdığ, _אלכו, kolt_, _dări,
   {{0xd13a2dfb,0xfc3f1054,0x32d905aa,0x7ae40350}},	//   ехи_, zdí_, _dèy_, _mtit,
   {{0x261909d0,0x38620117,0x46d80eeb,0x00000000}},	//   _पाती_, _kokr_, _भूतह, --,
   {{0x64a6964c,0x7ae47b31,0x61f81386,0x6d5c00aa}},	//   _саба, _otit, savl, äram,
   {{0x29111621,0xa3e400aa,0x61f814f3,0x7ae40193}},	//   zuza_, पुण_, pavl, _ntit,
   {{0x7afd02fe,0x6ce61536,0x0737040a,0xd3b904a1}},	//   vsst, ліме, נאים_, _русі_,
   {{0x7ae4ae6f,0x2bc702d5,0x628aae70,0xa19600f6}},	//   _atit, रेना, mifo, _сјај,
   {{0x2911159c,0x628a3794,0x7ae40113,0x00000000}},	//   vuza_, lifo, _btit, --,
   {{0xfc3fae71,0x2f18249c,0x7afdae72,0x3ea50103}},	//   rdí_, _роль_, usst, bolt_,
   {{0x7afdae73,0x29112cd0,0x7ae41ac3,0x7bdf03a9}},	//   rsst, tuza_, _dtit, _wfqu,
   {{0x7ae400ac,0x2ba500a8,0xd5eb00fe,0x00000000}},	//   _etit, _गुरा, _đìn, --,
   {{0x2911ae74,0x628a5c3b,0x7ae40090,0x7afd96fd}},	//   ruza_, hifo, _ftit, psst,
   {{0x35f57f94,0x9c140134,0x7c94010d,0xa7fb00e1}},	// [ccf0] ипар, _mọlt, _دشوا, _coña,
   {{0x32d906a3,0xa7fb0143,0x7cd300ae,0x2b49ae75}},	//   _rèy_, _doña, _sări, _irac_,
   {{0xceb307a6,0x7cd300d3,0x3cfe0449,0x69c87a52}},	//   ציע_, _pări, nstv_, žder,
   {{0xd3710080,0x7c3f009e,0xf4850103,0x628a0f5a}},	//   يها_, _jaqr, جائی, eifo,
   {{0x7c3f008c,0x6fcb00a7,0x81e60033,0x6d5c12f1}},	//   _maqr, _möcü, _ভয়_, äraj,
   {{0x45d4489f,0x628aae76,0x15ab00e5,0x01652cc3}},	//   _горс, gifo, _зъби_, икло,
   {{0xc69200a1,0x3ea5ae77,0xf40200ae,0xb6040094}},	//   _ואם_, volt_, faţă_, íšer,
   {{0xf8b50c13,0xaf0503d9,0x3495007e,0xfaff0052}},	//   ंतिय, апил, _табр, ksë_,
   {{0x3255008d,0x443f70cc,0xcf8e00bf,0x2ba51362}},	//   _квар, _iau_, وژه_, _गुला,
   {{0x443fae78,0x628a002b,0xa2b30096,0xddca022b}},	//   _hau_, cifo, ेगळ्, _enfō,
   {{0x443f66bf,0x7ae4ae79,0x3ea50018,0xb0350084}},	//   _kau_, _stit, rolt_, _внеш,
   {{0x443f6c85,0xcb6a01c9,0xdca644c5,0x7ae4020d}},	//   _jau_, ваме_, рами, _ptit,
   {{0x443fae7a,0x38620124,0xe7b00081,0x6d5c004d}},	//   _mau_, _rokr_, _কল্য, ørar,
   {{0x443fae7b,0x2b4905fe,0x17ee278e,0x00000000}},	//   _lau_, _drac_, जर्व_, --,
   {{0xa7fb09b3,0x2eff060f,0x7c3f008c,0x00000000}},	//   _soña, lsuf_, _faqr, --,
   {{0x443fae7c,0xcec80019,0xa7fb0042,0x61400103}},	//   _nau_, _hộp_, _poña, lálá,
   {{0x7e63ae7d,0x78780396,0x068613f5,0xa686065c}},	// [cd00] _konp, _níve, аган, алад,
   {{0x61400018,0xf5e7002d,0x63a6004d,0x8afb00ca}},	//   nálá, имул_, _økni, _שהיי,
   {{0x7e63ae7e,0x1dab3e2a,0x787102c3,0x00000000}},	//   _monp, _घुमत, _gåvo, --,
   {{0x499b0c6a,0x443fae7f,0x320503e3,0xc4c50076}},	//   _ישיב, _cau_, _adly_, متنو,
   {{0x443f5cf2,0x787825d8,0x27e00044,0xf402020a}},	//   _dau_, _cíve, mcin_, vaţă_,
   {{0x443f025a,0x27e09532,0xcec800de,0x6234002d}},	//   _eau_, lcin_, _nộp_, секу,
   {{0xd1300080,0x628aae80,0x443f00f3,0x52750284}},	//   سمة_, rifo, _fau_, ључу,
   {{0x27e00a75,0x443fae81,0x7416110a,0x2054013d}},	//   ncin_, _gau_, _خورا, ския,
   {{0x27e03aab,0x4426ae82,0x6440456b,0x7cd3020a}},	//   icin_, mfo_, _iami, _măru,
   {{0x443fae83,0x64420634,0x0c0e0139,0xd33700ca}},	//   _zau_, ldoi, _iyẹẹ_, _דרמה_,
   {{0x443fae84,0x27e003e3,0x628802a1,0xd7220033}},	//   _yau_, kcin_, _imdo, নিয়া_,
   {{0x4426ae85,0x644038d6,0x443fae86,0x4fa60686}},	//   nfo_, _jami, _xau_, _киев,
   {{0x7b64ae87,0x61402897,0xdd39020a,0x44260361}},	//   отре, bálá, păşe, ifo_,
   {{0x28db1362,0x4efb00a1,0x644200c2,0x2b495f7a}},	//   _मंदि, _יהדו, hdoi, _vrac_,
   {{0x7c3f0078,0x753c0357,0x6f0000b3,0x28f800d3}},	//   _taqr, _nsrz, lsmc, иерь_,
   {{0x6440ae88,0x6d4a062d,0x7cd300d3,0x6f020234}},	//   _nami, _irfa, _căru, _kvoc,
   {{0x443f1071,0xd7f89007,0xcc342259,0x7cd300ae}},	// [cd10] _rau_, рус_, _ذريع, _dăru,
   {{0x443fae89,0x6440ae8a,0xe6132876,0x7a3905cb}},	//   _sau_, _aami, تشر_, _спор_,
   {{0x443fae8b,0x6440ae8c,0xf8b10688,0x4426ae8d}},	//   _pau_, _bami, _فکر_, ffo_,
   {{0x29360130,0x6f02025b,0x443f5d91,0x6288009c}},	//   _פארן_, _ovoc, _qau_, _amdo,
   {{0x6440ae8e,0x443fae8f,0xa6db0102,0x91e52cde}},	//   _dami, _vau_, _orði, боле,
   {{0x443fae90,0x200600dc,0x64420072,0xe80f00aa}},	//   _wau_, _adoi_, adoi, िलका_,
   {{0x443f1071,0x65945e39,0x26d9ae91,0x20d102a1}},	//   _tau_, _дару, _huso_, _aġir_,
   {{0x64405d58,0x26d1ae92,0xfc3f0037,0x7cd300ae}},	//   _gami, _hizo_, ilís_, _mărt,
   {{0x7e63ae93,0x6d4aae94,0x161e02d5,0x337572bd}},	//   _ponp, _arfa, _पामर_, _угар,
   {{0x644031f0,0x6f020181,0x26d96632,0x63bb1dfd}},	//   _zami, _dvoc, _muso_, _izun,
   {{0x41b52761,0x26d910d9,0x26d1ae95,0x61400103}},	//   _امار, _luso_, _mizo_, rálá,
   {{0xf8bf0028,0x672f00a5,0xfc320037,0x26d10072}},	//   _nhé_, _opcj, أحد_, _lizo_,
   {{0x6d4aae96,0x9f400088,0xe7a743e2,0xd7a70ff9}},	//   _erfa, _þið_, _कुलप, _कुलच,
   {{0x7e7aae97,0x63bb0051,0x09e30b99,0x7cd3020a}},	//   chtp, _mzun, зорн, _săru,
   {{0x6a6b07aa,0x7cd3020a,0x673d02a1,0xa7fb0487}},	//   _nüfu, _păru, _assj, _coño,
   {{0x26d97127,0xf8bf5d9b,0x27e00d2a,0x63bbae98}},	//   _buso_, _ché_, ucin_, _ozun,
   {{0x44f50181,0x7bd63d82,0x2bc7074c,0x27e0ae99}},	// [cd20] eť_, _igyu, रेदा, rcin_,
   {{0x27e003e3,0x77c716dd,0x26d101c2,0x00000000}},	//   scin_, слуг_, _cizo_, --,
   {{0x6440ae9a,0xa96a2240,0x26194e2e,0xd6cf0037}},	//   _pami, _сина_, _पारी_, رقم_,
   {{0xf8bf00de,0x26d9a293,0x7af60313,0xdbd7042c}},	//   _ghé_, _fuso_, _kwyt, _mäßi,
   {{0x8c1b028c,0x28b50789,0x4426656d,0x26d1440d}},	//   רוני, ंतरि, rfo_, _fizo_,
   {{0x66e3013d,0x8b0600a5,0xbb3b0341,0x63bb1d50}},	//   _хора, częś, טעני, _dzun,
   {{0x6724ae9b,0x6440ae9c,0x2ee67c17,0x44260193}},	//   ltij, _tami, _stof_, pfo_,
   {{0x04962204,0x386026f7,0x64400239,0x28db030b}},	//   _الرح, njir_, _uami, _मंसि,
   {{0x421a029e,0x25b80bf5,0x6d4a05db,0x26d9008c}},	//   _مزاج_, _अरुण, _srfa, _xuso_,
   {{0xa3e40abe,0x626500e3,0x1ed70037,0x9f4f00ee}},	//   पुर_, _والق, حبيب_, _degà_,
   {{0x67245c15,0x321e0a4b,0x63bb010a,0x6a6b0342}},	//   htij, _icty_, _zzun, _müft,
   {{0x67242557,0xac1900d6,0x6a6b0364,0x7af60150}},	//   ktij, шому_, _lüft, _bwyt,
   {{0xa7fb03be,0x0b8b0c59,0x61faae9d,0x26190285}},	//   _soño, усни_, _ketl, _पाली_,
   {{0x26d9ae9e,0xb69b00d3,0x629801bf,0x7af600eb}},	//   _ruso_, _avân, nnvo, _dwyt,
   {{0x26d9ae9f,0x26d10143,0x6724029a,0xbe8501c3}},	//   _suso_, _rizo_, etij, _بجنو,
   {{0x26d9aea0,0x6724aea1,0x5b152e91,0x99850103}},	//   _puso_, ftij, _дмит, ülő_,
   {{0x6d480727,0x7af600eb,0x67240381,0x00000000}},	// [cd30] lvda, _gwyt, gtij, --,
   {{0x32f6007f,0x2cab0231,0x629801cb,0x00000000}},	//   dły_, locd_, jnvo, --,
   {{0xd5bb1d5c,0xf8bf00fd,0x38740328,0x60da08aa}},	//   уса_, _thé_, ñará_, _nutm,
   {{0x62981570,0x26d914a7,0x00000000,0x00000000}},	//   envo, _tuso_, --, --,
   {{0x44f52ba9,0x7c2d935f,0xe7840012,0x4ad9009d}},	//   sť_, _mbar, _еуро, ढदिव,
   {{0x60da0b14,0xf99012eb,0x7c2d007e,0x6d4601d3}},	//   _butm, _آبی_, _lbar, ākaj,
   {{0x32f600a5,0x61fa02db,0x00000000,0x00000000}},	//   ały_, _detl, --, --,
   {{0x4f093f1d,0x61fa1044,0x629818f0,0x00000000}},	//   анин_, _eetl, anvo, --,
   {{0x442d43eb,0x63bbaea2,0x93e80076,0x00000000}},	//   _ibe_, _uzun, _طفلك_, --,
   {{0x7c2daea3,0x29030336,0xd1091f11,0x7645aea4}},	//   _abar, ksja_, _نقطه_, ndhy,
   {{0x7c2d009c,0xfbc707ad,0x60da1d87,0xda200714}},	//   _bbar, रेसम, _gutm, _बाबत_,
   {{0x69d7063d,0x7f750012,0x6f0e04a8,0x00000000}},	//   _agxe, _мулц, üncü, --,
   {{0xc61100c7,0x442daea5,0x543a00c1,0xae210469}},	//   স্যা_, _mbe_, בערא, _मापन_,
   {{0x9c130174,0x3e7b00fd,0x8f9a0266,0x7c2daea6}},	//   _nọfe, _bête_, _דיני, _ebar,
   {{0xd9435ca8,0x442daea7,0x7cd3020a,0x76450324}},	//   мери, _obe_, _vărs, ddhy,
   {{0x6724aea8,0x7c2d2624,0x57ea2b36,0xf7720cc8}},	//   ttij, _gbar, рдам_, واء_,
   {{0x16660bd5,0xd5b800d9,0x3860003e,0xa6db003e}},	// [cd40] овам, _šā_, rjir_, _orðu,
   {{0x442daea9,0x3e7b0257,0x7c2daeaa,0x20c10037}},	//   _abe_, _fête_, _zbar, lóid_,
   {{0x6724aeab,0xfe2102d5,0x7c2d0270,0x7eaf0120}},	//   stij, _मानस_, _ybar, løps,
   {{0x2bc7007d,0x29180193,0x61faaeac,0x136a8329}},	//   रेवा, mura_, _setl, ишли_,
   {{0x2918aead,0x61fa042d,0x1dab02d5,0x83361a13}},	//   lura_, _petl, _घुसत, تراض,
   {{0x442d0857,0xa6e2003e,0x00000000,0x00000000}},	//   _ebe_, áðun, --, --,
   {{0x2918023f,0x69c30fb6,0x61faaeae,0xa5074a4e}},	//   nura_, _únet, _vetl, _мера_,
   {{0xb4d605d4,0x442d0d79,0x61fa2d27,0x3a3801c0}},	//   सदी_, _gbe_, _wetl, herp_,
   {{0x2918aeaf,0x63060470,0x1fa300ae,0x6d48022e}},	//   hura_, _ذوال, дрэг, wvda,
   {{0x2918aeb0,0x60da008e,0x35af0b89,0x7c2daeb1}},	//   kura_, _tutm, _जुड़, _sbar,
   {{0x29181825,0x98ba05aa,0x2b4021c8,0x442d0027}},	//   jura_, _aspč_, _asic_, _ybe_,
   {{0x9c130134,0x2c620094,0x00000000,0x00000000}},	//   _mọge, _kódy_, --, --,
   {{0xa09b00a1,0x2b402243,0x60c26dd8,0x8ae4004d}},	//   _דיאט, _csic_, _ihom, дісл,
   {{0x29186d42,0x29110034,0x2c620094,0x29031a8a}},	//   fura_, trza_, _módy_, tsja_,
   {{0x60c2aeb2,0x2905aeb3,0x98ba0154,0x78b60c89}},	//   _khom, éla_, _espč_, flyv,
   {{0xda1709d0,0x29034197,0x7c2d75e8,0xdb0401ff}},	//   _ताकत_, rsja_, _ubar, _eziñ,
   {{0xb6c90018,0x60c201b9,0x59a7136b,0x00000000}},	// [cd50] مائے_, _mhom, _गडकर, --,
   {{0x3e7b025a,0x2918aeb4,0x454b2c37,0x69c800d2}},	//   _tête_, bura_, ичем_, ýdec,
   {{0x29183c46,0xe4a7856b,0x27f202c3,0x76454b96}},	//   cura_, ордо, bbyn_, rdhy,
   {{0xe7870291,0x91fc00e8,0x60c26e01,0x00000000}},	//   _дуго, _glāz, _nhom, --,
   {{0xa85a00ca,0x91e52312,0x00000000,0x00000000}},	//   _הדרכ, поле, --, --,
   {{0x69c30042,0x60c2aeb5,0x00000000,0x00000000}},	//   _únes, _ahom, --, --,
   {{0x60c2aeb6,0x00000000,0x00000000,0x00000000}},	//   _bhom, --, --, --,
   {{0x60c22ae1,0xd12e5e51,0x442dac86,0xa99c00ca}},	//   _chom, امي_, _ube_, יבור,
   {{0x60c2a53b,0x9c130134,0x57b908c0,0x00000000}},	//   _dhom, _mọde, _आरोह, --,
   {{0x29180193,0x60c2aeb7,0xc3320142,0x0d8520f8}},	//   yura_, _ehom, _אומ_, злон,
   {{0xc61100c7,0x3eb901d3,0x291801e9,0x60c200da}},	//   স্থা_, ēst_, xura_, _fhom,
   {{0x29180193,0x2245a719,0x3a381507,0x60c20090}},	//   vura_, _halk_, werp_, _ghom,
   {{0xf09200a1,0xeb97579e,0x20c10037,0x3a3827aa}},	//   _אנא_, зия_, róid_, terp_,
   {{0x60c9026a,0xc6110033,0xa96a0131,0x20c10076}},	//   lmem, স্তা_, бига_, sóid_,
   {{0xfaa31c2a,0x6d5c007a,0x5d79006e,0x0dcb0120}},	//   харо, ärat, _לאַק, _туди_,
   {{0x83fd0068,0x2918aa14,0x60c9aeb8,0x6d46007f}},	//   _előz, rura_, nmem, łkac,
   {{0x27f202ad,0x60160587,0x18674659,0xe7ba0081}},	// [cd60] rbyn_, lümü, чати_, ংখ্য,
   {{0x29180706,0x248daeb9,0x27f21b80,0xe9d700ae}},	//   pura_, _amem_, sbyn_, _нкь_,
   {{0x89db040a,0x6016008b,0x78b60220,0xf992001c}},	//   _לחיי, nümü, plyv, _سبد_,
   {{0x60c915c0,0x7eb405fe,0x161e0c8c,0xe8e000fe}},	//   jmem, ràpi, _पावर_, _nhứt_,
   {{0x60c20085,0x2245aeba,0x6d4601d3,0x442001d3}},	//   _rhom, _balk_, ākai, ļi_,
   {{0x442004f9,0x60c2aebb,0x25080470,0x00000000}},	//   żi_, _shom, _ورزی_, --,
   {{0x22450665,0x787125e5,0x2936006e,0xc6930266}},	//   _dalk_, _såvi, לאַן_, _טאש_,
   {{0x0443103d,0x78710400,0x60c912f5,0x859b0327}},	//   _песн, _påvi, gmem, _השלו,
   {{0x6568009c,0x00000000,0x00000000,0x00000000}},	//   _àdhb, --, --, --,
   {{0x614609e4,0xd09101d4,0x78ad0131,0xf3f9044c}},	//   _неза, _müəl, zoav, _roţi_,
   {{0x70f616c4,0x60c204af,0x320c0350,0x2ba51e93}},	//   _رسائ, _thom, _iddy_, _गुजा,
   {{0xf3f900d3,0x60c204ff,0x8597006e,0x60c9797d}},	//   _poţi_, _uhom, לדיג_, cmem,
   {{0x76803db0,0xfbad0033,0x00000000,0x00000000}},	//   _köyd, _গণহত, --, --,
   {{0xaa640a51,0x6d5c00aa,0x60160233,0x00000000}},	//   нтск, äras, bümü, --,
   {{0x79a4062c,0x78ad2b88,0x7d020139,0x00000000}},	//   ерте, toav, _dírá, --,
   {{0x76800084,0x7d1a0193,0xf3f900d3,0x2db700a1}},	//   _löyd, muts, _toţi_, _מלון_,
   {{0x7d1aaebc,0x7af00146,0x78ad7ff7,0x00000000}},	// [cd70] luts, čitý, roav, --,
   {{0xfbd00080,0x7aedaebd,0x60c9002d,0xf7702ba0}},	//   _حتى_, _itat, zmem, داف_,
   {{0x94750688,0x7d1a02a4,0xb9020033,0x60c986b3}},	//   وگرا, nuts, _নৌ_, ymem,
   {{0x61e800dc,0xe3b01ac9,0x7e6a084e,0x00000000}},	//   _afdl, گرم_, _lofp, --,
   {{0x7d1aaebe,0x22456d9f,0x6e3a09a3,0x6016071d}},	//   huts, _palk_, ketb, zümü,
   {{0x7d1aaebf,0x7aed024a,0x6016020e,0xe3b000d1}},	//   kuts, _mtat, yümü, درم_,
   {{0x7d1aaec0,0xc61906ed,0xa2d902d5,0x22456b11}},	//   juts, दलीय_, _फंक्, _valk_,
   {{0x44390990,0x6a7009b5,0x248d0095,0x7d1aaec1}},	//   _ús_, _häft, _umem_, duts,
   {{0x60c9aec2,0x224500a1,0xaec500d3,0x7aed1a8b}},	//   rmem, _talk_, мбил, _ntat,
   {{0x3e8900d6,0x4df400a9,0xfe710037,0x3e7b020d}},	//   ійно_, няют, ئدة_, _bêta_,
   {{0xdca608a4,0x7aedaec3,0x7d1aaec4,0xa2aa2918}},	//   дани, _atat, guts, टवर्,
   {{0xa0c40037,0x6016020e,0x00000000,0x00000000}},	//   _كيلو, rümü, --, --,
   {{0x6d5c30c1,0x9f4f04f6,0x3af60ab3,0xa7fb0062}},	//   ärar, _begå_, ьянс, _goñi,
   {{0x7d1a023f,0x201f05fe,0xaec400d6,0x68fb00cb}},	//   buts, lgui_, _збіл, ćudn,
   {{0x7aedaec5,0x2d94013d,0x7d1aaec6,0x00000000}},	//   _etat, _пръс, cuts, --,
   {{0x201faec7,0xb906009f,0xeb9a0012,0x00000000}},	//   ngui_, _पढ_, _мий_, --,
   {{0x76470193,0xe7ed009f,0x7c249d7c,0x261900aa}},	// [cd80] _bajy, जड़ा_, _icir, _पाखी_,
   {{0x78a902dd,0xff470a85,0x00000000,0x00000000}},	//   čeva, _یخ_, --, --,
   {{0x29050103,0xddca05aa,0x186a31d9,0x00000000}},	//   álat_, _enfņ, _дани_, --,
   {{0xf48700bf,0x6e3aaec8,0xe3ba4d93,0x2d85649a}},	//   وانی, zetb, обе_, izle_,
   {{0x63be0034,0xd0410d2a,0x7680007b,0x778300ae}},	//   ępno, _hulɗ, _pöyd, _аляз,
   {{0x9c140294,0x7d1aaec9,0xe5a6007e,0xc6080033}},	//   _kọst, yuts, _жиги, র্জা_,
   {{0x28c30067,0x26d851a0,0xfd070103,0x7c2400fe}},	//   _वीडि, _iiro_, _جج_, _ocir,
   {{0xa7fb0072,0x7d1a02a4,0x05570504,0x66c900c6}},	//   _poñi, vuts, _تلفظ_, _užkr,
   {{0x26d81cd8,0xe29a1894,0x3f840542,0x7647aeca}},	//   _kiro_, _даа_, uzmu_, _yajy,
   {{0x7d1aaecb,0x44240028,0x26d8008a,0x7c24aecc}},	//   tuts, _hcm_, _jiro_, _acir,
   {{0x7aedaecd,0xb80e1926,0x4c952249,0x6e3a1129}},	//   _stat, िणाम_, еинс, retb,
   {{0x7d1aaece,0xa7fb0072,0xdefa013f,0x26d80172}},	//   ruts, _toñi, _дык_, _liro_,
   {{0xc0a90fba,0x4424aecf,0x6d43aed0,0x7d1aaed1}},	//   _عامل_, _mcm_, _esna, suts,
   {{0x7c243a29,0x7d1aaed2,0x44240227,0xfe6f0076}},	//   _ecir, puts, _lcm_, _ندى_,
   {{0x4c950a99,0x7d1a039f,0x76470113,0x998300c6}},	//   _пикс, quts, _rajy, vejų_,
   {{0x030e1085,0x78780103,0xd5f40023,0x44240231}},	//   _सिंह_, _hívj, _đán, _ncm_,
   {{0x26d8aed3,0x7c3d6403,0x7aed0051,0x20c10231}},	// [cd90] _biro_, mesr, _utat, nóia_,
   {{0x2004aed4,0xd5bb4b95,0x7c3d2419,0x68e303a9}},	//   hami_, осе_, lesr, _éndo,
   {{0x25b80113,0x26d80188,0xe4e40120,0x00000000}},	//   _cyrl_, _diro_, вічн, --,
   {{0x20046adb,0x4424aed5,0x26d800d9,0x764705bd}},	//   jami_, _ccm_, _eiro_, _wajy,
   {{0x2004aed6,0xf8b20266,0xfdbb02d5,0x27e97f60}},	//   dami_, _תשכ_, _उर्फ, mcan_,
   {{0x26d870e5,0x6595aed7,0x4424482b,0x28bf0179}},	//   _giro_, _загу, _ecm_, ्षवि,
   {{0x66050991,0x4424aed8,0xf204004d,0x7c3d059a}},	//   mahk, _fcm_, тячо, kesr,
   {{0x40940ff8,0x27e9aed9,0x66052664,0x201f0138}},	//   крыт, ncan_, lahk, ugui_,
   {{0x645baeda,0x443da514,0xd426026a,0x64a4001f}},	//   _inui, mew_, ıştı_, _раѓа,
   {{0x443daedb,0xef822e9e,0x6f1b008a,0x4d65017b}},	//   lew_, ульп, ruuc, еков,
   {{0x2004278c,0x506708d8,0x2fd901f3,0x69da7daf}},	//   bami_, _отда, _فواد_, žtek,
   {{0x2004aedc,0x443daedd,0x7c3d0149,0x20c10231}},	//   cami_, new_, gesr, bóia_,
   {{0x6605063f,0xa3e40789,0x25860139,0x7c240090}},	//   kahk, पुट_, _kílé_, _vcir,
   {{0xddc3002d,0x66055aa9,0x6da537f2,0x645b009c}},	//   _conţ, jahk, _пила, _lnui,
   {{0x26d80065,0x66056ec5,0x19b900d6,0x443d29f2}},	//   _riro_, dahk, дуть_, kew_,
   {{0x26d8aede,0x443d10a4,0x186704c9,0xdb0f0103}},	//   _siro_, jew_, наси_, őjár,
   {{0x6f092eee,0x26d8aedf,0x443daee0,0xa7a70326}},	// [cda0] nsec, _piro_, dew_, екта_,
   {{0x20045f83,0x98c007aa,0x27e9850b,0x66053466}},	//   zami_, ırır_, acan_, gahk,
   {{0x2004aee1,0x26d8aee2,0x27e9008c,0xa49400d1}},	//   yami_, _viro_, bcan_, نیست,
   {{0x27e9aee3,0x64490042,0x645b01f7,0xc4860109}},	//   ccan_, _caei, _cnui, элек,
   {{0x26d8aee4,0x66051124,0x20041c56,0x258600b6}},	//   _tiro_, bahk, vami_, _bílé_,
   {{0x2004aee5,0x6605063f,0x6f091458,0xa50a125f}},	//   wami_, cahk, dsec, _нега_,
   {{0x200406e9,0x46a3004b,0xe5a6002d,0x645b084e}},	//   tami_, _сарв, _чиви, _fnui,
   {{0x6449054f,0x645b850b,0xbf3400e5,0x00000000}},	//   _gaei, _gnui, внищ, --,
   {{0x2004aee6,0x03a319a9,0x29180052,0x60d903a8}},	//   rami_, _бито, hrra_, _diwm,
   {{0x6462aee7,0x27e987f3,0x2004aee8,0x29180216}},	//   štič, zcan_, sami_, krra_,
   {{0x27e9025c,0x6d410150,0x60d903a8,0x787800d2}},	//   ycan_, gwla, _fiwm, _cívk,
   {{0x660502e7,0x69de009c,0x787800b6,0xdee61773}},	//   zahk, _agpe, _dívk, _зоди,
   {{0x9f4938d5,0x660502e7,0xcfaa071c,0x29180143}},	//   _það_, yahk, _عاصم_, erra_,
   {{0x7bc429aa,0x443daee9,0xceb900d2,0x00000000}},	//   _dziu, zew_, tuře_, --,
   {{0x98c70c33,0x38c700e5,0x23c70065,0x00000000}},	//   есал, ещав, _kìjí_, --,
   {{0x6605005c,0x7c3500d3,0x27e979af,0x00000000}},	//   wahk, _реих, ucan_, --,
   {{0x6605048e,0x27e99ec0,0x2918a7e1,0x7bdf0372}},	// [cdb0] tahk, rcan_, arra_, _igqu,
   {{0x27e9aeea,0x06b709b4,0x644900d9,0xdb9c00a1}},	//   scan_, رناک_, _saei, _מסחר,
   {{0x660506ee,0xddc30220,0x443daeeb,0xa3d30b94}},	//   rahk, _konš, tew_, हेन_,
   {{0x6605005a,0x25f110e9,0x75680103,0xe8e000fe}},	//   sahk, ेरही_, ریقہ_, _giựt_,
   {{0x628302ad,0x387e020d,0x20c10076,0x443daeec}},	//   thno, être_, fóin_, rew_,
   {{0x672daeed,0x38694f65,0x66050063,0x70b2001c}},	//   mtaj, ljar_, qahk, یموض,
   {{0x672daeee,0x443d03e5,0x6f0901cb,0x7bdf039f}},	//   ltaj, pew_, wsec, _ogqu,
   {{0xfd6500ef,0x3869210f,0x6f094341,0xd9de0b7f}},	//   _thuậ, njar_, tsec, _मल्ट,
   {{0x672daeef,0xfc3f0146,0x00000000,0x00000000}},	//   ntaj, deí_, --, --,
   {{0x63bbaef0,0x672d75bf,0xd0110018,0x63a900b3}},	//   _iyun, itaj, _چلا_, _ixen,
   {{0x6281aef1,0x3207acf1,0x63bb0da7,0x672d0fc4}},	//   _illo, many_, _hyun, htaj,
   {{0xeb9a36c9,0x63bbaef2,0x3869aef3,0x672daef4}},	//   дим_, _kyun, jjar_, ktaj,
   {{0xc4d20130,0x28db048a,0xdb0b0649,0x6d4e0e3e}},	//   יגט_, _मंजि, _ènìy, åbar,
   {{0x63bbaef5,0x3207aef6,0x672d0095,0x7bdf063d}},	//   _myun, nany_, dtaj, _egqu,
   {{0xb7ef0134,0xc7ef0129,0xa3c502d5,0x9d450208}},	//   _ụbụb, _ụbụr, ॉइड_, _рейд,
   {{0x63bb0390,0xbb8600e3,0x3869aef7,0x63a90212}},	//   _oyun, _للبي, gjar_, _oxen,
   {{0xb8e905d4,0x6281aef8,0x63bb3673,0x4cc80081}},	// [cdc0] _ली_, _ollo, _nyun, _রংপু,
   {{0x32071672,0xe8e000de,0xa6830d62,0x38690231}},	//   jany_, _chợt_, алуд, ajar_,
   {{0x63a90933,0x63bbaef9,0x320700a5,0x7ae4aefa}},	//   _axen, _ayun, dany_, _huit,
   {{0x74132204,0x7ae4440b,0xd7061121,0x62810e04}},	//   لوما, _kuit, _изми, _allo,
   {{0x628100dd,0x63bb0079,0xfe211b11,0x00000000}},	//   _bllo, _cyun, _मांस_, --,
   {{0x7ae4aefb,0xc7b30054,0x3207aefc,0x09d60033}},	//   _muit, _כבר_, gany_, _ত্যা,
   {{0x30a61456,0x4a9b00c1,0x1a9b00c1,0xa3d331f4}},	//   крив, ויסג, ויסע, हेब_,
   {{0x62811ce1,0xd01000e3,0x23710052,0x442200f3}},	//   _ello, حلة_, ënjë_, _øk_,
   {{0xa2e602ec,0x7878613c,0x7ae4aefd,0xc2462a5a}},	//   _розд, _cívi, _nuit, _инак,
   {{0xb0610084,0x78788dbc,0x2486003d,0x6ce61acf}},	//   _ääne, _dívi, lhom_, кіме,
   {{0xfe6f00e3,0x7e7aaefe,0x62980087,0x361b0266}},	//   تدي_, rktp, mivo, וויד,
   {{0x7ae482a7,0x6298472a,0x2486aeff,0x672d12c5}},	//   _buit, livo, nhom_, ytaj,
   {{0x7ae4af00,0xfc3f0131,0x6d5e00c4,0x7cdd044c}},	//   _cuit, reí_, _špad, tărî,
   {{0x7ae404ee,0x6298a930,0x00000000,0x00000000}},	//   _duit, nivo, --, --,
   {{0x3869af01,0xfce30291,0x7ae4009c,0x6d342a59}},	//   tjar_, _којо, _euit, _сейф,
   {{0x672d02fd,0x7ae4232f,0x32071799,0xf8bf1da8}},	//   ttaj, _fuit, zany_, ्षेप,
   {{0x38691e81,0x2486003d,0x672daf02,0x2607268e}},	// [cdd0] rjar_, dhom_, utaj, вчег,
   {{0xd04b01d4,0x63bb0169,0x6d5e6c99,0x38690120}},	//   _digə, _ryun, _àpas, sjar_,
   {{0x32070146,0xdc4300b6,0x00000000,0x00000000}},	//   vany_, _léčb, --, --,
   {{0x32070067,0x5f13000f,0x224c00dc,0x6281023b}},	//   wany_, _दिल्_, _aadk_, _sllo,
   {{0x3207acf1,0x862500d0,0x7d1a0364,0x224c02ac}},	//   tany_, _مکال, hrts, _badk_,
   {{0x629802e5,0x2b1b034c,0x63bb0350,0x00000000}},	//   givo, _बिनु_, _vyun, --,
   {{0x56947c88,0x32071fe8,0xd5b80d76,0x9998020a}},	//   _тарт, rany_, _аст_, merţ_,
   {{0x24860579,0x32070034,0x1c1f00aa,0x63a901c8}},	//   chom_, sany_, _भागल_, _txen,
   {{0x99bf0081,0x32073a18,0xe3b800ae,0x00000000}},	//   _আলোক, pany_, _алтч_, --,
   {{0x7ae4af03,0x6281002b,0x78780850,0x00000000}},	//   _ruit, _ullo, _vívi, --,
   {{0x7ae44115,0x78a9033b,0x68e301dc,0x00000000}},	//   _suit, čevj, _éndh, --,
   {{0x7ae490f1,0x32050018,0xdb0d03eb,0x00000000}},	//   _puit, _hely_, _azañ, --,
   {{0x32050077,0x7ae4af04,0x7d1a1044,0xbf670981}},	//   _kely_, _quit, arts, _جداو,
   {{0x7ae4af05,0xbf9a0341,0x1e840426,0x8f9a0266}},	//   _vuit, _אינש, _клім, _איני,
   {{0x63be00a5,0xb606025b,0x32050018,0x9c130294}},	//   ępni, ntáž, _mely_, _kọle,
   {{0x7ae43d91,0xb6030094,0x38cb001c,0x32050381}},	//   _tuit, hráč, فاقی_, _lely_,
   {{0x6d5eaf06,0x9b460604,0x47c6001f,0x00000000}},	// [cde0] _àpar, _صندو, убав, --,
   {{0x4a4648ad,0xb60600d4,0x00000000,0x00000000}},	//   _снов, ktáž, --, --,
   {{0x2486af07,0x2956013d,0x6298235d,0x00000000}},	//   thom_, _съпр, vivo, --,
   {{0x7c26af08,0x2366023e,0xb3860ed4,0x00000000}},	//   ngkr, txoj_, ллел, --,
   {{0x6298132d,0xe29a4064,0x2486af09,0x68e5af0a}},	//   tivo, над_, rhom_, _zuhd,
   {{0x851c007d,0x55e33e86,0x6f1baf0b,0x24860078}},	//   _पटपट_, _горб, druc, shom_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x764e3223,0x629861f8,0x3f142b79,0x6f1b02db}},	//   _haby, sivo, адис, fruc,
   {{0x764eaf0c,0x4426019c,0x27e20947,0x64420037}},	//   _kaby, mgo_, _mgkn_, meoi,
   {{0x4426af0d,0x225e0808,0x64420037,0x3205af0e}},	//   lgo_, _untk_, leoi, _gely_,
   {{0x527507ba,0x4426af0f,0x2d8100aa,0x78a40596}},	//   _туту, ogo_, _ühel_, kniv,
   {{0x44265308,0x6f1b2330,0x644200e3,0x5b2713fc}},	//   ngo_, bruc, neoi, льга,
   {{0x4426af10,0x6f1b2eee,0x68e500c2,0xdfd20037}},	//   igo_, cruc, _suhd, _ايش_,
   {{0x764eaf11,0x68e500c2,0x64420037,0x7c2601cb}},	//   _naby, _puhd, heoi, agkr,
   {{0xd9183ae2,0x02e1000d,0x8277006e,0xa2c505d6}},	//   льт_, _पढ्न, נעלע_, ितत्,
   {{0x6f0284ce,0x6d4aaef1,0x57f500d6,0x6d580167}},	//   _kwoc, _isfa, рпат, _irva,
   {{0x6d58084f,0x764e27d0,0x64420080,0x4426af12}},	// [cdf0] _hrva, _baby, deoi, dgo_,
   {{0x4426af13,0x200601ff,0xe4e7004d,0x78a409a1}},	//   ego_, _leoi_, гідн, aniv,
   {{0x290c0fc5,0xfc3f182b,0x3cea00bc,0x64422b65}},	//   ádat_, cníc_, _घूमे_, feoi,
   {{0x4426af14,0x64423a38,0x6f020034,0xd5b823aa}},	//   ggo_, geoi, _owoc, усу_,
   {{0xd5af00fb,0x442901d3,0x7680026a,0x00000000}},	//   _کہا_, ļa_, _köyl, --,
   {{0x4426af15,0x44296bf7,0x764e4d21,0x272f071d}},	//   ago_, ża_, _gaby, mün_,
   {{0xfa7800ca,0x20190131,0x272f071d,0x00000000}},	//   רעות_, ósio_, lün_, --,
   {{0x6f1b1c40,0x69c800a5,0xb6060146,0x6f0205aa}},	//   truc, żdeg, rtáž, _bwoc,
   {{0x6d587f67,0x272f07d1,0x8fa555ce,0xf77200c1}},	//   _arva, nün_, рапе, ַקט_,
   {{0x6f1b70e5,0x9c130134,0x78a4af16,0x2ca900bc}},	//   rruc, _dọme, zniv, _ajad_,
   {{0x6d5802ef,0x2ca90090,0x26c10231,0x6607af17}},	//   _crva, _bjad_, ilho_, _mejk,
   {{0x673d2a07,0x6f1b01bf,0x272f0555,0xae2100c3}},	//   _opsj, pruc, kün_, _माकन_,
   {{0x6d5815b9,0x76800b88,0x984801d4,0x9c130174}},	//   _erva, _böyl, xşı_, _gọme,
   {{0x44268b58,0x660700b6,0x00000000,0x00000000}},	//   zgo_, _nejk, --, --,
   {{0xaca40174,0xd94621bd,0x442625bf,0x26c10206}},	//   _agụi, шеви, ygo_, dlho_,
   {{0x7d5600a1,0x66150085,0x7d1c1bf1,0x764e0169}},	//   _כיצד_, _adzk, árse, _saby,
   {{0x753c0d1b,0x272f1f8a,0xbb460231,0xa76600c6}},	// [ce00] _sprz, gün_, _тепк, шкад,
   {{0x98480dea,0x290c0037,0x764e0188,0x66cb19a8}},	//   rşı_, ádas_, _qaby, yüke,
   {{0x644200e3,0x920201d3,0x00000000,0x00000000}},	//   teoi, šāka, --, --,
   {{0x44260138,0x2257001c,0x764e09b7,0x58d30161}},	//   ugo_, یلند_, _waby, _моќт,
   {{0x644200e3,0x9c130174,0x764eaf18,0x66070125}},	//   reoi, _bọje, _taby, _fejk,
   {{0x4426af19,0x64420037,0x8b5700c1,0xe2080139}},	//   sgo_, seoi, יינס_, _gbó̟_,
   {{0xe5a3215c,0x753c0034,0x200601ff,0xa507007b}},	//   _дири, _uprz, _peoi_, _веса_,
   {{0x64a611a0,0x6f0206a3,0x9f4f0487,0x395a0072}},	//   _таба, _pwoc, _negó_, _mrps_,
   {{0x0877006e,0x4fc600c6,0x00000000,0x00000000}},	//   שעפט_, шска, --, --,
   {{0x6d581cb4,0xd73700d7,0x00000000,0x00000000}},	//   _prva, סטית_, --, --,
   {{0x272f0511,0x7d0300eb,0x395a02a1,0x2a730154}},	//   zün_, _cwns, _nrps_, _roxb_,
   {{0x76800702,0xb17b0130,0xc19b00a1,0xa17b00c1}},	//   _söyl, _שטאר, _בשבי, _שטאט,
   {{0x395a03a9,0x2f1810e0,0xdef40138,0x9fe50076}},	//   _arps_, _соль_, _уплы, _اسمه,
   {{0x6d5818ed,0x8af00092,0x386205aa,0xfd970281}},	//   _trva, _irəl, _ankr_, ائیت_,
   {{0x6d581ee2,0xf807079c,0xa3b806ec,0xfc3f0328}},	//   _urva, ичан, _घुस_, anía_,
   {{0x272f35f8,0x673d03a9,0xba270033,0x66071175}},	//   tün_, _ppsj, য়েড_, _sejk,
   {{0x7c2daf1a,0x35e7385a,0x66070218,0x00000000}},	// [ce10] _icar, ацев, _pejk, --,
   {{0xbebd4b22,0xc61f0081,0x7c2d001c,0x272f6227}},	//   ltūr, ন্না_, _hcar, rün_,
   {{0x9c130134,0xf3f908f9,0x19ab001f,0x4ab40d75}},	//   _nọke, гнеш_, _штип_, ंकरव,
   {{0xdd8607d9,0xbebd282c,0xe4a4004d,0x5dd9006e}},	//   _ہو_, ntūr, орчо, אַנס,
   {{0xb4c70251,0xbd050139,0x66070052,0xa802002b}},	//   _उठी_, _atẹ́, _tejk, óñen,
   {{0xa2291c32,0xa5f82576,0x00000000,0x00000000}},	//   ужка_, _веру_, --, --,
   {{0xbebd282c,0x9877013c,0x00000000,0x00000000}},	//   ktūr, lçı_, --, --,
   {{0xfbdf20df,0x1dba0e4c,0xd7f800fe,0x671b09a1}},	//   ndês_, _उड़त, _đăk_, _फटाक_,
   {{0x442d2bd4,0x9877013c,0x7e7501f9,0x00000000}},	//   _ice_, nçı_, özpo, --,
   {{0xe1f09c21,0x7c2d0cd0,0x628aaf1b,0x52740037}},	//   _قسم_, _acar, chfo, _والز,
   {{0xa3d3009d,0xc21200a1,0xfc462347,0x7af6003e}},	//   हेर_, _זהב_, šíme_, _styt,
   {{0xcb6a10b8,0x661b01c2,0x9877071d,0xa2c500ec}},	//   гаме_, _ɓuka, kçı_, ितव्,
   {{0x442daf1c,0x929d0034,0x395a8e42,0x00000000}},	//   _mce_, _zwła, _srps_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xada22c26,0xbcf50cc8,0x6da2121c,0x7e7c0364}},	//   _нашл, _استغ, _ниша, örpe,
   {{0x442d006c,0x7c2d0076,0x00000000,0x00000000}},	//   _nce_, _gcar, --, --,
   {{0xa6860a67,0x00000000,0x00000000,0x00000000}},	// [ce20] блад, --, --, --,
   {{0x598603fc,0x49ba0308,0x78bd28b6,0x7ebd00ee}},	//   _глоб, _ماجد_, _eksv, cèpt,
   {{0xa3da11b5,0x09d60033,0x64a6004d,0x7ebd00b3}},	//   डेन_, _ত্রা, бажа, lèps,
   {{0xa5078dec,0x186a3cee,0xe1ff0023,0x986a00ae}},	//   сеца_, _сами_, _đóa_, _симб_,
   {{0x628a063d,0xe8e0020b,0x00000000,0x00000000}},	//   thfo, _chụt_, --, --,
   {{0x461600fb,0x9258263d,0xbb3b006e,0x00000000}},	//   _دوسر, ракт_, רעסי, --,
   {{0x41b401f3,0x00000000,0x00000000,0x00000000}},	//   غمبر, --, --, --,
   {{0x2b4021e1,0x00000000,0x00000000,0x00000000}},	//   _opic_, --, --, --,
   {{0x3f8202c6,0x93aa0103,0x00000000,0x00000000}},	//   áku_, _صارف_, --, --,
   {{0x7c2d1043,0x6e661a52,0x22f700ca,0x00000000}},	//   _scar, стиж, _לזמן_, --,
   {{0xb6bb0130,0x62880634,0x629a2462,0x635e078e}},	//   רציי, _ildo, _imto, _dănţ,
   {{0x69c101e8,0x320e00ec,0x7e63010a,0x999a00c6}},	//   ülem, lafy_, _ennp, _lapų_,
   {{0x7c2d02fe,0x2911007f,0x00000000,0x00000000}},	//   _vcar, wsza_, --, --,
   {{0xa3da09d0,0x00000000,0x00000000,0x00000000}},	//   डेय_, --, --, --,
   {{0xc61f0033,0x2b4000d7,0x7c2d009c,0x00000000}},	//   ন্ডা_, _epic_, _tcar, --,
   {{0xc4c40434,0xb4c70251,0x98770511,0x2911007f}},	//   _سے_, _उठे_, tçı_, rsza_,
   {{0x29110068,0xe7305c4d,0x768000c2,0xa3b800c3}},	// [ce30] ssza_, فصل_, _köyh, _घुल_,
   {{0xf7702ba0,0x7bcd01d3,0x29110034,0xeef700ca}},	//   راق_, _izau, psza_, צמבר_,
   {{0x7afdaf1d,0xe5070076,0x2cfb0142,0x00000000}},	//   lpst, صباي, ָלדא, --,
   {{0x7afd0371,0xccf300c1,0x3aef0b12,0x629a417b}},	//   opst, לכע_, _küp_, _amto,
   {{0xa3d30b89,0xe3b30037,0xa2c50096,0xf8bf0065}},	//   हें_, أرض_, ितल्, _iké_,
   {{0xd9fb09c4,0x96930504,0x911900d3,0x7afd084e}},	//   ्रित_, _عیاش, ациу_, ipst,
   {{0x442daf1e,0xdcf501d3,0x1bf9023a,0xb145004d}},	//   _tce_, ēcīg, ंडाल_, інил,
   {{0xef195782,0x2eb3009d,0x442daf1f,0xf43400ae}},	//   ами_, ुत्त, _uce_, _несэ,
   {{0xd9fb0096,0x200d00f9,0xa4d4004d,0x70760037}},	//   ्रात_, raei_, _хоті, تميز_,
   {{0xee362f68,0x273b00d3,0x00000000,0x00000000}},	//   онь_, mână_, --, --,
   {{0x2b400072,0x8c4610ab,0xd0190f98,0x00000000}},	//   _spic_, оене, _نقاش_, --,
   {{0x2d8b0067,0x7d1c0103,0x6283225b,0x2247af20}},	//   ące_, ársa, lkno, lenk_,
   {{0x2d83108a,0x10d80037,0x66d0007b,0x00000000}},	//   šje_, _ابلغ_, läke, --,
   {{0xf8bfaf21,0xc61f0081,0xefb3001c,0x00000000}},	//   _aké_, ন্তা_, _ویژگ, --,
   {{0x38c803ed,0x7bcd0a00,0x7afd112f,0x00000000}},	//   ماری_, _ezau, apst, --,
   {{0x224741b8,0x00000000,0x00000000,0x00000000}},	//   henk_, --, --, --,
   {{0xe1ff0019,0x6283354c,0x68fc00c4,0x98a3180b}},	// [ce40] _đón_, kkno, sprd, фите,
   {{0xd6260037,0x2247af22,0x00000000,0x00000000}},	//   تعري, jenk_, --, --,
   {{0x37e61f5d,0x2247112f,0xa96a015f,0x44f600d1}},	//   _монг, denk_, _тина_, زساز,
   {{0x629a0085,0x67df00c6,0x6abc0a20,0x00000000}},	//   _smto, _sąjū, lorf, --,
   {{0x926a19d4,0x13390018,0x68e303a9,0x00000000}},	//   ирка_, متوں_, _ènda, --,
   {{0x2734af23,0xdce900b6,0xda0a58af,0x00000000}},	//   män_, íněn, वरित_, --,
   {{0x273400c2,0x320e30e6,0x67360109,0xe57a0284}},	//   län_, rafy_, ltyj, _тзв_,
   {{0xb97b00c1,0xc05a0120,0xc61f0033,0xdce200c6}},	//   ינצי, рік_, ন্দা_, mylė,
   {{0xeeaa00d6,0x228b004d,0x25de0096,0x7bc40479}},	//   иток_, _søke_, _कृती_, _nyiu,
   {{0x6283af24,0xe29737fa,0x69c16dc3,0x67360138}},	//   ckno, _дау_, ülek, ityj,
   {{0x27340d64,0x6abcaf25,0xd00f15ef,0x3c5900ae}},	//   hän_, dorf, _оф_, бинэ_,
   {{0x273400ce,0x656800ee,0xdee60e2c,0x00000000}},	//   kän_, _àdhu, _доди, --,
   {{0x27340084,0x320c0181,0x6fb60037,0x6abc00f2}},	//   jän_, _kedy_, _بمشا, forf,
   {{0x273402fd,0x7afdaf26,0xfc3f02c6,0x997300d2}},	//   dän_, rpst, mním_, _věže_,
   {{0xfc3f00b6,0x320c00d8,0x00000000,0x00000000}},	//   lním_, _medy_, --, --,
   {{0x7afd1a88,0x5b151009,0x3aef0233,0x00000000}},	//   ppst, _емит, _tüp_, --,
   {{0xfc3f02c6,0x6d5a01f9,0x7bcd0144,0x00000000}},	// [ce50] nním_, lvta, _uzau, --,
   {{0xadc30139,0x693500ae,0xaad219af,0x00000000}},	//   _afẹh, _еноу, _दीपक, --,
   {{0x7aed6040,0xea0000de,0x7ae5039f,0xfaff0216}},	//   _huat, _hiếu_, _iiht, lpë_,
   {{0xe3b312eb,0x7aedaf27,0x78a9af28,0xf494001c}},	//   ورش_, _kuat, čevs, وشند,
   {{0xeab00421,0x6d5e0f1c,0x29e10022,0x2bde00b6}},	//   _سعی_, _špal, lɗa_, नेपा,
   {{0x09df0f71,0xe1f11e49,0x7aed32c3,0xfc3f030b}},	//   _ব্যা, رست_, _muat, dním_,
   {{0x7aed03e9,0x91e22195,0x62830eb3,0x320c0085}},	//   _luat, ноше, rkno, _dedy_,
   {{0x7ae50006,0x7aedaf29,0x6283af2a,0x7655084e}},	//   _liht, _ouat, skno, _hazy,
   {{0x443faf2b,0x60061736,0x66d01531,0x69c514f0}},	//   _ibu_, чным_, säke, _lyhe,
   {{0x76550074,0x6eed0031,0x320c1849,0x00000000}},	//   _jazy, _hĺbk, _gedy_, --,
   {{0x69c50501,0x25de02d5,0x7f42014b,0x6abc5411}},	//   _nyhe, केपी_, _epoq, vorf,
   {{0x7aedaf2c,0xfc3f00b6,0x5064036a,0x6abc0364}},	//   _buat, bním_, _отча, worf,
   {{0x7aed09e9,0x443faf2d,0x6abcaf2e,0x6d5a0572}},	//   _cuat, _mbu_, torf, avta,
   {{0x2734af23,0xddc801d3,0x76550034,0x443f03a9}},	//   vän_, ņoša, _nazy, _lbu_,
   {{0x443faf2f,0x186a28c2,0x7ae509ac,0x6d460034}},	//   _obu_, бави_, _diht, łkar,
   {{0x38660fb6,0x67360084,0x7aedaf30,0x443faf31}},	//   ñor_, ttyj, _fuat, _nbu_,
   {{0xe61a30c0,0x6abc001f,0xf7434a09,0xa686001f}},	// [ce60] йда_, porf, нето, плад,
   {{0x443faf32,0x8cc40034,0x273411cd,0x673616d7}},	//   _abu_, रतको, rän_, rtyj,
   {{0x273400c2,0x443f010a,0x20c10076,0x673604d9}},	//   sän_, _bbu_, nóis_, styj,
   {{0x66e610e8,0x443f09a4,0xd499004d,0x66cb0345}},	//   _нома, _cbu_, орі_, lükl,
   {{0x443f6f0b,0x833a00c2,0x69c00233,0x2a7a0660}},	//   _dbu_, счет_, şmed, _kopb_,
   {{0x443faf33,0x6d43af34,0xfc3f030b,0x6724009e}},	//   _ebu_, _opna, vním_, mrij,
   {{0x1543545b,0x672401c0,0xa3da009f,0x320c0031}},	//   _перм, lrij, डे़_, _vedy_,
   {{0x443f1cb5,0xfc3f00b6,0x660e00d4,0x69c101f9}},	//   _gbu_, tním_, _hebk, ülei,
   {{0x320c030b,0x7e7802dd,0x6724af35,0x68e601c2}},	//   _tedy_, _povp, nrij, _mikd,
   {{0x2486af36,0x660e0029,0x46be030b,0xfc3f00b6}},	//   lkom_, _jebk, ्तिह, rním_,
   {{0x67240505,0x7aed06ee,0x2d8200c4,0xfc3f02c6}},	//   hrij, _suat, _očeš_, sním_,
   {{0x68e60074,0x7ae532d2,0xa3d3030b,0xfc3f0094}},	//   _nikd, _siht, हेक_, mník_,
   {{0x7aedaf37,0xfc3f025b,0x60c2af38,0x46be055c}},	//   _quat, lník_, _ikom, ्ताह,
   {{0x67240505,0xdfa50080,0xdee3007e,0x34a90251}},	//   drij, _تحمي, _зочи, _कद्द,
   {{0xfc3f0220,0x291e1c5f,0x7ae50329,0xc7fa0174}},	//   nník_, štan_, _viht, _ọsụs,
   {{0x7aed0013,0x24860039,0x3ebe0018,0x98c400ae}},	//   _tuat, jkom_, lott_, есул,
   {{0x672420ce,0x2486af39,0x7ae500aa,0x443f0085}},	// [ce70] grij, dkom_, _tiht, _rbu_,
   {{0xcb12004f,0x20c10037,0x443f01a8,0x2486253b}},	//   _שלי_, nóir_, _sbu_, ekom_,
   {{0xfc3f0094,0x68e60231,0x6d5e1206,0x68e303a9}},	//   jník_, _fikd, _špaj, _èndo,
   {{0x6724393f,0xfc3f025b,0x20c100e3,0x60c2af3a}},	//   brij, dník_, hóir_, _nkom,
   {{0x2fc60197,0x3ebe834b,0x20c10231,0x00000000}},	//   _nyog_, kott_, zóis_, --,
   {{0x60c2af3b,0x78adaf3c,0x614500d3,0x00000000}},	//   _akom, lnav, дека, --,
   {{0x3ebe03e2,0x78adaf3d,0x248695a0,0x20c10037}},	//   dott_, onav, bkom_, dóir_,
   {{0x443f092f,0x78adaf3e,0x24860c0b,0x7c3d029a}},	//   _ubu_, nnav, ckom_, jfsr,
   {{0x66d0173a,0x66cb0511,0x00000000,0x00000000}},	//   läka, yükl, --, --,
   {{0x644baf3f,0x60c201b2,0x6459af40,0x20c100e3}},	//   legi, _ekom, ldwi, góir_,
   {{0x248d5f76,0x67240268,0x6f030af0,0xfc3f0094}},	//   _klem_, zrij, _bíbò, cník_,
   {{0x645928c1,0x644baf41,0x20c11876,0x78ad6732}},	//   ndwi, negi, róis_, jnav,
   {{0xee2e4460,0xeb972120,0xb7f400bc,0x60c925b8}},	//   _ин_, дия_, _अलबम_, mlem,
   {{0x60c9af42,0x672478ff,0x644b03a8,0x2486069a}},	//   llem, vrij, hegi, zkom_,
   {{0xb9b5013d,0x644b649a,0x66cb020e,0x2486af43}},	//   естъ, kegi, rükl, ykom_,
   {{0x768002fd,0x60c9af44,0x291e0335,0x18673283}},	//   _löyt, nlem, štao_, маси_,
   {{0xe737121c,0x200f57b4,0x2486af45,0x644baf46}},	// [ce80] мет_, _megi_, vkom_, degi,
   {{0x6724af47,0x200faf48,0x248daf49,0x24864695}},	//   rrij, _legi_, _alem_, wkom_,
   {{0x60c9af4a,0x78ad18ef,0x6724af4b,0x3d010096}},	//   klem, bnav, srij, वीचे_,
   {{0x3ebe0068,0xfc3f0074,0x644b57fe,0xe1f83ff4}},	//   zott_, vník_, gegi, ुर्ण_,
   {{0x60c909ce,0x2486af4c,0x69c100bc,0x78a40361}},	//   dlem, rkom_, ülev, miiv,
   {{0x60c2af4d,0xfc3f0146,0x44320034,0xa50a0a7c}},	//   _skom, tník_, ży_, _мега_,
   {{0x644b08d3,0x200f01e9,0x248d01ce,0x21670284}},	//   begi, _begi_, _flem_, дији_,
   {{0x60c9af4e,0x212006b8,0x9f54661e,0xfc3f0146}},	//   glem, čih_, евич, rník_,
   {{0x3ebe0068,0x200f278d,0x20c10037,0xfc3f023c}},	//   tott_, _degi_, tóir_, sník_,
   {{0x60c9af4f,0x78a41d4b,0xfc3f0094,0x11d62259}},	//   alem, hiiv, pník_, _قتاد,
   {{0x3ebeaf50,0x20c10037,0xa3da00b6,0x200f36d4}},	//   rott_, róir_, डेर_, _fegi_,
   {{0x101600d0,0x60c275bc,0xc0aa0241,0x671e02d5}},	//   _آباد, _ukom, _باطل_, _पिंक_,
   {{0x78ad02dd,0x3ebe0018,0x2fc60124,0x60c0108c}},	//   vnav, pott_, _uyog_, momm,
   {{0x60c0af51,0x2ca0039f,0x987600e8,0x6d5c02c3}},	//   lomm, _emid_, _eļļu_, åras,
   {{0x442f0ec9,0x768000c2,0x78ad01cb,0x19580109}},	//   ygg_, _löys, tnav, мары_,
   {{0x58d422ff,0x60c0af52,0x3157006e,0x7bc10555}},	//   вост, nomm, וילן_, ğlub,
   {{0x644b338b,0x6d5e00c4,0x3f84af53,0x00000000}},	// [ce90] vegi, _špah, nymu_, --,
   {{0x644b0305,0x3ce9022e,0x60c93e3b,0x248d644b}},	//   wegi, _hiav_, zlem, _slem_,
   {{0x644baf54,0x60c02104,0x3ce901fa,0x60c901e8}},	//   tegi, komm, _kiav_, ylem,
   {{0x947500cd,0x3f8400c6,0x7d0d007f,0x00000000}},	//   رگزا, kymu_, _łask, --,
   {{0x200faf55,0x64598ad9,0x60c0af56,0xa3da052c}},	//   _regi_, rdwi, domm, डेल_,
   {{0x200f88c0,0x644b7a70,0x672d024a,0x442f0072}},	//   _segi_, segi, muaj, sgg_,
   {{0x60c907fd,0x349514e0,0x200f0332,0x60db4520}},	//   tlem, _завр, _pegi_, tmum,
   {{0x45d402fd,0x249f0759,0x3ce9023e,0x60c9020d}},	//   _росс, _umum_, _niav_, ulem,
   {{0x60c9af57,0x200fa902,0xe2c90018,0x60dbaf58}},	//   rlem, _vegi_, _فورو_, rmum,
   {{0xee3913b0,0xfe710080,0x60c9af59,0x60db0172}},	//   чно_, ادة_, slem, smum,
   {{0x200f4d4e,0x60c07377,0x78a40063,0xa2bc0285}},	//   _tegi_, bomm, yiiv, शकर्,
   {{0x3ce9022e,0x60c00e6c,0x26c14b29,0x672d63a5}},	//   _ciav_, comm, hoho_, kuaj,
   {{0x3ce901fa,0x26c1025b,0xdd8e09b4,0x6d5c320e}},	//   _diav_, koho_, لوی_, årar,
   {{0x291e0106,0x3f7a006e,0x26c10350,0x69c8007f}},	//   štam_, _מאנס, joho_, żdem,
   {{0x78a44207,0xd9431d7b,0x3ea9030b,0xdca60e05}},	//   tiiv, лери, čitě_, _паки,
   {{0x2ca011bc,0xd9c00442,0x7680007b,0x3ea500bc}},	//   _umid_, _एडीट, _nöyr, lilt_,
   {{0x672daf5a,0x684300d3,0xdbd200bc,0x00000000}},	// [cea0] guaj, ынта, nüüm, --,
   {{0x78bb00e9,0x78a40329,0xb7d701c3,0x3ea500bc}},	//   čuva, siiv, رولا_, nilt_,
   {{0x1a9b07a6,0x69c10068,0x2d85014b,0x4a9b006e}},	//   _זייע, ület, nyle_, _זייג,
   {{0x3ce9022e,0x3ea5af5b,0x672d0350,0xb4aa00a4}},	//   _xiav_, hilt_, buaj, गचे_,
   {{0x3ea50fbf,0x26c10032,0xa3da07d5,0x672d037a}},	//   kilt_, boho_, डें_, cuaj,
   {{0x7d1c581b,0x2d851042,0x00000000,0x00000000}},	//   ársk, kyle_, --, --,
   {{0x60c0af5c,0xd5b2006f,0x3ea500bc,0x00000000}},	//   tomm, _صفر_, dilt_, --,
   {{0x3f8400c6,0xd0100037,0x653b006e,0x33260133}},	//   tymu_, جلة_, _מעלד, prox_,
   {{0x60c0af5d,0x4ea64a6f,0x2d8302b6,0x3ea54075}},	//   romm, ерна, øjen_, filt_,
   {{0x60c0af5e,0x3ce9022e,0x3ea5af5f,0xaca70103}},	//   somm, _siav_, gilt_, کھتے_,
   {{0x291e00e9,0x3ce90197,0xc69300a1,0x3b000063}},	//   štaj_, _piav_, ראת_, _atiq_,
   {{0xe1ff00de,0x66cb7057,0x3ea5009c,0x00000000}},	//   _đói_, tükk, ailt_, --,
   {{0x3ea50bc6,0x8b671a37,0x3ce901fa,0x7cff00ae}},	//   bilt_, راحم, _viav_, vârş,
   {{0x2d85af60,0xdfcf00e3,0x628a87d2,0x7e6aaf61}},	//   byle_, _ايه_, nkfo, _unfp,
   {{0x3cea0b89,0x3ce90197,0xdd8f0836,0x9e650103}},	//   _घंटे_, _tiav_, _сш_, _جانن,
   {{0x672daf62,0x7d1a0973,0x00000000,0x00000000}},	//   tuaj, msts, --, --,
   {{0x66d00149,0x16be0034,0x7d1a00e8,0x628a00f3}},	// [ceb0] räkn, ्तूब, lsts, kkfo,
   {{0xc13b0019,0x26d801b9,0xd371001c,0x69c17057}},	//   _cướp_, _chro_, یها_, üles,
   {{0x09df00c7,0x7d1a0dbc,0x26c10051,0x672d0239}},	//   _ব্রা, nsts, roho_, suaj,
   {{0x2bde53ee,0xe4e43006,0x6aa701c0,0x26c100e7}},	//   नेवा, гічн, lijf, soho_,
   {{0x69d80220,0x672d0052,0xdd010218,0x47df0a43}},	//   _úver, quaj, _čučn, _ফ্রী,
   {{0x7d1a07d2,0x59d800a4,0x00000000,0x00000000}},	//   ksts, णेकर, --, --,
   {{0xd49b0a29,0x45d44876,0x3ea52fa2,0x00000000}},	//   _ера_, _борс, vilt_, --,
   {{0x42d100c7,0x44f70587,0xa4d50c10,0x6aa7029a}},	//   াদেশ, _iç_, _робі, hijf,
   {{0x3f8b0181,0x3ea50744,0x91f50023,0x34941469}},	//   ácu_, tilt_, _các, _сатр,
   {{0x628aaf63,0x4d654a4e,0x2901039f,0x645b23de}},	//   ckfo, вков, _otha_, _haui,
   {{0xc5f2028c,0x7d1a00d9,0x3f8b2f54,0x2b49010a}},	//   ידי_, gsts, šcu_, _apac_,
   {{0xdca6545a,0x291e00cc,0x68e303a9,0x3ea57f69}},	//   тами, štak_, _èndh, silt_,
   {{0x29012bc0,0x3ea5af64,0x09df0033,0x00000000}},	//   _atha_, pilt_, _ব্লা, --,
   {{0xc332006e,0x66d000c2,0x48ed02d5,0x2b490027}},	//   בוך_, väko, _आंखो_, _dpac_,
   {{0x6f1b042c,0x78bb0234,0x00000000,0x00000000}},	//   lsuc, čuvn, --, --,
   {{0x645b01c2,0xa2a108c0,0x7c36039f,0x00000000}},	//   _naui, कोत्, _ucyr, --,
   {{0x6f1b01bf,0x69c1026a,0x44f70367,0xbc790031}},	// [cec0] nsuc, üler, _aç_, úšťa,
   {{0xe6be178d,0x6aa701c0,0x06b50033,0x661701c8}},	//   ्तेज, cijf, _জীবি, gaxk,
   {{0x6f1b01bf,0xd8260396,0x98ad026a,0x2d1f00a3}},	//   hsuc, _идни, _çoğu_, _मटोल_,
   {{0x2b4900c6,0x52ca0bf5,0x00000000,0x00000000}},	//   _ypac_, ित्स, --, --,
   {{0xe29a1469,0xe3b22519,0x00000000,0x00000000}},	//   мад_, جرا_, --, --,
   {{0x660300a9,0x7d1a6487,0x00000000,0x00000000}},	//   _впра, ysts, --, --,
   {{0x645b01b9,0x91f500fe,0x999800c6,0x628aaf65}},	//   _faui, _sác, merų_, rkfo,
   {{0x765caf66,0x51835397,0x855700ca,0x60d90178}},	//   _hary, руша, _בשלב_, _chwm,
   {{0x765caf67,0xa3d6142e,0xaab20179,0x7e2a1536}},	//   _kary, _हरि_, ँचाक, міна_,
   {{0xd3370327,0x7d1a03e3,0x66cb00bc,0x6e946dd5}},	//   _ברמה_, tsts, tüki, الدا,
   {{0x765c5244,0xf29700ca,0x91e66561,0x00000000}},	//   _mary, _שכבר_, _роже, --,
   {{0x4fc608b8,0x7d1a31fc,0xd08300c2,0x6abd0e28}},	//   _исла, rsts, _выши, ोत्र,
   {{0x7d1a41ba,0x98a3007f,0x5f736dd5,0x00000000}},	//   ssts, nują_, _ناور, --,
   {{0x765caf68,0x6f020090,0x00000000,0x00000000}},	//   _nary, _itoc, --, --,
   {{0x63be0034,0x6aa7029a,0x59f8004d,0x3ed9006e}},	//   ępny, rijf, теся_, _אַקא,
   {{0x2aad2cc8,0x98a30034,0x6d4a0027,0x6d5800c6}},	//   džbe_, kują_, _ipfa, _isva,
   {{0x765caf69,0xd7f823ba,0x00000000,0x00000000}},	// [ced0] _bary, тус_, --, --,
   {{0xba552d16,0x79a70dc3,0x765c00eb,0x44f70131}},	//   _свој, _арме, _cary, _pç_,
   {{0x765c14aa,0x9c6400d1,0x5bd300b6,0x645b00fc}},	//   _dary, _صهیو, _सरुव, _paui,
   {{0x7bcd1114,0x6f02af6a,0xa319007b,0xa3c70285}},	//   _kyau, _otoc, ежду_, _उडद_,
   {{0x4c9c0089,0x6d5d01d3,0x98a3007f,0x00000000}},	//   ובאו, āsai, gują_, --,
   {{0x6d580542,0x6d4a052f,0x765caf6b,0xfb160142}},	//   _osva, _opfa, _gary, אַקט_,
   {{0x81cb00c7,0xc692006e,0x6f02af6c,0x66cb0174}},	//   রেন_, _פאל_, _atoc, wükw,
   {{0x6615af6d,0x30190037,0x6f1b02db,0x765caf6e}},	//   _hezk, رتبة_, tsuc, _zary,
   {{0x661501e9,0x765c9d16,0x6d4a0169,0x7bcdaf6f}},	//   _kezk, _yary, _apfa, _nyau,
   {{0x6f1b02dc,0x82d80012,0x291e00c6,0x6f02033c}},	//   rsuc, _адус_, štai_, _dtoc,
   {{0x273d1baa,0x6f1baf70,0xd0110037,0x661501c8}},	//   hìn_, ssuc, _هلا_, _mezk,
   {{0x62814e96,0x6f1baf71,0xab2a268e,0x7bc10555}},	//   _holo, psuc, нома_, ğlun,
   {{0x6281af72,0x4fa400d6,0x6d5e030b,0xf1a70006}},	//   _kolo, _київ, _špat, _केतन,
   {{0x628180c4,0x661502c6,0x0d7300d1,0x00000000}},	//   _jolo, _nezk, _نخبگ, --,
   {{0x62819b87,0x291e0730,0x98a30034,0xb87b0503}},	//   _molo, éta_, zują_, _mhíf,
   {{0x6281af73,0x63bb0092,0x48c40081,0x88e619e8}},	//   _lolo, _oxun, ্দ্র, ужбе,
   {{0x7c240080,0x765caf74,0x99980138,0x7bcd03e3}},	// [cee0] _idir, _pary, terų_, _gyau,
   {{0x62811f41,0xa3c70251,0xa683090f,0x00000000}},	//   _nolo, _उड़_, блуд, --,
   {{0x765c371a,0x98a600d3,0xd0190034,0x63bbaf75}},	//   _vary, _бине, kań_, _axun,
   {{0xb4c00006,0x98a30034,0xa85619e8,0x765c8fd1}},	//   ुते_, tują_, _стој, _wary,
   {{0x3860af76,0x765c013f,0x6442af77,0x7bcd006c}},	//   mdir_, _tary, rfoi, _xyau,
   {{0x62810a5f,0x38609162,0x28d80ff9,0xc6920018}},	//   _colo, ldir_, _भीति, _اِس_,
   {{0x628153d9,0x6f02af78,0x98a3007f,0xddc3020d}},	//   _dolo, _stoc, sują_, _manœ,
   {{0x38608da5,0x9958025b,0x7c24af79,0x65000129}},	//   ndir_, káže_, _ndir, _ịkwụ,
   {{0x62810012,0xa3cb034c,0x38607882,0x4424af7a}},	//   _folo, _रुप_, idir_, _idm_,
   {{0xa2e667aa,0x7c24af7b,0x00000000,0x00000000}},	//   _созд, _adir, --, --,
   {{0x3860028e,0x7bcd005c,0x44240063,0x64bc0095}},	//   kdir_, _syau, _kdm_, pčid,
   {{0xd00f33ce,0x3a3a002b,0xfbcd0081,0xdd9700d3}},	//   _فلم_, _acpp_, রেফত, ушь_,
   {{0x3860af7c,0x69c001e8,0x6281af7d,0x7c245744}},	//   ddir_, şmel, _yolo, _ddir,
   {{0x8f9b07a6,0x7c2401d4,0x2eb10179,0x6281af7e}},	//   _אידי, _edir, ीकृत, _xolo,
   {{0x6d5804a3,0x9928141b,0x6615af7f,0x6d4a0027}},	//   _usva, люта_, _rezk, _upfa,
   {{0x694700e9,0x395a0124,0x386011bc,0xfc3f00b3}},	//   jčeš, _dsps_, gdir_, rnís_,
   {{0x7bcd00f9,0x7af60154,0x2eee020d,0xa6150636}},	// [cef0] _uyau, _guyt, _kiff_, имач,
   {{0xd5bb2db3,0x3860008c,0x00000000,0x00000000}},	//   нсе_, adir_, --, --,
   {{0x628115be,0x386000a7,0xf487328d,0x00000000}},	//   _rolo, bdir_, лудн, --,
   {{0x628156bf,0x297a0341,0xa7fb0610,0xbebd2224}},	//   _solo, _סטרא, _bañe, trūk,
   {{0x5bd3017f,0xa7fb05e6,0x225e0113,0x86250018}},	//   _सरोव, _cañe, _batk_, _نکال,
   {{0xe8e00019,0xd0190034,0x8afc00c1,0xa7fb037a}},	//   _đức_, wań_, עהוי, _dañe,
   {{0xd175065c,0x409508d9,0x4424052f,0xd0190034}},	//   рылы, ирит, _fdm_, tań_,
   {{0x5f751f11,0x2eee00eb,0x63bb01c8,0x6281af80}},	//   لاخر, _aiff_, _txun, _wolo,
   {{0x6281af81,0x672d8750,0x98b800d9,0xef160ab3}},	//   _tolo, nraj, ntrā_, амы_,
   {{0x99980018,0x386007aa,0x672d0542,0x62980364}},	//   zerű_, zdir_, iraj, chvo,
   {{0x672d025b,0x6d5e0aa0,0x3860af82,0x00000000}},	//   hraj, _špar, ydir_, --,
   {{0x7f59023e,0xb87b0072,0x9f5d022b,0x64bc43c5}},	//   _tswq, _xiít, _dewò_, mčic,
   {{0x64490080,0x5f7703ef,0x7ff41d28,0x672d033b}},	//   _mbei, _حاضر, _اسما, jraj,
   {{0xa3da3fac,0x6f09034f,0x672d2258,0x99580146}},	//   डेट_, mpec, draj, ráže_,
   {{0x38600092,0x99580146,0xdce41515,0x6449af83}},	//   tdir_, sáže_, _hrnč, _obei,
   {{0xf7720080,0x7c242678,0x2eeeaf84,0x6d410212}},	//   ياء_, _udir, _ziff_, mtla,
   {{0x3860af85,0x672daf86,0x6d412c97,0x66d000c2}},	// [cf00] rdir_, graj, ltla, läki,
   {{0x6449af87,0x442400a4,0xaa461e33,0xe9a7001c}},	//   _abei, _sdm_, _теол, اگین_,
   {{0x6d4190b4,0x64bc03c6,0x395aaf88,0x2baa0976}},	//   ntla, jčic, _usps_, _चेता,
   {{0x04461a29,0x3860af89,0x6449009c,0x3eb80117}},	//   редн, qdir_, _cbei, črti_,
   {{0x68e486ec,0x6d4100aa,0x44243eaf,0x3aef02a1}},	//   mmid, htla, _vdm_, _mżpn_,
   {{0xd36f00e3,0x6d41af8a,0x68e40288,0x6449039f}},	//   بهه_, ktla, lmid, _ebei,
   {{0x5bd30961,0x64930702,0xbbd30fdd,0xddc80034}},	//   _सर्व, _için, _सर्क, zedł,
   {{0x8f46013a,0x224908a9,0x2fcf3135,0x68e40a16}},	//   аход, đaka_, _bygg_, nmid,
   {{0x6d410034,0xdce414f3,0xa0670859,0xb87b0103}},	//   etla, _crnč, рања_, _kiír,
   {{0x26c703ce,0x68e4af8b,0x99870031,0x6d4132a7}},	//   čnog_, hmid, _čiže_, ftla,
   {{0x24848629,0x60c4033b,0x85f7006e,0xddd80141}},	//   _komm_, čimb, יציע_, _bovš,
   {{0xdb0403be,0x2aad4072,0x321c0146,0xa2da00b7}},	//   _axiñ, džba_, lavy_, _पीत्,
   {{0x6d411afd,0xdce40a39,0x68e4af8c,0xa3da00a4}},	//   atla, _grnč, dmid, डेच_,
   {{0x68e400aa,0x321c0206,0x00000000,0x00000000}},	//   emid, navy_, --, --,
   {{0x2bd30490,0x3eac2bf6,0xddd80141,0x68ef0381}},	//   _सरका, midt_, _fovš, _picd,
   {{0x1410000f,0x2366005f,0x88940084,0x68e40db1}},	//   ारोह_, kvoj_, оисх, gmid,
   {{0xaa890f36,0x80c7009f,0x68ef03e0,0x00000000}},	// [cf10] _منظم_, ावते, _vicd, --,
   {{0x672d02a7,0x260757a3,0x68e4af8d,0x321c0206}},	//   rraj, рчаг, amid, javy_,
   {{0x6f090094,0x2bda001c,0x672d0302,0xbdf80033}},	//   zpec, _لایک_, sraj, _আজাদ_,
   {{0x672daf8e,0x2d9e01ff,0x00000000,0x00000000}},	//   praj, izte_, --, --,
   {{0xe3b008ba,0x2ca90134,0x0876006e,0x291e02f7}},	//   وره_, _mmad_, _הערט_, štat_,
   {{0x78ad013f,0x6d4100a7,0x2fcf0e3e,0x984f0233}},	//   liav, ytla, _rygg_, _işık_,
   {{0xb5e500c7,0xf59500e3,0x6d4100a7,0x2ca900bc}},	//   _প্রচ, _الأج, xtla, _omad_,
   {{0xf3f900d3,0x19b800a1,0x64bcaf8f,0x2129033b}},	//   _faţa_, יפור_, rčic, čah_,
   {{0x200d3cfb,0x321c0146,0x63a40037,0xddd80141}},	//   rbei_, bavy_, úint, _rovš,
   {{0x6f09af90,0x78adaf91,0x6d415d95,0x66d000c2}},	//   rpec, hiav, ttla, täki,
   {{0xddd804ad,0x64bc00c6,0x2d9102c6,0x78adaf92}},	//   _povš, lčia, áze_, kiav,
   {{0x6d41af93,0xc18c00c1,0x22990154,0x3b0a001f}},	//   rtla, _שטאָ, _dèke_, лемо_,
   {{0x6d41af94,0x64bc3173,0x78adaf95,0x60c90381}},	//   stla, nčia, diav, moem,
   {{0x64bc013f,0xd37a006e,0x60c9af96,0x2bde1101}},	//   ičia, ארשט, loem, नेगा,
   {{0xf2d20796,0x35ac009f,0xfce61589,0xfaa30915}},	//   פעל_, _टेढ़, _локо, чаро,
   {{0x60c9043e,0x2aad0146,0x64bc0138,0x98a3972d}},	//   noem, ržba_, kčia, писе,
   {{0x64bc0220,0xac9704f4,0xd70aaf97,0x3f8d4e18}},	// [cf20] jčia, _دنيا_, унзе_, nyeu_,
   {{0x68e45b5a,0xe7f40789,0x60c90313,0x3cdc0096}},	//   smid, _अलका_, hoem, _गीते_,
   {{0x3ce001fa,0x64bc013f,0x321c00d8,0x452a0582}},	//   _khiv_, ečia, vavy_, ужен_,
   {{0x291e01b3,0x78ad25b0,0xb6060146,0x00000000}},	//   štas_, ciav, dráž, --,
   {{0x321c0146,0x64930342,0xcc3b006e,0x60c901fc}},	//   tavy_, _içil, רענט, doem,
   {{0x6d170034,0xd9fa0852,0xa30b0103,0x23661175}},	//   _दबंग_, ्डित_, ارنے_, rvoj_,
   {{0x321c18ed,0x81cb0081,0xd14a001c,0x60c96165}},	//   ravy_, রেস_, اشتن_, foem,
   {{0x831a1850,0x2ed0088d,0x63a40076,0x00000000}},	//   _مقرر_, हत्त, úins, --,
   {{0xdfd0054f,0x0877006e,0x4cce0033,0xdb160113}},	//   بية_, מעקט_, রগাঁ, _ècèn,
   {{0xa7fb14e2,0x2d9e02e2,0xb87b00de,0xa75b00c1}},	//   _maña, tzte_, _khíc, נדיר,
   {{0x3eac0f04,0xa7fb0072,0xa2c50d77,0x98c800a3}},	//   ridt_, _laña, ाकर्, लवाए,
   {{0x3ce00197,0xb87b0037,0xe7f4007a,0x2d9e042c}},	//   _chiv_, _mhíc, _अलगा_, rzte_,
   {{0x661e005a,0x78adaf98,0x00000000,0x00000000}},	//   kapk, viav, --, --,
   {{0xdd940ab3,0xdb0a01ab,0x7f420372,0x6fdd00a4}},	//   _малы, ðnám, _iqoq, _परतू,
   {{0x661e0808,0x78adaf99,0x66d00084,0xb87b00fe}},	//   dapk, tiav, näku, _nhíc,
   {{0xa7fb8a14,0xb715008f,0x2a616025,0x64bc0138}},	//   _baña, ждащ, _wahb_, yčia,
   {{0xa7fb42be,0x78adaf9a,0x69c8042c,0x291eaf9b}},	// [cf30] _caña, riav, üder, átar_,
   {{0x6c3509b4,0x661e005c,0xa7fb058a,0x245300fe}},	//   _افکا, gapk, _daña, _ảm_,
   {{0x291e28fc,0xb87baf9c,0x78adaf9d,0xf3f9168c}},	//   štar_, _chíc, piav, анеш_,
   {{0xb87b0076,0x44fe084e,0x7d040f1c,0x7f42039f}},	//   _dhíc, _dï_, _čisl, _oqoq,
   {{0xa7fb0933,0x1dcf0251,0x98b800d3,0x083a006e}},	//   _gaña, _सुनत, stră_, _דערל,
   {{0x661e005a,0x64bc0774,0x6493008b,0xb6060094}},	//   capk, rčia, _içim, tráž,
   {{0x60c91ba6,0x64bc16d4,0x91e27db1,0x7f420372}},	//   toem, sčia, моше, _aqoq,
   {{0xaf052863,0x3f420088,0x6ea6030b,0x64bc8851}},	//   опил, fðu_, टोसु, lčin,
   {{0xb4d50f35,0x60c90db1,0x3f42003e,0x81c701d3}},	//   हती_, roem, gðu_, dzēš,
   {{0x92b70f36,0x64bc0fee,0xfd491aad,0xa2cb00ae}},	//   _احرا, nčin, азок_, _субз_,
   {{0xa2c6045f,0x3ce0023e,0x226400b6,0x443f02ef}},	//   िवर्, _phiv_, řská_, _kcu_,
   {{0x25e10cce,0xceb8007f,0x1bea1c47,0xfaff0216}},	//   _करनी_, anę_, идни_, rvën_,
   {{0xfc4a0139,0x98b800c6,0xe79c0233,0x00000000}},	//   _adíá_, ntrą_, düğü, --,
   {{0x201faf9e,0x64bc0995,0xa7fb002b,0xbebd00e8}},	//   laui_, jčin, _raña, grūt,
   {{0x81cb0f71,0x443f005f,0xfbde09b0,0x3ce0022e}},	//   রের_, _ocu_, नेजम, _thiv_,
   {{0x443f01fa,0xa7fb058a,0x7e6301ff,0x64bc0206}},	//   _ncu_, _paña, _hanp, ečin,
   {{0xe73a3379,0xe61a1d6e,0x661e06ee,0x7e63af9f}},	// [cf40] рез_, ида_, tapk, _kanp,
   {{0x443f0080,0x7e630139,0xb87b00fe,0xd62a0ed4}},	//   _acu_, _janp, _phíc, роже_,
   {{0x661e06ee,0x201f00dc,0x00000000,0x00000000}},	//   rapk, kaui_, --, --,
   {{0x7e630a00,0x69de75a0,0xe73a00c2,0x661e2106}},	//   _lanp, _izpe, _кем_, sapk,
   {{0x660901e8,0x443fafa0,0xd7de00b6,0xceb8548b}},	//   _şeke, _dcu_, _मरिच, ynę_,
   {{0xb87b00ef,0x67241711,0xe5a611d9,0x7e630383}},	//   _thíc, msij, _диги, _nanp,
   {{0x6724afa1,0xd1300037,0x052700ae,0x69d80537}},	//   lsij, رمة_, _морк_, _øved,
   {{0x661caba0,0x7e63043e,0x228b0120,0x656e01ec}},	//   _herk, _aanp, _søkt_, _irbh,
   {{0x67245ecd,0x661cafa2,0x66d00084,0x236d23bc}},	//   nsij, _kerk, säku, _grej_,
   {{0x3f420102,0x63a25cd6,0x67245460,0xcee70284}},	//   rðu_, mzon, isij, одње_,
   {{0x64bc01b3,0x628820bb,0x80c700aa,0x672403a9}},	//   nčio, _iodo, ावशे, hsij,
   {{0xceb840f0,0x06de0081,0x661c32a7,0x22bf007f}},	//   snę_, _ভূমি, _lerk, ałkę_,
   {{0x63a2afa3,0x67240335,0x69de01e9,0x64401881}},	//   nzon, jsij, _azpe, _mcmi,
   {{0x6288063f,0x672400e7,0x63a20036,0x7e630032}},	//   _jodo, dsij, izon, _ganp,
   {{0x6288a460,0x2d8301c5,0x48ab11fb,0x9850071d}},	//   _modo, øjet_, атам_, _ağız_,
   {{0x6288afa4,0x7e638570,0x63a20381,0x00000000}},	//   _lodo, _zanp, kzon, --,
   {{0x661c1084,0x63a20ab2,0xe71900e3,0x656e03ea}},	// [cf50] _berk, jzon, صيات_, _arbh,
   {{0x62880029,0x63a200a5,0x7bdf6117,0x661cafa5}},	//   _nodo, dzon, _izqu, _cerk,
   {{0x661cafa6,0x00000000,0x00000000,0x00000000}},	//   _derk, --, --, --,
   {{0x236dafa7,0xb4d55339,0x68010139,0x1835006e}},	//   _prej_, हते_, _dájó, _צאָל_,
   {{0x64bc2461,0x66d00212,0x443f0090,0x987a0266}},	//   mčil, täkt, _vcu_, _הארט,
   {{0x661c61fc,0xa7fb01ff,0x00000000,0x00000000}},	//   _gerk, _kaño, --, --,
   {{0x62889d73,0x7e630c56,0x443f7680,0x45d4084c}},	//   _dodo, _ranp, _tcu_, _жорс,
   {{0x64bc134c,0x63a2219a,0xa7fb0143,0x66d00212}},	//   nčil, bzon, _maño, säkt,
   {{0x63a20067,0x7e63afa8,0x62883572,0x201f0167}},	//   czon, _panp, _fodo, raui_,
   {{0x6459afa9,0x35d00336,0x661c01ff,0x7e6300bd}},	//   lewi, _तुड़, _xerk, _qanp,
   {{0x27f90072,0xfbc90327,0xe2c807e8,0x200600eb}},	//   _ogsn_, _עת_, _بولو_, _ffoi_,
   {{0x6283042d,0x645900f0,0x7c3d05e8,0x62881b05}},	//   ljno, newi, ggsr, _zodo,
   {{0xee2e2a6a,0x7e630f8b,0x64bc1c74,0x76930233}},	//   _пн_, _tanp, dčil, _kıyı,
   {{0xa7fb0890,0xf8bf0af0,0x64bc0138,0x2d8302b6}},	//   _baño, _ajé_, yčio, øjes_,
   {{0x63a26c5f,0xa7fb05e6,0xe7f80971,0x64590158}},	//   zzon, _caño, ंखला_, kewi,
   {{0x6e21afaa,0xa7fb1d2b,0x661cafab,0x6724032c}},	//   lalb, _daño, _serk, tsij,
   {{0x661c0b19,0x64593efb,0xcce50076,0x00000000}},	// [cf60] _perk, dewi, _تسوي, --,
   {{0x67244ab9,0xddc10018,0x66d00084,0x6e2129a6}},	//   rsij, lelő, väks, nalb,
   {{0x6724afac,0x6288afad,0xa7fb03be,0xf9fb00d7}},	//   ssij, _rodo, _gaño, _להימ,
   {{0x661c3b6c,0x645902d7,0x6288afae,0x63a2afaf}},	//   _werk, gewi, _sodo, tzon,
   {{0x661c03b4,0xd7f200e3,0x6e21013f,0x6724003d}},	//   _terk, _سكس_, kalb, qsij,
   {{0x63a2afb0,0x6288008a,0x6e210141,0x644b0537}},	//   rzon, _qodo, jalb, afgi,
   {{0x63a2297d,0x66d00084,0x81d40081,0x645934d0}},	//   szon, säks, সেন_, bewi,
   {{0x25e100a5,0x63a2afb1,0x55bb00ca,0x62880034}},	//   _करती_, pzon, _המלו, _wodo,
   {{0x62880b0b,0x201dafb2,0xa87b006e,0x14c90473}},	//   _todo, _dewi_, מאקר, िकरण,
   {{0x6e210556,0xb9210294,0x81cb0033,0x9e660037}},	//   galb, gasị_, রেই_, ساخن,
   {{0x7bd61114,0x00000000,0x00000000,0x00000000}},	//   _ayyu, --, --, --,
   {{0x2d821386,0xd19700a1,0xddc10103,0xa7fb0072}},	//   ćke_, _מכבי_, gelő, _raño,
   {{0x6e21afb3,0x2d83052f,0xb9210174,0xa0c90037}},	//   balb, øjer_, basị_, _بذلك_,
   {{0xb87b00ef,0x2ec70635,0x64590034,0xa7fb0328}},	//   _chín, रकृत, zewi, _paño,
   {{0xa9c4013f,0x321e0be5,0xb87b0503,0xb8950103}},	//   естк, _mety_, _dhín, وارڈ,
   {{0x64bc1cb4,0x321eafb4,0x50cc0096,0xb87b0139}},	//   učil, _lety_, ाविष, _ehín,
   {{0xb9040e72,0x7c2dafb5,0xc3110081,0x6d4810a5}},	// [cf70] _पी_, _idar, _হয়নি_, ltda,
   {{0x659500d3,0x00000000,0x00000000,0x00000000}},	//   мазу, --, --, --,
   {{0x64598d5f,0x64bc0087,0x6d48afb6,0x6605042c}},	//   tewi, mčij, ntda, rchk,
   {{0x6605afb7,0xc4350504,0xfbe100b6,0x69c5063d}},	//   schk, بکست, _नराम, _ixhe,
   {{0x3869afb8,0x321eafb9,0x38790027,0x62650095}},	//   mdar_, _bety_, _insr_, двла,
   {{0x3869afba,0x66d00149,0x7af7003d,0x6283023e}},	//   ldar_, säkr, _jixt, ujno,
   {{0x7c2d5956,0x776d03be,0x6e217377,0x7af73e3f}},	//   _odar, lvax, valb, _mixt,
   {{0x3869afbb,0x7c2dafbc,0xb9210129,0xb87b0076}},	//   ndar_, _ndar, wasị_, _mhío,
   {{0x64bc0480,0x533422f6,0x3869a6c2,0xddc101f9}},	//   kčij, _петт, idar_, velő,
   {{0x7c2dafbd,0xdd1b0146,0x321e084e,0x7af7003d}},	//   _adar, _váže, _gety_, _nixt,
   {{0x442dafbe,0x6d48066a,0x6da52b49,0x6e211a04}},	//   _kde_, gtda, фина, ralb,
   {{0x442d030b,0xb87b0037,0x7c3a0138,0x7c2d01ff}},	//   _jde_, _shín, ėtro, _cdar,
   {{0x3869afbf,0x7c2d02ad,0x6e210a53,0xc05807bf}},	//   ddar_, _ddar, palb, _хіх_,
   {{0xb87b00e3,0x7c2d7506,0x7af7afc0,0xddc10103}},	//   _bhío, _edar, _cixt, selő,
   {{0x442d3ad5,0xa3d404dd,0xb87bafc1,0xa967881d}},	//   _ode_, _सुन_, _chío, мира_,
   {{0x442dafc2,0xb87b00e3,0x7f4905fe,0x78af0154}},	//   _nde_, _dhío, oteq, _cmcv,
   {{0x7f49afc3,0x64bc6ed0,0x4b2608a1,0xb87b0023}},	// [cf80] nteq, učim, _ўмов, _thín,
   {{0x7c2d1fe8,0x442dafc4,0x64b808e7,0xb87b0037}},	//   _zdar, _ade_, ेक्श, _fhío,
   {{0x68fe00f9,0x321e0350,0x69c00233,0xb87b033c}},	//   _uupd, _rety_, ğmes, _ghío,
   {{0x69c001e8,0x321e5141,0x00000000,0x00000000}},	//   şmes, _sety_, --, --,
   {{0x442dafc5,0xb87b0076,0xf4870281,0x00000000}},	//   _dde_, _mhíl, بالی, --,
   {{0x442dafc6,0x6d48013c,0x81c90033,0xe29705b8}},	//   _ede_, ytda, োধন_, мач_,
   {{0x6d48afc7,0x321e05cc,0x64bc5e05,0x00000000}},	//   xtda, _vety_, nčik, --,
   {{0x442d1386,0xd0100037,0x00000000,0x00000000}},	//   _gde_, دلة_, --, --,
   {{0xc2461009,0x2ef4387c,0x321e00d8,0x00000000}},	//   _онак, нзир, _tety_, --,
   {{0x442d000d,0x248604a3,0xb34700bd,0x3869afc8}},	//   _zde_, ljom_, _duħħ, zdar_,
   {{0x2d980038,0x3869afc9,0x600a0686,0x442d02b6}},	//   áre_, ydar_, _днем_, _yde_,
   {{0x6fc90789,0x442d0332,0x6d48afca,0x67360891}},	//   _हुकू, _xde_, rtda, kryj,
   {{0xfc3f00e3,0x6d48afcb,0x2a7a0167,0x38690572}},	//   rgí_, stda, _bnpb_, vdar_,
   {{0x781707d5,0x629827a9,0xb87b0076,0xda7b036c}},	//   तर्क_, nkvo, _phío, цям_,
   {{0xa2b134d8,0x480c0174,0x64bc033b,0x59f800d3}},	//   _अगस्, _ọzịz, rčij, деря_,
   {{0xdd8e0068,0x81cb0081,0x00000000,0x00000000}},	//   _موڈ_, রেক_, --, --,
   {{0x3869afcc,0x7af7003d,0x60c20239,0x442d0141}},	// [cf90] rdar_, _tixt, _mjom, _rde_,
   {{0x76d50080,0x69c501bb,0xb87b00e3,0xd6db04a1}},	//   رياض, _txhe, _thío, іта_,
   {{0x38692253,0x00000000,0x00000000,0x00000000}},	//   pdar_, --, --, --,
   {{0x2aad0106,0xb69b00ae,0x60c2afcd,0x64c909c4}},	//   džbi_, _atât, _njom, िकेश,
   {{0x68edafce,0x442dafcf,0xf1b8009e,0x00000000}},	//   mmad, _vde_, _reġa_, --,
   {{0x2901afd0,0x21690243,0x246600c6,0x91e51165}},	//   _kuha_, зики_, _rūmų_, ноле,
   {{0x2901afd1,0x60c20090,0x68edafd2,0x2419013f}},	//   _juha_, _bjom, omad, _новы_,
   {{0x442dafd3,0x2901afd4,0x68edafd5,0x6f654460}},	//   _ude_, _muha_, nmad, евиз,
   {{0xe820007d,0x68edafd6,0x29012783,0x3f990146}},	//   बरता_, imad, _luha_, ásu_,
   {{0x0d850c63,0x68edafd7,0x249f009c,0x6298042c}},	//   елон, hmad, _hlum_, ckvo,
   {{0x290108d3,0x68edafd8,0xa6e2003e,0x248d007e}},	//   _nuha_, kmad, íðin, _koem_,
   {{0x859a00a1,0x8027001c,0xa3d402d5,0xb87b0503}},	//   פשרו, _آرام, _सुड_, _bhím,
   {{0x1dcf1006,0x68ed0188,0xf3f9078e,0x00000000}},	//   _सुरत, dmad, _baţi_, --,
   {{0x249f6b0f,0x60dbafd9,0x68ed09a1,0xb87b033c}},	//   _llum_, llum, emad, _dhím,
   {{0xf3f900ae,0x249f173c,0x00000000,0x00000000}},	//   _daţi_, _olum_, --, --,
   {{0x290111b9,0x68ed0694,0x248d159f,0x60db0270}},	//   _duha_, gmad, _noem_, nlum,
   {{0x7c260201,0xace9001c,0x363602d1,0x17c70120}},	// [cfa0] makr, _ترول_, فراس, егти_,
   {{0xe5a601c9,0x7c26afda,0x249fafdb,0x60db4dac}},	//   низи, lakr, _alum_, hlum,
   {{0x60db29cb,0x249fafdc,0x290102a4,0x7d0b00ae}},	//   klum, _blum_, _guha_, _însă,
   {{0x64a311c0,0x248d0036,0x661b0d62,0x240700b8}},	//   лаха, _coem_, _đuke, енци_,
   {{0x7cfe0029,0xe3b20867,0x248d02ac,0x9aa90d7f}},	//   _vīri, درا_, _doem_, _ردیف_,
   {{0x7d0d0783,0x7c26058f,0x2ca000eb,0x00000000}},	//   _časn, hakr, _llid_, --,
   {{0x55e3282a,0x1dcf0455,0x64a63f4f,0x2ca0007a}},	//   _борб, _सुलत, _зава, _olid_,
   {{0x60dbafdd,0xa3cb0251,0x62980138,0x7c26afde}},	//   glum, _रुक_, skvo, jakr,
   {{0x59d202e8,0xb4cc0ded,0x64a31486,0x22b60034}},	//   _दुसर, रकी_, _сата, ałka_,
   {{0x44267ddd,0xddd8030b,0x2ef80088,0xe35700ca}},	//   lao_, _zavř, örf_, _אשמח_,
   {{0x5fe202e8,0x01362c66,0xb63700c1,0xa3d400b7}},	//   _परवल, _سعاد, ערטס_, _सुत_,
   {{0x4426afdf,0x2fc60d7d,0x64428f30,0x29010103}},	//   nao_, _txog_, ngoi, _ruha_,
   {{0x78a45bcb,0x29018979,0x7ac717e9,0xc3140033}},	//   dhiv, _suha_, есве, _সিডি_,
   {{0x59d2009f,0x81cb0033,0x25e10ff9,0x2901afe0}},	//   _दुहर, রেও_, _करली_, _puha_,
   {{0x68edafe1,0x7cfe00c6,0x2ca00ac9,0xd5d0023a}},	//   tmad, _būre, _flid_, _तुलज,
   {{0x442603ce,0x7c260167,0x68edafe2,0x58d40dfb}},	//   jao_, cakr, umad, гост,
   {{0x442600e9,0x6a151778,0x3d0609d0,0x248d0a88}},	// [cfb0] dao_, _импу, _संडे_, _roem_,
   {{0x249f01b9,0xa3d4009f,0xe8e00023,0x64c902d5}},	//   _slum_, _सुध_, _đục_, िक्श,
   {{0xceb313b6,0x3ce9006c,0x4426afe3,0x68ed9c5c}},	//   ניע_, _khav_, fao_, pmad,
   {{0x442603ce,0x78a4afe4,0xf4843340,0x00000000}},	//   gao_, chiv, лучн, --,
   {{0x69e30542,0x6f029143,0xa3cbafe5,0x290e0216}},	//   šteć, _nuoc, _रुख_, _çfar_,
   {{0xc61b00c7,0x6d5840df,0x1db200b6,0x5eff0442}},	//   _ঢাকা_, _opva, ुपात, रदस्_,
   {{0x44261eff,0x7d0d50a5,0x6fc90789,0x60dbafe6}},	//   bao_, _časo, _हुजू, tlum,
   {{0x44265a07,0x249f4bce,0x397c0089,0x26d30042}},	//   cao_, _ulum_, לטונ, loxo_,
   {{0xc62400c7,0x6f02008f,0x60db06e1,0x7082007b}},	//   _পাতা_, _cuoc, rlum, ргыз,
   {{0xf1a73574,0x60dbafe7,0x82370602,0xe3b00037}},	//   _прен, slum, _سرطا, _طرق_,
   {{0xdca60e3f,0x4df42082,0x7c26afe8,0x60db564a}},	//   вани, ляют, takr, plum,
   {{0x224914f3,0x7d0415d7,0x3ce90197,0x6f02008f}},	//   đaku_, _čist, _chav_, _fuoc,
   {{0x26c700e9,0xab632570,0x00000000,0x00000000}},	//   čnoj_, авял, --, --,
   {{0xd02600c7,0xa7fb01ff,0x00000000,0x00000000}},	//   _যায়_, _gañi, --, --,
   {{0x4426afe9,0x26d3266c,0xada50231,0x2d8a052f}},	//   yao_, doxo_, _шакл, øbet_,
   {{0x2aad0dd9,0x6e23afea,0x4426afeb,0x00000000}},	//   džbu_, _henb, xao_, --,
   {{0x442600e9,0x6e230c56,0x7d031f53,0x26d30072}},	// [cfc0] vao_, _kenb, _huns, foxo_,
   {{0x78a4afec,0x44263e26,0xdebb01c2,0xb69b020a}},	//   shiv, wao_, ttuƙ, _stâr,
   {{0x6e23afed,0x7d031dd1,0xa2b70179,0x9586008f}},	//   _menb, _juns, ्चन्, ълже,
   {{0x7d030ab1,0xb4be5339,0xb4dc1e9f,0x7d0d00e7}},	//   _muns, ीके_, डते_, _časl,
   {{0x442600e9,0x7c240682,0x9343160b,0x7d03afee}},	//   rao_, _meir, инце, _luns,
   {{0x442603ce,0xe8e00028,0x386001b5,0x395a0167}},	//   sao_, _độc_, leir_, _kpps_,
   {{0x442600e9,0x6f022a3d,0x3cfd009f,0x7d035119}},	//   pao_, _suoc, _रंगे_, _nuns,
   {{0xe0cf00e3,0xf9930327,0x7c24afef,0x3ea50364}},	//   يزي_, שרה_, _neir, ehlt_,
   {{0xf8b30054,0x7d03009c,0x78a300ae,0x4424aff0}},	//   ישה_, _auns, _înve, _iem_,
   {{0x7d03aff1,0x15e613cc,0x3860018f,0x60cd007e}},	//   _buns, _करार_, heir_, čama,
   {{0x7c24aff2,0x6e238419,0x4424aff3,0x3ce901fa}},	//   _beir, _denb, _kem_, _phav_,
   {{0x80e000c7,0x4424aff4,0x6e23aff5,0x7c2446e8}},	//   _পূর্, _jem_, _eenb, _ceir,
   {{0x7c24aff6,0x4424aff7,0xd00773d1,0x7d030167}},	//   _deir, _mem_, _рече_, _euns,
   {{0x4424aff8,0x6e23052f,0x26d3019f,0x3cfd074c}},	//   _lem_, _genb, xoxo_, _रूके_,
   {{0x81d400c7,0x7c24aff9,0x3ce9023e,0x69d80856}},	//   সের_, _feir, _thav_, _øvel,
   {{0x442407d9,0xb4cc033a,0xb4be033a,0x6e2302a7}},	//   _nem_, रको_, ीको_, _zenb,
   {{0xf7731e53,0x64bc013f,0xfc3f0072,0x58840138}},	// [cfd0] جاز_, nčiu, chía_, шыра,
   {{0xed4d07d9,0x64bc013f,0xceb800a5,0xd6280291}},	//   _بھی_, ičiu, nię_, кође_,
   {{0x442400c9,0xa9c43df8,0x95050103,0xa979006e}},	//   _bem_, _всяк, اہرے_, _װאָכ,
   {{0x4424affa,0x6ba8026a,0x2aad0146,0x7c240042}},	//   _cem_, _örgü, ržbu_, _xeir,
   {{0x44243e92,0xe7843898,0xd7f800d3,0x00000000}},	//   _dem_, _куро, _аур_, --,
   {{0xdce400b6,0x672d7a54,0x98b800e8,0x00000000}},	//   _brně, msaj, murā_, --,
   {{0x672d02c3,0x64bc00c6,0x80cc0033,0x00000000}},	//   lsaj, ečiu, াতন্, --,
   {{0x6e23affb,0x657a0308,0x7d0300c2,0x2fc00c5c}},	//   _senb, _átha, _runs, _žiga_,
   {{0x672d0f71,0x68fdaffc,0x7c245986,0x2bd30eeb}},	//   nsaj, _misd, _reir, _धुला,
   {{0x44240075,0x7c240514,0x764593d3,0x7d03affd}},	//   _zem_, _seir, nghy, _puns,
   {{0x4424affe,0x7c24afff,0x2913022e,0xd00e262f}},	//   _yem_, _peir, _ntxa_, غلی_,
   {{0x4424011b,0x6e2355d3,0x672db000,0xf1a42565}},	//   _xem_, _wenb, ksaj, _трун,
   {{0x7d0301bf,0xceb800a5,0x6e28244c,0xef0e0204}},	//   _wuns, bię_, badb, _ым_,
   {{0x7d030ffe,0x68fd01b9,0xd9463715,0xdc14013c}},	//   _tuns, _aisd, леги, rğız,
   {{0x7c249436,0xa7fb0072,0x68fd1cab,0x38606d04}},	//   _teir, _mañu, _bisd, teir_,
   {{0x6d413dd2,0x1c46153d,0x18670859,0x661b03d6}},	//   mula, _сним, ласи_, _đuka,
   {{0xe737185c,0xe7c40081,0x68fd83a9,0xeb9a387c}},	// [cfe0] лет_, ্ধ্য, _disd, _чип_,
   {{0x4424b001,0x644961f8,0xda6648c7,0x68fd3d0c}},	//   _sem_, _acei, _свои, _eisd,
   {{0x4424006c,0x6d41b002,0x67230106,0x395a0231}},	//   _pem_, nula, ćnja, _upps_,
   {{0x291840e2,0x64bc00e9,0x672d003d,0x7cfe129d}},	//   mpra_, jčit, bsaj, _jūra,
   {{0x4424b003,0x6d418649,0xa7fb01ff,0x7e61b004}},	//   _vem_, hula, _bañu, kelp,
   {{0x6d416706,0x6ffb0029,0xa7fb037a,0x4424b005}},	//   kula, _mācī, _cañu, _wem_,
   {{0x4424b006,0xa3d4074c,0x249d023e,0x6d41063d}},	//   _tem_, _सुर_, bkwm_, jula,
   {{0x644900e3,0xa4f809e5,0x7afeb007,0x69de00dc}},	//   _gcei, _شکار_, _lipt, _mype,
   {{0x69d60251,0x6e28b008,0x29180052,0x7413001c}},	//   _मुसी, tadb, hpra_, _طولا,
   {{0x6e981510,0x6d41b009,0x7e61b00a,0x35d900bc}},	//   твор_, fula, gelp, _बुड़,
   {{0x6d41b00b,0xceb800a5,0x6e288979,0xac1927d4}},	//   gula, rię_, radb, кону_,
   {{0xbd8700cd,0x6e2800d4,0x61e5042c,0x459b006e}},	//   چنین_, sadb, ühle, גסטע,
   {{0x7e610f6f,0x68fd6639,0x6d41b00c,0xceb80034}},	//   belp, _risd, aula, pię_,
   {{0x7afe64ea,0x6d41b00d,0xedb50018,0x69de03a8}},	//   _cipt, bula, اجیک, _bype,
   {{0x19580077,0x35d980d0,0x69deb00e,0xc27b006e}},	//   лары_, _बुढ़, _cype, ערלי,
   {{0xa815171b,0x8afb00a7,0x69de0120,0x6d4f044c}},	//   рдаш, fiəç, _dype, ăcat,
   {{0x68fd8121,0xd7590190,0x00000000,0x00000000}},	// [cff0] _visd, ضلات_, --, --,
   {{0x644900e3,0xba550b1b,0xdcfb00c6,0x00000000}},	//   _scei, _твој, tytė, --,
   {{0x68fdb00f,0x672d294b,0x66d0007b,0x00000000}},	//   _tisd, ssaj, näky, --,
   {{0xc8676f63,0x48670465,0xddc3837b,0xb4c1007a}},	//   _стои, _съоб, _janš, ुवे_,
   {{0x6d41b010,0xa7fb0314,0x64bc033b,0xddc3b011}},	//   zula, _pañu, včit, _manš,
   {{0x6d41b012,0x82370b9f,0x7bdf0113,0x7afe015e}},	//   yula, ارشا, _myqu, _xipt,
   {{0x7e610381,0x659400ae,0x21a50120,0x6d4162f6}},	//   velp, _лару, рийм, xula,
   {{0x27e600a5,0x6d41b013,0x64bc1cb4,0x64490072}},	//   żone_, vula, učit, _ucei,
   {{0x2d98038c,0x6d410479,0x200db014,0x64bc00d4}},	//   øren_, wula, rcei_, rčit,
   {{0xcdf50084,0x00000000,0x00000000,0x00000000}},	//   ичны, --, --, --,
   {{0x62819bf9,0x7afe03a9,0x6d410270,0x00000000}},	//   _inlo, _ript, uula, --,
   {{0x6d410233,0xeb9a7a2f,0x7afe0e94,0x7fb6001c}},	//   rula, вим_, _sipt, اهیر_,
   {{0x6d41b015,0xe0d003ef,0xcee80281,0xddc305db}},	//   sula, _عزم_, ضرین_, _danš,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfce61a77,0x7bcd8420,0x61030103,0x48b6534b}},	//   _коко, _exau, _főle, ащат,
   {{0x98b800ae,0x69de0094,0x05d900b6,0xb4c100bc}},	//   dură_, _vype, _बुधब, ुवो_,

   {{0x6281b016,0x7afeb017,0x69de0034,0x98a311d9}},	// [d000] _onlo, _tipt, _wype, ците,
   {{0x611101d3,0xe61729b7,0x291802c3,0x00000000}},	//   _zāle, иду_, ppra_, --,
   {{0x0566b018,0x98b800ae,0x05d9034c,0x00000000}},	//   рвен, gură_, _बुदब, --,
   {{0xed5600c1,0x261606eb,0x00000000,0x00000000}},	//   יבער_, _प्री_, --, --,
   {{0xe8e20096,0x78a300ae,0x00000000,0x00000000}},	//   पतीच, _înva, --, --,
   {{0x387200f2,0x00000000,0x00000000,0x00000000}},	//   ldyr_, --, --, --,
   {{0xc44800cd,0xe297016c,0x98b800ae,0x5066004b}},	//   _میان_, рај_, cură_, атпа,
   {{0xc05a0120,0xea0000de,0x6281237a,0x3872093e}},	//   тік_, _giấu_, _enlo, ndyr_,
   {{0x66090b88,0xdb240113,0x00000000,0x00000000}},	//   _şeki, _èsèn, --, --,
   {{0x628101ec,0x00000000,0x00000000,0x00000000}},	//   _gnlo, --, --, --,
   {{0xa0a602fd,0x69d6009d,0xd00f085a,0x00000000}},	//   _кажд, _मुली, _мф_, --,
   {{0xd00f2761,0x22990139,0x00000000,0x00000000}},	//   _قلم_, _dèku_, --, --,
   {{0x7c360178,0xdfd20286,0xb87b0503,0x00000000}},	//   _ddyr, _بيش_, _mhít, --,
   {{0x799c0150,0x635a0a84,0x8f9b0327,0x290701dc}},	//   fyrw, mānā, _בידי, _énak_,
   {{0x610301f9,0x9e6500d1,0xcfd80a43,0x00000000}},	//   _tőle, _دانن, দেশন, --,
   {{0x7bcd01bb,0x5dfb00ca,0x7bc80233,0x00000000}},	//   _txau, _בפונ, ğdur, --,
   {{0x28f802fd,0x7d0d033b,0x17ad0033,0x7bdf11bc}},	// [d010] реть_, _časi, _কুড়ি, _uyqu,
   {{0x98b8002d,0xc7c4004d,0xd0b200a7,0x6b9d00f0}},	//   tură_, істи, rşən, mysg,
   {{0xa2b706ae,0x7cff013f,0xb87b0076,0x00000000}},	//   ्चस्, _jūro, _bhít, --,
   {{0xdd39020a,0xe43c02c6,0xb87b033c,0x00000000}},	//   lăţe, bříč, _chít, --,
   {{0xd7fb0831,0x94740867,0xb87b0037,0x98b800ae}},	//   _јун_, تدلا, _dhít, sură_,
   {{0xdd39044c,0xd51705bc,0x00000000,0x00000000}},	//   năţe, _نظرب, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c7025b,0xe4a719e8,0x7ea4009c,0x00000000}},	//   čnou_, _трго, _ròpa, --,
   {{0xa9e4030b,0x00000000,0x00000000,0x00000000}},	//   _गर्छ_, --, --, --,
   {{0x26e5143d,0x6b9d0150,0x00000000,0x00000000}},	//   _कठोर_, dysg, --, --,
   {{0x387203a8,0x00000000,0x00000000,0x00000000}},	//   ydyr_, --, --, --,
   {{0x6b9d0150,0x31ba00ca,0xb87b0503,0x00000000}},	//   fysg, _גזענ, _mhís, --,
   {{0x61e1b019,0x6abc003e,0xbf67015a,0x201f4339}},	//   _hyll, tirf, _خداو, mbui_,
   {{0x61e102fd,0x6f1bb01a,0x00000000,0x00000000}},	//   _kyll, mpuc, --, --,
   {{0x61e1052f,0x395e05fe,0x09e61756,0x6abc99c6}},	//   _jyll, ïts_, совн, rirf,
   {{0xa9280244,0x61e1348f,0x09c70033,0x201f3efe}},	//   _nižš, _myll, _এরশা, nbui_,
   {{0x57ea97e4,0x387213ea,0x6abc0ac9,0x68ef01ee}},	// [d020] удам_, rdyr_, pirf, _dhcd,
   {{0x645b61de,0xb87b0032,0x387200f2,0x799c0169}},	//   _abui, _akíd, sdyr_, pyrw,
   {{0xd70700d3,0x00000000,0x00000000,0x00000000}},	//   инӂе_, --, --, --,
   {{0x04460ba3,0x645b01b9,0xe43c02c6,0xb87b00da}},	//   седн, _cbui, příč, _dhís,
   {{0xe29aae6d,0x61e1037a,0x645b01b9,0x68e4306f}},	//   лад_, _ayll, _dbui, mlid,
   {{0x2902b01b,0x7d1a0146,0x61e14f34,0xb87b00da}},	//   _hika_, ypts, _byll, _fhís,
   {{0x2902b01c,0x61e10150,0xa6c701f3,0x68e400bc}},	//   _kika_, _cyll, _اوّل_, olid,
   {{0x290248d4,0x26da026e,0x50665961,0x3f14001f}},	//   _jika_, lopo_, стка, одис,
   {{0x2902b01d,0x68e4b01e,0x7e2a224a,0xa0670284}},	//   _mika_, ilid, ліна_, сања_,
   {{0x61e124a3,0x2902b01f,0x69c0026a,0xdc250033}},	//   _fyll, _lika_, şmey, _ভাইস_,
   {{0x61e1ada6,0xe0d600a9,0x68e4b020,0xc05a0836}},	//   _gyll, _людь, klid, _біл_,
   {{0xb5fb00c1,0x2fc90117,0xdb0a0094,0x26da03a9}},	//   טליכ, _žage_, žným, hopo_,
   {{0x26da1b95,0xdd3900d3,0x5f94078b,0x9e340832}},	//   kopo_, tăţe, _филт, _делч,
   {{0x2902b021,0x0db90068,0xcef60859,0xbd6a00ae}},	//   _aika_, ائیں_, _учењ, _брие_,
   {{0x2902b022,0x27e200f9,0xc98475a4,0x3f960134}},	//   _bika_, _aykn_, пути, ̣dụ_,
   {{0x25ef143d,0x2bda0976,0x3ebeb023,0x2902006d}},	//   _अरबी_, _युवा, litt_, _cika_,
   {{0x290200ac,0x7cff00d9,0x2d9eb024,0x7c2f063d}},	// [d030] _dika_, _jūrm, lyte_, macr,
   {{0x3ebeb025,0x683f0139,0x7d0a0bb1,0x2ca900d4}},	//   nitt_, _bàdà, _kufs, _hlad_,
   {{0x2902b026,0xb87b0037,0x2ca951c6,0x20020117}},	//   _fika_, _dhír, _klad_, žkih_,
   {{0x2902b027,0x3ebeb028,0x27e60034,0x20060023}},	//   _gika_, hitt_, żona_, _ngoi_,
   {{0x6eef052f,0xb87b0037,0x05d90bd9,0x78bf0216}},	//   løbe, _fhír, _बुरब, miqv,
   {{0x61e1b029,0x78ad0407,0x236d0087,0x26dab02a}},	//   _pyll, lhav, _vsej_, copo_,
   {{0xd9f90067,0xa2d20080,0x683f0065,0x6a9c006e}},	//   ंधित_, بيوت, _gàdà, רשונ,
   {{0x78ad0021,0x7f590396,0x6009426c,0xa3d40ff9}},	//   nhav, ајот_, шним_, _सुक_,
   {{0xfa0100c7,0x7d0a02e2,0x442fb02b,0x3ebe6448}},	//   ্রিল_, _aufs, mag_, fitt_,
   {{0x3ebe004d,0x61e1b02c,0x20060062,0x6eef0537}},	//   gitt_, _tyll, _egoi_, købe,
   {{0x2ca901d0,0xf1a70e2d,0x644b028d,0xed592a59}},	//   _blad_, _уран, oggi, шон_,
   {{0x644bb02d,0x442fb02e,0x2299b02f,0x26da0051}},	//   nggi, nag_, _tèks_, zopo_,
   {{0xee2eb030,0x2902b031,0x26da0051,0x7cd200d9}},	//   _он_, _rika_, yopo_, vārd,
   {{0x60c91af1,0x6da517e9,0x2902b032,0xe8e00019}},	//   lnem, _мила, _sika_, _đốc_,
   {{0x2902b033,0x442f02c9,0x2ca902b6,0x6f03063d}},	//   _pika_, kag_, _flad_, _iinc,
   {{0x60c9b034,0x02b60c16,0x6f03b035,0x442fa37f}},	//   nnem, _अग्न, _hinc, jag_,
   {{0x60c90257,0x2902b036,0x26da203f,0x68e4b037}},	// [d040] inem, _vika_, topo_, rlid,
   {{0x29020256,0xc966737e,0x41c9009d,0x60c90f1c}},	//   _wika_, _двой, िपास, hnem,
   {{0x29020029,0x7d041c24,0x78ad4d41,0x26dab038}},	//   _tika_, _kiis, bhav, ropo_,
   {{0x78ad00d8,0x60c97a9e,0x26dab039,0x442f008c}},	//   chav, jnem, sopo_, gag_,
   {{0xa3d40336,0x7d04008a,0x60db0335,0x26da0113}},	//   _सुख_, _miis, doum, popo_,
   {{0x6f030068,0x644b008f,0x7d04b03a,0x7c2f0451}},	//   _ninc, aggi, _liis, zacr,
   {{0x64a621fd,0x403458c0,0x6e2a4892,0x3ebe4075}},	//   _дава, пейс, _refb, vitt_,
   {{0x60c9b03b,0x7d040d80,0x442f008a,0x22400511}},	//   gnem, _niis, cag_, şik_,
   {{0x6f03b03c,0x61300065,0x4911007a,0x7bc020df}},	//   _binc, _bólá, _दूनो_, úmul,
   {{0x7d040167,0x6f03b03d,0x2ca90503,0x2d9e00c6}},	//   _aiis, _cinc, _slad_, tyte_,
   {{0x3ebe05c4,0x867b0341,0x6f03a202,0x7d0400c2}},	//   ritt_, בריו, _dinc, _biis,
   {{0x7d0d0074,0x6b8200d9,0x7d04008a,0x60db0072}},	//   _čast, _šoga, _ciis, coum,
   {{0xfe6f00cd,0x7c2f5d08,0x6d41b03e,0x2ca9442c}},	//   ردی_, racr, arla, _vlad_,
   {{0x7c2f0996,0x2ca90150,0x442faa07,0x60c0b03f}},	//   sacr, _wlad_, zag_, limm,
   {{0x442fb040,0x28c72a24,0x644b2e6f,0x78adb041}},	//   yag_, रचलि, yggi, thav,
   {{0x6d48b042,0xa3aa00a5,0x7d040009,0x6f03b043}},	//   muda, खना_, _giis, _zinc,
   {{0x6d48b044,0x78ad2b31,0x442fb045,0x6f03b046}},	// [d050] luda, rhav, vag_, _yinc,
   {{0x60c059ce,0x442f4c9c,0xc98710de,0x7c2d4f4e}},	//   himm, wag_, _думи, _hear,
   {{0x442fb047,0x6d48b048,0x7c2db049,0xd6d816dd}},	//   tag_, nuda, _kear, іту_,
   {{0xb4d500a5,0x7d04008a,0x7c2d022b,0x60db0072}},	//   सके_, _xiis, _jear, xoum,
   {{0x442f73dc,0xdfc60080,0x6d48006d,0x7c2db04a}},	//   rag_, _أي_, huda, _mear,
   {{0x3869184b,0x7ead0181,0x6d48b04b,0x442fb04c}},	//   lear_, _kúpe, kuda, sag_,
   {{0x6d484684,0x442f13b5,0x6f03b04d,0x60c9b04e}},	//   juda, pag_, _rinc, tnem,
   {{0x3869b04f,0x6f03b050,0x26c19754,0x7c2d4f4e}},	//   near_, _sinc, liho_, _near,
   {{0x60c9b051,0xea0000de,0x7d04872a,0xddc100b6}},	//   rnem, _phẫu_, _riis, telů,
   {{0x386909f7,0x0ea902fd,0x7d046765,0x60c9b052}},	//   hear_, ской_, _siis, snem,
   {{0x442db053,0x7d0432d2,0x7c2d5370,0xfce65e66}},	//   _kee_, _piis, _bear, зоно,
   {{0x7c2d0514,0x442db054,0x6d41b055,0x60c001c2}},	//   _cear, _jee_, rrla, cimm,
   {{0x442db056,0x7c2d0514,0xdd8e1e49,0x7d04198c}},	//   _mee_, _dear, نوی_, _viis,
   {{0x7c2d009c,0x442d00ca,0xfaa604d9,0x7d04041c}},	//   _eear, _lee_, чаго, _wiis,
   {{0x2bdc1133,0xea000028,0x386900e3,0xdca61cda}},	//   _गुरू_, _khẩu_, fear_, _наки,
   {{0x7c2d003b,0x442d04ee,0x3869b057,0xb4d53b08}},	//   _gear, _nee_, gear_, सको_,
   {{0x237f022e,0x78a4b058,0xe73a00d3,0xed160103}},	// [d060] _nruj_, rkiv, сез_, _وہیں_,
   {{0x6b7b00f5,0x78a420d1,0x60c001bf,0x442d2886}},	//   _פרינ, skiv, zimm, _aee_,
   {{0x7c2d3c37,0x6abe1885,0x6a9b00ca,0x255702c6}},	//   _year, _impf, _השינ, vělá_,
   {{0xb4d6007d,0x442db059,0x3869200e,0x6abe0113}},	//   हवे_, _cee_, cear_, _hmpf,
   {{0x442db05a,0x1ddd009d,0x60c000c2,0x6d4875e9}},	//   _dee_, _नुसत, vimm, zuda,
   {{0x6d48b05b,0x3f80013f,0x60c0b05c,0x00000000}},	//   yuda, _šiuo_, wimm, --,
   {{0x395800d9,0x82330018,0x60c0b05d,0x7e6801df}},	//   ntrs_, رروا, timm, vedp,
   {{0x442db05e,0x25ae01e8,0x661b3df1,0x98b80034}},	//   _gee_, ıklı_, _đuki, turę_,
   {{0x60c0b05f,0x7c2d4f64,0x98b8004b,0x00000000}},	//   rimm, _rear, strė_, --,
   {{0x7c2db060,0x6d48b061,0x60c002fd,0x7b0b00d9}},	//   _sear, tuda, simm, _kļuv,
   {{0x7c2d10f0,0x63a23ce7,0x442db062,0x6288b063}},	//   _pear, lyon, _yee_, _indo,
   {{0x0cab016e,0x7cff013f,0x6d48b064,0x629ab065}},	//   стои_, _kūri, ruda, _hoto,
   {{0x6d4835aa,0x629a4b2c,0x7eadb066,0x9b5800d3}},	//   suda, _koto, _súpe, пият_,
   {{0x629a0aa9,0x7c2d00d7,0x7cff0d7c,0x00000000}},	//   _joto, _wear, _mūri, --,
   {{0x38690080,0x63a26206,0x997e00ae,0x62880350}},	//   tear_, hyon, văţa_, _mndo,
   {{0x6abe02dc,0x25e000a5,0x629ab067,0x63a2b068}},	//   _empf, _कड़ी_, _loto, kyon,
   {{0x4c3c0054,0x442d2678,0x628803f3,0x3869b069}},	// [d070] _התחב, _ree_, _ondo, rear_,
   {{0x442db06a,0x3869b06b,0xcb1400c1,0x63a22b20}},	//   _see_, sear_, _אלץ_, dyon,
   {{0x3869b06c,0x442db06d,0x26c13834,0xdbd7007b}},	//   pear_, _pee_, riho_, sääm,
   {{0x6288b06e,0x442d0197,0x63a20a4b,0x7cff0d7c}},	//   _ando, _qee_, fyon, _būri,
   {{0xe2990f50,0x442d7519,0x69d80856,0x26c1019c}},	//   жал_, _vee_, _øver, piho_,
   {{0x442d06c0,0x91e508d8,0x629ab06f,0xfc3f768a}},	//   _wee_, моле, _coto, chív_,
   {{0x442d72e3,0x629ab070,0x63a23630,0x7cd20325}},	//   _tee_, _doto, ayon, hāra,
   {{0x92bf00c7,0x63a2b071,0xef1967cb,0x92cd0081}},	//   ীতে_, byon, оми_, রতে_,
   {{0x2d98b072,0x63a20079,0x61ed03e3,0x7ead4647}},	//   ären_, cyon, ƙalo, _núpc,
   {{0xddc824e5,0x6da522fb,0x6b820234,0x4ca50033}},	//   cedū, диоа, _šogo, খোমু,
   {{0x8c461167,0x7d0700d1,0xed160103,0x2a6a01f9}},	//   мене, dèrè, وہوں_, vebb_,
   {{0x629a766d,0xe45f00bc,0x00000000,0x00000000}},	//   _zoto, _ööd_, --, --,
   {{0x629a65a8,0xbbc818ff,0x3ae402c3,0x7d070113}},	//   _yoto, रपेक, köpt_, fèrè,
   {{0xddc563fe,0xf8bfb073,0x7d070113,0x00000000}},	//   _обли, _amé_, gèrè, --,
   {{0x09e342d1,0x63a25b32,0x00000000,0x00000000}},	//   ворн, zyon, --, --,
   {{0x2a6a0068,0xbebd00c6,0xa2bd5433,0x00000000}},	//   sebb_, spūd, वोत्, --,
   {{0x395800d9,0x656902ef,0x995800d8,0x00000000}},	// [d080] strs_, _ćeha, _dáša_, --,
   {{0x290c132d,0xadc40032,0x44380034,0x63a20239}},	//   ídas_, _ayẹy, _śr_, vyon,
   {{0xd82608d1,0x7cff0138,0xb87b0065,0x00000000}},	//   _одни, _sūri, _ikín, --,
   {{0x2eaa00a5,0x63a20383,0x7ea40154,0xfe78004b}},	//   _छत्त, tyon, _pòpk, zdį_,
   {{0x41c30557,0x6f0d0076,0x4ad20eeb,0x3d0709a1}},	//   _वेबस, _éach, _सदाव, _संघे_,
   {{0x68e3023b,0x63a2b074,0x61ed01c2,0x629a17f4}},	//   _ëndr, ryon, ƙall, _qoto,
   {{0x63a26d40,0x629a1f8b,0x7cf60042,0x6603013f}},	//   syon, _voto, cárg, _апра,
   {{0x7cff00d9,0x63a2210a,0x629a0350,0x51831d57}},	//   _tūri, pyon, _woto, туша,
   {{0x44269295,0x629a8dd8,0xb4bc009d,0x200200c2}},	//   mbo_, _toto, ेची_, äki_,
   {{0x4426b075,0x7e9800e3,0x6288b076,0x00000000}},	//   lbo_, سنجر_, _undo, --,
   {{0xfe7800c6,0x4426026d,0x00000000,0x00000000}},	//   rdį_, obo_, --, --,
   {{0x442635c4,0xb87b0af0,0x4fc60ba4,0x7cd201d3}},	//   nbo_, _akín, _осла, tāra,
   {{0x78a300d3,0x9be400d6,0x8ae7004d,0x4426008c}},	//   _învi, вірк, дівл, ibo_,
   {{0xe7e2000f,0xc33300ca,0x7cd20a84,0x00000000}},	//   _खड़ा_, כוש_, rāra, --,
   {{0x44261331,0x00000000,0x00000000,0x00000000}},	//   kbo_, --, --, --,
   {{0x2d580257,0x61e82907,0x4426903f,0x7cd20325}},	//   mée_, _mydl, jbo_, pāra,
   {{0x4426b077,0x2d58025a,0x6d5a8fe2,0x2ca40212}},	// [d090] dbo_, lée_, ltta, ömde_,
   {{0x05eb0303,0x7ead0220,0x442683fe,0x4975576e}},	//   офеи_, _kúpa, ebo_, _злос,
   {{0x2d5804ea,0x7ae509a4,0x7ea40428,0x6d5ab078}},	//   née_, _ikht, _còpi, ntta,
   {{0x6d5a02fd,0x4426b079,0x69d702a1,0x7e7800f2}},	//   itta, gbo_, _ixxe, _lavp,
   {{0x27ff00fd,0x2d5800fd,0x626564e9,0x00000000}},	//   _àun_, hée_, евла, --,
   {{0x61e80618,0x442694c9,0x7e780117,0x6d5a059a}},	//   _bydl, abo_, _navp, ktta,
   {{0x4426b07a,0x387903e3,0x6d5a53d3,0x91e21d4d}},	//   bbo_, _kasr_, jtta, лоше,
   {{0x2d580257,0x2aad0094,0x69d70090,0x00000000}},	//   dée_, ržby_, _mxxe, --,
   {{0x443f02e6,0x41df05cd,0x6d5a2a59,0xf1df007a}},	//   _idu_, _पुरस, etta, _पुरन,
   {{0xf1a7344a,0x2d7e009e,0x2d58020d,0x6d5a0e37}},	//   _орен, _bċe_, fée_, ftta,
   {{0x2d580257,0x6cc601b3,0x6d5a02b6,0x2bc50034}},	//   gée_, ейна, gtta, _लेबा,
   {{0x7cf62347,0x443f02c6,0x7fd50138,0x00000000}},	//   káre, _jdu_, _пілі, --,
   {{0x765500a5,0x6d5a0450,0xf1c30789,0x69d702a1}},	//   _oczy, atta, _वेतन, _axxe,
   {{0x7cf61e80,0x44260117,0x6ee6003e,0x2d58014b}},	//   dáre, zbo_, fðbu, bée_,
   {{0x6d5a9c4f,0x2d580257,0x2d9801df,0x44260188}},	//   ctta, cée_, øret_, ybo_,
   {{0x7afc042d,0x291e00d9,0x443f0129,0xddc101d3}},	//   smrt, īta_, _ndu_, celš,
   {{0x0686007e,0x2b4600e3,0xf74322be,0x1ae62ff8}},	// [d0a0] нган, _íoc_, лето, _поим,
   {{0xddc30074,0x443f9ce7,0xfc3f0037,0x45d60cb0}},	//   _manž, _adu_, bhís_, нцет,
   {{0x3a060100,0x44260154,0x7f5b0052,0x3abb00ca}},	//   _سکسی_, tbo_, htuq, _זמינ,
   {{0x6b8402fe,0xb4bc009d,0x443fb07b,0x7cf60143}},	//   _krig, ेचे_, _cdu_, báre,
   {{0x07a3263d,0x4426183f,0x61e86265,0x443f00f0}},	//   _баян, rbo_, _sydl, _ddu_,
   {{0x4426b07c,0x6d5a1e81,0x2d5800fd,0x443f00d7}},	//   sbo_, ytta, yée_, _edu_,
   {{0x044600d6,0x2d58020d,0x443f05bd,0xf1c33162}},	//   _певн, xée_, _fdu_, _वेदन,
   {{0x2d58025a,0xea000023,0x0f26004d,0x61e800d4}},	//   vée_, _nhậu_, ньом, _vydl,
   {{0x3f824098,0x68e30472,0x6b84b07d,0xa346001c}},	//   íku_, _índe, _nrig, _سپاه,
   {{0x61e80222,0x2d58025a,0xb87b0139,0x00000000}},	//   _tydl, tée_, _akíl, --,
   {{0x6b84b07e,0x6d5a00c2,0x6eef01df,0xa00a0037}},	//   _arig, utta, møbl, _فقال_,
   {{0x2d5804ea,0x61e401e8,0x6d5ab07f,0xac1900d6}},	//   rée_, ğild, rtta, ьому_,
   {{0x2d5804ea,0x60c2b080,0x7b6468f6,0x69c8b081}},	//   sée_, _imom, лтре, úden,
   {{0x2d980400,0x2d5800fd,0x6b840319,0x7cf60094}},	//   øres_, pée_, _drig, váre,
   {{0x81e20f71,0x64408ae3,0x6b84b082,0x386008e8}},	//   নের_, _odmi, _erig, ffir_,
   {{0x6b840c48,0xb4da000d,0x61e50364,0x2e460139}},	//   _frig, ठको_, ühli, _fífà_,
   {{0x6b8441b1,0xf77300d0,0x443f0124,0x60c24788}},	// [d0b0] _grig, داز_, _rdu_, _mmom,
   {{0x443f031b,0x7ae5005c,0xf1b03e2a,0x6d48b083}},	//   _sdu_, _ukht, जनान, orda,
   {{0x38790181,0x60c223c0,0x15a800e5,0x41df05d6}},	//   _tasr_, _omom, нъци_, _पुंस,
   {{0x6b84037a,0x7cf61ba6,0x00000000,0x00000000}},	//   _yrig, márc, --, --,
   {{0x889a09c1,0x68edb084,0xc8860364,0x443f00c6}},	//   _חברי, mlad, ößen_, _vdu_,
   {{0x21691b60,0xd6e20034,0x290b007e,0x76550034}},	//   дики_, _całą_, _hica_, _uczy,
   {{0x68edb085,0x82340604,0xfa7800ca,0x290b0027}},	//   olad, ارها, געות_, _kica_,
   {{0x443fb086,0xb7f509b0,0xd6c40081,0x290bb087}},	//   _udu_, _आराम_, ্তৃপ, _jica_,
   {{0x290bb088,0x68edb089,0x6d48b08a,0x248d0143}},	//   _mica_, ilad, erda, _inem_,
   {{0x290b00e9,0x38b5422e,0x25e60789,0x7ec6020d}},	//   _lica_, _hård_, _जुडी_, _répè,
   {{0x68ed272c,0x249f0154,0x6d4800e7,0x6b840479}},	//   klad, _koum_, grda, _srig,
   {{0x68ed4fbc,0x249f0154,0x00000000,0x00000000}},	//   jlad, _joum_, --, --,
   {{0xeb97b08b,0x2d981484,0x6d48b08c,0x68edb08d}},	//   вия_, ører_, arda, dlad,
   {{0xc33200a1,0x61e401e8,0x290b0036,0x68ed008c}},	//   שום_, şile, _aica_, elad,
   {{0x68edb08e,0x6cda0e38,0x09e61e70,0x291303be}},	//   flad, _офис_, товн, _cuxa_,
   {{0x290bb08f,0x7cf60103,0x7a3f026a,0x7ead2c85}},	//   _cica_, sárb, _açtı, _kúpo,
   {{0x290bb090,0x6b84b091,0x96ba0037,0x38605179}},	// [d0c0] _dica_, _urig, وائز_, rfir_,
   {{0x68ed769b,0x248d3e9b,0xe6100092,0x3860b092}},	//   alad, _anem_, _düşə, sfir_,
   {{0x200f0465,0x290bb093,0xe45a1031,0x67248f69}},	//   _oggi_, _fica_, дже_, spij,
   {{0x6724b094,0x68ed0cb6,0xb7340018,0x290ba776}},	//   ppij, clad, _مہرب, _gica_,
   {{0x2bc8009d,0x68e4b095,0x249f022b,0x2900166f}},	//   रपटा, moid, _doum_, mmia_,
   {{0x248db096,0x29000084,0xe7370831,0x290bb097}},	//   _enem_, lmia_, _јер_, _zica_,
   {{0x2913016d,0x2ab4042c,0x290b05bd,0x00000000}},	//   _xuxa_, _gäbe_, _yica_, --,
   {{0x68e4b098,0x64a358ad,0x38b5682e,0x7f491399}},	//   noid, _каса, _gård_, freq,
   {{0x64a30805,0x13060450,0xa0670291,0x3a38058f}},	//   _тата, _азам, тања_, karp_,
   {{0x3c32011b,0x68e46c28,0x200f1df8,0x68ed0b12}},	//   _được_, hoid, _eggi_, zlad,
   {{0x68ed9768,0x6d483564,0x68e45ef9,0x7f4901ff}},	//   ylad, urda, koid, areq,
   {{0x68e400c2,0x60c20d2a,0x38b50120,0x7f49464f}},	//   joid, _umom, _kåre_, breq,
   {{0xe0b70130,0xdb582976,0x7f490042,0x68e40503}},	//   _בלאט_, кюр_, creq, doid,
   {{0x68ed025e,0x290bb099,0x1ddd009d,0x2900b09a}},	//   wlad, _sica_, _नुकत, emia_,
   {{0x79a4490c,0x68edb09b,0x3f860094,0x1ea90037}},	//   арте, tlad, _hrou_, _ثاني_,
   {{0x6f0d028d,0x2cb2030a,0x2ca01c5d,0x00000000}},	//   _èacc, _glyd_, _goid_, --,
   {{0x68edb09c,0x57f522ee,0xc6f90c2b,0x290b30d9}},	// [d0d0] rlad, упат, енах_, _vica_,
   {{0x68ed305b,0x7d0d23b0,0x3a38b062,0x29130072}},	//   slad, _hias, carp_, _tuxa_,
   {{0x68edb09d,0xe7e3000d,0x7d0d068d,0xceb300c1}},	//   plad, _कुरा_, _kias, סיע_,
   {{0x73d910e8,0x78b6013f,0x24190b2f,0x321e30e6}},	//   ндер_, chyv, ходы_, _afty_,
   {{0x7d0d0067,0xe3b000ab,0x38b50149,0x64db00b7}},	//   _mias, يره_, _vård_, यकौश,
   {{0x7ead00e3,0x78ad0219,0xe1f90399,0x1308004d}},	//   _cúpl, lkav, нгл_, вній_,
   {{0x26020f53,0x3f860072,0x7ead5d08,0x6594085a}},	//   वेदी_, _arou_, _dúpl, _кару,
   {{0x78adb09e,0x3f861e69,0x22490367,0x248d0131}},	//   nkav, _brou_, şak_, _unem_,
   {{0x0fca00a5,0xb87b0032,0x7cf60103,0xf1bf00b6}},	//   ापगढ, _akík, jára, _řád_,
   {{0x63a40084,0xe3b0010d,0x81e20033,0x7cf60072}},	//   äine, _برف_, নেই_, dára,
   {{0x3cca078b,0x78ad69ec,0x605533c6,0x3a38003e}},	//   елно_, kkav, _مناط, varp_,
   {{0x7d0db09f,0x78ad00cb,0xa3ca0034,0x61e5042c}},	//   _cias, jkav, _ऊधम_, ühlu,
   {{0x60c9af74,0x3f8618f0,0x68e4b0a0,0x28c60285}},	//   miem, _grou_, void, रोफि,
   {{0x7f3a00f5,0x60c9065c,0x00000000,0x00000000}},	//   _טענו, liem, --, --,
   {{0x1a6612eb,0x391600cd,0xdb060018,0x68e4257b}},	//   نیکی_, اورز, nyké, toid,
   {{0x7d0d0009,0x60c9b0a1,0xd51a00fe,0x290023de}},	//   _gias, niem, _rằn, umia_,
   {{0x38cb00cd,0xb8dc0851,0x7cf60143,0x00000000}},	// [d0e0] رافی_, _अत_, cára, --,
   {{0x7c36b0a2,0x68e49598,0x2900007b,0x78ad0172}},	//   _heyr, soid, smia_, akav,
   {{0xa9a62b49,0x60c952eb,0x7d0d01fa,0x7c36003e}},	//   _синд, kiem, _yias, _keyr,
   {{0x7c3601c2,0x60c9b0a3,0x00000000,0x00000000}},	//   _jeyr, jiem, --, --,
   {{0x04431121,0x7c36b0a4,0x13940120,0x2ee502ac}},	//   сечн, _meyr, рилю, kolf_,
   {{0x38b502ec,0x2d87020d,0xe297b0a5,0x261a1da8}},	//   _våre_, _orne_, лач_, मुखी_,
   {{0x35a300d3,0xb4260781,0x00000000,0x00000000}},	//   _ларг, _معذو, --, --,
   {{0x3f8605fe,0x60c9b0a6,0x8937006e,0x7c36b0a7}},	//   _prou_, giem, ארקע_, _neyr,
   {{0xdfd000e3,0x2d870e9f,0x7d0db0a8,0x04570037}},	//   تية_, _arne_, _rias, _حلقة_,
   {{0x3f860665,0x7d0d4584,0x7cf619a3,0x33d50120}},	//   _vrou_, _sias, vára, _тіст,
   {{0x2d8700e9,0x7d0db0a9,0x7cfd0850,0x00000000}},	//   _crne_, _pias, nérg, --,
   {{0x60c95c48,0x3f86b0aa,0xab5b0103,0x7c364628}},	//   ciem, _trou_, nzüg, _ceyr,
   {{0x2d87b0ab,0x99900106,0x7c36b0ac,0xc3870032}},	//   _erne_, _čaše_, _deyr, _bẹ́ẹ,
   {{0xbda60dd0,0xdb2401f9,0x00000000,0x00000000}},	//   _محبو, ásáb, --, --,
   {{0x7d0d023e,0x7cf6b0ad,0x78ad23ce,0x7c36041c}},	//   _tias, márn, tkav, _feyr,
   {{0x7cf6b0ae,0x6e3ab0af,0x2fc905db,0x7c3601ee}},	//   lárn, latb, _žagi_, _geyr,
   {{0x96356321,0x00000000,0x00000000,0x00000000}},	// [d0f0] инац, --, --, --,
   {{0x78adb0b0,0x7cf6499e,0xda1904f8,0x60c9b0b1}},	//   skav, nárn, _दलित_, ziem,
   {{0x7ae702e6,0x78ad01d3,0x600b020e,0x00000000}},	//   mojt, pkav, _kömü, --,
   {{0x81cd00c7,0x7c3600a7,0x60c9020d,0x6e3a0381}},	//   রথম_, _xeyr, xiem, hatb,
   {{0x60c935cf,0xa856040a,0x7cf6025b,0x6e3a07ee}},	//   viem, _דירה_, kárn, katb,
   {{0xddda0068,0xae0404f8,0x38a700aa,0x57d40161}},	//   hető, रधान_, _võru_, _ѓорѓ,
   {{0x746b2887,0x60c91e06,0xa5f81262,0x7cf60146}},	//   _прав_, tiem, _беру_, dárn,
   {{0xcf450036,0xe1880d5b,0xdb0a0031,0x00000000}},	//   аний, ائون_, ľném, --,
   {{0x60c9b0b2,0x2295015a,0x6e3a00e7,0x6eef3229}},	//   riem, _پلاس, fatb, løbi,
   {{0x4d650b37,0x60c9b0b3,0x7c36306f,0x0ea900c2}},	//   аков, siem, _seyr, ткой_,
   {{0xcc8a00cd,0x60c9b0b4,0x7c36b0b5,0xbca60037}},	//   ننده_, piem, _peyr, لمدي,
   {{0x7c360092,0x2d87033b,0xfce6b0b6,0x16070d77}},	//   _qeyr, _vrne_, ромо, वेयर_,
   {{0x6e3a0009,0x7c290951,0x7cd201d3,0x7cc40103}},	//   batb, ñera, nāri, nőri,
   {{0xceb800a5,0xab274785,0x6eef02b6,0x41a91e05}},	//   chę_, рора_, købi, _कथास,
   {{0x7c3600f0,0x81130033,0x61ed0022,0x00000000}},	//   _teyr, _সবুজ_, ƙalu, --,
   {{0xf1b2006e,0x7cd20a84,0x7cf64dd8,0x600b0233}},	//   קסן_, kāri, máro, _gömü,
   {{0xe801267b,0xc87f02e2,0x7cf60220,0x46ea04c9}},	// [d100] लेला_, _daß_, láro, вдан_,
   {{0x645b1ba6,0xda66550f,0xf4870a85,0x63ab02c3}},	//   _acui, _твои, یانی, dygn,
   {{0x7cf62299,0x21250131,0x00000000,0x00000000}},	//   náro, _ntlh_, --, --,
   {{0x232a17e9,0x7cf60072,0x6e3a968d,0x645b2bc0}},	//   води_, iáro, zatb, _ccui,
   {{0x93770080,0xf7460831,0xe29a7089,0xc9d5001c}},	//   لصور_, _њего, кад_, _نمیک,
   {{0xddda0018,0x7cf637b9,0x7cfd0103,0xea0000fe}},	//   zető, káro, mére, _chầu_,
   {{0x7cf65a8e,0x6e3a0103,0xe5a600ae,0x7cfd0349}},	//   várn, vatb, _тиви, lére,
   {{0x645b0080,0x63ab0c08,0x98b10034,0x656e0113}},	//   _gcui, bygn, pszą_, _ipbh,
   {{0x7cf6045e,0x7cfd2749,0xddda0103,0x656900e7}},	//   tárn, nére, vető, _ćehi,
   {{0x1be1052c,0x600b0233,0x6ef400b3,0x00000000}},	//   _गुगल_, _sömü, ràbo, --,
   {{0x7cf6025b,0x7cfd20cc,0x6e3a1534,0xd65700ca}},	//   rárn, hére, ratb, סיטת_,
   {{0x55770130,0x7cf60018,0x13aa0033,0x4911007a}},	//   בעטן_, sárn, _খেয়, _दूगो_,
   {{0xa2bd0285,0xbbd13845,0x69de01ff,0x00bb00ca}},	//   वोक्, सपेक, _axpe, _במאמ,
   {{0x7cfd00fd,0x61ed01c2,0x7cf6408f,0xc87f042c}},	//   dére, ƙalt, báro, _saß_,
   {{0x7ae700dd,0x63ab0034,0x98c72cad,0x7cf60042}},	//   rojt, zygn, асал, cáro,
   {{0x7cfd025a,0x290f32ee,0x48156ceb,0x00000000}},	//   fére, öga_, смас, --,
   {{0x69deb0b7,0x7d18023e,0x7ae70146,0xf773071c}},	// [d110] _expe, _huvs, pojt, غار_,
   {{0x7c3db0b8,0x94e800a7,0x645b24f6,0x7cd200e8}},	//   lasr, _işə_, _scui, vāri,
   {{0x68e3167e,0x64150037,0xaadc00ca,0x7ead0503}},	//   _índo, مواط, _בחזר, _dúph,
   {{0x7cfd8dce,0x7cd200e8,0x00000000,0x00000000}},	//   bére, tāri, --, --,
   {{0x7cf6b0b9,0x212500ec,0x4abb09c3,0x224505aa}},	//   záro, _stlh_, _उताव, _pdlk_,
   {{0x65951a9f,0x7c3d0450,0x00000000,0x00000000}},	//   _лагу, hasr, --, --,
   {{0x45d40d4f,0xc692006e,0x7cf6002b,0xab5b02db}},	//   _дорс, _צאל_, xáro, nzüb,
   {{0x2602009d,0x7cf60018,0x00000000,0x00000000}},	//   वेळी_, váro, --, --,
   {{0x443db0ba,0xea0000de,0xb4e300af,0x201f0036}},	//   maw_, _thầu_, नकी_, rcui_,
   {{0x443d8efa,0xe8e00028,0x7cf60068,0x7ead0181}},	//   law_, _đọc_, táro, _kúpi,
   {{0xea0000de,0xd0110037,0x7ead309e,0x60400174}},	//   _khấu_, _فلا_, _júpi, _ịmeb,
   {{0x6459b0bb,0x6281b0bc,0x443db0bd,0x7cf6b0be}},	//   ngwi, _halo, naw_, ráro,
   {{0x7cf60018,0xee2e13a4,0x00000000,0x00000000}},	//   sáro, _нн_, --, --,
   {{0x443db0bf,0x6281b0c0,0x6aa50154,0xed590138}},	//   haw_, _jalo, _cohf, _бок_,
   {{0x62811206,0x443db0ba,0x62830113,0x6f1900eb}},	//   _malo, kaw_, idno, _huwc,
   {{0x7cfd0654,0x6281b0c1,0x443d003d,0x6d4120ab}},	//   tére, _lalo, jaw_, msla,
   {{0x7c24b0c2,0x98a3062a,0x443db0c3,0x00000000}},	// [d120] _ifir, чите, daw_, --,
   {{0x6281b0c4,0x38b5070a,0x81e20081,0xfbd300ca}},	//   _nalo, _våra_, নেট_, _מתח_,
   {{0x99860080,0x6d41b0c5,0xdb0607ff,0x7cfdb0c6}},	//   _الجو, nsla, szkó, sére,
   {{0x443d07ae,0x7cfd4a85,0x6281b0c7,0xb87b0139}},	//   gaw_, mérc, _aalo, _ajíf,
   {{0x7cf60301,0x291a9bd3,0xb8010851,0x00000000}},	//   járm, _hupa_, लेआम_, --,
   {{0x6d41b0c8,0x24800d94,0x628302ef,0x3a3a1a04}},	//   ksla, žim_, gdno, _jepp_,
   {{0x443db0c9,0x6281b0ca,0x918600e3,0x7c242736}},	//   baw_, _dalo, إجتم, _ofir,
   {{0x6d410429,0x236903e5,0x61e461f0,0x7cf60143}},	//   dsla, ħajr_, şilo, fárm,
   {{0x291a9f9f,0x6281b0cb,0x6d41b0cc,0x7c3d00d3}},	//   _lupa_, _falo, esla, vasr,
   {{0x6d41b0cd,0x7cf60068,0x877b006e,0x291a057a}},	//   fsla, sárl, נאיי, _oupa_,
   {{0x7c2904d8,0x7c3b0653,0x2d8a0a5a,0xdceb45ca}},	//   ñero, ðuro, íbe_, žiča,
   {{0x62810f90,0x6f1900eb,0x00000000,0x00000000}},	//   _zalo, _fuwc, --, --,
   {{0x6281b0ce,0x6e38996a,0x611100d9,0x7c3d00dc}},	//   _yalo, _tevb, _tālr, rasr,
   {{0x628125ae,0x7c24013c,0x7c2f0072,0x28c60287}},	//   _xalo, _efir, sbcr, रोसि,
   {{0x443d20c1,0x291a2b5c,0x7c24009e,0x4424b0cf}},	//   yaw_, _cupa_, _ffir, _ofm_,
   {{0x291a0012,0x7764003d,0x26cab0d0,0x62830e43}},	//   _dupa_, ftix, _ambo_, zdno,
   {{0x7bda0b88,0xfc3f00e3,0x6fb8009f,0x291a0090}},	// [d130] ştur, maí_, इनिं, _eupa_,
   {{0xfc3f0080,0xd5bb0077,0x6b8db0d1,0xb87b0139}},	//   laí_, лсе_, _irag, _akít,
   {{0x443db0d2,0x7c240102,0x6281a4df,0x4424b0d3}},	//   taw_, _yfir, _ralo, _bfm_,
   {{0xfc3f054f,0x6b8db0d4,0xb4e30f78,0x59cf0179}},	//   naí_, _krag, नके_, _हेयर,
   {{0x6281b0d5,0x20d3002d,0x291a40e8,0xb87b0139}},	//   _palo, nţie_, _zupa_, _ajíg,
   {{0xfc3f0080,0x443db0d6,0x3869b0d7,0x6b8d0113}},	//   haí_, saw_, lfar_, _mrag,
   {{0x443db0d8,0xea000023,0x6d410407,0x6283b0d9}},	//   paw_, _thấu_, xsla, rdno,
   {{0x386900e3,0x7c3b003e,0x6b8d014b,0xfc3f016d}},	//   nfar_, ðurl, _orag, jaí_,
   {{0x6449b0da,0x6281a84e,0xef161119,0xfc3f00e3}},	//   _idei, _talo, омы_, daí_,
   {{0x82340814,0xee392249,0x6d419fda,0x672d7cb4}},	//   _فرما, шно_, tsla, ipaj,
   {{0x6b8db0db,0x7cd20029,0x6da51102,0xfc3f0037}},	//   _arag, kārt, цина, faí_,
   {{0x291a0706,0x6b8d4d1e,0xfc3f0037,0x3a3ab0dc}},	//   _rupa_, _brag, gaí_, _sepp_,
   {{0x6d415b87,0x2d980149,0x291ab0dd,0x38690037}},	//   ssla, ärer_, _supa_, dfar_,
   {{0x291a0af0,0x6b8db0de,0x6d41b0df,0x6d4e0206}},	//   _pupa_, _drag, psla, ábac,
   {{0xed5928ea,0x6b8d02a7,0x3869b0e0,0x64490161}},	//   _той_, _erag, ffar_, _odei,
   {{0xb4e3033a,0x6b8da64c,0x3ea70154,0xfc3f0037}},	//   नको_, _frag, _hont_, caí_,
   {{0x3ea7b0e1,0xc31f0081,0x20d3002d,0xd05b03e3}},	// [d140] _kont_, নীতি_, cţie_, lluɓ,
   {{0x644902ad,0x291a83d3,0x7cfd0802,0x7cf60031}},	//   _adei, _tupa_, méra, kárk,
   {{0x7764b0e2,0x3ea7b0e3,0x7cfd00fd,0x64490090}},	//   stix, _mont_, léra, _bdei,
   {{0x672d023e,0x395801d3,0x38698813,0xddd805db}},	//   bpaj, murs_, cfar_, _javš,
   {{0x7cfd04ea,0xf48712eb,0x395800b3,0x644900f0}},	//   néra, تالی, lurs_, _ddei,
   {{0x68f6b0e4,0x26ca0239,0x64490178,0x61e4173c}},	//   llyd, _umbo_, _edei, şilm,
   {{0x44240072,0x7cfdb0e5,0x1a9b006e,0x00000000}},	//   _tfm_, héra, ייסע, --,
   {{0x8f4609fe,0xddd8025b,0x64490095,0xdb1d0103}},	//   оход, _navš, _gdei, szsé,
   {{0x629e02fd,0x2486019c,0x7ead124d,0x3ea76bc8}},	//   öpos, mdom_, _lúpu, _bont_,
   {{0x3ea70012,0x23665d91,0x7cfdb0e6,0x3eb80af9}},	//   _cont_, mtoj_, déra, órt_,
   {{0xfc3f054f,0x3ea77dc2,0xdd9002fc,0x6b8d1bdf}},	//   taí_, _dont_, روح_, _srag,
   {{0x248627cd,0x672d022e,0x3958b0e7,0xe571006e}},	//   ndom_, ypaj, durs_, ײַט_,
   {{0x3ea73435,0xfc3f0080,0x2bc502e8,0x39580257}},	//   _font_, raí_, _लेखा, eurs_,
   {{0x6b8d0272,0xfc3f0080,0x672d023e,0x24843aa3}},	//   _vrag, saí_, vpaj, _lamm_,
   {{0x2988117a,0x2486b0e8,0xfc3f0037,0xca14008f}},	//   осто_, kdom_, paí_, ддръ,
   {{0x7cfd8be8,0x20d300ae,0x28c611b5,0x23660052}},	//   béra, pţie_, रोलि, ktoj_,
   {{0x3869b0e9,0x23660052,0x63a4007b,0x7cfd2591}},	// [d150] rfar_, jtoj_, äinl, céra,
   {{0x61270b88,0xe80100a5,0x672d3a99,0x38692514}},	//   _yıld, लेगा_, rpaj, sfar_,
   {{0x39581667,0x7cd200e8,0x672d1175,0x38691cac}},	//   curs_, pārt, spaj, pfar_,
   {{0x248617d2,0xa87900c1,0xa97a006e,0x672d28b4}},	//   gdom_, _פאָר, _פארכ, ppaj,
   {{0x889a00a1,0xd37b1510,0x2909659a,0x2484866b}},	//   _הברי, рче_, mmaa_, _damm_,
   {{0x290900c2,0x2ca9b0ea,0x68460103,0x2d8e099c}},	//   lmaa_, _load_, _védő, _orfe_,
   {{0x3ea713fb,0x24840154,0x00000000,0x00000000}},	//   _ront_, _famm_, --, --,
   {{0x3ea710af,0x38bc00e3,0x237f006c,0x290928b4}},	//   _sont_, _tíre_, _tsuj_, nmaa_,
   {{0x3ea78759,0x2d8e03e3,0x7cfd002b,0x2909007b}},	//   _pont_, _arfe_, xéra, imaa_,
   {{0x92b700d0,0x7cf6b0eb,0x260200aa,0x68ed3fe6}},	//   _بحرا, mári, वेकी_, hoad,
   {{0x7cf67d14,0x3ea7b0ec,0xddd80117,0xf652006e}},	//   lári, _vont_, _pavš, עצט_,
   {{0x7cff013f,0x7cfd4229,0x2a7801bf,0x01fa00ca}},	//   _kūry, téra, werb_, _הפעל,
   {{0x7cf6077f,0x68ed00ec,0x03d90033,0xcee80103}},	//   nári, doad, _তরুণ, _ڈرون_,
   {{0x3958b0ed,0xdd0100d9,0x1e84004d,0x75290995}},	//   turs_, ītāj, _олім, _čezn,
   {{0xa2b30285,0x7cfd014b,0xdb0601f9,0x1d0a00e5}},	//   _अवन्, séra, gyká, _леки_,
   {{0x7cfd717b,0xb87b5aeb,0x68ed0956,0xe8fa0138}},	//   péra, _ajíb, goad, ёла_,
   {{0x24860580,0x3958942f,0x7d040079,0x2484533d}},	// [d160] vdom_, surs_, _ihis, _ramm_,
   {{0x7cf6b0ee,0x248400bc,0x7cd200e8,0xf1db0ff9}},	//   dári, _samm_, pārs, यपान,
   {{0x68ed08a8,0x7d042745,0x24840167,0x00000000}},	//   boad, _khis, _pamm_, --,
   {{0xa5078329,0x7cf6b0ef,0xeab20018,0x04570037}},	//   пеха_, fári, _آٹھ_, كلمة_,
   {{0x2486b0f0,0x7d04b0f1,0x24840154,0x33f60037}},	//   rdom_, _mhis, _vamm_, أساس,
   {{0x48f6030b,0x66c00149,0x46c0121d,0xa3a500b6}},	//   ्षको_, _sökf, _एतिह, nářů_,
   {{0x386b00e3,0x60dbb0f2,0x7c3b0088,0x248400bc}},	//   _éirí_, fnum, ðurk, _tamm_,
   {{0x78a402e6,0xfaff00dd,0x2366023b,0x5f9410b8}},	//   njiv, jtën_, ptoj_, диит,
   {{0x4426b0f3,0x2ca900a1,0x289b22fe,0x7cf60558}},	//   mco_, _road_, מיקא, cári,
   {{0x44269981,0x7d042651,0x7d16022b,0x644210e4}},	//   lco_, _ahis, _aiys, laoi,
   {{0xfaff023b,0x4426028d,0x6c552178,0x7d04b0f4}},	//   ftën_, oco_, мкну, _bhis,
   {{0x7d04b0f5,0x44261b9e,0x6442b0f6,0x00000000}},	//   _chis, nco_, naoi, --,
   {{0x68e31f84,0xaf0700bf,0x7d049094,0x78a404a3}},	//   _índi, تقیم_, _dhis, djiv,
   {{0x64420a02,0x7d049000,0x2b5900b3,0x00000000}},	//   haoi, _ehis, rusc_, --,
   {{0x68edb0f7,0x4426a838,0x7cf62e92,0x6442024a}},	//   toad, kco_, zári, kaoi,
   {{0x9ddb00a1,0xe8b501e8,0x7cfd0257,0xfdf70089}},	//   _לקוח, _dışı, méro, _מצות_,
   {{0x20d300d3,0x2909822b,0x6442033f,0x7cfd07c5}},	// [d170] nţia_, rmaa_, daoi, léro,
   {{0x7cf61e6f,0x29090673,0x60c000f9,0x68ed020a}},	//   vári, smaa_, hhmm, soad,
   {{0xf5790192,0x7cfd014b,0x68edb0f8,0x60dbb0f9}},	//   تماع_, néro, poad, ynum,
   {{0xdd8600d0,0x7cf6497e,0x437518c6,0x7c3f00bd}},	//   _یو_, tári, дукт, _jeqr,
   {{0x6d5ab0fa,0x7c3f00bd,0xd7e40120,0x7e7a03bd}},	//   huta, _meqr, _зіро, ketp,
   {{0x7cf60396,0x4426b0fb,0xe29619d4,0xdb060103}},	//   rári, aco_, даш_, szkö,
   {{0x6d5a58e0,0x7cf6b0fc,0x10a50927,0x442641be}},	//   juta, sári, дийн, bco_,
   {{0x4426b0fd,0x6d5ab0fe,0x7cfd0921,0x6442151d}},	//   cco_, duta, déro, caoi,
   {{0x6d4e8bf9,0x60dbb0ff,0xaf050b31,0x00000000}},	//   ában, rnum, мпил, --,
   {{0x7d04b100,0x443f0472,0x6d5a43e1,0x7d1601c2}},	//   _shis, _heu_, futa, _siys,
   {{0x6d5a4db4,0x443f805d,0x1d0a1b10,0x41b50037}},	//   guta, _keu_, жени_, _تمار,
   {{0x443f04ea,0x4174012b,0x3f8f011d,0xa3b80018}},	//   _jeu_, _سامس, _trgu_, _باہر_,
   {{0x443fb101,0x20d3002d,0xfaff023b,0x3f8301d3}},	//   _meu_, cţia_, rtën_, ājus_,
   {{0x6d5a33bf,0x44260890,0x443fb102,0x66c03125}},	//   buta, zco_, _leu_, _köke,
   {{0x7d04b103,0x3f8d0bfe,0x7cfd06fc,0x6d550103}},	//   _this, lveu_, céro, ázad,
   {{0x443fb104,0xe8fa0f1e,0x442689da,0x38c8001c}},	//   _neu_, іла_, xco_, سازی_,
   {{0x2ab40006,0xf7435e66,0xa6860161,0x61e4026a}},	// [d180] _läbi_, кето, млад, ğili,
   {{0x6b84b105,0x61e40367,0x257e00b6,0x44268fdb}},	//   _isig, şili, _půl_, wco_,
   {{0x1a9b00a1,0x4426b106,0xf1c30138,0x443fb107}},	//   _וייע, tco_, nešė_, _beu_,
   {{0x44267ddd,0x69da020d,0x00000000,0x00000000}},	//   uco_, ûteu, --, --,
   {{0x443f8042,0x7c3b0088,0x6442009b,0x7b0b00bd}},	//   _deu_, ðuri, raoi, _iżur,
   {{0x44261059,0x7bc60087,0x6d5a9844,0x443f057a}},	//   sco_, izku, yuta, _eeu_,
   {{0x443f2572,0x7cfd03be,0xdc3000c6,0x00000000}},	//   _feu_, xéro, _užėm, --,
   {{0x6b8402e6,0x3860b108,0x6d5a007a,0x27240149}},	//   _osig, ngir_, vuta, _kön_,
   {{0x4fc6055b,0x27240018,0x3f141110,0x61ed0555}},	//   ьска, _jön_, ндис, ğala,
   {{0x64403cf6,0x6d5a03f3,0x7ead0220,0x443f3280}},	//   _hemi, tuta, _súpr, _zeu_,
   {{0x629ab109,0x6b84b10a,0x443f00de,0x27240149}},	//   _into, _asig, _yeu_, _lön_,
   {{0xe57100c1,0x7e7ab10b,0x409300e3,0x20d300ae}},	//   אַך_, setp, _للمر, pţia_,
   {{0x6d5a05a7,0x64402129,0x6288b10c,0x764e00a5}},	//   suta, _memi, _kado, _odby,
   {{0x6440b10d,0xdd901363,0x6288b10e,0x628ab10f}},	//   _lemi, _موت_, _jado, ndfo,
   {{0x6b84b110,0xaf070037,0x6127026a,0x48ab013f}},	//   _esig, _تقوم_, _kıla, отам_,
   {{0x644065be,0x6d4800f3,0x3860003e,0xceb829aa}},	//   _nemi, msda, ggir_, lkę_,
   {{0x443fb111,0x6d48b112,0x569501b6,0x2b490a39}},	// [d190] _reu_, lsda, наат, _uvac_,
   {{0x443f5bdb,0x27240587,0xceb813ff,0x629a0167}},	//   _seu_, _dön_, nkę_, _nnto,
   {{0x443f57d6,0x6d481db2,0x6440b113,0x628a02ad}},	//   _peu_, nsda, _bemi, ddfo,
   {{0x629ab114,0x6440b115,0x62880032,0x66c00212}},	//   _anto, _cemi, _aado, _röke,
   {{0x6288b116,0x66c00222,0x443f0e9c,0xf8bf0649}},	//   _bado, _söke, _veu_, _ilé_,
   {{0x6288b117,0x29190010,0x6d480160,0x629a0113}},	//   _cado, _hisa_, ksda, _cnto,
   {{0x6288b118,0x443fb119,0x2919b11a,0xceb80034}},	//   _dado, _teu_, _kisa_, dkę_,
   {{0x629a1c40,0x6440b11b,0x76450332,0x6d480407}},	//   _ento, _gemi, lahy, dsda,
   {{0x62884c43,0xb2751a6d,0x6d4a0ec9,0x2d987c75}},	//   _fado, _плаш, _avfa, åren_,
   {{0x6440b11c,0x7ce80092,0x6288b11d,0x7cfd0103}},	//   _zemi, zırd, _gado, sérl,
   {{0xab5b0068,0x6440b11e,0x7f5b0188,0xf8bfb11f}},	//   szül, _yemi, suuq, _olé_,
   {{0x2919b120,0x0fd0009d,0x672f1197,0x64401524}},	//   _nisa_, _तेवढ, _otcj, _xemi,
   {{0x7f5b008a,0x2bba0037,0x6d480441,0x00000000}},	//   quuq, ساحة_, asda, --,
   {{0xc3327c04,0xf8bf0af0,0xdbcd01ab,0x6d481e72}},	//   רום_, _alé_, róðr, bsda,
   {{0x2919b121,0x27240149,0xf8bf020d,0x61270233}},	//   _bisa_, _sön_, _blé_, _yıla,
   {{0xf8bf6772,0x6b840d2a,0xadd60089,0x291900b3}},	//   _clé_, _tsig, _רוקח_, _cisa_,
   {{0x291901e5,0x3860b122,0x27e6025a,0x644042a2}},	// [d1a0] _disa_, rgir_, çon_, _remi,
   {{0x291e0f61,0xf8bf43b3,0x7c290072,0x6ef400b3}},	//   ítas_, _elé_, ñerv, làbr,
   {{0x64400496,0x62880941,0x491a02d5,0x2919b123}},	//   _pemi, _rado, _मंटो_, _fisa_,
   {{0x93461bf9,0x2919b0d1,0x44f600cd,0x63a20b7e}},	//   енде, _gisa_, رساز, txon,
   {{0x6288b124,0x7cf60220,0xceb824c5,0x00000000}},	//   _pado, lárs, ykę_, --,
   {{0x764e052f,0x2919429e,0xf8bf2347,0x76450167}},	//   _udby, _zisa_, _zlé_, cahy,
   {{0x62884f7b,0x6440b125,0x66e32b08,0x7cf6035d}},	//   _vado, _temi, _сора, nárs,
   {{0x62881f56,0x6d4e0610,0xceb80034,0x6f18007e}},	//   _wado, ábam, wkę_, _sivc,
   {{0x93aa2761,0x6288b126,0xdefa0077,0xceb80034}},	//   _عارف_, _tado, зын_, tkę_,
   {{0x6d487d3f,0x59b200aa,0x7cf60220,0x201d0154}},	//   tsda, ीनार, kárs, _egwi_,
   {{0x61db0c3c,0x6eb40034,0xceb829aa,0x7cf6b127}},	//   यपृष, ेसबु, rkę_, járs,
   {{0x7cf60181,0xb87b0139,0x27e60034,0xdd120511}},	//   dárs, _ajín, żony_, rüşl,
   {{0x2919b128,0x6d4832c5,0x4fb30cc8,0xceb8007f}},	//   _risa_, ssda, _مصور, pkę_,
   {{0x29190496,0x8f9b0341,0xfd7400ae,0xe3e20033}},	//   _sisa_, _מידי, _алкэ, _বরাব,
   {{0xa2b30569,0x291913f6,0xf8bf00e3,0xddc8b129}},	//   _अवस्, _pisa_, _plé_, ledž,
   {{0x764502e7,0xc4c40103,0x3f860154,0x69c70216}},	//   wahy, _طے_, _ksou_, rzje,
   {{0x2919b12a,0x3f86033a,0xddc8706d,0x481505e1}},	// [d1b0] _visa_, _jsou_, nedž, тмас,
   {{0x798501bb,0x65950b7b,0x7cf60220,0x3f9b0042}},	//   _tshw, казу, bárs, _áque_,
   {{0x7cf6b12b,0x2919b12c,0x7645671f,0x7c3b0233}},	//   párt, _tisa_, rahy, ıurf,
   {{0x29190167,0x7c2d0090,0xa41f0033,0x64bd0285}},	//   _uisa_, _jfar, দর্য_, ्फेश,
   {{0x45180470,0x80a40f35,0x7c2d6a0b,0x6fd01cff}},	//   رآمد_, काने, _mfar, _तेलं,
   {{0x2489b12d,0x80d302d5,0xbb3c0796,0x213e030a}},	//   žam_, बोने, לעדי, _bwth_,
   {{0x3f8605aa,0x7cfd0103,0xe0570281,0x61fa03a8}},	//   _asou_, gérk, فیات_, _cytl,
   {{0xa99c0266,0x23d21178,0xddc80a39,0x71240286}},	//   לבור, _देवद, fedž, درول,
   {{0x776db12e,0x442d7b31,0x248000bc,0x00000000}},	//   ntax, _ife_, õime_, --,
   {{0x7c2db12f,0x1e9501a0,0x7f490abd,0x31c72cf5}},	//   _afar, трир, rseq, _псев,
   {{0x7f490036,0x213e009c,0x3eae02c3,0xdcf40a13}},	//   sseq, _gwth_, _doft_, žača,
   {{0x7c2d00dd,0x2247a848,0x7cf6b130,0x00000000}},	//   _cfar, lank_, várs, --,
   {{0x442d00ac,0xd10e0179,0x30d8006e,0xd7d006eb}},	//   _mfe_, ागरण_, _אַװע, _सेंच,
   {{0x3eae023e,0x7cf63e91,0x00000000,0x00000000}},	//   _goft_, társ, --, --,
   {{0x442db131,0xd94318e4,0xaa430243,0x78af0218}},	//   _ofe_, иери, ресл, _bocv,
   {{0x442d37dc,0x7c29002b,0x7cf6b132,0x2d8701ee}},	//   _nfe_, ñert, rárs, _isne_,
   {{0x16660221,0x7cf641ef,0x00000000,0x00000000}},	// [d1c0] квам, sárs, --, --,
   {{0x442db133,0xa9262edd,0x7cf60143,0xaca80103}},	//   _afe_, _идол, cárr, _آپکے_,
   {{0x2247057a,0x546a02e3,0x00000000,0x00000000}},	//   dank_, даем_, --, --,
   {{0x38c80139,0x6b960a07,0x2b400027,0x00000000}},	//   _dìrù_, _kryg, _kwic_, --,
   {{0xa2b309c4,0x61ed008b,0x7cf61ba6,0xe3632657}},	//   _अवश्, şall, nárq, икци,
   {{0x442db134,0x62630831,0x61fab135,0x66e60566}},	//   _efe_, авља, _pytl, _рога,
   {{0xe5a322d1,0x442d0283,0x9426002d,0x35a302a0}},	//   _кири, _ffe_, _амбе, _карг,
   {{0x61fa035d,0x6b9600a5,0x442d0167,0x2b4d0d62}},	//   _vytl, _oryg, _gfe_, šeci_,
   {{0xb4be00a5,0x7cfd00d4,0x6e2d04a8,0x00000000}},	//   इसी_, sérk, _şaba, --,
   {{0x7cfdb136,0x7c2d55e1,0x38b50149,0xb87b0139}},	//   méri, _sfar, _hårt_, _ajíl,
   {{0x7cfd4668,0x7c2d0364,0x61e4026a,0x91e33a46}},	//   léri, _pfar, ğils, _кофе,
   {{0x6b960429,0x776d0092,0xc5f300a1,0xcb3500e5}},	//   _bryg, ytax, ידת_, лемъ,
   {{0x60c27de3,0x3f861097,0x2d87b137,0x7cf60143}},	//   _ilom, _usou_, _esne_, gárq,
   {{0x6b96b138,0x60c2039f,0x78af05db,0x00000000}},	//   _dryg, _hlom, _socv, --,
   {{0x7c3b0102,0x60c2432d,0x7c2903be,0x7cfd020d}},	//   ðurs, _klom, ñers, héri,
   {{0x6b96052f,0x7c2d198d,0x38720150,0x48c30033}},	//   _fryg, _ufar, gfyr_, ্ক্র,
   {{0x22470167,0x66c00212,0x442db139,0x7cf60328}},	// [d1d0] yank_, _söka, _rfe_, párr,
   {{0x776db13a,0x60c271d2,0xe3b3001c,0x6d5ab13b}},	//   rtax, _llom, یرش_, orta,
   {{0x776db13c,0x60c2ae2f,0x7af56bcb,0x62ea0033}},	//   stax, _olom, mozt, য়গায়_,
   {{0xf4e10033,0x6d5a00f3,0xde15006e,0x8ddb00d7}},	//   বত্ব, irta, אַנץ_, וקבק,
   {{0x7cfdb13d,0x42d50426,0x6ec500b7,0x785e020a}},	//   géri, ліку, िसमु, săvâ,
   {{0xf99009b4,0x91e54564,0x36d544bd,0x61ed020e}},	//   _ابی_, лоле, _согр, şalm,
   {{0xfa781723,0x60c23813,0x36d40cd1,0x442d00fc}},	//   דעות_, _blom, _торр, _tfe_,
   {{0x7cfdb13e,0x6fd40336,0x25bc0537,0x442d101e}},	//   béri, _बेहू, øvle_, _ufe_,
   {{0x6d5ab13f,0x7af50018,0x7cfd7ddd,0x623503a7}},	//   erta, kozt, céri, _безу,
   {{0x612701e8,0x60c2b140,0x52741ac9,0xc7b200ca}},	//   _yıll, _elom, _نامز, צבי_,
   {{0xb87b0065,0x8c4647c4,0x60c2b141,0x30753d37}},	//   _ajím, лене, _flom, _булс,
   {{0x248d00b3,0x7cf63536,0x00000000,0x00000000}},	//   _jaem_, tárq, --, --,
   {{0x20240038,0xeb970e38,0x6d5ab085,0xa2b93613}},	//   ásiť_, гия_, arta, ्सप्,
   {{0x60c21b30,0x7cf610d9,0x7cc40018,0x6b96057a}},	//   _zlom, rárq, nőrz, _vryg,
   {{0x6d5a005f,0x22453d85,0x2d87005f,0x5d7900c1}},	//   crta, _melk_, _usne_, _טאַק,
   {{0x6b965ddb,0x26c300e7,0xbc661d62,0x00000000}},	//   _tryg, _aljo_, _свик, --,
   {{0x4806766f,0xa80636bf,0x2ca0009c,0x00000000}},	// [d1e0] упав, узал, _inid_, --,
   {{0xe5a61011,0x8c1b00ca,0xa9a605da,0x249fb142}},	//   лизи, _אופי, _биод, _anum_,
   {{0xe45a4988,0x7cd201d3,0x248d03a8,0xd946166f}},	//   еже_, dārz, _baem_, _щени,
   {{0x7cfdb143,0xa34a0848,0x136a0318,0x248d0131}},	//   téri, езда_, ешки_, _caem_,
   {{0x38b5038b,0x68e40085,0xcc3b006e,0x60c2009c}},	//   _vårt_, mnid, גענט, _rlom,
   {{0x60c20995,0x29005220,0x92941037,0x88c60033}},	//   _slom, llia_, ракц, _এদিক,
   {{0x68e4226c,0x26da0270,0x8cc700a4,0x00000000}},	//   onid, mipo_, ासमो, --,
   {{0x7cfd025a,0x92e400c7,0x68e4b144,0x6d5a031a}},	//   péri, নতে_, nnid, vrta,
   {{0x68e40150,0xceba01c2,0x6d552e3f,0xaf33001c}},	//   inid, _liƙe_, ázan, یریت,
   {{0x67260da3,0x22450090,0x2900b145,0xe3eb0142}},	//   _mukj, _gelk_, hlia_, _אַבֿ,
   {{0x29000051,0xd6db0327,0x61270367,0x2b910031}},	//   klia_, תחיל, _yılm, _môcť_,
   {{0x6d5a09f7,0x7ce807aa,0x26da07ac,0x7cfd0103}},	//   rrta, tıra, hipo_, hérv,
   {{0x6d5a00cc,0x29003c09,0x7af51fd1,0xd0120037}},	//   srta, dlia_, tozt, _الش_,
   {{0x66c00222,0xc9873967,0x2ca01066,0x290003a8}},	//   _sökn, луби, _enid_, elia_,
   {{0x7af51f3f,0x68e40150,0x67260381,0x63b9007f}},	//   rozt, fnid, _aukj, zywn,
   {{0x29000465,0x3835162c,0x7ebf084e,0x00000000}},	//   glia_, рнар, _lêpl, --,
   {{0x7d0db146,0xe89400c2,0x96f9001f,0x672605db}},	// [d1f0] _ihas, щать, веат_, _cukj,
   {{0x68e4b147,0x2900b148,0x248d016d,0xaa670a01}},	//   anid, alia_, _saem_, _стик,
   {{0x7d0d2ada,0x2900b149,0x00000000,0x00000000}},	//   _khas, blia_, --, --,
   {{0x63b90067,0x2900b14a,0xddc80220,0xf8c900bc}},	//   tywn, clia_, radň, _रतिय,
   {{0x03a50012,0x66c003e0,0xddd80094,0x7d0db14b}},	//   рило, _kökl, _navž, _mhas,
   {{0x7d0d0022,0x26da3518,0xb7da00d7,0x00000000}},	//   _lhas, cipo_, _יקרי, --,
   {{0x38790063,0x63b9007f,0x80b90033,0xe2c90e27}},	//   _kbsr_, sywn, ইফস্, _یورو_,
   {{0x78ad15f4,0x249f0653,0x22450126,0xb97c006e}},	//   njav, _unum_, _welk_, גנהי,
   {{0x644bb14c,0x09d2009d,0x20d3002d,0x20190084}},	//   magi, _सध्य, nţii_, äsi_,
   {{0x644bb14d,0x7f5b40de,0x7d0db14e,0x2eb5490c}},	//   lagi, rruq, _ahas, рсис,
   {{0x7d0db14f,0x78adb150,0x68e4026d,0x290002cb}},	//   _bhas, kjav, ynid, ylia_,
   {{0x628300ee,0xceba0d2a,0x386b0239,0x7647780f}},	//   leno, _riƙe_, _nccr_, _lejy,
   {{0x7d0d517d,0xee2e25f3,0x78ad0095,0x3ceb0146}},	//   _dhas, _мн_, djav, _živé_,
   {{0x644b1a95,0x60c98c16,0x6283a3d8,0x13ba006e}},	//   hagi, lhem, neno, דזשע,
   {{0xd9462562,0x644b8d91,0x66c00212,0x67260167}},	//   реби, kagi, _söko, _sukj,
   {{0x60c90084,0x6283b151,0x7d0db152,0x2ca02f05}},	//   nhem, heno, _ghas, _unid_,
   {{0x644bb153,0x6283b154,0x7c2435f2,0x4a760a29}},	// [d200] dagi, keno, _igir, _кынт,
   {{0xfd4c0028,0xdcf9030b,0x60db0451,0x68e4b155}},	//   _nhiệ, _osvě, hium, snid,
   {{0x14261a18,0x628300cb,0x4a5b00a1,0x26dab156}},	//   адем, deno, _בדיו, ripo_,
   {{0x644bb157,0x7cfd3275,0x26dab158,0x67260063}},	//   gagi, sérv, sipo_, _tukj,
   {{0x60c9b159,0x20d300d3,0x66c000a7,0xd46700d3}},	//   dhem, cţii_, _hökm, риче_,
   {{0x62835b8c,0xb87b0032,0xfd4c020b,0x00000000}},	//   geno, _ajíh, _chiệ, --,
   {{0x644bb15a,0x6d5510a8,0x69ce25bb,0x224200fe}},	//   bagi, ázal, nzbe, _đkkd_,
   {{0x7c24b15b,0x60c94479,0x92c80033,0x644bb15c}},	//   _ngir, ghem, োকে_, cagi,
   {{0x4ea66924,0x6283b15d,0x7527023e,0x232ab15e}},	//   арна, beno, _zujz, _рози_,
   {{0x7d0d931e,0x7c24b15f,0xfaff00dd,0x62330831}},	//   _shas, _agir, ntët_, _међу,
   {{0x069700a1,0x7cfd0103,0x7d0d98aa,0x4c9524dc}},	//   בדים_, kért, _phas, бинс,
   {{0x211a00d1,0xddd805db,0x7eb600fc,0x00000000}},	//   _شتاب_, _tavž, _câpr, --,
   {{0xd0d305d1,0x4ab400a4,0x9f4901cd,0xdee610a6}},	//   _بينظ, ुसंव, _áað_, _коди,
   {{0x644b4131,0x77640428,0x7c240361,0x7d0d034f}},	//   zagi, duix, _egir, _whas,
   {{0x1fe80081,0x644b3c3e,0x7d0db160,0x78adb161}},	//   _পরিস, yagi, _thas, tjav,
   {{0x26d8b162,0x7ce8008b,0x7d0db163,0x7cfd0103}},	//   _amro_, nırl, _uhas, gért,
   {{0x78adb164,0x6283b165,0xdcf2003d,0x2f0b02b6}},	// [d210] rjav, yeno, _żgħi, søge_,
   {{0x6b8d025e,0xed4d00fb,0x644bb166,0x6283002b}},	//   _isag, _تھی_, wagi, xeno,
   {{0x6283181b,0x644ba021,0xb99500e3,0xc8bf00b6}},	//   veno, tagi, _الجب, _एकपट,
   {{0x776405fe,0xfc3fb167,0x62834382,0x20d300ae}},	//   buix, nbí_, weno, pţii_,
   {{0x644b741c,0x6283b168,0x7647022e,0x7ce80491}},	//   ragi, teno, _tejy, dırl,
   {{0x644bb169,0x6b8db16a,0xa5f9022a,0x00000000}},	//   sagi, _msag, _бегу_, --,
   {{0x60c90060,0x644bb16b,0x44240f20,0x34951e6d}},	//   them, pagi, _fgm_, _лавр,
   {{0x3869487c,0x6283b16c,0x6b8d01e9,0x00000000}},	//   ngar_, seno, _osag, --,
   {{0xfd4c0028,0x60dbb16d,0x60c9b16e,0x68fd0085}},	//   _thiệ, rium, rhem, _mksd,
   {{0x60db2c97,0x4d6513fc,0xddb50037,0x7c240441}},	//   sium, бков, محجب, _sgir,
   {{0x6b8db16f,0x60c9b170,0x60db0036,0xa294004d}},	//   _asag, phem, pium, _фахі,
   {{0xe1f01a37,0xfce600d3,0x20ca009c,0xfc3f00b3}},	//   _غسل_, сомо, _cùid_, gbí_,
   {{0x80a40f53,0x66c01df4,0xfaff023b,0x2d8a02b6}},	//   कारे, _sökm, jtës_, æber_,
   {{0xa96a1f5d,0x6d5c3618,0x69ce0364,0xa3af0ed5}},	//   лига_, árac, tzbe, _ओपन_,
   {{0xcd3500bf,0x6b8db171,0x68fd0167,0x7c290218}},	//   _ارتب, _esag, _bksd, žera,
   {{0x38690b6a,0xfaff00dd,0x7c240384,0x65650167}},	//   ggar_, ftës_, _ugir, duhh,
   {{0xc7a308d8,0x03e20081,0xdc3b006e,0x69ce0103}},	// [d220] питк, _বর্ণ, _געפר, szbe,
   {{0x7ce80dea,0x38690076,0x66c02743,0x68fd28b6}},	//   zırl, agar_, _tökm, _eksd,
   {{0xb8ce0081,0x644901bf,0xfaff023b,0x7ce80511}},	//   _কত_, _beei, rtët_, yırl,
   {{0xfaff00dd,0xed5600c1,0xceba0d2a,0x232a4163}},	//   stët_, מבער_, _miƙa_, годи_,
   {{0xa80503be,0xb87b0065,0xceba01c2,0x20d3020a}},	//   ruñé, _ajíw, _liƙa_, nţiu_,
   {{0x26d800e9,0xd62715a9,0x954a0241,0x7afe0063}},	//   _umro_, _горе_, _مشرق_, _jkpt,
   {{0x7ce808bb,0xd2590426,0xfc3f00b6,0x80a4045f}},	//   tırl, рці_, ybí_, काले,
   {{0x644901bf,0x44240510,0x032607c6,0x399b006e}},	//   _geei, _ugm_, _гдан, ריקד,
   {{0xd9a50789,0x60c0b172,0x30770037,0xb87b0139}},	//   _ऑप्ट, rkmm, صحية_, _ejíw,
   {{0x66fa40c1,0xa29f030b,0x5d5411db,0x38699890}},	//   ्तिक_, _गोप्, окот, zgar_,
   {{0xd24f0dce,0x6b8d6fdd,0x38690e26,0x00000000}},	//   _سنن_, _ssag, ygar_, --,
   {{0x7cfdb173,0x7bcf037a,0xd12f0037,0x248600c4}},	//   vérs, tzcu, _أمن_, neom_,
   {{0x66fa007d,0x06fa19af,0xc4d300ca,0xfc3f34b6}},	//   ्ताक_, ्ताव_, פגש_, rbí_,
   {{0x3da6249c,0x6d4e03be,0x7cfd0146,0x38bc00b6}},	//   _гриб, ábas, térs, _míru_,
   {{0xf8bf00fd,0xa803026a,0x6cd50246,0x69d80141}},	//   _liée_, ğıms, _وقتا, _žver,
   {{0x58d41824,0x320c0146,0x6b8db174,0x24860095}},	//   пост, _mzdy_, _tsag, jeom_,
   {{0xf77018a9,0x38695986,0xb8d10789,0x6eac0c54}},	// [d230] فال_, rgar_, _टच_, जापु,
   {{0x38690cd9,0x6efd0257,0xfaff0052,0x2d9c02c6}},	//   sgar_, lèbr, rtës_, _krve_,
   {{0xfaff023b,0xf60b1acf,0x98650018,0x65650167}},	//   stës_, ухай_, _ویسے_, uuhh,
   {{0x6efd020d,0x2d9c00c4,0x20ca0441,0xe6100103}},	//   nèbr, _mrve_, _lùib_, رشل_,
   {{0x69d8003e,0x00000000,0x00000000,0x00000000}},	//   _þver, --, --, --,
   {{0xe29944aa,0x04fb0033,0x64490113,0x00000000}},	//   рак_, েদের_, _weei, --,
   {{0x960808a1,0x32cb004d,0x00000000,0x00000000}},	//   _гэта_, _nøye_, --, --,
   {{0x7ce80511,0xceba0d2a,0xf8c90179,0x2f551469}},	//   tırm, _riƙa_, रसिय, отос,
   {{0x2d9801df,0x2d9cb175,0x00000000,0x00000000}},	//   æren_, _arve_, --, --,
   {{0x200300d9,0xd2510d74,0x6d4600e7,0xb4c914e5}},	//   āji_, _آنا_, ćkan, _ऋतु_,
   {{0xb035008f,0x2d9c0218,0xdb060034,0x00000000}},	//   _днеш, _crve_, zykó, --,
   {{0x23600106,0x7c2914f3,0xc0ab0308,0x60d90027}},	//   šije_, žern, _حائل_, _umwm,
   {{0xab2a2e9e,0xb4fa006e,0x6ab7039f,0x443800a7}},	//   рога_, שפרי, _boxf, _ər_,
   {{0x81cc0081,0xddda007e,0x66c00342,0xa29f0285}},	//   রপর_, setš, _gökh, _गोम्,
   {{0x2d9802fe,0x5d69028d,0x200b042d,0x7ce8026a}},	//   året_, _тийм_, škić_, nırk,
   {{0xdb060034,0x66c0b176,0x48e80a43,0x00000000}},	//   tykó, _tökk, পত্র, --,
   {{0xe8f700d6,0xfaff023b,0x464a0058,0x9d1b00d7}},	// [d240] ілу_, rtër_, изан_, _דוקט,
   {{0x2be0007d,0xfaff00dd,0x7ce80233,0x00000000}},	//   _पेया, stër_, kırk, --,
   {{0x7afc59af,0x4aa700b7,0x00000000,0x00000000}},	//   mort, खारव, --, --,
   {{0x23db0285,0x66c0007b,0x2d9a93ae,0x00000000}},	//   _मेहद, _möki, _špek_, --,
   {{0x24860218,0x00000000,0x00000000,0x00000000}},	//   reom_, --, --, --,
   {{0x7afcb177,0xdeb303e3,0x7cf60103,0x4ace00a4}},	//   nort, ƙaƙe, gárz, होचव,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x320c035d,0x00000000,0x00000000,0x00000000}},	//   _vzdy_, --, --, --,
   {{0x20020088,0x95ec0033,0x98b30995,0xe2e600e5}},	//   æki_, _করিম_, žeće_, _джап,
   {{0x7afc017a,0x00000000,0x00000000,0x00000000}},	//   jort, --, --, --,
   {{0xa2a71492,0xa2b9397e,0x1df804d9,0x7afcb178}},	//   चार्, ्सर्, сены_, dort,
   {{0x644201ff,0x61ed020e,0x00000000,0x00000000}},	//   nboi, ğalt, --, --,
   {{0x99980138,0x7afc5bde,0x7c2900c4,0xdb1d4173}},	//   karų_, fort, žero, lysé,
   {{0x7afcaed0,0x70da0336,0x7c36030a,0x00000000}},	//   gort, _बगुल, _efyr, --,
   {{0xdb1d0018,0x7c360150,0x28bf0c9c,0xf84b15c2}},	//   nysé, _ffyr, _एकदि, ичай_,
   {{0x26cab179,0x34b93212,0x4735583b,0x115b006e}},	//   _albo_, _आवेद, знас, ידלע,
   {{0x7afcb17a,0x7ce8013c,0x2d9a0117,0x00000000}},	// [d250] bort, zırk, _špeh_, --,
   {{0xadfe17ad,0x501b00ca,0x7afc226a,0x00000000}},	//   _उडान_, שומו, cort, --,
   {{0x63b6007b,0x00000000,0x00000000,0x00000000}},	//   äynn, --, --, --,
   {{0xf9fa00ca,0x224c01ff,0x00000000,0x00000000}},	//   _להתמ, _aedk_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x77ba00a1,0x02c503a2,0x67ba00ca,0x212cb17b}},	//   _המשח, वसेन, _המשק, _budh_,
   {{0xca7c0341,0x200901d3,0xdb1d0103,0xe0570281}},	//   ינגט, _šai_, gysé, قیات_,
   {{0x25750501,0x6577023e,0xadfe00c3,0x7afcb17c}},	//   mål_, mtxh, _उड़न_, zort,
   {{0xb4e702e8,0x34c70251,0x6d5cb17d,0xf0760103}},	//   यची_, लसीद, áran, سیوں_,
   {{0xf195004d,0x00000000,0x00000000,0x00000000}},	//   _низь, --, --, --,
   {{0x6da506b2,0x7cfd1f84,0x7afcb17e,0xb9270134}},	//   чина, térp, vort, retọ_,
   {{0x7afcb17f,0xdb0d0220,0xbfb700b9,0xa29f3162}},	//   wort, ľkýc, _وحشت, _गोत्,
   {{0x7afcb180,0xa2d2055e,0x8fa50ff5,0x2b49030a}},	//   tort, भोक्, _хале, _cwac_,
   {{0x644200d3,0x8f9a006e,0x38980174,0x25751842}},	//   zboi, _ליני, _ọr_, kål_,
   {{0x7d110068,0x657701fa,0x3ea7b181,0x999800c6}},	//   üksé, jtxh, _innt_, varų_,
   {{0xa3ab030b,0x69c1004d,0x7afc643b,0x23bd0d1a}},	//   गमा_, ølea, sort, ्नाद,
   {{0xb87b0032,0x32050227,0x00000000,0x00000000}},	// [d260] _ajís, _lyly_, --, --,
   {{0x7afc0188,0x645b0063,0x6b844829,0x00000000}},	//   qort, _adui, _ipig, --,
   {{0x6577023e,0x3abb0327,0x7abb00ca,0x00000000}},	//   gtxh, _המינ, _הציו, --,
   {{0x27ed02e6,0x212c009c,0x00000000,0x00000000}},	//   _žene_, _rudh_, --, --,
   {{0x29020006,0x64420a54,0xa294224a,0x212c0167}},	//   _ikka_, rboi, далі, _sudh_,
   {{0x3205030b,0x657701fa,0x6b84908d,0xceba01c2}},	//   _byly_, btxh, _mpig, _riƙo_,
   {{0xb9090019,0xa13c00e8,0x00000000,0x00000000}},	//   _nghỉ_, _orķe, --, --,
   {{0x3ea76a8b,0xf4840421,0xc1040037,0x764e009c}},	//   _annt_, _تاسی, بوعي, _heby,
   {{0x4fc61a5c,0xdd1f02c6,0x6d4614f3,0x00000000}},	//   яска, tížn, ćkam, --,
   {{0x3f1301b6,0x3ea7009c,0x2ba60034,0xeeaa51ad}},	//   ндыс, _cnnt_, खमैथ, стик_,
   {{0xaab08fe5,0x2d8c029a,0x6b840239,0xd23b00ca}},	//   ञानक, uwde_, _apig, _הגבל,
   {{0x6298b182,0x764e53ed,0x63a03e94,0x00000000}},	//   ldvo, _leby, _krmn, --,
   {{0x66c00092,0xde580c10,0x00000000,0x00000000}},	//   _höku, _далі_, --, --,
   {{0x765c074a,0x753c0067,0x2902b183,0x764e030b}},	//   _ndry, _otrz, _akka_, _neby,
   {{0x25dc009d,0x183a00ac,0xc98461f2,0xa3e3074c}},	//   _गेली_, _ọmụm, нути, _फेन_,
   {{0x02d91f77,0xb87b0139,0x77640042,0x6d5802a1}},	//   _भग्न, _ajír, frix, _ivva,
   {{0xf77304f4,0x764e1842,0x76b90e05,0x23db0096}},	// [d270] عار_, _beby, олар_, _मेंद,
   {{0x29020361,0x628a2ca7,0xe7be1980,0x645b0154}},	//   _ekka_, jefo, _एअरप, _sdui,
   {{0x764e0150,0x3915002d,0x765c0178,0xa4d9018a}},	//   _deby, _омор, _ddry, оджу_,
   {{0xb4e702e8,0x765c02ad,0x386d02b6,0x764e010a}},	//   यचे_, _edry, _øer_, _eeby,
   {{0x68edb184,0x889a00a1,0x6d4a00f0,0x764e03a8}},	//   mnad, _וברי, _lwfa, _feby,
   {{0x628a2196,0x764eb185,0x03a22872,0x63a009ac}},	//   gefo, _geby, тишо, _drmn,
   {{0x68ed1f97,0x236003e5,0xd5b8002d,0x6d5cb186}},	//   onad, ġija_, _ест_, áral,
   {{0x68edb187,0x5fc8000d,0x7f5900c9,0x23600335}},	//   nnad, ाईंल, ојот_, šija_,
   {{0x6d58b188,0x68edb189,0xa22700cd,0x67270517}},	//   _avva, inad, _فراه, _kijj,
   {{0x68ed4929,0x2ca9b18a,0x67271b63,0x672f008c}},	//   hnad, _anad_, _jijj, _mucj,
   {{0x68edb18b,0x6b840451,0x693c0995,0x2909007b}},	//   knad, _spig, _ičeg, klaa_,
   {{0x67270361,0x81b60033,0x66c001cd,0x00000000}},	//   _lijj, _চেক_, _hökt, --,
   {{0x3ea700e7,0xdce201d3,0x6d58b18c,0x59d60179}},	//   _tnnt_, gulā, _evva, _डेजर,
   {{0x7d070257,0x320001e8,0x67270b14,0x68ed0231}},	//   térê, şiye_, _nijj, enad,
   {{0x764e0248,0x6281b18d,0x20ca009c,0x9cf60d62}},	//   _reby, _mblo, _mùin_, _очиш,
   {{0x7764b18e,0x629801ac,0x764e294f,0xb4e70096}},	//   trix, zdvo, _seby, यचो_,
   {{0x62813da7,0x753c00a5,0x7d041ab9,0x6727083e}},	// [d280] _oblo, _strz, _ikis, _bijj,
   {{0x68edb18f,0x77643c39,0x2909b190,0x00000000}},	//   anad, rrix, alaa_, --,
   {{0x6d41b191,0x7e7e0222,0x628a03f5,0x00000000}},	//   npla, _öppe, vefo, --,
   {{0xcdb600ca,0x628a0294,0x2909008c,0x7d0400bd}},	//   ופעה_, wefo, claa_, _jkis,
   {{0x628a67d2,0x764e3762,0x62810090,0x6298015c}},	//   tefo, _teby, _bblo, tdvo,
   {{0x6d410bad,0x68e48837,0xd13a00a9,0x290001e9}},	//   kpla, liid, охи_, loia_,
   {{0x62980a9f,0x753c0034,0x62810090,0x20ca01f7}},	//   rdvo, _utrz, _dblo, _dùin_,
   {{0x62813b3f,0x628a1f35,0x68e45b29,0xa6c00033}},	//   _eblo, sefo, niid, _এগিয়,
   {{0x7c2971f1,0x628a0381,0xa29f00a4,0x6d41b192}},	//   žerk, pefo, _गोव्, epla,
   {{0x7d046ba2,0x2ca9030b,0x29000062,0x6d414385}},	//   _akis, _snad_, hoia_, fpla,
   {{0x6d41b193,0x68edb194,0x29000634,0xab5b0103}},	//   gpla, ynad, koia_, gyün,
   {{0x7d16b195,0xbfc6013d,0x66c0b196,0x3cf40206}},	//   _chys, _обек, _köks, _ľavé_,
   {{0x68e4024b,0xfeb700cd,0x68ed059a,0xf8bf034f}},	//   diid, سایت_, vnad, _bién_,
   {{0x7d040a15,0x6d4104cc,0x69d502db,0x00000000}},	//   _ekis, bpla, tzze, --,
   {{0x6d550018,0x68edb197,0x29000062,0x00000000}},	//   ázat, tnad, foia_, --,
   {{0xdce200d9,0x7c87224a,0x68edb198,0x2366007e}},	//   pulā, _цуке, unad, kroj_,
   {{0x7c2db199,0x971500d3,0x00000000,0x00000000}},	// [d290] _igar, емац, --, --,
   {{0x68edb19a,0x7c2d0090,0x8cc702d5,0x7d1db19b}},	//   snad, _hgar, ासको, lmss,
   {{0xa29f0942,0xe3b000cd,0x68e4b19c,0x68ed05e8}},	//   _गोष्, یره_, biid, pnad,
   {{0x809e06ed,0x6281953b,0x66c01df4,0x7d040063}},	//   _खोले, _sblo, _sökt, _xkis,
   {{0x6d411420,0xe824120a,0x67270d2a,0x9cd80327}},	//   zpla, _афро, _tijj, וואה_,
   {{0x6d410120,0x2bd03e2a,0x00000000,0x00000000}},	//   ypla, हनता, --, --,
   {{0x6d4106c5,0x78bd67c7,0x7c2db19d,0x00000000}},	//   xpla, _kosv, _ogar, --,
   {{0x7c2db19e,0x23660106,0x1fb50ce5,0xa29f0cd5}},	//   _ngar, broj_, есор, _गोर्,
   {{0x6d4101cb,0x20ca0441,0x78bdb19f,0xdb070206}},	//   wpla, _iùil_, _mosv, _šmýk,
   {{0x7c2db1a0,0x1dca009d,0x7d04351f,0x290001e9}},	//   _agar, ानंत, _skis, zoia_,
   {{0x75290ab2,0x1d0a078b,0x7d163d36,0x69c101df}},	//   _kiez, зени_, _phys, ølel,
   {{0x55da00c1,0x6d41b1a1,0xe1d800b6,0x78bd00e8}},	//   פֿינ, rpla, _भेटघ, _nosv,
   {{0x7529b1a2,0x00d800cd,0x2be01c0a,0x29000b3b}},	//   _miez, _تبلت_, _पेशा, voia_,
   {{0x60c9b1a3,0x6d41b1a4,0x7c2db1a5,0x75295a63}},	//   lkem, ppla, _egar, _liez,
   {{0x442d0857,0x13bd030b,0x2cab00e3,0x6f010087}},	//   _oge_, ्नुभ, áidí_, molc,
   {{0x26fa000c,0x75290067,0x442db1a6,0x60c9a873}},	//   ्त्र_, _niez, _nge_, nkem,
   {{0xfaa60e08,0xb6a62731,0x68e46765,0xfaff023b}},	// [d2a0] _запо, ниал, riid, mrën_,
   {{0xa29f1e05,0x7c2db1a7,0x442d2ac6,0x60c98b4d}},	//   _गोल्, _zgar, _age_, hkem,
   {{0x60c96ffd,0x752901d3,0x7bc6b1a8,0x29006e85}},	//   kkem, _biez, lyku, poia_,
   {{0x23666136,0xe45215f8,0x20ca01f7,0x68e4008c}},	//   troj_, اضا_, _cùil_, qiid,
   {{0x7529b1a9,0x6abe01bf,0x03a35be6,0x439400c2}},	//   _diez, _kopf, лицо, талс,
   {{0x442db1aa,0x2360033b,0x23660052,0x2d8700f3}},	//   _ege_, šijo_, rroj_, _opne_,
   {{0x6ec3000d,0x6f0126ae,0x442d0072,0x75290063}},	//   ाउनु, dolc, _fge_, _fiez,
   {{0x2b4004e9,0x75290381,0x23660216,0x00000000}},	//   _otic_, _giez, proj_, --,
   {{0xb4be0976,0xfaff0216,0x2b40014b,0x00000000}},	//   ेसी_, drën_, _ntic_, --,
   {{0x7c2db1ab,0xfaff0052,0x75295856,0x6abe039f}},	//   _sgar, erën_, _ziez, _nopf,
   {{0x2b4003a4,0xfaff0216,0x8ffa0d83,0x00000000}},	//   _atic_, frën_, _کرار_, --,
   {{0x629ab1ac,0xbebc01d3,0xe3a70103,0x93f400a4}},	//   _hato, kmīg, _تشہی, _अशाच_,
   {{0x629ab1ad,0x9b580465,0xddcb01ac,0x7d1db1ae}},	//   _kato, ният_, ćišt, rmss,
   {{0x2f9700a1,0x629a0a00,0xd00f08ba,0xdd901f11}},	//   _נכון_, _jato, _اله_, _نوت_,
   {{0x629ab1af,0x3a25070a,0x2d830216,0x2b40078e}},	//   _mato, älp_, çjet_, _etic_,
   {{0x629ab1b0,0x6d5a4469,0x7c2db1b1,0x776d002b}},	//   _lato, msta, _ugar, tuax,
   {{0xe81c007d,0xe73339d9,0x7c840084,0x75290063}},	// [d2b0] पेला_, اصر_, _суще, _riez,
   {{0x629ab1b2,0x66c00149,0x442db1b3,0x20ca01b5}},	//   _nato, _sökr, _sge_, _sùil_,
   {{0x7529b1b4,0x6c6a0068,0xeef7006e,0x65d50076}},	//   _piez, _علیہ_, עמבר_, خياط,
   {{0x629a0f06,0x00000000,0x00000000,0x00000000}},	//   _aato, --, --, --,
   {{0xe29921fd,0x60c9033b,0x75290b60,0xa85600d7}},	//   дал_, vkem, _viez, _בירה_,
   {{0x91e591e5,0x6d5a0358,0x629a54c1,0x752926d7}},	//   коле, ksta, _cato, _wiez,
   {{0x6f01b1b5,0xf8bf03a9,0x60c923ce,0x00000000}},	//   volc, _koé_, tkem, --,
   {{0x442d01c5,0x629ab1b6,0xceb80034,0x10a500ae}},	//   _uge_, _eato, eję_, тиин,
   {{0x60c93cb8,0x6d5ab1b7,0x629ab1b8,0xa28300cd}},	//   rkem, esta, _fato, _میشو,
   {{0x6d5a19fb,0xfbd70081,0xa3ce02d5,0x69d80103}},	//   fsta, সপাত, शनर_, _üveg,
   {{0xdc6a26fd,0xfaff023b,0xd1b20504,0x29190090}},	//   манд_, trën_, _نیوک, _ohsa_,
   {{0xfce60870,0x7bc60067,0x83fd0103,0x6ea102d5}},	//   томо, tyku, _időb, _कोरु,
   {{0x6d5ab1b9,0x629a2bd2,0x7ae70052,0xfaff0052}},	//   asta, _yato, fijt, rrën_,
   {{0xceb80067,0x3d126e55,0x2919010a,0x6d5a5370}},	//   cję_, _धीरे_, _ahsa_, bsta,
   {{0xab270b99,0x6d5ab1ba,0x29190113,0xfaff0052}},	//   тора_, csta, _bhsa_, prën_,
   {{0x09e10081,0x26d14f43,0xceba01c2,0x273602b6}},	//   _মুহা, _alzo_, _riƙi_, _pæn_,
   {{0xc05200c1,0x6abeb1bb,0x97c31166,0x7ae7007e}},	// [d2c0] יזן_, _topf, айте, bijt,
   {{0xb8c905a7,0x20ca01b9,0x00000000,0x00000000}},	//   _गो_, _rùim_, --, --,
   {{0xbebc01d3,0x20ca01b9,0x00000000,0x00000000}},	//   smīg, _sùim_, --, --,
   {{0x6d5c0080,0x09f7040a,0xa3ce1b79,0xdb041570}},	//   árai, _ימים_, शनल_, _orië,
   {{0x629ab1bc,0x6d5a1548,0x693c025b,0x939300e3}},	//   _pato, zsta, _učeb, لجوا,
   {{0x6d5ab1bd,0xe2830231,0x6d5c12b8,0xf8bf2591}},	//   ysta, илчи, šrai, _zoé_,
   {{0x66e31f5d,0xdb1d0103,0x6d5a6c16,0xdb040381}},	//   _тора, nysá, xsta, _arië,
   {{0x629a068d,0x6d5ab1be,0x2376071c,0x2eca034d}},	//   _wato, vsta, _لائح, िस्त,
   {{0x6d5a00a5,0x24070012,0x69c700a5,0x7cfd002b}},	//   wsta, _анти_, zyje, mérx,
   {{0x32d00065,0x4ea60927,0x317c0231,0x00000000}},	//   _fàya_, триа, ptvz_, --,
   {{0x6d5a362e,0x63a25f36,0xdb040023,0x7f5b008c}},	//   usta, lvon, _triê, asuq,
   {{0x13c60081,0x23690335,0x61fa037a,0xceb8007f}},	//   _শেয়, šaje_, _ixtl, sję_,
   {{0x3f9800d9,0x6e960076,0x00000000,0x00000000}},	//   ārus_, _للشا, --, --,
   {{0x6d5a8190,0x27ed18b4,0xaa64180b,0xdee30058}},	//   psta, _ženo_, итск, _кочи,
   {{0x6d5a0078,0xa9c40ab3,0x7ae73b89,0xdb1d01f9}},	//   qsta, астк, rijt, gysá,
   {{0xa3b2030b,0x63a2b1bf,0x257c00b6,0x68fb67e3}},	//   टमा_, kvon, díl_, čudo,
   {{0xdb04001c,0xf7700568,0x00000000,0x00000000}},	// [d2d0] _oriè, قال_, --, --,
   {{0x257c0037,0x63a2b1c0,0x00000000,0x00000000}},	//   fíl_, dvon, --, --,
   {{0x76570188,0x569405e1,0x00000000,0x00000000}},	//   raxy, рахт, --, --,
   {{0xe7de030b,0xb87bad42,0xe791026a,0xdb04020d}},	//   _नेकप, _zmín, _göğü, _ariè,
   {{0xfd530134,0x6385022a,0x2f19020d,0x387900c4}},	//   _begị, угла, lège_, _icsr_,
   {{0xe3b00bd4,0x257c01cd,0x00000000,0x00000000}},	//   ترم_, bíl_, --, --,
   {{0xa3e30006,0x45d50084,0x81e60033,0xf527100f}},	//   _फेर_, _совс, _যুব_, _афан,
   {{0x320c0178,0xd6c50033,0x63a20154,0x00000000}},	//   _dydy_, _এগিয, bvon, --,
   {{0x64590979,0x61fa03a9,0x443f050f,0x93f5002d}},	//   mawi, _extl, _ifu_, _спац,
   {{0x6459b1c1,0x1e950058,0x0ccc2a09,0x753506b0}},	//   lawi, урир, ास्म, _kuzz,
   {{0x5de504d9,0x00000000,0x00000000,0x00000000}},	//   ужна, --, --, --,
   {{0x7e7e0222,0x75354215,0x6459b1c2,0xcb6a3f1a}},	//   _öppn, _muzz, nawi, наме_,
   {{0x7535b1c3,0x31a3026a,0xef0e0c3f,0x443f1cd1}},	//   _luzz, _hız_, _гм_, _mfu_,
   {{0x31a301e8,0x6459b1c4,0x2d950859,0x1c1a02d5}},	//   _kız_, hawi, _брис, नेगल_,
   {{0x6459b1c5,0x443f0134,0x2d9801df,0x75350036}},	//   kawi, _ofu_, æret_, _nuzz,
   {{0x645900a5,0xddc802c6,0x443f1acd,0x5bc60076}},	//   jawi, jadř, _nfu_, _مقبل,
   {{0xad1b00f5,0x06862012,0x9d1b00a1,0x7655022b}},	// [d2e0] _אוקר, лган, _אוקט, _bezy,
   {{0x7d06b1c6,0xdb040072,0x443f8e1f,0xa3d71fbb}},	//   loks, _orié, _afu_, ानन_,
   {{0x765506a3,0x64a6031e,0x4a7b00c1,0x753500c4}},	//   _dezy, лажа, _אריב, _cuzz,
   {{0x257c2955,0x6459b1c7,0x7d066273,0x443f053e}},	//   ríl_, gawi, noks, _cfu_,
   {{0xdb04014b,0x63a2b1c8,0x5453004d,0x2ba71784}},	//   _priè, uvon, світ, खिया,
   {{0x2d5102e6,0x63a2b1c9,0x443f00ac,0x7535b1ca}},	//   kše_, rvon, _efu_, _fuzz,
   {{0x2d510b27,0x918600e3,0x753588d2,0x7d0600c2}},	//   jše_, اجتم, _guzz, koks,
   {{0x6459b1cb,0xc95300ca,0x00000000,0x00000000}},	//   cawi, זמה_, --, --,
   {{0x6d43013f,0x03a315ef,0x75225dab,0x32462bcf}},	//   _atna, _лито, mmoz, _безг,
   {{0x672e0124,0xb77b006e,0x00000000,0x00000000}},	//   _jibj, עאיש, --, --,
   {{0x672e009e,0x00000000,0x00000000,0x00000000}},	//   _mibj, --, --, --,
   {{0x672e009e,0x7f831aaa,0x7d064ba8,0x00000000}},	//   _libj, جلین, goks, --,
   {{0x69c8181f,0x3eb802c3,0x2d8b044c,0x3cdb00c3}},	//   øden, örts_, ăcea_, खोगे_,
   {{0x945d0067,0x64590034,0x2d510087,0x2f1900fd}},	//   _końc, zawi, bše_, tège_,
   {{0x48ab1c2a,0x60c2b1cc,0x6d462f54,0x76550034}},	//   нтам_, _koom, ćkas, _rezy,
   {{0x7535028d,0x7d060063,0x6d480324,0x20d1033c}},	//   _ruzz, coks, mpda, _láin_,
   {{0x62880ec8,0x75350036,0x466b1bc1,0x00000000}},	// [d2f0] _obdo, _suzz, ерем_, --,
   {{0x60c27bf5,0x7c29b1cd,0x6b8db1ce,0x8883001c}},	//   _loom, žers, _ipag, _گیرن,
   {{0x6459b1cf,0xa29f007a,0x443f01ce,0x319700a7}},	//   tawi, _गोग्, _pfu_, _təzə_,
   {{0xfc3fad43,0x6b8d0294,0xc50b001c,0x5c38006e}},	//   ncí_, _kpag, رتال_, ָרגן_,
   {{0x64590067,0x20d800e3,0xa85a00ca,0xdc3c006e}},	//   rawi, _méid_, _בדרכ, געדר,
   {{0x6459b1d0,0x21696cb6,0x6b8d00ac,0x20d10076}},	//   sawi, вики_, _mpag, _cáin_,
   {{0xfc3f0618,0x31a30092,0x64597698,0x443fb1d1}},	//   kcí_, _qız_, pawi, _tfu_,
   {{0x2d5100cc,0x6b8d0af0,0x443fb1d2,0x62880154}},	//   vše_, _opag, _ufu_, _ebdo,
   {{0xaac60e50,0x60c2b1d3,0xddda0146,0x26c30a39}},	//   रॉडक, _doom, latň, _kojo_,
   {{0x63a9b1d4,0x66d20088,0x249f0197,0x0d851052}},	//   _iren, _lækn, _haum_, алон,
   {{0x249fb1d5,0x7d060084,0x60c2b1d6,0x6b8db1d7}},	//   _kaum_, toks, _foom, _apag,
   {{0xe1f0012b,0x2d51103b,0xed56004d,0x60c201ee}},	//   _عسل_, rše_, шою_, _goom,
   {{0x9f6b013d,0x249f022e,0x2d9801df,0x63a9b1d8}},	//   _чрез_, _maum_, ærer_, _jren,
   {{0x212f0054,0x63a95bad,0x249f4cd4,0x6da55ee6}},	//   _high_, _mren, _laum_, _вика,
   {{0x6d430124,0x672e033b,0xa8560859,0x212f01b9}},	//   _utna, _ribj, итај, _kigh_,
   {{0xfc3254c8,0x249fb1d9,0x236000cb,0x776d03be}},	//   _بحث_, _naum_, šiji_, frax,
   {{0x26c3b1da,0xe73773cd,0x66d202b6,0xa6e63671}},	// [d300] _bojo_, иет_, _dækn, ажал,
   {{0x2ca00991,0x26c3034f,0x212f033c,0x00000000}},	//   _haid_, _cojo_, _ligh_, --,
   {{0x63a9b1db,0x249f2015,0x212f01b9,0xae0b206b}},	//   _aren, _baum_, _oigh_, _सुमन_,
   {{0x63a9b1dc,0x249f006c,0x98a600ae,0x212fb1dd}},	//   _bren, _caum_, _тиме, _nigh_,
   {{0x249fb1de,0x63a91c07,0x24070d02,0xcc3b006e}},	//   _daum_, _cren, анци_, דענט,
   {{0x60c27345,0x63a9b1df,0x809e10cf,0x291239bd}},	//   _soom, _dren, _खोजे, llya_,
   {{0x212f01b9,0x63a9b1e0,0xd5b20103,0x249f009c}},	//   _bigh_, _eren, _ظفر_, _faum_,
   {{0x23690039,0x68f60150,0x63a9b1e1,0x74160421}},	//   šaja_, nnyd, _fren, _نوزا,
   {{0x24861271,0x9998033b,0x68f60150,0x1eaa0037}},	//   mfom_, jbrž_, inyd, نادي_,
   {{0x249f01bb,0x248600e7,0xeeaa016d,0x212f01ec}},	//   _zaum_, lfom_, ттик_, _eigh_,
   {{0x6b8d83a8,0x63a90284,0x60c2007a,0x249f022e}},	//   _spag, _zren, _toom, _yaum_,
   {{0x20180253,0x249f01fa,0x0ea60096,0xfc3f02c6}},	//   ərin_, _xaum_, _कोरड, ucí_,
   {{0xd01000cd,0x29120124,0x2ca04d2f,0xfb87004b}},	//   _علت_, dlya_, _daid_, шынн,
   {{0xfc3f0037,0x6d481f60,0xa3d7417a,0x6d5c997a}},	//   scí_, ppda, ानत_, áras,
   {{0x68f602e0,0x26c31186,0x39450185,0x0dca00c9}},	//   fnyd, _rojo_, ëls_, _јули_,
   {{0x776db1e2,0xfce41009,0x6f08033b,0x2ca001b9}},	//   trax, _мојо, lodc, _gaid_,
   {{0x7d0d03f3,0x693c161f,0x249fb1e3,0x6135013f}},	// [d310] _ikas, _učen, _raum_, _išle,
   {{0x2be00b94,0x249f0197,0x2ca0388e,0xf647037e}},	//   _पेटा, _saum_, _zaid_, рхан,
   {{0x249f023e,0x66d20088,0x63a9001c,0x8c090081}},	//   _paum_, _tækn, _sren, রেশন_,
   {{0x69c4000d,0x249f006c,0x73d90058,0x20d10037}},	//   रहरी, _qaum_, лдер_, _cáil_,
   {{0x68ed284f,0x26c30072,0xd37b0a95,0x7d0db1e4}},	//   miad, _tojo_, тче_, _mkas,
   {{0x68edb1e5,0x1308097a,0x69130233,0x48ff00b6}},	//   liad, аній_, kçek, लवको_,
   {{0x20d10080,0x7d0d8300,0x249f022e,0x70130081}},	//   _fáil_, _okas, _taum_, _হলেও_,
   {{0x68edb1e6,0x7d0d2073,0x09f80327,0x59ba0bf5}},	//   niad, _nkas, ימום_, _उपसर,
   {{0x92670d59,0x63a9b1e7,0x2d8e0169,0x20ca009c}},	//   _ندام, _uren, _apfe_, _nùiu_,
   {{0x7d0d2826,0x2ca0b1e8,0x68ed0150,0x201100e8}},	//   _akas, _said_, hiad, āzi_,
   {{0x68f602ad,0xdca6121c,0x212f151d,0x2ca000ca}},	//   ynyd, бани, _tigh_, _paid_,
   {{0x2ca00063,0x32d90154,0xdb0e02c6,0x212f01b9}},	//   _qaid_, _dèye_, ějíc, _uigh_,
   {{0x68ed02e0,0x2ca00006,0xa3d70386,0x7d0d0167}},	//   diad, _vaid_, ानि_, _dkas,
   {{0x644900a7,0x7d0db1e9,0x00000000,0x00000000}},	//   əmiş, _ekas, --, --,
   {{0x68ed02ad,0x80db0640,0x186a29db,0x20d1033c}},	//   fiad, _बताइ, лави_, _láim_,
   {{0xa3d71115,0x68ed0150,0x60db0396,0x68f600f0}},	//   ाना_, giad, nhum, unyd,
   {{0xbb860080,0x2fdf0364,0x693c0357,0x2fcd0103}},	// [d320] _الخي, nzug_, _ičem, nyeg_,
   {{0x68f60f5a,0x00000000,0x00000000,0x00000000}},	//   snyd, --, --, --,
   {{0x94120092,0x60db0060,0x68ed19b0,0x1a9b00c1}},	//   ədən_, khum, biad, _גייע,
   {{0x68ed222b,0x045a02fc,0x69ce0138,0x7aee03e3}},	//   ciad, اجات_, mybe, libt,
   {{0xa3d20251,0x69ce776e,0x60db266f,0x87b91d57}},	//   हैं_, lybe, dhum, _курт_,
   {{0x78a4b1ea,0xd5d60761,0xf74314e0,0x0ea60980}},	//   ldiv, _любы, _херо, _कोंड,
   {{0x60dbb1eb,0x6f088bdb,0x69ce776e,0xc5d5004d}},	//   fhum, vodc, nybe, _діть,
   {{0x78a40465,0x27ed005f,0x60db019c,0xa3e3148e}},	//   ndiv, _ženi_, ghum, _फेक_,
   {{0xa9260094,0x9ed8002d,0xd0100037,0x69ce0213}},	//   mažď, имит_, بلة_, hybe,
   {{0x693c084f,0x68edb1ec,0x765e13d5,0x079b021e}},	//   _pčel, ziad, napy, נסיל,
   {{0xc04f3006,0xb8000081,0xc0e60879,0x4c9517aa}},	//   _ні_, ্ধিত_, _ложк, оинс,
   {{0x69130b88,0x64423f82,0x68ed08a8,0x60dbb1ed}},	//   rçek, ncoi, xiad, chum,
   {{0x68ed0b0b,0x78a43bec,0x6f0800d4,0x69ce0131}},	//   viad, ddiv, podc, eybe,
   {{0x68edb1ee,0x27e000a5,0x7c360018,0x6fc500b6}},	//   wiad, dzin_, _egyr, िहरू,
   {{0x68ed02ad,0x6ce70c10,0x7d0d8e09,0x2909007b}},	//   tiad, _гіпе, _tkas, toaa_,
   {{0x32cb004d,0x7d0db1ef,0x98c42569,0x27e000fe}},	//   _høyt_, _ukas, псул, fzin_,
   {{0x68edb1f0,0x799e02f1,0xf77007e8,0xaad1074c}},	// [d330] riad, _espw, ّام_, _सकपक,
   {{0x68eda256,0xa3ac0cce,0xb8d0034c,0x69c1004d}},	//   siad, गिन_, _टो_, øles,
   {{0x68ed09d3,0x69ce0126,0x78a4226a,0x00000000}},	//   piad, cybe, bdiv, --,
   {{0x76490491,0xd1260246,0x60db0201,0x26d80381}},	//   _şeyd, _زم_, xhum, _elro_,
   {{0xd0061a13,0x987a00c1,0x91b602d5,0xf8bf6b97}},	//   _آل_, _דארט, _अपॉइ, _diét_,
   {{0x23690087,0x00000000,0x00000000,0x00000000}},	//   šajo_, --, --, --,
   {{0x60db0201,0xa4d500d6,0xc1050037,0x00000000}},	//   thum, _дові, يوتي, --,
   {{0x2b4900e9,0x20d10037,0x00c91894,0xdce201d3}},	//   _otac_, _táim_, рлик_, rtlī,
   {{0x2b490350,0x00000000,0x00000000,0x00000000}},	//   _ntac_, --, --, --,
   {{0x60db26f6,0x4d65881d,0x7bcf0063,0x69c83229}},	//   shum, оков, dycu, ødek,
   {{0x60db0060,0x27e0b1f1,0x2b495c36,0x3f84100b}},	//   phum, zzin_, _atac_, atmu_,
   {{0x7fd5116d,0x69ceb1f2,0x1d0a125c,0x00000000}},	//   _мілі, vybe, реми_, --,
   {{0xf8bf0257,0x78a40146,0x2b4900b3,0xf8b800fe}},	//   _liés_, vdiv, _ctac_, _đĩ_,
   {{0x645b009c,0x201d0201,0x6577019f,0x69ce00c6}},	//   _leui, _izwi_, kuxh, tybe,
   {{0x7c3b0559,0x19b9004d,0x66c00233,0xde020284}},	//   žura, буть_, _göky, _опши,
   {{0x27e0b1f3,0x645bb1f4,0x8b965566,0x7aee023e}},	//   tzin_, _neui, _дроч, sibt,
   {{0xeb9a4d70,0x46ea372e,0x78a4b1f5,0xf09200ca}},	// [d340] _тип_, адан_, rdiv, ונן_,
   {{0x27e016ce,0x3200020e,0x273f03a8,0x00000000}},	//   rzin_, şiyi_, _dîn_, --,
   {{0x66d234e2,0x765eb1f6,0xfc3f04d8,0xdb04016d}},	//   _hækk, rapy, ldía_, _triâ,
   {{0x83fd0103,0x645b01b9,0xf8bf033c,0x00000000}},	//   _időj, _ceui, _chéd_, --,
   {{0x693c0335,0xb4ca0789,0xfc3f04d8,0x3860b1f7}},	//   _oček, _लकी_, ndía_, mair_,
   {{0x3860b1f8,0x64428c84,0x77911aaa,0x60d900eb}},	//   lair_, scoi, _سیما, _alwm,
   {{0x66d2b1f9,0x645b39a4,0xd25908a1,0x201d0079}},	//   _lækk, _feui, сці_, _azwi_,
   {{0x3860a1dd,0xf4860103,0x645b01d0,0x20ca01b9}},	//   nair_, _گاڑی, _geui, _rùis_,
   {{0xb60200b6,0x20ca009c,0x77640072,0x6e2f013c}},	//   řádn, _bùir_, nsix, əkbə,
   {{0x38600514,0x753c6dd9,0x66d20088,0x610101d3}},	//   hair_, _kurz, _sækj, vēle,
   {{0x2b49b1fa,0xf8bf0a43,0xdea30022,0x25a50103}},	//   _stac_, _miér_, _jinƙ, _állt_,
   {{0x6298b1fb,0x38600449,0x2ba7023a,0x628a00f0}},	//   levo, jair_, खिला, lffo,
   {{0x38607fd6,0x6135013f,0xd0f900c1,0x753c0634}},	//   dair_, _išla, _פּער, _lurz,
   {{0x66d2052f,0xb4e70285,0x62983763,0x2d85b1fc}},	//   _dækk, _पष्_, nevo, btle_,
   {{0x753c0063,0x66d201cd,0x00000000,0x00000000}},	//   _nurz, _tækj, --, --,
   {{0x38607fe9,0x765c022b,0x6b840090,0x66d2003e}},	//   gair_, _aery, _fqig, _fækk,
   {{0x14ab04f8,0xb8e30336,0x765cb0ac,0xf7730076}},	// [d350] _घोषण, _एच_, _bery, ظار_,
   {{0x62981cb4,0x645b00fd,0x628a029a,0x765c0178}},	//   jevo, _seui, jffo, _cery,
   {{0x3860b1fd,0x765cb1fe,0xba9a00ca,0xc56b0e27}},	//   bair_, _dery, _הסתי, شحال_,
   {{0x3860a10f,0x291e05fe,0xf8bf0131,0x79850372}},	//   cair_, ïtat_, _viés_, _iqhw,
   {{0x645b025a,0x6aa50808,0x765c39b9,0xd7f873a0}},	//   _veui, _kahf, _fery, _дур_,
   {{0x62980934,0x95cb0881,0xe2995e0d,0xe7f80f42}},	//   gevo, _куба_, сак_, ंपरा_,
   {{0x645b03a9,0x753c006d,0x6aa500dc,0x248d0131}},	//   _teui, _gurz, _mahf, _tbem_,
   {{0x673db1ff,0x00000000,0x00000000,0x00000000}},	//   _kusj, --, --, --,
   {{0x73d905c7,0x6298342c,0x753c0364,0x765c0233}},	//   _удар_, bevo, _zurz, _yery,
   {{0x764522d4,0x66d201c5,0x6298b200,0xd25100e3}},	//   nchy, _rækk, cevo, _أنا_,
   {{0x3860005c,0xdca62383,0xb0350012,0x673502a1}},	//   yair_, пани, _енеш, _mizj,
   {{0x38600090,0x2d0602d5,0xeb9a05ed,0xfaff0216}},	//   xair_, रवेल_, бим_, krës_,
   {{0x386000ee,0x2d85b201,0x239d0154,0x7985039f}},	//   vair_, stle_, _jňj_, _aqhw,
   {{0xfc3f0610,0xfaff023b,0x66d202b6,0x6735af22}},	//   rdía_, drës_, _vækk, _nizj,
   {{0x386057ca,0xfaff0052,0xdb04033c,0x00000000}},	//   tair_, erës_, _criá, --,
   {{0x765cb202,0x673d029a,0xe207007f,0x20d8033c}},	//   _sery, _busj, ciół_, _léin_,
   {{0x3860b203,0x765cb204,0x969610f7,0x6d4100a7}},	// [d360] rair_, _pery, зреш, lqla,
   {{0x38600a02,0xfc3fb205,0x7e61b206,0x673d0120}},	//   sair_, ndín_, nalp, _dusj,
   {{0x80db0abe,0x1dcb16f8,0x2a5700ca,0xba9b00ca}},	//   बसाइ, ाहित, _מבין_, _פסטי,
   {{0xa3d70096,0x6281039f,0xfaff0216,0x765cb207}},	//   ानं_, _aclo, brës_, _wery,
   {{0x7e610029,0x6298b208,0xaae500cd,0x753c0364}},	//   kalp, tevo, _رسیو, _wurz,
   {{0x753cb209,0x6281009c,0xdea301c2,0x20d8033c}},	//   _turz, _cclo, _tinƙ, _céin_,
   {{0x78a603ce,0x6298b20a,0x628a02ad,0x6913026a}},	//   _kakv, revo, rffo, rçev,
   {{0x64a35cc6,0x40342c4c,0x318e00a7,0x00000000}},	//   _паса, мейс, _cəza_, --,
   {{0x20d8054f,0x6298a8f3,0xa3d702d5,0x20020092}},	//   _féin_, pevo, ानः_, çki_,
   {{0x7e61037a,0xe8040034,0x26ca0113,0x62810076}},	//   galp, _रखना_, _jobo_, _gclo,
   {{0x78a6b20b,0x201904c8,0x5d63002d,0x00000000}},	//   _oakv, ýsir_, нтяз, --,
   {{0x98ab00ae,0x76450094,0x94200096,0x78a600c6}},	//   _mică_, zchy, _बराच_, _nakv,
   {{0x6b9d01c0,0x66d3026a,0x613500d8,0x00000000}},	//   uwsg, _yıkı, _ušla, --,
   {{0x7e61034f,0x6125003e,0x673d05db,0x8f9b0327}},	//   calp, gólf, _rusj, _לידי,
   {{0x673db20c,0x78a606cd,0xbd871a13,0x6d4a2ba4}},	//   _susj, _bakv, _فنون_, _utfa,
   {{0xfaff0052,0x23660216,0x00000000,0x00000000}},	//   trës_, ksoj_, --, --,
   {{0x6aa50332,0x213e80c4,0x6735037a,0x4735013f}},	// [d370] _tahf, _luth_, _pizj, днас,
   {{0xfaff023b,0xdb0406cb,0xb99900d6,0x26ca01dc}},	//   rrës_, _triá, _двох_, _cobo_,
   {{0x764500f0,0x26ca033b,0xfc3f0328,0xddcd0138}},	//   rchy, _dobo_, ndío_, _įkūr,
   {{0xe4e4116d,0x66d301e8,0x6615030b,0xb4d74694}},	//   нічн, _sıkı, _vyzk, िसे_,
   {{0x65658131,0xa7fb01ff,0x20d8009c,0x00000000}},	//   sshh, _beñe, _péin_, --,
   {{0xb87b002b,0xf2c71402,0x213e01ec,0xe82202d5}},	//   _emít, ясен, _buth_, _मरता_,
   {{0x26fb04dd,0x6594457f,0x7d0f0103,0x90d50023}},	//   ्वीर_, _пару, kocs, _dùn,
   {{0x213e009c,0x318e00a7,0xb465001c,0xe1f00981}},	//   _duth_, _qəza_, _آگاه, دسه_,
   {{0x7e61b20d,0x64490139,0x7d0f2bd6,0xdee51230}},	//   talp, _ifei, docs, допи,
   {{0xe3b000b1,0xef160084,0xb87b00b6,0x1e951d3f}},	//   _حرف_, ммы_, _hlíd, фрир,
   {{0xfc3fb20e,0x213e0a02,0x7e61b20f,0x6913b210}},	//   rdín_, _guth_, ralp, nçes,
   {{0x7e6144c4,0xe3e40081,0x2d6701ac,0xa7fb0062}},	//   salp, _ফুটব, rđe_, _zeñe,
   {{0xef0e0a29,0x7e610270,0x78a600aa,0x2d6700e7}},	//   _ам_, palp, _rakv, sđe_,
   {{0xb4ba0ed3,0xed590831,0x66d20088,0x69130233}},	//   _अच्_, _док_, _tæki, kçes,
   {{0x26cab211,0x78a60138,0x7d0f01f9,0x00000000}},	//   _robo_, _pakv, bocs, --,
   {{0x693c005f,0x26cab212,0x00000000,0x00000000}},	//   _očev, _sobo_, --, --,
   {{0xf7720080,0x3ea78d81,0x26ca08a8,0x59ba1ae6}},	// [d380] ضاء_, _kant_, _pobo_, _उपकर,
   {{0x64490165,0x68ef02a1,0x6125003e,0x2366015c}},	//   _afei, _emcd, bólg, vsoj_,
   {{0x78a602e6,0x693c0095,0xa9263968,0x60cb5cc0}},	//   _takv, _ačev, _одол, _oogm,
   {{0x26ca0c56,0x60cb77a0,0x3ea7b213,0x3f9f0294}},	//   _wobo_, _nogm, _lant_, kwuu_,
   {{0x2b7b006e,0x26ca0113,0x225eb214,0x00000000}},	//   ַטקײ, _tobo_, _petk_, --,
   {{0x64490396,0x3ea700f0,0x610101d3,0x246e0023}},	//   _efei, _nant_, vēla, ộm_,
   {{0xa7fb03be,0x64490150,0x60cbb215,0xdb0400ee}},	//   _veñe, _ffei, _bogm, _eriç,
   {{0xa6db003e,0x3ea701cb,0x20d80131,0x00000000}},	//   _guðb, _aant_, _véio_, --,
   {{0xa7fb0933,0x60cb0085,0xe29208ba,0x3ea7b216}},	//   _teñe, _dogm, _لذا_, _bant_,
   {{0x20180029,0xdb0d0072,0x0323002d,0x3ea7b217}},	//   āri_, _traé, _адун, _cant_,
   {{0x6b960138,0x3ea70178,0x8af700a7,0x00000000}},	//   _apyg, _dant_, şəka, --,
   {{0xfc3f0328,0x00000000,0x00000000,0x00000000}},	//   rdío_, --, --, --,
   {{0x3ea700d6,0x9b58008f,0xc5f800e8,0x80080103}},	//   _fant_, мият_, _žēl_, _عرصہ_,
   {{0x3ea76595,0x00000000,0x00000000,0x00000000}},	//   _gant_, --, --, --,
   {{0x20d800e3,0x8caa0557,0xdb0d00fd,0xdce201d3}},	//   _léim_, _जोको, _fraî, gulē,
   {{0x25f466d3,0x23690106,0xcd2b001c,0x3ea700b3}},	//   ्पनी_, šaji_, _بستن_, _zant_,
   {{0x2126009c,0x66b502a0,0x00000000,0x00000000}},	// [d390] _mhoh_, нбау, --, --,
   {{0x4a5500d6,0x333f008a,0xfc3f00b6,0x21260449}},	//   _якос, _ruux_, zdíl_, _lhoh_,
   {{0x2ca93791,0x64490364,0xa2c2142e,0xaaa832c9}},	//   _kaad_, _pfei, लान्, _छोटक,
   {{0x20d80037,0x2a7f01c2,0x2ca9026d,0xfd5e020b}},	//   _béim_, ɗuba_, _jaad_, _suyễ,
   {{0xe66711d9,0x20d80037,0x69d52b4f,0x2ca91350}},	//   _отво, _céim_, lyze, _maad_,
   {{0x2ca9b218,0x66d2003e,0x3941010a,0xe804007f}},	//   _laad_, _bæku, _kuhs_, _रखता_,
   {{0xb87b030b,0x00000000,0x00000000,0x00000000}},	//   _umís, --, --, --,
   {{0x3ea7b219,0x3a380054,0x7af501ff,0xdbc70233}},	//   _sant_, ורום_, hizt, _göçm,
   {{0x20d80503,0x00000000,0x00000000,0x00000000}},	//   _géim_, --, --, --,
   {{0xa3ac00b6,0x00000000,0x00000000,0x00000000}},	//   गिर_, --, --, --,
   {{0xa3d705cd,0x3ea7b21a,0xc6920341,0x2ca90188}},	//   ानक_, _vant_, נאט_, _baad_,
   {{0x3ea70054,0xeb9a0a80,0x98ac01d3,0x20d10503}},	//   _want_, пим_, īdī_, _cáit_,
   {{0x3ea7b21b,0x2ca9835f,0x212d03e3,0xaed5007b}},	//   _tant_, _daad_, mmeh_, _подш,
   {{0xbea2176e,0x693c0087,0x7af51415,0x00000000}},	//   _башк, _očet, gizt, --,
   {{0x09e61a18,0xc5fa0081,0x682a0018,0xf2d2006e}},	//   ховн, _অর্থ_, ködé, נעל_,
   {{0x98a337fa,0x2ca901ee,0x00000000,0x00000000}},	//   лисе, _gaad_, --, --,
   {{0x6676001c,0xcb6a001c,0x7d044e3b,0xdb0d0094}},	// [d3a0] فدار, _عمده_, _ijis, žkác,
   {{0xa3b304dd,0x3ce0023e,0x69c8052f,0x7c2405bd}},	//   टिन_, _hliv_, ødes, _izir,
   {{0xe7f00557,0x69c100aa,0x610100e8,0xfc3f023c}},	//   _घेरा_, älet, vēln, zdím_,
   {{0x20d14b1f,0xe73a4223,0x29022a3e,0x2ca9008c}},	//   _máis_, _нем_, _ujka_, _xaad_,
   {{0x883b0054,0x29120060,0x98161629,0xc1c802c6}},	//   _מתכו, moya_, _سبحا, िङ्ग,
   {{0x68e4b21c,0x2126023b,0x29002214,0xf1a66b5b}},	//   lhid, _shoh_, lnia_, ерин,
   {{0x3ce0b21d,0xdb040313,0x29004638,0x7d1600d4}},	//   _oliv_, _asië, onia_, _okys,
   {{0x7c2402dd,0xb87b7e46,0x29004562,0x71f70190}},	//   _ozir, _ilíc, nnia_, عروس_,
   {{0xd2520080,0x2ca91f49,0x7c242ac5,0x29008674}},	//   _منذ_, _raad_, _nzir, inia_,
   {{0x15f40b7f,0x2ca9b21e,0x7d04b21f,0x63a2612b}},	//   _आधार_, _saad_, _ajis, mwon,
   {{0x3ce001c5,0x20d600d6,0x2912010a,0x7c242d3b}},	//   _bliv_, _підс, koya_, _azir,
   {{0x2ca90188,0xa7fb0143,0x212602ac,0x69d50206}},	//   _qaad_, _leña, _uhoh_, vyze,
   {{0x29000067,0x63a2b220,0x693c0087,0x29120167}},	//   dnia_, nwon, _očes, doya_,
   {{0x29000067,0x657e067d,0x7c2400d9,0x2ca9008a}},	//   enia_, kuph, _dzir, _waad_,
   {{0x29120139,0x6125266c,0x38622acb,0x20d10076}},	//   foya_, sóle, _bekr_, _gáis_,
   {{0x63a2b221,0x2900008f,0x2912006d,0xa3e00c17}},	//   kwon, gnia_, goya_, दना_,
   {{0xb87bb222,0x4424007e,0x7c2400bd,0xa7fb2681}},	// [d3b0] _alíc, _nzm_, _gzir, _beña,
   {{0x2900b223,0x7d04030b,0x63a20371,0x7d1d5025}},	//   ania_, _zjis, dwon, llss,
   {{0x2912b224,0x68e45b4e,0x63a201c0,0x66d2003e}},	//   boya_, bhid, ewon, _rækt,
   {{0x693cb225,0xdb040154,0x68e43d33,0x610100e8}},	//   _včet, _asiè, chid, vēlo,
   {{0x03a51339,0x63a20172,0x00000000,0x00000000}},	//   тило, gwon, --, --,
   {{0xe2960fa5,0x78adb226,0xf8bf00de,0x610100e8}},	//   ваш_, ldav, _khéo_, tēlo,
   {{0x693c0087,0xb87b0072,0x80aa0033,0x63a206b0}},	//   _hčer, _glíc, কান্, awon,
   {{0x78adb227,0x693c0357,0x63a22cd0,0x27e914f3}},	//   ndav, _kčer, bwon, ozan_,
   {{0x27e9b228,0x443fa9d5,0x93940604,0x645902a4}},	//   nzan_, _igu_, _مجلا, mbwi,
   {{0x7d16b229,0x2900b22a,0x59b3000c,0x443f0167}},	//   _skys, znia_, ुमार, _hgu_,
   {{0x1d0a1510,0x3ce0023e,0x29003720,0x41740246}},	//   дени_, _pliv_, ynia_, _مانس,
   {{0x2369005f,0x764903a3,0xcb6a0832,0x693c0095}},	//   šaju_, _şeyl, маме_, _očer,
   {{0x68e4b22b,0x83fd0018,0x60db0239,0x62831192}},	//   vhid, _idős, mkum, ogno,
   {{0x78bd09ce,0x68e4b22c,0x6283b22d,0x66d2052f}},	//   _ansv, whid, ngno, _lækr,
   {{0x3f8d3a17,0x68e40441,0x29002fcc,0x443fb22e}},	//   lteu_, thid, tnia_, _ogu_,
   {{0x443fb22f,0xa7fb14e2,0x60dbb230,0x7e630899}},	//   _ngu_, _seña, nkum, _henp,
   {{0xa6860d72,0x6d43b1e6,0x2912b231,0x3f8d05fe}},	// [d3c0] клад, _huna, roya_, nteu_,
   {{0x6d43b232,0x68e4b233,0x5b7b040a,0x394600c2}},	//   _kuna, shid, _קריא, _иног,
   {{0x60db7f6a,0x64a663df,0x7e6301e9,0xdb040072}},	//   kkum, кажа, _menp, _oriú,
   {{0x7529b234,0x63a2b235,0x443fb236,0x385a0018}},	//   _chez, twon, _cgu_, _تشدد_,
   {{0x6d43b237,0x31da030b,0xa7fb08a8,0xa80300a9}},	//   _luna, बन्ध, _teña, _взял,
   {{0x7e630c56,0x66d201c5,0x63a2b238,0xb87b5d30}},	//   _nenp, _væks, rwon, _ilía,
   {{0x6d430044,0x693c0c27,0x63a245cd,0x55790fe9}},	//   _nuna, _učes, swon, _пётр_,
   {{0x7c3b1197,0x63a20126,0x752943c3,0x60db2447}},	//   žuri, pwon, _ghez, gkum,
   {{0x673c1c73,0x68e300d3,0x6d43b239,0x7ce60037}},	//   _kirj, _înde, _auna, _mórd,
   {{0x6d43b23a,0x661c2452,0xa3cf0034,0x59d2049d}},	//   _buna, _kyrk, शहर_, सहार,
   {{0x7e63b23b,0x6d43b23c,0x867b00a1,0x6d440220}},	//   _denp, _cuna, וריו, _čias,
   {{0x6d431098,0x7ce60165,0x9f640103,0x7e639fda}},	//   _duna, _nórd, ától_, _eenp,
   {{0x7d1d37a5,0x78ad0559,0x3f8d0428,0x03c50139}},	//   rlss, vdav, cteu_, _bóṣe,
   {{0xdb0d0933,0x67da00d9,0x00000000,0x00000000}},	//   _traí, _mājā, --, --,
   {{0xb87b0143,0x69c80430,0x661c007b,0x7b0500e8}},	//   _alía, ødep, _nyrk, _ērtā,
   {{0x7ce66117,0x27e90a00,0x20180092,0x764e02ac}},	//   _córd, tzan_, ərir_, _afby,
   {{0x78ad5985,0x6d4302dd,0x673c33a7,0x3d0f009f}},	// [d3d0] rdav, _zuna, _birj, सवीं_,
   {{0x6d43b23d,0xe71900e3,0x443f052f,0x60db00b6}},	//   _yuna, ريات_, _sgu_, zkum,
   {{0x693c0ec8,0x78ad65bd,0x673c9a3a,0x75290060}},	//   _včer, pdav, _dirj, _phez,
   {{0x661c0856,0x61250088,0xa6db003e,0x3cf900c4}},	//   _dyrk, kóla, _guðn, nisv_,
   {{0xdfc60fb7,0xf8bf0181,0x38691575,0x291900e7}},	//   _اي_, _iné_, maar_, _iksa_,
   {{0x386904ee,0x9f9c0088,0x61350138,0xdce200c6}},	//   laar_, _ræða_, _išli, bulė,
   {{0x443f00dc,0x8145001c,0x753b0131,0x7e630154}},	//   _tgu_, دنبن, _tiuz, _renp,
   {{0x443f025e,0x38690934,0x6d43b23e,0x7e63b23f}},	//   _ugu_, naar_, _runa, _senp,
   {{0x60c9113a,0x60dbb240,0x776d0933,0x6d43b241}},	//   rjem, rkum, nsax, _suna,
   {{0x6d434d64,0xfe7100e3,0x3f8db242,0x60dbb243}},	//   _puna, حدة_, rteu_, skum,
   {{0x38690db8,0x26d103be,0x415519e8,0x3f8d1f4a}},	//   kaar_, _mozo_, _свес, steu_,
   {{0x38690cad,0x7e630f5a,0x3f8d0428,0x2d4800fc}},	//   jaar_, _wenp, pteu_, _dûe_,
   {{0xd11008e7,0xf8bf00de,0x3869b244,0x7e6301e9}},	//   ावरण_, _chém_, daar_, _tenp,
   {{0x6d43788a,0xf8bf2502,0x7ce60072,0x776d23bc}},	//   _tuna, _ané_, _sórd, dsax,
   {{0x09e30058,0x6d437b23,0x41b30285,0xf1b30285}},	//   борн, _uuna, ंटिस, ंटिन,
   {{0x4c860752,0x673cb245,0x63a92655,0x38693337}},	//   _слив, _sirj, _osen, gaar_,
   {{0x63a9359c,0xdd0401d3,0x661c00dc,0x673c783c}},	// [d3e0] _nsen, šsēd, _syrk, _pirj,
   {{0x661c00c2,0x6b5b0266,0x673c0216,0x00000000}},	//   _pyrk, _רדיפ, _qirj, --,
   {{0x38692ddf,0x63a9b246,0xa2c22ebd,0x44221ea1}},	//   baar_, _asen, लास्, _šk_,
   {{0x98ba0012,0x938a0f32,0xf8bf0037,0x5983097a}},	//   _după_, еска_, _gné_, _улюб,
   {{0x63a90103,0x66741ac9,0x673c03e3,0xb87b96ba}},	//   _csen, _نگار, _tirj, _klín,
   {{0x661c1d46,0x610800b6,0x37cd0033,0x61ea042c}},	//   _tyrk, děla, _রেকর, tzfl,
   {{0x63a9b247,0x870700ae,0x7e685647,0xd6270307}},	//   _esen, _серв_, vadp, _боре_,
   {{0x6ad11677,0x2edc000d,0x26d17838,0x1c0402d5}},	//   _सक्र, यस्त, _zozo_, रपाल_,
   {{0xdfd00037,0x00000000,0x00000000,0x00000000}},	//   زيد_, --, --, --,
   {{0x539b00a1,0x83fd0018,0x61466acb,0x2a6a0018}},	//   _אימו, _időp, _бежа, jabb_,
   {{0x3869008a,0xdd9400c6,0x02d5376e,0xa3ac1da8}},	//   yaar_, шаны, _тютю, गिक_,
   {{0x13d80081,0x705600e3,0x7e680009,0xd00f01dc}},	//   _দেয়, _إنشا, sadp, _کله_,
   {{0x3869159f,0xfd1f00e5,0x7e6807ac,0xbebc00e8}},	//   vaar_, rlì_, padp, tlīd,
   {{0xa7fb11ce,0x38690305,0x32d905aa,0x2a6a01f9}},	//   _seño, waar_, _pèyi_, gabb_,
   {{0x3869b248,0x318e0092,0x6b8f0124,0xa7fb037a}},	//   taar_, _bəzi_, stcg, _peño,
   {{0x3eae0644,0x00000000,0x00000000,0x00000000}},	//   _haft_, --, --, --,
   {{0x386958a6,0x26d14467,0x25aab249,0xf7700037}},	// [d3f0] raar_, _pozo_, _asbl_, كال_,
   {{0xe94509b4,0x38694f93,0xa3b314e5,0xa3d80592}},	//   _پردی, saar_, टिस_, ाहन_,
   {{0x80ba04a9,0x3869b24a,0x63a90283,0x00000000}},	//   _शोभे, paar_, _ssen, --,
   {{0xa8a71612,0x63a909ac,0xdb160154,0xb87b00b6}},	//   _срок, _psen, _aryè, _zlín,
   {{0x3cfd000f,0xd7fb007e,0x26d10350,0xb4640120}},	//   _लगने_, _чун_, _tozo_, скіл,
   {{0x321e025b,0x612500a5,0xe29971b6,0x81b903e3}},	//   _byty_, góln, так_, _haɓɓ,
   {{0xd49b08a1,0x00000000,0x00000000,0x00000000}},	//   _пра_, --, --, --,
   {{0xdfd10080,0x63a900bc,0x6d440220,0x50b54f31}},	//   قيع_, _tsen, _čiap, рску,
   {{0x63a9b24b,0x82872ba0,0x3fc705bc,0x00000000}},	//   _usen, _مجال, ادعی_, --,
   {{0xe7f80034,0x273800a7,0x877c006e,0x00000000}},	//   ूपता_, tünə_, גאזי, --,
   {{0xa3b300a5,0xa2c2000c,0x6cc664ba,0xe81c00c3}},	//   टिव_, लार्, айна, _भुना_,
   {{0x61250165,0x78af00d4,0x00000000,0x00000000}},	//   mólo, _nacv, --, --,
   {{0x6125002b,0xb87b743b,0x00000000,0x00000000}},	//   lólo, _plín, --, --,
   {{0xd84f0174,0xab2a596a,0x00000000,0x00000000}},	//   _kọwa_, тога_, --, --,
   {{0x612509d3,0xb87b00da,0x2a6a01f9,0x68460c3f}},	//   nólo, _clío, rabb_, инва,
   {{0x2a6a0018,0xb87b0076,0xa3d83613,0x00000000}},	//   sabb_, _dlío, ाहम_, --,

   {{0xb8fe1091,0x16664070,0x9666007b,0x97480103}},	// [d400] _तक_, ивам, икае, اثرہ_,
   {{0xe9da08c3,0xf65604a1,0x3eae02a1,0x00000000}},	//   _ако_, ртаю, _xaft_, --,
   {{0xa6db0088,0x7a7b0341,0x546a5309,0x7afcb24c}},	//   _guðm, _בריס, ваем_, mirt,
   {{0x7afc0b88,0x81b901c2,0x6125266c,0x00000000}},	//   lirt, _gaɓɓ, dólo, --,
   {{0x33f60396,0x68e3020a,0x78a446be,0x69dcb24d}},	//   јчес, _înda, meiv, lyre,
   {{0x66e601c9,0x78a4b24e,0x81b903e3,0x78af110e}},	//   _тога, leiv, _zaɓɓ, _zacv,
   {{0x64a6559f,0x69dc64d3,0x32650120,0x60e62cc3}},	//   _кава, nyre, стів, ициз,
   {{0xc953193b,0xa3b313ae,0x78a400e7,0x2110270a}},	//   חמה_, टिश_, neiv, ावेश_,
   {{0x612500a5,0x69dc4743,0x7afcb24f,0x7649071d}},	//   póln, hyre, kirt, _şeyi,
   {{0x7522b250,0x7afc008c,0xa3b30dba,0x69dc01ff}},	//   lloz, jirt, टिर_, kyre,
   {{0x6125222b,0x7522077e,0x7afc4a43,0x10a60c59}},	//   cólo, oloz, dirt, _виен,
   {{0x69dcb251,0x752201cb,0x00000000,0x00000000}},	//   dyre, nloz, --, --,
   {{0x8f540397,0x60c2b252,0x3eae0085,0x799e0167}},	//   _انتش, _inom, _taft_, _appw,
   {{0x3f84b253,0x6e940192,0x260f0096,0x610101d3}},	//   mumu_, _طلبا, _तुझी_, vēli,
   {{0x5d840080,0x3f84b254,0x7522b255,0x00000000}},	//   _العل, lumu_, kloz, --,
   {{0x6d5a2df1,0x7afc02bc,0xdb0d0161,0x91fc01d3}},	//   mpta, airt, _oraç, _reāl,
   {{0x7afca11f,0x629a0087,0x3f84b256,0x61250103}},	// [d410] birt, _obto, numu_, zólo,
   {{0xc9871728,0x454500e3,0x7afc5a7c,0x69dc01df}},	//   _куми, منطق, cirt, byre,
   {{0xdb0d01e8,0x3f843061,0xc50b0018,0x69c800c2}},	//   _araç, humu_, پتال_, ädet,
   {{0x3f848f5c,0x451802ec,0xdb0d241b,0x78a400a1}},	//   kumu_, ація_, _braç, ceiv,
   {{0x3f840b4b,0x889a03c2,0x61fe0094,0x00000000}},	//   jumu_, _גברי, úpln, --,
   {{0x60c2b257,0x3f84b258,0x61250328,0x7522010a}},	//   _anom, dumu_, tólo, aloz,
   {{0x44290181,0xe05712eb,0xfa780327,0xd24e0037}},	//   ťa_, لیات_, בעות_, رني_,
   {{0x27ed0074,0xdb0d016d,0x61251ba6,0x85050103}},	//   _ženy_, _fraç, cóll, _اورن,
   {{0x3f84b259,0xdb0d001f,0xef19008f,0xfc3f0076}},	//   gumu_, _graç, лми_, idís_,
   {{0x2bcb06ed,0x0d850818,0x63bbb25a,0x61250143}},	//   ामना, блон, _irun, pólo,
   {{0xdc6a29db,0x6da5008f,0x63bb003e,0x290b007f}},	//   ланд_, щина, _hrun, _ojca_,
   {{0x3f84b25b,0x7afc01bf,0x2b410154,0xddc13b84}},	//   bumu_, wirt, _aihc_, galš,
   {{0x7ce600e3,0xeb97244f,0x7afcb25c,0x3f84b25d}},	//   _córa, бия_, tirt, cumu_,
   {{0x69dc02c2,0x63bb024a,0x7c28013c,0xa3d80285}},	//   tyre, _mrun, ədrl, ाहत_,
   {{0xf2d20130,0x7afc0102,0x09e324ec,0x3ea5b25e}},	//   לעך_, rirt, порн, melt_,
   {{0x7ce6054f,0x63bb0af0,0x26c30161,0xdcfb00d9}},	//   _fóra, _orun, _anjo_, putā,
   {{0x2d85a57a,0x7afcb25f,0x69dc0c96,0x78a464de}},	// [d420] lule_, pirt, syre, reiv,
   {{0x3ea514e3,0x7c57001c,0x69c80874,0xdaaa007e}},	//   nelt_, _پلیر_, ädes, _свод_,
   {{0x63bb0d4f,0x752241ec,0x41a60034,0xfad7006e}},	//   _arun, tloz, _कैंस, _הויך_,
   {{0x20d80080,0xdb0d0161,0xfd500065,0x3ea57aa0}},	//   _léir_, _praç, _aadọ, helt_,
   {{0x3ea51bfa,0x2d85b260,0xd91b00a1,0x261808d4}},	//   kelt_, hule_, _תוכל, _बुरी_,
   {{0x2d85b261,0x39420194,0x6d5ab262,0x3f84b263}},	//   kule_, _hiks_, ypta, vumu_,
   {{0xd13000fb,0x63bbb264,0x3ea57a1a,0x21670831}},	//   ومت_, _erun, delt_, бији_,
   {{0x3f84b265,0x63bbb266,0xdb0db267,0x9f54264b}},	//   tumu_, _frun, _traç, ович,
   {{0x63bb3a7b,0x39420006,0x3ea51f35,0x38600131}},	//   _grun, _miks_, felt_, ibir_,
   {{0x3f84b268,0x3ea5b269,0xd36f00e3,0xd84f0294}},	//   rumu_, gelt_, _أهل_, _họta_,
   {{0x2d85b26a,0x3860b26b,0x3f84b26c,0x171b006e}},	//   gule_, kbir_, sumu_, רויע,
   {{0x6d5a282c,0x39420934,0xdb04b26d,0x60c2019f}},	//   rpta, _niks_, _asià, _unom,
   {{0x3860b26e,0x3ea50429,0xddc10e94,0xdb0400b3}},	//   dbir_, belt_, ralš, _friü,
   {{0x2d851c7b,0x628a0429,0xde583006,0xd84f0134}},	//   bule_, ngfo, _такі_, _lọta_,
   {{0x2d85b26f,0x13c30081,0xf3f900ae,0x7e6a01ff}},	//   cule_, ্নয়, _veţi_, _iefp,
   {{0xdb0403be,0x7ce68737,0x5c1a0174,0x25bf00c4}},	//   _brió, _tóra, ọdụi, _čul_,
   {{0x6d4a72af,0x69c83a40,0x7d0d0167,0x6bda0018}},	// [d430] _hufa, äder, _ijas, _نوٹس_,
   {{0x6d4ab270,0x3ce9b271,0x7c2db272,0x62980381}},	//   _kufa, _hlav_, _izar, jfvo,
   {{0x3942b273,0xd84f0e62,0x3860003d,0xdcfb00ae}},	//   _fiks_, _bọta_, bbir_, cută,
   {{0x6d4a0b58,0x6f1ab274,0xa634004d,0x6aa702ef}},	//   _mufa, hotc, їнці, lejf,
   {{0xd37b4438,0x68eda2b8,0x2d850062,0x7d0d024a}},	//   уче_, mhad, zule_, _mjas,
   {{0x6d5800e9,0x68ed9669,0xa5e75d49,0x6d4a0154}},	//   _otva, lhad, _любл, _oufa,
   {{0x20d80080,0x6f1a0238,0x236001d3,0x3ce900d6}},	//   _réir_, dotc, ģija_, _olav_,
   {{0x63bb08da,0x68edb275,0xe0d9266a,0x3ea501bf}},	//   _trun, nhad, рви_, welt_,
   {{0x4439b276,0x6d5839c1,0x3ea5b25e,0x63bbb277}},	//   _às_, _atva, telt_, _urun,
   {{0x2d85b278,0x6d4ab279,0x7d0d0673,0x7ce6002b}},	//   tule_, _bufa, _ajas, _córn,
   {{0x3cca08c3,0x70790177,0x3ea5254d,0x7c2db27a}},	//   ално_, _نماز_, relt_, _azar,
   {{0x3ea505a7,0x6d4ab27b,0x3ce900e7,0x2d85b27c}},	//   selt_, _dufa, _clav_, rule_,
   {{0xa3e90b94,0x7c2d00a5,0x2d85b27d,0xdb04222b}},	//   मनि_, _czar, sule_, _asiá,
   {{0x764700dd,0x7c2d005c,0x6f1a009c,0x2d85b27e}},	//   _ngjy, _dzar, cotc, pule_,
   {{0x442d030b,0x7c2d02a7,0x6d4a023f,0x3ce90124}},	//   _lze_, _ezar, _gufa, _flav_,
   {{0x68ed117b,0x442db27f,0xa92600d6,0x7d0d00dd}},	//   ghad, _oze_, ідал, _gjas,
   {{0x442d0283,0x6ecd0034,0x6d4a48a7,0x272f0233}},	// [d440] _nze_, तापु, _zufa, züne_,
   {{0x6125003e,0x98b901d3,0x63a00167,0x1db0b280}},	//   fólk, _visā_, _rpmn, _जनमत,
   {{0x68ed7893,0x394200d9,0x442db281,0x29090188}},	//   bhad, _tiks_, _aze_, bnaa_,
   {{0x68ed064b,0x76490491,0x7f43b282,0x6e230313}},	//   chad, _şeyt, _linq, _mynb,
   {{0xf7720f43,0x442d0034,0x78b6004b,0x00000000}},	//   _تاج_, _cze_, mdyv, --,
   {{0x6d442a3c,0x272f026a,0x68e4b283,0x69c30072}},	//   _liia, tüne_, lkid, _ánec,
   {{0x442d00ac,0xa7fb0143,0x84e6004d,0x7e6a033c}},	//   _eze_, _reñi, _довж, _refp,
   {{0x26d8b284,0x68e44f56,0x6d4a30ff,0x27e0008a}},	//   _horo_, nkid, _rufa, oyin_,
   {{0x6d58005f,0x27e0b285,0x7c2474ed,0xb87b0088}},	//   _stva, nyin_, _nyir, _slík,
   {{0x232a0465,0x7f43b286,0x63adb287,0x6d44009c}},	//   _този_, _cinq, çane, _aiia,
   {{0x29090694,0x7c2d268f,0xf65300a1,0x3ce92d11}},	//   ynaa_, _szar, וצת_, _plav_,
   {{0x26d8b288,0x6d4442e9,0x7c240079,0x44240031}},	//   _loro_, _ciia, _byir, _kym_,
   {{0x7f43015e,0xa7fb034f,0x7ce62ee8,0x6d4a0167}},	//   _finq, _teñi, _tórn, _wufa,
   {{0x26d8b289,0x6d4a7b6d,0xdb0403eb,0x7ce68bf9}},	//   _noro_, _tufa, _briñ, _fóro,
   {{0x68ed8424,0x5b1402ec,0x6d583135,0x6d4401b9}},	//   thad, ємст, _utva, _fiia,
   {{0x02b7033a,0x7d0d198d,0x68e400f9,0x7c2d4850}},	//   _आफ्न, _ujas, gkid, _tzar,
   {{0x68ed2c09,0x26d81cb5,0x7d1d5dab,0xf7730241}},	// [d450] rhad, _boro_, moss, باز_,
   {{0x68edb28a,0x7d1d2349,0xd5bb0205,0x26d8b28b}},	//   shad, loss, исе_, _coro_,
   {{0x26d80129,0x25480740,0x68ed3b2d,0x7649026a}},	//   _doro_, _oğlu_, phad, _şeys,
   {{0x7d1d8fed,0xe3b10dce,0xe4e40c10,0x44240034}},	//   noss, فرت_, мічн, _bym_,
   {{0x26d858d7,0xa3a7097d,0x27f20034,0x6ee4009c}},	//   _foro_, تحان, czyn_, _pòbl,
   {{0x6d02417a,0xa6db0088,0x26d8b28c,0xdb0d3906}},	//   _लगभग_, _auðv, _goro_, _araú,
   {{0x7d1d61b0,0xddc300d3,0x1a9c006e,0x7b090031}},	//   koss, _menţ, ייגע, tľuj,
   {{0x26d80294,0x7f43b28d,0xf8bf00de,0x54551ca3}},	//   _zoro_, _sinq, _ghét_, _хват,
   {{0x6d0204a9,0x7d1d0423,0x442d8fc9,0x6d440329}},	//   _लगबग_, doss, _uze_, _riia,
   {{0x68e401e9,0x6d4400aa,0x62670dce,0x7c240169}},	//   zkid, _siia, _ذائق, _ryir,
   {{0xa3b3022d,0x7c24063f,0xe16500cd,0x7d1d8aae}},	//   टिक_, _syir, _رضای, foss,
   {{0x692c01bf,0x27e004b7,0x6eed26e0,0x7d1db28e}},	//   eßen, yyin_, _súbd, goss,
   {{0xeb972a6e,0x395a037a,0x6d441d4b,0x6e230f5a}},	//   пия_, _stps_, _viia, _wynb,
   {{0x249f034f,0x273400bc,0x00000000,0x00000000}},	//   _lbum_, mäng_, --, --,
   {{0x26d89445,0x6f01b28f,0xc33200a1,0xf1bd0bf5}},	//   _roro_, milc, גום_, ्मिन,
   {{0x80a10067,0x26d837dc,0x7d1d2c68,0x6125b290}},	//   _कॉमे, _soro_, coss, fóli,
   {{0x26d8b291,0xdb040088,0x68e4b292,0x2900010a}},	// [d460] _poro_, _frið, rkid, riia_,
   {{0x68e4b293,0x7cf624e5,0x41bd00a8,0x44248d67}},	//   skid, ršru, ्मास, _rym_,
   {{0x27f20034,0x4424b294,0x27e0b295,0xf8bf020b}},	//   szyn_, _sym_, syin_, _phét_,
   {{0xf7460315,0x61252733,0xed56006e,0x249f009c}},	//   _немо, bóli, לבער_, _cbum_,
   {{0x61257ddd,0x6f010044,0x232a16d9,0xd8d7006e}},	//   cóli, kilc, боди_, _זוכט_,
   {{0xe737013d,0x249f0294,0xd0460092,0x00000000}},	//   _нея_, _ebum_, əməl, --,
   {{0x7ce60072,0x6f01033b,0x2ca000c4,0xf8bf00fe}},	//   _pórl, dilc, _obid_, _thét_,
   {{0x442417b5,0x249f2fcf,0x387201c2,0x2ca000bd}},	//   _tym_, _gbum_, nayr_, _nbid_,
   {{0x40530080,0x7d1d808c,0x6d5515b1,0x44240172}},	//   رئيس, voss, ízan, _uym_,
   {{0xd24f0037,0x2ca07653,0x620701f9,0xb23a0076}},	//   _منك_, _abid_, árlá, _هكذا_,
   {{0x06970054,0x7d1db296,0x10a62917,0x6449020e}},	//   הדים_, toss, _нижн, şmiş,
   {{0x7afe057a,0x239e01d3,0x00000000,0x00000000}},	//   _ampt, pājā_, --, --,
   {{0xe81c0ed3,0x6eed9e69,0x63a40231,0x00000000}},	//   _भुला_, _súbe, çinh, --,
   {{0x3f7b006e,0x610802c6,0x7d1db297,0x00000000}},	//   _פאוס, děli, soss, --,
   {{0xd30800ef,0x3a250021,0xfe9b0796,0x0e9b00ca}},	//   yện_, ælp_, _היומ, _השול,
   {{0x58d422ff,0x612508ec,0xb87bb298,0x7afe00d7}},	//   ност, tóli, _llív, _empt,
   {{0x5b1500ae,0x7b1500d3,0xc64b0076,0x273402c3}},	// [d470] _омит, _одих, مجال_, känd_,
   {{0xe8df0174,0xceb852eb,0xac990018,0x3f520023}},	//   _ipọd_, ndę_, _اچھا_, _mâu_,
   {{0x3f520028,0x94d50426,0x61250328,0x5fae0034}},	//   _lâu_, можц, sóli, _जैसल,
   {{0x2ea9030b,0x6fdc0034,0xb87b016d,0xa7fb034f}},	//   _कस्त, यहां, _alív, _señu,
   {{0xddc3025b,0xa6db0088,0x3f5200de,0xb87b0653}},	//   _menš, _suðu, _nâu_, _blív,
   {{0x2618023a,0xf8bf014b,0xceb8007f,0x00000000}},	//   _बुकी_, _thés_, jdę_, --,
   {{0x6f01b299,0x95080018,0xf48700ae,0x3f84010a}},	//   vilc, _کہنے_, _нуан, ermu_,
   {{0xb9250032,0x60d9008c,0x273402c3,0x00000000}},	//   _aipẹ_, _qowm, täng_, --,
   {{0x3f520028,0x442b00de,0xa3d8023a,0x8cd100a3}},	//   _câu_, _ác_, ाहः_, धानो,
   {{0x60060fdf,0x3f520019,0x0ecd0e4c,0x273402c3}},	//   ьным_, _dâu_, ़ाधड, räng_,
   {{0x6f01033b,0x81bc01d3,0xdb0d042c,0xbb1b044c}},	//   rilc, _dzēs, _spaß, trîn,
   {{0x13e100c7,0x6f010087,0xeb9a413c,0xddc301d3}},	//   _মেয়, silc, оим_, _cenš,
   {{0x6f01b29a,0xa2c20096,0x80090103,0x2734042c}},	//   pilc, लाच्, _براہ_, läne_,
   {{0xfe7100d0,0x3f9800d3,0x63a4008b,0x00000000}},	//   _شدت_, ărut_, çini, --,
   {{0xa3b4000d,0xbb430e4f,0x7b0902ef,0x611300ae}},	//   _छैन_, терк, džud, călc,
   {{0x52da007a,0xb87b003e,0x2618007f,0x200e00c4}},	//   _बक्स, _olíu, _बुगी_, šmiš_,
   {{0x48fd00b7,0x3cf90052,0x3f5200fe,0xf09200ca}},	// [d480] रोधो_, ërve_, _xâu_, כנן_,
   {{0xe737007e,0x6c680068,0x61e30185,0xddc80094}},	//   деу_, _بلکہ_, kynl, ladš,
   {{0x27340149,0x6ee401b9,0x00000000,0x00000000}},	//   vänd_, _dòbh, --, --,
   {{0x2d854450,0x2d530396,0x9dd6006e,0xd4670291}},	//   irle_, _mãe_, וועק_, дице_,
   {{0xb4ae0557,0x25ad0a39,0xd5b100fe,0x95f90285}},	//   _कसी_, _ćele_, _ấn_, ्पॉट_,
   {{0x98b9013f,0x3f52b29b,0x2492007f,0x6ee401b9}},	//   _visą_, _râu_, żym_, _gòbh,
   {{0x3f520019,0x05660c10,0x249d023e,0xda00121d}},	//   _sâu_, _іван, bfwm_, ोपित_,
   {{0xceb800a5,0xf99300a1,0x612501cd,0x00000000}},	//   wdę_, דרה_, kólu, --,
   {{0xb7db0130,0x2d85425a,0x98be0138,0x032612d1}},	//   ַקטי, erle_, ūtė_, _ждан,
   {{0x81bc00d9,0x1dc90285,0x00000000,0x00000000}},	//   _dzēr, िमंत, --, --,
   {{0x7ce60103,0xdb210103,0x6125065b,0xceb816c3}},	//   _kórh, _ítél, vólv, rdę_,
   {{0x6ee40472,0xa3b5007a,0x0fb60336,0x4103008f}},	//   _mòbi, _जनम_, _अनपढ, _изхв,
   {{0x2d850cf9,0x69c84796,0x69da0206,0x5eda0033}},	//   arle_, åden, äten, যোগে,
   {{0x1eaa0182,0x28e10d75,0xddd80233,0x00000000}},	//   _ذاتي_, _नवहि, _gevş, --,
   {{0x391507f3,0x26cd00de,0x19940b26,0x6113020a}},	//   емвр, _đeo_, каря, lăla,
   {{0xf8bf00de,0xdb0d0623,0x61250072,0x26ca0381}},	//   _chép_, _isaí, sólv, _anbo_,
   {{0xf7700602,0x2d8cb29c,0xb90702d5,0x473535ca}},	// [d490] لال_, lude_, _बक_, енас,
   {{0x6ee400ee,0x960707e8,0x00000000,0x00000000}},	//   _bòbi, وبام, --, --,
   {{0x2d8c00e9,0x885900ae,0x00000000,0x00000000}},	//   nude_, _нинс_, --, --,
   {{0xf8bf00de,0xb87b0143,0x980d0033,0xd7fb0307}},	//   _ghép_, _clít, _শরীফ_, _дуг_,
   {{0xb87b0037,0x2d8cb29d,0x6eed0503,0xdb04058f}},	//   _dlít, hude_, _lúba, _eriõ,
   {{0x41b51d5c,0x6595041e,0x2d8cb29e,0x78ad79f1}},	//   есит, _пагу, kude_, leav,
   {{0x2d8c7781,0xa3b3045f,0xe80300a3,0x00000000}},	//   jude_, टिङ_, _रेता_, --,
   {{0x2d8cb29f,0xa6db003e,0xfa0d0023,0x78ad45d9}},	//   dude_, _guðr, _đầu_, neav,
   {{0x61e3038c,0xf0760018,0x2d8c084e,0x00000000}},	//   synl, ریوں_, eude_, --,
   {{0x4d650c58,0x2d8c0172,0x61250231,0x00000000}},	//   нков, fude_, vólu, --,
   {{0x2d8c007a,0x6eed0503,0x00000000,0x00000000}},	//   gude_, _cúba, --, --,
   {{0x998d00a5,0xa10700cd,0x6eed0076,0x31560142}},	//   łeś_, _غذاه, _dúba, _װיסן_,
   {{0xb87b20df,0x78adb2a0,0x00000000,0x00000000}},	//   _moíd, deav, --, --,
   {{0x2d8c0074,0x91fc00d9,0x7ff40470,0x00000000}},	//   bude_, _teāt, _جسما, --,
   {{0xf8bf0028,0x2d8ca121,0x09ce0033,0x7ce60139}},	//   _phép_, cude_, রন্থ, _lóri,
   {{0xb4ae009d,0xa3cf000c,0x395e00d9,0x68461469}},	//   _कसे_, षमा_, īts_, енба,
   {{0xa7a72ba6,0xf7720037,0x5eb20033,0x3f8d0428}},	// [d4a0] нкта_, طاء_, জারে, nueu_,
   {{0x7d06b2a1,0x8c1b00a1,0x00000000,0x00000000}},	//   liks, _מופי, --, --,
   {{0xf8bf00de,0xc4860e20,0x645b033c,0x78ad0537}},	//   _thép_, елек, _bfui, beav,
   {{0x78ad0c5b,0xb87b9b0c,0x7d0665fa,0x798e392d}},	//   ceav, _coíd, niks, mubw,
   {{0xa2940f1e,0xd3262917,0xdce20abd,0xf7721f11}},	//   валі, ньки, ntlı, _حاج_,
   {{0x60cb96ee,0xd24f1f11,0x7ce60956,0xb87b1bb9}},	//   _angm, منه_, _dóri, _flís,
   {{0xe7370c5b,0xe3d80033,0x7d06007b,0x3eac20a8}},	//   _чер_, _দেখব, kiks, vedt_,
   {{0xd37200bf,0x859b00a1,0x673e0126,0x7bc4b2a2}},	//   _مهر_, _משלו, lmpj, _oriu,
   {{0x7d06b2a3,0x3f8d05fe,0x3eac00a2,0xff06013f}},	//   diks, gueu_, tedt_, еянн,
   {{0x2d8c8cda,0x798e35fe,0x7522083e,0x00000000}},	//   tude_, kubw, looz, --,
   {{0x7bc4b2a4,0x7d06b2a5,0x3eac13c8,0x69da00c2}},	//   _ariu, fiks, redt_, ätel,
   {{0x2d8cb2a6,0x9c130129,0xb87b00ee,0x7bc48ef0}},	//   rude_, kọta, _llír, _briu,
   {{0xdee60ce5,0xddd80103,0x78ad00f3,0x7bc44d25}},	//   _поди, _vevő, veav, _criu,
   {{0x657c2d5a,0x29020a4b,0x2d8cb2a7,0x798e0172}},	//   _ovrh, _amka_, pude_, fubw,
   {{0x78adb2a8,0x7d0690cd,0x98c70e2f,0x798e0512}},	//   teav, biks, нсал, gubw,
   {{0x61f50018,0x7bc400e5,0x673e029a,0x765c007f}},	//   _üzle, _friu, empj, _afry,
   {{0x69d82e00,0x1bd500ae,0x75220172,0xab620233}},	// [d4b0] _àven, _ропя, dooz, şüre,
   {{0xb87b02c6,0x798e1935,0x00000000,0x00000000}},	//   _plís, bubw, --, --,
   {{0x610800b6,0x28d1023a,0x6b9d042c,0x236d007f}},	//   něls, हादि, ltsg, _swej_,
   {{0xa879006e,0x69c5009c,0x673e01cb,0x765c030a}},	//   _קאָר, _irhe, ampj, _efry,
   {{0x386932c3,0x98ab0034,0x6e2a02ac,0x765c0178}},	//   mbar_, _chcą_, _lyfb, _ffry,
   {{0x7d067b35,0x212600f9,0x6b9d0364,0x386932e8}},	//   ziks, _akoh_, itsg, lbar_,
   {{0x75220283,0x41b20076,0x00000000,0x00000000}},	//   booz, لمور, --, --,
   {{0x3869b2a9,0x610800b6,0x9f520146,0x629c0212}},	//   nbar_, děls, ždým_, _öron,
   {{0x7d0620bc,0x6ee400b3,0x68e3020a,0x657c1b32}},	//   viks, _lòbu, _îndu, _zvrh,
   {{0x3f831e68,0x3869b2aa,0x394bb2ab,0x63a9b2ac}},	//   čju_, hbar_, _lics_, _ipen,
   {{0xee393840,0x7d06b2ad,0xcc8a001c,0x7bc40138}},	//   ьно_, tiks, ونده_, _sriu,
   {{0x7bc40995,0xa3b51592,0x60cb4df3,0xd7d1030b}},	//   _priu, _जना_, _ungm, समाच,
   {{0x3f8d05fe,0x2ef51b4d,0xde1600cd,0x38690ac1}},	//   queu_, _издр, فقیت_, dbar_,
   {{0x2d6e030b,0xe8ca030b,0x7d06b2ae,0x63a90051}},	//   bře_, ाञ्च, siks, _mpen,
   {{0x6b9d3994,0xb87b0131,0xc92a004d,0x3869042c}},	//   atsg, _alíq, довж_, fbar_,
   {{0x63a9a65a,0x6ba502c3,0x798eb2af,0x00000000}},	//   _open, åtgä, rubw, --,
   {{0x62810b27,0x657c02e6,0x7d04271c,0x69c501bf}},	// [d4c0] _odlo, _svrh, _imis, _erhe,
   {{0x75220a15,0x7d040090,0x7f4d0131,0xb87b033c}},	//   wooz, _hmis, _éaqu, _coíb,
   {{0x63a93884,0x3869b2b0,0xceb200a1,0x212d061d}},	//   _apen, bbar_, שיב_, kleh_,
   {{0x80a1114d,0x628100f0,0xe80302d5,0x7d04003d}},	//   _कॉले, _adlo, _रेवा_, _jmis,
   {{0x291203b4,0x3940b2b1,0xc1da02c6,0x7d046a0b}},	//   mnya_, mmis_, यङ्ग, _mmis,
   {{0x29122664,0x394087f1,0x68f6b2b2,0x613500c6}},	//   lnya_, lmis_, lhyd, _išly,
   {{0x7d04b2b3,0x291263c1,0x63a90393,0x39400138}},	//   _omis, onya_, _epen, omis_,
   {{0x2912b2b4,0x64a623d0,0x69c3b2b5,0x68f68753}},	//   nnya_, _шаба, _šnek, nhyd,
   {{0x2912005a,0xb426487a,0xa8e00023,0x9c130134}},	//   inya_, _شعرو, _độn, họra,
   {{0x291203b4,0x7d04b2b6,0x2d6e02c6,0xfc3f0143}},	//   hnya_, _amis, tře_, nfíe_,
   {{0x29122129,0xfdd00033,0x3869b2b7,0x6113044c}},	//   knya_, ান্ড, ybar_, călo,
   {{0x291202fa,0x6eed0072,0x6b9d1a04,0x6f030415}},	//   jnya_, _fúbo, ttsg, _emnc,
   {{0x291206ee,0x38694abf,0x394b0428,0xdb250103}},	//   dnya_, vbar_, _rics_, ősít,
   {{0x2fc61ef8,0x2912399b,0x6b9d0ac9,0xd00f001c}},	//   _irog_, enya_, rtsg, _بله_,
   {{0x2912063f,0x394b5370,0x386901bf,0x28c413cc}},	//   fnya_, _pics_, tbar_, _लोहि,
   {{0x7d1600dd,0x29120da3,0x2fc6b2b8,0x3ebc01ce}},	//   _gjys, gnya_, _krog_, _havt_,
   {{0x383507f4,0x3869b2b9,0x386604d8,0xa85400e5}},	// [d4d0] унар, rbar_, ñora_, ркуч,
   {{0x291206b0,0x2d9e0305,0xb87b124d,0x3869b2ba}},	//   anya_, otte_, _elíp, sbar_,
   {{0x2912005a,0x69c511aa,0x63a9243b,0x272f0018}},	//   bnya_, _urhe, _spen, lünk_,
   {{0x7ce61f1b,0x291200ec,0x7c2d30a3,0x3ebc13b9}},	//   _fóru, cnya_, _kyar, _lavt_,
   {{0x2fc60d7d,0xc48401b6,0xd2a92ac0,0x6d4d02ac}},	//   _nrog_, рлік, екле_, _miaa,
   {{0xe29600c9,0x68ed0a50,0xf8d1009d,0x27e9699b}},	//   гаш_, lkad, हावय, myan_,
   {{0x78bd08a3,0x6eedb2bb,0x27e9b2bc,0x10a5008f}},	//   _kasv, _súbo, lyan_, гийн,
   {{0x272f0103,0x6d4d019c,0x3d0200c3,0x7c2db2bd}},	//   künk_, _niaa, _लगें_, _oyar,
   {{0x27e9b2be,0x7c2d66f5,0x63a90010,0x2d9eb2bf}},	//   nyan_, _nyar, _upen, ette_,
   {{0x442db2c0,0x2fc6298b,0x29121d49,0xb06213e1}},	//   _iye_, _drog_, znya_, ääri,
   {{0xde056e54,0x442d98c9,0x7c2d6ff9,0x2912b2c1}},	//   упни, _hye_, _ayar, ynya_,
   {{0x78bd0b27,0x7c2d023f,0x27e9b2c2,0x442d0a15}},	//   _nasv, _byar, kyan_, _kye_,
   {{0xbea526d0,0xdb0d04d8,0x7c2d0193,0x442d02a4}},	//   _балк, _arañ, _cyar, _jye_,
   {{0x442d02ec,0x27e9b2c3,0xdb0d03be,0x291200ec}},	//   _mye_, dyan_, _brañ, wnya_,
   {{0x29122129,0x442d659f,0x7d0400bd,0x7529366c}},	//   tnya_, _lye_, _tmis, _okez,
   {{0x442db2c4,0x7ce6002b,0x68ed259e,0x35fb0033}},	//   _oye_, _córt, gkad, ্থাৎ_,
   {{0x291203b4,0x442da88c,0x27e9b2c5,0x7c2db2c6}},	// [d4e0] rnya_, _nye_, gyan_, _gyar,
   {{0x291203b4,0x7bcb0161,0x98a0b2c7,0x753b0079}},	//   snya_, _água, klić_, _ahuz,
   {{0x442db2c0,0x29122664,0x4a9b0130,0x1a9b00c1}},	//   _aye_, pnya_, _אייג, _אייע,
   {{0x442d26d8,0x68ed0222,0x753bb2c8,0x2912005c}},	//   _bye_, ckad, _chuz, qnya_,
   {{0x442d0193,0xf4870018,0x98a0007f,0x28d12fc2}},	//   _cye_, طانی, elić_, हारि,
   {{0x2d9e038c,0x78bd103b,0x68e300d3,0x29e103e3}},	//   ytte_, _zasv, _îndr, iɗan_,
   {{0x6abeb2c9,0x272f0103,0x442d00ca,0x98a00880}},	//   _mapf, zünk_, _eye_, glić_,
   {{0x442d05aa,0x3ea7016d,0x7df300a7,0x60db3ec1}},	//   _fye_, _abnt_, cəsə, gjum,
   {{0x2ef41e54,0x442d0a15,0x98ab0034,0x6d4d0313}},	//   изир, _gye_, _chcę_, _riaa,
   {{0x68edb2ca,0x7c2d0193,0x6d4d0167,0x979b006e}},	//   zkad, _ryar, _siaa, עשיק,
   {{0x7c2d10dd,0x6d4d0124,0x236001d3,0x7ce60031}},	//   _syar, _piaa, ģiju_, _nórs,
   {{0x27e97f49,0x272f0018,0x61e501bf,0x98a90031}},	//   yyan_, tünk_, ähle, tlač_,
   {{0x78bdb2cb,0x2d9e4e7d,0x6abe0193,0x9b58008f}},	//   _rasv, stte_, _bapf, лият_,
   {{0x78bd03ce,0xbebc0029,0x7ce600e3,0x272f0103}},	//   _sasv, glīt, _sórt, rünk_,
   {{0xc3330054,0x7ce64b71,0x78bdb2cc,0x7e7a058e}},	//   מוש_, _pórt, _pasv, matp,
   {{0x27e92e44,0xd7fb0231,0x00000000,0x00000000}},	//   tyan_, нуз_, --, --,
   {{0x68edb2cd,0x629ab2ce,0x7c2d01e8,0xd795008f}},	// [d4f0] rkad, _octo, _uyar, ризъ,
   {{0x68edb2cf,0x27e9b2d0,0x442db2d1,0x2d8c0a9f}},	//   skad, ryan_, _rye_, orde_,
   {{0x5455085f,0x27e9b2d2,0x442db2d3,0x2bc3009d}},	//   авет, syan_, _sye_, शिवा,
   {{0x442d0c56,0x7ce603be,0x2d8c0037,0x7e7a01af}},	//   _pye_, _hórr, irde_, hatp,
   {{0xe2991e13,0x672500c2,0x987a0266,0x2ca90090}},	//   вал_, pohj, _בארט, _mbad_,
   {{0x442d06a3,0x91e511f8,0x057713c3,0x00000000}},	//   _vye_, иоле, _مارد, --,
   {{0x442db2d4,0xf8bf01dc,0x2ca900c4,0x81c700e8}},	//   _wye_, _kaé_, _obad_, ktēš,
   {{0x3f9f0084,0x442d057a,0x00e500d3,0x98a02a6c}},	//   ttuu_, _tye_, ржин, rlić_,
   {{0x2d8c04ee,0x442d0201,0x60dbb2d5,0x98a01197}},	//   erde_, _uye_, rjum, slić_,
   {{0x2ca90498,0x63bb7fdd,0x26c1001c,0x2d830117}},	//   _abad_, _isun, ndho_, šjem_,
   {{0x3f9f0084,0x6da50a7c,0xe80c0abe,0xee36002d}},	//   stuu_, шина, _सेना_, инь_,
   {{0x8c46020f,0xdfd10076,0x00000000,0x00000000}},	//   иене, _ويا_, --, --,
   {{0x2d8cb2d6,0x5fa9030b,0x3f670395,0xbc1a0565}},	//   arde_, _कहिल, _стеб, тіні_,
   {{0x7ce615d0,0x80a10bf5,0x7a400018,0xcb67002d}},	//   _córr, क्रे, játé, раре_,
   {{0xf8bf01dc,0x00000000,0x00000000,0x00000000}},	//   _baé_, --, --, --,
   {{0xc95501b3,0x786613a4,0x3f5b0019,0x5fa92f8f}},	//   стры, рказ, _kêu_, _कहाल,
   {{0xb8de1f83,0x3f8d015e,0x63bb53ed,0x6abe02db}},	// [d500] _इस_, nreu_, _nsun, _tapf,
   {{0x8ca70034,0x657e01bf,0x98ab00e8,0x00000000}},	//   ट्ठो, tsph, ījās_, --,
   {{0xd9100814,0x63bbb2d7,0x98a634fc,0x23640113}},	//   _فیس_, _asun, _кине, _stmj_,
   {{0x64a63ba4,0x26d1b2d8,0x938a336f,0x61ee01bf}},	//   рада, _enzo_, вска_, _übli,
   {{0x93462edd,0xe3b20602,0x3f5b00de,0x26c13fbf}},	//   анде, ترا_, _nêu_, bdho_,
   {{0x3f8d05fe,0xfc3f0610,0x6d5a023b,0x2d8b0034}},	//   dreu_, nfía_, yqta, ącej_,
   {{0x7e7a0973,0x257c0139,0x63bb0372,0x00000000}},	//   vatp, _dálá_, _esun, --,
   {{0x38603a13,0x2d8c015c,0x1fa603a0,0x3f8d2226}},	//   ncir_, vrde_, арог, freu_,
   {{0xdfd000e3,0x7e7a015e,0x7649013c,0x00000000}},	//   سيد_, tatp, _şeyx, --,
   {{0x9ed80161,0x85440174,0xe465003e,0x629a1206}},	//   умот_, _ịghọ_, _þörf_, _ucto,
   {{0x073700a1,0x2d8c0db1,0x80b80eeb,0x667b006e}},	//   שאים_, urde_, ्यदे, כטיק,
   {{0xa06a131b,0x3f8d18ae,0x63a202ac,0x8fa60e3a}},	//   _рада_, breu_, oton, _ваде,
   {{0x63a2b2d9,0x92d80081,0x81c701d3,0x7e7a0234}},	//   nton, াসী_, rtēš, patp,
   {{0x62983500,0x81c701d3,0x39b80154,0x63a20131}},	//   ngvo, stēš, _bōs_, iton,
   {{0xed570303,0x58d50476,0x7c871e94,0xa9c449b7}},	//   _кој_, бовт, _купе, остк,
   {{0x3f5b00ef,0x63a2b2da,0xa3d60b42,0x2ca9008c}},	//   _yêu_, kton, िमा_, _ubad_,
   {{0xfb8500cd,0xddda12b8,0x63a2b2db,0x6d58024a}},	// [d510] _ادبی, katū, jton, _huva,
   {{0x6d58b2dc,0x63a211b9,0xf8bf00cd,0x39b805aa}},	//   _kuva, dton, _waé_, _fōs_,
   {{0xdfc60018,0x24550c5e,0x26c1008c,0x63bba45c}},	//   _کي_, مناس, rdho_, _ssun,
   {{0x6d58b2dd,0x63a2b2de,0x63bb0167,0xf4873a46}},	//   _muva, fton, _psun, ружн,
   {{0x7ae58ca9,0xd3080028,0x63a21ba1,0xe7840f2e}},	//   _koht, yệt_, gton, _муро,
   {{0x7ae502fd,0x3f5b00fe,0x7e781d80,0x21750b36}},	//   _joht, _rêu_, _nevp, буир,
   {{0x6d58b2df,0x63a2b2e0,0x256c0383,0x00000000}},	//   _nuva, aton, _vòlò_, --,
   {{0x63bb72f4,0x6ea9000d,0x3f8db2e1,0x5a1800ca}},	//   _tsun, ज्नु, treu_, יקון_,
   {{0x63bbb2e2,0xd371001c,0x3de40033,0x6d58058f}},	//   _usun, _رها_, _ফেলল, _auva,
   {{0x3f8d8056,0x6d58b2e3,0x5ea50bf4,0x79955658}},	//   rreu_, _buva, حمدل, kuzw,
   {{0x6d5857b1,0x69c70268,0x7e78007e,0x6eed0850}},	//   _cuva, jvje, _devp, _júbi,
   {{0xf1c3013f,0x6d58b2e4,0x69c70268,0x3f8d71d2}},	//   rašė_, _duva, dvje, preu_,
   {{0x7052006f,0x21c700fe,0x61b70285,0x6f656e50}},	//   _عنوا, _hđh_, _आनुष, _اهتم,
   {{0x543a00c1,0x611300ae,0x6d55002b,0x799512e6}},	//   טערא, dăli, ízas, fuzw,
   {{0x5d850080,0xc332040a,0x63a20018,0x8d9500e3}},	//   _البل, פול_, zton, _العش,
   {{0x3879033c,0x97da007b,0x00000000,0x00000000}},	//   _cesr_, льзу_, --, --,
   {{0x38604034,0x78b600e7,0x06860ed7,0xddc300b6}},	// [d520] rcir_, _čavč, йган, _jenž,
   {{0xf6562e9e,0x6d58008b,0x6d461a8a,0x065601b3}},	//   стаю, _yuva, lmka, стаў,
   {{0x27340149,0x463a30cf,0x2a5700ca,0x38790036}},	//   länk_, учая_, _לבין_, _fesr_,
   {{0x63a2b2e5,0x672302e6,0x6eed08a8,0xb0a6136b}},	//   tton, čnja, _dúbi, _कॉंग,
   {{0x6113044c,0x63a2b2e6,0xdb0d09a1,0x00000000}},	//   căli, uton, _eraõ, --,
   {{0xf8bf001c,0x04fa0033,0x21c7020b,0x00000000}},	//   _akéh_, েকের_, _bđh_, --,
   {{0xc05a0f6b,0xddda5873,0x68e63600,0x41c604d9}},	//   ліп_, ratū, _kokd, сёла,
   {{0x64a313f5,0x63a2b2e7,0x92d80081,0x6d58b2e8}},	//   _наса, pton, াসে_, _ruva,
   {{0x6d588ab9,0x69c70dd9,0x00000000,0x00000000}},	//   _suva, zvje, --, --,
   {{0x3f8a0146,0xdb040072,0x395a020d,0xe297085f}},	//   čbu_, _osiñ, _oups_, _гаф_,
   {{0x6b84b2e9,0x6eed0072,0x628808e8,0x7ae51d4b}},	//   _avig, _xúbi, _iddo, _roht,
   {{0xa15700a1,0x79951632,0xdd0700a7,0x68e60218}},	//   _הבאה_, vuzw, _döşl, _nokd,
   {{0x7ae5007b,0x69c80537,0x6ab5014b,0x00000000}},	//   _poht, æden, tezf, --,
   {{0x6b846f53,0x6d58b2ea,0x6b890335,0x6d46b2eb}},	//   _dvig, _tuva, šego, amka,
   {{0x6b840bc6,0xddc8705f,0x60c20350,0xb6c90103}},	//   _evig, ladž, _kaom, یائے_,
   {{0x3e4e0092,0x611300ae,0x79954ee2,0x69c7150c}},	//   mət_, tăli, ruzw, rvje,
   {{0xe8030557,0x69c7239f,0xddc800e9,0x7ae50181}},	// [d530] _रेखा_, svje, nadž, _toht,
   {{0x7bcd0a00,0x7d0fb2ec,0x60c2b2ed,0x00000000}},	//   _irau, lics, _laom, --,
   {{0x3e4e0092,0xddc80b14,0x69da007b,0x7bcd003e}},	//   nət_, hadž, ätet, _hrau,
   {{0x60c2b2ee,0x7bcd231b,0xdce2020a,0xfc3f0328}},	//   _naom, _krau, mplă, nfío_,
   {{0x889a040a,0xddc80d62,0x3e4e0092,0x31a1007f}},	//   _דברי, jadž, hət_, wóz_,
   {{0x3e4e00a7,0x4b7c006e,0x395a0085,0x776d0042}},	//   kət_, נאוו, _yups_, mpax,
   {{0x6aaa02dc,0x659410f7,0x6a9c00a1,0xa3b5074c}},	//   _öffe, _нару, אשונ, _जनक_,
   {{0x7a40003e,0x6f659289,0x62880517,0x60c203dc}},	//   _hátí, овиз, _eddo, _caom,
   {{0xb87b0579,0x7bcd01bb,0x7b090146,0x7d0f0103}},	//   _blíz, _nrau, ržuj, dics,
   {{0x0d85184d,0xe45000e3,0x3e4e0092,0x776d0042}},	//   олон, _أضف_, fət_, ipax,
   {{0x7bcd02a7,0x26c3b2ef,0xc69200a1,0x6b8408ca}},	//   _arau, _majo_, ואי_, _svig,
   {{0x7bcdb2f0,0x2d8b00b6,0x6d46b2f1,0x395a3d39}},	//   _brau, čce_, umka, _rups_,
   {{0x28c409d0,0x7bcd01af,0xfd620294,0xb87b0072}},	//   _लोगि, _crau, _katọ, _coím,
   {{0x7bcdb2f2,0x3e4e0092,0x7d0f009c,0x290b047e}},	//   _drau, bət_, aics, _amca_,
   {{0x7bcd0634,0x60c28dbe,0x00000000,0x00000000}},	//   _erau, _yaom, --, --,
   {{0x26c30032,0x290b0063,0x7bcd1754,0x28d1009f}},	//   _aajo_, _cmca_, _frau, हागि,
   {{0x26c314e2,0x6b8403be,0x07a31553,0x656900e7}},	// [d540] _bajo_, _uvig, матн, _čeha,
   {{0x249f0012,0x57ba000d,0xeb9100c1,0x69c80212}},	//   _acum_, _उनीह, _אָט_, ådes,
   {{0xe45a0b99,0xa2dd030b,0x26c3b2f3,0x630f0033}},	//   аже_, पान्, _dajo_, াকায়_,
   {{0x69c80031,0x136a19d4,0x00000000,0x00000000}},	//   ťdes, ашки_, --, --,
   {{0xf74622ee,0x4420b2f4,0x00000000,0x00000000}},	//   _мемо, çi_, --, --,
   {{0x3e4e01d4,0x3872004d,0xddc30090,0x6b8b02b6}},	//   yət_, lbyr_, _benż, _ægge,
   {{0xaacb030b,0xe61700ae,0x6f000065,0x00000000}},	//   ायतक, _ддр_, _lábù, --,
   {{0x89db00ca,0x3e4e00a7,0xc0ca0291,0xdcfb01d3}},	//   שחקי, vət_, руке_, kstā,
   {{0x63ad00dd,0x69cc009d,0xe29a3456,0x00000000}},	//   çant, हिडी, _ваз_, --,
   {{0x2018002d,0xddc82a6c,0x60c20239,0x2ca03794}},	//   ări_, radž, _waom, _acid_,
   {{0x60c2b2f5,0xb65b00c1,0xaade00b6,0x7bcd0138}},	//   _taom, ידיש, मानक, _srau,
   {{0xcd0702ec,0x3e4e01d4,0x7cff0052,0x7bcdb2f6}},	//   ічни, rət_, _mërg, _prau,
   {{0x7ac71dde,0xdcfb00d9,0x3e4e0092,0x2ca0009c}},	//   осве, gstā, sət_, _dcid_,
   {{0x6eed0032,0xb0a600c3,0x387f0117,0x00000000}},	//   _búbu, क्रग, _žur_, --,
   {{0x7d0f01c0,0x0e750220,0x26c30188,0x58d53051}},	//   pics, äčší, _rajo_, повт,
   {{0x58d40ff7,0x26c35a7b,0x7bcdb2f7,0x6f000139}},	//   мост, _sajo_, _trau, _fábù,
   {{0x7cff01e5,0x6fbc018b,0x7d0db2f8,0x31b7152c}},	// [d550] _përf, ्टिं, _imas, _आन्ध,
   {{0x8ca7022d,0x00000000,0x00000000,0x00000000}},	//   ट्रो, --, --, --,
   {{0x2bc30e52,0x2aba00ca,0x3aba00ca,0x44b503bf}},	//   शिका, _המתא, _המתנ, збес,
   {{0x7cff00dd,0xf99200f5,0xfd620134,0x7d0d3079}},	//   _dërg, _ארט_, _satọ, _jmas,
   {{0x3949b2f9,0x7d0d0129,0x00000000,0x00000000}},	//   mmas_, _mmas, --, --,
   {{0x39493358,0x850505bc,0x1fd00081,0x7d0d0e26}},	//   lmas_, _کورن, িহাস, _lmas,
   {{0x394910d9,0x2d8a75cf,0x7d0db2fa,0x3f8401d3}},	//   omas_, ábel_, _omas, esmu_,
   {{0x69cc009d,0x394971cb,0x6b4b00bd,0x2734007b}},	//   हिती, nmas_, _iżgu, väni_,
   {{0x44394b1f,0x394901d3,0x3cdf0096,0xdcfb0138}},	//   _ás_, imas_, गाने_, lutė,
   {{0x7d0d2d3b,0x443f00ac,0x3f86030b,0xb87b0072}},	//   _amas, _izu_, _dvou_, _elíx,
   {{0xdcfb013f,0xcee800cd,0x8cd80557,0xe8030d75}},	//   nutė, ترين_, यालो, _रेघा_,
   {{0x7d0d01b9,0xcb090327,0x80a20336,0x6113020a}},	//   _cmas, _גל_, _गाये, tălu,
   {{0x443f02ef,0x2fc90076,0x2734007b,0x00000000}},	//   _jzu_, _éag_, säni_, --,
   {{0xdcfb00d9,0x7d0db2fb,0x656900e7,0x7a210174}},	//   rstā, _emas, _čehn, _ịtal,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443fb2fc,0x2ca00188,0xdcfb2207,0x00000000}},	//   _ozu_, _ucid_, dutė, --,
   {{0x81b10081,0x6d5606a8,0x443f17e0,0x387200f3}},	// [d560] টটি_, _iiya, _nzu_, rbyr_,
   {{0x7cff074a,0xaa46b2fd,0x6d566fd4,0x69cc007a}},	//   _përg, _непл, _hiya, हिदी,
   {{0x6d440197,0x6d563ad3,0x443f0129,0x7e7e007a}},	//   _khia, _kiya, _azu_, _õppe,
   {{0x6d56b2fe,0x3949b2ff,0x7cff0052,0x00000000}},	//   _jiya, cmas_, _gërd, --,
   {{0x6d56b300,0x6d440a02,0x00000000,0x00000000}},	//   _miya, _mhia, --, --,
   {{0x2912b301,0x6d563c9f,0x6ef60257,0xd2500018}},	//   liya_, _liya, _câbl, نچا_,
   {{0x3f86030b,0x443f0129,0xdcfb00ae,0x27f200c2}},	//   _svou_, _ezu_, nstă, lyyn_,
   {{0x2912b302,0x6d56b303,0x2900001f,0x68e4b304}},	//   niya_, _niya, nhia_, njid,
   {{0x7c240052,0x00000000,0x00000000,0x00000000}},	//   _nxir, --, --, --,
   {{0x6d440134,0x2912152a,0x64401172,0x6d5602a6}},	//   _ahia, hiya_, _izmi, _aiya,
   {{0x6d56b305,0x3949013f,0x2912b306,0x6d44151d}},	//   _biya, ymas_, kiya_, _bhia,
   {{0x6d44b307,0x6d56a09e,0x660101e8,0x291240fb}},	//   _chia, _ciya, _ülke, jiya_,
   {{0x6d56b308,0x2912b309,0x2900ab11,0x6d44b30a}},	//   _diya, diya_, dhia_, _dhia,
   {{0xdee30eec,0x3f820138,0x00000000,0x00000000}},	//   _почи, škus_, --, --,
   {{0x7cff01e5,0x6d560b88,0x29121114,0x6d440091}},	//   _përd, _fiya, fiya_, _fhia,
   {{0x2912b30b,0x3949b30c,0x6d440755,0x7d0db30d}},	//   giya_, umas_, _ghia, _umas,
   {{0xb8e51e9f,0x80a11f88,0x00000000,0x00000000}},	// [d570] _एस_, क्टे, --, --,
   {{0x6d56b30e,0x3949b30f,0xbbc906ed,0x98b201d3}},	//   _ziya, smas_, िटीक, ībās_,
   {{0x2912b310,0x6d569748,0x7d1db311,0x64404051}},	//   biya_, _yiya, onss, _azmi,
   {{0x2900b312,0x2912006d,0x7d1d876e,0xf1c702c6}},	//   chia_, ciya_, nnss, žáky_,
   {{0x8ca5009d,0x7d1d003e,0x27e000fe,0x03a51828}},	//   _कानो, inss, cxin_, фило,
   {{0x2d850220,0x81c200e8,0x7d1d02c3,0x6eed033c}},	//   ysle_, _ģērb, hnss, _lúbr,
   {{0xb457010d,0x74f900ae,0x00000000,0x00000000}},	//   _فیاض_, _девр_, --, --,
   {{0x7d1d0381,0x00000000,0x00000000,0x00000000}},	//   jnss, --, --, --,
   {{0x443f8fe9,0x6d56b313,0x6d44b314,0x9f44007b}},	//   _uzu_, _riya, _rhia, kymä_,
   {{0x6d56b315,0x6d44b316,0x2912b317,0x4d65550d}},	//   _siya, _shia, ziya_, мков,
   {{0x57ba2fbd,0x6d56b318,0x6d440197,0x112b0978}},	//   _उन्ह, _piya, _phia, _люди_,
   {{0xd00e0814,0x29005d91,0x6d56b319,0x6d4401fa}},	//   الی_, xhia_, _qiya, _qhia,
   {{0x2d9a00d6,0xbea54e85,0x6eed0031,0xacbb014b}},	//   _åpen_, _жалк, _dúbr, voût,
   {{0x6283b31a,0x6d561f06,0x2912b31b,0x2d85695d}},	//   nano, _wiya, wiya_, psle_,
   {{0x6d441071,0x6d56b31c,0x248d04a3,0xc33200a1}},	//   _thia, _tiya, _odem_, דום_,
   {{0xb4bc0454,0x628302ad,0x7c240a00,0x248d0113}},	//   _असे_, hano, _txir, _ndem_,
   {{0x2912b31d,0x6283063d,0x236d01bb,0x46ea17ab}},	// [d580] riya_, kano, _ntej_, одан_,
   {{0x2912b31e,0x2900b31f,0x68f6b320,0x68e47723}},	//   siya_, shia_, skyd, sjid,
   {{0x6283b321,0x2912620e,0x6abc18ef,0x60c9b322}},	//   dano, piya_, merf, kdem,
   {{0x60c94c54,0x6abcb323,0x799c02a4,0x00000000}},	//   jdem, lerf, murw, --,
   {{0x62833360,0x60c90517,0x69ce9a92,0x9f5200b6}},	//   fano, ddem, lvbe, ždém_,
   {{0x7cff00dd,0x248d207f,0x416a0291,0x645b0062}},	//   _kërc, _edem_, ојим_, _egui,
   {{0xbebc00d9,0x65c30a54,0x799c02a4,0x81e40033}},	//   lnīg, _ибра, nurw, _পেজ_,
   {{0xe643686c,0x6abcb324,0x645b0172,0x2d8a007e}},	//   _респ, herf, _ggui, šbek_,
   {{0x6abc0088,0x20040a9e,0x61fd00a7,0x6eed5593}},	//   kerf, uzmi_, _əsli, _rúbr,
   {{0x628309d3,0x799c02a4,0x7ce6007f,0xe8000179}},	//   cano, kurw, _górz, लैया_,
   {{0x069700a1,0xd12f256d,0xecd00e4c,0x00000000}},	//   ודים_, _ах_, _तोहफ, --,
   {{0xb4bc009d,0x799cb325,0x7cff0216,0x7afeb326}},	//   _असो_, durw, _sërb, _alpt,
   {{0x7cff01e5,0x7d1d1b87,0x6abc9bce,0x9f44007b}},	//   _përb, rnss, ferf, tymä_,
   {{0xe6c842d4,0x6abc6073,0xdbdc003e,0x73f9006e}},	//   रयोज, gerf, ráðg, פּרו,
   {{0x799c0193,0xbebc00e8,0xc9841102,0x7bc400b7}},	//   gurw, enīg, кути, _esiu,
   {{0x6aaa02e2,0x69d862c9,0x7e6d0234,0x00000000}},	//   _öffn, _švec, _đapi, --,
   {{0x78adb327,0x96db009f,0x6283b2c5,0xd7590037}},	// [d590] rfav, नालॉ, yano, سلات_,
   {{0x628336b1,0x6b9d0772,0x56942753,0x60c9b328}},	//   xano, musg, каут, zdem,
   {{0x6283b329,0x27340149,0x6b9db32a,0x60c9b32b}},	//   vano, vänt_, lusg, ydem,
   {{0x26c71cbc,0xf7730d59,0x69c5728e,0x765c03a8}},	//   žno_, _لاس_, _ishe, _egry,
   {{0x6b9d2c28,0xdb0d00bc,0x7e6a0324,0x00000000}},	//   nusg, _osaü, _offp, --,
   {{0x3869b32c,0x877a0341,0x3959b32d,0x8c1c00ca}},	//   lcar_, _מאשי, _hiss_, חודי,
   {{0x6b9daa91,0x3959b32e,0x613e0052,0x00000000}},	//   husg, _kiss_, gëlo, --,
   {{0x386998ce,0x6283b32f,0x6b9db330,0x41b20037}},	//   ncar_, sano, kusg, امير,
   {{0x62830ce9,0x3959b331,0x613e0216,0x799c0169}},	//   pano, _miss_, mëll, zurw,
   {{0x69c52b7f,0x3959753d,0x0ea90ae3,0x63a9039f}},	//   _oshe, _liss_, чкой_, _iqen,
   {{0x40590867,0xdca61e79,0x628101d3,0xee395c8f}},	//   _فلاح_, нани, _ielo, яно_,
   {{0xfce6004d,0x6abc06e5,0x6e3c111d,0x799c05bd}},	//   хомо, werf, ürba, vurw,
   {{0x6281b332,0x6abc4bf9,0x4c350077,0x69c5b333}},	//   _kelo, terf, вэрт, _ashe,
   {{0x7cff00dd,0x799c2359,0x62810995,0xb4bc0789}},	//   _përc, turw, _jelo, _अस्_,
   {{0x395904f9,0x443a0023,0x4efa00ca,0x6abc5264}},	//   _biss_, ́p_, _מהסו, rerf,
   {{0x0d82013d,0x6281b334,0x3959b335,0x799c0193}},	//   _слън, _lelo, _ciss_, rurw,
   {{0x69c5b336,0x6abcb337,0x799cb338,0x7bc40a4b}},	// [d5a0] _eshe, perf, surw, _usiu,
   {{0xf1c50028,0x69c500dd,0x00000000,0x00000000}},	//   _đáng_, _fshe, --, --,
   {{0x3959009e,0xbbe90d7f,0xeef6006e,0x1a9b0142}},	//   _fiss_, _فریم_, עמער_, _ציטע,
   {{0x628102ad,0xe811009d,0x142644f3,0x3869b339}},	//   _aelo, _ठेवा_, ндем, ccar_,
   {{0x6281b33a,0xe3af0867,0x3f7d0206,0x00000000}},	//   _belo, مرو_, jňu_, --,
   {{0x628186fd,0xddda0094,0x31c6403e,0x3f7d0206}},	//   _celo, hatš, есив, dňu_,
   {{0x6281b33b,0x26ca010a,0x29e10022,0xd05b01c2}},	//   _delo, _iabo_, lɗar_, nkuɗ,
   {{0x6d5e00fd,0x77690131,0xf1c50285,0x628109a1}},	//   _épai, _éexc, विजन, _eelo,
   {{0x26cab33c,0x032600c2,0x925a001c,0x6281b33d}},	//   _kabo_, _здан, _فشار_, _felo,
   {{0x62812a2a,0x1ddb1362,0xfaff0052,0x91e61102}},	//   _gelo, यमंत, hpër_, _позе,
   {{0x32070067,0xa2dd000c,0x7bcf01fa,0x2d8a06f0}},	//   czny_, पार्, wvcu, ébe_,
   {{0x26cab33e,0x6b9db33f,0xac19097a,0xb0620d67}},	//   _labo_, tusg, дому_, äädi,
   {{0xd12f0068,0x7b0900e7,0xfd1f0036,0x39598360}},	//   _امن_, džur, rnì_, _riss_,
   {{0x26ca2127,0xd84f2caa,0x2b5a02ac,0x69c50216}},	//   _nabo_, _dọla_, _cipc_, _pshe,
   {{0x6b4002e2,0x318c00b6,0x945d0154,0x317e0239}},	//   mögl, něz_, _dańj, _jwtz_,
   {{0x3ebeb340,0x26ca7018,0x2d9eb341,0x2eee2feb}},	//   lett_, _aabo_, mute_, _hoff_,
   {{0xf7700391,0x2d9eb342,0x981700bf,0x26ca4076}},	// [d5b0] مال_, lute_, ربرا, _babo_,
   {{0x26ca132d,0x69c501bb,0x39590113,0xbebc00d9}},	//   _cabo_, _tshe, _wiss_, lnīb,
   {{0x69c5b343,0x2d9e2366,0x4ade00aa,0x26cab344}},	//   _ushe, nute_, मारव, _dabo_,
   {{0x6281b345,0xd4e43d7c,0xdbe40af0,0xe4e4224a}},	//   _selo, лючи, _béèr, лічн,
   {{0x62811143,0x3ebeb346,0xa2dd030b,0x2d9eb347}},	//   _pelo, kett_, पाल्, hute_,
   {{0x2d9e007a,0x26ca0ff4,0x3ebe004d,0x6b8d0027}},	//   kute_, _gabo_, jett_, _mvag,
   {{0x3ebe3b69,0xdbdd026e,0x6f070065,0x2d9eb348}},	//   dett_, _láàr, _lébù, jute_,
   {{0x2d9eb349,0x26ca1f6e,0x62813f41,0xed631054}},	//   dute_, _zabo_, _welo, _leží_,
   {{0x3ebeb34a,0x26cab34b,0x13b42c66,0x2eee0172}},	//   fett_, _yabo_, _مصلح, _boff_,
   {{0x2d9e01ae,0x6eff016d,0x9c130134,0x6d4f0381}},	//   fute_, _bêba, kọba, emca,
   {{0x2eee88cf,0x2d9e7206,0x6b8d56ef,0xcfa801f3}},	//   _doff_, gute_, _avag, وایم_,
   {{0x7cff0052,0xdbe40381,0x00000000,0x00000000}},	//   _përa, _héér, --, --,
   {{0xddda0094,0x3ebeb34c,0x09ca0096,0xd0f600ca}},	//   ratš, bett_, ाट्य, _שמנת_,
   {{0x2eee02a1,0xdbdd0065,0x2d9e4519,0x60cbb34d}},	//   _goff_, _dáàr, bute_, _hagm,
   {{0x26cab34e,0x19b91476,0x6b8d0090,0x6b400212}},	//   _rabo_, нуть_, _evag, sögo,
   {{0x26cab34f,0x60cb00e7,0x2eee058d,0xa3e1030b}},	//   _sabo_, _jagm, _zoff_, धमा_,
   {{0x60cb93ef,0xf7720b05,0x26cab350,0xccf300a1}},	// [d5c0] _magm, شاء_, _pabo_, _ככה_,
   {{0x60cbb351,0xbebc00d9,0xb87b0072,0x26ca008a}},	//   _lagm, mnīc, _boís, _qabo_,
   {{0xd6cf003f,0xc486535e,0x26ca05db,0x7c2201cd}},	//   تقل_, влек, _vabo_, _þorb,
   {{0x3ebe0068,0x60cbb352,0x26ca4076,0x318c00b6}},	//   zett_, _nagm, _wabo_, věz_,
   {{0xa3b4013a,0x26cab353,0x2d9eb354,0x64a3b355}},	//   ублі, _tabo_, zute_, рача,
   {{0x93432ab6,0x78a40ab8,0x318c02c6,0x77690231}},	//   анче, lgiv, těz_, _éexa,
   {{0x60cb0537,0x2eee01ff,0x25b805db,0xab5b042c}},	//   _bagm, _roff_, _uprl_, kwün,
   {{0x2d9eb356,0x3ebe6ef6,0xddd82449,0xeaff02d5}},	//   vute_, wett_, _nevš, _उत्त_,
   {{0x3ebe0068,0x60cbb357,0xff0600c2,0xa3b609a1}},	//   tett_, _dagm, вянн, _जहि_,
   {{0x248404f9,0x2d9eb358,0x75226c25,0xdbe40139}},	//   _hemm_, tute_, lnoz, _géér,
   {{0x69d801b3,0x5d55013d,0x248403e5,0x6b8db359}},	//   _šven, лкот, _kemm_, _svag,
   {{0x3ebe4ba6,0xa3b61757,0x2d9eb35a,0x60cb02c9}},	//   sett_, _जहा_, rute_, _gagm,
   {{0x5f060562,0x78a40501,0x6d4f00ee,0x2d9e020a}},	//   _изда, dgiv, rmca, sute_,
   {{0x2d9eb35b,0x68ef0694,0x9b58013d,0x52c070d3}},	//   pute_, _socd, кият_, _एसोस,
   {{0x3eab2347,0xd90f0103,0xdbdd02ac,0x60cb6506}},	//   žitý_, قید_, _dáár, _yagm,
   {{0x60c000c2,0x78a40036,0x00000000,0x00000000}},	//   nemm, ggiv, --, --,
   {{0x75221672,0x69d8002b,0x58840138,0x00000000}},	// [d5d0] dnoz, _áven, рыса, --,
   {{0x60c08da4,0xb87b00b6,0x9c130174,0x78a4010a}},	//   hemm, _sníd, pọba, agiv,
   {{0x60c0b35c,0xa4700174,0xd4700174,0x2d8c01d0}},	//   kemm, _ịdọt, _ịtọr, nsde_,
   {{0x60c0b35d,0x6d5e00fd,0x76990139,0x2126023b}},	//   jemm, _épau, _bùyà, _njoh_,
   {{0x289a0105,0x44291c77,0xfd580294,0x25f3009d}},	//   _אירא, ça_, _akaụ, ूनही_,
   {{0x4429003d,0x05130033,0x60cb3cb9,0x00000000}},	//   ħa_, িকের_, _sagm, --,
   {{0x60cb152a,0x60c0b35e,0xbebc00d9,0xdbd60065}},	//   _pagm, femm, znīc, _dùùr,
   {{0x50457030,0x26c11515,0x75220036,0xe0570281}},	//   лейб, leho_, cnoz, نیات_,
   {{0x3f420088,0x7cff5407,0x2d8c000b,0xddd80117}},	//   rðun_, _përn, esde_, _revš,
   {{0x26c1b35f,0x63bb3bc6,0xfde91107,0x2ca90707}},	//   neho_, _ipun, едок_, _acad_,
   {{0x60cb066a,0x00000000,0x00000000,0x00000000}},	//   _tagm, --, --, --,
   {{0xeb9a1803,0xe0d00dd0,0x60c000fd,0x61e5042c}},	//   ним_, _وزن_, cemm, ählu,
   {{0x69d75d06,0x5fb7000d,0x8ca50252,0x26c10181}},	//   _arxe, _अहिल, _कारो, keho_,
   {{0x63bb6586,0x26c10193,0x6da50606,0x6f920037}},	//   _mpun, jeho_, _бика, _الوض,
   {{0xceb200a1,0xbebc00d9,0x660900b6,0x78a443cc}},	//   _היו_, snīc, _řekn, tgiv,
   {{0x63bb30d9,0xbebc01d3,0xd5b100fe,0x2ca900eb}},	//   _opun, pnīc, _ấy_, _gcad_,
   {{0xd9433968,0x7d04b360,0x6b891711,0x3f8db361}},	// [d5e0] сети, _ilis, šegr, nseu_,
   {{0x78a4b362,0x4b7b0796,0x26c10079,0x69c80537}},	//   sgiv, _ראיו, geho_, ædes,
   {{0x63bb2243,0x3ce0017a,0x881a0139,0x7dea00a7}},	//   _apun, _kniv_, _dírẹ, vəsk,
   {{0x63bb0503,0x00000000,0x00000000,0x00000000}},	//   _bpun, --, --, --,
   {{0x26c12cd0,0x7522b363,0x7d0460d9,0x60c0007b}},	//   beho_, rnoz, _mlis, vemm,
   {{0x3940b364,0x7d040990,0x26c10181,0x63bb03a9}},	//   llis_, _llis, ceho_, _dpun,
   {{0x7d0402fd,0x2f000154,0x8ca522e8,0x76580031}},	//   _olis, _bògn_, _कालो, ľvys,
   {{0xb87b0396,0x764300a5,0x752200a7,0x3940b365}},	//   _iníc, żnyc, qnoz, nlis_,
   {{0x60c00ff7,0x7dea0092,0x69d80138,0x3940b366}},	//   remm, məsi, _švel, ilis_,
   {{0x7d041ee3,0xd24f00bf,0x60c03c8b,0x7dea0092}},	//   _alis, _کنم_, semm, ləsi,
   {{0x394085b1,0x07370796,0x7d0419ca,0xf1a90190}},	//   klis_, ראים_, _blis, _لانه_,
   {{0x394018c4,0x26c10193,0x7d046b63,0x6c552e81}},	//   jlis_, zeho_, _clis, икну,
   {{0x26c1023f,0xab62026a,0x7d0400da,0x8ff7450f}},	//   yeho_, şüne, _dlis, _مرور_,
   {{0x7d04b367,0xe1f10068,0x628ab368,0x7dea0092}},	//   _elis, _اسے_, nafo, həsi,
   {{0x63a22409,0x7d04aa50,0xe91900d6,0x26c1b369}},	//   huon, _flis, вові_, veho_,
   {{0x6f1ab36a,0x63a2b36b,0x26c10193,0x3940b36c}},	//   litc, kuon, weho_, glis_,
   {{0x26c1b36d,0x6d4d34b0,0x6c780c5e,0x7dea00a7}},	// [d5f0] teho_, _ihaa, _صحيح_, dəsi,
   {{0x3940b36e,0x6d4db36f,0x7d16045b,0x63a2a76d}},	//   alis_, _hhaa, _zmys, duon,
   {{0x63bb6ae6,0x26c1b370,0x69d708a8,0xfe1a0789}},	//   _spun, reho_, _urxe, _फेमस_,
   {{0x297a00f5,0x26c10027,0x3940ac00,0xba74001c}},	//   _שטרא, seho_, clis_, _پایت,
   {{0xdfc65e51,0x63a27775,0x6d5f37e5,0xe2850dd8}},	//   _بي_, guon, _miqa, алли,
   {{0x68ed77d1,0xa3b60251,0x6d5fb371,0x2d9102c6}},	//   ljad, _जहर_, _liqa, ázek_,
   {{0x6f1a01c0,0x7dea0092,0x7cff023b,0xf0750018}},	//   ditc, bəsi, _përl, لیاں_,
   {{0x68ed2129,0x63a2b372,0x7dea0092,0xe0d905c7}},	//   njad, buon, cəsi, тви_,
   {{0x753bb373,0x628a019f,0x63bb0051,0xaf050f21}},	//   _ikuz, bafo, _upun, ипил,
   {{0x6d4d025e,0x5187550a,0x7d1600b6,0x628a00ee}},	//   _ahaa, _буда, _smys, cafo,
   {{0x7d04b374,0x1d0a08c3,0x6d4d009c,0x3f8d015e}},	//   _plis, вени_, _bhaa, sseu_,
   {{0x6d4db375,0x7fd5013a,0x443f056c,0xcb6a6321}},	//   _chaa, _вікі, _kyu_, каме_,
   {{0x6d4d0694,0x29098e04,0x68ed97eb,0xdee54064}},	//   _dhaa, dhaa_, djad, _воли,
   {{0x6d4d01c8,0xdce40078,0x7dea00a7,0x64493620}},	//   _ehaa, _kunċ, zəsi, _mzei,
   {{0xfc3f0890,0xada5512a,0x753b45e9,0x6d5f00dc}},	//   rgía_, _тайл, _okuz, _fiqa,
   {{0x7529239f,0x92b30081,0x7d0458cc,0x753b00ac}},	//   _njez, য়ায়_, _ulis, _nkuz,
   {{0x07a61787,0x3940b376,0xa686004d,0x7dea0092}},	// [d600] разн, rlis_, илад, vəsi,
   {{0x753bb377,0x39407aa1,0x6d5fa8fe,0xd910001c}},	//   _akuz, slis_, _épar, _کیر_,
   {{0x3940b378,0x443f34ac,0x7dea0092,0xd9461012}},	//   plis_, _ayu_, təsi, _вени,
   {{0x290900ac,0x6b84023f,0x63a21093,0x443fb379}},	//   chaa_, _kwig, tuon, _byu_,
   {{0xf86302ec,0xb60700d9,0x7dea0092,0x29000239}},	//   _євро, ekšē, rəsi, mkia_,
   {{0x2900b37a,0x6b8446b6,0x611300ae,0x443f0113}},	//   lkia_, _mwig, călz, _dyu_,
   {{0xe81a04dd,0x6449b37b,0x63a2b37c,0x00000000}},	//   _नेता_, _ezei, suon, --,
   {{0x7cff01e5,0x64a34587,0x3f420102,0x2900b37d}},	//   _përm, _маса, rðum_, nkia_,
   {{0x443f4d8e,0x2900b37e,0x63a2436b,0x00000000}},	//   _gyu_, ikia_, quon, --,
   {{0x6d4d008a,0x6d5f8543,0x3eb8003e,0x65600090}},	//   _shaa, _siqa, ýrt_, _himh,
   {{0x29000084,0xb6d900c1,0x628801d3,0x65607ebb}},	//   kkia_, אַרט, _iedo, _kimh,
   {{0x215a2c9a,0x6b8402a4,0x6f1a0231,0x7cff0052}},	//   _شجاع_, _bwig, sitc, _tërm,
   {{0x6288a2a5,0x6f1a00c4,0xdb04037a,0x68ed033b}},	//   _kedo, pitc, _apiñ, vjad,
   {{0x7cff01e5,0x628802e2,0x6b84b37f,0x6560b380}},	//   _kërk, _jedo, _dwig, _limh,
   {{0x8d9400e3,0x6b848f26,0x68edb381,0x06cf0081}},	//   _البش, _ewig, tjad, রামি,
   {{0x7c2d0a00,0x6288b382,0x7cff0052,0x6560b383}},	//   _txar, _ledo, _mërk, _nimh,
   {{0x68edb384,0x19581ad1,0xf7731d28,0x76b913a2}},	// [d610] rjad, раты_, تاز_, ллар_,
   {{0x7d1db385,0x753bb386,0x29090188,0x656003ea}},	//   liss, _skuz, shaa_, _aimh,
   {{0x443f0da3,0x59f900ae,0x200d0036,0x442d0503}},	//   _syu_, _сеня_, zzei_, _sxe_,
   {{0x7d1db387,0x291b0090,0xd1261790,0x2d9e10e4}},	//   niss, qiqa_, _رم_, irte_,
   {{0x628804ee,0xe2f90565,0x7cff00dd,0x7529b388}},	//   _bedo, леді_, _përj, _vjez,
   {{0x7d1db389,0x6288028d,0x656023a5,0xb0620302}},	//   hiss, _cedo, _eimh, ääni,
   {{0x7d1d96c8,0x32010146,0xf42600c2,0x9f59b38a}},	//   kiss, áhy_, _ääni_, ásí_,
   {{0x753b067d,0x1dd511b5,0x26d103e3,0x7d1db38b}},	//   _ukuz, धिसत, _hazo_, jiss,
   {{0x443f023f,0x2d9eb38c,0x6288b38d,0x26d1b38e}},	//   _uyu_, erte_, _fedo, _kazo_,
   {{0x62888a90,0xaf0522be,0x29000a00,0x26d11257}},	//   _gedo, спол, zkia_, _jazo_,
   {{0x7d1db38f,0x26d138b7,0x2d91023c,0x00000000}},	//   fiss, _mazo_, éze_, --,
   {{0x628802e5,0x26d188ec,0x41555e39,0x2a730169}},	//   _zedo, _lazo_, _увес, _afxb_,
   {{0x2d9eb390,0x8fc7029e,0x38c8110a,0x613e0052}},	//   arte_, _خزان, یاری_, gëlu,
   {{0x20a7000f,0x26d169f8,0x2919006d,0xf21c00c3}},	//   _गाँध, _nazo_, _amsa_, _भेड़_,
   {{0x7d1db391,0x7bcd00e5,0x2900007b,0x2d9e0559}},	//   biss, _esau, tkia_, crte_,
   {{0x7d1d1dbe,0x6b84b392,0x7866aa4b,0x29001093}},	//   ciss, _twig, сказ, ukia_,
   {{0x6903007a,0x2900b393,0x3cf1025b,0x26d1b394}},	// [d620] _tõen, rkia_, žová_, _bazo_,
   {{0xb8ff048a,0x3ce613db,0x2bd5009d,0x26d1034f}},	//   _धो_, टावे_, दिरा, _cazo_,
   {{0xf99218a9,0x20a70f73,0x77940103,0xb0a73350}},	//   _عبد_, _गांध, _ڈیزا, _गांग,
   {{0x6288b395,0xe76a0dd0,0x2bef0033,0x64a60ffa}},	//   _sedo, _محسن_, _চেয়ে_, сада,
   {{0x6903007a,0xb87b0072,0x195700ca,0x26d10117}},	//   _mõel, _unía, _לבטל_, _fazo_,
   {{0x7cff01e5,0x7d1d178b,0x0b060033,0x64401515}},	//   _përk, ziss, _ঈদুল_, _vymi,
   {{0x64400067,0x6288a15c,0x7e7e007a,0x6560b396}},	//   _wymi, _vedo, _õppi, _timh,
   {{0x1f74020f,0x65600a6c,0x6288001c,0x60f8008f}},	//   олия, _uimh, _wedo, рния_,
   {{0x7d1d2a61,0x6b400088,0x26d1b397,0x00000000}},	//   viss, lögu, _yazo_, --,
   {{0x7d1db398,0xd5440139,0x613e084e,0x6288039f}},	//   wiss, _fẹ̀h, eëlt, _uedo,
   {{0x2002b399,0x7d1db39a,0x2ae70179,0x00000000}},	//   ški_, tiss, ञासु_, --,
   {{0xc5f300a1,0xa06a0831,0x7f8301f3,0x2d9e0754}},	//   לדת_, _сада_, _کلون, rrte_,
   {{0x7d1db296,0x70560678,0xd0e5063c,0xa2dd0096}},	//   riss, _انشا, कारण_, पाच्,
   {{0x7d1db39b,0x8ca502d5,0x2d9e033b,0xde5808a1}},	//   siss, _काको, prte_, _калі_,
   {{0x7d1db39c,0x26d1002b,0x7afa02c3,0x00000000}},	//   piss, _razo_, ötta, --,
   {{0x7bcdb39d,0xa3e8000d,0xe81a0e5f,0x6b4001cd}},	//   _tsau, यमा_, _नेहा_, dögu,
   {{0x02fa0336,0x26d108a8,0xc1b500b6,0x7bcd81aa}},	// [d630] ्साह_, _pazo_, _अङ्ग, _usau,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cff00dd,0x7e6d0233,0x00000000,0x00000000}},	//   _përh, _şapk, --, --,
   {{0xa8a708d1,0x26d14816,0xb87b0037,0x2e3b006e}},	//   _урок, _wazo_, _inío, נגאנ,
   {{0x26d10022,0x62654036,0x7af701ff,0x00000000}},	//   _tazo_, овла, _koxt, --,
   {{0x69d82c2e,0xaaad0213,0x00000000,0x00000000}},	//   _švei, ञ्चक, --, --,
   {{0x945d0067,0xdce400e9,0x7cff00dd,0x3f860154}},	//   _pańs, _sunč, _tërh, _awou_,
   {{0xe800030b,0xdce40a87,0x7af702ac,0x00000000}},	//   लैका_, _punč, _loxt, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcc206ed,0xef190b1e,0xbebc00e8,0x92941fbf}},	//   षज्ञ, рмо_, lnīj, _науц,
   {{0x6b5201c5,0x3ce606ed,0xacea26b2,0x6cc63153}},	//   lægg, टाले_, амна_, ойна,
   {{0xa3ad3d34,0x7ae50023,0x9c130134,0x00000000}},	//   _कमा_, _anht, pọla, --,
   {{0x1b4a18d4,0x7af701cb,0xb87b0076,0x3fc900d1}},	//   изми_, _boxt, _anío, _خدای_,
   {{0x613e0052,0x15f90caf,0x00000000,0x00000000}},	//   bëls, ंहार_, --, --,
   {{0xfd1200e3,0x690300aa,0xab1904a1,0x00000000}},	//   _يجب_, _tõel, сцях_, --,
   {{0x65680113,0x18674ba7,0x00000000,0x00000000}},	//   _édhi, жати_, --, --,
   {{0x2d87009c,0xdb063341,0x9aa50d7f,0x00000000}},	// [d640] _hwne_, ttkä, _کمپو, --,
   {{0x6d46b39e,0xb87b002b,0x00000000,0x00000000}},	//   llka, _unín, --, --,
   {{0xb87b0080,0xa2d405cd,0x7cff023b,0xe61a016c}},	//   _gnío, _योग्, _sëri, јде_,
   {{0xd94675a4,0x69de0451,0xec36006e,0x2d87022b}},	//   _феми, _irpe, ֿאַר_, _mwne_,
   {{0x6d46b39f,0x69de2281,0x6b40003e,0x7d57021e}},	//   ilka, _hrpe, sögu, קינד_,
   {{0x69de0335,0x2ae30034,0x6d46042c,0xb062007b}},	//   _krpe, खाएँ_, hlka, äämi,
   {{0xaab21344,0x4ab2000f,0x00000000,0x00000000}},	//   _जानक, _जानव, --, --,
   {{0xa2ba0455,0xd1300037,0x61f702c3,0x00000000}},	//   _शॉर्, عمة_, äxla, --,
   {{0xc95300a1,0x5ed30033,0xe4d70781,0x00000000}},	//   ומה_, তানে, _بوقت_, --,
   {{0x7b1002e2,0x6d463dd6,0x7dea00a7,0x2fdd00f0}},	//   _häuf, elka, xəss, _drwg_,
   {{0x7b100364,0x63a2b3a0,0x6b400212,0x00000000}},	//   _käuf, lron, högs, --,
   {{0x7afa4ff4,0x3f8602f1,0x00000000,0x00000000}},	//   öttn, _twou_, --, --,
   {{0x9f4601bf,0x00000000,0x00000000,0x00000000}},	//   _groß_, --, --, --,
   {{0x7b1002e2,0x6d46b3a1,0xbd6a261f,0x63a2b3a2}},	//   _läuf, alka, _крие_, iron,
   {{0x59ce110f,0x63a2b3a3,0x69de007e,0x2d9102c6}},	//   _हैदर, hron, _crpe, ázet_,
   {{0x8d1802fc,0xf77000d1,0x2f0001b9,0x00000000}},	//   _وزير_, چال_, _sògh_, --,
   {{0x63a200cd,0xf7700397,0x629a1d63,0xfcaa006e}},	// [d650] jron, نال_, _odto, _היפּ,
   {{0x3f7b00c1,0x629e1f97,0x9c130294,0x6b520537}},	//   יאמס, ópol, họka, vægg,
   {{0x63a2b3a4,0x9c13199b,0x80bc0179,0x7e7e00bc}},	//   eron, kọka, ्जाइ, _õppu,
   {{0x63a29c9e,0x629a56ae,0xf9da00c1,0x613e023b}},	//   fron, _adto, _פֿיל, këlq,
   {{0x63a28289,0xf8bf0139,0x2bde1176,0x00000000}},	//   gron, _ibé_, मिया, --,
   {{0x78ad00d9,0x65952012,0x7cff0216,0x4b7c2252}},	//   lgav, _нагу, _gërv, סאוו,
   {{0x63a2b3a5,0x6d46008c,0x00000000,0x00000000}},	//   aron, ylka, --, --,
   {{0x78adb3a6,0x63a2b3a7,0xddc8007f,0x00000000}},	//   ngav, bron, łośn, --,
   {{0x6b5202b6,0xf8bf680d,0xef193c75,0x00000000}},	//   læge, _mbé_, йми_, --,
   {{0x248d0565,0x00000000,0x00000000,0x00000000}},	//   _heem_, --, --, --,
   {{0x7bdf34f3,0x248d023e,0x9d460fe3,0xc8ab0034}},	//   _arqu, _keem_, зенд, _छांट,
   {{0x2365007e,0x71d61777,0xac8300d3,0x78ad0381}},	//   _hilj_, _מועד_, нгюл, jgav,
   {{0x80270080,0x248d0197,0x69de00b6,0x60c90517}},	//   _برام, _meem_, _srpe, meem,
   {{0x63a4b3a8,0xf8bf026e,0x3d0200a5,0x60c954ab}},	//   šing, _abé_, _mówi_, leem,
   {{0x2fcd2ba3,0x2365b3a9,0xed5a002d,0x6f180103}},	//   lweg_, _milj_, _лок_, _بزنس_,
   {{0x248d0db8,0x60c9b3aa,0x78adb3ab,0xcc8a0e3a}},	//   _neem_, neem, ggav, _убие_,
   {{0x7cff00dd,0x8cbc0285,0x2fcd365f,0xb87b00da}},	// [d660] _përv, ष्णो, nweg_, _gním,
   {{0x63a200fd,0x60c9000b,0x00000000,0x00000000}},	//   vron, heem, --, --,
   {{0x248d0231,0x60c968d1,0x69de0b7e,0x629e0072}},	//   _beem_, keem, _urpe, ópom,
   {{0x248d022e,0xf8bf0649,0xb0da02d5,0x2fcd029a}},	//   _ceem_, _gbé_, _मोंग, kweg_,
   {{0x248db3ac,0x69dc0b97,0x645d023c,0xe7942c31}},	//   _deem_, lvre, _úsil, _تاجک,
   {{0xb3e90cc8,0xa3ad278e,0x2fcd1090,0x6b520537}},	//   تعمل_, _कमर_, dweg_, bæge,
   {{0x248d0197,0x518611c0,0xd24f00d1,0x2fcd0381}},	//   _feem_, чула, هنه_, eweg_,
   {{0x63a28940,0x859b00a1,0x248d0134,0xe01d0034}},	//   pron, _לשלו, _geem_, _बेहद_,
   {{0x2fcd1570,0x03a315db,0x00000000,0x00000000}},	//   gweg_, _пито, --, --,
   {{0x7522b3ad,0xdce400d9,0x248d022e,0x0dca0aec}},	//   lioz, _runā, _zeem_, буми_,
   {{0x248d01bb,0x908a00e3,0xb87b0363,0x69dc1197}},	//   _yeem_, _هناك_, _sním, jvre,
   {{0x248d0197,0x752220a3,0x68030065,0x69dcb3ae}},	//   _xeem_, nioz, _jíjú, dvre,
   {{0x656eb3af,0x8ae7004d,0x673eb3b0,0x69dc084e}},	//   _lubh, півл, kopj, evre,
   {{0xb87b0146,0x4ab2009d,0x7b640396,0xa2bf0285}},	//   _vním, _जाणव, етсе, ल्प्,
   {{0xceb30341,0x78adb3b1,0x7cff023b,0x69dc02ac}},	//   _ניק_, tgav, _bërt, gvre,
   {{0xa3ad04dd,0x8e4700e3,0x6b52052f,0x7cff0052}},	//   _कमल_, _عليك_, væge, _përu,
   {{0x38342dd8,0x78ad0126,0x7bdf04c3,0x248d0124}},	// [d670] ентр, rgav, _urqu, _reem_,
   {{0x7d0d0074,0x3ce9006c,0x04f90081,0x78ad76bb}},	//   _hlas, _hnav_, _আগের_, sgav,
   {{0x28f93840,0x8afc00a1,0x248d01fa,0x78ad07d2}},	//   _день_, _להזי, _peem_, pgav,
   {{0x752200cc,0x656e0a02,0x69c50201,0xf6500076}},	//   gioz, _dubh, _iphe, ائك_,
   {{0x39494743,0x656e01ec,0x248d0131,0x7d0db3b2}},	//   mlas_, _eubh, _veem_, _mlas,
   {{0x49b800bf,0x39490fca,0xe3b00604,0x656e009c}},	//   _باید_, llas_, طره_, _fubh,
   {{0x248d006c,0x39491fdc,0x60c91e07,0x7d0d6abc}},	//   _teem_, olas_, teem, _olas,
   {{0x7c3a00a5,0x2fcd4bd8,0xa4d4004d,0x600961f2}},	//   ętrz, tweg_, _посі, жним_,
   {{0x60c9b3b3,0xa2b5013d,0xb0ae0789,0x39492e2d}},	//   reem, _обач, _टारग, ilas_,
   {{0x69c5b3b4,0x2fcd1c7d,0x3949b3b5,0x60c93234}},	//   _ophe, rweg_, hlas_, seem,
   {{0xdca64564,0x3949b3b6,0x2fcd2819,0x7bc4023b}},	//   мани, klas_, sweg_, _spiu,
   {{0x69dc0d62,0x63a40357,0x00000000,0x00000000}},	//   vvre, šine, --, --,
   {{0x69c5019f,0xb87b0139,0x2bd500a3,0xed570120}},	//   _aphe, _eník, दिगा, ьою_,
   {{0xada10181,0x3949b3b7,0xdce4020a,0xb3bf0033}},	//   ľúbe, elas_, _bună, _এছাড়,
   {{0x7cff023b,0x63ab6f3e,0x5ed30033,0xb87b0031}},	//   _përt, hugn, তাদে, _kníh,
   {{0x3949b3b8,0x7d0d5dd3,0x69dc4ed2,0x691102b6}},	//   glas_, _glas, rvre, _nåed,
   {{0x7cff01e5,0x69c5b3b9,0x657c0146,0x6d446f7b}},	// [d680] _vërt, _ephe, _strh, _ikia,
   {{0x39494a21,0x7d0d033b,0xa2bf17ff,0x61e100f0}},	//   alas_, _zlas, ल्म्, _orll,
   {{0x3949b3ba,0x75d60037,0x186a35c1,0x7cff0216}},	//   blas_, بيضا, _мани_, _gërs,
   {{0x100d0c17,0x63ab042c,0x657c00d4,0x00000000}},	//   िनाश_, fugn, _vtrh, --,
   {{0x7522b3bb,0x31c619af,0x63ab5e86,0x3940b0d3}},	//   rioz, लब्ध, gugn, mois_,
   {{0x39401829,0x7522a464,0xa2fa023a,0x656e009c}},	//   lois_, sioz, ्सेज_, _tubh,
   {{0xaac0000c,0x96633340,0xa50a2569,0x657cb3bc}},	//   श्यक, _акре, _дева_, _utrh,
   {{0x3940b3bd,0x6d4401fa,0x399b00a1,0x63ab0eac}},	//   nois_, _nkia, קיפד, bugn,
   {{0x26d8b3be,0x8fa3372d,0x6e94090f,0x63ab0036}},	//   _karo_, вање, нипу, cugn,
   {{0x26d8b3bf,0x6d44b3c0,0x7d0d1556,0x6d56b3c1}},	//   _jaro_, _akia, _slas, _ahya,
   {{0x7d0db3c2,0x2d98b3c3,0x26d8b3c4,0x394904d6}},	//   _plas, ére_, _maro_, ylas_,
   {{0x26d800a6,0x6d560124,0x7e6d00ae,0x3f42003e}},	//   _laro_, _chya, _şapt, gður_,
   {{0x29121423,0x6d560124,0x60c20032,0x394907ee}},	//   dhya_, _dhya, _ibom, vlas_,
   {{0x7cff01e5,0x6d4401e9,0x21240037,0x7d0d007f}},	//   _përs, _ekia, limh_, _wlas,
   {{0x69d801ac,0x39400257,0xcda71f11,0x3eb900a7}},	//   _šver, fois_, _قهوه_, əst_,
   {{0x26d83b5b,0x2124033f,0x6d44009c,0x7cff0052}},	//   _aaro_, nimh_, _gkia, _vërs,
   {{0x3949a024,0x20042ac2,0xd6db013d,0x24860106}},	// [d690] rlas_, nymi_, жте_, dbom_,
   {{0xb906033a,0x3949b3c5,0x08540084,0x6b8d00f9}},	//   _यो_, slas_, твую, _iwag,
   {{0x26d8b3c6,0x69c50201,0x60c273cc,0x3940b3c7}},	//   _daro_, _uphe, _obom, bois_,
   {{0x63abb3c8,0x6b8db3c9,0x20040031,0x98a0007f}},	//   tugn, _kwag, kymi_, tnią_,
   {{0x26d8b3ca,0xc8641728,0x2fc6006c,0xc3cb0182}},	//   _faro_, _атри, _npog_, تظام_,
   {{0x2909686e,0x60c223db,0x6b8d2622,0x26d8b3cb}},	//   lkaa_, _abom, _mwag, _garo_,
   {{0x2fc607ac,0x61457ef2,0x60c20361,0x6b8d7fc6}},	//   _apog_, нека, _bbom, _lwag,
   {{0x63abb3cc,0x26d801c2,0x2909293a,0x60c2009c}},	//   pugn, _zaro_, nkaa_, _cbom,
   {{0x8335013a,0x26d8b3cd,0x6b8d7da1,0x349411c0}},	//   _знах, _yaro_, _nwag, _шатр,
   {{0x6d5602a4,0x6d44b3ce,0x83190037,0x60c21c7b}},	//   _shya, _skia, _عقار_, _ebom,
   {{0x290902fd,0xd12e110a,0x6b8d2b7f,0x6569007b}},	//   kkaa_, شمی_, _awag, _kieh,
   {{0x28df2166,0x60c20e62,0xfd120192,0x6b8d0198}},	//   _पोलि, _gbom, اجد_, _bwag,
   {{0xeb975fcf,0x3f420682,0x656902fd,0x60db62e7}},	//   ния_, rður_, _mieh, mdum,
   {{0x3b0a0084,0x60db27c3,0x68fd03ea,0x24861912}},	//   чего_, ldum, _aosd, zbom_,
   {{0xf2d200c1,0x68fd0042,0x7f41058a,0xc3320796}},	//   װען_, _bosd, molq, אום_,
   {{0x60dbb3cf,0x26d8b3d0,0x65698e1a,0x6d440239}},	//   ndum, _saro_, _nieh, _ukia,
   {{0x07a32cb3,0x237f0d7d,0x26d804d8,0x6b8db3d1}},	// [d6a0] латн, _ntuj_, _paro_, _gwag,
   {{0x60d93c40,0x2912023f,0x7bd606a8,0x249f0090}},	//   _lawm, shya_, _isyu, _adum_,
   {{0x394000c9,0x64490032,0x248600e7,0x20040034}},	//   pois_, _ayei, tbom_, zymi_,
   {{0x6449010a,0xb0ae1784,0x98a0007f,0xbebc00e8}},	//   _byei, _टाइग, dnić_, lnīt,
   {{0x26d8b3d2,0x98a000a5,0x65690090,0x249f02a1}},	//   _taro_, enić_, _dieh, _ddum_,
   {{0x64495202,0x20040094,0xbcfb020d,0x656902ac}},	//   _dyei, vymi_, mmée, _eieh,
   {{0x200400a5,0x27e0b3d3,0x2fc60313,0x64a60138}},	//   wymi_, lvin_, _spog_, _пава,
   {{0x60d9023e,0x25bb00a1,0x81b20081,0x60db11b9}},	//   _cawm, _מצלמ, টবল_, gdum,
   {{0x60d90090,0x21240037,0x27e02452,0x25af0034}},	//   _dawm, rimh_, nvin_, ągle_,
   {{0xdcc904f8,0x656901bf,0x7afe00d3,0x2ca0b3d4}},	//   िज्ञ, _zieh, _nopt, _adid_,
   {{0x80bd009d,0x6b8d5202,0x7bd60706,0x27e0007b}},	//   व्हे, _swag, _asyu, hvin_,
   {{0x7cff023b,0x60d901c2,0x60c260d9,0x6b8d024a}},	//   _përq, _gawm, _ubom, _pwag,
   {{0x68fd005c,0x6d5d0865,0x7afe030a,0x00000000}},	//   _rosd, rmsa, _bopt, --,
   {{0x27e0b3d5,0xdcfb0138,0x7b10042c,0x00000000}},	//   dvin_, ystė, _räuc, --,
   {{0x29090084,0x60d901fa,0x68fdb3d6,0xb9250037}},	//   tkaa_, _yawm, _posd, نفسي,
   {{0x58d40b99,0x6b8d01e2,0x290f0037,0x2ca0009e}},	//   лост, _twag, óga_, _gdid_,
   {{0x29091f41,0x6b8d13f9,0xbcfb1527,0x07090604}},	// [d6b0] rkaa_, _uwag, rméd, ويري_,
   {{0x656902e2,0x81d70081,0x2909659a,0x6b52052f}},	//   _sieh, ামত_, skaa_, lægn,
   {{0x64491a47,0xfb1c00ca,0x68fd01b9,0xa8020345}},	//   _syei, _מוזמ, _tosd, çırd,
   {{0x48ab02fd,0x237f2904,0xbcfb01f9,0x9f5901f9}},	//   _этом_, _ptuj_, lméb, ású_,
   {{0xc6a7372d,0x98a0007f,0x656919da,0xe4a401b6}},	//   _први, wnić_, _vieh, урхо,
   {{0x65690078,0x8c1c00ca,0x1308004d,0xa6c90504}},	//   _wieh, הודי, нній_, _توسل_,
   {{0x15a8013d,0x65693ae9,0x7afab3d7,0x00000000}},	//   _пъти_, _tieh, ötti, --,
   {{0xf994193b,0x98a026dd,0x60d98267,0x25fe00a3}},	//   ארק_, rnić_, _qawm, लहरी_,
   {{0x200b0363,0x60dbb3d8,0xe0d6022c,0x1fbd1bc3}},	//   áci_, rdum, твы_, ्बेड,
   {{0xaf054c32,0x00000000,0x00000000,0x00000000}},	//   тпол, --, --, --,
   {{0x7cff01e5,0x60d9023e,0xa2ba02d5,0x690300bc}},	//   _përp, _tawm, _शॉट्, _jões,
   {{0xeb9a0394,0x7afe22a1,0x2bde06e4,0x00000000}},	//   мим_, _sopt, मिला, --,
   {{0x7afeb3d9,0x00000000,0x00000000,0x00000000}},	//   _popt, --, --, --,
   {{0xa3e20557,0xe8ff0257,0x00000000,0x00000000}},	//   धित_, _aoû_, --, --,
   {{0xcb67002d,0x00000000,0x00000000,0x00000000}},	//   таре_, --, --, --,
   {{0x2d855e10,0x27e0b3da,0x2ca03cc8,0xf77201f9}},	//   mple_, tvin_, _udid_, لائ_,
   {{0x7afeb3db,0x3959007e,0x27e0b3dc,0xa6960284}},	// [d6c0] _topt, _dhss_, uvin_, вреј,
   {{0x32070094,0xbcfb00fd,0x3ce600bc,0x0683004d}},	//   kyny_, rmée, _जोते_, игун,
   {{0x63bb039f,0xdbe3020d,0xceb8007f,0x2d857bc8}},	//   _aqun, _rééc, więk_, nple_,
   {{0xd8264383,0x64a6b3dd,0x7c22003e,0x81d70033}},	//   _адми, тада, _þors, ামা_,
   {{0x6903007a,0x290c01d3,0xd4670ed6,0x332700b3}},	//   _võet, ūdas_, вице_, finx_,
   {{0x8c1b0327,0xa89400e8,0x77690231,0x00000000}},	//   ווני, šķīr, _éexp, --,
   {{0x3f8f283d,0x7bc100ae,0x63bb063d,0x00000000}},	//   _awgu_, ălui, _equn, --,
   {{0xf9930054,0x31ba00dd,0x6603681f,0x00000000}},	//   ברה_, rëz_, änke, --,
   {{0xa2bf009d,0x04463051,0x24890143,0x5e8600d3}},	//   ल्ह्, _реан, ñame_, кунз,
   {{0x27ff00fd,0xb4d20285,0x9df8001f,0xb87b00b3}},	//   _àune_, _वसु_, енот_, _unív,
   {{0x629862d7,0x4c9544ab,0xd1760cbe,0x236b0206}},	//   mavo, линс, _рызы, žijú_,
   {{0x62980235,0x602616bd,0xd026008f,0x4fc6065c}},	//   lavo, _идеа, _имей, _аска,
   {{0xdcfb0029,0xd00f00e3,0x7ff3071c,0x613e0216}},	//   lstī, _ولم_, _نسوا, këlz,
   {{0xb3450396,0x6298b3de,0xda7b007b,0x5b270120}},	//   moçã, navo, ьям_, тьма,
   {{0x1db606eb,0x6b5202b6,0x00000000,0x00000000}},	//   _अमित, mægl, --, --,
   {{0x0dc71352,0x6298b3df,0x693436bf,0xc984007e}},	//   _руши_, havo, ансу, рури,
   {{0x80be0033,0xb8db00b7,0x0855004d,0x3207007f}},	// [d6d0] ্যপ্, _घा_, уваю, zyny_,
   {{0xdcfb0029,0x6d4f027e,0x59ce0378,0x00000000}},	//   kstī, llca, _हैकर, --,
   {{0x63a400e3,0x6298b3e0,0x6d5f0036,0x7c2201cd}},	//   áinn, davo, _èpas, _þorr,
   {{0x58840963,0x394d03e5,0xf48761f2,0x00000000}},	//   _выра, ċess_, тужн, --,
   {{0xad1c07a6,0xaac00d88,0x4ac01344,0x9d1c006e}},	//   וואר, श्वक, श्वव, וואט,
   {{0x6298b3e1,0x6903007a,0x059505bc,0x3207931c}},	//   gavo, _tões, _مارگ, tyny_,
   {{0x80be00c7,0xb594008f,0xd5b816d8,0xdb060206}},	//   ্যন্, _висш, _ист_, nuká,
   {{0xdfd100e3,0x7c3a5c70,0x32073751,0x657a014b}},	//   ميع_, ştri, ryny_, _étha,
   {{0x629862d7,0x6575677b,0xb87b0072,0x3207b3e2}},	//   bavo, _huzh, _uníu, syny_,
   {{0x6575023b,0x62989b3d,0x637f00ae,0x00000000}},	//   _kuzh, cavo, _vână, --,
   {{0xd2510080,0x4d66534b,0xd1b806cf,0x00000000}},	//   _انا_, лков, _لانا_, --,
   {{0x637f00d3,0xdb061d7e,0x65755bca,0x2d853d0f}},	//   _tână, stkü, _muzh, rple_,
   {{0x657550cb,0xbebc01d3,0x8fa50ed7,0x4fa500b8}},	//   _luzh, rnīr, _сале, _силв,
   {{0x8f9a07a6,0xe45600c1,0x63ab0076,0x2d855f35}},	//   _װיקי, טירט_, irgn, pple_,
   {{0xfce6004d,0x98a62b16,0x00000000,0x00000000}},	//   _бойо, ливе, --, --,
   {{0x62980c90,0x5fb71980,0x00000000,0x00000000}},	//   zavo, _आमाल, --, --,
   {{0x6d46b3e3,0x46ea0ba3,0x27e60080,0xb87b7ca8}},	// [d6e0] moka, ндан_, íon_, _anís,
   {{0x6d46b3e4,0x6b84b3e5,0x6d5f028d,0x2bf300b6}},	//   loka, _itig, _èpar, ुहरू_,
   {{0x6937005f,0xa3b6009d,0x6b8402a1,0x3abb0eda}},	//   mćen, चून_, _htig, _אמינ,
   {{0xb87b22a4,0x6d4667a8,0xd91005bc,0x2db6006e}},	//   _caíd, noka, _بیر_, טלען_,
   {{0x6298b3e6,0x44200028,0x06cf0033,0x00000000}},	//   tavo, ài_, রাজি, --,
   {{0x6d46b3e7,0x63a46b36,0xa2bf0096,0x53341fdb}},	//   hoka, šino, ल्ल्, јект,
   {{0x62980871,0x2902b3e8,0x6d46b3e9,0x88d70081}},	//   ravo, _koka_, koka, হারক,
   {{0x29020d64,0xf99300a1,0x6d46b3ea,0x4154001f}},	//   _joka_, זרה_, joka, јвис,
   {{0xe292054f,0x35ba0251,0x6298b3eb,0x2902b3ec}},	//   _هذا_, _उमड़, pavo, _moka_,
   {{0x2902b3ed,0x657501c2,0x65620052,0x3eb8374f}},	//   _loka_, _yuzh, lmoh, ürt_,
   {{0x6b8405bd,0x72060037,0x46c600b6,0xd5430139}},	//   _atig, _حوام, र्यह, _jé̟j,
   {{0x6d46b3ee,0x29024f39,0xdb0f0216,0xeb0d00b7}},	//   goka, _noka_, pucë, हस्त_,
   {{0xc6211784,0xdb1d0018,0x61e80094,0x315700ca}},	//   _मध्य_, ltsé, _hrdl, _עידן_,
   {{0x501b0054,0xf1b8b3ef,0x65620216,0x46c602c6}},	//   _אודו, _इमान, hmoh, र्मह,
   {{0x6d4649a4,0x13cd0081,0x764e017a,0x29020578}},	//   boka, লিয়, _nyby, _boka_,
   {{0x2d9e5f76,0x6d46b3f0,0x93c700ae,0x92d00033}},	//   mste_, coka, ltăţ, ষায়_,
   {{0x2902006d,0x2d9e525b,0xab5b0364,0x00000000}},	// [d6f0] _doka_, lste_, rtüb, --,
   {{0xb87b0ba0,0x7bcd2a0b,0xeb9f13b9,0x61e80a1f}},	//   _saíd, _ipau, msø_, _ordl,
   {{0x2d9e1570,0x764e030a,0xeb9f12dc,0x44270d7f}},	//   nste_, _cyby, lsø_, گراف,
   {{0x2d9eb3f1,0x39a101b3,0x7985063d,0x01ba0081}},	//   iste_, mės_, _ithw, ংবাদ,
   {{0x39a108a1,0x389a021e,0x61e80076,0x289a0142}},	//   lės_, _בירנ, _ardl, _בירא,
   {{0x2d9eb3f2,0x6b7c00c1,0x6d46b3f3,0x21260113}},	//   kste_, ערונ, zoka, _amoh_,
   {{0x39a10ad3,0x6d46b3f4,0x2d9eb3f5,0x247e0129}},	//   nės_, yoka, jste_, _ịme_,
   {{0x2d9eb3f6,0xd1315e51,0xb0f30081,0x26d3137f}},	//   dste_, تمع_, জস্ব_, lexo_,
   {{0x2d9eb3f7,0x02a7016e,0x7bcd0197,0x00000000}},	//   este_, _брем, _npau, --,
   {{0x39a101b3,0x26d30042,0x2d9e3994,0x212601dc}},	//   kės_, nexo_, fste_, _emoh_,
   {{0x6d46b3f8,0x2d9e4e5f,0x798501fa,0x2d91020d}},	//   toka, gste_, _nthw, èze_,
   {{0x39a1013f,0x00000000,0x00000000,0x00000000}},	//   dės_, --, --, --,
   {{0x29020c00,0x2d9eb3f9,0x79850372,0x6b840090}},	//   _roka_, aste_, _athw, _qtig,
   {{0x6d46984a,0x2902b3fa,0xbcfba8a0,0x5f740286}},	//   soka, _soka_, rméa, _طاهر,
   {{0x6d46b3fb,0x2902b3fc,0xc8961d2e,0x6f0300e3}},	//   poka, _poka_, ирањ, _ionc,
   {{0x776e023e,0xbcfb0103,0x6937007e,0xdb060233}},	//   _sibx, lmén, sćen, kukç,
   {{0xfaa65f3b,0x6937706c,0xa96744a1,0x29020381}},	// [d700] _капо, pćen, рита_, _voka_,
   {{0x39a101b3,0x3ce00197,0xdb0601e8,0x6f03014b}},	//   bės_, _haiv_, dukç, _jonc,
   {{0x2902b3fd,0xab5b02e2,0x2bde1677,0x690300bc}},	//   _toka_, stüc, मिका, _tõep,
   {{0x7d040084,0x62811f04,0x66031531,0x69820129}},	//   _jois, _aflo, änka, _ọgwụ,
   {{0x6562b3fe,0x3ce00197,0x60c401ff,0xbcfb01f9}},	//   rmoh, _maiv_, _ñimi, kmén,
   {{0xf1a62cd8,0x7d04b3ff,0x6f03b400,0x2d9eb401}},	//   арин, _lois, _nonc, yste_,
   {{0xbcfb0018,0x35a33445,0xe5a31a6d,0x602801d3}},	//   dmén, _марг, _мири, zīmī,
   {{0x7d04b402,0x62817c1d,0x39522864,0x7b10042c}},	//   _nois, _eflo, nlys_, _säul,
   {{0x39a1013f,0x6f03b403,0x628100eb,0x00000000}},	//   zės_, _bonc, _fflo, --,
   {{0x2d9e15b9,0x7b100364,0x7d0403dc,0x93c7044c}},	//   tste_, _bäum, _aois, utăţ,
   {{0x7bcd01b3,0x6f030472,0x7d04b404,0x7d1616cf}},	//   _spau, _donc, _bois, _blys,
   {{0x7d04b405,0x39a101b3,0x3ce0006c,0xf8bf26e0}},	//   _cois, vės_, _caiv_, _amén_,
   {{0x6f0304ea,0x2d9eb025,0x3ce0023e,0x7d040268}},	//   _fonc, sste_, _daiv_, _dois,
   {{0x6e94054f,0x39a108a1,0x8f9b0130,0x2d9eb406}},	//   _الثا, tės_, _יידי, pste_,
   {{0x7d04b407,0x7d1658ae,0xba08008f,0x394b037a}},	//   _fois, _flys, ахте_, _pkcs_,
   {{0x39a1013f,0x9875539a,0x7d04594c,0x26ca01cb}},	//   rės_, слац, _gois, _abbo_,
   {{0x39a101b3,0x6d4db408,0x63a40ebd,0xc8673bba}},	// [d710] sės_, _ikaa, šinj, ртви,
   {{0x39a1013f,0x67ca00d9,0x1dda0034,0x8aa7100c}},	//   pės_, dējā, _बनात, _трид,
   {{0x5fd80b94,0x09f90080,0x3ce0023e,0x6d4d625d}},	//   _बैसल, _صفحة_, _yaiv_, _kkaa,
   {{0xbcfb0018,0x26d3b409,0x3ce00197,0x26ca0350}},	//   zmén, sexo_, _xaiv_, _ebbo_,
   {{0xd7f81110,0x39490042,0x6d4d0a4b,0x00000000}},	//   _кур_, moas_, _mkaa, --,
   {{0x9735010d,0xc3243006,0xe29601b6,0x00000000}},	//   _اکرا, омік, баш_, --,
   {{0x20020084,0x758200cd,0x3f860154,0xa0a54a6f}},	//   äkin_, _فیلم, _atou_, байд,
   {{0x6f030087,0xeb04022d,0x7b1001bf,0xba3800ca}},	//   _sonc, _रक्त_, _räum, יטוח_,
   {{0x7529b40a,0xa3e2142e,0x6f03b40b,0xbcfb0018}},	//   _imez, धिः_, _ponc, tmén,
   {{0x6d4d63c1,0x7d0401b5,0x7d16b40c,0x249d01fa}},	//   _akaa, _sois, _slys, lawm_,
   {{0x3ce0023e,0x7d04b40d,0x7d1613ea,0xb6da006e}},	//   _paiv_, _pois, _plys, אַכט,
   {{0xcb0909c1,0x98b00031,0x753b0172,0xd25600ca}},	//   _אל_, _šaľa_, _jjuz, _השעה_,
   {{0x7d04b40e,0x7f8500e3,0x853a006e,0x753bb40f}},	//   _vois, _التن, רגרי, _mjuz,
   {{0x249d006c,0x6f1a2527,0x81bc0033,0x6d4d83b7}},	//   hawm_, chtc, েটর_, _ekaa,
   {{0x7d04a090,0x7529030b,0x249d023e,0x00000000}},	//   _tois, _omez, kawm_, --,
   {{0x443f0092,0xb87b04d8,0x3949137f,0xe6d00557}},	//   _oxu_, _raíc, goas_, सज्ज,
   {{0xc6760bf4,0x6676097d,0x39522522,0xf8bf0113}},	// [d720] مطاب, مدار, rlys_, _imél_,
   {{0xe64602ec,0x7529b410,0x2d59020d,0x63a42316}},	//   безп, _amez, néen_, šink,
   {{0x394903be,0x645bb411,0xadea00b6,0x00000000}},	//   boas_, _azui, टियन_, --,
   {{0x69deb412,0x443f02a1,0x98ac01d3,0x3949034f}},	//   _ispe, _bxu_, ēlēs_, coas_,
   {{0x7cff023b,0x68e4026a,0xc30a04a1,0x29000a4b}},	//   _përz, mdid, ледж_, mjia_,
   {{0x75290129,0x753b0174,0x67ca01d3,0x68e4b413}},	//   _emez, _ejuz, rējā, ldid,
   {{0xe7e002d5,0x41e60037,0x443fb414,0xa4f801f9}},	//   निकप, إستف, _exu_, _پکار_,
   {{0xd13000e3,0x443f00bd,0x2900a9e8,0x67ca00e8}},	//   ظمة_, _fxu_, njia_, pējā,
   {{0x200d0103,0x3dce0131,0x68e42c05,0xc6000033}},	//   gyei_, _spfw_, idid, _এইটা_,
   {{0x69de7b5b,0x6d4d0185,0xb7db0341,0x64400113}},	//   _ospe, _skaa, נקיי, _ixmi,
   {{0x63a2b415,0xceb86392,0x00000000,0x00000000}},	//   lson, rgę_, --, --,
   {{0x629a0052,0x39490072,0x6b9603a8,0x00000000}},	//   _heto, xoas_, _bwyg, --,
   {{0x629a5526,0xe0431a18,0x68e4b0c3,0x7f4600ae}},	//   _keto, _енци, ddid, _ледж,
   {{0xf1dc018b,0x629a00dd,0xdd9003ef,0x63a25a34}},	//   _मनान, _jeto, _قوت_, ison,
   {{0x80db0033,0xc33300ca,0x692c11bc,0x394900bc}},	//   ভার্, לוש_, rşen, toas_,
   {{0x629a37ca,0x99553006,0x2900023b,0x68e45e9f}},	//   _leto, ікац, gjia_, gdid,
   {{0x3949001f,0xdb0f04d8,0xb87b0143,0x629a0483}},	// [d730] roas_, lucí, _caía, _oeto,
   {{0x291b0abd,0x629ab416,0x63a234f5,0x68e4194a}},	//   shqa_, _neto, dson, adid,
   {{0x6eca0efb,0x249d01fa,0x247e0129,0x24890143}},	//   त्यु, tawm_, _ịma_, ñamo_,
   {{0x5455013d,0xa3b90421,0x629a084e,0x63a2084e}},	//   овет, لاتر_, _aeto, fson,
   {{0x629a27cd,0x03a5002d,0x2bdf25af,0xe2990036}},	//   _beto, цило, _पैमा, аал_,
   {{0x629ab417,0x249d023e,0x057701c3,0xdb060125}},	//   _ceto, sawm_, _هارد, stkö,
   {{0x7bdfb418,0x63a245be,0x569400c6,0x629a154c}},	//   _lsqu, ason, _хаст, _deto,
   {{0xdb0f46b4,0x753b0051,0x7529b419,0x443f0062}},	//   ducí, _ujuz, _umez, _txu_,
   {{0xef191bec,0x63a20018,0x6006055b,0x46c60179}},	//   ими_, cson, жным_, र्वह,
   {{0x629a03ee,0x2ca9b41a,0xc34b013f,0x00000000}},	//   _geto, _adad_, _сябе_, --,
   {{0x291907d1,0x7bdf034f,0xab5b0103,0x22c50174}},	//   _olsa_, _asqu, ttün, _ịkwu_,
   {{0x629ab41b,0x2fdd023e,0x2ca9037a,0x69de0154}},	//   _zeto, _tswg_, _cdad_, _rspe,
   {{0x2d590257,0x27e96f10,0x629a06b0,0x2ca903a8}},	//   péen_, jvan_, _yeto, _ddad_,
   {{0x2ca9b41c,0x63a40080,0x3f8d15d0,0x7bdf0036}},	//   _edad_, áini, mpeu_, _dsqu,
   {{0x7bdf7ffa,0x6ee4048f,0xb87b2ee8,0x80be0033}},	//   _esqu, _رسول, _saía, ্যর্,
   {{0x63a4522a,0x60c9002b,0x088a01b6,0x7d1d042c}},	//   šini, nfem, рбай_, chss,
   {{0x68e40d9f,0x3706322c,0x98a90034,0x27e90103}},	// [d740] rdid, опаг, znać_, gvan_,
   {{0xab5b1f8a,0x6560009c,0x98a9007f,0x00000000}},	//   ntül, _shmh, ynać_, --,
   {{0x39462046,0x69deb41d,0x8c3b01bf,0x27e9007b}},	//   _мног, _uspe, raße, avan_,
   {{0x63a21a4e,0x629a129e,0x938a1942,0x317801f9}},	//   tson, _seto, аска_, _érzi_,
   {{0x93465c8f,0xd40300c2,0x7bc602ac,0xc3d606cf}},	//   онде, дящи, ntku, تغاث,
   {{0x47d900c1,0xa3bbb41e,0x37d900c1,0xfbb20034}},	//   _פֿרײ, _अमर_, _פֿרע, _जिनम,
   {{0x65c30ed8,0x629a386f,0x63a2188c,0x60c9093e}},	//   _обра, _veto, sson, ffem,
   {{0x63ad0b4b,0x1fa626a7,0x629a7f4a,0x7bc60e37}},	//   šana, орог, _weto, ktku,
   {{0x629ab41f,0xdfd000ab,0x4aca1677,0x50b700cd}},	//   _teto, ريد_, िभाव, زديد_,
   {{0xcf2600e3,0xbcfb00fd,0xe2972753,0x00000000}},	//   تربي, rmém, _мау_, --,
   {{0x667b00f5,0xa3e2039d,0x27e91ba9,0x7bc6084e}},	//   יטיק, धिक_, zvan_, etku,
   {{0x657cb420,0x27e9008b,0xdb1d0653,0xbfa30023}},	//   _murh, yvan_, rtsí, _kiế,
   {{0xdee615c3,0x1ae400c7,0xa06a0291,0x4ae701b3}},	//   _моди, খানে_, _тада_, оўва,
   {{0xb87b0072,0xdce4007e,0x00000000,0x00000000}},	//   _caín, _dunđ, --, --,
   {{0x7bc608d3,0x657c8526,0x00000000,0x00000000}},	//   atku, _nurh, --, --,
   {{0x27e90401,0x00000000,0x00000000,0x00000000}},	//   tvan_, --, --, --,
   {{0xdce414f3,0x00000000,0x00000000,0x00000000}},	// [d750] _gunđ, --, --, --,
   {{0x27e9b421,0x368b01b6,0xa92800b6,0x657cb422}},	//   rvan_, рсан_, _požá, _burh,
   {{0x657c2608,0xab5b0364,0x7af700bd,0xcfc20033}},	//   _curh, ntüm, _inxt, ্টিন,
   {{0xbfa30023,0x69c5063d,0x98a000c4,0x00000000}},	//   _biế, _iqhe, viić_, --,
   {{0x7ae51d2d,0x69c71ca4,0xd7fb0360,0x78fa00ca}},	//   _kaht, ltje, _тун_, _הפרו,
   {{0x657c0113,0x20e700fe,0x69c701cb,0x7d1d0216}},	//   _furh, _ối_, otje, ërsj,
   {{0x69c7b423,0x34950636,0x7ae52a3c,0x94450018}},	//   ntje, _навр, _maht, _کھان,
   {{0x7ae51d2d,0x212b06a3,0x04c90037,0x69c701cb}},	//   _laht, òch_, _دوري_, itje,
   {{0x69c70480,0x60c9037d,0x78fc00ca,0xe3e901f9}},	//   htje, rfem, שפחו, _دکان_,
   {{0xa2b423c3,0xef191a57,0x7ae55d14,0x6b523459}},	//   _обуч, смо_, _naht, nægt,
   {{0x69c700dd,0x69c5023e,0xb87bb424,0xdce40e94}},	//   jtje, _nqhe, _raín, _sunđ,
   {{0xb87b0042,0x69c702b6,0xdce4037d,0x8c460161}},	//   _saín, dtje, _punđ, земе,
   {{0x69c70126,0x2bdf00a3,0x7ae59ae8,0x69c5063d}},	//   etje, _पैदा, _baht, _aqhe,
   {{0xa3ae0782,0x692c026a,0xdee50231,0x69c70381}},	//   _किस_, rşem, _хоки, ftje,
   {{0x7bc68fd7,0xab270120,0x811f007f,0x00000000}},	//   stku, чора_, _बताओ_, --,
   {{0x657a00fd,0x00000000,0x00000000,0x00000000}},	//   _éthi, --, --, --,
   {{0x68437cc9,0x69c70126,0x186761f2,0x69c50372}},	// [d760] ента, atje, зати_, _eqhe,
   {{0x63b90381,0x00000000,0x00000000,0x00000000}},	//   duwn, --, --, --,
   {{0xfebd0033,0x69c70381,0xf5b6007b,0x00000000}},	//   _অসাধ, ctje, ясаю, --,
   {{0xd9460859,0x00000000,0x00000000,0x00000000}},	//   _хеми, --, --, --,
   {{0xf8b309c1,0x2d9804d8,0xdb1d0103,0x61e1235b}},	//   _אשר_, árez_, ltsá, _asll,
   {{0x657c0084,0x3f82003e,0xbfa30023,0xd3790120}},	//   _turh, íkum_, _viế, ічі_,
   {{0x7d1d057a,0x6b5202b6,0x672e0090,0x68e602c3}},	//   ërsk, lægs, _imbj, _kakd,
   {{0xbcfb0068,0x26da0d12,0xbfa300de,0x68e601c2}},	//   rmék, lepo_, _tiế, _jakd,
   {{0x44220212,0x61e100b3,0xa2c4030b,0x2486305d}},	//   _åk_, _esll, _राप्, mcom_,
   {{0x2486b425,0x68e601c2,0x61e10090,0x69c77001}},	//   lcom_, _lakd, _fsll, ytje,
   {{0x2d9810af,0x1cd9013f,0xbcfbb426,0x8cc100c3}},	//   ère_, одны_, lméi, _वादो,
   {{0x2486b427,0x68e604a6,0x7ae52c3d,0xd7ac0096}},	//   ncom_, _nakd, _saht, _चिंच,
   {{0x61dc022d,0x60c2b428,0xab5bb429,0x69c7029a}},	//   _मनुष, _icom, stüm, wtje,
   {{0x26da0292,0xbcfb00e3,0x81cf0033,0x69c7b42a}},	//   jepo_, iméi, শির_, ttje,
   {{0x68e6b42b,0x7ae50673,0xb87b0072,0x24860479}},	//   _bakd, _vaht, _faíl, kcom_,
   {{0x672e03e5,0x69c74c28,0x76550034,0xb87b00d2}},	//   _ambj, rtje, _ryzy, _hníz,
   {{0x7ae584ba,0x69c737ff,0x24860031,0x6b5202b6}},	// [d770] _taht, stje, dcom_, tægt,
   {{0x6d4f085f,0x6b8db42c,0xec3800ca,0x69c7b42d}},	//   loca, _itag, _מאחר_, ptje,
   {{0x692c0233,0x00000000,0x00000000,0x00000000}},	//   kşeh, --, --, --,
   {{0x7d1d00dd,0x62888bd9,0x32cf0233,0xdcf9022b}},	//   ërsh, _afdo, zıyı_, _ouvč,
   {{0x96eb1ca9,0x2a6100c4,0x00000000,0x00000000}},	//   _льва_, _hzhb_, --, --,
   {{0x63ad00d9,0x6d4f0037,0x290b026a,0x6b8d0a4b}},	//   šano, hoca, _hoca_, _mtag,
   {{0x290b026a,0x6d4fb42e,0x2486023c,0xdb2401f9}},	//   _koca_, koca, bcom_, éséb,
   {{0x2d830146,0x248638bf,0x290b0095,0x6d4f2972}},	//   íjem_, ccom_, _joca_, joca,
   {{0x63a40080,0x6b8db42f,0xd0a800e3,0xb4b91fbb}},	//   áint, _ntag, سطين_, चली_,
   {{0xee39ae87,0x290b2fb6,0x3f8b01d3,0x249f009c}},	//   жно_, _loca_, īcu_, _heum_,
   {{0x6d4fb430,0x6d470128,0x9d460f0a,0x6b8db431}},	//   foca, čkan, денд, _atag,
   {{0x60c20080,0x63a90088,0x30150243,0x00000000}},	//   _gcom, _kven, _одер, --,
   {{0xa2c4000d,0xeb972dfb,0x249f0154,0x60db0a4b}},	//   _राम्, мия_, _meum_, meum,
   {{0x6b8d0037,0xdb1d0018,0x68e60dcf,0x60db25d9}},	//   _dtag, ttsá, _sakd, leum,
   {{0x6b8d2bf6,0x68e6060f,0x00000000,0x00000000}},	//   _etag, _pakd, --, --,
   {{0x63a94a9b,0x26da0010,0x249f820f,0x6d4f015e}},	//   _oven, wepo_, _neum_, coca,
   {{0xcece00de,0x24860031,0x290b0231,0x68e601cb}},	// [d780] _mộng_, vcom_, _doca_, _vakd,
   {{0x363600cd,0xcece0023,0x2ca005c2,0x2486007f}},	//   وراس, _lộng_, _heid_, wcom_,
   {{0x68e6b432,0x2486b433,0x249f01b9,0x26dab434}},	//   _takd, tcom_, _beum_, repo_,
   {{0x290bb435,0x249f0441,0xe45a4717,0x9e3c00d4}},	//   _goca_, _ceum_, оже_, naďa,
   {{0x249f02a1,0xc3da00cd,0x2ca00da0,0x60db03be}},	//   _deum_, تباط_, _meid_, deum,
   {{0x60c2008f,0xbcfb0503,0x317eb436,0x6d4f14a8}},	//   _scom, rméi, _putz_, zoca,
   {{0x63a93df4,0x24865ad8,0x7b1001bf,0xda0e05fa}},	//   _even, pcom_, _häus, सहित_,
   {{0xcece0028,0x2ca00006,0x78a40383,0x00000000}},	//   _cộng_, _neid_, naiv, --,
   {{0x27e0b437,0x64a3371f,0xcece00fe,0x692c047e}},	//   nwin_, _шата, _dộng_, rşeh,
   {{0x2216001d,0x44260010,0x63a4b438,0x75226d15}},	//   _офер, mzo_, šins, lhoz,
   {{0x27e018c4,0x1d350c10,0x6b8d188c,0x44260451}},	//   hwin_, ення, _stag, lzo_,
   {{0x6603473d,0x60db5991,0x2ca000eb,0x28ce1179}},	//   änki, ceum, _ceid_, _हॉलि,
   {{0x4426b439,0x290b2243,0x1016006f,0x2ca001b9}},	//   nzo_, _roca_, _تباد, _deid_,
   {{0x290bb43a,0x00000000,0x00000000,0x00000000}},	//   _soca_, --, --, --,
   {{0xd90f03ed,0x290bb43b,0xc1dc009d,0xf77f026a}},	//   لید_, _poca_, _मनोग, _suç_,
   {{0x58d409fe,0xa2d50789,0xa3ae00ec,0x6eca030b}},	//   кост, _मॉन्, _किं_, त्रु,
   {{0x3fbc00c7,0x6b8d8fcc,0x290b09ac,0x588400c6}},	// [d790] _অনুষ, _utag, _voca_, тыса,
   {{0x4426b43c,0x60dbb43d,0x7d0d8327,0x00000000}},	//   dzo_, zeum, _hoas, --,
   {{0x63a90572,0xb8e500c7,0x60db9417,0x44260b24}},	//   _sven, _এস_, yeum, ezo_,
   {{0xb4b903a2,0x7d0db43e,0x00000000,0x00000000}},	//   चले_, _joas, --, --,
   {{0xdb1d01c5,0xcece0019,0x7d0d3f45,0x3ce90167}},	//   rtsæ, _rộng_, _moas, _maav_,
   {{0xfbb200a5,0x31666c41,0xdb1d02b6,0xe3b00076}},	//   _जिसम, _ahoz_, stsæ, شره_,
   {{0xe5c4349e,0x248004a3,0xd37800c4,0x26c14ba4}},	//   _исто, žima_, _dić_, mgho_,
   {{0x7d0d0012,0x3fe50950,0xfa78028c,0x7522b43f}},	//   _noas, ежив, ועות_, choz,
   {{0x61f80038,0x20190018,0x60db036b,0x63a901df}},	//   _ďalš, ási_, reum, _uven,
   {{0x60db4834,0x26c10da7,0x2ca0b440,0xc43205bc}},	//   seum, ngho_, _seid_, _حکمت,
   {{0xed5a3d7c,0xa2c43ec9,0x27e084ce,0x3eae01b9}},	//   зон_, _रात्, zwin_, _ddft_,
   {{0xdb061054,0x7d0db441,0x7c2602db,0x692c8308}},	//   mské, _coas, tzkr, lşev,
   {{0xdb06025b,0xdb1d0212,0x09a80096,0x78a45f36}},	//   lské, ktsä, गळ्य, vaiv,
   {{0xada526fd,0x316d5e7a,0x00000000,0x00000000}},	//   _закл, lmez_, --, --,
   {{0x44260020,0x3ea52e17,0xdb060074,0x2ca0b442}},	//   zzo_, malt_, nské, _teid_,
   {{0x3ea5b443,0x316d026a,0xb4b932f7,0xdd8e0076}},	//   lalt_, nmez_, चलो_, _اوي_,
   {{0x63ad19d0,0x81d500c7,0x59750077,0x78a4b444}},	// [d7a0] šanj, িটি_, тыру, raiv,
   {{0x27e0b445,0xff7a00c1,0x3ea5b446,0x44263441}},	//   rwin_, פטעמ, nalt_, vzo_,
   {{0xdb060146,0x3ce9023e,0x316d6c5b,0x7d0d0350}},	//   jské, _yaav_, kmez_, _yoas,
   {{0x3ea5b447,0x3ce901fa,0x4426b448,0xdb061054}},	//   halt_, _xaav_, tzo_, dské,
   {{0x3940b2e1,0x3ea52225,0xd1300281,0x69370e94}},	//   mnis_, kalt_, یمت_, rćet,
   {{0x44263b93,0xf65100fb,0x3ea5007a,0x3940b449}},	//   rzo_, ائے_, jalt_, lnis_,
   {{0x8cc100a5,0x6d565fae,0x3940b44a,0x6d440134}},	//   _वालो, _okya, onis_, _ojia,
   {{0x3940b44b,0x6d440239,0x6d56083e,0x00000000}},	//   nnis_, _njia, _nkya, --,
   {{0x9346545a,0x93c80068,0xbcfb4173,0xb466061b}},	//   _знае, _تازہ_, llég, _чкал,
   {{0x6d44b44c,0x6d471b32,0x394001bf,0x6d5638d1}},	//   _ajia, čkam, hnis_, _akya,
   {{0x3940b44d,0xd36f33c6,0x7d0d0052,0xf1d4007a}},	//   knis_, _اهل_, _poas, _दहिन,
   {{0x2724003e,0x39520158,0x00000000,0x00000000}},	//   _hönd_, joys_, --, --,
   {{0x3ea54834,0x7d0d00d3,0xa2d5007a,0x6d440154}},	//   balt_, _voas, _मॉड्, _djia,
   {{0x3940b44e,0x6d560283,0x628a2591,0x7b10042c}},	//   enis_, _ekya, ncfo, _säur,
   {{0x39403f6a,0xcf5700a1,0x99672cad,0x799e0178}},	//   fnis_, _רבות_, етал, _cwpw,
   {{0x0e5b00a1,0x39400116,0x6e2e01cd,0x691100f3}},	//   _מדוב, gnis_, úbbu, _råes,
   {{0xb909033a,0xdb1d17a5,0xdb06b44f,0x7d1d0216}},	// [d7b0] _यस_, ttsä, zské, ërsu,
   {{0x6d5db450,0x394000bc,0x466b0012,0xf6471ca5}},	//   llsa, anis_, прем_, нхен,
   {{0xdb1d0222,0x394002e2,0xd5bb05b6,0x348e00ac}},	//   rtsä, bnis_, яса_, _ịdị_,
   {{0xdb06025b,0xdb1d02c3,0xdc3400d4,0x00000000}},	//   vské, stsä, zúča, --,
   {{0x81d500c7,0xdb1d0364,0x68ed020e,0x00000000}},	//   িয়া_, ptsä, mdad, --,
   {{0xdb060146,0x2909553d,0x2f1b0231,0x00000000}},	//   tské, ljaa_, _rêgo_, --,
   {{0x3ea50006,0x9f4bad42,0x316d026a,0x2909358c}},	//   valt_, ící_, tmez_, ojaa_,
   {{0x68ed401a,0xdb06025b,0x3ea501bf,0x13f5008f}},	//   ndad, rské, walt_, _избя,
   {{0x3ea509ce,0xa3ae00a5,0xf8bf0018,0xb4dd00aa}},	//   talt_, _किए_, _elég_, तजी_,
   {{0x3940b451,0x6569b452,0x68ed0049,0xbcfb00b6}},	//   znis_, _hheh, hdad, hléd,
   {{0x68fd0501,0xa3e93245,0xdc340181,0x3ea55d6e}},	//   _onsd, यिक_, rúča, ralt_,
   {{0x3ea50006,0x4087008f,0xe804030b,0x6aca0034}},	//   salt_, _чужб, रममा_, िभ्र,
   {{0x68edafce,0x3ea57810,0xe8d90174,0x398700b7}},	//   ddad, palt_, alị_, _aõs_,
   {{0x68edb453,0x68fd0154,0x8064004d,0x6d5db454}},	//   edad, _ansd, _свіж, alsa,
   {{0xa2c414e5,0x3940b455,0xdb040161,0xfaa32cbf}},	//   _रास्, tnis_, _aviã, расо,
   {{0x6d440496,0x68ed4ca2,0xf1b200c1,0xdcf900d9}},	//   _ujia, gdad, יסל_, _tuvā,
   {{0x2fcd462c,0xf8bf00ee,0xfc3f0037,0xdb16003e}},	// [d7c0] nteg_, _amés_, laín_, ðbót,
   {{0x3940b456,0x667612eb,0x65690112,0x68edb457}},	//   snis_, ندار, _aheh, adad,
   {{0x644908a8,0x37cf0033,0x3940b458,0x7589004d}},	//   _axei, রিগর, pnis_, есів_,
   {{0x6b844586,0x63b90150,0x6569039f,0xbcfb0103}},	//   _kuig, frwn, _cheh, lmér,
   {{0x0fbc0033,0x69ceb459,0x6569b45a,0x6b8402ac}},	//   _অন্ধ, ltbe, _dheh, _juig,
   {{0x6569b45b,0x6b8401b5,0xbcfb464f,0xe3630036}},	//   _eheh, _muig, plég, акчи,
   {{0xf1a30138,0x6b84b45c,0xe5a30ce5,0xbcfb00fd}},	//   арын, _luig, _виси, llée,
   {{0x65690381,0x69ce6178,0x00000000,0x00000000}},	//   _gheh, itbe, --, --,
   {{0xceba03e3,0x777c0090,0x42ca0161,0x3a3c05db}},	//   _alƙa_, _kirx, _оган_, _žvpl_,
   {{0xa3e717e5,0x69ce13c5,0x821a1676,0xdcdb1dae}},	//   _बनत_, ktbe, _оцет_, यज्ञ,
   {{0x68ed1321,0xc0e70103,0x6f1a18ef,0x425600ae}},	//   ydad, رفین_, rktc, _ртат,
   {{0x6b841030,0x200200aa,0x65690052,0x7afe01cb}},	//   _buig, äkis_, _xheh, _anpt,
   {{0x02c9007a,0xaed4002d,0x6b84036b,0xcfb4008f}},	//   _रामभ, _болш, _cuig, _сблъ,
   {{0x6b8401f7,0x69ce4bcb,0x68ed026d,0xdce600e8}},	//   _duig, ftbe, wdad, rmkā,
   {{0x987e0b88,0xaad200b6,0x98a90034,0x98c71b9d}},	//   _açık_, द्धक, niać_, ксал,
   {{0xbcfb9975,0x63ad6097,0x6b841909,0xed590031}},	//   rmés, šani, _fuig, buľa_,
   {{0x68ed2733,0x195832e3,0x290900c2,0xadea07d5}},	// [d7d0] rdad, таты_, rjaa_, टिकन_,
   {{0xa2c420cd,0x6569b45d,0x68edb45e,0x7d1d5530}},	//   _राष्, _sheh, sdad, lkss,
   {{0x6b8401c0,0x69ce029a,0xfdfb00c3,0x657b007b}},	//   _zuig, ctbe, एमएस_, _piuh,
   {{0x99f60054,0x2d5900fd,0x765c047c,0x7d1d09a1}},	//   _עזרה_, mées_, _dyry, nkss,
   {{0xd006223e,0x63a002ad,0x2d590257,0x7bcf015e}},	//   _ال_, _cwmn, lées_, ntcu,
   {{0x56943006,0x8c1c0089,0xdb1d014b,0x798507f5}},	//   _варт, וודי, fusé, _kuhw,
   {{0x2d59025a,0x2d8a03be,0x00000000,0x00000000}},	//   nées_, íbel_, --, --,
   {{0x00e51bb8,0x6b820036,0x644900b3,0x4fe90161}},	//   ужин, _èogg, _txei, емин_,
   {{0x7ff55e51,0x7bcd023e,0x2d5900fd,0x63a00150}},	//   اسبا, _nqau, hées_, _gwmn,
   {{0x6b840013,0x8e0942c7,0x2fcd060f,0x3ea30103}},	//   _ruig, енов_, rteg_, újt_,
   {{0xdca60747,0x2fcdb45f,0xdb1d020d,0x00000000}},	//   лани, steg_, cusé, --,
   {{0xa3e71085,0x6b8405fe,0x2d9101d3,0x27200374}},	//   _बना_, _puig, īze_, _यत्र_,
   {{0xdcf900d9,0xdb040231,0x00000000,0x00000000}},	//   _atvē, _aviá, --, --,
   {{0x69ce12ab,0x798552f6,0x6fb20b9f,0x7d1d02ac}},	//   ttbe, _buhw, _اموا, akss,
   {{0x2d590257,0xc33200ca,0xf38a026e,0x00000000}},	//   gées_, מוך_, _iṣe_, --,
   {{0x69ceb460,0x6b84b461,0xa2d502d5,0x5fb716f8}},	//   rtbe, _tuig, _मॉस्, _इटाल,
   {{0x69ceb462,0x9696121c,0x6eca023a,0x5b3600ae}},	// [d7e0] stbe, греш, त्कु, _бэну,
   {{0x613e01d3,0x628100d1,0xbcfb014b,0x69ceb463}},	//   rīli, _nglo, rlée, ptbe,
   {{0x777c08a8,0x2d5900fd,0xd6e60033,0x692c00ae}},	//   _virx, cées_, নালয, uşes,
   {{0x6281b464,0x291e01d3,0xab5b0364,0x142624ec}},	//   _aglo, ītas_, stüt, лдем,
   {{0xbd2d0130,0x628f00d3,0x98a90034,0x00000000}},	//   וואָ, _şcoa, wiać_, --,
   {{0xab5b026a,0x7cfb007b,0x00000000,0x00000000}},	//   ltür, _kärä, --, --,
   {{0x26d80044,0x15460161,0x00000000,0x00000000}},	//   _ibro_, _бевм, --, --,
   {{0xf38a0139,0x60f8008f,0x6d5d02c6,0x681a00e8}},	//   _aṣe_, тния_, ůraz, _tādā,
   {{0xa3ae0455,0x00000000,0x00000000,0x00000000}},	//   _किट_, --, --, --,
   {{0x2bdf009f,0x2d5900fd,0x62810090,0x38bb0139}},	//   _पैगा, yées_, _gglo, _kàrà_,
   {{0x2d597b49,0xab5b7f09,0x24892574,0xe29b00d7}},	//   xées_, ktür, žame_, _נשאר,
   {{0xd9fe007d,0xac1908d1,0x6281005f,0x2d590257}},	//   _उपजत_, вому_, _zglo, vées_,
   {{0x26d85703,0xbcfb0610,0xddcb0dab,0x7d1d9d6b}},	//   _obro_, eléc, čišt, rkss,
   {{0x2d590257,0xce94013d,0xbcfb00fd,0x3ced033b}},	//   tées_, _такъ, fléc, žev_,
   {{0xa3ab05d4,0x78a67dec,0xdd900037,0xaa591588}},	//   _कौन_, _bekv, _بوب_, тиву_,
   {{0x2d590257,0xc984002d,0x26d82b12,0x00000000}},	//   rées_, сури, _abro_, --,
   {{0x2d59025a,0x4735460b,0x78a60b8e,0x00000000}},	// [d7f0] sées_, анас, _dekv, --,
   {{0x291e00dd,0xbcfb03be,0x2d5900fd,0x38bb0032}},	//   ëtar_, bléc, pées_, _bàrà_,
   {{0x3f860072,0xdc5633e7,0x78a60103,0x00000000}},	//   _luou_, _مریک, _fekv, --,
   {{0x057412eb,0x26d8b465,0xb87b0072,0x54a7001c}},	//   ماند, _ebro_, _saíu, احاف,
   {{0xab5b00a7,0xaad2023a,0x00000000,0x00000000}},	//   rrüf, द्वक, --, --,
   {{0x41b53549,0x77ba00ca,0x38bb0065,0x883a00ca}},	//   асит, _במשח, _fàrà_, _יתרו,
   {{0xab5b01bf,0x2249008f,0x68ef0188,0x636d0072}},	//   prüf, ъпки_, _kacd, húng,
   {{0xa2d50455,0x5eaf0033,0x00000000,0x00000000}},	//   _मॉर्, জ্ঞে, --, --,
   {{0x68efb466,0xa2cd1c83,0x2eee0154,0xf1c70031}},	//   _macd, _साप्, _baff_, _snáď_,
   {{0xe80d04dd,0x6281b467,0x2eee028d,0x00000000}},	//   _सपना_, _uglo, _caff_, --,
   {{0x52840080,0x60b50177,0xed46215c,0xd1b80781}},	//   _المك, _نمائ, иноп, _مانا_,
   {{0x2b5a00e7,0x63ad00e7,0x2d520143,0xee3626fd}},	//   _skpc_, šanu, láez_, рню_,
   {{0xa09a0130,0x8fa507ca,0x00000000,0x00000000}},	//   _סיסט, _тале, --, --,
   {{0xfaa3133d,0x2eee03a8,0x00000000,0x00000000}},	//   жаро, _gaff_, --, --,
   {{0xa2cd0efb,0xc3320327,0x68ef008c,0xbb43105b}},	//   _सान्, קול_, _bacd, церк,
   {{0x3ea708ca,0x68460450,0x2bc300a4,0xb7c20231}},	//   _hent_, анба, वंशा, çãon,

   {{0x3ea7b468,0xb8ee0e19,0x69a70179,0xab5bb469}},	// [d800] _kent_, _रा_, टीबी, rtür,
   {{0x2d87b46a,0xf7720cc8,0xab5b0684,0x3ea70154}},	//   _kune_, زاء_, stür, _jent_,
   {{0x2d8700a1,0x3ea7b46b,0x6d476b2f,0x78a6b46c}},	//   _june_, _ment_, čkav, _tekv,
   {{0x636405fe,0xaad21388,0x6d46b46d,0x69de0078}},	//   tòno, द्रक, nnka, _ippe,
   {{0x68e4b46e,0x29020193,0x442000de,0x2d870f01}},	//   meid, _inka_, ái_, _lune_,
   {{0x68e4891a,0x8c1b0054,0x60cb009c,0x21ce00a7}},	//   leid, כוני, _acgm, _məhv_,
   {{0x442088ac,0x1bed6e55,0xdcc60789,0x2d87b46f}},	//   ši_, _चैनल_, _वांछ, _nune_,
   {{0x6d46333e,0x68e45112,0x2eeeb470,0x3ea703a8}},	//   jnka, neid, _saff_, _aent_,
   {{0x8f461087,0x3ea7b471,0x42ea0291,0x2d870565}},	//   иход, _bent_, _имао_, _aune_,
   {{0x68e4b472,0x2d87002d,0x69de0305,0x6d46b473}},	//   heid, _bune_, _oppe, enka,
   {{0x68e4b474,0x6d220f35,0x656207ac,0x36f700ca}},	//   keid, मसंग_, oloh, בצים_,
   {{0xb87b0231,0x65621c49,0x68e43661,0x00000000}},	//   _maír, nloh, jeid, --,
   {{0x3ea73058,0x69de32b8,0xa2cd022d,0xa3c90096}},	//   _fent_, _appe, _साम्, लंय_,
   {{0x3ea7b475,0x80d2030b,0x2d87028d,0x2d8001b9}},	//   _gent_, भ्रे, _fune_, _eiie_,
   {{0x68e400e3,0x2d8701e9,0x6d46023e,0x29883b4c}},	//   feid, _gune_, bnka, исто_,
   {{0xdb1d0579,0x68e45d5f,0xa3e7007a,0x1d080284}},	//   musí, geid, _बनल_, _већи_,
   {{0xbcfb095d,0x65620094,0x636d0206,0xb87b0231}},	// [d810] cléa, dloh, lúne, _raís,
   {{0x307700a1,0x2ca9b476,0x68ef008c,0xb87b13a9}},	//   שתמש_, _head_, _wacd, _saís,
   {{0xb87bb477,0x68e48bc2,0xa3c902e8,0x2d8a0220}},	//   _país, beid, लून_, íbeh_,
   {{0x67053ec9,0x2fc40174,0x5e79006e,0x45840120}},	//   राहक_, kumg_, אָנד, ігів,
   {{0xc6510018,0x75f00103,0x3eacb478,0xdd020357}},	//   _کہاک, tózá, kadt_, šući,
   {{0x97250470,0x2ca900ca,0x69de40d6,0x78ad007b}},	//   _افسو, _lead_, _yppe, laav,
   {{0x6d4655f1,0x34958b6f,0xdbdd0094,0x3ea700ca}},	//   ynka, _габр, dšív, _rent_,
   {{0x3ea7b46b,0x78ad96db,0x67050285,0x2ca92e6a}},	//   _sent_, naav, रावक_, _nead_,
   {{0x2d870044,0x27e90f20,0x3ea7b479,0x6727010a}},	//   _sune_, nwan_, _pent_, _kljj,
   {{0x2d87b47a,0x27e9b47b,0x533400ae,0x78ad0302}},	//   _pune_, iwan_, _деут, haav,
   {{0x2ca916e3,0x27e921dc,0x7997006c,0x6b96b47c}},	//   _bead_, hwan_, _ntxw, _styg,
   {{0xeb9a752b,0x2ca9117b,0xa3bb009f,0x27e9b47d}},	//   лим_, _cead_, _आटा_, kwan_,
   {{0x68e40029,0xef0ea4c9,0x27e9b47e,0x2ca98862}},	//   veid, _ем_, jwan_, _dead_,
   {{0x60c9b47f,0x6e9500e3,0x27e9698f,0x68e4b480}},	//   lgem, _الغا, dwan_, weid,
   {{0x68e4b481,0x656202c9,0x2ca90cc2,0x3f8d0052}},	//   teid, yloh, _fead_, lqeu_,
   {{0x6ed32cb6,0x628f00d3,0x27e9005c,0x8886166f}},	//   ब्रु, _şcol, fwan_, слаж,
   {{0xa3c9000f,0x636406a3,0xb87b0558,0x27e9b482}},	// [d820] लूम_, wònm, _saír, gwan_,
   {{0x7bc6aed3,0xaadf02d5,0x7d0400d4,0x7d16041c}},	//   muku, _पॉपक, _hnis, _hoys,
   {{0x7bc6b483,0x7d0403e5,0x27e90821,0xdb060103}},	//   luku, _knis, awan_, cská,
   {{0xab5b07d1,0x2ee565b0,0xb4c2000d,0xf38a026e}},	//   crüb, helf_, ंले_, _aṣa_,
   {{0x60c97558,0x7d04b484,0x656219da,0x9e3c0206}},	//   dgem, _mnis, rloh, raďi,
   {{0x81e100c7,0xff4709b4,0xf1a64070,0x60c9024a}},	//   দিন_, _رخ_, брин, egem,
   {{0x7d040af0,0x248900cc,0x7bc6694c,0xdb1d0161}},	//   _onis, žama_, huku, lusã,
   {{0x7bc6b485,0xf8ba022d,0xa49100d0,0x1ae40081}},	//   kuku, ेलिय, _قیمت, মায়া,
   {{0x2ca9b486,0x3eac611b,0x7bc6b487,0x43860214}},	//   _read_, tadt_, juku, _طلاق,
   {{0x75220068,0x2ca9b488,0x63b302c6,0xdb0602b6}},	//   lkoz, _sead_, ření, lskæ,
   {{0xa2cd10e9,0x2ca9007a,0x3eac0018,0x27e900dc}},	//   _सात्, _pead_, radt_, zwan_,
   {{0xf8bf03be,0x75224bdd,0x7bc61fde,0x2adb030b}},	//   _alén_, nkoz, fuku, ख्नु_,
   {{0x7bc64e8c,0x2ca900bc,0x78ad4710,0x673e00c4}},	//   guku, _vead_, vaav, kipj,
   {{0x7d04b489,0xab5b0364,0x83fd01f9,0xcb6900d1}},	//   _enis, drüc, _szők, شمزه_,
   {{0x78ad4986,0x27e901c2,0xc33902c6,0xdb0f0076}},	//   taav, wwan_, _říká, nscé,
   {{0x7bc60b1a,0x6d4721b8,0xdb1d016d,0x7d040b97}},	//   buku, čkas, fusã, _gnis,
   {{0x78ad02fd,0xc8672195,0x636d25da,0x7bc6b48a}},	// [d830] raav, стви, núnc, cuku,
   {{0x78adb48b,0x27e9787d,0xa2cd3ec9,0x7d040034}},	//   saav, rwan_, _साध्, _znis,
   {{0x27e901c2,0x78ad007b,0x466b13a4,0xa3ab1b11}},	//   swan_, paav, урам_, कीन_,
   {{0x2ee50ab2,0x7ae7b48c,0xab5b0364,0x00000000}},	//   zelf_, lejt, brüc, --,
   {{0x69d503f3,0x3949b48d,0xa2c4000d,0xdfc60190}},	//   ltze, mnas_, _राख्, _تي_,
   {{0xa3aa0abe,0xdd8615ae,0x39492c2e,0x69d50634}},	//   _खबर_, _يو_, lnas_, otze,
   {{0x69d503f3,0x5ea70081,0x7bc62e60,0x349511f8}},	//   ntze, _খালে, zuku, _мавр,
   {{0x3949b48e,0x7bc65794,0x69d50a00,0x7ae700b6}},	//   nnas_, yuku, itze, hejt,
   {{0x60c9b48f,0x69c75d4d,0x7ae70146,0x69d50364}},	//   rgem, huje, kejt, htze,
   {{0x60c9aa6f,0x3cdc030b,0x6d4d2287,0x0ea900c2}},	//   sgem, ग्ने_, _ajaa, шкой_,
   {{0xf1dd2cb6,0x3949b490,0x69c72174,0x7ae7030b}},	//   _महिन, knas_, juje, dejt,
   {{0xed5a2e91,0x7bc6b491,0x7d1623f4,0x63a400d3}},	//   ром_, tuku, _qoys, ţine,
   {{0xdbf406ed,0xc1780fba,0x75290239,0xbcfbb492}},	//   इटेड_, _اصلا_, _mlez, plén,
   {{0x41dd000c,0xf1dd000c,0xa3ab0c16,0x6d4d45a7}},	//   _महास, _महान, कीय_, _ejaa,
   {{0x69c733ae,0x753b0517,0x6d47b493,0x2bb600aa}},	//   guje, _omuz, čkar, _अटका,
   {{0x75290134,0x69820294,0x799c00f0,0xaadb50d7}},	//   _nlez, _ọgbụ, rprw, म्बक,
   {{0x69d50a00,0xa3ab09c4,0x7bc6063d,0x2b8f013c}},	// [d840] atze, कीम_, quku, _güc_,
   {{0x69c71b30,0x3949b494,0x753bb495,0x869a00d3}},	//   buje, anas_, _amuz, ртат_,
   {{0x75220068,0xb87b0139,0x3949b496,0x75290113}},	//   tkoz, _abíd, bnas_, _blez,
   {{0x63640428,0xab5b0364,0xd576004d,0x7e6302ac}},	//   mòni, prüc, цузь, _mynp,
   {{0x63640472,0xdb060537,0x3940b497,0x2e0e00a7}},	//   lòni, rskæ, miis_, rəfi_,
   {{0x7529b498,0x394093f5,0x753b58da,0x673e0052}},	//   _elez, liis_, _emuz, qipj,
   {{0x63640428,0xdb1d020d,0x4cc20033,0xdb0602c3}},	//   nòni, ursé, ষ্যু, mskä,
   {{0x39400c23,0x75292780,0x31570037,0x68f629aa}},	//   niis_, _glez, يجية_, ndyd,
   {{0x68f600f0,0xd00700f6,0xaaaa0285,0x00000000}},	//   idyd, жење_, कराक, --,
   {{0xa3df05d4,0x6d4d01c0,0x39496da8,0x3940008c}},	//   _तहत_, _sjaa, znas_, hiis_,
   {{0x7ae73933,0x3949b499,0x60200139,0xc69300ca}},	//   vejt, ynas_, _bámú, ואת_,
   {{0x69c708c6,0xc0c70277,0x24802316,0x6364015e}},	//   vuje, _душе_, žimu_, dòni,
   {{0x3940019a,0xdb060212,0x7ae700b6,0x68f60178}},	//   diis_, kskä, tejt, ddyd,
   {{0x4f57006f,0x63640428,0x7e63084e,0x6b9db49a}},	//   _وجود_, fòni, _fynp, rpsg,
   {{0x7ae7b49b,0x3a250088,0x636d0037,0x69d501e9}},	//   rejt, álp_, núna, utze,
   {{0x69d5786f,0x2d9eb49c,0xdc2b00bf,0x3940008c}},	//   rtze, mpte_, _نسخه_, giis_,
   {{0x394997de,0x7ae700dd,0x69c76eb0,0x76b90077}},	// [d850] rnas_, pejt, suje, йлар_,
   {{0x6d5db49d,0x7529b49e,0x8f9b0327,0x0705110d}},	//   losa, _slez, יימי, राइव_,
   {{0xa2c40714,0x7529b49f,0x6b8db4a0,0xa4980134}},	//   _राज्, _plez, _huag, _ịhụt,
   {{0x6f180128,0x3940b4a1,0x636d0037,0x6b8d04f3}},	//   _lovc, ciis_, dúna, _kuag,
   {{0x03a57f94,0xb1130134,0x3cfc0341,0xe29922fb}},	//   чило, _hụgh, ילאנ, бал_,
   {{0x6f1802e6,0x6b8d3826,0x6d5d52b5,0x00000000}},	//   _novc, _muag, hosa, --,
   {{0x6d5db4a2,0x29192e87,0x6b8d0124,0xf62800d6}},	//   kosa, _kosa_, _luag, _діти_,
   {{0x753b4076,0x3cf50034,0x6b8db4a3,0x7529024a}},	//   _umuz, इयों_, _ouag, _ulez,
   {{0x6d5db4a4,0x6b8d0257,0x42550260,0x7e630149}},	//   dosa, _nuag, _کنار, _synp,
   {{0x636d003e,0x63a9b4a5,0x7e63084e,0x91f70037}},	//   búna, _iwen, _pynp, _وأضا,
   {{0xf8bf00c9,0x98cb0034,0x63a900f9,0x68f60150}},	//   _além_, िलाए, _hwen, ydyd,
   {{0x63a94984,0xbcfbb4a6,0x29190933,0x6d5d5942}},	//   _kwen, blém, _nosa_, gosa,
   {{0x63a914b1,0x0c23338d,0x6b8d01b9,0x60db2d76}},	//   _jwen, емян, _cuag, mfum,
   {{0x63a9b4a7,0x3b0a0084,0xb11300ac,0x699600d6}},	//   _mwen, щего_, _bụgh, зрах,
   {{0x3940082e,0x63a93944,0xa3ab0096,0x00000000}},	//   tiis_, _lwen, कीत_, --,
   {{0x291910d6,0x63640990,0x63a9b4a8,0x5fc202b0}},	//   _cosa_, ròni, _owen, _शिमल,
   {{0x8ca20067,0x29190496,0x3940b4a9,0x68f602ad}},	// [d860] _क्यो, _dosa_, riis_, rdyd,
   {{0x636405fe,0x394093f5,0x4bfb006e,0x69c100d2}},	//   pòni, siis_, _פליס, álec,
   {{0xceb200a1,0x29192c74,0xa3c9009f,0x63a9b4aa}},	//   גיב_, _fosa_, लूस_, _awen,
   {{0x63a931bd,0x6b8d023e,0x291932a6,0x6e3c016d}},	//   _bwen, _yuag, _gosa_, úrbi,
   {{0x63a90113,0xa3e617ad,0xb4bc06eb,0xe3b71ba7}},	//   _cwen, यौं_, _आयी_, зліч_,
   {{0xf1a64a53,0x2d9eb4ab,0x1fc30081,0x63a900f9}},	//   прин, ypte_, ্বাস, _dwen,
   {{0xa2cd04f8,0x64a613fc,0x7986417d,0x6d5db4ac}},	//   _सार्, _нава, _kikw, yosa,
   {{0x79860294,0x636daf9b,0x63a9022b,0x25080281}},	//   _jikw, rúna, _fwen, _برسی_,
   {{0x6d5d1055,0x63a94747,0x7986b4ad,0x636d0037}},	//   vosa, _gwen, _mikw, súna,
   {{0x539b09c1,0x7986b4ae,0xb4bc06ed,0xd138007f}},	//   _לימו, _likw, _आयु_, _stąd_,
   {{0x6d5db4af,0x2baf1a09,0x63a918ef,0xc0e61855}},	//   tosa, जीना, _zwen, _ножк,
   {{0xab5b01bf,0x6b8d023e,0x2d9eb4b0,0x79867180}},	//   grün, _puag, rpte_, _nikw,
   {{0xbcfb0018,0x6b8d24b3,0xb1130294,0xd10933dc}},	//   llék, _quag, _sụgh, वारण_,
   {{0x6d5db4b1,0x6b8d023e,0x7986009c,0xb1130174}},	//   sosa, _vuag, _aikw, _pụgh,
   {{0x2919b4b2,0x6d5d816f,0x6edb00ca,0x79860198}},	//   _posa_, posa, _החופ, _bikw,
   {{0x79868d88,0x3eae1743,0x6b8d0cc2,0x00000000}},	//   _cikw, _heft_, _tuag, --,
   {{0x291903be,0x7986b4b3,0x00000000,0x00000000}},	// [d870] _vosa_, _dikw, --, --,
   {{0x9f4da612,0xc987002d,0xb1130294,0x63a90b58}},	//   rveç_, _нуми, _tụgh, _rwen,
   {{0x63a9b4b4,0xcb1200ca,0x38c80103,0x25aa0178}},	//   _swen, _סלט_, _کاپی_, _cwbl_,
   {{0xe8eb00fb,0x3eae00a1,0x7986b4b5,0x3874016d}},	//   _اردو_, _left_, _gikw, çará_,
   {{0x29d7b4b6,0xdb061d21,0xfc3f0072,0x78bd0381}},	//   lça_, rrkö, maís_, _idsv,
   {{0x3eae0092,0xc2c40037,0x81e10033,0xa2d200a4}},	//   _neft_, فيهي, দিস_, _ठाण्,
   {{0x29d7b4b7,0xdce42e78,0x2d8e03e3,0x25aa0150}},	//   nça_, _uhić, _nufe_, _gwbl_,
   {{0x212b00a5,0x63a9b4b8,0x850500b9,0x29d70131}},	//   óch_, _twen, _تورن, iça_,
   {{0xab5b00a7,0xbcfb037a,0x27ff0357,0x3eae16ce}},	//   vrün, pléj, _šunj_, _beft_,
   {{0x29d701e8,0x00000000,0x00000000,0x00000000}},	//   kça_, --, --, --,
   {{0xc33200a1,0x60db05bd,0x78bd0141,0x9f4d02ac}},	//   _שוב_, pfum, _odsv, lweë_,
   {{0x3f9f00c2,0x78afb4b9,0x46dd00b6,0x00000000}},	//   ppuu_, _necv, न्तह, --,
   {{0x9f4d0313,0x29d70131,0x79863cec,0x245800d2}},	//   nweë_, eça_, _rikw, _týmů_,
   {{0x09e61121,0x1dc5049d,0x7af70072,0x7986b4ba}},	//   могн, _विपत, _caxt, _sikw,
   {{0x3f8f295c,0x7986022b,0x9f4d00ce,0x00000000}},	//   _hugu_, _pikw, rveä_, --,
   {{0x3f8f008a,0xb4bc0101,0x3f87003e,0x92e90033}},	//   _kugu_, _आये_, _hinu_, যায়_,
   {{0x18674242,0x79860051,0x29d71097,0x9cd70266}},	// [d880] дати_, _vikw, aça_, _חופה_,
   {{0x3f8f03e3,0x8c4301bf,0xe6a80fef,0x917a00fe}},	//   _mugu_, ößer, गरेज, _mấy_,
   {{0x3f870006,0x3f8f0a7e,0x59e21592,0x3ea100bc}},	//   _minu_, _lugu_, _पहिर, _õhtu_,
   {{0x1dc500c3,0xe5a30a51,0xed590031,0x480a00d3}},	//   _विनत, тици, buľu_, _демн_,
   {{0xf8b30327,0x394db4bb,0x38c40065,0x8b65001c}},	//   _בשר_, čest_, _eèrà_, _زایم,
   {{0x3f870649,0xae0d0296,0x80db0033,0x00000000}},	//   _ninu_, िमान_, _মোল্, --,
   {{0x3f8fb4bc,0x201900c2,0x91e30284,0x00000000}},	//   _augu_, äsin_, воје, --,
   {{0x2d8e1074,0x92ae0081,0x3f8f0044,0x2d9c1d32}},	//   _rufe_, কলে_, _bugu_, _rtve_,
   {{0x3f874b7f,0x3f8f14f3,0x2d9c00d8,0x00000000}},	//   _binu_, _cugu_, _stve_, --,
   {{0x3f8f02a7,0x692c026a,0x2d8e0231,0xdbcc0139}},	//   _dugu_, rşey, _pufe_, _lóóg,
   {{0xbcfb674d,0x3f8700ae,0x809f0179,0x7bc049d6}},	//   lléi, _dinu_, _ग्वे, ámun,
   {{0x3f870088,0xa00a00e3,0x7af700a7,0xb4bc00b6}},	//   _einu_, _وقال_, _saxt, _आयो_,
   {{0x7b67249c,0x63a20a00,0x3f8f4d35,0x3f870995}},	//   дтве, npon, _gugu_, _finu_,
   {{0xf047037f,0x3f8703e3,0x78af020a,0xbcfb0076}},	//   _تعمی, _ginu_, _secv, iléi,
   {{0x7af701d4,0xb345016d,0xbcfb0503,0x386d0095}},	//   _vaxt, liçã, hléi, _šer_,
   {{0x29d7b4bd,0x6376b4be,0x3f8701d3,0x7af7008c}},	//   rça_, lând, _zinu_, _waxt,
   {{0xb8f714e5,0xc9840012,0xb345001f,0x6d4f019f}},	// [d890] _सा_, тури, niçã, mnca,
   {{0x6376020a,0x29d79b97,0xb8820072,0x63a21ea1}},	//   nând, pça_, ñían, dpon,
   {{0x6d4f3401,0x6e2d0d2a,0x63a202ac,0x00000000}},	//   onca, _ƙabi, epon, --,
   {{0x629a0149,0x4d7c0142,0x00000000,0x00000000}},	//   _afto, ַרגע, --, --,
   {{0x68edb4bf,0xe2991f0d,0x290b002d,0x5f1105d6}},	//   mead, пал_, _inca_, ताम्_,
   {{0x68ed0099,0xb345001f,0x442903e5,0x3f8f01c2}},	//   lead, diçã, ġa_, _rugu_,
   {{0xe0d10080,0x4429b4c0,0x3f8f27ad,0x9f59b4c1}},	//   هزة_, ša_, _sugu_, ísí_,
   {{0x3f8718b5,0x68edb4c2,0x636d0487,0x6d4f034f}},	//   _sinu_, nead, múnm, ébal,
   {{0x3f87b4c3,0x3995793d,0xdb0601ab,0xff2500d3}},	//   _pinu_, _lås_, rskú, емпо,
   {{0x27e4070a,0x68edb4c4,0xee39141a,0x809f034d}},	//   _ämne_, head, зно_, _ग्रे,
   {{0x3995032e,0x69c70357,0x00000000,0x00000000}},	//   _nås_, jrje, --, --,
   {{0x3f8fb4c5,0xb3450161,0x68edb4c6,0x7bc600e7}},	//   _tugu_, biçã, jead, trku,
   {{0x69c1025b,0x3f870139,0xa1160602,0x23650063}},	//   álen, _tinu_, _سقوط_, _kklj_,
   {{0x643a00c1,0xf8bf026e,0x6d4fb4c7,0x290b21eb}},	//   לערנ, _adé_, anca, _anca_,
   {{0x63a20018,0xb1130294,0x68ed0037,0x69c100b6}},	//   zpon, _gụch, fead, šlen,
   {{0x68ed81a6,0x6376002d,0x63bbb4c8,0x248d00f9}},	//   gead, mâne, _ovun, _ngem_,
   {{0x63bb0172,0x69c73f1b,0x63760231,0x63a20324}},	// [d8a0] _nvun, arje, lâne, xpon,
   {{0x248db4c9,0x39955a6b,0xf8bf0032,0xe9da13c7}},	//   _agem_, _fås_, _edé_, _еко_,
   {{0xfad707a6,0x02c90336,0x63bb9efe,0x612e009c}},	//   _אויך_, _राजभ, _avun, _lùla,
   {{0x68ed0527,0x69dc3a10,0x809f0789,0x61350088}},	//   cead, mtre, _ग्ले, _hálf,
   {{0x69dc2497,0x69ce6f33,0xe2f8004d,0x83fd0103}},	//   ltre, lube, делі_, _szőr,
   {{0x6d466fd4,0xbcfb0076,0x69dc0f5a,0x00000000}},	//   hika, rléi, otre, --,
   {{0x69dc8eb5,0x6d46b4ca,0x69ce03a9,0x27f28d67}},	//   ntre, kika, nube, lwyn_,
   {{0x6d460991,0x63a2b4cb,0xb345001f,0x31ba00d9}},	//   jika, ppon, tiçã, rīz_,
   {{0x6d465ff3,0x69ce0201,0x69c7053f,0x2002003e}},	//   dika, hube, zrje, íki_,
   {{0xb34500c9,0x4426b4cc,0x69ce45f3,0x2d890451}},	//   riçã, myo_, kube, _siae_,
   {{0x44262346,0xb3450396,0xa0a62de0,0x2d440018}},	//   lyo_, siçã, _заед, rűen_,
   {{0x6d469928,0x4426b4cd,0x68ed09d3,0x65620009}},	//   gika, oyo_, xead, nooh,
   {{0x44265fce,0x48fb08fa,0xb87b0af0,0x8fa31a18}},	//   nyo_, _लोगो_, _abín, _баче,
   {{0xa3e80b86,0x69c70087,0x44260188,0x69dc5d41}},	//   _बहन_, trje, iyo_, ftre,
   {{0x68edb4ce,0xdb0404d8,0x998500b6,0xd90f010d}},	//   tead, _avió, álů_, مید_,
   {{0x44260283,0x69c700dd,0x7bda002d,0x2489b4cf}},	//   kyo_, rrje, ătur, žami_,
   {{0x7d0db4d0,0x68ed4f4e,0x69dc6f22,0x3cf800ab}},	// [d8b0] _inas, read, atre, _سعيد_,
   {{0x68edb4d1,0x4426b4d2,0x69dc0019,0x69c7003d}},	//   sead, dyo_, btre, prje,
   {{0xceb30130,0x69dc00e3,0x69ce1f72,0x7d0d2e7f}},	//   ריע_, ctre, cube, _knas,
   {{0xa56700cd,0x8883001c,0x7bdd00bc,0x290b0027}},	//   ردان, _میزن, otsu, _unca_,
   {{0x7bddb4d3,0x4426b4d4,0x27ff03be,0x7bcfb4d5}},	//   ntsu, gyo_, _éun_, nucu,
   {{0x6d461b74,0x7bddb4d6,0x316602f1,0x81ea0033}},	//   zika, itsu, _akoz_, মিন_,
   {{0x4426b4d7,0x7bdd00aa,0x1a9c00c1,0x95c80291}},	//   ayo_, htsu, ליגע, _пута_,
   {{0x44268b47,0x25be0088,0x60091229,0x63bb40d6}},	//   byo_, _ætla_, дним_, _tvun,
   {{0x4426b4d8,0x4395013d,0xb87b0037,0x8ca2148e}},	//   cyo_, _разс, _mbío, _क्षो,
   {{0x7d0d3061,0x6d460bb6,0xd2f70068,0x6376016d}},	//   _anas, wika, _سکتا_, tâne,
   {{0xed5a107a,0x6ea70068,0x614703a9,0x6135003e}},	//   дон_, ونکہ_, _cèlè, _nálg,
   {{0x2cb201d4,0xd24e00cd,0x63760161,0xceba03e3}},	//   _qeyd_, _بچه_, râne, _roƙe_,
   {{0x317f01e8,0x61352c85,0x7bcf0169,0x00000000}},	//   mmuz_, _pálf, gucu, --,
   {{0x69dcb4d9,0x8ca22ebd,0x316d4229,0x637600ae}},	//   ttre, _क्रो, llez_, mânc,
   {{0xf2d2006e,0x63760161,0x21fc00b6,0x7bdd98ed}},	//   יעם_, lânc, máhá_, atsu,
   {{0x69dcb4da,0xdb0f00e3,0x442601c2,0x7d0d01c2}},	//   rtre, rscá, yyo_, _gnas,
   {{0x7bcfb4db,0x44260188,0x69ce0172,0x63760f21}},	// [d8c0] cucu, xyo_, sube, nânc,
   {{0x44261ee3,0x9bb700a1,0x69dcb4dc,0x27f200f0}},	//   vyo_, _שהיה_, ptre, rwyn_,
   {{0x6562019c,0x442614b4,0xd84300d4,0x00000000}},	//   tooh, wyo_, točí_, --,
   {{0x44263289,0xb4cc4255,0x03a60582,0xf4b4001c}},	//   tyo_, लले_, видо, اشاگ,
   {{0xd8430146,0x32050383,0x7f430372,0xbcfb300f}},	//   ročí_, _arly_, _omnq, mlét,
   {{0x4426b4dd,0x46a378ee,0x6376016d,0x04432c37}},	//   ryo_, _варв, dânc, шечн,
   {{0x44261336,0xf7430058,0x0fc30033,0x7bdd042c}},	//   syo_, _теро, ্বোধ, ztsu,
   {{0x44260bb6,0x63760161,0x316db4de,0x6d5602a4}},	//   pyo_, fânc, glez_, _njya,
   {{0xe80504a9,0x63760161,0x05554c81,0xb38600d3}},	//   रिया_, gânc, _стря, _алал,
   {{0x7d0d07bc,0x21ce0092,0xbcfb00fd,0x7bdd01fa}},	//   _snas, _məhz_, hlét, vtsu,
   {{0x7520019f,0xb87b0065,0x7d0d0167,0x7bcf0169}},	//   _komz, _abíl, _pnas, wucu,
   {{0x5d64004c,0x7bdd059a,0x7bcf2cda,0x7f43063d}},	//   итяз, ttsu, tucu, _emnq,
   {{0x60c2b4df,0xdb040143,0x1013001c,0x63760131}},	//   _idom, _aviñ, _نبود, cânc,
   {{0x7520b4e0,0x7bdd452d,0x69c10146,0x636d0072}},	//   _lomz, rtsu, šlem, gúnh,
   {{0x273601c5,0xa9230220,0x7bdd7c2b,0xbcfb1d23}},	//   _mænd_, áľov, stsu, flét,
   {{0x75200415,0x7d0d0051,0x6135037a,0x7bcfb4e1}},	//   _nomz, _unas, _gáld, pucu,
   {{0xdb06033d,0x6aa2b4e2,0x60c20239,0x98751a6d}},	// [d8d0] lský, _şofe, _mdom, улац,
   {{0x6d440067,0x2cb901c2,0x395200b3,0x00000000}},	//   _zmia, lasd_, anys_, --,
   {{0xdb060074,0x60c271d3,0x2baf0096,0xe78404fd}},	//   nský, _odom, जीरा, руто,
   {{0x60c2b4e3,0x61350139,0xe79501f3,0x00000000}},	//   _ndom, _kále, _ماسک, --,
   {{0xfbdf016d,0xd10309c4,0xbcfb0349,0x75200141}},	//   ntê_, _शोषण_, llés, _domz,
   {{0x61350088,0x6376016d,0xf9900421,0x27f900d7}},	//   _mále, vânc, _دبی_, _issn_,
   {{0x21693e04,0x61456b5b,0x68fd013f,0xdb060146}},	//   ники_, лека, _kasd, jský,
   {{0x6376001f,0xdb060146,0xf8bf0032,0xe0d93bba}},	//   tânc, dský, _ilés_, хви_,
   {{0x6135025b,0x1c0700a5,0x68fd3317,0x54551d62}},	//   _nále, शिफल_, _masd, _сват,
   {{0x39499926,0x60c201b2,0x637634ef,0x200600f0}},	//   hias_, _edom, rânc, _droi_,
   {{0x0d861cb1,0x20062f48,0x39490138,0xd12e0470}},	//   ллон, _eroi_, kias_, زمی_,
   {{0xb87b0065,0x61350139,0x60c2009c,0x02df0f38}},	//   _abím, _bále, _gdom, प्रभ,
   {{0xeb97167b,0x39490519,0x518400ae,0x61350072}},	//   лия_, dias_, _туфа, _cále,
   {{0xdd8e0113,0x2d91b4e4,0x68fd02ac,0xdb060094}},	//   _کوي_, ízes_, _aasd, bský,
   {{0xa2db147f,0xbcfb0472,0x39490d5a,0x69d4009d}},	//   _नान्, glés, fias_, बंधी,
   {{0x3949b4e5,0x68fd0072,0x81b50033,0x6d560079}},	//   gias_, _casd, _জমা_, _ujya,
   {{0x27eb01c2,0x7d7b22fe,0x2fdf5cf6,0x3d19009f}},	// [d8e0] _cpcn_, _אנקו, ntug_, _बचते_,
   {{0x888310f7,0x657b585f,0x81ea0081,0x6569b4e6}},	//   служ, _ahuh, মিত_, _akeh,
   {{0xf8bf025a,0x61354098,0x394943d6,0x6b96b4e7}},	//   _clés_, _zále, bias_, _huyg,
   {{0x3949386c,0x68fd1fdc,0x27e6b4e8,0x7afeb4e9}},	//   cias_, _gasd, çons_, _hapt,
   {{0x7afe3b69,0x9cd700a1,0xbef3009d,0x657b0da3}},	//   _kapt, רונה_, _असून_, _dhuh,
   {{0xf74602fd,0x08fc00c7,0x6ed80455,0x290002a7}},	//   _сего, _একটু_, _माधु, ldia_,
   {{0x27e0b4ea,0x41e600e3,0xf2c51acf,0xf1a300c6}},	//   ltin_, استف, рсін, брын,
   {{0x2900b4eb,0xd01000e3,0xdb061fe8,0x200602ef}},	//   ndia_, قلب_, vský, _proi_,
   {{0x29000051,0x2fdf2375,0x62870103,0xf8bf0113}},	//   idia_, gtug_, _újon, _klér_,
   {{0x138a00e3,0xdb060146,0x4ad30557,0xe80513ae}},	//   _أخرى_, tský, _ताइव, रिता_,
   {{0x2293054f,0x2cb90103,0x27e00216,0x32930076}},	//   _المس, tasd_, htin_, _المأ,
   {{0x3949b4ec,0xdb06b4ed,0x27e0b4ee,0x40a800cd}},	//   xias_, rský, ktin_, _شخصی_,
   {{0x39492ad4,0xa2db4038,0x27e0b4ef,0x2ca00169}},	//   vias_, _नाम्, jtin_, _dfid_,
   {{0xa3c9007d,0x6b9601e8,0x613500b6,0xdb0600b6}},	//   लूट_, _duyg, _vále, pský,
   {{0x13d108fa,0xe3d1000d,0x394900ce,0x7afe03a9}},	//   _सम्भ, _सम्झ, tias_, _dapt,
   {{0x27e0b4f0,0x29000472,0xbcfb0103,0x06cc0033}},	//   ftin_, gdia_, rlés, র্মি,
   {{0x3949132d,0x7afe002d,0x3f8e010a,0x68fd084e}},	// [d8f0] rias_, _fapt, _kifu_, _vasd,
   {{0x3949b4f1,0xaadc009d,0x657bb4f2,0x68fd1f19}},	//   sias_, _बायक, _shuh, _wasd,
   {{0x3949309c,0x68fdb4f3,0x06cc0081,0x2c7b0139}},	//   pias_, _tasd, র্ভি, _fàdí_,
   {{0x67d563fe,0xc56b0e25,0x68e40076,0x7afeb4f4}},	//   _кому, رحال_, cfid, _zapt,
   {{0x7afe0b88,0x78adb4f5,0x61fa01ff,0x0ed40714}},	//   _yapt, mbav, _astl, _दांड,
   {{0x26c30167,0x06cc0033,0x56941acf,0x398b0065}},	//   _udjo_, র্বি, _гарт, _fòsì_,
   {{0x657b00dd,0x798f0361,0x00000000,0x00000000}},	//   _thuh, _kicw, --, --,
   {{0xceba01c2,0x2e3b0065,0x00000000,0x00000000}},	//   _roƙa_, _láfé_, --, --,
   {{0x61fa1886,0x2f55372a,0x3f8e0a4b,0x00000000}},	//   _estl, итос, _bifu_, --,
   {{0xb87b0065,0x80d70096,0x6ab70090,0x798f063d}},	//   _abík, _यावे, _nexf, _licw,
   {{0xd2512204,0x6285025b,0x438400e3,0x61353916}},	//   _بنا_, ýhod, _اللق, _cálc,
   {{0xeb9a136c,0xd0110080,0x7afeb4f6,0x7ff52268}},	//   ким_, _ولا_, _sapt, _نستا,
   {{0xed570f80,0x3ce90063,0x2e3b0065,0x98a0050d}},	//   роя_, _dbav_, _báfé_, lkić_,
   {{0xa3e804dd,0x2d950f32,0x2d52042d,0x3f8e0027}},	//   _बहस_, _крис, kšeg_, _gifu_,
   {{0xc33200a1,0x98a07b57,0x69261d6f,0x798f8b39}},	//   חום_, nkić_, амва, _bicw,
   {{0x2900b4f7,0x7afeb4f8,0x18a60ed7,0x8c6700ac}},	//   udia_, _wapt, раам, ụmọd,
   {{0x7afe224a,0x6ab70090,0x969657c0,0x2cad0072}},	// [d900] _tapt, _fexf, ареш, ñede_,
   {{0x27e0b4f9,0xdb06003e,0x4a46007b,0xbcfb0103}},	//   rtin_, rskó, _внов, llép,
   {{0x48e620f9,0xdb2412eb,0x98a003d6,0xdb06003e}},	//   _конв, _نوکی, jkić_, sskó,
   {{0xb4c2000d,0x84e60c10,0x27e0b4fa,0x6abc487c}},	//   ूले_, родж, ptin_, larf,
   {{0x6386007e,0x33f61e11,0x00000000,0x00000000}},	//   агда, рчес, --, --,
   {{0x69ce0ab2,0x31c60aad,0x6abc0088,0x798f3759}},	//   orbe, асив, narf, _zicw,
   {{0xd24f114c,0x399c0065,0x798f0079,0x00000000}},	//   ونه_, _jís_, _yicw, --,
   {{0x3f8e00dc,0xbcfb00b6,0x32cc0065,0x6abc17d4}},	//   _sifu_, jlép, _bóyà_, harf,
   {{0xd0e205cd,0x6abcb4fb,0x2fcd0113,0x03a30ac6}},	//   क्षण_, karf, greg_, _мито,
   {{0x80a60e28,0x25750222,0x3ce90036,0x6abc003e}},	//   _ट्रे, håll_, _sbav_, jarf,
   {{0x6abcb4fc,0x2fcdb4fd,0xa2db0096,0x5fc20096}},	//   darf, areg_, _नात्, _शिकल,
   {{0x2fcd14f3,0x613502c6,0x00000000,0x00000000}},	//   breg_, _válc, --, --,
   {{0x6abc02ad,0x69ce8082,0x69c8b4fe,0x3f8e0090}},	//   farf, erbe, áden, _tifu_,
   {{0x6d5d00fd,0x98a90433,0x6abc50f2,0x06cc0033}},	//   érab, rkač_, garf, র্তি,
   {{0x613542bc,0xff7b006e,0xc17800c6,0x23ad0139}},	//   _hála, _שטומ, _upės_, _kójò_,
   {{0x2d520039,0xe6af02d5,0x248000d4,0x636d0076}},	//   všeg_, टर्ज, žimy_, lúnt,
   {{0x69ce50db,0xdb040161,0x58870ab3,0x78adb4ff}},	// [d910] arbe, _aviõ, рыва, rbav,
   {{0x6135b500,0x399c0076,0x798f0027,0x23ad0139}},	//   _mála, _fís_, _wicw, _lójò_,
   {{0xd006037f,0x04950037,0xbcfb0113,0xe80500b7}},	//   _کل_, ملاح, joék, रिहा_,
   {{0x69d5406e,0x98a082aa,0x7af5b501,0x00000000}},	//   muze, vkić_, lezt, --,
   {{0xa3b204a9,0xfc3f030b,0x69d5b502,0x61350730}},	//   झील_, nzí_, luze, _nála,
   {{0x257c0146,0x2d52042d,0xf36741c0,0x7af51415}},	//   víle_, pšeg_, штен, nezt,
   {{0x27f504a8,0x2367801a,0x00000000,0x00000000}},	//   şanı_, ronj_, --, --,
   {{0x2fcdb503,0x98a00995,0x06cc0033,0x00000000}},	//   treg_, rkić_, র্দি, --,
   {{0xdee50cba,0x7af50103,0xc2eb0037,0x98a0015c}},	//   бопи, kezt, _لعام_, skić_,
   {{0x636d04d8,0x2fcd8325,0x69d54944,0xef1900ae}},	//   gúnt, rreg_, kuze, умо_,
   {{0x37a80081,0x6ed80592,0xd1b80246,0x4d6610bb}},	//   _ওয়ার, _मारु, _نانا_, йков,
   {{0x69d500e9,0x3ce3007d,0x6135b504,0x40950037}},	//   duze, ट्ले_, _fála, _الإر,
   {{0x6abc0088,0x30850037,0x00000000,0x00000000}},	//   tarf, _الشف, --, --,
   {{0xfaa30cb0,0xeb972cc3,0x7af51fd1,0x69d56cbe}},	//   заро, сир_, gezt, fuze,
   {{0xbb43686c,0x69d50f4c,0x69ce24e7,0x3b010090}},	//   черк, guze, urbe, _dahq_,
   {{0x3a250222,0x399c01cd,0xa3e80b3f,0x6abc7604}},	//   älpa_, _vís_, _बहल_, sarf,
   {{0x46ea0231,0x2d800129,0x3d15294e,0xc6960037}},	// [d920] лдан_, _ihie_, धारे_, مشاع,
   {{0x69d5b505,0x2d9201c2,0xf7720037,0xdb1d020d}},	//   buze, _hiye_, ساء_, yssé,
   {{0xd0f90336,0xf3ec0081,0xceb20089,0x30f90be5}},	//   ्याण_, ওয়ার_, פיא_, ्याः_,
   {{0xd91000bf,0x93aa0037,0x2d928d22,0xc486015f}},	//   _تیر_, هاتف_, _jiye_, блек,
   {{0x6ed817ff,0x68f6b506,0xe5050037,0xa3b200aa}},	//   _मालु, meyd, تبلي, झीं_,
   {{0x29020a75,0xf6d502ec,0xceba03e3,0x68f62d53}},	//   _haka_, _міся, _roƙo_, leyd,
   {{0x613501ab,0xdb1d00fd,0x64a66ab4,0x1a9b006e}},	//   _sála, ussé, _габа, ניקע,
   {{0xf993040a,0x68f62d53,0x2902b507,0x2d92340d}},	//   הרה_, neyd, _jaka_, _niye_,
   {{0x3d1c0454,0x2902b508,0x74540068,0x7af50103}},	//   याने_, _maka_, _بھائ, yezt,
   {{0x613507d9,0x2d920af0,0x11d6097a,0x68f6b509}},	//   _vála, _aiye_, _гідр, heyd,
   {{0x2d98057a,0x2d92b50a,0x61465e41,0x7af50103}},	//   êre_, _biye_, _лежа, vezt,
   {{0xd7fe00ef,0x29026ff7,0x2d800174,0x69d5b50b}},	//   _đăng_, _naka_, _chie_, vuze,
   {{0x2d920b88,0x716500e3,0x7af53d7d,0x68f63d8e}},	//   _diye_, _بالك, tezt, deyd,
   {{0x29020065,0x637f0161,0x613c781e,0x2d920139}},	//   _aaka_, cênd, _bélg, _eiye_,
   {{0x2902b50c,0xa2db0f8f,0x2d921114,0x61350155}},	//   _baka_, _नास्, _fiye_, _máln,
   {{0x69d5b50d,0x3ebe1f28,0x57b5261f,0x2d80009c}},	//   ruze, latt_, жбат, _ghie_,
   {{0x76b9007e,0x2902b50e,0x2907030b,0x6d4f1c8d}},	// [d930] илар_, _daka_, ěna_, mica,
   {{0xec380054,0x21260449,0x1cf100ac,0x06cc0033}},	//   _לאחר_, _looh_, _ọjọọ_, র্সি,
   {{0xa3db009d,0x29020415,0x7c2f5359,0xab5b0364}},	//   ढून_, _faka_, lycr, srüs,
   {{0x3d1c00c3,0x29020154,0xab5b0233,0x21267c52}},	//   याये_, _gaka_, prüs, _nooh_,
   {{0x320c0167,0x3ebe7704,0x5ed00033,0x3ce100b7}},	//   _ardy_, katt_, ত্যে, _काने_,
   {{0x2902b50f,0x85bb0adb,0x55bb001c,0x6d4f1dbd}},	//   _zaka_, _مارس_, _مطرح_, hica,
   {{0x7aea01bf,0x613500b6,0xe573212c,0x3d1c00b7}},	//   _öfte, _dáln, _فطر_, यामे_,
   {{0x81ea0081,0x672707ee,0x80af0033,0xdb0d058f}},	//   মিং_, _hojj, _টাঙ্, _avaü,
   {{0x200b0074,0x320c00f9,0x672706b0,0x3f9900fe}},	//   íci_, _erdy_, _kojj, êsu_,
   {{0x63a90396,0x656bb510,0x671c05cd,0x613f0065}},	//   _iten, logh, नायक_, _bàlù,
   {{0x2d925a41,0x637f016d,0x83fd0103,0x442fb511}},	//   _piye_, gêne, _győr, lyg_,
   {{0x656b7fce,0x6d4fb512,0xdb060149,0x69c80072}},	//   nogh, gica, nskö, ádem,
   {{0xeb9a007e,0x3ebe904c,0xae17110a,0x69c500f3}},	//   риг_, batt_, _گذشت, _avhe,
   {{0x2902172a,0x3b0a0084,0x63a90051,0x3ebe0036}},	//   _saka_, шего_, _mten, catt_,
   {{0x29029788,0x68f60084,0xdb060212,0x6f0300ae}},	//   _paka_, teyd, kskö, _ianc,
   {{0x60dbb513,0x6f0364e8,0x63a96107,0x6a800065}},	//   ngum, _hanc, _oten, _aáfí,
   {{0x6f03b514,0x29023156,0x63a94524,0x67270090}},	// [d940] _kanc, _vaka_, _nten, _bojj,
   {{0x2902b515,0x7d04b516,0x68f6a4e0,0x00000000}},	//   _waka_, _hais, seyd, --,
   {{0x2902b517,0x6a800065,0x7d16b518,0x60db0063}},	//   _taka_, _dáfí, _knys, kgum,
   {{0x186a2917,0x7d040634,0x2c586336,0x613c0139}},	//   _вами_, _jais, ọdu_, _kéle,
   {{0x7d04b519,0x06cc0081,0x25ad0146,0x69c100b6}},	//   _mais, র্ষি, _čele_, šlet,
   {{0x6d4fb51a,0x60db00d9,0x63a90167,0xf1a62312}},	//   zica, egum, _dten, орин,
   {{0x63a9b51b,0x613c111c,0x6d4f1937,0x656b0134}},	//   _eten, _léle, yica, bogh,
   {{0x7d04b51c,0x442f0150,0x26c70220,0x60dbb51d}},	//   _nais, byg_, ónov_, ggum,
   {{0x6f0300dc,0x3ebe004d,0x00000000,0x00000000}},	//   _banc, tatt_, --, --,
   {{0x6d4fb51e,0x6f033d46,0x61350072,0x75220b14}},	//   wica, _canc, _fálo, ljoz,
   {{0x6d4f1c8d,0x7d04b51f,0x3ebeb520,0x613c0018}},	//   tica, _bais, ratt_, _péld,
   {{0x7d04a813,0x3ebeb521,0x25a50072,0x6f0301f7}},	//   _cais, satt_, _élle_, _eanc,
   {{0x6d4fb522,0x6135b523,0x60c0b524,0x644229f2}},	//   rica, _zálo, mamm, nzoi,
   {{0x613cb525,0x78a40231,0x637f0131,0xb87b0503}},	//   _déle, eciv, mênc, _mbít,
   {{0x7d04ac40,0xd90f00bf,0x656b0129,0x637f001f}},	//   _fais, نید_, yogh, lênc,
   {{0x7d04b526,0x6f030044,0x9f5d02f1,0x613c0103}},	//   _gais, _zanc, _aswè_, _féle,
   {{0x6d4db527,0x6f03006d,0x637f0161,0x00000000}},	// [d950] _imaa, _yanc, nênc, --,
   {{0x7d0408a9,0xb87b0072,0x6f03b528,0x00000000}},	//   _zais, _acíc, _xanc, --,
   {{0x2d9cb529,0x442f14bd,0x7d040a4b,0x7d1600f0}},	//   _juve_, wyg_, _yais, _ynys,
   {{0x2fc603ce,0x442f070a,0x6135037a,0x78a40036}},	//   _ovog_, tyg_, _cáll, cciv,
   {{0x18350130,0x656bb52a,0x60c00188,0x61350042}},	//   _זאָל_, rogh, damm, _dáll,
   {{0x637f0396,0x2d9cb52b,0xd6d84daa,0x257c0220}},	//   dênc, _ouve_, _мтс_, ríla_,
   {{0x6d4d1f4f,0x6f037c6b,0xe5c424dc,0x81f70103}},	//   _omaa, _ranc, _осто, تہار_,
   {{0x26c1b52c,0x61350018,0xda5c00ca,0x63a96fdd}},	//   laho_, _válo, יכול, _tten,
   {{0x6f0334ac,0x63a9b52d,0xaadc0d7e,0x637f001f}},	//   _panc, _uten, _बालक, gênc,
   {{0x7d04b52e,0x6d4db52f,0x6f030188,0xfe4508d8}},	//   _sais, _amaa, _qanc, зноо,
   {{0x613c025a,0xe8020455,0x1d0a42d1,0xab5b0018}},	//   _séle, _रैना_, бени_, tsün,
   {{0xed5a00d5,0x6f03b530,0x78bd6dce,0xc10400e3}},	//   сом_, _wanc, _nesv, _يولي,
   {{0x6f03b531,0x7d04b532,0x26c15c19,0x637f016d}},	//   _tanc, _vais, kaho_, cênc,
   {{0x613c0068,0x200f013f,0xdb060220,0x6d4d363c}},	//   _véle, _irgi_, jskô, _emaa,
   {{0x7d04b533,0x78bd085d,0xaca40174,0x2d9c0172}},	//   _tais, _besv, _ahụw, _guve_,
   {{0x7d040a02,0x3f9d1a3a,0x613c3880,0x316d01ff}},	//   _uais, _kuwu_, _téle, noez_,
   {{0x78bdb534,0xaa8a0260,0xf8bf002b,0xeaaf0018}},	// [d960] _desv, _گندم_, _toén_, ئٹہ_,
   {{0xb87b0065,0x78a40451,0x869aaa28,0x7bc65954}},	//   _abís, sciv, стат_, msku,
   {{0x1a9b0130,0x7bc61d46,0x4a9b00c1,0x60c088ab}},	//   _לייע, lsku, _לייג, yamm,
   {{0x63760012,0xc4860a8e,0xdb0d0088,0xaadc030b}},	//   mâni, плек, _hvað, _बाँक,
   {{0x26c11a45,0x61350068,0x7bc6b535,0x60c000c2}},	//   baho_, _váll, nsku, vamm,
   {{0x637f0161,0xfc3f0610,0xf4870260,0x61350072}},	//   vênc, ncía_, سانی, _dálm,
   {{0x2fc603ce,0x60c0b536,0xa50a013d,0x200f0a00}},	//   _svog_, tamm, _лева_, _argi_,
   {{0xd13000e3,0x637f001f,0x7bc65575,0xb0c6099d}},	//   ئمة_, tênc, ksku, रृंग,
   {{0x60c01d46,0x2d9c15a5,0xa4f1020e,0x394003e3}},	//   ramm, _suve_, lışı_, ihis_,
   {{0x60c0b537,0x637f00c9,0x6d4d03ee,0x75290051}},	//   samm, rênc, _smaa, _zoez,
   {{0x637f001f,0x2cad46b4,0x6d4d0124,0x7bc60220}},	//   sênc, ñedo_, _pmaa, esku,
   {{0xc27b00f5,0x2fc604a3,0x26c1392d,0x667b00ca}},	//   _פראי, _tvog_, zaho_, מטיק,
   {{0x7bc60d2d,0xdfcf0037,0x78bd07ee,0x3940b538}},	//   gsku, _مين_, _resv, dhis_,
   {{0x2d9cb539,0x6ffb00a1,0x78bd2d5a,0xab5b0103}},	//   _tuve_, _להדפ, _sesv, csül,
   {{0x6376001f,0x81ea0081,0x26c10193,0xde5700d6}},	//   gâni, মিক_, vaho_, _наші_,
   {{0x6d4db53a,0x3940152f,0x26c105bd,0xa3cd02d5}},	//   _umaa, ghis_, waho_, _शटल_,
   {{0xb9055e07,0xb87b0139,0x26c12cd0,0x2e420139}},	// [d970] _ना_, _abír, taho_, _féfé_,
   {{0xc6a41c1b,0x629a0124,0x6abe0364,0x6fcf0096}},	//   ерци, _ngto, _gepf, _दिसू,
   {{0x7529b53b,0x26c1092f,0x6d5db53c,0x6376001f}},	//   _poez, raho_, onsa, câni,
   {{0x6d5d0049,0x394017dd,0xdced03d6,0x61350155}},	//   nnsa, chis_, _okač, _pálm,
   {{0xdfc60c5e,0x2919002d,0x2d5202dd,0x63a20201}},	//   _جي_, _insa_, kšen_, gqon,
   {{0x27e9768b,0x69c7b53d,0x68edb53e,0xe3b00452}},	//   mtan_, osje, lfad, ارن_,
   {{0xd0150490,0x69c700d6,0x75290126,0xe805000c}},	//   तम्भ_, nsje, _toez, रिका_,
   {{0x56941cfb,0x7bc6b53f,0x29090010,0x68ed0076}},	//   _част, ysku, ndaa_, nfad,
   {{0x69d502e2,0x60061119,0x3d1c00c3,0xdb1db540}},	//   hrze, дным_, यासे_, lusõ,
   {{0x27e93ad9,0x333903ed,0x02a73429,0x69c76abe}},	//   itan_, _بزرگ_, _храм, ksje,
   {{0x69d50034,0x291900f9,0x27e9b541,0x22590076}},	//   jrze, _onsa_, htan_, _بلاد_,
   {{0x62810106,0x27e9b542,0x69c7b543,0x69d50034}},	//   _izlo, ktan_, dsje, drze,
   {{0x68ed00e3,0x27e92acb,0x29090188,0x3d1e0378}},	//   dfad, jtan_, ddaa_, _बचीं_,
   {{0x29198a62,0x63760161,0x9f8400d6,0xdce400cc}},	//   _ansa_, tâni, _згід, _okić,
   {{0x3940b544,0x27e902a7,0xfc3f2567,0x68edb545}},	//   this_, etan_, rcía_, ffad,
   {{0xceba03e3,0x27e9b546,0x291901ec,0x63760131}},	//   _roƙi_, ftan_, _cnsa_, râni,
   {{0x27e902c9,0xb8f6000d,0x63bb0129,0xb87b00b6}},	// [d980] gtan_, _सय_, _nwun, _sbír,
   {{0x3940022e,0x613c0257,0x3d1c009d,0xa4f1008b}},	//   shis_, _méla, यावे_, tışı_,
   {{0x27e906ee,0xd946545a,0x7afcb547,0x63bbb548}},	//   atan_, _жени, mert, _awun,
   {{0x69dcb549,0x7afcb54a,0x27e9b54b,0x6135b54c}},	//   mure, lert, btan_, _dálk,
   {{0x27e972de,0x0edd009d,0x59830426,0x938a075f}},	//   ctan_, _मांड, _шлюб, оска_,
   {{0x7afcb54d,0xbfa500de,0x613501cd,0x00000000}},	//   nert, _việ, _fálk, --,
   {{0x63bbb54e,0x6d5db54f,0x7afcb550,0x3cf200d8}},	//   _ewun, ynsa, iert, _obyv_,
   {{0xab5b00a7,0xbfa500fe,0x6fbf0eeb,0x00000000}},	//   vsüm, _tiệ, लीभू, --,
   {{0xbcfb04ea,0x6d5db551,0x69dc3b6b,0xe2ca0aec}},	//   nnée, éram, hure, _млад_,
   {{0x613c0257,0x3ce10006,0xb38300ae,0xdce601d3}},	//   _déla, _काहे_, _алул, vokā,
   {{0x68ed01e8,0x27e90634,0x2ca9042c,0x63a07a86}},	//   yfad, ztan_, _pfad_, _humn,
   {{0x613c0102,0x63a0413e,0x27e90907,0x69dc019e}},	//   _féla, _kumn, ytan_, dure,
   {{0x7afcb552,0x2d521a98,0x61ea13c5,0x613c014b}},	//   fert, pšen_, ltfl, _géla,
   {{0x69d50067,0x7afcb553,0x69c72b31,0xc4c40068}},	//   trze, gert, tsje, _ھے_,
   {{0x69dcb554,0xda783d7c,0x68edb555,0x63a0b556}},	//   gure, дят_, tfad, _lumn,
   {{0x69c7637f,0x6376020a,0x78b60f5a,0x00000000}},	//   rsje, mânu, gbyv, --,
   {{0x68edb557,0x27e9022b,0xbcfb00fd,0x69c7b558}},	// [d990] rfad, utan_, gnée, ssje,
   {{0x27e9b559,0x69d50067,0x9f9a02fd,0x7bdd3d45}},	//   rtan_, prze, mään_, musu,
   {{0x7bddb55a,0x7ae54aad,0x69dcb55b,0x9f9a007b}},	//   lusu, _icht, cure, lään_,
   {{0x27e9b55c,0x29191098,0x613500b6,0x2909008c}},	//   ptan_, _unsa_, _válk, qdaa_,
   {{0x7bddb55d,0x9f9a0084,0x27ff008f,0x62810103}},	//   nusu, nään_, _èun_, _szlo,
   {{0x63a00012,0xc2c50037,0x798d01c2,0x613c01dc}},	//   _dumn, ريبي, lmaw, _réla,
   {{0xe1f10de1,0xa4d502ec,0xe2960396,0x7bdd67c2}},	//   است_, _пові, наш_, husu,
   {{0x7afc1415,0x9f9a02fd,0x7bddb55e,0x645a0224}},	//   zert, kään_, kusu, áciá,
   {{0x7ae5b55f,0x9f9a00c2,0x63bb23d1,0x00000000}},	//   _ocht, jään_, _uwun, --,
   {{0x7bddb560,0x61350088,0x200db561,0x798d0479}},	//   dusu, _máli, rvei_, hmaw,
   {{0x7afc3199,0x06cc00c7,0x06d50081,0x798d0167}},	//   vert, র্কি, স্থি, kmaw,
   {{0x7ae5b191,0x7afc4b17,0xc0e900cd,0x69dcb562}},	//   _acht, wert, _رفتن_, vure,
   {{0x7afcb563,0x3ce109c3,0x7bddb564,0x69dc06c0}},	//   tert, _कारे_, gusu, wure,
   {{0x69dcb565,0x06d50081,0x7afc1597,0xdbd200bc}},	//   ture, স্তি, uert, müüj,
   {{0x7afc918b,0x6376661b,0x2cab0076,0x00000000}},	//   rert, mânt, éidí_, --,
   {{0x7ae5ac50,0x7bddb566,0x69dcb567,0x7afc0133}},	//   _echt, busu, rure, sert,
   {{0x7afc063f,0x69dc04e4,0x613522a4,0xfaa60219}},	// [d9a0] pert, sure, _cáli, _папо,
   {{0xe2050028,0x386603e5,0xbcfb0257,0x98c501d3}},	//   _đóng_, ħor_, rnée, ētās_,
   {{0x63a003ce,0x1f360341,0x2d5202c6,0x00000000}},	//   _sumn, ערער_, yšel_, --,
   {{0x80be05d4,0x63a000ae,0xeaa00065,0x53e65d76}},	//   _एजें, _pumn, _fiṣu_, ецка,
   {{0x3ce1009f,0x613515b1,0x2d52033b,0x00000000}},	//   कलते_, _gáli, jšem_, --,
   {{0x4908000d,0xae1f397e,0x61ea0653,0x98a9007f}},	//   ाएको_, यमान_, ttfl, tkać_,
   {{0x3ce10034,0x61350146,0xf77700ca,0xe7e100c3}},	//   _काले_, _záli, _נעלי_, गूठा_,
   {{0x2d5202c6,0xab5b00bc,0x9f9a007b,0x7bdd00ad}},	//   ušel_, tsük, yään_, yusu,
   {{0xe8133aee,0x98a9007f,0x613c01f9,0x00000000}},	//   ठिया_, skać_, _féln, --,
   {{0x9f9a00c2,0x798d0034,0x7e463ac9,0x6e9400ae}},	//   vään_, zmaw, ехме, кипу,
   {{0x2bd3099d,0xb1e50037,0x00000000,0x00000000}},	//   _तिहा, _لأنه, --, --,
   {{0x9f9a0d64,0x3ce1009d,0x8fa60613,0x7ae5014b}},	//   tään_, _काळे_, _заде, _scht,
   {{0x3c46020d,0x00000000,0x00000000,0x00000000}},	//   _rêvé_, --, --, --,
   {{0x7bddb568,0xf8b80019,0x60c223ea,0x613c0113}},	//   rusu, _đĩa_, _heom, _kélo,
   {{0x2bd30006,0x0a6805e1,0x7bdd1ca0,0x798d00ec}},	//   _तिवा, ерти_, susu, tmaw,
   {{0x9f9a0084,0x7bddb569,0x99980a11,0x613c2c69}},	//   sään_, pusu, екст_, _mélo,
   {{0x671c1362,0xa3d20469,0x9f9a007b,0x67d40dfb}},	// [d9b0] नांक_, _विष_, pään_, лоту,
   {{0x6135077f,0x4de4009f,0x65c70018,0xade462c3}},	//   _váli, _कमाई_, _néhá, _कमान_,
   {{0x78a20094,0x2d520220,0xb60601d3,0xc3090033}},	//   žova, dšej_, jušā, লামি_,
   {{0x60c21770,0x61350653,0xb4cb0096,0xa4d5004d}},	//   _neom, _hálv, लणे_, тоді,
   {{0x672e02a1,0x290b044c,0x00000000,0x00000000}},	//   _fobj, _iaca_, --, --,
   {{0x2d520106,0x613c0113,0x69da034f,0x6ad30033}},	//   všem_, _bélo, áteg, দ্রো,
   {{0x290b172a,0x637600d3,0x7a3c00c2,0x6135003e}},	//   _kaca_, vânt, mätö, _málv,
   {{0x290b08a9,0x26c30027,0x613c0b68,0x672e0117}},	//   _jaca_, _hejo_, _délo, _zobj,
   {{0x33f418a9,0x290ba39f,0x63b40146,0x60c201b9}},	//   _مسلس, _maca_, čený, _deom,
   {{0xee390cc5,0xddd8013f,0xa2db31f4,0x2d52033b}},	//   дно_, _gyvū, _नाट्, ršem_,
   {{0x0d864e08,0x7bcd00c2,0x26c3b56a,0x1e82007b}},	//   клон, _avau, _mejo_, ильм,
   {{0x705209b4,0x26c37d79,0xd14b0037,0xc0cb007b}},	//   انیا, _lejo_, _عشان_, _хуже_,
   {{0x06cc0081,0x00000000,0x00000000,0x00000000}},	//   র্টি, --, --, --,
   {{0xd5d1007d,0xeb970465,0x26c3b56b,0xbea2b56c}},	//   _हिंज, кия_, _nejo_, _кашк,
   {{0x290b06ee,0xeb972887,0x44200023,0x2d520117}},	//   _baca_, тир_, ̣i_, nšek_,
   {{0x60c203be,0x00000000,0x00000000,0x00000000}},	//   _xeom, --, --, --,
   {{0x290b0a29,0x672e0292,0x26c3b56d,0x661503e3}},	// [d9c0] _daca_, _pobj, _bejo_, _arzk,
   {{0x5fd4009d,0x6fd40034,0x249fb56e,0x6135034f}},	//   _दिसल, _दिसं, _agum_, _gálv,
   {{0xe7fe0b89,0x290bb56f,0x26c3b570,0xa3e4009d}},	//   _उनका_, _faca_, _dejo_, पून_,
   {{0x290b0027,0x61350032,0x00000000,0x00000000}},	//   _gaca_, _kálu, --, --,
   {{0x69da00cc,0x5ed90081,0x290019c3,0x6d5d00fd}},	//   šted, ব্যে, meia_, érai,
   {{0x60c2b571,0x27e02b29,0x6135003e,0x68e4b572}},	//   _seom, muin_, _málu, lgid,
   {{0x44200012,0x212f009c,0x27e04a00,0x5fd40006}},	//   ţi_, _bogh_, luin_, _दिहल,
   {{0x29002c68,0x613c00fd,0xfbd3049d,0x2ca003a9}},	//   neia_, _vélo, _तिलम, _ngid_,
   {{0x60c20c27,0x53a621fd,0xc95309c1,0x27e0b573}},	//   _veom, _разб, ימה_, nuin_,
   {{0x2900b574,0x6376020a,0x2b580350,0x00000000}},	//   heia_, râns, jirc_, --,
   {{0x27e0b575,0xceb816d7,0x212f0ac1,0x60c2b576}},	//   huin_, rbę_, _fogh_, _teom,
   {{0x27e0b577,0x613522a4,0xc8e10179,0x09b10033}},	//   kuin_, _sálv, _फाइट, _ছিলা,
   {{0x4426a010,0x29009a94,0x27e00167,0x290bb578}},	//   nxo_, deia_, juin_, _raca_,
   {{0x44267ce4,0x6d460808,0x290b222b,0x27e0b579}},	//   ixo_, ahka, _saca_, duin_,
   {{0x4f9b00a1,0x6135a376,0x2ba50251,0x78a20220}},	//   _קבוצ, _válv, _गंवा, ľovn,
   {{0x68e46e7b,0x6d46b57a,0x29000131,0x6d870018}},	//   ggid, chka, geia_, _جمعہ_,
   {{0x27e00472,0x3f9c4ee2,0x656200b6,0x7d0d00f9}},	// [d9d0] guin_, _kivu_, dnoh, _iaas,
   {{0x7d0d67ac,0xa6cc0081,0x3f9c024a,0x290b00d1}},	//   _haas, র্ঘট, _jivu_, _waca_,
   {{0x7d0d6765,0x442611ca,0x26c38e31,0x290bb57b}},	//   _kaas, exo_, _vejo_, _taca_,
   {{0x27e000f9,0x2d52033b,0x6562007e,0xb33c0090}},	//   buin_, všek_, gnoh, _jiħf,
   {{0x7d0d0c15,0x26c3b57c,0xc6a71942,0x613542b3}},	//   _maas, _tejo_, _арби, _mált,
   {{0x7d0db57d,0x799dadca,0x78adb57e,0x00000000}},	//   _laas, _hisw, lcav, --,
   {{0x799d0010,0x51f50037,0x2d5200d2,0x00000000}},	//   _kisw, استر, ušek_, --,
   {{0x7d0d9712,0x3ce901fa,0x78adb57f,0x6009b580}},	//   _naas, _ncav_, ncav, еним_,
   {{0x799db581,0x34940284,0x00000000,0x00000000}},	//   _misw, _ватр, --, --,
   {{0x257c0579,0x4816006e,0x5f450182,0x212f0113}},	//   víli_, אַטן_, اندل, _wogh_,
   {{0x7d0d1e0b,0x3f9c3b46,0x61350143,0xa3e402d5}},	//   _baas, _divu_, _bált, पंथ_,
   {{0x10152c66,0x6d462688,0x7d0d008a,0x27e007ac}},	//   _مبتد, uhka, _caas, yuin_,
   {{0x29002f0b,0x7d0d008c,0x60c9b582,0x68e4028e}},	//   veia_, _daas, maem, vgid,
   {{0x6d4600dd,0x257c1137,0x60c90b94,0xa03a006e}},	//   shka, ríli_, laem, _רעספ,
   {{0x6135b504,0x7d0d194a,0x2900135c,0xed5a268e}},	//   _fált, _faas, teia_, _пок_,
   {{0x27e0b583,0x2bdc0251,0x7d0d0b47,0x3f9c015c}},	//   tuin_, _बिपा, _gaas, _zivu_,
   {{0x6d56023f,0x6d440010,0x2900b584,0x44260036}},	// [d9e0] _imya, _ilia, reia_, xxo_,
   {{0x613c0103,0x60c90113,0x27e04327,0x68e4b585}},	//   _célj, haem, ruin_, sgid,
   {{0x7d0db586,0x290013a9,0x6d44b587,0x799d010a}},	//   _yaas, peia_, _klia, _fisw,
   {{0x7d0d008a,0x61350088,0x44260b8f,0x78adb588}},	//   _xaas, _máls, txo_, ccav,
   {{0x69ce313e,0x27e0b589,0x4426128a,0x6562b58a}},	//   lsbe, quin_, uxo_, rnoh,
   {{0x4426b58b,0x6f010dd9,0x46a31be7,0xfbdc294e}},	//   rxo_, jelc, _гарв, _बिनम,
   {{0x6d4487c0,0x3f9cb58c,0x267900ae,0x799d05bd}},	//   _olia, _rivu_, _астэ_, _yisw,
   {{0x3d0e0d1b,0x69ceb58d,0x3f9c0084,0x4fd41e6d}},	//   ियों_, isbe, _sivu_, ажит,
   {{0x7d0d289c,0xddcfa8a3,0x3f9c906d,0x3d18088d}},	//   _raas, _češn, _pivu_, _बोधे_,
   {{0x6d44b58e,0x69ce01be,0xb11400ac,0x7d0d1d84}},	//   _alia, ksbe, _gụny, _saas,
   {{0x6d444450,0x7d0da896,0x3f820029,0x60c9010a}},	//   _blia, _paas, ēku_, baem,
   {{0x6d440a1b,0x628800d9,0x3f9c0239,0x7d0d0188}},	//   _clia, _izdo, _wivu_, _qaas,
   {{0x61350068,0x799d005c,0x7d0db58f,0x69ce1183}},	//   _vált, _risw, _vaas, esbe,
   {{0x799da24b,0x7d0db590,0x6d560283,0x16040d7a}},	//   _sisw, _waas, _emya, रबार_,
   {{0x7d0d6010,0x613c0068,0x69ceb591,0x6d442eba}},	//   _taas, _nélk, gsbe, _flia,
   {{0x6d44b592,0x62880146,0xeab00018,0x78ad00cc}},	//   _glia, _mzdo, قعہ_, ucav,
   {{0xd6db2046,0x2bdc1101,0x78adb593,0x69dc9fc4}},	// [d9f0] ете_, _बिया, rcav, arre,
   {{0x78adb594,0x628812fb,0x6d440031,0xb33c02a1}},	//   scav, _ozdo, _zlia, _jiħd,
   {{0x78ad2a3e,0xe784007b,0x6d44007b,0x799d0078}},	//   pcav, суто, _ylia, _tisw,
   {{0xf8b11e49,0x613c030b,0x637f0131,0x2bdc50d7}},	//   _ذکر_, _délk, mêni, _बिमा,
   {{0xd00616c4,0x7bcf2546,0x39490a02,0x02c54c81}},	//   _بل_, nscu, mhas_, айло,
   {{0x39490396,0x973204c6,0x2fcd0580,0x257c02c6}},	//   lhas_, _وکلا, vseg_, dílu_,
   {{0xe12510b8,0x7bdd042c,0x20020233,0x00000000}},	//   имки, hrsu, çkin_, --,
   {{0x3949525c,0xb4f90130,0x6f010364,0x2fcd4e1d}},	//   nhas_, _שפּי, welc, tseg_,
   {{0x657b0601,0xbcfb0103,0xb1140134,0xab5b3ad7}},	//   _ikuh, tnén, _tụny, nsüs,
   {{0xff51003f,0x6d44b595,0x7777003d,0x6135003e}},	//   تخب_, _slia, noxx, _páls,
   {{0x6d44b596,0x32670e08,0x4d660e45,0x23ab01c5}},	//   _plia, _став, иков, _høj_,
   {{0xed5a248d,0x2fcd00e7,0xa2af09c4,0x61350103}},	//   том_, pseg_, ुरक्, _váls,
   {{0x65692cc8,0x3949b597,0x657b00f9,0x212d0880}},	//   _mjeh, dhas_, _mkuh, mjeh_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e3008e,0x7e7900c1,0x637f0161,0x69dc01e9}},	//   nunl, _באַז, gêni, urre,
   {{0x6d5d025a,0x98a30e38,0x69ce44cb,0x39490a6c}},	//   érat, жите, rsbe, ghas_,
   {{0x69cea362,0xf99f09f5,0xa7a70284,0x00000000}},	// [da00] ssbe, _diè_, икта_, --,
   {{0x61e33007,0x69ce1cab,0xe6c50037,0x657baea9}},	//   kunl, psbe, متمي, _akuh,
   {{0x39490091,0xaadb00a1,0x1dab007f,0x00000000}},	//   bhas_, _בחיר, _घूमत, --,
   {{0x3949b598,0x00000000,0x00000000,0x00000000}},	//   chas_, --, --, --,
   {{0xb6a600d6,0xe3af0dce,0x7c220072,0x212d0dd9}},	//   _вигл, ورو_, _áord, djeh_,
   {{0x68f60150,0x657b019f,0xb87b030a,0xf74603c8}},	//   lfyd, _ekuh, _acíw, _тего,
   {{0x613c2e00,0xf1a3065c,0x6ce6009f,0xf8aa0442}},	//   _héli, орын, _कांग_, _कलाय,
   {{0x213f048e,0xb87b0139,0x3940b599,0x29120172}},	//   gkuh_, _abíy, nkis_, ndya_,
   {{0xa2e6455f,0x27f20150,0x2937006e,0xdb040503}},	//   _возд, ntyn_, שאפן_, _dtiú,
   {{0x613cb59a,0x00000000,0x00000000,0x00000000}},	//   _méli, --, --, --,
   {{0x628801d3,0x3940b59b,0x2d680995,0x00000000}},	//   _uzdo, kkis_, rđen_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcb2209d0,0x613c0072,0x2d8501d3,0xc3090033}},	//   मांड_, _néli, ēle_, লারি_,
   {{0x637f0131,0xbcfb0094,0x0eba04d9,0xdb1d0b81}},	//   têni, mném, _руды_, nssø,
   {{0x39492ae3,0x98c70cf5,0xf99f34a5,0x7bcf7a2a}},	//   thas_, исал, _piè_, sscu,
   {{0x3ce110e9,0x3940b59c,0x7c2201d3,0x613c72ec}},	//   _काटे_, gkis_, _šore, _béli,
   {{0x6d5db59d,0xf0930130,0x613cb59e,0x61e3071d}},	// [da10] misa, ַנע_, _céli, zunl,
   {{0x6d5db59f,0x613c025a,0xf7701d28,0x657b0666}},	//   lisa, _déli, وال_, _skuh,
   {{0x3d1c02e8,0x656900e7,0x3940022e,0x2d52033b}},	//   याचे_, _pjeh, bkis_, ršev_,
   {{0x613c978d,0x3940b5a0,0x059600d1,0x26c7007f}},	//   _féli, ckis_, مانگ, źno_,
   {{0x98a90995,0x39590314,0x65690052,0xbcfb00d4}},	//   njač_, _imss_, _vjeh, jném,
   {{0xdb040080,0xfbb800a1,0xbcfb0146,0x61e3b5a1}},	//   _stiú, ספות_, dném, tunl,
   {{0x3ce802e8,0xdb0422ed,0x45d405e1,0x61e30270}},	//   _झाले_, _quié, _морс, uunl,
   {{0x61e301e8,0x6569067d,0x6b4b0018,0x23ab052f}},	//   runl, _ujeh, _függ, _tøj_,
   {{0x2019b5a2,0x6d5db5a3,0x673530a0,0x61e30555}},	//   ísi_, disa, _kozj, sunl,
   {{0x43850037,0xdb0401b9,0x98a90e94,0x917100fe}},	//   _الطق, _ftiù, djač_, _mở_,
   {{0x63a90010,0x212d0ea3,0x6d5d47c3,0x443d3918}},	//   _huen, pjeh_, fisa, lyw_,
   {{0x6d5d5fce,0x63a9068d,0x200b052f,0x6aa50090}},	//   gisa, _kuen, æcis_, _aghf,
   {{0x814c07a6,0x517400e3,0x417400e3,0x63a94479}},	//   _בעאַ, _بالأ, _بالس, _juen,
   {{0x7fb400d0,0x98a008a9,0x39590095,0x63a9b5a4}},	//   _بلوچ, ljić_, _amss_, _muen,
   {{0x6d5db5a5,0x3940b5a6,0xaa434876,0x63a9007b}},	//   bisa, tkis_, перл, _luen,
   {{0x6d5d3c46,0x6281b5a7,0x98a01386,0xccc608d8}},	//   cisa, _mylo, njić_, _убий,
   {{0x7d060084,0x3940b5a8,0x63a918c9,0x29120eac}},	// [da20] meks, rkis_, _nuen, rdya_,
   {{0xdb0e0084,0xa3ab09d0,0x3940b5a9,0xaa462312}},	//   äkär, _गढ़_, skis_, _геол,
   {{0x27f2b5aa,0xb8ee0081,0x2f5a006e,0xbcfb00d4}},	//   styn_, _রা_, נדענ, zném,
   {{0x63a98630,0x7d06b5ab,0xa8b900d3,0x5693004d}},	//   _buen, neks, _вырф_, чаєт,
   {{0x63a90eb8,0xdb040049,0x6281039f,0x6ba10342}},	//   _cuen, _stiù, _aylo, _üzgü,
   {{0x63a902a7,0x27e0b5ac,0x6d5d6cd3,0x7d0613e1}},	//   _duen, mrin_, zisa, heks,
   {{0x6d5d0b32,0x26d89655,0x63a90131,0x63a1b5ad}},	//   yisa, _idro_, _euen, _diln,
   {{0x3d18382d,0x63a93539,0x463b0130,0x7d06b5ae}},	//   _बोले_, _fuen, _געלע, jeks,
   {{0x27e00649,0xe8e00019,0x26cab5af,0x63a12fea}},	//   nrin_, _ngọt_, _kebo_, _filn,
   {{0x6d5db5b0,0x26ca0477,0x9df80396,0xbcfb0094}},	//   wisa, _jebo_, анот_, rném,
   {{0x6d5db5b1,0x877b0089,0xa3e41fbb,0x528600e3}},	//   tisa, ראיי, पूर_, _الاك,
   {{0x27e0b5b2,0x26ca0181,0x63a1002d,0x2fdf20f6}},	//   krin_, _lebo_, _ziln, brug_,
   {{0x4096054f,0x703a0241,0x69da0220,0x79841db4}},	//   _الشر, _حساس_, áten, dliw,
   {{0x26ca033a,0x6d5db5b3,0x27e0b5b4,0x6b810174}},	//   _nebo_, sisa, drin_, _ịgbo,
   {{0x6d5d70d5,0x69da02e6,0x6735282b,0x237e00e7}},	//   pisa, šten, _rozj, _mktj_,
   {{0x8e830080,0x7d0601e8,0x26d889a5,0xbcfb00fd}},	//   _عليه, ceks, _adro_, fiée,
   {{0x588700c2,0xe894007b,0x26ca00d7,0x47353d77}},	// [da30] сыва, зать, _bebo_, онас,
   {{0x6b4b042c,0x2b5a0072,0x26ca063d,0x79840361}},	//   _büge, _gmpc_, _cebo_, aliw,
   {{0x63a90a43,0x26cab5b5,0x27e0b5b6,0x6d680072}},	//   _suen, _debo_, arin_, _ásaí,
   {{0x63a17981,0x63a98630,0x27e0b5b7,0xe4cb00cd}},	//   _siln, _puen, brin_, ابان_,
   {{0x63a1b5b8,0x25ad00cc,0x63a90bfe,0xe3b300cd}},	//   _piln, _čelu_, _quen, سرش_,
   {{0x41b509fe,0x443d00f0,0x6b4b374f,0x26ca041c}},	//   осит, ryw_, _füge, _gebo_,
   {{0x63a108a1,0x26c102ef,0x63bc0117,0x7d06b5b9}},	//   _viln, mbho_, _črne, yeks,
   {{0x13a700cd,0x63a9a3a7,0x6281033d,0xdb16022b}},	//   _هنری_, _tuen, _vylo, _etyè,
   {{0xe81c0d0b,0xbcfb025b,0x7d065ab2,0x98a90181}},	//   निया_, mnéh, veks, kiaľ_,
   {{0xbcfb025b,0x289c00c1,0x248d007e,0x2fc605aa}},	//   lnéh, ניזא, _izem_, _dwog_,
   {{0x2bdc0f53,0xdced0220,0x27e060a7,0x79960034}},	//   _बिहा, _diaľ, zrin_, ymyw,
   {{0xbcfb025b,0x6d5d0257,0x2fdf08c5,0x78a20095}},	//   nnéh, érap, prug_, žovi,
   {{0x613c10d9,0x66e00065,0x60cb039f,0x00000000}},	//   _célu, _jákà, _iegm, --,
   {{0x7d06b5ba,0x613c0103,0x637f0131,0x00000000}},	//   seks, _délu, cênt, --,
   {{0xfaa3620c,0x7d06b5bb,0x26ca0ece,0x999e02c6}},	//   даро, peks, _rebo_, átů_,
   {{0x27e0990c,0x26cab5bc,0xbcfb1054,0x201d0034}},	//   trin_, _sebo_, jnéh, _krwi_,
   {{0xbcfb135f,0x60cb0018,0x7984b5bd,0x27e0601d}},	// [da40] dnéh, _megm, rliw, urin_,
   {{0x27e071bf,0x2b5a01af,0x25aa10a5,0xbcfb020d}},	//   rrin_, _umpc_, _publ_, riée,
   {{0x98a613dc,0xb87b0076,0x248d0052,0x3f850450}},	//   _мине, _scít, _azem_, illu_,
   {{0x66e00139,0x92a6007f,0x27e0947e,0xa3ce0285}},	//   _bákà, zyłą, prin_, _शबद_,
   {{0x26ca005c,0xe5a310a6,0x613c0103,0x87b9636a}},	//   _tebo_, фици, _mélt, _густ_,
   {{0x248d00e7,0x8c1b00a1,0xb33c0090,0xb87b00d8}},	//   _dzem_, יוני, _biħa, _vcít,
   {{0x2d8034fa,0xbcfb0244,0x201800e8,0x00000000}},	//   _okie_, bnéh, ārim_, --,
   {{0xbcfb0146,0x200f01ec,0x00000000,0x00000000}},	//   cnéh, _bsgi_, --, --,
   {{0xf99317f5,0x60cb0694,0xff060423,0x637f016d}},	//   ורה_, _degm, оянн, tênt,
   {{0x35af00a3,0x60cb041c,0x00000000,0x00000000}},	//   _जूड़, _eegm, --, --,
   {{0x69da030b,0x171b006e,0x613c0113,0x826600d1}},	//   átel, בויע, _sélu, _بهان,
   {{0x6eba09c4,0x8fa60d5e,0x2d920063,0x3f8503a8}},	//   _श्रु, _даде, _chye_, allu_,
   {{0x98a90181,0x69dab5be,0xa6d50081,0x4f650018}},	//   tiaľ_, štel, স্টট, _کانف,
   {{0xada50220,0x2bdc030b,0x23b0020d,0xbcfb455c}},	//   _skúš, _बिरा, _màj_, inéi,
   {{0x613c01f9,0x68fd009c,0x00000000,0x00000000}},	//   _félt, _pbsd, --, --,
   {{0x98a90031,0xed580859,0x00000000,0x00000000}},	//   siaľ_, _мој_, --, --,
   {{0xbcfb135f,0x2ca90188,0x27140033,0xfc3f0428}},	// [da50] vnéh, _igad_, ঠানো_, rcís_,
   {{0x65b302a1,0xf5390206,0x00000000,0x00000000}},	//   _aħha, _piťo_, --, --,
   {{0xbcfb025b,0xab9800e3,0x248d0103,0x6376020a}},	//   tnéh, _بخير_, _szem_, bânz,
   {{0xaae709e5,0x02b3030b,0xaba8001c,0x6d4f020b}},	//   _اسکو, ँड्न, _دهیم_, nhca,
   {{0x69d53c90,0xbcfb025b,0x5884004b,0x68ed4d41}},	//   lsze, rnéh, _жыра, mgad,
   {{0x27e95aa9,0xbcfb0146,0x21260270,0x248400dc}},	//   muan_, snéh, _anoh_, _dymm_,
   {{0x27e9b5bf,0x4429002d,0xe5732ba0,0x69d52c35}},	//   luan_, ţa_, _قطر_, nsze,
   {{0x2bdc000f,0x26000034,0x2d6800c4,0x00000000}},	//   _बिला, _रहती_, rđek_, --,
   {{0x27e9b5c0,0x68ed0f61,0x6d4fb5c1,0x6dba0090}},	//   nuan_, igad, dhca, _jċaf,
   {{0x2ca9b5c2,0x69d50018,0x60cb225b,0x63bbb5c3}},	//   _agad_, ksze, _wegm, _itun,
   {{0x27e90f8b,0x656bb5c4,0x69d50034,0x290900c2}},	//   huan_, ongh, jsze, keaa_,
   {{0x27e9b5c5,0x656bb5c6,0x69d53c90,0x3114097a}},	//   kuan_, nngh, dsze, _офіс,
   {{0x27e92058,0x31b10018,0x81ad0081,0x50670037}},	//   juan_, _ház_, _কবি_, _بطاق,
   {{0x27e99188,0xa0260088,0x2d9977a0,0x63bb0239}},	//   duan_, stöð, amse_, _mtun,
   {{0x6b50070a,0x69d50018,0x29d7003d,0x27140033}},	//   _lägg, gsze, għa_, ঠামো_,
   {{0x68edb5c7,0x63bbb5c8,0x2c750294,0xc212006e}},	//   ggad, _otun, ụda_, עהן_,
   {{0x200db5c9,0x945f03e3,0xb9043845,0x63bb5f48}},	// [da60] nwei_, _fāɗ, _नय_, _ntun,
   {{0x7d160694,0x6d460084,0x68edb5ca,0xf1070bd9}},	//   _hays, lkka, agad, वजुद_,
   {{0x7d1656c6,0x63bbb5cb,0x6d4600ce,0x00000000}},	//   _kays, _atun, okka, --,
   {{0x27e95604,0x6d4694ad,0x92e80081,0x6b5002c3}},	//   buan_, nkka, _বসে_, _bägg,
   {{0x293700c1,0x6d460084,0x9f4489d5,0xb87b0032}},	//   _זאכן_, ikka, sumé_, _adíf,
   {{0x656b0080,0x7d16008a,0x63bb0167,0xbcfb00da}},	//   angh, _lays, _dtun, rnéi,
   {{0xf10705d4,0xbcfb0080,0x6f0837e6,0x63bbb5cc}},	//   वजूद_, snéi, vedc, _etun,
   {{0xb6a30f94,0x63bb2fd8,0x9c8702c6,0x6d4e010a}},	//   _числ, _ftun, _jičí, _ŋaan,
   {{0x6f08037a,0x69d52214,0x00000000,0x00000000}},	//   tedc, zsze, --, --,
   {{0x69d5297d,0xa8570054,0x68ed2e6c,0x6562264d}},	//   ysze, פייה_, zgad, lioh,
   {{0x27e9293b,0x69da2a22,0x31b10103,0x00000000}},	//   zuan_, štej, _gáz_, --,
   {{0x27e9b5cd,0xd843025b,0x9c870094,0x14cc6bbd}},	//   yuan_, ničí_, _ničí, ारिण,
   {{0x69d500a5,0x7d16026d,0xa3cf0b42,0x613c0103}},	//   wsze, _days, वीप_, _félr,
   {{0x69d57a5f,0x6d460084,0x8fa3169f,0x00000000}},	//   tsze, akka, _заче, --,
   {{0x2bd917ff,0xd90f00cd,0x7d160188,0x68ed0877}},	//   _भटका, هید_, _fays, tgad,
   {{0x27e9b5ce,0x69d50dbd,0x7d16008a,0x19580109}},	//   tuan_, rsze, _gays, пасы_,
   {{0x6d4d0694,0x69d50018,0x36d50a01,0x6d5f0078}},	// [da70] _ilaa, ssze, дозр, _imqa,
   {{0x27e9b5cf,0x68edb5d0,0x69d51feb,0xfbd200a1}},	//   ruan_, sgad, psze, _שתי_,
   {{0xfbaf00c7,0x63bb32a7,0x6d4d6c18,0x27e99368}},	//   _কবিত, _stun, _klaa, suan_,
   {{0x27e91e16,0xb4e73873,0x65620234,0x656b020a}},	//   puan_, पले_, gioh, ungh,
   {{0xe1f100bf,0x68430032,0x27e98f3f,0xb8860031}},	//   چسب_, _dídú, quan_, _príť,
   {{0xaabf06ae,0x6b500149,0xb87b0139,0xd0400092}},	//   ्रिक, _vägg, _adíg, qamə,
   {{0xe296075f,0x6d4601ce,0x9195001f,0xf53900d4}},	//   маш_, ykka, мјиш, _toť_,
   {{0xa0a50d4f,0x349500c6,0x63bb0361,0x00000000}},	//   майд, _жабр, _ttun, --,
   {{0x63bbb5d1,0xaabf0469,0x7d1631ed,0x7529630a}},	//   _utun, ्राक, _rays, _inez,
   {{0x6d4db5d2,0xf8aa05cd,0xe8aa33c5,0x7d16b5d3}},	//   _alaa, _कल्प, _कल्च, _says,
   {{0x6d4db5d4,0x75290542,0xfce6017b,0x7d160257}},	//   _blaa, _knez, моно, _pays,
   {{0x6d4d0abf,0x7d162bb3,0x69da705a,0x6b5000bc}},	//   _claa, _qays, štek, _mäge,
   {{0x6b500222,0x6d460084,0x753b0072,0x6b4b00aa}},	//   _läge, rkka, _mouz, _süga,
   {{0x753b0042,0x06e30081,0x2f1800c2,0x7d16008c}},	//   _louz, ন্তি, _ночь_, _ways,
   {{0x6d4d0174,0x6b5056eb,0xbcfb0314,0x316d00ae}},	//   _flaa, _näge, mién, onez_,
   {{0x316d025a,0xbcfb037a,0x6d4d01cb,0x753b02c6}},	//   nnez_, lién, _glaa, _nouz,
   {{0xbf8a0019,0x316db5d5,0xd7f90120,0x00000000}},	// [da80] _đoạn_, inez_, зує_, --,
   {{0x75296b52,0xbcfb05e6,0x6d4d00e7,0x49ba2c9a}},	//   _anez, nién, _zlaa, _واجد_,
   {{0x753bb5d6,0x6b500212,0x65627c53,0xd5b00103}},	//   _bouz, _vägd, tioh, اہر_,
   {{0x448a1011,0x273f00ae,0x753bb5d7,0x998a00c6}},	//   обен_, _sînt_, _couz, rybų_,
   {{0x753b34d7,0x32050124,0xa2a0121d,0x3d00009d}},	//   _douz, _aply_, गेन्, ष्ये_,
   {{0x629c0146,0x316d01e9,0x75294944,0xa294084c}},	//   _úrok, enez_, _enez, налі,
   {{0xbcfb0328,0xd2500037,0x24f60638,0x7c2205db}},	//   dién, طنة_, _очар, _šorl,
   {{0xd1300080,0x316d0257,0x673c008a,0x61ea1c7e}},	//   امة_, gnez_, _horj, rufl,
   {{0x673c2a3c,0x61ea00ae,0xd0070396,0xc48300ae}},	//   _korj, sufl, дење_, _алтк,
   {{0x6d4d0db8,0x753b1428,0xc43b00ca,0x3eaa0537}},	//   _slaa, _zouz, _ותמי, øbt_,
   {{0x6d4d686b,0x673c02dd,0x753b0154,0x00000000}},	//   _plaa, _morj, _youz, --,
   {{0xdfcf231d,0x2bd00ff9,0x50660927,0x6fb60076}},	//   _چين_, तीभा, _отла, _قمصا,
   {{0x63a8b5d8,0x6d4d16b4,0xbcfb00e1,0xe571006e}},	//   _kidn, _vlaa, bién, אַם_,
   {{0xbcfb058a,0x290201c2,0x673c00c2,0xa2c11d96}},	//   cién, _abka_, _norj, रुप्,
   {{0x63a8008a,0x2bd000a8,0x656000bd,0x00000000}},	//   _midn, तीबा, _ommh, --,
   {{0x6d4db5d9,0xd90f0260,0x63a80b8e,0xac950138}},	//   _ulaa, جیح_, _lidn, _пайш,
   {{0x6b50070a,0xb8e7007d,0x753b0322,0x6f180141}},	// [da90] _säge, _उभ_, _rouz, _kavc,
   {{0x753bb5da,0x75296c1a,0x3d00009d,0xadf2102d}},	//   _souz, _snez, ष्ठे_, _अमान_,
   {{0x753b000d,0x58d50a22,0x44bc0294,0x2d68007e}},	//   _pouz, _понт, _ịsụ_, rđev_,
   {{0x23e0007d,0x6b5026af,0xa8350831,0x7bcd2d17}},	//   _निशद, _väge, _земљ, _kwau,
   {{0x291900ae,0xd40b0182,0x753b1428,0x00000000}},	//   _iasa_, تتام_, _vouz, --,
   {{0xb3e004a9,0x2919068d,0x39493b1a,0x673cb5db}},	//   _निरख, _hasa_, lkas_, _gorj,
   {{0x29190a75,0x2006002d,0x236902e6,0x4b3800a1}},	//   _kasa_, _apoi_, đaj_, ורגל_,
   {{0x3949b5dc,0x56941167,0x29194b82,0x69da0161}},	//   nkas_, _раст, _jasa_, átei,
   {{0x2919b5dd,0x2d8b193c,0xbcfb0487,0x3949b5de}},	//   _masa_, dlce_, tién, ikas_,
   {{0x2919b5df,0x8c150033,0x26d10141,0x628803a8}},	//   _lasa_, ামান_, _jezo_, _fydo,
   {{0x8d66236f,0x62885dcd,0x394900aa,0xbcfb00e1}},	//   евне, _gydo, kkas_, rién,
   {{0x63a80995,0x2d840257,0x26d1b5e0,0x917a0023}},	//   _zidn, ôme_, _lezo_, _vậy_,
   {{0x66f01c0a,0x394951ab,0x92c30033,0x6f180090}},	//   _चालक_, dkas_, ্লী_, _favc,
   {{0x29190772,0x2600007a,0x3949b5e1,0x00000000}},	//   _aasa_, _रहली_, ekas_, --,
   {{0x29190979,0xdb0f0037,0xbcfb8420,0xa3cf0096}},	//   _basa_, ádái, gnés, वीत_,
   {{0x61350018,0xa3c1009f,0x386d00e7,0x394990aa}},	//   _pály, ूठा_, _žera_, gkas_,
   {{0x7d04023f,0xc72601b6,0x25bf005f,0x29191558}},	// [daa0] _ibis, ндай, _čula_, _dasa_,
   {{0x2d820998,0x7c24026e,0x06e30081,0x2d9b028d}},	//   loke_, _irir, ন্সি, _èper_,
   {{0x2919049e,0x3949b5e2,0x63a8b5e3,0x673c0364}},	//   _fasa_, bkas_, _ridn, _vorj,
   {{0x3949b5e4,0x3a2501c5,0x2919b5e5,0x96954d18}},	//   ckas_, ælpe_, _gasa_, труш,
   {{0x66150018,0x7d04b5e6,0x9cd700ca,0x673c4c46}},	//   _eszk, _mbis, תונה_, _torj,
   {{0x2919b5e7,0x7d040090,0x7c2b01cd,0x2d824835}},	//   _zasa_, _lbis, _ágre, hoke_,
   {{0x7d04b5e8,0x63a8b5e9,0x2919b5ea,0x3fac0081}},	//   _obis, _vidn, _yasa_, _গবেষ,
   {{0x7afb03ce,0x63a822a5,0x2900b5eb,0x9f4d00c2}},	//   đuti, _widn, nfia_, hteä_,
   {{0x63a80222,0x2d82b5ec,0x213d0063,0x6288007f}},	//   _tidn, doke_, _dowh_, _wydo,
   {{0x7d04b5ed,0x4424b5ee,0xd13000cd,0x46130103}},	//   _abis, _irm_, امک_, _جوہر,
   {{0x7c24b5ef,0x7986010a,0x7bcd024a,0x00000000}},	//   _arir, _okkw, _swau, --,
   {{0x2d82b5f0,0x917100fe,0x7c240216,0x442407ee}},	//   goke_, _tớ_, _brir, _krm_,
   {{0x291903d7,0x394945e8,0x5c040138,0x57df00c3}},	//   _rasa_, vkas_, ляра, _फटेह,
   {{0x29191ee3,0x7d040283,0x79860078,0x67020167}},	//   _sasa_, _ebis, _akkw, र्मक_,
   {{0xb9e402ec,0x2d82b5f1,0x7c245080,0x26d102f1}},	//   літи, boke_, _erir, _rezo_,
   {{0xf99300e3,0x44240099,0x69da0257,0x3949013f}},	//   ابس_, _orm_, âtea, ukas_,
   {{0xb8d9382d,0x3949172a,0x23cf40c1,0x4424083e}},	// [dab0] _चल_, rkas_, _सौंद, _nrm_,
   {{0x3949b5f2,0x29191114,0x7d1d00bb,0x2aee00a5}},	//   skas_, _wasa_, ldss, _जाएँ_,
   {{0x2919b5f3,0x26d12281,0xb8f70033,0xdb040131}},	//   _tasa_, _vezo_, _সা_, _suiç,
   {{0x7d1d2085,0x59b61376,0x4424007e,0xbc680260}},	//   ndss, _आंतर, _brm_, _آمین_,
   {{0x7d1d0fc0,0x53e00469,0x798db5f4,0xe3b801ce}},	//   idss, _निःश, mlaw, ебі_,
   {{0x798db5f5,0x04420396,0x27e90abd,0xb87b6779}},	//   llaw, решн, mran_, _edíc,
   {{0x69da02dd,0x56942155,0x66150034,0x6b5030c1}},	//   štev, _барт, _uszk, _jäga,
   {{0x7d1d21a4,0x798d14a7,0x00000000,0x00000000}},	//   jdss, nlaw, --, --,
   {{0x2d820f6e,0x27e9b5f6,0x798d00f9,0x442405db}},	//   voke_, nran_, ilaw, _grm_,
   {{0x27e93a4c,0x4f2200c2,0x257c02c6,0x94000096}},	//   iran_, адьб, díly_, ोबरच_,
   {{0x27e958db,0x2d82b5f7,0x798d5916,0x1be40378}},	//   hran_, toke_, klaw, _कटहल_,
   {{0x25e917ff,0x27e9b5f8,0x7d040090,0x23670216}},	//   _चटनी_, kran_, _qbis, linj_,
   {{0x2d82b5f9,0x798d01af,0x6459042c,0x7d045c7a}},	//   roke_, dlaw, nzwi, _vbis,
   {{0x2d82b5fa,0x27e9b5fb,0x9ad40129,0x005600a1}},	//   soke_, dran_, _bịar, _בשנת_,
   {{0x27e9b5fc,0x798d0150,0x2d820027,0xda630f32}},	//   eran_, flaw, poke_, аври,
   {{0x7d04b5fd,0x0c261012,0x27e9b5fe,0x09d2009f}},	//   _ubis, _амин, fran_, _तबीय,
   {{0x186740e1,0x629c0074,0x684313fc,0x7c240169}},	// [dac0] вати_, _úrov, анта, _urir,
   {{0x998d02e6,0x79860167,0x798d010a,0x00000000}},	//   ćeš_, _wkkw, alaw, --,
   {{0x27e946cf,0xd5b9004d,0x798d03e3,0x7c220095}},	//   aran_, есі_, blaw, _šorh,
   {{0x44244218,0x69dc0429,0xb7bb016d,0xd946107a}},	//   _prm_, msre, _grão, _реми,
   {{0x3f8c003e,0x69dc4192,0x3f870141,0x27e91a4a}},	//   yldu_, lsre, _oknu_, cran_,
   {{0xf8bf0113,0x232704c9,0x442401b6,0x60c9b5ff}},	//   _anéh_, кочи_, _vrm_, ebem,
   {{0xd24f5e51,0x69dc5cfe,0xbebc00d9,0x672e0212}},	//   ينه_, nsre, ldīg, _inbj,
   {{0x60c95944,0xdce6013f,0xdef8003d,0x60f800e5}},	//   gbem, mokė, miċi_, хния_,
   {{0xdef803e5,0x64a3b600,0x670214e5,0x4424b601}},	//   liċi_, _вата, र्थक_, _urm_,
   {{0xa2c105a5,0xaca40134,0x23670a39,0x69dc0c96}},	//   रुद्, _chọw, cinj_, ksre,
   {{0x13d70081,0x69dc0335,0x2bd0009d,0x00000000}},	//   _সময়, jsre, तीसा, --,
   {{0x27e95835,0x67020557,0xbcfb0103,0xe7e20b2b}},	//   yran_, र्तक_, gnép, _पिंप,
   {{0x201800d9,0xa3b80251,0x7d1d682e,0x46b20179}},	//   āris_, _घूम_, rdss, जशाह,
   {{0x2bb50034,0x6abf50a4,0x69dc0571,0x31b801f9}},	//   ंदबा, ्रेर, fsre, _kéz_,
   {{0x27e960ba,0x25bf0335,0x00000000,0x00000000}},	//   wran_, _čulo_, --, --,
   {{0x2bdc7674,0x6b5062da,0xdef8003d,0xc6d20081}},	//   _बिचा, _väga, diċi_, ালোচ,
   {{0x9b451e49,0x798d048e,0x27e9b602,0x58872787}},	// [dad0] _منظو, rlaw, uran_, тыва,
   {{0x5b1502fd,0x27e9b603,0xdef8003d,0x69dc443b}},	//   _смот, rran_, fiċi_, bsre,
   {{0x2367037d,0x27e914cb,0x31b80103,0xc6a700c2}},	//   vinj_, sran_, _néz_, траи,
   {{0x69c7b604,0x27e97d68,0xfd1f0032,0x4518004d}},	//   mpje, pran_, ndì_, кція_,
   {{0xdfc65e51,0x69da166d,0x2bdc09c3,0x7bdd225b}},	//   _دي_, štet, _बिछा, nssu,
   {{0x7bdd57f2,0x6459b605,0x00000000,0x00000000}},	//   issu, rzwi, --, --,
   {{0x45d40084,0xb5a701b6,0x23670052,0xc6a400f6}},	//   _восс, _арай, rinj_, _врти,
   {{0x7bdd4ee8,0x236700c4,0x00000000,0x00000000}},	//   kssu, sinj_, --, --,
   {{0xa3e0000d,0x23675dca,0x60c91d87,0xe4750284}},	//   _थिए_, pinj_, rbem, _слањ,
   {{0xee3900b4,0x25ad01cb,0x2d89b606,0x60c90fcf}},	//   ено_, _hiel_, _akae_, sbem,
   {{0xf8d3007d,0x9d462b66,0x7bdf31dd,0x25ad0116}},	//   तराय, генд, _avqu, _kiel_,
   {{0x69dc038c,0xab5b0364,0x6d88037a,0xc6920327}},	//   vsre, spül, eñar, מאי_,
   {{0xafe501b6,0x25adb607,0x7bdd01af,0x69c7029a}},	//   _солл, _miel_, gssu, epje,
   {{0xf8bf0af0,0x69dc950d,0x6dba0090,0x00000000}},	//   _afé_, tsre, _iċan, --,
   {{0x7bdd0036,0xdea1010d,0xdb0d0131,0x443200fe}},	//   assu, _دیدی, _guaí, ̣y_,
   {{0x69dc867e,0x3f85b608,0xfe70001c,0x25ad05c2}},	//   rsre, lolu_, _بده_, _niel_,
   {{0x248d0197,0x271d0033,0x69dc9c53,0x9f4a0131}},	// [dae0] _nyem_, নানো_, ssre, _àmão_,
   {{0xdef8003d,0xb8eb2a55,0x34cc42d4,0x69dc6ab7}},	//   tiċi_, _र्_, ार्द, psre,
   {{0x25adb609,0x8afb0089,0x248dad94,0x25e90096}},	//   _biel_, _אפיק, _ayem_, _चटणी_,
   {{0x25ad0257,0x61fc0212,0x23b90154,0xd5af001c}},	//   _ciel_, _ärli, _bèj_, سفه_,
   {{0x938a26d0,0x3f8503e5,0x25ad6ea0,0x23cf0789}},	//   нска_, kolu_, _diel_, सीलद,
   {{0x2bb7000f,0x2912063d,0x68f6245e,0x00000000}},	//   _इंसा, leya_, lgyd, --,
   {{0x3942522a,0x3f85b60a,0x26da198f,0x248d0113}},	//   _koks_, dolu_, mapo_, _eyem_,
   {{0x25ad1cab,0x7bc40b81,0x394200e4,0x26da0350}},	//   _giel_, _otiu, _joks_, lapo_,
   {{0x2d680018,0x9f540859,0x98ac00c6,0x00000000}},	//   tően_, ивич, ėlės_, --,
   {{0x25ad28c7,0xade50378,0x3f851710,0x26dab60b}},	//   _ziel_, _किशन_, golu_, napo_,
   {{0x1d353006,0xa2a00fdd,0x291253fb,0x81bc01d3}},	//   ання, गेश्, keya_, _krēm,
   {{0xc27b193b,0x2b41005c,0x26dab60c,0x7bdd02db}},	//   _ארבי, _sohc_, hapo_, tssu,
   {{0xfd1f013d,0x7bdd0257,0x26da0051,0x248d01fa}},	//   rdì_, ussu, kapo_, _xyem_,
   {{0x909700d6,0xdb1600fe,0x40930037,0x7bdd2fa2}},	//   _світ_, _huyê, _الهر, rssu,
   {{0xf9930177,0xa14301d3,0x26dab60d,0x00000000}},	//   مبر_, _šķir, dapo_, --,
   {{0x69c700dd,0x7bc401b9,0x2d89024a,0x2912149c}},	//   rpje, _ftiu, _ukae_, geya_,
   {{0x69c7b60e,0xbebc01d3,0xb8fd00c3,0x7d7400d1}},	// [daf0] spje, mdīb, _ड़_, _داوط,
   {{0xbebc0029,0x25adb60f,0x69c73069,0x1c2202d5}},	//   ldīb, _siel_, ppje, मिरल_,
   {{0x69da0995,0x25adb610,0xcf930130,0x39429d62}},	//   šter, _piel_, צטע_, _foks_,
   {{0x69c5b611,0x7d1f003d,0x680701d3,0x248d022b}},	//   _ithe, _jaqs, tījā, _pyem_,
   {{0x7d1f3b3b,0x25ad3682,0x26da068d,0x9fdf0081}},	//   _maqs, _viel_, bapo_, _বঙ্গ,
   {{0x69c500dd,0x03a53e86,0x25ad04e2,0x26da6500}},	//   _kthe, шило, _wiel_, capo_,
   {{0x25ad0b60,0x3f8500fc,0xe8e0020b,0x00000000}},	//   _tiel_, volu_, _ngớt_, --,
   {{0x600925ab,0x3fe52f93,0x7d1f2fee,0x69c57df0}},	//   вним_, ажив, _naqs, _mthe,
   {{0x3f85805a,0x656bb612,0xdb1600de,0x6702397e}},	//   tolu_, migh, _duyê, र्वक_,
   {{0x69c5004f,0x20d300de,0x613c0018,0x6f65660c}},	//   _othe, ải_, _mély, рвоз,
   {{0x644b4689,0x7bc424bf,0xed5a065c,0x63bc033b}},	//   lygi, _stiu, вон_, _črni,
   {{0xe1f0003f,0x3f85b613,0xdca600d3,0x656b49fb}},	//   _رسم_, solu_, иани, nigh,
   {{0x69c5b614,0x60db0239,0x06f7148e,0x7d1f0078}},	//   _athe, maum, ुभाव_, _daqs,
   {{0x60dbb615,0xbea51a77,0x656bb616,0xb3d70081}},	//   laum, _калк, high, _সমাজ,
   {{0xfaa600a0,0x6d9d00e3,0x656b019c,0xa96a0e3a}},	//   раво, féad, kigh, вива_,
   {{0x1c461e13,0x60db0010,0xdb160019,0x26da0010}},	//   _вним, naum, _xuyê, wapo_,
   {{0x656b6972,0x29129c79,0xad1b00a1,0x7f43b617}},	// [db00] digh, reya_, _יוקר, _konq,
   {{0x7f43b618,0x6d44007a,0x66e60d84,0x60dbb619}},	//   _jonq, _hoia, рожа, haum,
   {{0x26da99d6,0x6702022d,0x3942013f,0xa2d90251}},	//   rapo_, र्षक_, _toks_, _नज़्,
   {{0xe7ef009d,0x1426017b,0x6d44b61a,0x26da00f9}},	//   _चमचा_, идем, _joia, sapo_,
   {{0x4ada13db,0x6b4b007a,0x6d4400ee,0x00000000}},	//   _बजाव, _sügi, _moia, --,
   {{0x27e0b61b,0x6d44ab2b,0x67020af1,0x7f4322fa}},	//   msin_, _loia, र्शक_, _nonq,
   {{0x6d560068,0x27e0b61c,0x656bb61d,0x877b021e}},	//   _olya, lsin_, bigh, _סאלי,
   {{0xdb1600de,0xf1262c37,0x26d800d7,0xdb0535e3}},	//   _quyê, рько, _hero_, _mihá,
   {{0x27e0b61e,0x26d80239,0xdce402a1,0xa2ca2397}},	//   nsin_, _kero_, _emiċ, _स्थ्,
   {{0x27e09438,0x6d56b61f,0x26d8001c,0x442604ff}},	//   isin_, _alya, _jero_, mvo_,
   {{0x27e0b620,0xdb160019,0xb87b0065,0x660e0063}},	//   hsin_, _tuyê, _adíl, _jpbk,
   {{0xa2ca0714,0x26d86a7b,0x442661b9,0x75221fd1}},	//   _स्त्, _lero_, ovo_, ndoz,
   {{0xae4300bf,0x69c5b621,0x6b5001bf,0x44260063}},	//   مپیو, _sthe, _tägl, nvo_,
   {{0x656bb622,0x4426b623,0x26d8560d,0x6d5673a3}},	//   zigh, ivo_, _nero_, _elya,
   {{0x7d1f003d,0x996749cc,0xa3b81757,0xe819009f}},	//   _taqs, атал, _घूस_, नौना_,
   {{0x442602e6,0x6d44740c,0x5d840246,0x75200350}},	//   kvo_, _goia, _ولول, _namz,
   {{0xd6db0396,0x26d8b624,0x656bb625,0x442600e7}},	// [db10] вте_, _bero_, vigh, jvo_,
   {{0x26d804d8,0x629a01e9,0x656b000b,0x00000000}},	//   _cero_, _ozto, wigh, --,
   {{0x69c5b626,0x442600e5,0x60db8646,0x644b0150}},	//   _uthe, evo_, yaum, wygi,
   {{0x27e07a33,0x38bd0139,0x6d440042,0x644b02ac}},	//   bsin_, _dáró_, _xoia, tygi,
   {{0x26d8b627,0x44290fb6,0x2fc6022e,0x27e0317d}},	//   _fero_, ía_, _ntog_, csin_,
   {{0x67d43703,0x26d827b3,0xa3e8074c,0x60c20139}},	//   _фору, _gero_, _मटर_, _afom,
   {{0x21690459,0x25b8b628,0x656b06a8,0x4426b629}},	//   лики_, _gurl_, pigh, avo_,
   {{0xc69207a6,0xf8bf167e,0xb33c00bd,0x9a7800ca}},	//   _זאל_, _inés_, _biħs, יתוף_,
   {{0x6569b62a,0x60db32a7,0x26d8b62b,0xe1640037}},	//   _imeh, raum, _yero_, تدوي,
   {{0x26c110d9,0x7520b62c,0x26d8008c,0x6dba0090}},	//   ncho_, _zamz, _xero_, _iċaj,
   {{0x2295054f,0xb87b030b,0x60db0239,0x6d4400ae}},	//   _الاس, _sdíl, paum, _poia,
   {{0x27e00084,0x8d5653c8,0xf99f00fe,0x82340076}},	//   ysin_, сточ, _nhè_, _بركا,
   {{0x656900ac,0x7f43b62d,0x69c100b6,0xdb0d037a}},	//   _mmeh, _tonq, ílen, _atañ,
   {{0x316d483a,0xaa463a62,0x290b0565,0x00000000}},	//   liez_, бегл, _abca_, --,
   {{0x26d8092f,0xfbd200d0,0x442618ea,0xf99f028d}},	//   _rero_, _کتب_, zvo_, _bhè_,
   {{0xf99fb62e,0x27e0b62f,0x26d8b630,0x65690174}},	//   _chè_, tsin_, _sero_, _nmeh,
   {{0x26d8b631,0x98a30e1b,0xceba01c2,0xf8bf015e}},	// [db20] _pero_, зите, _haƙa_, _anés_,
   {{0x27e0b632,0x65694b62,0x316d7dff,0x44260b6a}},	//   rsin_, _ameh, hiez_, vvo_,
   {{0x27e0b633,0x26d8b634,0x14c800cd,0x869a00d3}},	//   ssin_, _vero_, لهای_, утат_,
   {{0x44260c00,0x95eb0018,0x27e09363,0x7589004d}},	//   tvo_, ابلہ_, psin_, асів_,
   {{0x2a6e00e7,0x75200138,0x7522b635,0x26d820d1}},	//   _žfbh_, _vamz, rdoz, _tero_,
   {{0x8c1b00a1,0x65691ccd,0x7520484a,0x25b8009c}},	//   טוני, _emeh, _wamz, _turl_,
   {{0x316d0257,0x201d0113,0x9f5f00fd,0x6d9d0076}},	//   fiez_, _aswi_, ctué_, néac,
   {{0x657b01e5,0x39400063,0x75200350,0x316d875e}},	//   _gjuh, njis_, _uamz, giez_,
   {{0x25bf04a3,0x38606408,0x60dd003e,0x60d9009e}},	//   _čuli_, nzir_, ðsma, _dewm,
   {{0xdbd41de7,0xb35600d0,0x161d030b,0x65690141}},	//   _núñe, _دیتا_, फिचर_, _zmeh,
   {{0xab5b2f0b,0x00000000,0x00000000,0x00000000}},	//   nqüe, --, --, --,
   {{0x316db636,0x06970796,0x38600063,0x25a60178}},	//   ciez_, מדים_, kzir_, nmol_,
   {{0x06e30081,0x2cb80146,0x26c124f9,0xd0100286}},	//   ন্টি, _šedá_, ycho_, _آلت_,
   {{0x3860005c,0x0eba02e3,0x139b006e,0xf99f0154}},	//   dzir_, _суды_, ָבלע, _shè_,
   {{0x6d9d0257,0x2bd9023a,0x60cd044c,0x00000000}},	//   réab, _बौरा, _înmâ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c1022b,0x7d0db637,0x20040206,0x657b0141}},	// [db30] tcho_, _ibas, ntmi_, _rjuh,
   {{0x2d8b008f,0x26c11964,0x656960d1,0x7c2d1a03}},	//   loce_, ucho_, _smeh, _irar,
   {{0x26c1b638,0xf99fb639,0x0c780470,0xdce601d3}},	//   rcho_, _thè_, _نصیب_, likā,
   {{0xbcfb04ea,0x2d8bb63a,0x26c1b63b,0x3952024a}},	//   ciét, noce_, scho_, ckys_,
   {{0x7d0db63c,0xbcfbb63d,0xdce601d3,0x316d07d4}},	//   _mbas, liés, nikā, viez_,
   {{0xbcfb0018,0x2329174e,0x2d6801f9,0x490500b6}},	//   gnéz, роки_, tőek_, ह्रो_,
   {{0x7d0db63e,0xe2990c2d,0x29090a4b,0xdce400c4}},	//   _obas, шак_, ofaa_, _smič,
   {{0x7c2db63f,0x65694100,0x4fe92105,0xbfc51da9}},	//   _orar, _umeh, амин_, обик,
   {{0x316db640,0x7c2d00f9,0xceba03e3,0x2d8b0231}},	//   riez_, _nrar, _saƙa_, doce_,
   {{0x7d0d2127,0x442db641,0x8e09456f,0x63bb00f9}},	//   _abas, _ire_, анов_, _iuun,
   {{0x6e4521b6,0xe8d90857,0x7c2db642,0x802712eb}},	//   ценз, ghị_, _arar, _گرام,
   {{0xdb0d0102,0x63bbadf7,0xdce600d9,0x6d5d0037}},	//   _stað, _kuun, fikā, ghsa,
   {{0x63bb007a,0xbcfb97b2,0xdee5b643,0x1b230081}},	//   _juun, viét, _доли, মানে_,
   {{0x63bbb644,0x78130251,0x7d0d007a,0x7c2d0172}},	//   _muun, डबैक_, _ebas, _drar,
   {{0x6d5d02bc,0xed5a2957,0x7c2db645,0xe8d900ac}},	//   bhsa, _вой_, _erar, chị_,
   {{0x442db646,0x7d0d06c0,0x2d8b5347,0xae783006}},	//   _ore_, _gbas, coce_, _усіх_,
   {{0x442db647,0xbcfb06aa,0xfe410018,0xdbd4002b}},	// [db40] _nre_, riét, _رکھی, _túñe,
   {{0x96960396,0xbcfb037a,0x36963ac9,0x00000000}},	//   ореш, biés, ошес, --,
   {{0x442d1723,0xe61a4438,0xbcfb2299,0xaad0023a}},	//   _are_, рде_, miér, _त्यक,
   {{0x442d42c9,0xa50a0b7b,0xdb0500c2,0xbcfb0094}},	//   _bre_, реда_, _eihä, liér,
   {{0x442db648,0x25a6b649,0x2480b64a,0x9f4d5b8f}},	//   _cre_, rmol_, çim_, nteó_,
   {{0x442db64b,0x63bb7d23,0x69c31097,0x69ce029a}},	//   _dre_, _duun, _énec, opbe,
   {{0x442db64c,0x66032549,0x98a20138,0xab5b00a7}},	//   _ere_, _опра, _kokį_, mpüt,
   {{0x442d1957,0x79961650,0x63bb250c,0xf8b80d75}},	//   _fre_, nlyw, _fuun, _अलोप,
   {{0xb4e61a94,0x442d0b27,0x2d8b3c59,0xc05a00d6}},	//   पणी_, _gre_, voce_, рій_,
   {{0x63a1009c,0x7c2d01ff,0x98a00141,0x2004028a}},	//   _ghln, _rrar, jdič_, rtmi_,
   {{0x200461f4,0xb4ab0088,0xdd95055b,0xbcfb037a}},	//   stmi_, _íþró, заны, diér,
   {{0xdce600e8,0x6ed600a4,0x7c2d183f,0x6d5d0231}},	//   tikā, _मजकु, _prar, uhsa,
   {{0x98b300d9,0x2d8b15ec,0x61f80094,0xe8d90134}},	//   ādīt_, roce_, luvl, shị_,
   {{0x7c2d023b,0x7053001c,0x2d8b00b6,0xdce601d3}},	//   _vrar, _تنها, soce_, rikā,
   {{0x3f8cb64d,0xf96b11c0,0x80dd0081,0xceba03e3}},	//   modu_, арай_, _যাত্, _haƙo_,
   {{0x7c2db64e,0x4cd50081,0x3f8c01d3,0x7d0db64f}},	//   _trar, _থাকু, lodu_, _ubas,
   {{0x7c2d7206,0x27f22522,0xbcfb034f,0x1b100033}},	// [db50] _urar, gryn_, biér, ায়ে_,
   {{0x4e1e07e2,0x442db650,0x3f8c0078,0x63bb6259}},	//   _बनाई_, _rre_, nodu_, _ruun,
   {{0x63bb069d,0x442d5455,0x672500dd,0x1db1007f}},	//   _suun, _sre_, rdhj, ीआपत,
   {{0x442db651,0x3f8c6201,0x3959028d,0x6a140504}},	//   _pre_, hodu_, _ulss_, _کبیر,
   {{0xbcfb0257,0xdb0404d8,0x3f8cb652,0xc3240033}},	//   chée, _guió, kodu_, পানি_,
   {{0x442d0c56,0x67ba00ca,0x77ba00ca,0x63bb010a}},	//   _vre_, _למשק, _למשח, _vuun,
   {{0x56945cc6,0xa3cf02d5,0xa4d5097a,0x63bb39b8}},	//   _жарт, वीज_, _нові, _wuun,
   {{0x442d40d6,0xceba03e3,0x63bb74af,0x6b5000aa}},	//   _tre_, _baƙo_, _tuun, _vägi,
   {{0x442db653,0x245800c2,0x69c102c6,0x85540281}},	//   _ure_, _дать_, ílej, _زیور_,
   {{0xf8b81101,0x3f8cb654,0xa2ca0096,0x6b501c49}},	//   _अल्प, godu_, सुद्, _tägi,
   {{0x227700d0,0xc7b400ca,0x490c023a,0x00000000}},	//   _بلاگ_, ובץ_, ड्डो_, --,
   {{0x670b1117,0x070b245a,0x00000000,0x00000000}},	//   स्तक_, स्तव_, --, --,
   {{0xbcfb167e,0x3f8c161f,0x9f35004d,0x9fc9344d}},	//   tiér, bodu_, _неді, _угла_,
   {{0xef1801d3,0x8ccc058f,0x00000000,0x00000000}},	//   ceļ_, _थ्रो, --, --,
   {{0xbcfb0074,0xb87b0033,0xc33200ca,0x6d9d9b0c}},	//   riér, _leíd, עול_, méan,
   {{0xa96724e4,0x6d9d095d,0x47c64441,0xbcfb034f}},	//   писа_, léan, збав, siér,
   {{0x1dd70251,0x46ea4033,0xe8d90129,0x27e6020d}},	// [db60] भीरत, йдан_, chọ_, éon_,
   {{0xf77218a9,0xd7ef00e3,0x2ca02516,0x69ce45d9}},	//   راء_, اكل_, _izid_, ppbe,
   {{0x7abb00a1,0x98a20138,0x14ca00c2,0x3abb00ca}},	//   _לציו, _tokį_, были_, _למינ,
   {{0xb4e6009d,0x6d9d095d,0xbcfb020d,0x3f8cb655}},	//   पणे_, héan, phée, zodu_,
   {{0x29e80abd,0x999e00c6,0x3207007f,0x3f8c0233}},	//   lğa_, štų_, etny_, yodu_,
   {{0x670300af,0x6ab00033,0x59d31e05,0x79580139}},	//   _लायक_, _জ্যো, धीकर, _kíwo,
   {{0x3f8c01d9,0xc7a300d3,0xceba0022,0x3ce2015c}},	//   vodu_, _чирк, _saƙo_, kakv_,
   {{0x3f8c00a5,0xdb0403be,0x2d9206b0,0xf8dc023a}},	//   wodu_, _muiñ, _nkye_, बरिय,
   {{0xb4ca0c9c,0x3f8cb656,0x1b230033,0x7ff60076}},	//   ोरी_, todu_, মাতে_, أسعا,
   {{0x3eb81484,0xe2920037,0x2d8302c6,0x00000000}},	//   ørt_, _كذا_, čkem_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ecc09a0,0x80d60033,0x75c500c6,0x869b021e}},	//   _द्रु, _ধাক্, _jėza, מייז,
   {{0x2d800154,0x00000000,0x00000000,0x00000000}},	//   _djie_, --, --, --,
   {{0x2d920361,0xade51179,0x6d4016f9,0x00000000}},	//   _ekye_, _किचन_, ömar, --,
   {{0x6e933490,0xdb04002b,0xe8d90134,0x00000000}},	//   _пишу, _cuiñ, shọ_, --,
   {{0x2d8002ac,0x00000000,0x00000000,0x00000000}},	//   _gjie_, --, --, --,
   {{0xb8d50557,0x81bc01d3,0x57b573dd,0x2126009c}},	// [db70] _छः_, _krēs, дбат, _maoh_,
   {{0xb8f405d4,0x64d51c83,0x2d9901b5,0x7bcdb657}},	//   _स्_, दर्श, llse_, _itau,
   {{0xdb040328,0x04ca0174,0x2d993370,0x00000000}},	//   _guiñ, _ịpịn, olse_, --,
   {{0x7f940428,0x260e00c3,0x00000000,0x00000000}},	//   màqu, _ठहरी_, --, --,
   {{0x5fb80e4c,0x6b5002c3,0x2d6f02c6,0x00000000}},	//   _उंगल, _vägv, vřel_, --,
   {{0x97350421,0x883a00ca,0xe7871510,0x7bcd024a}},	//   _تکرا, _ותשו, _хумо, _mtau,
   {{0x6fd505d4,0x22540220,0xd56703d9,0x00000000}},	//   _मौजू, _čaká_, _етап, --,
   {{0x394b0472,0x6727b658,0x65942f1f,0xd12e0076}},	//   _jocs_, _hajj, _засу, لمى_,
   {{0x7bcd01bb,0x6727b659,0x32072907,0x394b00b3}},	//   _ntau, _kajj, stny_, _mocs_,
   {{0x2d920441,0xbebc00d9,0x6727b65a,0x35950174}},	//   _skye_, ldīj, _jajj, _ụsụụ_,
   {{0x7bcd2c5c,0x6727b65b,0xe1f00f98,0x00000000}},	//   _atau, _majj, _مسن_, --,
   {{0xed57004d,0x394b0090,0x00000000,0x00000000}},	//   дою_, _nocs_, --, --,
   {{0xf402044c,0x00000000,0x00000000,0x00000000}},	//   cuţă_, --, --, --,
   {{0xfaa62064,0x5eb70081,0x2d992988,0xbcfb014b}},	//   даго, _আজকে, alse_, théc,
   {{0xeb97b65c,0xdb040328,0x2018020a,0x9f4d037a}},	//   фир_, _quiñ, ărie_, nreí_,
   {{0x29e8013c,0x61ee052f,0x6d9db65d,0x9f440052}},	//   rğa_, _æble, néal, ysmë_,
   {{0x672777b8,0x60dd0088,0x3b8623b9,0x0c2300ae}},	// [db80] _bajj, ósmy, _олиг, _амын,
   {{0x7c24b65e,0x6d460995,0xbcfb0037,0xab5b02db}},	//   _isir, ljka, mhéa, spür,
   {{0x6727b65f,0x5b5700ca,0x394b4d8d,0x2d6f02c6}},	//   _dajj, _חייב_, _focs_, dřej_,
   {{0x6e2316e3,0xb4ca17ff,0x6d460660,0x7c24b660}},	//   _msnb, ोरे_, njka, _ksir,
   {{0x68e4b661,0x5ede0081,0xbf1d0096,0x672718bc}},	//   maid, _মাসে, _बघून_, _fajj,
   {{0x68e4b662,0xf8bf255c,0x7c24b663,0x67270361}},	//   laid, _jaén_, _msir, _gajj,
   {{0x7d0408a9,0x6f1a007e,0xdb160139,0x00000000}},	//   _ocis, vetc, _muyà, --,
   {{0x2900b664,0x68e48424,0x64a60293,0x7d040027}},	//   ngia_, naid, _жаба, _ncis,
   {{0x02cf277c,0x73066acb,0x67270517,0x7c24b665}},	//   _स्वभ, _опаз, _yajj, _nsir,
   {{0x68e44450,0xb35600bf,0xbcfb0037,0x29000063}},	//   haid, _زیبا_, dhéa, hgia_,
   {{0x7c24b666,0x36f700a1,0x7bcd2a0d,0x6b500212}},	//   _asir, וצים_, _stau, _lägs,
   {{0xc0a90159,0x2023007b,0x7f9400ee,0x00000000}},	//   _کامل_, äriä_, vàqu, --,
   {{0x68e40013,0xe043249b,0x7c240103,0x394b00b3}},	//   daid, _инци, _csir, _rocs_,
   {{0xfe6f0de1,0x4424b667,0xe1f10018,0xdb1600b3}},	//   ادی_, _msm_, _جسے_, _cuyà,
   {{0x7c24a878,0x68e4b668,0x442400ec,0x394b05fe}},	//   _esir, faid, _lsm_, _pocs_,
   {{0x68e4b669,0xbcfb0080,0x2900013d,0x6727b66a}},	//   gaid, bhéa, ggia_, _sajj,
   {{0x7d1db66b,0x672704f9,0x6d9d0ba6,0x7bcd0a4b}},	// [db90] mess, _pajj, néam, _utau,
   {{0x7d1d9060,0x6727009e,0x00000000,0x00000000}},	//   less, _qajj, --, --,
   {{0xb9051348,0xfad60054,0x8aa71c00,0x68e4b66c}},	//   _না_, _אותך_, _юрид, baid,
   {{0x68e4b66d,0x6727083e,0xc6a424ec,0x67d528f1}},	//   caid, _wajj, труи, _пому,
   {{0x67271232,0x4424b66e,0x9475001c,0xdb160154}},	//   _tajj, _csm_, رگرا, _ityò,
   {{0x27e9b66f,0xf8bf002b,0x7d1db670,0x39b800c4}},	//   msan_, _xaén_, hess, _hčsp_,
   {{0x27e9b671,0x41b526b2,0x7d1db672,0xb87b0143}},	//   lsan_, нсит, kess, _edít,
   {{0x34951456,0x4424b673,0x27e9b674,0x6562b675}},	//   _забр, _fsm_, osan_, choh,
   {{0x27e9b676,0x7d1d069d,0xa2ca0b7f,0x6d9d07d4}},	//   nsan_, dess, _स्क्, réal,
   {{0x27e9ac13,0x6b500149,0x6d5f2bb3,0x7d1d00ce}},	//   isan_, _lägr, _alqa, eess,
   {{0x7d1db677,0x27e96248,0x75290372,0x44240381}},	//   fess, hsan_, _kaez, _zsm_,
   {{0x27e9b678,0x90e709b4,0x260705a7,0x6d4d002b}},	//   ksan_, _آسان, _हमनी_, _coaa,
   {{0x6d4d0063,0x27e90212,0x68e47293,0x752901ff}},	//   _doaa, jsan_, vaid, _maez,
   {{0xdb1c01d4,0x68e4068d,0x27e9b679,0x200a020a}},	//   _özün, waid, dsan_, ăbit_,
   {{0x2d961a18,0x68e4b67a,0x7d1d2ebb,0x290000de}},	//   _прис, taid, bess, tgia_,
   {{0x7d1db67b,0x60c954ca,0x7c24b67c,0x7d04b67d}},	//   cess, ncem, _tsir, _ucis,
   {{0x68e4b67e,0x27e90694,0x7c241c35,0x46f60e3a}},	// [dba0] raid, gsan_, _usir, ечет,
   {{0x68e4b67f,0x6d5d0052,0x1aea0033,0x753b01ff}},	//   said, ërav, ঞ্জে_, _anuz,
   {{0xaadb0054,0x27e937be,0x442408c4,0x68e4ad7c}},	//   _מחיר, asan_, _ssm_, paid,
   {{0x27e9008a,0x4424b680,0x2ee500d7,0x00000000}},	//   bsan_, _psm_, half_, --,
   {{0x3d12244d,0xb87b0396,0x6562b681,0x27e90188}},	//   ध्ये_, _veíc, rhoh, csan_,
   {{0x6562a6b8,0x7d1db682,0xf48712eb,0x087700c1}},	//   shoh, zess, رانی, _װעלט_,
   {{0x75290063,0x7d1db683,0xbcfb00cd,0x46a3067f}},	//   _faez, yess, dhén, _барв,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d1d6e38,0x442400dc,0xceba01c2,0xd0070396}},	//   vess, _usm_, _haƙi_, еење_,
   {{0x7d1db684,0x31a1291d,0x00000000,0x00000000}},	//   wess, róza_, --, --,
   {{0x26c7005f,0x6dba02a1,0x69c80094,0x75290350}},	//   žnog_, _aċar, ídel, _yaez,
   {{0x27e90694,0x63ba02e6,0x60c901c2,0x61f8007e}},	//   ysan_, _hitn, ccem, mrvl,
   {{0x27e927d9,0x69de0139,0x7c8414e4,0x63ba0231}},	//   xsan_, _awpe, гуре, _kitn,
   {{0x5b241c32,0x63ba0078,0xdb17014b,0xa2a74c5b}},	//   льса, _jitn, _xixè, टेक्,
   {{0x7d1db685,0x61eab686,0x63bab687,0xb88302c6}},	//   pess, nsfl, _mitn, zlíč,
   {{0x673c05aa,0xceba01c2,0x63bab688,0x0e9b0796}},	//   _anrj, _naƙi_, _litn, _משול,
   {{0x6b500149,0x27e9b689,0x2b4501f9,0x00000000}},	// [dbb0] _vägr, usan_, ölcs_, --,
   {{0x27e931ed,0x63ba2c07,0x6dbb0090,0xb88302c6}},	//   rsan_, _nitn, _iċaq, vlíč,
   {{0x7ae7420e,0xceba0d2a,0xf7480037,0x629a0de9}},	//   majt, _baƙi_, علمي_, _nyto,
   {{0x442f08a8,0x7ae7b68a,0x63a80357,0xa3d5007b}},	//   tvg_, lajt, _ahdn, водч,
   {{0x63ba02e6,0x27e9448b,0x6dbb02a1,0x39494d6b}},	//   _bitn, qsan_, _jċaq, mjas_,
   {{0x629a06c2,0xe2995cb1,0x7ae7b68b,0x3949b68c}},	//   _byto, мал_, najt, ljas_,
   {{0x38690575,0x629ab68d,0x63521009,0x61ea4a8a}},	//   lzar_, _cyto, рвју, gsfl,
   {{0x7ae7b68e,0x7777003d,0xdb17002b,0x5694315f}},	//   hajt, lixx, _dixé, _саст,
   {{0x3869b68f,0x7ae7705a,0x7ed500d6,0x600600c2}},	//   nzar_, kajt, кінч, вным_,
   {{0x63ba00a6,0x7ae70660,0x60c9b690,0xdb170725}},	//   _gitn, jajt, scem, _fixé,
   {{0xa2ca2a06,0xc3240033,0xceba0044,0x2018020a}},	//   _स्ट्, পাশি_, _yaƙi_, ăria_,
   {{0xed5a4e66,0x00000000,0x00000000,0x00000000}},	//   фом_, --, --, --,
   {{0x0d830fd5,0x644f6546,0x63ba03a9,0x00000000}},	//   рлян, _àcid, _yitn, --,
   {{0x93fa004f,0x3869005c,0x7ae7b691,0xf8bf05ef}},	//   ולשי, dzar_, gajt, _agé_,
   {{0x200db692,0xbcfb00fd,0xb87b037a,0x49961ac8}},	//   ltei_, chéo, _reía, вшат,
   {{0xf1b30096,0x6d5d0216,0x387f05db,0x00000000}},	//   ुदिन, ërat, _žura_, --,
   {{0x200d97e4,0x8c4641a4,0x7ae748a3,0xcc8a00cd}},	// [dbc0] ntei_, _репе, bajt, _زنده_,
   {{0x44380618,0x7bfb00a1,0x7ae77da9,0xd910015a}},	//   _čr_, _קפיצ, cajt, _گیر_,
   {{0xb87b0328,0xd245001c,0x38690143,0x63bab693}},	//   _veía, _اچ_, azar_, _ritn,
   {{0x63ba02e6,0xd91009e5,0x629a0138,0x386901c2}},	//   _sitn, _دیر_, _ryto, bzar_,
   {{0xa3dd009d,0x61eab694,0x938a2249,0x63ba4c54}},	//   थील_, wsfl, мска_, _pitn,
   {{0x7bc4010a,0x61ea03bd,0x629a0324,0x2d82107b}},	//   _muiu, tsfl, _pyto, hnke_,
   {{0xf5061a57,0x63ba1d15,0xd5b204f4,0xceba01c2}},	//   _изво, _vitn, _نفس_, _taƙi_,
   {{0x2d540161,0xdb170042,0xc05a004d,0x629a0094}},	//   _mães_, _vixé, діо_, _vyto,
   {{0xdefa00ae,0x61ea1a04,0x63bab695,0x5f940cb0}},	//   мын_, ssfl, _titn, лиит,
   {{0x63ba0a9f,0x7d1600b6,0x9f5300c2,0x2d82028a}},	//   _uitn, _abys, ивыч, enke_,
   {{0x3869b696,0x00000000,0x00000000,0x00000000}},	//   zzar_, --, --, --,
   {{0xdced00e7,0x7bc46c0e,0xdb16003e,0x9f4d002b}},	//   _tmač, _buiu, _styð, rreá_,
   {{0x7ae70941,0x7bc4044c,0x06e80081,0x6d9d020d}},	//   tajt, _cuiu, _পানি, néai,
   {{0x69c30103,0x7bc46c0e,0x7d1603a8,0x00000000}},	//   _ének, _duiu, _ebys, --,
   {{0xda782dfb,0xb87b0065,0x2d540161,0xe91900d6}},	//   вят_, _adíp, _cães_, нові_,
   {{0x3869b697,0x3f9ea495,0x99640012,0x394912b8}},	//   tzar_, lltu_, атул, ujas_,
   {{0x394900aa,0x7ae707c0,0x6ca400ae,0xdb0e0113}},	// [dbd0] rjas_, pajt, _врэж, kmbè,
   {{0x3869436e,0xf7700adb,0x6d5d7936,0x2ca40233}},	//   rzar_, يال_, lksa, ümde_,
   {{0x3a841736,0x35f541a4,0x77770078,0xe8d90294}},	//   _выяв, упер, rixx, nkị_,
   {{0x6d5db698,0x3869037a,0x00000000,0x00000000}},	//   nksa, pzar_, --, --,
   {{0x7ae50006,0x2489001f,0x6d5d26d1,0x69c587da}},	//   _keht, çam_, iksa, _huhe,
   {{0x4209a102,0x69c563d0,0xb464004d,0x7ae500bd}},	//   енко_, _kuhe, шкіл, _jeht,
   {{0xe29637f2,0x69c500aa,0x6d5db699,0xbcfb014b}},	//   лаш_, _juhe, kksa, thél,
   {{0x7ae584e5,0x69c51e52,0xa0a52742,0x22490880}},	//   _leht, _muhe, лайд, ćak_,
   {{0x69c50052,0x7ae501ff,0x200d01ff,0x00000000}},	//   _luhe, _oeht, utei_, --,
   {{0x200db69a,0x7ae500b6,0x6d5d9f18,0x5e493967}},	//   rtei_, _neht, eksa, епом_,
   {{0x200d6def,0x1d0a008f,0x645953ca,0x69c50027}},	//   stei_, нени_, lywi, _nuhe,
   {{0x200db69b,0x7bc400ae,0x6abe0d61,0x00000000}},	//   ptei_, _puiu, ्ड्र, --,
   {{0xff5300cd,0x60dbb69c,0xe8d90174,0xbcfb0b39}},	//   _پخش_, mbum, akị_, chém,
   {{0x60dbb69d,0x69c5b69e,0x98a000e7,0x2d54016d}},	//   lbum, _buhe, ldić_, _pães_,
   {{0xaca40065,0x00000000,0x00000000,0x00000000}},	//   _ikọw, --, --, --,
   {{0x69c5074a,0x6d5db69f,0x98a0005f,0x98a90220}},	//   _duhe, cksa, ndić_, adač_,
   {{0x999e0018,0x59c01c83,0x186767cb,0x7ae505db}},	// [dbe0] ítő_, _शंकर, гати_, _feht,
   {{0x645900a5,0x7ae53cfb,0x7bcb0231,0x00000000}},	//   dywi, _geht, _égua, --,
   {{0x9bb700a1,0x69c50193,0x75d30037,0x00000000}},	//   _תהיה_, _guhe, ميلا, --,
   {{0xd9460cfc,0x98a01197,0x4a7b0142,0x645900f0}},	//   _семи, jdić_, _טריב, fywi,
   {{0x4d7b00c1,0xbebc00d9,0x06e80081,0xdcef020a}},	//   ערנע, ldīt, _পাঠি, lică,
   {{0x53340562,0xaca400ac,0xd2cf00c3,0x61e100eb}},	//   рект, _nkọw, सुलझ, _bwll,
   {{0x3d050d1b,0x96665be9,0x68e60063,0x6d5d02b6}},	//   _वाले_, _скве, _kekd, yksa,
   {{0xaca437dc,0x4154276c,0x41c300e3,0xbcfb00fd}},	//   _akọw, рвис, حقيق, thém,
   {{0xa3cb1085,0x68e6007e,0x7522024a,0x64a3273f}},	//   _रूप_, _mekd, meoz, _гата,
   {{0x66e408c0,0x75220072,0x141b006e,0x442602a4}},	//   गरिक_, leoz, _אומב, mwo_,
   {{0x3eb8b6a0,0x59b40efb,0x98a000e7,0xa24533e7}},	//   ärt_, ंगार, bdić_, _نیول_,
   {{0x69c5b6a1,0xdd9501b6,0xafe6038f,0x68e6174d}},	//   _ruhe, рамы, _бодл, _nekd,
   {{0x6d5db6a2,0x44260d79,0x69c5b6a3,0x60c202a4}},	//   rksa, nwo_, _suhe, _igom,
   {{0x69c502fd,0x070300a5,0xdcef00d3,0x38ab0139}},	//   _puhe, _लाइव_, fică, _lòrí_,
   {{0x645900a5,0x69c500dd,0xa3e40034,0xab5b016d}},	//   zywi, _quhe, भीत_, nqüi,
   {{0x260802e8,0x442648dd,0x58d51107,0xc4bf0033}},	//   ांनी_, kwo_, роат, _উজ্জ,
   {{0x7ae5b6a4,0x60c276d3,0xb6060335,0xbd880037}},	// [dbf0] _teht, _mgom, _lišć, _حنين_,
   {{0x4426b6a5,0x6e2a00e7,0x69c538a2,0x2fc60270}},	//   dwo_, _ksfb, _tuhe, _muog_,
   {{0x57a400a9,0xe4d5071c,0xfbd00d5b,0x60c20172}},	//   сшта, لقاد, _وتی_, _ogom,
   {{0x60c20efc,0x89da0089,0x6459007f,0xbcfb03a9}},	//   _ngom, _שחרי, tywi, dhék,
   {{0x29190072,0x38ab0139,0xbcfb014b,0x44260517}},	//   _ibsa_, _dòrí_, ckée, gwo_,
   {{0x6459b6a6,0xb60603ab,0x60c2195f,0x1b230081}},	//   rywi, _bišć, _agom, মাকে_,
   {{0x291902ef,0x645500a7,0x66180206,0x44260517}},	//   _kbsa_, _əziy, čaká, awo_,
   {{0x4426092f,0xaca30139,0x672e0a39,0x00000000}},	//   bwo_, _ajọf, _zabj, --,
   {{0x84670465,0xdb0d0072,0x98a000cb,0xff2505b6}},	//   _съве, _luañ, rdić_, ампо,
   {{0xee390ce5,0x889c006e,0x2f55282f,0xd4980fec}},	//   вно_, עבזי, ртис, _срс_,
   {{0x3ea511a0,0x2ca90092,0x8d760f36,0xc2c40604}},	//   ринг, _azad_, لاحا, _ايمي,
   {{0xa3a904dd,0x518414e8,0x60c2083e,0x318c00d2}},	//   _गीत_, _луча, _ggom, těze_,
   {{0x26d10126,0xa3cb0f78,0xe50d1981,0x59b40285}},	//   _ofzo_, _रूम_, _हानि_, ंगसर,
   {{0x68e6b6a7,0x60c200ae,0x98a20034,0x2919b6a8}},	//   _sekd, _zgom, _jaką_, _absa_,
   {{0x09e602ec,0x2d8b0257,0x0f7a0341,0x672e18d3}},	//   робн, ébec_, _ברסל, _rabj,
   {{0x4426007f,0x00000000,0x00000000,0x00000000}},	//   ywo_, --, --, --,

   {{0x212f2bc0,0xa3e41203,0x249fb6a9,0x00000000}},	// [dc00] _magh_, _भौं_, _nyum_, --,
   {{0x13cc0081,0x7c290233,0x212f0441,0x34de1dae}},	//   রীড়, çere, _lagh_, मर्द,
   {{0x76262972,0x59a71179,0x5afb0142,0xfca90d7f}},	//   рмез, _कीवर, _בליצ, _لایو_,
   {{0x44260067,0xe45a02fd,0x61fc0c2e,0x25bf009c}},	//   two_, кже_, _årli, _ciul_,
   {{0x7522b6aa,0xd90d010d,0x240712d3,0x00000000}},	//   reoz, _سیل_, инци_, --,
   {{0x4426b6ab,0x60c200e5,0x2ca00063,0x8c370266}},	//   rwo_, _sgom, _myid_, יטנס_,
   {{0x661c1711,0x25bf00d3,0x212f01b9,0x201d05aa}},	//   _uprk, _fiul_, _bagh_, _apwi_,
   {{0xb60602ef,0xbcfb0094,0x25ad009c,0x1fda0033}},	//   _višć, chéh, _ghel_, _দিবস,
   {{0x7f9d0257,0xe3ba0609,0x212f01ce,0x00000000}},	//   hèqu, _аба_, _dagh_, --,
   {{0xc3060103,0x381700a1,0x200b0472,0x46aa009f}},	//   _خبرو, סקים_, àcia_, _कराह,
   {{0x201d0383,0xb87b037a,0xdb170231,0x00000000}},	//   _epwi_, _reím, _lixã, --,
   {{0x60c20384,0xdb17002b,0xdb1e00b3,0x25ad0216}},	//   _ugom, _vixí, _hipè, _xhel_,
   {{0xd0078dec,0x80dd00c7,0x249f023e,0x260809c3}},	//   _вече_, _যাচ্, _xyum_, ांडी_,
   {{0x200400d9,0x271702c6,0x2ee70116,0x2ca900d4}},	//   mumi_, _mění_, _genf_, _vzad_,
   {{0x2004b6ac,0x26d10d62,0xa9240206,0x00000000}},	//   lumi_, _rfzo_, _žľaz, --,
   {{0x644d00c2,0xa647001c,0x00000000,0x00000000}},	//   äaik, یخان, --, --,
   {{0x2d99b6ad,0x2004669a,0x00000000,0x00000000}},	// [dc10] mose_, numi_, --, --,
   {{0x2d99b6ae,0x7c2db6af,0x00000000,0x00000000}},	//   lose_, _isar, --, --,
   {{0x20045f25,0xcf93006e,0x7c2d00bd,0x00000000}},	//   humi_, קטע_, _hsar, --,
   {{0x2004b6b0,0x2d9908a9,0xe57000e3,0x6d9d0072}},	//   kumi_, nose_, وطن_, méas,
   {{0x20040b4b,0x68ed7c2e,0x6d9d0076,0x7c2d02a1}},	//   jumi_, maad, léas, _jsar,
   {{0x68ed7c2e,0xb5c906fa,0x2004b6b1,0x2d99b6b2}},	//   laad, _موسم_, dumi_, hose_,
   {{0x7d0d255c,0xd5bb268e,0xdb1e4fd0,0x6d9d3a38}},	//   _ocas, _аса_, _sipë, néas,
   {{0x68edb6b3,0x2909b6b4,0x200400e5,0x7d0d0314}},	//   naad, ngaa_, fumi_, _ncas,
   {{0x2d99b6b5,0x200440d0,0x660500ec,0x656b0037}},	//   dose_, gumi_, luhk, mhgh,
   {{0x7d0db6b6,0x68ed008a,0x1f651087,0x00000000}},	//   _acas, haad, ском, --,
   {{0x7c2db6b7,0x68edb6b8,0x66050899,0x69d7006c}},	//   _asar, kaad, nuhk, _ntxe,
   {{0x442d0270,0x6366003e,0x3a3a037a,0x7c2d01ff}},	//   _kse_, _iðna, _rrpp_, _bsar,
   {{0x68ed024b,0x442db6b9,0xdb1e0143,0x69d701c8}},	//   daad, _jse_, _hipé, _atxe,
   {{0x1dcf0e72,0x6d4b0c56,0xb47a00c1,0x660517b6}},	//   _संपत, _ògan, אָלי, kuhk,
   {{0x68ed0188,0x2d99b6ba,0x7c2d6f01,0xbcfb0143}},	//   faad, bose_, _esar, zhéi,
   {{0x442d01e5,0x68edb6bb,0x66057199,0x2909b6bc}},	//   _ose_, gaad, duhk, ggaa_,
   {{0x69d702a7,0x442d0af0,0x6d4406a8,0xdb1e0037}},	// [dc20] _etxe, _nse_, _inia, _lipé,
   {{0x6d44022e,0x6d56008c,0x67250ac9,0x00000000}},	//   _hnia, _hoya, gehj, --,
   {{0x442db6bd,0x6d56b6be,0x6605063f,0x68ed008a}},	//   _ase_, _koya, guhk, baad,
   {{0x6d56b6bf,0xbcfb00e3,0xdb1e06a3,0x7aee0188}},	//   _joya, théi, _sipè, labt,
   {{0x6d560da3,0x69dcb6c0,0x67250537,0x00000000}},	//   _moya, lpre, behj, --,
   {{0x660546c3,0x69c30451,0x7aee85dd,0x2004b6c1}},	//   buhk, _ènec, nabt, vumi_,
   {{0x27f23de7,0x66050085,0x6d56008c,0x2d9985f2}},	//   lsyn_, cuhk, _ooya, yose_,
   {{0xf1260a8d,0x6d56b6c2,0x2d9903be,0x442db6c3}},	//   сько, _noya, xose_, _fse_,
   {{0xa49403ed,0x27f20c2e,0x442d0036,0x3e4e00a7}},	//   _بیشت, nsyn_, _gse_, məti_,
   {{0x2004b6c4,0x543b0130,0x160c05a7,0x6d44b6c5}},	//   rumi_, _געמא, _हमार_, _ania,
   {{0xa3e4110f,0xeb9f1484,0x69dc19be,0x2d99b6c6}},	//   भीर_, ktør_, jpre, tose_,
   {{0x69dcb6c7,0x2d99013f,0x68ed008a,0x6562b6c8}},	//   dpre, uose_, xaad, nkoh,
   {{0x6d56adb1,0x7d0db6c9,0x68ed00aa,0x6d440034}},	//   _doya, _vcas, vaad, _dnia,
   {{0x68ed32bd,0x69dc8786,0x2d99b6ca,0x65620216}},	//   waad, fpre, sose_, hkoh,
   {{0x69dcb6cb,0x68edb6cc,0x1dcf0285,0x6d560154}},	//   gpre, taad, _संयत, _foya,
   {{0x7c2d0a75,0x6d9d0037,0x2b1a030b,0x6d44b6cd}},	//   _tsar, réas, म्बु_, _gnia,
   {{0xb8d10d0b,0x68ed1f5c,0x7c2db6ce,0x7aee008a}},	// [dc30] _ओर_, raad, _usar, babt,
   {{0x66052f6b,0x68edb6cf,0x442db6d0,0x7bddb6d1}},	//   tuhk, saad, _rse_, mpsu,
   {{0x656b0a02,0x63a30146,0x442db6d2,0xd91900ae}},	//   thgh, vlnn, _sse_, _конц_,
   {{0x442d01e5,0xd12609b4,0xe7ed0455,0x66050808}},	//   _pse_, _غم_, _चौथा_, ruhk,
   {{0xe3b10241,0x06e80081,0xd0062729,0x660500b7}},	//   ورت_, _পারি, _تل_, suhk,
   {{0x442d2782,0x31b3178c,0x660500bc,0x8c1c00d7}},	//   _vse_, ुद्ध, puhk, טודי,
   {{0x3e4e00a7,0x78c801f9,0x00000000,0x00000000}},	//   bəti_, _ásvá, --, --,
   {{0x442d006c,0xd1b90103,0x88e70033,0xeb9f0537}},	//   _tse_, جاتا_, _ফাঁক, lrød_,
   {{0x442d0054,0x5f750103,0x6d56b6d3,0x69dc3692}},	//   _use_, قادر, _roya, zpre,
   {{0x6d56b6d4,0x2d8b0018,0x69dc0270,0x6569063d}},	//   _soya, ében_, ypre, _hleh,
   {{0x69dcb6d5,0xe0d5001f,0xd12e0e27,0x7bdd4f97}},	//   xpre, _доењ, رمی_, epsu,
   {{0x69dc0087,0x6d566acd,0x66d00139,0x00000000}},	//   vpre, _qoya, _kòkó, --,
   {{0x6d5604ea,0x9f35004d,0x00000000,0x00000000}},	//   _voya, _меді, --, --,
   {{0xf99f0065,0xdce405db,0x00000000,0x00000000}},	//   _akè_, _ilič, --, --,
   {{0xa3cb000f,0x656932c3,0x6d566095,0x06e80081}},	//   _रूस_, _oleh, _toya, _পালি,
   {{0x7aee21d2,0x6d44b6d6,0xb4e8009f,0xdce433d7}},	//   sabt, _unia, _मजे_, _klič,
   {{0x69dcac67,0x46ea0095,0x98a31167,0xa9673974}},	// [dc40] spre, идан_, дите, цита_,
   {{0xbf8700ef,0x81df0081,0xbcfb0018,0x27f20170}},	//   _điện_, _তিন_, nkén, rsyn_,
   {{0x2018002d,0x316d0018,0xdd8f00cd,0x27f222cf}},	//   ării_, khez_, _سوی_, ssyn_,
   {{0x96da110f,0xdce4042d,0x317f0350,0x27f21370}},	//   _प्रॉ, _olič, jiuz_, psyn_,
   {{0x656200dd,0xc2f30081,0xeb9f01df,0x3e4e00a7}},	//   rkoh, চ্ছি_, brød_, rəti_,
   {{0x47c30465,0x6562b6d7,0x69c3025a,0x9c830579}},	//   _обяв, skoh, _éner, _účel,
   {{0xdce400e7,0xe1ef00e3,0x29e86f01,0xd25716c0}},	//   _alič, نسي_, nşa_, жцы_,
   {{0x6b9c1abd,0xdced1711,0x387f00cc,0xf99f0451}},	//   horg, _imać, _žuri_, _xkè_,
   {{0x6b9cb6d8,0xe5a33e1e,0x3860b6d9,0x7f4a004d}},	//   korg, _цити, nyir_, аїна_,
   {{0xdea301c2,0x25a6b6da,0x00000000,0x00000000}},	//   _hanƙ, llol_, --, --,
   {{0xe8a737b3,0xdce436da,0xe80c08d4,0x6b9cb6db}},	//   _खर्च, _amiđ, िंडा_, dorg,
   {{0x316d00fd,0xd130015a,0x3d270120,0x00000000}},	//   chez_, _سمت_, цьов, --,
   {{0xbcfb0018,0x6b9cb6dc,0x1ae20033,0xf8bf0113}},	//   bkén, forg, _বাড়া, _laér_,
   {{0xa3b00067,0xdea303e3,0x96da1fbb,0x99d70037}},	//   _टीम_, _lanƙ, _प्लॉ, قترا,
   {{0x0eba0138,0x7ed307e8,0xda34147c,0xaada007f}},	//   _туды_, _غزوا, меры, भड़क,
   {{0x26c70031,0x65a300bc,0x00000000,0x00000000}},	//   ľnom_, põhi, --, --,
   {{0x6b9cb6dd,0xc6f90805,0x00000000,0x00000000}},	// [dc50] borg, йнах_, --, --,
   {{0xd6db0e4a,0x6b9c00e5,0xb90224eb,0x65690147}},	//   рта_, corg, _न्_, _sleh,
   {{0xcb12040a,0xdea301c2,0x65690fb2,0xb4d80129}},	//   _אלי_, _banƙ, _pleh, _ịzụt,
   {{0xa6e30081,0x7bcd010a,0x0574001c,0xbcfbb6de}},	//   _পাওয়, _kuau, واند, chét,
   {{0x7bc5b6df,0xdea30022,0x2d8b0076,0xd7f86262}},	//   _kihu, _danƙ, ince_, _мур_,
   {{0x232908c3,0x7bc51308,0x26080096,0xd8ba00ca}},	//   соки_, _jihu, ांशी_, _לצרכ,
   {{0xdce402e6,0x7afa0088,0x96f835c1,0xa5f81cdb}},	//   _slič, ótti, _фест_, _меру_,
   {{0x657b696a,0x6b9c0ab2,0x32073a18,0x645c00a7}},	//   _umuh, zorg, runy_, _əriz,
   {{0x4439b6e0,0x3207b6e1,0xb4c90096,0x81bc01d3}},	//   _és_, suny_, ोडी_, _spēc,
   {{0x443f0121,0x316d0018,0x2d8bb6e2,0x39591759}},	//   _iru_, shez_, ence_, _loss_,
   {{0x443f025b,0x6da65833,0x6b9cb6e3,0xada600e5}},	//   _hru_, зина, vorg, занл,
   {{0x69ca0161,0x7bc503e3,0x3959b6e4,0xbcfb0103}},	//   _éfei, _aihu, _noss_, skén,
   {{0x6b9cb6e5,0xdce4077e,0x7bc52f3e,0x160d0789}},	//   torg, _ulič, _bihu, ांडर_,
   {{0x2d8b2944,0xd00e00e3,0x26c70039,0x7bc58131}},	//   ance_, _صلى_, žnoj_, _cihu,
   {{0x7bc5005a,0xbcfb0257,0xae1f0378,0xaa430036}},	//   _dihu, thét, _बहिन_, нерл,
   {{0x394611c4,0x443f2624,0x6b9cb6e6,0x88ca5ccc}},	//   ños_, _oru_, sorg, слав_,
   {{0x2d82b6e7,0x443f03e5,0x2bd8001c,0x7bcd037a}},	// [dc60] mike_, _nru_, _بابک_, _guau,
   {{0x2d82b6e8,0x7bc5b6e9,0x7c24b6ea,0xdea301c2}},	//   like_, _gihu, _ipir, _sanƙ,
   {{0x443fb6eb,0x386002fa,0x38660d62,0x6735009e}},	//   _aru_, syir_, šor_, _dazj,
   {{0xe80c0179,0xa50a2360,0x7bc562fa,0x443fb6ec}},	//   िंदा_, седа_, _zihu, _bru_,
   {{0xe8030067,0xdce60029,0x68e4b6ed,0x27ee030b}},	//   _लिया_, dokļ, mbid, álně_,
   {{0x27e026f7,0x68e402a7,0x7c240051,0x443f1175}},	//   mpin_, lbid, _mpir, _dru_,
   {{0x443f0682,0x7f58023e,0xdea301c2,0x2d82b6ee}},	//   _eru_, _rovq, _tanƙ, kike_,
   {{0x68e4b6ef,0x443f040f,0x59be00c0,0xdc3f00ae}},	//   nbid, _fru_, ्दिर, nţăr,
   {{0x69c6b6f0,0x68e4b6f1,0x1604074c,0x27e0b6f2}},	//   _mike, ibid, शंकर_, npin_,
   {{0x69c6b6f3,0x644082ac,0x138a0037,0x9df8001f}},	//   _like, _irmi, _اخرى_, онот_,
   {{0x69c60d64,0x2d82b6f4,0xdd950138,0x7c240a00}},	//   _oike, fike_, даны, _apir,
   {{0x644041f9,0x69c6b6f5,0x44240332,0x160d0980}},	//   _krmi, _nike, _kpm_, ांतर_,
   {{0x2b5a00b3,0x7bc500bc,0x44246815,0x69b00d75}},	//   _bopc_, _pihu, _jpm_, ंतनी,
   {{0x69c6b6f6,0xddda0018,0x7fb800cd,0x3959058f}},	//   _aike, sztő, _بهتر_, _soss_,
   {{0x395901af,0x99670219,0x7c240052,0xf8da0174}},	//   _poss_, птал, _epir, _ọrụa,
   {{0x3f9eb6f7,0x4424b6f8,0x26ca026e,0xf2df00de}},	//   lotu_, _opm_, _agbo_, _đâm_,
   {{0xa2bc0852,0x69c60496,0x27e000f9,0x3959004d}},	// [dc70] षेत्, _dike, gpin_, _voss_,
   {{0x3f9e01d3,0x69c68bc2,0x7d1d3e54,0x443f378a}},	//   notu_, _eike, lfss, _rru_,
   {{0x6440b6f9,0x6d4000fd,0x44248002,0x3f8cb6fa}},	//   _armi, ômag, _apm_, indu_,
   {{0x443fac3d,0x64400063,0x26ca3ad5,0x3f9e0094}},	//   _pru_, _brmi, _egbo_, hotu_,
   {{0x98ab0012,0x240900d6,0x3f9e5dac,0x443f2bf9}},	//   _dacă_, інки_, kotu_, _qru_,
   {{0x798d00f9,0x8c1c006e,0x644000c4,0x64460234}},	//   lnaw, צווי, _drmi, _škic,
   {{0x98ab00d3,0x2004028d,0x3f9e00e8,0x00000000}},	//   _facă_, ermi_, dotu_, --,
   {{0x636f1484,0x443fb6fb,0x798db6fc,0x44240231}},	//   _sønd, _tru_, nnaw, _fpm_,
   {{0x443f2d63,0x2d8204a3,0xf2c702b3,0x7c29026a}},	//   _uru_, vike_, _есен, çerl,
   {{0x798d2081,0xd00e010d,0x9e65098a,0x8af700a7}},	//   hnaw, گلی_, двод, _şənb,
   {{0x442f02ad,0xa2a40251,0x2004b6fd,0x140d00a8}},	//   lwg_, _चुप्, armi_, _समुह_,
   {{0xd00e1ac9,0xb33c00bd,0xcac50033,0x7c24010a}},	//   دلی_, _ikħa, ্রাফ, _ppir,
   {{0xef0e0aec,0x2d821cc9,0xe6aa0efb,0xbcfbb6fe}},	//   _им_, rike_, _कर्ज, ckém,
   {{0x69c674f5,0x8e8508c3,0xb87b037a,0xa3c202d5}},	//   _sike, _огле, _leís, ृदय_,
   {{0x69c62aad,0x6fd500c7,0xfaa3918d,0xbcfb3912}},	//   _pike, _দিয়ে, варо, rhér,
   {{0x140d07e2,0x68388d62,0xb4c960a3,0x68e40634}},	//   _समूह_, júdá, ोडो_, ubid,
   {{0xbcfb00fd,0x2fc700ca,0x7c241500,0x2d920079}},	// [dc80] phér, _king_, _upir, _ijye_,
   {{0x69c6b6ff,0x68e477b9,0x2d8001f7,0x2fcf059a}},	//   _wike, sbid, _hmie_, _mugg_,
   {{0x2fc709f0,0x44249234,0x7afa003e,0x2fcf059a}},	//   _ming_, _spm_, óttu, _lugg_,
   {{0xc4860358,0x27e032a7,0xdb1e00b3,0x3ea706cd}},	//   млек, ppin_, _hipà, _mynt_,
   {{0xd24f00bf,0x2fdd023e,0x79840134,0x3f8c01cd}},	//   ینه_, _ntwg_, miiw, yndu_,
   {{0x2fc7b700,0x06e80081,0x26ca4eac,0x79840361}},	//   _ning_, _পাকি, _ugbo_, liiw,
   {{0x3f9e02e6,0x2eee171d,0xb87b0072,0x2d80084e}},	//   votu_, _reff_, _feís, _omie_,
   {{0x2fc70167,0x2d920193,0xf0d20134,0x60f8008f}},	//   _aing_, _njye_, _rịsọ, чния_,
   {{0x44244018,0xdce60138,0x3f9e9cc5,0xf2020336}},	//   _upm_, likė, totu_, रूज़_,
   {{0x2fc70449,0x2d8000fd,0x69de077e,0x798d0034}},	//   _cing_, _amie_, _otpe, znaw,
   {{0xe0da28b9,0x2fc7b701,0x3f9e7ad4,0xbcfb0094}},	//   _две_, _ding_, rotu_, ském,
   {{0x7afe0231,0x7d1d042c,0x3f9eb702,0x00000000}},	//   _adpt, ufss, sotu_, --,
   {{0xb87b0018,0x9cc80077,0x2fc7407b,0x7d1d003e}},	//   _leír, дыра_, _fing_, rfss,
   {{0x2fc7ac50,0x7c3d0537,0x00000000,0x00000000}},	//   _ging_, rvsr, --, --,
   {{0xa2a400c0,0x61f81030,0x3ea784a3,0x00000000}},	//   _चुम्, nsvl, _gynt_, --,
   {{0x69da0080,0x2fc70019,0x798d3883,0x442f006c}},	//   ítea, _zing_, unaw, ywg_,
   {{0x442f01fa,0xe50d00aa,0x57b503bf,0x798db703}},	// [dc90] xwg_, हलसि_, ебат, rnaw,
   {{0x2ca905e0,0x798d084e,0xb87b1d6c,0x61f802ac}},	//   _iyad_, snaw, _seís, ksvl,
   {{0xfc3f034f,0x68ef10f4,0x06e80033,0x00000000}},	//   lví_, _tecd, _পাখি, --,
   {{0xceb30105,0x46df000d,0xa4d500d6,0x442f705d}},	//   דיע_, _प्रह, ході, twg_,
   {{0xd0062761,0xd8da00ca,0xd6db0161,0x61f802ac}},	//   _حل_, _מקרר, _мтв_, esvl,
   {{0x442f00f0,0x00000000,0x00000000,0x00000000}},	//   rwg_, --, --, --,
   {{0xc6a40a29,0xd2510604,0x442f01fa,0x2fc7b704}},	//   _арти, انع_, swg_, _ring_,
   {{0x2fc7172a,0x7af50a00,0x3cfb0034,0x2055007e}},	//   _sing_, hazt, ्लों_, етор,
   {{0x160d009d,0x61f802ac,0x3ea71b6f,0x7af501c8}},	//   ांवर_, asvl, _synt_, kazt,
   {{0xa3d40f73,0x3ea701df,0xf8bf0065,0xbcfb02c6}},	//   _संत_, _pynt_, _gbée_, lkéh,
   {{0x2fc7b705,0x7af50062,0x2ca9041c,0x00000000}},	//   _ving_, dazt, _ayad_, --,
   {{0x20020138,0xc6920089,0x2fc700d7,0xbcfb00d4}},	//   škia_, ראט_, _wing_, nkéh,
   {{0x2fc7b706,0xf5390181,0xa2c70386,0x3dc900fc}},	//   _ting_, _mať_, ाशक्, _diaw_,
   {{0x2fc7009c,0x7af50634,0xbcfb0094,0x70df00b6}},	//   _uing_, gazt, hkéh, _नभुल,
   {{0x3f85b707,0xeb9702a0,0xf2d2021e,0xbcfb00d4}},	//   milu_, хир_, רעל_, kkéh,
   {{0x3f85b708,0xb87b034f,0x2d9202a4,0x00000000}},	//   lilu_, _reír, _ujye_, --,
   {{0xa3cb1152,0x7af501e9,0x8c140033,0x200d6072}},	// [dca0] _रंग_, bazt, িবহন_, nuei_,
   {{0x212d2b27,0xdce6013f,0x7c36039f,0x00000000}},	//   heeh_, tikė, _isyr, --,
   {{0x69de0572,0x212d03a9,0x00000000,0x00000000}},	//   _utpe, keeh_, --, --,
   {{0xd91000d0,0xd6e80081,0x63740139,0x200d0062}},	//   _خیر_, _পাওয, _kàng, kuei_,
   {{0xd467225d,0xf5390220,0x68f6612f,0xd90d09e5}},	//   нице_, _dať_, mayd, _ذیل_,
   {{0x68f6b709,0x7c360063,0xf8af0018,0x29be0174}},	//   layd, _msyr, _چکے_, _ọchụ_,
   {{0x3f850128,0x31c6b70a,0x69ca03a9,0x00000000}},	//   dilu_, нсив, _éfes, --,
   {{0x64a63e18,0xbcfb0618,0xa3cb009f,0x68f6b15c}},	//   _заба, ckéh, _रूक_, nayd,
   {{0x59d20d0b,0x200d0396,0x9171020b,0x00000000}},	//   _दूसर, guei_, _sợ_, --,
   {{0x68f6008c,0xd2aa00ae,0x61f800c4,0x3f850062}},	//   hayd, _екзе_, psvl, gilu_,
   {{0x7c3600dc,0x00ca0f84,0x28a701e4,0x212d0113}},	//   _asyr, _елек_, _कुनि, beeh_,
   {{0xfc3f033a,0x68f66221,0x9171020b,0x00000000}},	//   tví_, jayd, _vợ_, --,
   {{0x3f85b70b,0x68f6008a,0x69da0018,0x71650037}},	//   bilu_, dayd, íten, _جالك,
   {{0xdced02a1,0xdb580219,0x00000000,0x00000000}},	//   _klaċ, нюс_, --, --,
   {{0x3da70ed1,0x7af502a7,0xe8030096,0x7ed5004d}},	//   _приб, razt, _लिहा_, _річч,
   {{0x195801b6,0x68f66d66,0x29120283,0x6c850037}},	//   насы_, gayd, ggya_, _للعم,
   {{0x6d4db70c,0x636f13ea,0x63740065,0xa898131b}},	// [dcb0] _inaa, _løna, _gàng, екту_,
   {{0x81bc0029,0x69b317ff,0x7641003e,0xa3b0023a}},	//   _spēl, _आठवी, _ályk, _टील_,
   {{0x6d4d1570,0x68f6b70d,0xbcfb0031,0x5f1300b7}},	//   _knaa, bayd, tkéh, _दास्_,
   {{0x3f8500cc,0x32070094,0xdb0e32e1,0x00000000}},	//   zilu_, vrny_, rmbå, --,
   {{0xf0d20134,0xa3d400c3,0x6d4d65eb,0xa3b95f34}},	//   _rịpọ, _सूद_, _mnaa, واتر_,
   {{0xbcfb025b,0x9f5f00b3,0x00000000,0x00000000}},	//   skéh, truí_, --, --,
   {{0xe29601c9,0x6d4d9e0c,0x61ed0218,0xcfda0033}},	//   каш_, _onaa, ćalo, _দিগন,
   {{0x200d740c,0x6d4d0517,0xe7a9007f,0x00000000}},	//   tuei_, _nnaa, कतकप, --,
   {{0x26c70031,0x6374015e,0xa3d5004d,0x34940ed7}},	//   ľnou_, _bànd, _розч, _батр,
   {{0x6d4db70e,0x200302fb,0x753b4683,0xb4bf0d61}},	//   _anaa, čji_, _hauz, ुखी_,
   {{0x13e60f71,0xfce67fa9,0x1d0a0636,0x3f8529c3}},	//   _নিয়, коно, мени_, rilu_,
   {{0xd25600a1,0x753b01e9,0x3f851e4d,0x212d00dc}},	//   _בשעה_, _jauz, silu_, qeeh_,
   {{0x200db70f,0x753b0239,0x3f8535e8,0xe0d00281}},	//   quei_, _mauz, pilu_, _ازم_,
   {{0x63a36fef,0x753bb710,0x6d4da944,0x68f6008c}},	//   nonn, _lauz, _enaa, wayd,
   {{0x56130081,0xfaa62813,0x68f69768,0xdce600e8}},	//   সবুক_, таво, tayd, nikī,
   {{0x63a32d36,0x1c4616bd,0x753b4393,0x637400ee}},	//   honn, _аним, _nauz, _tàng,
   {{0x63a37988,0x1c16afe5,0x68f6b711,0x6b8701cb}},	// [dcc0] konn, _तमिल_, rayd, bijg,
   {{0x63a3b712,0x68f607aa,0x1bba2ba0,0x3cde0ded}},	//   jonn, sayd, _تابع_, कुरे_,
   {{0x63a3b713,0x5a961eac,0x68f60112,0x753b0365}},	//   donn, _шриф, payd, _bauz,
   {{0x753b0012,0x5983036a,0x6374015e,0x5693004d}},	//   _cauz, _влюб, _màne, шаєт,
   {{0x753b01e9,0xf487001c,0x290249ee,0x00000000}},	//   _dauz, پانی, _idka_, --,
   {{0x63a3b714,0xdced00bd,0x00000000,0x00000000}},	//   gonn, _plaċ, --, --,
   {{0x753b0991,0x61e1009c,0x3d1300b6,0x00000000}},	//   _fauz, _ctll, _थाले_, --,
   {{0x673c198c,0x753b02a7,0x261c037a,0xd6273bba}},	//   _harj, _gauz, mío_, _шосе_,
   {{0xb4251e53,0x673c8ab9,0x34a7014d,0x1b0a0081}},	//   _معلو, _karj, _авто_, শ্যই_,
   {{0x63a3025a,0x753b00e9,0x6d4d057a,0x2002013f}},	//   conn, _zauz, _snaa, škio_,
   {{0x3eaa052f,0x69da00b6,0x637400b3,0x6560019f}},	//   æbt_, ítel, _càne, _komh,
   {{0x629a0062,0x6b8701cb,0x673c0216,0x752201ff}},	//   _ixto, wijg, _larj, nfoz,
   {{0x64426ba4,0x261c0072,0x6b87029a,0x637400ee}},	//   nvoi, hío_, tijg, _tànd,
   {{0x636f0400,0x673c03a9,0x6560019f,0x6442007b}},	//   _lønn, _narj, _lomh, ivoi,
   {{0x5fb70054,0xdcedb715,0x5ec00081,0x6b870126}},	//   _שהוא_, _hlač, _শ্রে, rijg,
   {{0x63a3b716,0x81bc00d9,0x6d4d0051,0x261c0610}},	//   zonn, _spēj, _unaa, dío_,
   {{0x63a3b717,0x69d8b718,0xeab00018,0x212603a9}},	// [dcd0] yonn, _éven, معہ_, _mboh_,
   {{0x66030220,0xf77300ab,0x261c0610,0x6560009c}},	//   ánko, جار_, fío_, _aomh,
   {{0x673c08d3,0x636f01df,0xc6a44460,0x28f90d4f}},	//   _darj, _bønn, арци, _пень_,
   {{0x6560445f,0x63a3b719,0x00000000,0x00000000}},	//   _comh, wonn, --, --,
   {{0x63a3b71a,0x6560006b,0x442918ae,0xdb050113}},	//   tonn, _domh, ïa_, _akhé,
   {{0x212601dc,0x753b0239,0x261c0328,0x673cb71b}},	//   _aboh_, _wauz, bío_, _garj,
   {{0x63a3b71c,0x3869b71d,0x2bda06ed,0xb59515a9}},	//   ronn, lyar_, _यूना, _бивш,
   {{0xf2df0028,0x63a3b71e,0x56940da5,0xdce4077e}},	//   _đâu_, sonn, _таст, _ilić,
   {{0x3869b71f,0x60dbb720,0x63a3b721,0x05840138}},	//   nyar_, rcum, ponn, _турм,
   {{0x260802e8,0x60dbb722,0x386903e3,0x63a3026d}},	//   ांची_, scum, iyar_, qonn,
   {{0x2f5401b6,0xa3d9007f,0x00000000,0x00000000}},	//   ртыс, _ठंड_, --, --,
   {{0xed5a1803,0x518478ee,0x6b85010b,0x2b46020a}},	//   хом_, _куча, _amhg, _şoc_,
   {{0x644f1f9f,0xdced080e,0x0d830ff7,0x00000000}},	//   _ácid, _glač, слян, --,
   {{0x50b800cd,0xdcef00d9,0xdee2192f,0x213d02a1}},	//   _شدند_, ficē, _лоши, _hawh_,
   {{0x201f42dd,0xaaa400c3,0x00000000,0x00000000}},	//   ltui_, _खुशक, --, --,
   {{0x261c09e9,0x673cb723,0x213fb724,0xb886030b}},	//   vío_, _sarj, nduh_, hlíž,
   {{0x38690068,0x81bc0029,0x656002bc,0xdce400e7}},	// [dce0] gyar_, _spēk, _romh, _alić,
   {{0x6560b725,0x636f13c8,0x261c24c7,0x00000000}},	//   _somh, _sønn, tío_, --,
   {{0x673cb726,0x201f00c2,0xa96a00ae,0xa3c91178}},	//   _varj, htui_, _зина_, ोदन_,
   {{0x644202e5,0x261c04d8,0x386967c9,0x14c800cd}},	//   tvoi, río_, byar_, نهای_,
   {{0x673cb727,0x644245b0,0x7bd601c2,0x39400167}},	//   _tarj, uvoi, _juyu, mdis_,
   {{0x6442b728,0x7bd6b729,0x3940b72a,0x3a3a0154}},	//   rvoi, _muyu, ldis_, _kspp_,
   {{0xa3d4412e,0x6560b72b,0x644200c2,0x1dcf0d61}},	//   _सूर_, _tomh, svoi, _संगत,
   {{0xdcedb72c,0x7d04b72d,0xe5a61785,0x3a3a05aa}},	//   _plač, _ndis, _сиби, _mspp_,
   {{0x0443711a,0x637405fe,0xb8861054,0x1f741bc1}},	//   _летн, _cànc, blíž, илия,
   {{0x7d04b72e,0x85140336,0x25a6008c,0xeb9f00f2}},	//   _adis, _डाँट_, lool_, trøm_,
   {{0x4aa417ff,0x7bd601c2,0x2b1b1592,0x213f0063}},	//   _खुलव, _auyu, _बाबु_, bduh_,
   {{0xdced0618,0x7bd6b72f,0x38691114,0x7d040257}},	//   _tlač, _buyu, yyar_, _cdis,
   {{0x39400078,0x7d0425a3,0x60187775,0x00000000}},	//   ddis_, _ddis, _роля_, --,
   {{0x200b0038,0x25a6b730,0x7bd60587,0xdcef00e8}},	//   ácie_, hool_, _duyu, ticē,
   {{0x25a6b731,0x35d90251,0x333e00ee,0xb87b016d}},	//   kool_, _बूढ़, _matx_, _ofíc,
   {{0x79a70b21,0x7d0001cd,0x394001ce,0x00000000}},	//   урге, ómst, gdis_, --,
   {{0x7bd69de3,0xab871146,0xdce40357,0x56f50161}},	// [dcf0] _guyu, _бунк, _slić, ипаѓ,
   {{0x7c2db732,0x38697414,0x213f7b57,0x70d1277c}},	//   _ipar, ryar_, zduh_, _हल्ल,
   {{0x6dbc0067,0x386902fa,0x5a470d4f,0x9635018a}},	//   _właś, syar_, _сэпа, рнец,
   {{0x4a5a0054,0x8af801d4,0x7bd6b733,0x7c2d0294}},	//   _סדרו, _şəxs, _yuyu, _kpar,
   {{0x78fa004f,0x68ed47fd,0xbcfb0103,0x333e9740}},	//   _בפרו, mbad, lkés, _batx_,
   {{0x27e9b734,0x68edb735,0x69cf09ac,0x7c2d0169}},	//   mpan_, lbad, _hice, _mpar,
   {{0xe0d10080,0x2d8bb736,0xe4e70c10,0x27e9b737}},	//   يزة_, kice_, _бізн, lpan_,
   {{0x7c2db738,0x25a6b739,0x68ed793a,0x201f00c2}},	//   _opar, cool_, nbad, ttui_,
   {{0x2d8bb73a,0x26110251,0x27e9b73b,0x316daed0}},	//   dice_, दूरी_, npan_, rkez_,
   {{0x442db73c,0x201fb73d,0x333e01ff,0x7e250e06}},	//   _ipe_, rtui_, _gatx_, адож,
   {{0x201f6ebc,0x64490088,0x2d8b6f73,0x7bd6b73e}},	//   stui_, _hrei, fice_, _suyu,
   {{0x6da6b73f,0x7bd6048e,0x2d8bb740,0x27e974ab}},	//   рима, _puyu, gice_, kpan_,
   {{0x68ed0188,0x69d7b741,0x7529b742,0x442d01cb}},	//   dbad, _auxe, _mbez, _jpe_,
   {{0x442db743,0x27e90009,0x69cfb744,0x2d8b6c99}},	//   _mpe_, dpan_, _aice, éber_,
   {{0x75293df1,0x34b20b94,0x7bd601dc,0x00000000}},	//   _obez, _जर्द, _wuyu, --,
   {{0x2d8b0039,0x68ed0e34,0x6449b745,0x7bd60449}},	//   cice_, gbad, _orei, _tuyu,
   {{0x68431357,0x69cfb746,0x442d01bb,0x3940b747}},	// [dd00] онта, _dice, _npe_, rdis_,
   {{0x39404a19,0x68edb748,0x7bfb0266,0x25a60ac1}},	//   sdis_, abad, _שפיצ, wool_,
   {{0x442db749,0x7afcb74a,0x27e9048e,0x68edb74b}},	//   _ape_, mart, apan_, bbad,
   {{0x6449b74c,0x7afcb74d,0x39400063,0x442d9000}},	//   _brei, lart, qdis_, _bpe_,
   {{0x644978e9,0x69c4b74e,0x25a6223f,0x79960350}},	//   _crei, mmie, rool_, mnyw,
   {{0x64490bd8,0x200db74f,0x69c4b750,0x2d8bb751}},	//   _drei, drei_, lmie, zice_,
   {{0x200db752,0x442db753,0x63740013,0x6449b754}},	//   erei_, _epe_, _càna, _erei,
   {{0x6449b755,0x7afcb756,0x7996294f,0x200d01bf}},	//   _frei, hart, nnyw, frei_,
   {{0x6449b757,0x7afcb758,0x2d8bb759,0x200d0036}},	//   _grei, kart, vice_, grei_,
   {{0x2d8bb75a,0x69c4b75b,0x7afcb75c,0x29dc0143}},	//   wice_, hmie, jart, _oía_,
   {{0x7afc6ce9,0x3eb80572,0x7c2d4cda,0x68ed008c}},	//   dart, årt_, _spar, ybad,
   {{0x7af73884,0x200db75d,0x7c2da019,0x61eaae96}},	//   _sext, brei_, _ppar, mpfl,
   {{0x69cf0020,0x69c40038,0x2d8b0d94,0x69d70933}},	//   _rice, dmie, rice_, _suxe,
   {{0x7afcb75e,0xc90f1161,0x69cfb75f,0x69d72a96}},	//   gart, िल्म_, _sice, _puxe,
   {{0xd90f037f,0x69cfb760,0x3f8c4fa3,0x61ea0364}},	//   وید_, _pice, midu_, npfl,
   {{0x29dc11c4,0x3f8c7313,0x69d70149,0x7c292ddc}},	//   _día_, lidu_, _vuxe, çers,
   {{0x27e96ccc,0x98b9139c,0x69cf361a,0x00000000}},	// [dd10] upan_, улат_, _vice, --,
   {{0x7afca0ac,0x68edb761,0x69c4b762,0x29dc0072}},	//   cart, sbad, amie, _fía_,
   {{0x20020117,0xd6d82064,0x27e9b763,0x69cf6d04}},	//   ških_, рту_, span_, _tice,
   {{0x6449b764,0x27e94cea,0x3f8cb765,0x4518004d}},	//   _prei, ppan_, hidu_, иція_,
   {{0x798da58c,0xf95600a1,0x3f8c14f3,0x1dd000aa}},	//   miaw, _הסרת_, kidu_, _संघत,
   {{0x200d1043,0x083a00c1,0xe2990689,0x644901ce}},	//   vrei_, _געשל, лал_, _vrei,
   {{0x644900f0,0x2d891a3a,0x61ea042c,0x00000000}},	//   _wrei, _omae_, gpfl, --,
   {{0x7afcb766,0x798db767,0x200d1ada,0x7529b768}},	//   zart, niaw, trei_, _ubez,
   {{0x7afc0044,0x25ad003d,0x442db769,0x6449b76a}},	//   yart, _ikel_, _upe_, _urei,
   {{0x200d73d5,0x02a73a83,0x6374009c,0x69c4b76b}},	//   rrei_, _крем, _tàna, zmie,
   {{0x798d048e,0x69c4b3e2,0x63740032,0xbea5021b}},	//   kiaw, ymie, _kànn, санк,
   {{0xbc1a01b6,0x29dc08a8,0x200db76c,0xc69200ca}},	//   лігі_, _ría_, prei_, לאי_,
   {{0x7afcb76d,0x3f8cb76e,0x28a70179,0xdd12009e}},	//   tart, bidu_, _कुलि, _iżżi,
   {{0x3d1a13db,0x3f8c0580,0x69d80103,0x29dc002b}},	//   _भावे_, cidu_, _évek, _pía_,
   {{0x7afc009d,0xf2d200c1,0x09e63974,0x5f740604}},	//   rart, לעם_, собн, _ظاهر,
   {{0x29dc0fb6,0xe80302b0,0x69c41733,0x249f0231}},	//   _vía_, _लिखा_, umie, _oxum_,
   {{0x69c4b76f,0xa3c90469,0xab9a0286,0x00000000}},	// [dd20] rmie, ोदा_, _مخدر_, --,
   {{0x7afc150c,0x29dc22cd,0x69c4b770,0x25bf01c8}},	//   qart, _tía_, smie, _ahul_,
   {{0x671e34d8,0x7d7701f3,0x637d0139,0x69c400e8}},	//   _पाठक_, _ضمیر_, _kènf, pmie,
   {{0x25bfb5c4,0x893606f6,0x61fc01df,0xbcfb0103}},	//   _chul_, _اعدا, _ærli, nkép,
   {{0x23650b27,0xd5af33c6,0x2458345a,0x25bfb771}},	//   _bolj_, رفه_, раль_, _dhul_,
   {{0x98a2013f,0xeb9f052f,0x394203a9,0xdb07b772}},	//   _sakė_, rsøg_, _haks_, vojë,
   {{0x3f8c06e1,0x39420006,0x236500ae,0xbcfb0103}},	//   vidu_, _kaks_, _dolj_, kkép,
   {{0x7a430068,0xf5960080,0x61ea01bf,0x2ca0b773}},	//   lítá, _الرج, rpfl, _oxid_,
   {{0xdefa01b6,0x61ea0364,0x2bb900c3,0x00000000}},	//   лын_, spfl, _इठला, --,
   {{0x200bb774,0x74132296,0x394201df,0x200a0117}},	//   ácia_, _روما, _laks_, čbi_,
   {{0x3f8cb775,0x637401ec,0x39a100c6,0x2d990a61}},	//   ridu_, _hàno, lėse_, éreo_,
   {{0xa1c61312,0x3f8cb776,0x5fba34fd,0x39420270}},	//   _убед, sidu_, _उठवल, _naks_,
   {{0x39a1013f,0xb87bb777,0x7a430018,0x3f8cb778}},	//   nėse_, _afín, kítá, pidu_,
   {{0xab84014d,0x7a430103,0xa0070037,0x2ff700ae}},	//   пуск, jítá, _اقول_, _уншь_,
   {{0x798d048e,0x7de62296,0x42db006e,0x7a4301f9}},	//   tiaw, _استم, רקלע, dítá,
   {{0xb4d7023a,0x996400ae,0x00000000,0x00000000}},	//   _सले_, птул, --, --,
   {{0xa3d404dd,0xc6f95827,0x798d0479,0xc98411db}},	// [dd30] _संग_, инах_, riaw, чури,
   {{0x798d5aa9,0x2d990124,0xfb15001c,0x7a430103}},	//   siaw, lnse_, _بودج, gítá,
   {{0x58d53ac9,0x798d00a4,0xf7700037,0xb635450f}},	//   _монт, piaw, راك_, تفاع,
   {{0x2d999c13,0x39420063,0x637d03a9,0x00000000}},	//   nnse_, _gaks_, _kèng, --,
   {{0x23656fc9,0x68ff0092,0x2d99b779,0x6374015e}},	//   _polj_, maqd, inse_, _càno,
   {{0xc5fb00ab,0x63aa0150,0x637d01dc,0x394200c4}},	//   _معرض_, gofn, _mèng, _zaks_,
   {{0xdb1e01e5,0x39420167,0x637d03a9,0xe3b00037}},	//   _shpë, _yaks_, _lèng, رره_,
   {{0x212b272c,0x3fe56eb1,0x6009b77a,0x249f023e}},	//   ých_, ожив, аним_, _txum_,
   {{0x7767023e,0x4439b77b,0x636f0ac1,0x63740032}},	//   _kojx, _ès_, _løni, _kànl,
   {{0x443fa809,0x9397212c,0x00000000,0x00000000}},	//   _isu_, _اجرا, --, --,
   {{0x3eb900a5,0xbcfb01f9,0x00000000,0x00000000}},	//   ęsto_, tkép, --, --,
   {{0x443f0090,0x3cca08c3,0x69d80677,0x637d03a9}},	//   _ksu_, илно_, _évei, _bèng,
   {{0xbcfb0018,0x637d03a9,0x7a430103,0x00000000}},	//   rkép, _cèng, yítá, --,
   {{0x2d9903ee,0x7ae502a1,0x26e30179,0xbcfb0103}},	//   anse_, _cfht, गडोर_, skép,
   {{0xaa435cbb,0x7a430018,0x09e30a99,0x7f4303a4}},	//   мерл, vítá, досн, _ianq,
   {{0x443f026e,0x28ea0d62,0x7f43008c,0x00000000}},	//   _osu_, рдап_, _hanq, --,
   {{0x6d56271c,0xa76624ec,0xeb9a09f2,0x7a430103}},	// [dd40] _inya, окад, _вип_, títá,
   {{0x6d56006c,0x47c300d6,0x6d468426,0x3942b77c}},	//   _hnya, дбув, ldka, _waks_,
   {{0x443fb77d,0x7f43025a,0x3942b77e,0x95860769}},	//   _asu_, _manq, _taks_, олже,
   {{0x7a430068,0x6d440a00,0x68ff00a7,0x81e80033}},	//   sítá, _jaia, caqd, _বিল_,
   {{0x6d4402a7,0xa3d400c3,0x290020ac,0x6d5652cd}},	//   _maia, _सूख_, maia_, _mnya,
   {{0x29009740,0x6d4400aa,0x7f430231,0x39a100c6}},	//   laia_, _laia, _nanq, rėse_,
   {{0x443fb77f,0x26d80087,0x6d56b780,0x2d990313}},	//   _esu_, _igro_, _onya, ynse_,
   {{0x2900b781,0x443fb782,0x25081aaa,0x6d560517}},	//   naia_, _fsu_, _درسی_, _nnya,
   {{0x7f43b783,0x68e40072,0x2d99b784,0x98b9020a}},	//   _banq, icid, érem_, _iasă_,
   {{0x6d56b785,0x4426b786,0x6440b787,0x543b0130}},	//   _anya, mto_, _ismi, _דעמא,
   {{0x4426b788,0x6d560808,0x6d44b789,0xb87b0143}},	//   lto_, _bnya, _baia, _afíl,
   {{0x4426b78a,0x65624e63,0x6d44b78b,0x2d99028d}},	//   oto_, njoh, _caia, unse_,
   {{0x4426b78c,0x290001e9,0x98b900ae,0x26d80850}},	//   nto_, daia_, _masă_, _ogro_,
   {{0x44263884,0x98b900d3,0x68e43536,0xf41300ca}},	//   ito_, _lasă_, ecid, ופש_,
   {{0x442639f0,0x6d44b78d,0x2900b78e,0x195904d9}},	//   hto_, _faia, faia_, бавы_,
   {{0x4426b78f,0x6d440a00,0x2900b790,0x6d560270}},	//   kto_, _gaia, gaia_, _gnya,
   {{0xd6db82e2,0x47d50080,0x44260038,0xe87c008e}},	// [dd50] ате_, سيار, jto_, rüşü,
   {{0x44261098,0x27e60037,0x7d1d01df,0x443fb791}},	//   dto_, íona_, lgss, _rsu_,
   {{0x69da0018,0x95cb0077,0x6440b792,0xbb3a00ca}},	//   ítet, ауда_, _asmi, _העתי,
   {{0xdcef00d9,0x98b900d3,0x200401d3,0x4426b793}},	//   dicī, _casă_, ksmi_, fto_,
   {{0x764e02ad,0x44269427,0x78bd01d3,0x38c90504}},	//   _erby, gto_, _uzsv, _دادی_,
   {{0x25a602ef,0x93420120,0x638500c6,0x83880120}},	//   čola_, енше, ягла, обів_,
   {{0x4426b794,0x443f01c2,0x6440a791,0x63740139}},	//   ato_, _wsu_, _esmi, _gànm,
   {{0x443f023e,0x4426008a,0xf65200a1,0x68fd0124}},	//   _tsu_, bto_, _אצל_, _jesd,
   {{0x442611d1,0xf8b90f62,0x443f00aa,0x68fdb795}},	//   cto_, _आरोप, _usu_, _mesd,
   {{0x6d440a00,0x68fdb796,0x657b02ac,0x28be08c0}},	//   _saia, _lesd, _hluh, ्धति,
   {{0x2f5402ec,0x6d56005c,0x9d46002d,0x6605023b}},	//   єтьс, _pnya, пенд, nshk,
   {{0xb2ba00a1,0xd00e12eb,0xdca61f5d,0x65690381}},	//   _המער, خلی_, зами, _joeh,
   {{0x6d440f61,0xe6b8022d,0xd7bd0096,0x65696b11}},	//   _vaia, _अर्ज, ्गाच, _moeh,
   {{0xf99f0065,0x6d440350,0x7c26b797,0x6569009c}},	//   _ajè_, _waia, rtkr, _loeh,
   {{0x637d6ab6,0x4426298d,0xa3d42f4f,0x6d4400d3}},	//   _gène, zto_, _संघ_, _taia,
   {{0x6d5660fd,0x4426b798,0xb87b0575,0x6f0101c2}},	//   _unya, yto_, _efím, lalc,
   {{0x68fd132d,0x4426132d,0x38c800bf,0x68e4b799}},	// [dd60] _desd, xto_, زاری_, rcid,
   {{0x6f011419,0x68e4b79a,0x69da26ca,0x46a6008f}},	//   nalc, scid, ítes, пазв,
   {{0x4426b79b,0x2900b79c,0x657b0090,0x7c65001c}},	//   wto_, paia_, _bluh, _فایل,
   {{0x44260a5f,0xe45a00d6,0x63740032,0x0566008f}},	//   tto_, йже_, _gànj, явен,
   {{0x4426b79d,0x69deb79e,0x6f010aa0,0x7afe0138}},	//   uto_, _hupe, kalc, _kept,
   {{0x6f0102dd,0x69deb79f,0x7afeb7a0,0x68fd029a}},	//   jalc, _kupe, _jept, _zesd,
   {{0x877b0130,0xdb1e3916,0x6f01033b,0x69de73b1}},	//   _פאלי, _hipó, dalc, _jupe,
   {{0x4426aef9,0x7afe00cc,0x657b1cb4,0x69de56b0}},	//   pto_, _lept, _gluh, _mupe,
   {{0x6f01b7a1,0xe5a3002d,0x64408077,0xdced00c4}},	//   falc, _чити, _usmi, _hlać,
   {{0x43860241,0x32463dba,0x386000ee,0x69be00b7}},	//   _علاق, _незг, ixir_, _वीसी,
   {{0x628300a5,0x69deb7a2,0xe8b90096,0x00000000}},	//   czno, _nupe, _आर्च, --,
   {{0x06970054,0xdced0357,0x637d7c05,0x00000000}},	//   לדים_, _mlać, _vène, --,
   {{0x0cab013d,0x68fdb7a3,0x69de01b9,0x7d1db7a4}},	//   стни_, _resd, _aupe, rgss,
   {{0x9a874460,0x6f0193a4,0x7f5808e5,0x20020138}},	//   публ, calc, _факс_, škis_,
   {{0x27e6054f,0x69deb7a5,0x3f8e0169,0x7afe00ca}},	//   íonn_, _cupe, _imfu_, _dept,
   {{0x319700d3,0x7de100e8,0x00000000,0x00000000}},	//   tăzi_, _mēsl, --, --,
   {{0xa3cc04a9,0x52d00081,0x7d0dae49,0x3e820154}},	// [dd70] रगा_, _স্মৃ, _idas, _fété_,
   {{0x65690194,0xb8830579,0xdced080e,0x69de0113}},	//   _soeh, vníč, _blać, _fupe,
   {{0x7bdf0abd,0xcb12040a,0x68fd235a,0x637d0428}},	//   _huqu, _בלי_, _tesd, _lènc,
   {{0x660500dd,0x7afe030b,0x6f010117,0x636f0537}},	//   rshk, _zept, zalc, _lønt,
   {{0xd0060e25,0xf8b10260,0x395920df,0x69de0034}},	//   _جل_, _شکر_, _inss_, _zupe,
   {{0x8c1c0054,0xdb1e0428,0xb8830146,0x7bdfb7a6}},	//   מודי, _hipò, rníč, _muqu,
   {{0x6f010b27,0x7d0d01e8,0x3949b7a7,0x69d8016d}},	//   valc, _odas, odas_, _évet,
   {{0x7d0db7a8,0x657bb7a9,0x6f01783f,0x00000000}},	//   _ndas, _uluh, walc, --,
   {{0x628300fb,0x394927a8,0x7bdf73a6,0x00000000}},	//   szno, idas_, _nuqu, --,
   {{0x7d0db7aa,0x8e09142f,0xdb1c0c2e,0x3949b7ab}},	//   _adas, онов_, områ, hdas_,
   {{0x6da60c58,0x7afeb7ac,0x63a4317d,0x6f010087}},	//   дина, _rept, éine, ralc,
   {{0xcb091723,0x7bdf60d3,0xed5a2c59,0x82340688}},	//   _כל_, _buqu, цом_, _سرما,
   {{0x3949236c,0x7bd70072,0x671e1fbb,0x20020a39}},	//   ddas_, _bixu, _पालक_, škir_,
   {{0x7d0d0006,0x3949b7ad,0x7bd7002b,0x69deb7ae}},	//   _edas, edas_, _cixu, _pupe,
   {{0x636f00f2,0x7bdf0231,0x00000000,0x00000000}},	//   _høns, _euqu, --, --,
   {{0x7bd7015e,0x636f02b6,0x7bdf2454,0x00000000}},	//   _eixu, _køns, _fuqu, --,
   {{0xdb1e0428,0xdced0095,0x7bdf063d,0xb95b00fe}},	// [dd80] _dipò, _slać, _guqu, _thìn,
   {{0xdced02e6,0x636f038c,0x69deb7af,0x3946129d}},	//   _plać, _møns, _tupe, žos_,
   {{0x636f01df,0xa96a3028,0x2b5a0231,0xeb9f09af}},	//   _løns, _дина_, _inpc_, prør_,
   {{0x3959009e,0xdb1e0072,0x00000000,0x00000000}},	//   _gnss_, _tipó, --, --,
   {{0x7bdf008a,0xe8f71c32,0x8835002d,0xd4670284}},	//   _xuqu, _юля_, _пэрц, мице_,
   {{0x68f6579f,0x533307c8,0x637d0113,0x7bd701ff}},	//   lbyd, вешт, _rènc, _xixu,
   {{0xd25002fc,0x69d80103,0x636f00f2,0x00000000}},	//   انب_, _éves, _rønt, --,
   {{0x3d1a3d34,0x071e0251,0x6374015e,0x3d18007f}},	//   _भागे_, _पाँव_, _màni, थलों_,
   {{0x6374015e,0x00000000,0x00000000,0x00000000}},	//   _làni, --, --, --,
   {{0x3e4c00b6,0x39490138,0x637d015e,0x7bdf16d5}},	//   _pět_, zdas_, _vènc, _ruqu,
   {{0x7bdf00ee,0x4e8a00c2,0x7c3600c6,0x394900c6}},	//   _suqu, ющим_, _apyr, ydas_,
   {{0x2b5a00ae,0xdb0702c6,0x161f0285,0x7bd75d6f}},	//   _anpc_, rojí, मंतर_, _sixu,
   {{0x071e009f,0x321c0220,0x68f6b7b0,0x7bd7044c}},	//   _पांव_, luvy_, dbyd, _pixu,
   {{0xdb070094,0x60c2b7b1,0x69c6007b,0xdb1e02f1}},	//   pojí, _izom, _ahke, _sipò,
   {{0x3f9e063d,0x7bdf0063,0xdb1e0154,0x7e8602c6}},	//   mntu_, _wuqu, _pipò, úspě,
   {{0xf7700979,0x7bdf010a,0x63740139,0x7d0d02a4}},	//   یال_, _tuqu, _dàni, _udas,
   {{0xe89402fd,0x39490358,0xb907417a,0x2486015c}},	// [dd90] вать, rdas_, _पल_, jzom_,
   {{0x3949b7b2,0xbc380f98,0x2a6e0216,0x236c0372}},	//   sdas_, _آسيا_, ëmbë_, _nodj_,
   {{0x68f60113,0xaa95002d,0x39492791,0xb6070023}},	//   bbyd, _чинч, pdas_, _giớ,
   {{0x2a7600ca,0xcdd9006e,0xb60702a1,0x60c20372}},	//   _נערך_, פֿער, _ruġġ, _ozom,
   {{0xc91600a1,0xb60703e5,0x43951486,0x69cd01df}},	//   _אחרת_, _suġġ, надс, mmae,
   {{0x8c1c0089,0x59bf0789,0xb87b0065,0x637d022b}},	//   קווי, ्षवर, _agíg, _bèna,
   {{0x6d1f04f1,0xd6690308,0x60c2101e,0xf52717e9}},	//   _भांग_, _عمرو_, _azom, _офан,
   {{0x3f9e00d9,0x7dde00d9,0x69cd0178,0x00000000}},	//   entu_, _mūsd, nmae, --,
   {{0x4f95249c,0x65945e39,0xf1df09a1,0x9f5f0131}},	//   ерну, _рату, _पूरन, ssuí_,
   {{0x9e6504c9,0x60c20a39,0x80c40179,0x6ade11b5}},	//   евод, _dzom, ाइजे, _मलेर,
   {{0x7c36af46,0xa3cc0251,0xc7b200a1,0x59db3aee}},	//   _spyr, रगर_, רבי_, _मंगर,
   {{0xf2df00ef,0x636f0120,0xf67a006e,0x3f9e0bf0}},	//   _đây_, _tøns, פארמ, antu_,
   {{0x61e11f30,0x636f01df,0x3f9e010a,0xeb9f0537}},	//   _hull, _uøns, bntu_, rsøn_,
   {{0x61e1b7b3,0x69c601e5,0xbea505b6,0x2d82023b}},	//   _kull, _shke, _палк, shke_,
   {{0x61e10db8,0xfaa3013f,0x00000000,0x00000000}},	//   _jull, гаро, --, --,
   {{0x61e1b7b4,0xe9d701a0,0xa967182e,0x98a000c4}},	//   _mull, екс_, ниса_, nfić_,
   {{0x7d06b7b5,0x61e109aa,0x68f68e69,0x2d8000ae}},	// [dda0] maks, _lull, rbyd, _ilie_,
   {{0x7d063d7a,0x4a4600d6,0xee4900fe,0x637400b3}},	//   laks, _знов, _kẽ_, _tàni,
   {{0x61e1b7b6,0xb87b0032,0x98b9548b,0x00000000}},	//   _null, _agíd, _masę_, --,
   {{0x09e70081,0x84e60426,0xee4900de,0xceb20266}},	//   _ফিচা, ходж, _mẽ_, ניא_,
   {{0xee490019,0x61e1b7b7,0xf9f20033,0xe660013c}},	//   _lẽ_, _aull, _জটিল_, ırığ,
   {{0x533422f9,0x7d061d2d,0x8c1b00ca,0xa294224a}},	//   тект, haks, פוצי, калі,
   {{0x2d80544a,0x60c20018,0xdbc700aa,0x2d92010a}},	//   _olie_, _szom, _tööj, _omye_,
   {{0x61e1b7b8,0xd65700a1,0x7d064b2c,0xae0900c3}},	//   _dull, _אילת_, jaks, _विजन_,
   {{0x64a30fe9,0x23e800d1,0x00000000,0x00000000}},	//   _бата, _آذری_, --, --,
   {{0x61e1012a,0x75220068,0x2d920172,0x2d80b7b9}},	//   _full, lgoz, _amye_, _alie_,
   {{0x61e10bd8,0x3eb85ec1,0x9d190ed1,0xe0da0396}},	//   _gull, ært_, монт_, _еве_,
   {{0x290203ce,0x7522b7ba,0x869b0266,0x673e01cb}},	//   _neka_, ngoz, לייז, hepj,
   {{0x61e10ab2,0x79840010,0xe7b0007f,0xdcbb00e5}},	//   _zull, dhiw, जकाप, ящо_,
   {{0x2d80b7bb,0x00000000,0x00000000,0x00000000}},	//   _elie_, --, --, --,
   {{0x61e122e7,0x6d960029,0x2902b7bc,0xf9c730cf}},	//   _xull, mšan, _beka_, ещан,
   {{0x661e005a,0xdd910688,0x7d06b7bd,0xf77300cd}},	//   dupk, _خوب_, caks, گار_,
   {{0x69cd1484,0x3dc90270,0x00000000,0x00000000}},	// [ddb0] rmae, _ihaw_, --, --,
   {{0xf7732761,0x200b0220,0x6da42461,0x69d8028d}},	//   دار_, ácii_, nđan, _èven,
   {{0x3dc901fa,0xcf9300c1,0x661e005c,0x57a41009}},	//   _khaw_, נטע_, gupk, ушта,
   {{0x7984b7be,0x75220172,0x00000000,0x00000000}},	//   chiw, ggoz, --, --,
   {{0x61e1b7bf,0x04454e26,0x6d960029,0xb95400a9}},	//   _sull, телн, kšan, _свящ,
   {{0x6d9602dd,0x7d06032f,0x61e1b7c0,0x2902b7c1}},	//   jšan, zaks, _pull, _zeka_,
   {{0x85bb1790,0x61e100a7,0x7d0602f1,0x29020201}},	//   _فارس_, _qull, yaks, _yeka_,
   {{0x205551d0,0x61e1b7c2,0x6d9637e6,0xee490023}},	//   втор, _vull, ešan, _rẽ_,
   {{0xee4900ef,0x7d0671af,0x200b3210,0x7f19036c}},	//   _sẽ_, vaks, éci_, міну_,
   {{0x61e1a001,0x765500a5,0x6d9601d3,0x79960201}},	//   _tull, _krzy, gšan, ziyw,
   {{0x7d0605a7,0x3ea52124,0xbea55b6c,0x4ed4004d}},	//   taks, тинг, танк, люют,
   {{0x3dc901bb,0xed5700d6,0xee490019,0xdb070094}},	//   _chaw_, вою_, _vẽ_, vojá,
   {{0x7d060b4b,0x2902b7c3,0xfebb010d,0x3dc90188}},	//   raks, _reka_, _کاشت_, _dhaw_,
   {{0x2902b7c4,0x27e200e7,0xdee2004d,0x7bce024a}},	//   _seka_, _rukn_, _коши, umbu,
   {{0x7d0696aa,0x79842123,0x7bce023b,0x394bac08}},	//   paks, thiw, rmbu, _bacs_,
   {{0xdb071515,0x3cb300ac,0x6f0300d7,0x7bd903a9}},	//   rojá, ụzụ_, _henc, _èwun,
   {{0x6f0326f7,0x1b1700c7,0x29022611,0x66e603a6}},	// [ddc0] _kenc, দ্ধে_, _veka_, воза,
   {{0x79848ac0,0x7d040a81,0x290281fe,0x661eb7c5}},	//   shiw, _heis, _weka_, tupk,
   {{0x6f03b7c6,0x2902b7c7,0x7d040f6b,0xf7432917}},	//   _menc, _teka_, _keis, рехо,
   {{0x7d0401c8,0x00000000,0x00000000,0x00000000}},	//   _jeis, --, --, --,
   {{0x661e0167,0x213f0167,0x3940b7c8,0x76550113}},	//   supk, deuh_, meis_, _erzy,
   {{0xf6510018,0x394027cd,0x7d049664,0x66e619e8}},	//   جئے_, leis_, _leis, _јова,
   {{0x76550034,0xcb1300ca,0xf1a60846,0x00000000}},	//   _grzy, בלו_, крин, --,
   {{0x3253008f,0x00000000,0x00000000,0x00000000}},	//   рвър, --, --, --,
   {{0xf9937c04,0x637d00ee,0x30a600e5,0x00000000}},	//   ירה_, _gèno, ъркв, --,
   {{0xd378b7c9,0x394001b5,0x6f0385fa,0x7f4a0092}},	//   _biće_, heis_, _cenc, _qafq,
   {{0x7d0402e2,0x826600bf,0x6d961dfc,0x6f034fa8}},	//   _beis, _جهان, ršan, _denc,
   {{0xac193e04,0x7d040e5c,0x61460831,0x765800c2}},	//   ному_, _ceis, _једа, ävyy,
   {{0x7d0432cc,0x6d9600d9,0x39400487,0x9f3400c6}},	//   _deis, pšan, deis_, _белі,
   {{0x394b9d1f,0x6f03b7ca,0x7dde01d3,0xd378007e}},	//   _sacs_, _genc, _bīst, _fiće_,
   {{0x9e3402fd,0x2d99b7cb,0x2e4a008f,0x39400381}},	//   _сейч, éres_, _цяло_, feis_,
   {{0x7d042b90,0x3dc906a8,0x6f0370ab,0x2ca91848}},	//   _geis, _uhaw_, _zenc, _txad_,
   {{0x2d9905a7,0x6d5f97a8,0x08552787,0x00000000}},	// [ddd0] mise_, _inqa, ываю, --,
   {{0x76550d1b,0x7d04b7cc,0x2d990fda,0x9f4d016d}},	//   _przy, _zeis, lise_, mpeã_,
   {{0x3940b7cd,0x2d99b7ce,0xb9240174,0x6d960995}},	//   beis_, oise_, _jesụ_, kšal,
   {{0x2d99b7cf,0x39403884,0xa97900c1,0x6d96033b}},	//   nise_, ceis_, _נאָכ, jšal,
   {{0xa2d50285,0x68ed008c,0x7c2d00bd,0x69dd039f}},	//   येन्, mcad, _jqar, _iise,
   {{0x2d99b7d0,0x69dd5f08,0x765500a5,0xd37b0012}},	//   hise_, _hise, _trzy, ьче_,
   {{0x69ddb7d1,0x6f03b7d2,0xdb070088,0x2d99109a}},	//   _kise, _renc, lljó, kise_,
   {{0x6f03b7d3,0xb145002d,0x69dd237d,0x527436c5}},	//   _senc, унил, _jise, рушу,
   {{0x6f03117e,0x7d04b7d4,0x2d99b7d5,0x3f850150}},	//   _penc, _reis, dise_, thlu_,
   {{0x7d04b7d6,0x69ddb7d7,0x6d5f003d,0xd3781419}},	//   _seis, _lise, _anqa, _piće_,
   {{0x69ddb7d8,0x2d99b7d9,0x7d04b7da,0x518700d3}},	//   _oise, fise_, _peis, _иуда,
   {{0x69ddb7db,0x63ad00e3,0x7de800b6,0x2d9911c8}},	//   _nise, éanf, _těsn, gise_,
   {{0x39404cfb,0x7d04b7dc,0x442f009c,0x6f0370e7}},	//   veis_, _veis, ntg_, _tenc,
   {{0x7d0402e2,0x69dd9c13,0x200b0220,0x2d99637d}},	//   _weis, _aise, áciu_, érer_,
   {{0x7d04b7dd,0x69ddb7de,0x81e50081,0x2d99b7df}},	//   _teis, _bise, বীর_, bise_,
   {{0x2d99b7e0,0x69ddb7e1,0x6449b7e2,0x5c960076}},	//   cise_, _cise, _osei, _مؤخر,
   {{0x07a60077,0x3940b7e3,0x200db7e4,0x442d0197}},	// [dde0] гаан, reis_, nsei_, _nqe_,
   {{0x69ddb7e5,0x68edb7e6,0x3940b7e7,0x200d016d}},	//   _eise, acad, seis_, isei_,
   {{0x7bde00f9,0x3940b7e8,0x4b7b006e,0x69ddb7e9}},	//   _iipu, peis_, _נאטו, _fise,
   {{0x69dd1103,0xc4860084,0x1a9b006e,0x05ba0dd0}},	//   _gise, ллек, _טייע, ردات_,
   {{0x7bdeb7ea,0x7f410052,0x6e210364,0xf8b800c3}},	//   _kipu, kelq, hulb, _आडिय,
   {{0x66e30d6f,0x2d99b7eb,0x69dd019f,0x987b006e}},	//   _гора, zise_, _zise, _טאכט,
   {{0x442f0124,0x63745493,0x2d99019b,0xf1c90094}},	//   atg_, _bànr, yise_, znáš_,
   {{0x7bde07ac,0xdb0e0094,0x637d022b,0x30141543}},	//   _lipu, dobí, _jènj, адир,
   {{0x65600037,0x6d9678ee,0x442d010a,0x6da40095}},	//   _inmh, ršal, _gqe_, rđal,
   {{0x2d99b7ec,0x7bdeb7ed,0xeb9f00d6,0x91e667cb}},	//   wise_, _nipu, rsøk_, _боже,
   {{0x2d99b7ee,0x7c2d023b,0x6e21b7ef,0x6f081670}},	//   tise_, _sqar, gulb, radc,
   {{0x7bde01c8,0x63740139,0x00000000,0x00000000}},	//   _aipu, _gànr, --, --,
   {{0x2d99b7f0,0x69ddb7f1,0x7bde0294,0x3cf409a1}},	//   rise_, _rise, _bipu, ंड़े_,
   {{0x2d99b7f2,0x69ddb7f3,0x09bf05a5,0xdfd000e3}},	//   sise_, _sise, ्ष्य, _بيت_,
   {{0xf0b000fb,0x7bde072f,0x637d0113,0x00000000}},	//   _دیکھ, _dipu, _bènj, --,
   {{0xd5a40018,0x2e130dce,0x442f0036,0x2d99b7f4}},	//   _رہ_, _ابوح, ytg_, qise_,
   {{0x69dd6d6c,0xb87b0032,0x8ccb0034,0xdb0700ce}},	// [ddf0] _vise, _afír, सेखो, tojä,
   {{0xe8ff04ea,0x78bd025b,0x7bdeb7f5,0xe71900e3}},	//   _août_, _vysv, _gipu, ئيات_,
   {{0xdced6a54,0xe7ea0034,0x78bd084e,0x00000000}},	//   _hlađ, _झूठा_, _wysv, --,
   {{0xe8ff0257,0xe8df0174,0xdced0106,0x85040781}},	//   _coût_, _klọb_, _klađ, مومن,
   {{0x232928b9,0x00000000,0x00000000,0x00000000}},	//   воли_, --, --, --,
   {{0xdced02e6,0xe299188d,0x22151e9e,0x9d970294}},	//   _mlađ, кал_, афир, ụahị,
   {{0x442fb7f6,0x45d5007b,0x00000000,0x00000000}},	//   stg_, _вовс, --, --,
   {{0x200d007a,0xe8ff0257,0x644950dc,0xdb150052}},	//   tsei_, _goût_, _tsei, fozë,
   {{0x644902fd,0x9f850fe3,0x3cf40789,0x60060138}},	//   _usei, игид, ंडसे_, аным_,
   {{0x38691f32,0x200db7f7,0xdfce00d1,0xe9df033c}},	//   ixar_, rsei_, ويي_, _liú_,
   {{0x8d660423,0x7bdeb7f8,0x200d1143,0x02a711d9}},	//   авне, _ripu, ssei_, _срам,
   {{0x200d00ae,0x7bdea53c,0xdb0e0094,0x7f4100ee}},	//   psei_, _sipu, robí, selq,
   {{0x0c232dfb,0x6e210009,0x26050096,0xdb0e0a7f}},	//   омян, sulb, हीती_, sobí,
   {{0x6a86302e,0x7df3020a,0xc332006e,0x6e21630c}},	//   алга, _răsf, ֿון_, pulb,
   {{0xf8bf0649,0x7bde1c24,0xaa46007b,0xa92802c6}},	//   _ayé_, _vipu, шевл, _nežá,
   {{0xd37833db,0xe9df033c,0x316d078e,0x317f01ff}},	//   _mića_, _ciú_, njez_, nkuz_,
   {{0x7bde7142,0x8c460978,0xdced0477,0xa2d505d6}},	// [de00] _tipu, _тепе, _glađ, येत्,
   {{0xdced0090,0x6abe0381,0xf77f9767,0x46f653c8}},	//   _imaġ, _typf, _puça_, рчат,
   {{0xdd8f00bf,0xe9df0b05,0x81ab0033,0x7d1602c6}},	//   _روی_, _fiú_, _গঠন_, _kdys,
   {{0x2bb405d4,0x26170251,0x14c8001c,0x63740428}},	//   ंकवा, _पटरी_, ههای_, _rànq,
   {{0x9346389b,0xd4031612,0x00000000,0x00000000}},	//   инде, оящи, --, --,
   {{0xd378005f,0xa6ca0231,0xd3b7004d,0x3952004b}},	//   _bića_, _алга_, алії_, ldys_,
   {{0xe81e1687,0x6d96031a,0x46a33c1f,0x6da40095}},	//   यंका_, ršaj, _дарв, rđaj,
   {{0x39524848,0x26ca077e,0x316d0052,0x39a100c6}},	//   ndys_, _izbo_, gjez_, tėsi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1be12172,0xd3780095,0x395200c2,0x7d16030a}},	//   _गूगल_, _fića_, hdys_, _adys,
   {{0xdcebac77,0xdced0a9e,0x63b8b7f9,0x6b9cb7fa}},	//   šiča, _slađ, movn, dirg,
   {{0x63b8b7fb,0x25a602ad,0xed65013c,0x00000000}},	//   lovn, nnol_, _şöbə_, --,
   {{0x7d160150,0x8fa6180b,0x637d0113,0x3952807c}},	//   _ddys, _каде, _bènh, ddys_,
   {{0x2cad03e5,0x798603e3,0xa3cc02d5,0x61e8019f}},	//   ħed_, _alkw, रगट_, _kudl,
   {{0xb3450396,0xda78008f,0x224cb7fc,0x09070fec}},	//   leçã, аят_, _jsdk_, ичам,
   {{0x7de10029,0x63b86b32,0x61e802a1,0xf8bf0154}},	//   _vēst, hovn, _mudl, _pyé_,
   {{0x63b819d0,0x6b9c39c6,0x26c5574a,0x61e8063d}},	// [de10] kovn, birg, _šlo_, _ludl,
   {{0xf0d20134,0x63b80146,0x38690428,0x25a600f0}},	//   _aịkọ, jovn, rxar_, enol_,
   {{0xd6db0465,0x61e84d6c,0x00000000,0x00000000}},	//   тта_, _nudl, --, --,
   {{0xe94500cd,0x25a6b7fd,0x3ed9006e,0x00000000}},	//   _اردی, gnol_, אַנא, --,
   {{0xe81e0c13,0xf0d20134,0xb3450161,0xd3780218}},	//   _पिया_, _dịkọ, jeçã, _sića_,
   {{0xd3780039,0x63b80087,0x61e8063d,0xf1df1677}},	//   _pića_, govn, _budl, _पूजन,
   {{0x637d03a9,0x00000000,0x00000000,0x00000000}},	//   _jèni, --, --, --,
   {{0x016500c9,0x61e8b7fe,0x6b9c0e26,0xf3ff0131}},	//   скио, _dudl, zirg, _ção_,
   {{0x63b80094,0x753b23d1,0x637d00b3,0xdb0e0103}},	//   bovn, _ibuz, _lèni, őkés,
   {{0x63b80871,0x23740080,0x443fb7ff,0x645bb5f0}},	//   covn, _والح, _ipu_, _irui,
   {{0x1d0a0fa5,0x69cf05db,0x61e8b800,0x00000000}},	//   лени_, _ohce, _gudl, --,
   {{0x645bb421,0x443fb801,0xf77f0131,0x6da642c7}},	//   _krui, _kpu_, _ouço_, сима,
   {{0x753ba5f6,0xb345016d,0x6b9cb802,0x443f0085}},	//   _mbuz, ceçã, tirg, _jpu_,
   {{0xf1b9b803,0x443fb804,0x7f85001c,0xdefb00ae}},	//   loš_, _mpu_, _دلتن, _рыд_,
   {{0x25a602ad,0x753b0517,0x7df300d3,0xed5a37a8}},	//   ynol_, _obuz, _băse, _бой_,
   {{0x69cf73fd,0x2d8b025b,0xfaa33c97,0x637d001c}},	//   _chce, chce_, часо, _dèni,
   {{0xf1df0ed3,0x443f5c59,0x8d7609e5,0x25a600de}},	// [de20] _पूछन, _npu_, _ناکا, vnol_,
   {{0x753bb805,0x4b2600f7,0x6d46b806,0x9b460f36}},	//   _abuz, _умов, leka, _اندو,
   {{0xe61a4a53,0xf1b90357,0x645b009c,0xd9462796}},	//   уде_, koš_, _arui, _лени,
   {{0x645b10c2,0x7df300d3,0xf7ea0037,0xd5b9004d}},	//   _brui, _găse, _مرسى_, асі_,
   {{0x2900b807,0x63b819ad,0x61e8019c,0x69c4b808}},	//   mbia_, tovn, _sudl, mlie,
   {{0x645ba5ab,0x6d46b809,0x2605009d,0x29000138}},	//   _drui, heka, हीही_, lbia_,
   {{0x63b80871,0x645b0126,0x443f00dc,0x6d5a01d3}},	//   rovn, _erui, _epu_, ētaj,
   {{0x6d4603ce,0xb3450396,0xa91b0088,0xf1b90095}},	//   jeka, teçã, _alþj, goš_,
   {{0x645bb80a,0x63b80106,0xc95300ca,0x63ad00fd}},	//   _grui, povn, למה_, éanc,
   {{0x69c402dc,0xb345001f,0x61e82a0b,0x4426b80b}},	//   hlie, reçã, _tudl, muo_,
   {{0xdceb13e8,0x69c4b80c,0x6d460172,0x44267475}},	//   žičn, klie, feka, luo_,
   {{0x443f0063,0xd3780357,0xf1b900c4,0xd00a0b0a}},	//   _ypu_, _kićo_, coš_, _беде_,
   {{0x442600e9,0x69c4b80d,0x7c264da8,0x637d015e}},	//   nuo_, dlie, gukr, _sèni,
   {{0x69c402ac,0xd378031a,0x60c2b80e,0x61e2033c}},	//   elie, _mićo_, _iyom, _hiol,
   {{0x6d46b80f,0x3f9eb810,0x98b0003d,0x60c20da7}},	//   beka, mitu_, _ħaġa_, _hyom,
   {{0x69c40465,0x3f9e7465,0x64400167,0x60c2a540}},	//   glie, litu_, _opmi, _kyom,
   {{0x7d0f244c,0x61e20956,0x44260134,0xdb0e0e4b}},	// [de30] macs, _miol, juo_, sobá,
   {{0x4426b811,0x3f9eb41b,0x7d0fb812,0x637d03a9}},	//   duo_, nitu_, lacs, _tèni,
   {{0x69c443e9,0x2900008f,0x644001d3,0x60c2010a}},	//   blie, bbia_, _apmi, _lyom,
   {{0xd6d8272a,0x7d0f0694,0x442680a9,0x3f9e0a00}},	//   сту_, nacs, fuo_, hitu_,
   {{0x60c20068,0x4426b813,0x3f9eb814,0xd4690a29}},	//   _nyom, guo_, kitu_, риле_,
   {{0x6d46b815,0xe81e2010,0x27eb7c82,0xcec300b6}},	//   zeka, _पिता_, _iucn_, _jiří_,
   {{0x3f9eb816,0x2d821484,0x1dc9009d,0x6d461e24}},	//   ditu_, ykke_, रतात, yeka,
   {{0x4426b817,0x753b271c,0x798d265b,0x201f29c0}},	//   buo_, _ubuz, nhaw, trui_,
   {{0x61e2b818,0xf1b90e94,0x44260b21,0x25bf03e3}},	//   _diol, roš_, cuo_, _ikul_,
   {{0x3f9e82a2,0x69c40029,0x6d46b819,0x7df300d3}},	//   gitu_, zlie, weka, _născ,
   {{0x27e326f1,0x6d469092,0xa1195e51,0x798db81a}},	//   _mijn_, teka, _نقاط_, khaw,
   {{0x27e30126,0x798d01bb,0x68e20138,0x61e25ded}},	//   _lijn_, jhaw, žodi, _giol,
   {{0x6d462bff,0x3f9eb81b,0xef0e426e,0x798db81c}},	//   reka, bitu_, _ом_, dhaw,
   {{0x7c261d1e,0x3f9e2efd,0x29190090,0x61e2b81d}},	//   rukr, citu_, _adsa_, _ziol,
   {{0x44260129,0x7d0fb81e,0x290bb81f,0x6d4687c8}},	//   zuo_, bacs, _beca_, peka,
   {{0xddc3453b,0x290bb820,0xe8fa5e39,0x798db821}},	//   _общи, _ceca_, рла_, ghaw,
   {{0x290bb822,0xb4c80ff9,0x92c50033,0x8bf10033}},	// [de40] _deca_, _उरे_, _এলো_, জীবন_,
   {{0x2900022b,0x69c4b823,0x291907ac,0xb6a6075f}},	//   sbia_, slie, _edsa_, оизл,
   {{0x69c408da,0x798db824,0xfa6a0c2b,0x290b0639}},	//   plie, bhaw, _танк_, _feca_,
   {{0x4426b825,0x2e3a00c1,0xe45a3f6c,0x3f9e7218}},	//   tuo_, יגענ, иже_, zitu_,
   {{0x27e30126,0x20190146,0x61e201cb,0x136a6e52}},	//   _fijn_, ásil_, _riol, ишки_,
   {{0x442652d7,0xd7c5009d,0x925a00e3,0x61e2b826}},	//   ruo_, वतःच, لشعر_, _siol,
   {{0x63ad054f,0x3f9e16aa,0x66d00065,0x09bd0033}},	//   éana, vitu_, _dókí, _আওতা,
   {{0x27e34ff3,0x44264479,0xca7b0142,0x00000000}},	//   _zijn_, puo_, ינצט, --,
   {{0x4426b827,0x3f9eb828,0x232a16d9,0x00000000}},	//   quo_, titu_, _вози_, --,
   {{0x60c20010,0xdfd000e3,0xaac000c0,0xe29a002d}},	//   _vyom, عيد_, _शुभक, _каз_,
   {{0x3f9eb829,0xddc90138,0x7df3020a,0xdb070216}},	//   ritu_, rydž, _răsc, snjë,
   {{0x9c130134,0x3dd2030a,0xc05a0120,0x00000000}},	//   _jọgb, _chyw_, _вік_, --,
   {{0x9ccb0138,0x290bb82a,0x160a0096,0xe7ea00c3}},	//   рына_, _reca_, हीतर_, _झूला_,
   {{0x798d009c,0x33f0015e,0x00000000,0x00000000}},	//   whaw, _màx_, --, --,
   {{0xd3781386,0x27e39f4f,0xae17030b,0x3f9c063d}},	//   _moć_, _rijn_, _थिएन_, _imvu_,
   {{0x27e30381,0x00000000,0x00000000,0x00000000}},	//   _sijn_, --, --, --,
   {{0x27e30126,0x290b6da8,0xa3cd023a,0x67e90141}},	// [de50] _pijn_, _veca_, रतम_, _ožje,
   {{0xd37803ce,0x798d6712,0x2bd23ec9,0x25bf0270}},	//   _noć_, shaw, _दीपा, _skul_,
   {{0x6e280b27,0x7d0d0808,0x6d960995,0x6da40039}},	//   nudb, _keas, ršav, rđav,
   {{0xb8d10081,0x27e30126,0x7bc7b82b,0xa9270190}},	//   _ওর_, _wijn_, llju, _بعده,
   {{0x39490cc2,0x6d9608a9,0x7d0d5d5b,0xdb1500b6}},	//   meas_, pšav, _meas, hozí,
   {{0x394972de,0x8cce0c13,0x7d0d4f4e,0x7df300d3}},	//   leas_, _सरसो, _leas, _lăsa,
   {{0xa91b0088,0xb5a7571b,0xd37802f7,0x6e2800c4}},	//   _alþi, _драй, _doć_, judb,
   {{0x7d0db82c,0x25ad3e76,0x60095334,0x63b10141}},	//   _neas, _ujel_, бним_, _šenč,
   {{0x3dd20150,0x637d001c,0x8fa56804,0x00000000}},	//   _rhyw_, _bènt, запе, --,
   {{0x39490a62,0x7bc73561,0x6e2802ef,0x637d210f}},	//   heas_, jlju, fudb, _cènt,
   {{0x6d9608c5,0x637d0113,0xed5a0d57,0x7d0db82d}},	//   kšat, _dènt, бон_, _beas,
   {{0x7d0db82e,0x6d96033b,0x3f9c039f,0x523a0142}},	//   _ceas, jšat, _emvu_, _לײענ,
   {{0xd1b803ed,0x7d0d0049,0x3949b82f,0xa2bf009f}},	//   _بالا_, _deas, deas_, _लुत्,
   {{0xff510688,0x70520037,0x6e2800f9,0x637d90d5}},	//   _سخت_, _أنوا, budb, _gènt,
   {{0x67210084,0x91fc01d3,0xa96a1510,0xdb1c0216}},	//   _öljy, _grād, бива_, lorë,
   {{0x7d0d43a3,0xfe700037,0x00000000,0x00000000}},	//   _geas, _جده_, --, --,
   {{0xa2a2099d,0x1dc90789,0xdb1c023b,0xeb9f0537}},	// [de60] _केन्, रतरत, norë, rsør_,
   {{0x6d56b830,0x7af70036,0x79840034,0x637d00b3}},	//   _haya, _gfxt, skiw, _mèns,
   {{0x7d0db831,0xf6230aec,0xf1cb07ad,0x637d001c}},	//   _yeas, едхо, ातान, _lèns,
   {{0x3949b832,0x63ad0037,0x7c360216,0x00000000}},	//   ceas_, éann, _kqyr, --,
   {{0x6d56b833,0x2912b834,0xe4e3036c,0xd37800c4}},	//   _maya, maya_, нішн, _poć_,
   {{0x6d560484,0x2912b835,0xcc3b00c1,0x2d9900fd}},	//   _laya, laya_, מענט, érez_,
   {{0x9c130174,0x637d30ea,0xa2b1039d,0xed6102c6}},	//   _tọgb, _rènt, _अखण्, ížky_,
   {{0x29126ac9,0x7de8000d,0x637d03a9,0x6e281f60}},	//   naya_, _měst, _bèns, vudb,
   {{0x7d0d00a1,0x7df3044c,0x00000000,0x00000000}},	//   _reas, _răsa, --, --,
   {{0x29123d3a,0xe7be0af1,0x7d0d0a91,0x6d56b836}},	//   haya_, ्तिप, _seas, _aaya,
   {{0x6d56b837,0x7bc702e6,0x00000000,0x00000000}},	//   _baya, vlju, --, --,
   {{0x29121084,0x6d56008a,0x6e28108e,0xdb1c0216}},	//   jaya_, _caya, rudb, borë,
   {{0x6d56381b,0x2912159d,0x6e28b838,0x9f340565}},	//   _daya, daya_, sudb, _желі,
   {{0xdb152e92,0x629c003e,0xceb800c6,0x00000000}},	//   pozí, _þros, ugęs_, --,
   {{0x7d0db839,0x3949b83a,0x6d56b83b,0x38fa0294}},	//   _teas, teas_, _faya, _ọkụk,
   {{0x291272ed,0x87090033,0x00000000,0x00000000}},	//   gaya_, _লাইফ_, --, --,
   {{0x3949b494,0x7bc7005f,0xa40b0251,0x6d96042d}},	// [de70] reas_, plju, _सौंप_, ršat,
   {{0x3949654a,0x6d56180d,0x04fe0033,0xf77f0052}},	//   seas_, _zaya, ুলোর_, _kuçi_,
   {{0x2912b83c,0x6d56b83d,0x394904d8,0x6d5a00e8}},	//   baya_, _yaya, peas_, ētav,
   {{0x2912b83e,0x7ddf2224,0x2100033b,0x6d5631ed}},	//   caya_, _būsi, nčič_, _xaya,
   {{0x63adb83f,0xf99f05aa,0x00000000,0x00000000}},	//   éano, _imè_, --, --,
   {{0x69d800e5,0x98a90234,0xdb1c01dc,0x00000000}},	//   _èver, ngač_, gorè, --,
   {{0x6d86002b,0x637d00d1,0x656c01cd,0x91fc00e8}},	//   _sóam, _sèns, ólhý, _arāb,
   {{0xdb1c00dd,0x80651b48,0x26d10036,0xf6520327}},	//   torë, движ, _izzo_, _בצל_,
   {{0x34940805,0x6d56b840,0x26d12d5a,0xf48400ae}},	//   _затр, _raya, _hzzo_, _пуфн,
   {{0x2912b841,0xdb1c0052,0x63a400da,0x2b8f0233}},	//   zaya_, rorë, éint, _yüce_,
   {{0x63a39808,0x2912b842,0xdb1c0052,0x6d560d18}},	//   minn, yaya_, sorë, _paya,
   {{0x63a3b843,0x29120188,0x6d564628,0x65690090}},	//   linn, xaya_, _qaya, _jneh,
   {{0x6d5682b4,0x29120491,0x62837cb9,0xdb1c00fd}},	//   _vaya, vaya_, lyno, loré,
   {{0xa3cd1344,0xa3bf1344,0x63a32d14,0x6d56b844}},	//   रति_, ीति_, ninn, _waya,
   {{0x2912531f,0x6d565c0c,0x28e006ed,0x63a30167}},	//   taya_, _taya, पेनि, iinn,
   {{0x63a3b845,0xb33c00bd,0x98a004e9,0x2c1700a4}},	//   hinn, _imħe, ngić_, _तिचं_,
   {{0xb9060454,0x63a3b846,0x98a30752,0xa3bf03a2}},	// [de80] _पण_, kinn, вите, ीता_,
   {{0x2912b847,0x63a3b848,0x6569159d,0x7de800b6}},	//   saya_, jinn, _aneh, _těst,
   {{0x63a3b849,0x6f1c016d,0x29124ca9,0x657b00fc}},	//   dinn, órci, paya_, _bouh,
   {{0x29124628,0x186a1f3e,0xdb1501f9,0x00000000}},	//   qaya_, _дами_, mozá, --,
   {{0x63a3502c,0xe2f81acf,0xdb0e0206,0x00000000}},	//   finn, пелі_, dobú, --,
   {{0xf62604f5,0x63a3510b,0x6569039f,0xb33c0090}},	//   _одго, ginn, _eneh, _omħe,
   {{0xe5a61a18,0xd2570109,0x13390018,0x6283b84a}},	//   _живи, дцы_, ستوں_, gyno,
   {{0xdb1c0149,0xd37809ac,0x78af015c,0xdce400d8}},	//   llrä, _mići_, šivš, _anič,
   {{0x63a386d5,0xe4c30dd8,0xcf261f11,0xd6b00033}},	//   binn, _айти, وردي, _করিয,
   {{0xdb150018,0x4426b0ac,0x65690094,0xdb1cb84b}},	//   kozá, mro_, _zneh, boré,
   {{0xd12f0c43,0x657b03a9,0xdb1c020d,0x7c261d7f}},	//   _их_, _youh, coré, erkr,
   {{0x4426b84c,0x008600ae,0x00000000,0x00000000}},	//   oro_, _олео, --, --,
   {{0x5c7414fa,0x00000000,0x00000000,0x00000000}},	//   влят, --, --, --,
   {{0x44261379,0xcf26001c,0xe8d90134,0xdfa601c3}},	//   iro_, _آرشي, nkụ_, _تحصي,
   {{0x442600f0,0x7c260313,0x00000000,0x00000000}},	//   hro_, arkr, --, --,
   {{0xd3780995,0xdce40146,0x63a3b84d,0xceb30089}},	//   _dići_, _znič, zinn, _שיק_,
   {{0x777c023b,0x44265646,0x62830034,0x2e380072}},	// [de90] _borx, jro_, zyno, léf_,
   {{0x657b98bb,0x65690220,0x63a349ee,0xa8020072}},	//   _souh, _sneh, xinn, áñan,
   {{0x63a3ab6f,0x44261ffc,0x98af0233,0x657b00b6}},	//   vinn, ero_, ıgı_, _pouh,
   {{0x63a316f1,0x4426b84e,0xdb1c16e7,0x630b0033}},	//   winn, fro_, voré, _রাইট_,
   {{0x777c0042,0x78fa00ca,0x628300f0,0x00000000}},	//   _forx, _מפרו, wyno, --,
   {{0x42550636,0x777c01f2,0x3959b84f,0xb4c100aa}},	//   етит, _gorx, _hass_, _ुरी_,
   {{0x63a3b850,0x4426b851,0x24894105,0xdb0e3bf0}},	//   rinn, aro_, šam_, tobú,
   {{0x3cf90034,0x6569b852,0x3f8e0350,0x00000000}},	//   ंडों_, _uneh, _alfu_, --,
   {{0x20190018,0x63a334ae,0x395995fb,0x98a0015c}},	//   ési_, pinn, _mass_, rgić_,
   {{0x39594304,0x82f8001c,0x35a500c3,0x00000000}},	//   _lass_, _قرمز_, _खगड़, --,
   {{0xd1310037,0x398e003e,0xed5a2e0f,0x1ee70a85}},	//   _مما_, _lýsa_, пон_, بودی_,
   {{0xdb0a0074,0x3f8e0051,0xed5a12dd,0x7bc50201}},	//   čník, _elfu_, чом_, _akhu,
   {{0xd378015c,0xa2830018,0x0d833c75,0x00000000}},	//   _sići_, _سیکو, улян, --,
   {{0xe51f0179,0xdce40087,0x207a006e,0xdb1501f9}},	//   मृति_, _unič, _מאנא, tozá,
   {{0x6da60f99,0x1a6612eb,0xd94603d9,0x9f4f0052}},	//   _пика, ریحی_, неви, _lugë_,
   {{0xdb152e16,0x44269103,0x7bc50201,0xdce4009e}},	//   rozá, yro_, _ekhu, _eliġ,
   {{0x395902d6,0xfc3200e3,0x777c015e,0x6d440139}},	// [dea0] _dass_, _صحة_, _porx, _ibia,
   {{0x44260396,0xdc3b00a1,0x777c0092,0x26de0146}},	//   vro_, _צעיר, _qorx, _útok_,
   {{0x3959227a,0x4426ab54,0x98c000a7,0x00000000}},	//   _fass_, wro_, ırıq_, --,
   {{0x4426b307,0x3959333b,0xf6510018,0x7dd60103}},	//   tro_, _gass_, گئے_, lásb,
   {{0x4426b853,0xdceb0995,0x7dd60072,0x777c00ee}},	//   uro_, šića, cáse, _torx,
   {{0x9f47023b,0x77911ac9,0x46a66f46,0xecd300b6}},	//   _dinë_, _پیما, _загв, _सरसफ,
   {{0x60e50092,0x6d44b854,0x27ea010a,0x00000000}},	//   ərmə, _obia, _iibn_, --,
   {{0xd25901b3,0x3940058f,0x2b5a030a,0x00000000}},	//   ьці_, nfis_, _lapc_, --,
   {{0xcfa6062a,0xf99300a1,0x7dd601f9,0x00000000}},	//   ешни, טרה_, kásb, --,
   {{0x25a65059,0x6d44b855,0x661c0b14,0x0fce0033}},	//   liol_, _abia, _kvrk, রদ্ধ,
   {{0xbcfb0018,0x6d4400e7,0xdd95013f,0x69c65fb9}},	//   ndég, _bbia, ваны, _okke,
   {{0x25a6b856,0xac190879,0x222b001c,0x57be00b6}},	//   niol_, мому_, _رزمی_, ्तुह,
   {{0xdb1c00f0,0x3959b857,0x00000000,0x00000000}},	//   gorï, _rass_, --, --,
   {{0x25a60150,0x69c65160,0xc0a90470,0x6d440172}},	//   hiol_, _akke, _تامل_, _ebia,
   {{0x2d9904ea,0x7ddf013f,0x1c1d007a,0x395954db}},	//   ères_, _būst, _भटकल_, _pass_,
   {{0x629800e9,0x2b5a00ee,0x00000000,0x00000000}},	//   izvo, _eapc_, --, --,
   {{0x25a602ad,0x6d4f0991,0x2bd200a5,0xe8940243}},	// [deb0] diol_, meca, _दीवा, гать,
   {{0x7dd6b858,0x69c60102,0x6d4f0067,0x6d5d3988}},	//   ráse, _ekke, leca, ldsa,
   {{0x765a0181,0xf7700391,0x7c2f55a7,0x26ca02ac}},	//   _štyr, حاق_, lucr, _cybo_,
   {{0x6d5d21ad,0x6d4fb859,0x2d8b030b,0x236c007e}},	//   ndsa, neca, nkce_, _andj_,
   {{0x76550d1b,0xf8d50251,0x29090051,0x7c3d619c}},	//   _wszy, _दरिय, mbaa_, ntsr,
   {{0xe61333e7,0x69cdb85a,0x1bf80266,0x57be02d5}},	//   _مشر_, llae, עצור_, ्तृह,
   {{0x25a65af9,0x69cd0150,0x41b5168c,0x00000000}},	//   biol_, olae, ксит, --,
   {{0x6d4f0292,0x29090188,0x25a68fdb,0x7c3d0572}},	//   jeca, nbaa_, ciol_, ktsr,
   {{0x6d4f52c4,0x6594002d,0x661c0234,0xdc3c01d3}},	//   deca, _сату, _zvrk, ršīg,
   {{0xd3780542,0x6d440451,0x6d5d6835,0xe8d90174}},	//   _biću_, _sbia, edsa, edị_,
   {{0x9f47030b,0x2b500092,0x9f4f020d,0xd37a006e}},	//   _jiné_, _öncə_, _jugé_, _קרעט,
   {{0xb33c003d,0x7c3db85b,0xeb0a02d5,0xc2c40076}},	//   _imħa, ftsr, वर्त_, _صيني,
   {{0x69cd02ad,0x1fb50950,0x557600c1,0x442fb85c}},	//   dlae, _искр, דערן_, nug_,
   {{0xd3780218,0x61eb041c,0x68080139,0x00000000}},	//   _fiću_, _higl, _léjò, --,
   {{0xc33209c1,0x442fb85d,0x6d4f9159,0x9f4703a9}},	//   יום_, hug_, beca, _niné_,
   {{0x3a25003e,0x64493741,0xdb1cb85e,0x6d44039f}},	//   álpa_, _opei, morí, _ubia,
   {{0x61ebb85f,0x09e33b4f,0x3940b860,0xdb1c305b}},	// [dec0] _migl, ротн, rfis_, lorí,
   {{0x3860b861,0x442fb862,0x25a600f0,0x9bca0076}},	//   rvir_, dug_, wiol_, _زوجك_,
   {{0xe9da0831,0xdb1c167e,0x9f4700fd,0x31ba01d3}},	//   _око_, norí, _ciné_, līze_,
   {{0x2d8000fd,0x8ab700ca,0x443d033c,0x64490503}},	//   _joie_, _יהיו_, ftw_, _bpei,
   {{0x25a60150,0x6449002b,0x69c4b863,0x442f0113}},	//   riol_, _cpei, moie, gug_,
   {{0xdceb0f39,0xd703013d,0x61eb05ef,0x661c0357}},	//   žićn, _взри, _aigl, _tvrk,
   {{0x61ebb864,0xa6e00081,0x82330037,0x6d4f70ab}},	//   _bigl, _প্রয়, لريا, yeca,
   {{0x442f02c9,0xdb1cb865,0x2fc72375,0x6d4f0428}},	//   bug_, dorí, _akng_, xeca,
   {{0x6d4f00cc,0x61eb00cc,0xbcfb00fd,0xd3780357}},	//   veca, _digl, ndée, _siću_,
   {{0x2d925148,0xd378031a,0xd346001c,0x836a2eb5}},	//   _alye_, _piću_, _شیعه_, _تصرف_,
   {{0xdb1c11c4,0x6d4fb866,0x61eb013d,0xf8bf025a}},	//   gorí, teca, _figl, _idée_,
   {{0x61eb0451,0x7c3db867,0xa18300c2,0x398700bc}},	//   _gigl, ttsr, _вышл, _tõsi_,
   {{0x2019000d,0x5f7600cd,0xae060aa1,0x6d5db868}},	//   ásit_, _لاغر, वीजन_, rdsa,
   {{0x8fa30d47,0xdb0700dd,0x2d92022b,0x7f8400ee}},	//   _каче, mijë, _elye_, _pòqu,
   {{0x442f01bf,0x7c2f953c,0x28e002d5,0x2d803ece}},	//   zug_, sucr, पेसि, _foie_,
   {{0xa806026a,0x7bceb869,0x442f2375,0x69c401e9}},	//   ktığ, albu, yug_, goie,
   {{0x98a201d4,0x3dc903cb,0xb87b0139,0x17ed00aa}},	// [ded0] _bakı_, _ikaw_, _agír, जदेव_,
   {{0x3b550870,0x7f8400ee,0x69cd6ac2,0x8c1c00ca}},	//   _скор, _tòqu, slae, _חוזי,
   {{0xa2a202e8,0xd00603ed,0x6449b86a,0xcf9300c1}},	//   _केल्, _گل_, _spei, סטע_,
   {{0x442fb86b,0xc88404a8,0x00000000,0x00000000}},	//   tug_, _bağı_, --, --,
   {{0xd006003f,0xfc3fb86c,0xef1800d9,0xf4d10081}},	//   _دل_, ntí_, kaļ_, িশ্ব,
   {{0x442f7c17,0x61ebb86d,0xdb1c09b3,0x954200a7}},	//   rug_, _sigl, yorí, əşmə,
   {{0x442fb86e,0x05bb0a09,0x61eb028d,0x443d0034}},	//   sug_, _قدرت_, _pigl, stw_,
   {{0x61fe0146,0x2fc70063,0xdb1c0031,0xdb0e0094}},	//   ípla, _skng_, vorí, dobý,
   {{0x61ebb86f,0xf94a006e,0x69da1570,0x6449007b}},	//   _vigl, געפֿ, ïtei, _upei,
   {{0xdb1c9e6b,0x2d990126,0x69c4b870,0x2d8000fd}},	//   torí, ëren_, zoie, _soie_,
   {{0x61ebb871,0x2d920154,0x69c4024a,0x00000000}},	//   _tigl, _plye_, yoie, --,
   {{0xed5700d6,0xc1050037,0x7dd60076,0xc884071d}},	//   гою_, _صوتي, fása, _yağı_,
   {{0x711a004f,0x2d804eb2,0xdb1c04d8,0x7afc02ef}},	//   _נוספ, _voie_, sorí, tcrt,
   {{0xe0d00103,0x798d7f38,0x00000000,0x00000000}},	//   _بزم_, ekaw, --, --,
   {{0x69c4b872,0x798d0022,0x6eca0287,0xdb1c0231}},	//   toie, fkaw, _सुपु, torâ,
   {{0x798d1ba1,0x6d4e00d4,0x00000000,0x00000000}},	//   gkaw, íhač, --, --,
   {{0x38660076,0x999802c6,0xfc3f00b3,0xa3e300a3}},	// [dee0] íor_, strů_, ctí_, नगा_,
   {{0x7d16008a,0xe7370095,0xbcfb020d,0x91fc01d3}},	//   _heys, леу_, rdée, _brāl,
   {{0x798d01c2,0x452a00b4,0x80aa6bbd,0xdb1c00ee}},	//   bkaw, ежен_, _जेने, morà,
   {{0xa806026a,0xc51600b9,0x49ba0103,0x2956008f}},	//   ttığ, ابات, _ساجد_, _съор,
   {{0xd8760192,0x7d16b0ac,0xd91b00ca,0xd4675136}},	//   _صاحب, _meys, _אוכל, лице_,
   {{0x3952b873,0x932600cd,0x7d16b874,0xea0000de}},	//   leys_, ارشن, _leys, _ngẫu_,
   {{0xa8060342,0x7dd601f9,0xb59d0065,0x2fc505db}},	//   stığ, zása, _kẹ̀w, dolg_,
   {{0xa80601e8,0x2bdb0e50,0x7df300d3,0x3ced0559}},	//   ptığ, _मीना, _găsi, ževi_,
   {{0x2fc501bf,0xf8b40034,0x351b00ca,0xbfaa235c}},	//   folg_, ंपिय, _רומנ, етне_,
   {{0xa2bf06ed,0xa85700a1,0xb33c02a1,0xad270470}},	//   _लुक्, נייה_, _imħo, گردو,
   {{0x3f6301b6,0x7d16b875,0x00000000,0x00000000}},	//   стыб, _beys, --, --,
   {{0x7dd60018,0xb8860031,0xa2bb00d7,0x7d1601ee}},	//   tása, _zvíť, _אמבט, _ceys,
   {{0x5b270a2d,0xaca50129,0xdced00bd,0x7d162bb3}},	//   льва, knụz, _inaċ, _deys,
   {{0xbe8600d0,0xfc3fb876,0x7d16041c,0x00000000}},	//   _مجبو, rtí_, _eeys, --,
   {{0xfc3f5348,0x6f1ab877,0xe91900d6,0x7d16b878}},	//   stí_, matc, кові_, _feys,
   {{0x195800c6,0x7d16b879,0x6f1a72b7,0x00000000}},	//   ласы_, _geys, latc, --,
   {{0x798db87a,0x2d9900e3,0x97151e79,0xf72b00d3}},	// [def0] rkaw, mhse_, имац, ецей_,
   {{0x798db87b,0x6d5f026d,0x6f1a0a60,0x994e1405}},	//   skaw, _haqa, natc, _výš_,
   {{0xb8cc7150,0xb87b1f32,0x941f0092,0x6d5f008c}},	//   _के_, _egíp, ərək_, _kaqa,
   {{0x7bc7b87c,0xceb3006e,0x29f80995,0x6d5f5413}},	//   loju, זיע_, _očaj_, _jaqa,
   {{0x6d5f0694,0x588700c6,0x1b180081,0x291b1a4a}},	//   _maqa, _сына, _তাতে_, maqa_,
   {{0x7bc74a0f,0xe285007b,0x6d5f9ee9,0x14a40096}},	//   noju, илли, _laqa, _खेळण,
   {{0x2fc501a2,0x52750012,0xa80601e8,0x6f1a0fa3}},	//   volg_, рулу, rtış, datc,
   {{0x91fc00d9,0xd185028d,0x6d5f17f4,0x22ae00a7}},	//   _grām, рлий, _naqa, _dək_,
   {{0xd34700cd,0x7bc700d9,0x9f47028d,0x6eca3aee}},	//   _میشه_, koju, _finì_, _सुबु,
   {{0x6f1a0141,0xdb1c19a3,0x2054008f,0x628a0381}},	//   gatc, korá, стър, byfo,
   {{0x6d5fb87d,0x7bc7b87e,0x41551b60,0xdb1c0437}},	//   _baqa, doju, _ввес, jorá,
   {{0xfce6276c,0x6d5f0188,0x00000000,0x00000000}},	//   ионо, _caqa, --, --,
   {{0x3952007b,0x7d09002b,0x645b014b,0x7d160847}},	//   veys_, ñesa, _jsui, _veys,
   {{0xdee55894,0xdb1c415a,0x69dd5f1e,0x7bc742fd}},	//   _коли, forá, _ahse, goju,
   {{0x6d5f4330,0xbea20396,0x395200c2,0xd6b00033}},	//   _faqa, _машк, teys_, _কর্প,
   {{0x2d990364,0x66761ac9,0x7dd60103,0xdc351515}},	//   chse_, یدار, máso, _zúčt,
   {{0x7dd60068,0x7bc7b87f,0x80dd0789,0x443f023e}},	// [df00] láso, boju, _परफे, _nqu_,
   {{0xdb1c002b,0x753b002d,0x661b007f,0x27ee003e}},	//   borá, _acuz, _łuka, öfn_,
   {{0x6d5f3cc5,0x645b00c2,0xdb0e007f,0x91fc00e8}},	//   _yaqa, _asui, sobó, _prām,
   {{0x6d5f4828,0x00000000,0x00000000,0x00000000}},	//   _xaqa, --, --, --,
   {{0x63aab880,0x11d6001c,0x66097035,0x2902008c}},	//   tifn, یتعد, _čeke, _ifka_,
   {{0xbcfb00e3,0xb4d61362,0x7dd60018,0x00000000}},	//   idéa, _हरी_, káso, --,
   {{0x2b470b88,0x7ddd0018,0xd25000e3,0x443f0090}},	//   _önce_, lése, سنة_, _equ_,
   {{0x63aa005c,0x7dd60103,0x628ab881,0xd1300037}},	//   sifn, dáso, ryfo, أمة_,
   {{0x7df300d3,0x29000487,0x6d5f2e12,0x7bc71a87}},	//   _măsu, icia_, _raqa, yoju,
   {{0x63ad00e3,0x6d5fb882,0x65600037,0x22ae00a7}},	//   éant, _saqa, _hamh, _tək_,
   {{0xa3e305cd,0x29000181,0x244006a3,0xb4d600b6}},	//   नगर_, kcia_, lòm_, _हरु_,
   {{0x6560b883,0x656200dd,0xdb1c0558,0x29000031}},	//   _jamh, ndoh, vorá, jcia_,
   {{0x6442b884,0x7bc7b885,0x7dd6488f,0x00000000}},	//   ntoi, toju, pásn, --,
   {{0x2900b886,0xc0a90391,0x6560a364,0x2902008a}},	//   ecia_, _حامل_, _lamh, _afka_,
   {{0xdced02e6,0x7bc71dfc,0x79a73153,0x69c00b18}},	//   _inač, roju, арае, čmen,
   {{0x80dd0569,0x637d0c56,0x6560b887,0x6f180090}},	//   _परमे, _dèny, _namh, _hevc,
   {{0x7d1d5460,0x6f1801fa,0x7bc7b888,0xa3d605cd}},	// [df10] mass, _kevc, poju, सता_,
   {{0xe7190080,0xe7330391,0x7d1d202b,0x753b00d3}},	//   ايات_, تصر_, lass, _scuz,
   {{0x212608a9,0x6f1801e8,0x65600372,0xcb5600ca}},	//   _odoh_, _mevc, _bamh, _הסתה_,
   {{0x2900013d,0x7d1d2019,0x656001ec,0x3ced015c}},	//   ccia_, nass, _camh, ževu_,
   {{0x7dd60018,0x6560b889,0xe81600c3,0x00000000}},	//   záso, _damh, दीदा_, --,
   {{0x7d1db88a,0x2126001c,0xb3c8084c,0x67e905db}},	//   hass, _adoh_, аліз_, _ožji,
   {{0xd6e500c7,0x06e500c7,0xe69500e3,0x2919b88b}},	//   _প্রয, _প্রি, _الأد, _kesa_,
   {{0x753b03e0,0x6d07030b,0x78b800cc,0x7d1d79e9}},	//   _ucuz, _व्लग_, šavš, jass,
   {{0x6442b88c,0x60060109,0x7d1d23ce,0x9f4e02f1}},	//   ctoi, бным_, dass, _kifè_,
   {{0x7dd60068,0x2919b88d,0x3f83003e,0x6f18007e}},	//   táso, _lesa_, ðju_, _cevc,
   {{0x201f0396,0x7ddd0103,0x7d1db88e,0xd3e6010d}},	//   ssui_, zése, fass, _اقلی,
   {{0x2919b88f,0x7d1db890,0x442fb891,0x7dd60103}},	//   _nesa_, gass, org_, ráso,
   {{0x515a00a1,0x7c29033b,0x7e6a1183,0x6d460eb3}},	//   _תכנו, šern, _erfp, rfka,
   {{0x394b0231,0x3b950da5,0x21260141,0x00000000}},	//   _abcs_, ојст, _zdoh_, --,
   {{0x2919b892,0xf8bf1ee6,0x6996510e,0x00000000}},	//   _besa_, _axé_, брах, --,
   {{0x7ddd0018,0xe9df0028,0x29191ba6,0x2d9201d3}},	//   tése, _chú_, _cesa_, īzes_,
   {{0x290074e8,0x29194b6a,0x4ca600c7,0xa9670e38}},	// [df20] rcia_, _desa_, _গুরু, щита_,
   {{0x6560b893,0x2900013d,0xbcfbb894,0x869a11d9}},	//   _samh, scia_, ndén, лтет_,
   {{0x2e2301e8,0x291903e3,0x290007a3,0x9f4e0154}},	//   nıf_, _fesa_, pcia_, _difè_,
   {{0x4a5b0054,0xdb1c15ed,0x63140081,0x29190808}},	//   _עדכו, forç, _সাইট_, _gesa_,
   {{0xfe6700bf,0xf3f10023,0x260c007a,0x65623dfd}},	//   _کد_, _bị_, डीजी_, rdoh,
   {{0x6442b895,0x7d1d0103,0x7c241c35,0x29190027}},	//   rtoi, zass, _mvir, _zesa_,
   {{0x6442b896,0x7d04317e,0xf3f165aa,0x7d1d2937}},	//   stoi, _ofis, _dị_, yass,
   {{0x7d1d0131,0x65600a02,0x7c240087,0x15432fd2}},	//   xass, _uamh, _ovir, _несм,
   {{0x7d1db296,0x6f18033b,0xdb1c015e,0x00000000}},	//   vass, _pevc, corç, --,
   {{0x7d04b897,0xf3f10134,0x63a404e2,0x44245e7c}},	//   _afis, _gị_, ëind, _ivm_,
   {{0xf8d5143d,0x59c8152c,0x7ddd0103,0x826601c3}},	//   _दर्प, लवार, vésb, _دهان,
   {{0x44246073,0xc693006e,0x79863944,0x7c240090}},	//   _kvm_, פאר_, _nokw, _bvir,
   {{0x2919b898,0x3ced00aa,0x442448fc,0x7ddd0103}},	//   _resa_, äev_, _jvm_, tésb,
   {{0x7c24013f,0x7d042bb2,0x2919023b,0x7df300d3}},	//   _dvir, _efis, _sesa_, _păst,
   {{0x2919b899,0xe9df0019,0xda780c79,0x798643fa}},	//   _pesa_, _phú_, бят_, _bokw,
   {{0x7d1d00bd,0x61fab89a,0x00000000,0x00000000}},	//   qass, _mutl, --, --,
   {{0x79860294,0x44240126,0xdced0090,0xf8bf034f}},	// [df30] _dokw, _nvm_, _flaġ, _edén_,
   {{0x6fdd0257,0x61fab89b,0xba550859,0x9f470206}},	//   pèce, _outl, _двој, _kiná_,
   {{0xe9df16b3,0xd6dbb89c,0x9f4700b6,0x7c24195e}},	//   _thú_, ута_, _jiná_, _zvir,
   {{0x9b450018,0x333e0027,0x2e3b006e,0x7bd5573b}},	//   _انھو, _actx_, רגאנ, llzu,
   {{0x442fb89d,0x61fa007e,0x29d7255b,0x6eca42c3}},	//   urg_, _autl, nçam_, _सुसु,
   {{0x61fa5f08,0x42090ce5,0x7986019f,0x8c1c0089}},	//   _butl, анко_, _zokw, נווי,
   {{0xe29958c0,0x3869b89e,0xdb1c0161,0x65950077}},	//   рай_, lvar_, sorç, _даву,
   {{0x80dd147f,0xdb1c0161,0xc005004c,0x1bf902d5}},	//   _परदे, porç, опик, ंदाल_,
   {{0x7529b89f,0x38690092,0x00000000,0x00000000}},	//   _idez, nvar_, --, --,
   {{0x6d4d7a18,0xd00e0421,0x61fab8a0,0xf8aa006e}},	//   _abaa, کلی_, _futl, יספֿ,
   {{0x7c2403ce,0x61fa00cc,0xbcfb0072,0x76450150}},	//   _svir, _gutl, rdén, nthy,
   {{0xe294006e,0x7dd600d4,0x386901ce,0x394901cb}},	//   _צװײ_, pásm, kvar_, jfas_,
   {{0x764501dc,0x06b00033,0x7dd60103,0x399c0139}},	//   hthy, _করছি, lásk, _jíse_,
   {{0x69cfb8a1,0xf8bf0065,0x200db8a2,0x6d4d7608}},	//   _akce, _adéo_, mpei_, _ebaa,
   {{0x7986b8a3,0x7d04003d,0x752906e4,0x394907ee}},	//   _pokw, _tfis, _odez, ffas_,
   {{0xbcfbb8a4,0x7d04158f,0x7c24013f,0x6d4d0e62}},	//   ndél, _ufis, _tvir, _gbaa,
   {{0x3f878779,0x38694dfb,0xe7aa01a0,0x764500f0}},	// [df40] _konu_, gvar_, авал_, ethy,
   {{0x2d820542,0x752981c2,0x00000000,0x00000000}},	//   ljke_, _adez, --, --,
   {{0x2b580b18,0x4424007e,0x7986b8a5,0x4c05015a}},	//   merc_, _svm_, _tokw, _وظیف,
   {{0x4424055b,0x893615f8,0x2d820ebd,0xa96a0293}},	//   _pvm_, _بعدا, njke_, _тима_,
   {{0x29120198,0x195700ca,0xd7ca00d1,0x00000000}},	//   mbya_, _ובכל_, _نوحه_, --,
   {{0x75290134,0x69d60103,0x61fab8a6,0x00000000}},	//   _edez, llye, _putl, --,
   {{0xd6270752,0xe2970291,0x61fa1a4a,0x1dca00a4}},	//   _море_, жај_, _qutl, रवात,
   {{0x6eca058f,0xfbc20033,0x399c0076,0x2b580357}},	//   _सुषु, োগিত, _físe_, herc_,
   {{0xdced00bd,0x4424107b,0x6fd400b3,0x00000000}},	//   _ilaħ, _uvm_, làci, --,
   {{0x7dd60730,0x3f98003e,0xff980291,0x7ddd48b2}},	//   lásh, óru_, ској_, désa,
   {{0x61460f1e,0xb7db00c1,0x80aa0285,0x00000000}},	//   _межа, שקיי, _जेरे, --,
   {{0xdced00bd,0xbcfb014b,0x386d00d8,0xd9c400b6}},	//   _jlaħ, rdéo, _šerm_, वकोट,
   {{0x7b672c13,0x6eca1c3b,0x61e2b8a7,0xf0b00103}},	//   отве, _सुरु, _ihol, _سیدھ,
   {{0xa0070e25,0x76450150,0x6fa60034,0x29d70131}},	//   _بقول_, ythy, टोशू, rçam_,
   {{0x8f9b040a,0x61e2b8a8,0x6aa20022,0x5a44002d}},	//   _דיגי, _khol, _ƙofa, мэта,
   {{0x2bdb097c,0x6d4d39b8,0x6fd400b3,0x29120062}},	//   _मीरा, _ubaa, dàci, gbya_,
   {{0xbcfbb8a9,0x61e22086,0xe70b0286,0x7ddd014b}},	// [df50] ndém, _mhol, لتان_, césa,
   {{0xe9450814,0x2b5800ae,0x80dd5a5f,0x6603b8aa}},	//   _کردی, cerc_, _परसे, ínko,
   {{0xd5753e04,0x386917d2,0x61e27432,0x7c2a00e8}},	//   зуль, svar_, _ohol, _āfri,
   {{0x76450150,0xbc681ac9,0x61e202a1,0x00000000}},	//   rthy, _امین_, _nhol, --,
   {{0xd4690cfc,0x76450c86,0x9879006e,0xa3d600a4}},	//   силе_, sthy, _האָט, सतं_,
   {{0x61e2b8ab,0x57f400c2,0x7dd60103,0x6fd400ee}},	//   _ahol, _опят, tásk, bàci,
   {{0x6fd40428,0xdced0090,0x61e21c5d,0x7f8d00ee}},	//   càci, _flaħ, _bhol, _xúqu,
   {{0xd24e223e,0x98ab0491,0x3f870511,0xe4e7004d}},	//   اني_, _hacı_, _sonu_, _дізн,
   {{0x25adb8ac,0x61e2b8ad,0x60060fe9,0x00000000}},	//   _imel_, _dhol, пным_, --,
   {{0xee390236,0x61e2657c,0x25bf017a,0x249d4881}},	//   бно_, _ehol, _hjul_, ızmı_,
   {{0x59bd0efb,0x2b580036,0x61e210e4,0x00000000}},	//   ्कार, verc_, _fhol, --,
   {{0x61e2846c,0xdb150103,0x91fc00e8,0x00000000}},	//   _ghol, kozó, _prāv, --,
   {{0xea0000ef,0x61e93a7b,0x7dd611e9,0xdb0e020d}},	//   _biết_, mmel, nási, libé,
   {{0x61e9b8ae,0x3f9e109b,0x398e003e,0x7ddd9e05}},	//   lmel, chtu_, _lýst_, résa,
   {{0x09e640a9,0x64b800bc,0xea00020b,0x00000000}},	//   зовн, _अश्श, _diết_, --,
   {{0x61e94c28,0xe8fa3f37,0xf2d2006e,0x3dd60033}},	//   nmel, сла_, געל_, _সংকল,
   {{0x291200f9,0x69d66619,0x61e92325,0x98ab013c}},	// [df60] rbya_, rlye, imel, _bacı_,
   {{0x25adb8af,0x7c265954,0xea000019,0x61e9b47f}},	//   _amel_, mskr, _giết_, hmel,
   {{0xd90d0018,0x61e9b8b0,0xeab235ac,0x9b170266}},	//   _چیف_, kmel, _سعد_, _מחיה_,
   {{0x7dd65d81,0x7bceb8b1,0x6f1c0034,0x6fd4015e}},	//   fási, lobu, órcz, ràci,
   {{0x7c26338b,0x938a3ff1,0x9f5f016d,0x17fa0037}},	//   nskr, йска_, rquê_, _درجة_,
   {{0x61e2b8b2,0x53340aca,0x25ad08d3,0x7bce019f}},	//   _shol, фект, _emel_, nobu,
   {{0x9f470084,0x61e250dc,0x236507c0,0x78a412d9}},	//   _minä_, _phol, _dalj_, lziv,
   {{0x7c266f9c,0xb6bb00ca,0x798460d9,0x61e9b8b3}},	//   kskr, _הצלי, njiw, gmel,
   {{0x7df40012,0x7bce7c5e,0x64a31c0f,0x7c260381}},	//   _răsp, kobu, _зата, jskr,
   {{0x7c262566,0x08e90081,0x61e200a1,0x2b940212}},	//   dskr, টুকু_, _whol, _däck_,
   {{0x61e2b8b4,0x7bceb8b5,0x799603e3,0xdb1c01f9}},	//   _thol, dobu, kkyw, ború,
   {{0x3f9e01e5,0xa44b0146,0x61e29ff0,0x75220a4b}},	//   shtu_, lášť_, _uhol, naoz,
   {{0x7c26b8b6,0x628a0174,0x69cd0042,0x705400d1}},	//   gskr, ̣mọ, voae, _آنتا,
   {{0x200bb8b7,0x4426b8b8,0xdeb40dd8,0x15fc00c3}},	//   ície_, iso_, _облы, एदार_,
   {{0xea0000ef,0x7ac42ce9,0x15ec0336,0x66090d62}},	//   _viết_, есте, जगार_, _čeko,
   {{0x4426b8b9,0x7c2676b2,0xceb300ca,0x9964002d}},	//   kso_, bskr, _ריק_, нтул,
   {{0xea000028,0x91fc0029,0x6e3a1e95,0x442605db}},	// [df70] _tiết_, _krās, lutb, jso_,
   {{0x4c9c00a1,0x7bceb8ba,0xade1007a,0x25ad0117}},	//   _לבחו, cobu, _गीतन_, _smel_,
   {{0x44260150,0x41cc201e,0x28f900ae,0x61e9afc9}},	//   eso_, ावास, _мень_, ymel,
   {{0x3ea100aa,0x00000000,0x00000000,0x00000000}},	//   _ühte_, --, --, --,
   {{0xf8c10abe,0x4426b8bb,0x6e3ab8bc,0x236500c4}},	//   _एशिय, gso_, hutb, _palj_,
   {{0x7dd6b8bd,0x00000000,0x00000000,0x00000000}},	//   rási, --, --, --,
   {{0x44260283,0x61e9b8be,0x7d060212,0xd7d902d5}},	//   aso_, tmel, ycks, _बीएच,
   {{0xd9e324cf,0xcbf90033,0x7bce019f,0x40958063}},	//   _कीमत_, _অবৈধ_, zobu, дрот,
   {{0x4426b8bf,0x7bce5784,0x7ddd0103,0x316601ff}},	//   cso_, yobu, tésn, _daoz_,
   {{0x61e9a575,0x91fc01d3,0x7c260407,0x61360342}},	//   smel, _prāt, vskr, tülü,
   {{0xdb1c0181,0xee36002d,0x9f5f3ece,0x3d1a0096}},	//   porú, мнэ_, nqué_, परले_,
   {{0x6136008e,0x9f470084,0xdb070094,0x40ce00ac}},	//   rülü, _sinä_, vijá, ịrị_,
   {{0x4c83013d,0x6aa20022,0xd7bf0096,0x91aa0103}},	//   вляв, _ƙofo, ्वाच, _بننے_,
   {{0x9fb501d4,0x7076015a,0xbd030381,0x6d4101f9}},	//   dəçi_, _آموز_, _éénp, őlap,
   {{0xaa430036,0x7c266b38,0xf1e10034,0x00000000}},	//   керл, sskr, _पठान, --,
   {{0x44260694,0xe9da1557,0x213f0808,0x7c266f92}},	//   yso_, іка_, nguh_, pskr,
   {{0x7984113a,0x6d4401ff,0x00000000,0x00000000}},	// [df80] rjiw, _icia, --, --,
   {{0x1b180081,0xe8de00c3,0x75220350,0x00000000}},	//   _তাকে_, _मरीच, waoz, --,
   {{0x9f5f0990,0x29f80146,0xdb0e0212,0x78a401f9}},	//   rquè_, _včas_, gnbå, sziv,
   {{0x4426b8c0,0xe57a1402,0x6fd4015e,0x00000000}},	//   tso_, юзе_, làct, --,
   {{0x44263ff1,0x045a00e3,0xea0000fe,0x03a644b5}},	//   uso_, تجات_, _khắt_, мидо,
   {{0xa3a800a5,0x75220174,0x3940b8c1,0xf8b30327}},	//   खों_, saoz, lgis_, _ישר_,
   {{0x4426538c,0x6fdd0428,0xf7431c16,0x7dd649d6}},	//   sso_, tècn, _шеро, lásu,
   {{0x6d4401fa,0x3253013d,0x386d02ef,0x66e30fe3}},	//   _ncia, твър, _šeri_, _роса,
   {{0x394000aa,0xcfaa0037,0x4426008c,0x00000000}},	//   igis_, قادم_, qso_, --,
   {{0x83fd0018,0xada40034,0x187b00ca,0x399502c3}},	//   _erős, óźni, קטיב, _påsk_,
   {{0x6fd40428,0xa3cb0096,0x073700ca,0x6db504d9}},	//   dàct, ळकर_, ואים_, ейну,
   {{0x6d44028d,0x6e3a320e,0x4ad200c3,0x27350139}},	//   _ccia, rutb, _दुधव, _kùnà_,
   {{0xdb05054f,0x50e23245,0x6e3a05e8,0xbcfb686f}},	//   _amhá, _परिष, sutb, ndéi,
   {{0x21241519,0x6d440090,0x7dd60103,0xbcfb0037}},	//   lamh_, _ecia, dásu, idéi,
   {{0xb90c0134,0x00000000,0x00000000,0x00000000}},	//   _ọbịb, --, --, --,
   {{0x21240fab,0x75200068,0x6f0d077e,0x39409d6b}},	//   namh_, _nemz, _đaci, ggis_,
   {{0xa3ce1e5e,0x6d5d55e6,0xb4dd0fef,0x27f8b8c2}},	// [df90] रवा_, mesa, _डरे_, _birn_,
   {{0xd6db6eb1,0x399c01cd,0x7c3d4880,0xda7b00ae}},	//   оте_, _vísa_, musr, _дям_,
   {{0x19955d49,0xfbdf0161,0x9f5d01dc,0x7c3d00bc}},	//   _заня, ntêm_, _duwè_, lusr,
   {{0x6d5db8c3,0x9f5fa937,0x2d9904dc,0x7520037a}},	//   nesa, rqué_, nkse_, _cemz,
   {{0x7dd6381f,0x92bb0081,0x9f5f145c,0x660e01c8}},	//   mást, _ঘরে_, squé_, _etbk,
   {{0x6d5d9c12,0xd7c9001c,0x27f8009c,0x29090357}},	//   hesa, _روزه_, _girn_, lcaa_,
   {{0x6d5d2118,0xf99f06a3,0x00000000,0x00000000}},	//   kesa, _klè_, --, --,
   {{0x6d5d25f2,0x2d990126,0x7dd6b8c4,0xdb0700c2}},	//   jesa, jkse_, nást, lijä,
   {{0x6d5d7360,0x00000000,0x00000000,0x00000000}},	//   desa, --, --, --,
   {{0x6d44b8c5,0x2d990a9f,0x75203428,0x6569b8c6}},	//   _scia, ekse_, _zemz, _haeh,
   {{0x443db8c7,0x9f4f0139,0xe81f007f,0x00000000}},	//   luw_, _kugú_, मीता_, --,
   {{0x65695602,0x386000f0,0x212401b9,0x00000000}},	//   _jaeh, ywir_, camh_, --,
   {{0xdb070084,0xbdf90068,0x7c3d00aa,0x672500aa}},	//   kijä, _کرتا_, gusr, kahj,
   {{0xf99fb8c8,0xa066261f,0x2d997519,0x6569009c}},	//   _alè_, _чаша_, akse_, _laeh,
   {{0x8f9a00f5,0x6d5db8c9,0x6fd40472,0x34dc00c0}},	//   _מיסי, besa, ràct, _बर्द,
   {{0x6d5d7b32,0x443d563a,0x7dd60103,0x00000000}},	//   cesa, kuw_, tásu, --,
   {{0x26de02e6,0x3940b8ca,0xea0000de,0x38c8001c}},	// [dfa0] _što_, rgis_, _thắt_, ذاری_,
   {{0x657b00f9,0x443d01c0,0x290b0090,0xf99f10fe}},	//   _anuh, duw_, _efca_, _elè_,
   {{0x443d01c0,0x752000e7,0xfc3f0146,0x9f470139}},	//   euw_, _pemz, nzín_, _binú_,
   {{0x9426038f,0x9f5d00bf,0x7ae10103,0x26d80138}},	//   емде, _duwé_, ülte, _vyro_,
   {{0x65690167,0x7dd60103,0xc9530eda,0x00000000}},	//   _daeh, láss, _גמר_, --,
   {{0xceba01c2,0xdb1c003e,0xd62a5a67,0x6d5db8cb}},	//   _leƙa_, fnré, _ноге_, zesa,
   {{0x66e319e8,0x3afb00c1,0x6d5d635e,0x764100c2}},	//   _бора, פּגע, yesa, _älyp,
   {{0xea0000ef,0xdcf60154,0x244901cd,0x00000000}},	//   _nhật_, _anyč, búm_, --,
   {{0x82fa0260,0x6d5db8cc,0xdced0ac3,0x61f903a9}},	//   _فراز_, vesa, _inać, _diwl,
   {{0xa3c7007d,0x200bb8cd,0x21240a1b,0x29d70428}},	//   _उदय_, ícia_, samh_, lçat_,
   {{0xdd910fba,0x705400cd,0x1bfa0285,0x00000000}},	//   لود_, رنگا, _एंजल_, --,
   {{0x29d705fe,0x7afe002b,0x7c3d0673,0x9f4e0139}},	//   nçat_, _agpt, tusr, _difá_,
   {{0x2d99685e,0x6d4f0113,0x48c40033,0x00000000}},	//   rkse_, rfca, ্ধুর, --,
   {{0xcf2600e3,0x0ce102d5,0xdb150216,0x2d8403bd}},	//   _أرشي, _नरीम, mizë, ömer_,
   {{0xdb0e24c7,0x443d016d,0xdb150052,0xdb07007b}},	//   cibí, zuw_, lizë, vijä,
   {{0x3f8e0051,0x7c3db8ce,0x5c755cac,0x00000000}},	//   _hofu_, pusr, _алит, --,
   {{0x7d0d85f2,0x7dd6b8cf,0xdb150052,0x9f5d001c}},	// [dfb0] _ifas, rást, nizë, _suwé_,
   {{0x7c2db8d0,0xab84020f,0x00000000,0x00000000}},	//   _ivar, _буюк, --, --,
   {{0x7c2db8d1,0xc7c42e91,0x67255f50,0xe3b10281}},	//   _hvar, усти, rahj, یرت_,
   {{0x7c2d01ce,0x7dd60103,0x5a160266,0x7d0d009e}},	//   _kvar, lásr, _שקרן_, _jfas,
   {{0x7d0db8d2,0x84eb00c3,0x7c2d009e,0x5fd000b6}},	//   _mfas, जेंट_, _jvar, सकाल,
   {{0x443d010a,0x644b4a8a,0x7d0d01b9,0x2449b8d3}},	//   ruw_, rtgi, _lfas, rúm_,
   {{0xfc3f0037,0x65690167,0xdce40a39,0x644b059a}},	//   huí_, _taeh, _raič, stgi,
   {{0x96f80f11,0x644b029a,0x7d0db8d4,0x65690231}},	//   _чест_, ptgi, _nfas, _uaeh,
   {{0x29d70161,0x7dd60103,0x63ae0120,0xa1560284}},	//   lças_, záss, ønnø, тању_,
   {{0x02a700b4,0x7d0db8d5,0xdced00cb,0x7ddd0103}},	//   _прем, _afas, _znać, lésh,
   {{0x7c2db8d6,0x29d70396,0x6da60562,0xa3c0009d}},	//   _avar, nças_, вина, ीवर_,
   {{0xaad50251,0x7bc50167,0x2d9602f3,0x80d30033}},	//   _धड़क, _ajhu, трос, দেষ্,
   {{0xb87b0068,0xfc3fb8d7,0xd7d10096,0xdb050212}},	//   _szín, guí_, तकाच, _omhä,
   {{0x7d0db8d8,0x7dd60018,0x316d5642,0xd00e2c9a}},	//   _efas, táss, ldez_, _بلو_,
   {{0xea000028,0x7c2db8d9,0x7d0d00f0,0x9f5f00b3}},	//   _thật_, _evar, _ffas, nquí_,
   {{0x442d03ce,0x316d020d,0x7d1b0088,0xf1c400d4}},	//   _ove_, ndez_, ðust, pešť_,
   {{0x6d56b8da,0xa3e409dd,0x7c2d6c1a,0x316d2ad4}},	// [dfc0] _ibya, नतम_, _gvar, idez_,
   {{0xdced08a9,0xb8da00aa,0x00000000,0x00000000}},	//   _snać, _अइ_, --, --,
   {{0x4b37006e,0x7c2db8db,0x7dd6034f,0x442d8d44}},	//   _בריל_, _zvar, lásq, _ave_,
   {{0xf8bf0428,0x63a11f53,0x25a00076,0x00000000}},	//   _adéu_, _alln, óil_, --,
   {{0x29d76e38,0x6d560b58,0x00000000,0x00000000}},	//   aças_, _mbya, --, --,
   {{0x442d2450,0xdb150052,0x57250037,0x00000000}},	//   _dve_, vizë, _مرفق, --,
   {{0x6d56b8dc,0x442d6a30,0xdb1cb8dd,0x00000000}},	//   _obya, _eve_, loró, --,
   {{0xd13000e3,0x63a14e0d,0x7dd60103,0x29d71f4a}},	//   حمة_, _elln, zásr, lçar_,
   {{0x4fd40fa5,0x6747003e,0x660978ee,0x442d02ac}},	//   лжит, _þrjá, _čeki, _gve_,
   {{0x29d768a4,0x7d0d099f,0x6d56b8de,0x1f7379a6}},	//   nçar_, _sfas, _abya, алья,
   {{0x7c2db8df,0xdd95065c,0xc7b300ca,0x7dddb8e0}},	//   _svar, ганы, שבת_, lési,
   {{0x236cb8e1,0x25a6b8e2,0x63b8b8e3,0xe2970cc6}},	//   _hadj_, nhol_, livn, _шах_,
   {{0x4fc6387c,0x7ddd00bf,0x7dd60018,0x40340cba}},	//   _иска, nési, tásr, _селс,
   {{0xc0e30752,0x09bd063c,0x6d560a15,0x39951842}},	//   _точк, ्क्य, _ebya, _låst_,
   {{0x75fa030b,0x6fdd5f86,0x7ddd0257,0xdb150094}},	//   _různ, dèch, hési, nizé,
   {{0x7c2db8e4,0x39a4135d,0x7d0d0875,0x00000000}},	//   _tvar, ашув, _ufas, --,
   {{0xfc3f3bf0,0xdb1cb8e5,0x7c2d0031,0x25a63045}},	// [dfd0] quí_, goró, _uvar, dhol_,
   {{0x9c140174,0x63b802ef,0x7dddb8e6,0x7c29366a}},	//   _kọns, jivn, dési, šers,
   {{0x442d02e6,0xd6db01a0,0xa3c8030b,0xaa9555d0}},	//   _sve_, фта_, ोकन_, _синч,
   {{0x29d73906,0x2d8b0880,0xceb30327,0x442d1306}},	//   rças_, njce_, סיף_, _pve_,
   {{0x236c0154,0x00000000,0x00000000,0x00000000}},	//   _badj_, --, --, --,
   {{0x63b889a1,0xbcfb0018,0xe613097d,0x7bd5b8e7}},	//   givn, ldés, _نشر_, nozu,
   {{0x42520037,0x62984030,0xada60206,0x7bd501ff}},	//   منور, gyvo, _hnúš, iozu,
   {{0x45d5453b,0x200b0396,0x25a6b8e8,0x442d0575}},	//   _собс, ício_, chol_, _tve_,
   {{0x316d2718,0x4439b8e9,0x65945397,0x442db35e}},	//   rdez_, _ís_, _тату, _uve_,
   {{0xea0000de,0x645b01e9,0x9f85180b,0x629801cb}},	//   _giặt_, _ipui, угод, byvo,
   {{0x6fdd0428,0x7bd57dd4,0x00000000,0x00000000}},	//   nèci, dozu, --, --,
   {{0x399c0146,0xea0000de,0xb33c0090,0x00000000}},	//   _písm_, _nhạt_, _ilħa, --,
   {{0xa3c70096,0x6e3a1cab,0x00000000,0x00000000}},	//   _उदा_, artb, --, --,
   {{0xd00e16cc,0xf1b902df,0xfc036e90,0xaa46b8ea}},	//   _على_, liš_, спро, легл,
   {{0x32050054,0xfaa30a2d,0x15f51bed,0x7e96071c}},	//   _july_, баро, ेदार_, _منور_,
   {{0xdb1c0034,0xa2c41178,0x6d560079,0x00000000}},	//   toró, िपत्, _ubya, --,
   {{0xa2da02e8,0x57ea2249,0x7ddd0042,0xfc320076}},	// [dfe0] _पुन्, едам_, xési, _احب_,
   {{0xf8bf098d,0x6d4601df,0xc1b000b6,0x6dab0022}},	//   _adés_, lgka, _जग्ग, nƙan,
   {{0x29d71f8d,0x2d8034b3,0x25a60150,0x2d920135}},	//   rçar_, _knie_, thol_, _koye_,
   {{0x6d4639a0,0xdb1c30e6,0xb5da0037,0x2d920032}},	//   ngka, poró, رباء_, _joye_,
   {{0x69c4a075,0x63b82188,0x2d800067,0x69d6b8eb}},	//   mnie, tivn, _mnie_, moye,
   {{0x69c47049,0x3205b8ec,0x6298b8ed,0x7ddd2c69}},	//   lnie, _buly_, tyvo, rési,
   {{0x63b87bd9,0xbcfbb8ee,0x25a6b8ef,0x645bb8f0}},	//   rivn, ndér, phol_, _epui,
   {{0xc0341d2e,0xb0340d06,0xe5a321be,0x645b009c}},	//   аниј, аниш, _лиси, _fpui,
   {{0xf99300a1,0x80dc0081,0x320500f9,0x69c4b8f1}},	//   מרה_, মেন্, _euly_, inie,
   {{0xbcfb31bb,0x65621d4b,0x224c013c,0x69d60027}},	//   zdés, leoh, _tqdk_, hoye,
   {{0x69c4b8f2,0xf1b90660,0x2d920044,0x7bd502c6}},	//   knie, biš_, _boye_, vozu,
   {{0x69c4b8f3,0xf1b90995,0x4ad200b6,0x69d600d7}},	//   jnie, ciš_, _दुइव, joye,
   {{0x69c428a6,0x7bd5b8f4,0x32050154,0x00000000}},	//   dnie, tozu, _zuly_, --,
   {{0x765cb8f5,0x6d46022e,0x69c41514,0x7f96020d}},	//   _opry, agka, enie, _pâqu,
   {{0xea0000de,0x9f4700b6,0x8cd51efb,0x7bd512fb}},	//   _phạt_, _jiný_, _युरो, rozu,
   {{0x69c4b8f6,0x391530fa,0x69d6b8f7,0x2d9201c2}},	//   gnie, рмар, goye, _goye_,
   {{0xa3e404dd,0xbcfb0068,0x20060063,0x65621d89}},	// [dff0] नता_, rdés, _juoi_, deoh,
   {{0x3f9e1236,0x7c2fb8f8,0x46a736f2,0x2d800031}},	//   nktu_, mscr, лшеб, _znie_,
   {{0x69c483ae,0x645b608e,0x7c2f1881,0xd7c80037}},	//   bnie, _spui, lscr, دوله_,
   {{0xdb1c003e,0xfe090023,0xd6d80f54,0x24190ae3}},	//   lorð, _hắc_, уту_, воды_,
   {{0xa5c50139,0x394b0113,0x7c2f2ac6,0x200600fe}},	//   _atóè, _iccs_, nscr, _nuoi_,
   {{0x6fdd05fe,0xd7f80235,0x386b0036,0x798d2af5}},	//   pèci, _бус_, _iscr_, ljaw,
   {{0xfe090019,0xaadb009f,0x39540072,0x6b7c00ca}},	//   _mắc_, _मुमक, _éasí_, תרונ,
   {{0x798d1a73,0xfe0900de,0x34952a84,0x2006b8f9}},	//   njaw, _lắc_, _кабр, _buoi_,
   {{0x78ad022b,0x200600de,0xb33c02a1,0x67270090}},	//   nzav, _cuoi_, _ilħn, _kejj,
   {{0x69c4959a,0x81bc0029,0x442fb8fa,0x20060023}},	//   znie, _svēt, msg_, _duoi_,
   {{0xf1b949d1,0xdee54ead,0x6727003d,0x7c3d6512}},	//   piš_, рони, _mejj, ersr,
   {{0x660702ef,0x38790220,0x81ab0065,0x81bc01d3}},	//   _mujk, _orsr_, _fáwọ, _dvēs,
   {{0x69d604ea,0xef0e5ae3,0x2d920c56,0x69c400d9}},	//   voye, _мм_, _voye_, vnie,
   {{0x69c40067,0xb92b00de,0x78ad050c,0x0cc60034}},	//   wnie, _thuỷ_, dzav, _लखीम,
   {{0x69c41511,0x69d6b8fb,0x21260d19,0xc9b61009}},	//   tnie, toye, _yeoh_, асањ,
   {{0x7c2f72a7,0x2d80b8fc,0xbcfb00d4,0x798d00dc}},	//   bscr, _unie_, rdér, gjaw,

   {{0x69c4b8fd,0x7d040193,0x316f0167,0x6727b8fe}},	// [e000] rnie, _igis, _magz_, _bejj,
   {{0x69c40029,0x998d0660,0x61e4003d,0x7c240065}},	//   snie, češ_, ċili, _iwir,
   {{0x672703e5,0x69c4b8ff,0x443d0034,0x9f5c022b}},	//   _dejj, pnie, erw_, _divè_,
   {{0x1e560130,0x7c240193,0x3ce00113,0x6442007b}},	//   ישער_, _kwir, _kyiv_, tuoi,
   {{0x7ddd61f8,0x9f4f0487,0x99980138,0x6fdd015e}},	//   mést, _jugó_, strų_, lècu,
   {{0xd25a11d9,0x7c241103,0x6727009e,0x6f030141}},	//   вци_, _mwir, _gejj, _ngnc,
   {{0x2006013d,0xfe670dd0,0x27ff00e5,0xf1a6037e}},	//   _suoi_, _بد_, _èuna_, ирин,
   {{0x20060465,0xa2da02e8,0x7c2f22d4,0x7d042cff}},	//   _puoi_, _पुण्, yscr, _ngis,
   {{0x2006025a,0x64a37775,0x67270361,0x9c8700d8}},	//   _quoi_, _дата, _yejj, _mlčí,
   {{0x2006013d,0x7d04b900,0x44240188,0x3ce90095}},	//   _vuoi_, _agis, _iwm_, _rzav_,
   {{0x44240197,0x78adb901,0xfe090023,0x660049e9}},	//   _hwm_, zzav, _rắc_, _kimk,
   {{0x200663fc,0xfe090028,0x4424006c,0x7c2fb902}},	//   _tuoi_, _sắc_, _kwm_, tscr,
   {{0xa2da121d,0x6ce700f3,0x98a20154,0x7c3d1183}},	//   _पुत्, ріне, _bekč_, ursr,
   {{0x09b102e8,0x69c8025a,0x7c2f0037,0x53d60251}},	//   ीच्य, éden, rscr, धविश,
   {{0x442401bb,0xff1700a1,0x2b5a022b,0x7ddd0042}},	//   _lwm_, _דקות_, _dbpc_, fést,
   {{0x4efb00a1,0x78ad0428,0x7ce10174,0x442f00f0}},	//   _בלוג, tzav, _ịrun, ysg_,
   {{0x798d113a,0x7c240150,0xfe090019,0x225e0167}},	// [e010] rjaw, _gwir, _tắc_, _lptk_,
   {{0x78ad04a3,0x7c223b82,0x7dc80233,0x00000000}},	//   rzav, _çora, hısl, --,
   {{0x41d6000f,0x17f80037,0x995c02c6,0xd7f8484c}},	//   डकास, شركة_, _síť_, рут_,
   {{0xeef7040a,0x7bc7033b,0x67270172,0x660001f9}},	//   במבר_, lnju, _wejj, _cimk,
   {{0x66006f51,0x4424b903,0x672718a8,0x3ce0023e}},	//   _dimk, _cwm_, _tejj, _xyiv_,
   {{0xfc3f0080,0x9cd800a1,0x3949b904,0xa34919a0}},	//   irí_, בודה_, lgas_, узка_,
   {{0x527500d3,0x38694c43,0x356b090f,0x92640037}},	//   сулу, lwar_, _иран_, قديم,
   {{0x39496739,0x442401fa,0xe7eb08d4,0x6d4d010a}},	//   ngas_, _fwm_, _जीता_, _ncaa,
   {{0x386903e3,0x394964a5,0xeae400c3,0x44244cca}},	//   nwar_, igas_, _गर्त_, _gwm_,
   {{0xf8b200ca,0x6d4d007e,0xfc3f00ee,0x38690022}},	//   פשי_, _acaa, drí_, iwar_,
   {{0x9f470472,0x59c742d4,0x4424022e,0x75290361}},	//   _sinó_, रचार, _zwm_, _keez,
   {{0xcb0900a1,0x4424022e,0x6d4d0172,0x386901c2}},	//   _טל_, _ywm_, _ccaa, kwar_,
   {{0x442401bb,0xfc3f0428,0x9f470383,0x7529b905}},	//   _xwm_, grí_, _dinò_, _meez,
   {{0x3869b906,0x3cdc00b7,0xdb1c0052,0x7bc709ac}},	//   dwar_, _गुणे_, mirë, gnju,
   {{0x4ad204a9,0x68e301d4,0xfaa33e1c,0xaca40174}},	//   _दुखव, əndi, паро, moọk,
   {{0x09060c2d,0x3949b907,0x7c2405bd,0xfc3fb908}},	//   спан, ggas_, _twir, brí_,
   {{0xea0000ef,0xa3d7149b,0x249d023e,0xeb9a8446}},	// [e020] _nhất_, सवा_, jywm_, _бип_,
   {{0x69ddb909,0x6609015c,0xe8f70408,0x7ddd00b3}},	//   _ekse, _čekr, слу_, béss,
   {{0x75299dd5,0x7bde0134,0x44241938,0x386901c2}},	//   _beez, _ikpu, _swm_, awar_,
   {{0x4424022e,0x998600e3,0x7ddd0103,0x00000000}},	//   _pwm_, _الحو, lésr, --,
   {{0xea000028,0x7529b90a,0x44240113,0x00000000}},	//   _chất_, _deez, _qwm_, --,
   {{0x4424006c,0x29de00f0,0xd5b20470,0x69c1020d}},	//   _vwm_, rïau_, _کفر_, élev,
   {{0x7bde00ac,0x752906b0,0x29de00f0,0xdb150131}},	//   _mkpu, _feez, sïau_, lizã,
   {{0x44249557,0x914a37f2,0xdb1c0052,0xdb1505f1}},	//   _twm_, учка_, firë, vizí,
   {{0x7bde00ac,0x7ddd0103,0x4f2a018a,0x01330076}},	//   _okpu, zéss, лінг_, سعيد,
   {{0xc3220081,0x7bde0129,0x7529029a,0xa3e40096}},	//   _নাকি_, _nkpu, _zeez, नतळ_,
   {{0x8c0000c7,0x11d62917,0x394900c6,0xb7db0142}},	//   ্ঠান_, _людя, ygas_, רקיי,
   {{0x69c80018,0xc69300a1,0x7bde0294,0xfc3f0181}},	//   édel, לאת_, _akpu, trí_,
   {{0x9f3400f3,0x00000000,0x00000000,0x00000000}},	//   _делі, --, --, --,
   {{0x7ddd0103,0x00000000,0x00000000,0x00000000}},	//   téss, --, --, --,
   {{0x0f5709c1,0xfe090019,0x3d9516bd,0x3949b90b}},	//   _היום_, _hắn_, _микр, tgas_,
   {{0x7bde0129,0x3949013f,0x7bc70117,0xdd2100d2}},	//   _ekpu, ugas_, snju, lůžk,
   {{0xa2da0961,0x23ab052f,0x75290063,0x386901c2}},	// [e030] _पुस्, _høje_, _reez, uwar_,
   {{0x3869006d,0x3949b90c,0xfe0900de,0x7529b90d}},	//   rwar_, sgas_, _mắn_, _seez,
   {{0x38692d17,0x46d90034,0x6b85078e,0x00000000}},	//   swar_, _बुशह, _inhg, --,
   {{0x69dd00aa,0xea0000fe,0x78bb00c6,0x00000000}},	//   _ukse, _phất_, _žuvu, --,
   {{0x27ff0451,0x5fc8045f,0xe9df026e,0xfe0900fe}},	//   _èuno_, िचाल, _ikú_, _nắn_,
   {{0x80dc000f,0xe2990012,0x00000000,0x00000000}},	//   _पड़े, иал_, --, --,
   {{0x2560022b,0xa18900c2,0x23ab0537,0x00000000}},	//   _bčlč_, ибка_, _nøje_, --,
   {{0xea000028,0xfe090019,0xdb1c023b,0x7ddd0103}},	//   _thất_, _bắn_, tirë, zésr,
   {{0xfe0900de,0xaadb0caf,0xae031926,0x2492004d}},	//   _cắn_, _मुसक, _रंजन_, øymt_,
   {{0x533428c2,0x9c140174,0xa3e405d6,0x23ab0537}},	//   _неут, _wọks, नतः_, _bøje_,
   {{0x02a70360,0xdb1c023b,0x938800b4,0x8d6622ff}},	//   _урам, sirë, _уста_, овне,
   {{0x82d600c1,0xe9df6b7b,0x23670087,0x7d090138}},	//   _וועג_, _nkú_, lenj_, žesn,
   {{0x22470018,0xfe090019,0x399c00b6,0x7ddd0103}},	//   lunk_, _gắn_, _míst_, tésr,
   {{0xbea51880,0x98a20029,0xb4fa0089,0xe9df0031}},	//   _малк, _nekā_, יפרי, _akú_,
   {{0x91780af0,0x224701f9,0x00000000,0x00000000}},	//   _jé̟_, nunk_, --, --,
   {{0x628700fd,0xdce40995,0x7c220216,0x00000000}},	//   _àjou, _naić, _çoro, --,
   {{0xe9d70f1e,0xfe0900de,0x48e31107,0x7ddd01f9}},	// [e040] іку_, _xắn_, дотв, pésr,
   {{0x9b460103,0xe9df0065,0x236763aa,0x7ddd020d}},	//   _بندو, _ekú_, jenj_, lésp,
   {{0xa6ca00e3,0x2247b90e,0x7bdcb90f,0x7dd60103}},	//   جوال_, junk_, moru, dász,
   {{0xa2da000c,0x22470103,0xae5a006e,0x69c10103}},	//   _पुष्, dunk_, יכער, élet,
   {{0xdb150fd9,0xb87b0018,0x7986b910,0x938a1167}},	//   lizá, _szív, _inkw, иска_,
   {{0x7bdc5d47,0xfe0900de,0x7a150034,0x7dd60103}},	//   noru, _rắn_, _wąte, gász,
   {{0xdb1530a5,0xe5a664e9,0xa2da074c,0x22470103}},	//   nizá, _диви, _पुश्, gunk_,
   {{0xf1260c10,0x00000000,0x00000000,0x00000000}},	//   цько, --, --, --,
   {{0x75221fe5,0xa2da1efb,0x54ee0034,0xc35600e5}},	//   mboz, _पुर्, _जरिए_, _мъжъ,
   {{0x6d40003e,0x91780032,0xfe0900fe,0x7bdc80e5}},	//   óman, _fé̟_, _vắn_, joru,
   {{0x7986010a,0xa3d700a4,0x00000000,0x00000000}},	//   _onkw, सवर_, --, --,
   {{0xd83f0146,0x79860294,0xdced042d,0xfe0900fe}},	//   íčku_, _nnkw, _snađ, _tắn_,
   {{0xb87b0139,0xa2be9ee8,0x00000000,0x00000000}},	//   _ayín, _वेत्, --, --,
   {{0xbebc0029,0x7bdca514,0x23bc1677,0x7986b911}},	//   rbīb, goru, ्चिद, _ankw,
   {{0xda7808d8,0x64420cc2,0x7e2a004d,0x7d16030a}},	//   оят_, hroi, _тіла_, _ffys,
   {{0x7ddd037a,0x00000000,0x00000000,0x00000000}},	//   césp, --, --, --,
   {{0x22470103,0x6d5f0139,0x7dd601f9,0x00000000}},	// [e050] zunk_, _ibqa, yász, --,
   {{0x7bdcb912,0x5ba71510,0x81c20081,0x798686eb}},	//   coru, _фриз, ৃতি_, _enkw,
   {{0xa2da00df,0x2367033b,0xf5180174,0x69c10103}},	//   _पुल्, venj_, _ịtụp, éles,
   {{0x671b148e,0x48c90081,0x644200fd,0x9f470076}},	//   _प्रक_, _শরীর, froi, _mhná_,
   {{0x6442b913,0x399c003e,0xfbd02c31,0x638505ed}},	//   groi, _víst_, _ستی_, згла,
   {{0x22470018,0x78fa00ca,0xdb1c020d,0x8c1c0266}},	//   tunk_, _לפרו, tiré, סווי,
   {{0x3f890019,0xe299b914,0x00000000,0x00000000}},	//   _đau_, сай_, --, --,
   {{0x7bdcb915,0x22470103,0x9f5c5021,0x92fe0033}},	//   zoru, runk_, _diví_, ুরূপ_,
   {{0x7bdc074e,0x201901e5,0xdb0e0797,0x6442b916}},	//   yoru, ësi_, ribú, croi,
   {{0x224701f9,0xdb1c014b,0x6d5f01ee,0xddc90206}},	//   punk_, piré, _abqa, ludň,
   {{0x7bdc044c,0x7c3600c6,0x00000000,0x00000000}},	//   voru, _svyr, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bdc0012,0x00000000,0x00000000,0x00000000}},	//   toru, --, --, --,
   {{0xdb15b917,0x96bd0179,0xe1f90138,0x200b0206}},	//   tizá, ्पाउ, lmų_, íciu_,
   {{0x753b02e6,0x6da633ed,0x7bdcb918,0xdee21ba5}},	//   _oduz, _ника, roru, _поши,
   {{0x7d760241,0x7bdcb919,0x753bb91a,0xdb15b91b}},	//   _رابط, soru, _nduz, rizá,
   {{0x661b0307,0xfe090023,0xf8c63ec9,0x00000000}},	// [e060] _čuka, _mắm_, लपेप, --,
   {{0xfe090028,0x46f60cba,0x753b0231,0x00000000}},	//   _lắm_, пчет, _aduz, --,
   {{0xfe050253,0xdd8f00d1,0x8b9b0327,0xfc3f01f9}},	//   _üçün_, _شوی_, _הבית, szít_,
   {{0xfe0900de,0x80dc0096,0xb33c02a1,0x00000000}},	//   _nắm_, _पडले, _ilħi, --,
   {{0x397b00ca,0x320c00d4,0x00000000,0x00000000}},	//   _הטכנ, _sudy_, --, --,
   {{0x64426ee3,0x753b1ccd,0x320c00d8,0x00000000}},	//   rroi, _eduz, _pudy_, --,
   {{0x27f700b6,0x3f98003e,0x48f6023a,0x21cc00d2}},	//   řené_, örum_, ्शको_, běhl_,
   {{0xfe0900de,0x7ae10364,0x3e7a01d3,0x9f5c034f}},	//   _cắm_, ülti, _rīt_, _viví_,
   {{0xb87b0018,0x660e008a,0x80a60034,0x6560009c}},	//   _nyíl, _hubk, गनें, _ibmh,
   {{0x995c02c6,0x00000000,0x00000000,0x00000000}},	//   _níž_, --, --, --,
   {{0x1df9007b,0x68e602ac,0x00000000,0x00000000}},	//   жены_, _lykd, --, --,
   {{0x7ae500c2,0xfe0900fe,0x60cd0117,0x3f87058f}},	//   _ryht, _gắm_, _žame, _ennu_,
   {{0x61e203e5,0xa2c41677,0x673c00c4,0xf1b300ca}},	//   _ikol, िपक्, _odrj, _אסף_,
   {{0x9f5c0231,0x53dc023a,0x661c00e8,0x00000000}},	//   _divã_, मकिश, _otrk, --,
   {{0xb91a0857,0x1f5b00ca,0x61e26fdd,0xaf5b00ca}},	//   _ọtụt, _הדוא, _kkol, _הכוכ,
   {{0xf7730814,0x61e203e5,0x1994008f,0x3a3f00d4}},	//   کار_, _jkol, нася, čup_,
   {{0xa3dc009d,0xa2be0ed5,0x661c00c4,0x61e20a4b}},	// [e070] ठवा_, _वेस्, _atrk, _mkol,
   {{0x61e20078,0x501b2252,0x00000000,0x00000000}},	//   _lkol, צובו, --, --,
   {{0x36340037,0xf7703a89,0xe1f90138,0xb904052c}},	//   فرنس, داق_, ymų_, _पु_,
   {{0x25a60899,0x6d4fb91c,0x61e20517,0x656001b9}},	//   gkol_, ngca, _nkol, _cbmh,
   {{0x69cd00cc,0x76430103,0x6560009c,0xfe09020b}},	//   mnae, ányb, _dbmh, _rắm_,
   {{0xfe090019,0x61e283c5,0xa2e500ae,0x050d0033}},	//   _sắm_, _akol, молд, শরের_,
   {{0x61e20090,0xe3b00037,0x00000000,0x00000000}},	//   _bkol, درن_, --, --,
   {{0x69cdb91d,0x6d5d01c0,0x23606126,0x753b013c}},	//   nnae, jfsa, đija_, _uduz,
   {{0xbf05034d,0xe1f90138,0x50b50f2e,0xbcfb020d}},	//   रश्न_, rmų_, ьску, nféd,
   {{0xee3945b1,0xdb1e0257,0x644b7f0d,0x2d892353}},	//   оно_, _empê, mugi, _anae_,
   {{0x644bb91e,0x9d462246,0xdb08025a,0xfe090019}},	//   lugi, менд, _élém, _tắm_,
   {{0x9f453154,0x656b028d,0x2d890328,0x61e20154}},	//   illé_, negh, _cnae_, _gkol,
   {{0x61fb0517,0x64596178,0x644b0900,0x69cd0d62}},	//   mmul, ntwi, nugi, dnae,
   {{0x61e90006,0x61fb00d3,0x68e60313,0x656b0294}},	//   llel, lmul, _rykd, hegh,
   {{0xea000028,0x4adb0251,0x09e63574,0x25bf00d3}},	//   _chết_, _मुआव, довн, _omul_,
   {{0x61e92897,0x20070350,0x644b18e0,0xfe0900fe}},	//   nlel, _hini_, kugi, _lắk_,
   {{0x2007b91f,0x09e3224a,0xa3dd030b,0x23dd077d}},	// [e080] _kini_, тотн, णका_, यवाद,
   {{0x6281b920,0x2007b921,0x68e6013f,0x200f7118}},	//   _orlo, _jini_, _vykd, _mugi_,
   {{0x200f6aa7,0x200772ce,0xdb1c0143,0x463a0fe9}},	//   _lugi_, _mini_, nirí, ючая_,
   {{0x644bb922,0xea000028,0x64590134,0x2007b923}},	//   fugi, _đặc_, ftwi, _lini_,
   {{0x61e9067d,0x6281b924,0xb3a90096,0x644bb925}},	//   dlel, _arlo, कसंख, gugi,
   {{0x61e21f2f,0x2007b926,0x61fbb927,0xdce60094}},	//   _skol, _nini_, emul, jekč,
   {{0x661c0268,0x7996006c,0x644b0138,0xa2be034d}},	//   _utrk, ojyw, augi, _वेश्,
   {{0x2007b928,0x30a60581,0x200fb929,0x61fb00a6}},	//   _aini_, дров, _bugi_, gmul,
   {{0x200754b8,0xc05a00d6,0xe1120134,0x62816a16}},	//   _bini_, цій_, _bụrị, _erlo,
   {{0x200704eb,0x61e203e5,0xb4aa09d0,0x61fb4145}},	//   _cini_, _wkol, खनी_, amul,
   {{0x2007b92a,0xdb1e01dc,0x200f01ff,0xdb1c2df7}},	//   _dini_, _impè, _eugi_, girí,
   {{0x61e2b92b,0x200777f3,0x61e9b92c,0x200fb92d}},	//   _ukol, _eini_, clel, _fugi_,
   {{0x2007b92e,0x61e00124,0xd90f00cd,0xd378007e}},	//   _fini_, moml, یید_, _kać_,
   {{0x2007b92f,0x09c7009d,0x9f5800c2,0xea0000fe}},	//   _gini_, रच्य, örä_, _phết_,
   {{0x69cd04a3,0x9f4e0139,0xdb1c0328,0x656b0294}},	//   tnae, _fifò_, cirí, yegh,
   {{0x2007b930,0xdb0700c2,0x61e0b931,0x644b0063}},	//   _zini_, kijö, noml, yugi,
   {{0x2007067d,0x656b00d3,0x7d0db932,0x3f9c6e71}},	// [e090] _yini_, vegh, _igas, _kovu_,
   {{0x656b06c0,0x69cd0580,0x644b023f,0xd37802f7}},	//   wegh, snae, vugi, _nać_,
   {{0x656b0294,0x20ca009d,0x61e0b933,0xa2be274c}},	//   tegh, ापुढ, koml, _वेल्,
   {{0x7c2db934,0x3f9c1fce,0x644bb935,0x91fc01d3}},	//   _kwar, _lovu_, tugi, _spān,
   {{0x7d0d0124,0x61e037b4,0x7c2d00bd,0x78a40027}},	//   _mgas, doml, _jwar, cyiv,
   {{0x3f9c02e6,0x200f0918,0x7c2d4ee2,0xe6672dfb}},	//   _novu_, _rugi_, _mwar, _отбо,
   {{0x61fba447,0xc2e70033,0x644bb936,0x7d0db937}},	//   tmul, গেনি_, sugi, _ogas,
   {{0x200703b4,0x7d0d3946,0xdb1e02cd,0x7c2d03a9}},	//   _sini_, _ngas, _empè, _owar,
   {{0x2007b938,0x61e950ef,0x3ce901fa,0x321e0113}},	//   _pini_, rlel, _nyav_, _etty_,
   {{0x442d6d39,0x7d0db939,0x61fb84d6,0x61e905f1}},	//   _iwe_, _agas, smul, slel,
   {{0x2007b93a,0x6609b93b,0x7d0d0174,0xddc62383}},	//   _vini_, _kiek, _bgas, ебни,
   {{0x2007022b,0x442db93c,0x8d7606fa,0xdb1e2e00}},	//   _wini_, _kwe_, راجا, _impé,
   {{0x2007b93d,0x442d0c56,0x5e5600cd,0x6609b93e}},	//   _tini_, _jwe_, ولیس_, _miek,
   {{0x6609b93f,0x7c2d3769,0x442d35e0,0x7d0d06b0}},	//   _liek, _dwar, _mwe_, _egas,
   {{0x442d86b9,0x799d18f0,0x69c40364,0x7c2d039f}},	//   _lwe_, _bosw, tiie, _ewar,
   {{0x6609b940,0x442db941,0x3f9c0039,0xed640146}},	//   _niek, _owe_, _zovu_, _drží_,
   {{0x7c2db942,0x186706d5,0x6d56023f,0x17860077}},	// [e0a0] _gwar, нати_, _icya, нгам,
   {{0x5c5b00f5,0xf99f0113,0x660901ff,0x61e06789}},	//   _צדיק, _hièl_, _aiek, zoml,
   {{0x7c2d4020,0x34a800c3,0x6609b943,0x442d756f}},	//   _zwar, कन्द, _biek, _awe_,
   {{0x442d3bc5,0x660900a5,0x14c800cd,0xa2da030b}},	//   _bwe_, _ciek, وهای_, _पुग्,
   {{0xfb0b0a00,0xb4aa0067,0x66090da3,0x442d0a0a}},	//   _óëñ_, खने_, _diek, _cwe_,
   {{0x442d14b1,0x6dab0022,0xd2501374,0x00000000}},	//   _dwe_, nƙar, لنت_, --,
   {{0x442db944,0x387202ad,0x9294013f,0x48fc00c3}},	//   _ewe_, lwyr_, тайц, लेरो_,
   {{0xd13000e3,0x395200f0,0x3f9c0169,0x00000000}},	//   جمة_, ngys_, _sovu_, --,
   {{0x442db945,0x38720150,0xdb1e16e7,0x6b9e057a}},	//   _gwe_, nwyr_, _empé, _oopg,
   {{0x66090ab2,0x7c2d0193,0x61e02150,0x6d560169}},	//   _ziek, _rwar, soml, _acya,
   {{0x7c2db946,0x38720150,0x442d019f,0x63a5042c}},	//   _swar, hwyr_, _zwe_, öhne,
   {{0x717300cd,0xdd120511,0xa1ba071c,0x7dc800a7}},	//   _مهما, rüşm, _عطاء_, xıst,
   {{0x69c100fd,0x8fa62cb3,0x7d0d05db,0xc19b00ca}},	//   èlem, _паде, _vgas, _משאי,
   {{0x387202ad,0x3f9c411d,0xf4120033,0xd007002d}},	//   dwyr_, _uovu_, _হবার_, _зече_,
   {{0x2bd20096,0xf99f0154,0x6b9e1bf0,0xfbd200b6}},	//   _सदरा, _fièl_, _dopg, _सदरम,
   {{0x7d0d41e3,0x7c2db947,0xdb1c016d,0x6dab0d2a}},	//   _ugas, _twar, tirã, rƙas,
   {{0x7ddd0018,0x7c2db948,0x38720150,0x6609b949}},	// [e0b0] kész, _uwar, gwyr_, _riek,
   {{0x6609568f,0x442db94a,0x2cb3008b,0x7ae10103}},	//   _siek, _rwe_, ındı_, ülts,
   {{0x6609959a,0x7bc70c3f,0x6e3a4e5d,0x799d010a}},	//   _piek, miju, nstb, _tosw,
   {{0x7bc7b94b,0xdb1c5991,0x27e12a52,0x442d0248}},	//   liju, mirá, sohn_, _pwe_,
   {{0x75240143,0x00000000,0x00000000,0x00000000}},	//   ñiza, --, --, --,
   {{0x7bc7b94c,0x64a25e0d,0x7ddd0018,0x660900a5}},	//   niju, раша, gész, _wiek,
   {{0x2256172a,0x66097a91,0x248400dc,0xdb1c4c36}},	//   نلود_, _tiek, _ermm_, nirá,
   {{0xceb800a5,0x442d0193,0x2019016d,0x00000000}},	//   dzę_, _twe_, ísio_, --,
   {{0x442db94d,0x44390649,0x7bc7b94e,0xf99f0154}},	//   _uwe_, _ìs_, kiju, _nièm_,
   {{0x657bb94f,0xa28300cd,0x7bc73565,0x645b9b57}},	//   _hauh, _میتو, jiju, _iqui,
   {{0x273c030b,0x657bb950,0x7bc76b36,0x22640094}},	//   lání_, _kauh, diju, čská_,
   {{0x657b5d6a,0xdb1c0610,0xf99f1da6,0x30850037}},	//   _jauh, dirá, _noè_, _للصف,
   {{0x853a00a1,0x273c030b,0x657b00f9,0x00000000}},	//   וגרי, nání_, _mauh, --,
   {{0x8fa20a95,0x2d99023b,0x657bb951,0x7bc7b952}},	//   _ваше, ajse_, _lauh, giju,
   {{0xdb1c45aa,0x273c00b6,0xceb80034,0x75f84691}},	//   girá, hání_, czę_, líze,
   {{0x273c030b,0x9f450076,0x657bb953,0x66e50336}},	//   kání_, illí_, _nauh, _कड़क_,
   {{0x26170396,0x2d5a02dd,0x7bc7b954,0x645b002b}},	// [e0c0] _aço_, _všeč_, biju, _nqui,
   {{0x273c000d,0x387202ad,0xdb1c04d8,0xd9f40096}},	//   dání_, rwyr_, birá, _आठवत_,
   {{0x1dc60971,0x7ddd0018,0x38720150,0xdb1c0328}},	//   _लगात, vész, swyr_, cirá,
   {{0xe9a624f7,0x2d5a0141,0x00000000,0x00000000}},	//   _рамп, _ušeč_, --, --,
   {{0x779100d0,0x00000000,0x00000000,0x00000000}},	//   _گیلا, --, --, --,
   {{0x7c220233,0x00000000,0x00000000,0x00000000}},	//   _çoru, --, --, --,
   {{0x645b3446,0x877b006e,0x7ddd0103,0x13390018}},	//   _equi, _קאלי, rész, رتوں_,
   {{0x28c72fc2,0x80e00081,0x167700a1,0x7bc7b955}},	//   _रेडि, _পৃষ্, _בגלל_, ziju,
   {{0x394200dc,0xb465001c,0xdfda00e5,0x26180ff9}},	//   _mdks_, _مدله, дън_, _बंडी_,
   {{0xaadb0ed3,0xdce400cb,0xc60000ac,0x6e3a029a}},	//   _मुझक, _naiđ, _ịchọ, tstb,
   {{0xdd910678,0x777cb956,0x4426b957,0x42562ec2}},	//   مود_, _marx, lpo_, _штат,
   {{0x23690039,0x75f800b6,0x6e3a18ef,0x44260239}},	//   đaje_, bíze, rstb, opo_,
   {{0xceb80067,0x4426b958,0x5c74121a,0xba7400d1}},	//   szę_, npo_, алят, یافت,
   {{0x442611ce,0xdb1c9be2,0x8f344993,0xfe6f010d}},	//   ipo_, tirá, _секц, حدی_,
   {{0x273c00b6,0x7bc7b959,0xcb3400e5,0x00000000}},	//   zání_, riju, ресъ, --,
   {{0x1e970054,0x7bc701b3,0x44260129,0xdb1c0610}},	//   _יכול_, siju, kpo_, rirá,
   {{0x657b0084,0x7bc7013f,0xb33c0078,0x777cb95a}},	// [e0d0] _rauh, piju, _moħb, _barx,
   {{0x273c033a,0x76430018,0x2ca40212,0x7d1d0103}},	//   vání_, ányo, ämde_, lcss,
   {{0x39580031,0xdce402a1,0x7bc50027,0x645bb95b}},	//   _šesť_, _iniġ, _imhu, _squi,
   {{0x79952863,0x7d0901d3,0xa4390d6f,0x273c00b6}},	//   _симф, _tīrī, езду_, tání_,
   {{0x44260bb6,0x798f09cc,0x777c008a,0x657b00c2}},	//   gpo_, _incw, _farx, _vauh,
   {{0x273c00b6,0xfe0a00fe,0xdce400bd,0x60cd00c4}},	//   rání_, _hắt_, _jniġ, _žamo,
   {{0x657bb95c,0x4426b95d,0xdce40090,0x16340fe9}},	//   _tauh, apo_, _mniġ, _веся,
   {{0x387900dc,0x273c00b6,0x96f800ae,0x00000000}},	//   _kssr_, pání_, _рест_, --,
   {{0xfe0a0028,0x60090243,0x7bc5b95e,0x6717007f}},	//   _mắt_, нним_, _omhu, _तलाक_,
   {{0x777c0990,0x443fb95f,0x53b7009d,0x23770103}},	//   _xarx, _ivu_, _अतिश, _جارح,
   {{0xada6007e,0x6da6016e,0xdb1c0088,0x66157944}},	//   ганл, гина, gnrý, _juzk,
   {{0x644b5cd6,0x7bc501b9,0x63a10103,0x3f8e0172}},	//   orgi, _amhu, _holn, _enfu_,
   {{0x443d0085,0x63a1b960,0x628e8d54,0x00000000}},	//   nsw_, _koln, _àbor, --,
   {{0x317f01e9,0xc2f60033,0x69c102d5,0x673500d4}},	//   lduz_, _চলতি_, रोसी, _nezj,
   {{0xd946455b,0xfe0a0028,0x63a1b961,0xc3320796}},	//   леви, _bắt_, _moln, מום_,
   {{0x443f03ce,0xfe0a0019,0x317fb962,0x39590113}},	//   _ovu_, _cắt_, nduz_, _ccss_,
   {{0xe9d7534b,0xfe0a0023,0x6d440634,0x386b0027}},	// [e0e0] укт_, _dắt_, _idia, _cpcr_,
   {{0x7c24b963,0x777c0188,0x6b563031,0x26180980}},	//   _itir, _qarx, _стих, _बंदी_,
   {{0x2b5a022b,0xfaa62012,0x98ab00e8,0x46f60392}},	//   _icpc_, _сано, _vecā_, учат,
   {{0x35e516dd,0x63a1009c,0x38790113,0xfe0a0023}},	//   аців, _aoln, _fssr_, _gắt_,
   {{0x777cb964,0x69c6b965,0x44263c41,0x66150634}},	//   _tarx, _imke, upo_, _euzk,
   {{0x66e60636,0x63a1b966,0x7c240239,0x00000000}},	//   _бога, _coln, _mtir, --,
   {{0x63a17981,0x443f765d,0x27ea061d,0x644b2e07}},	//   _doln, _evu_, _ikbn_, argi,
   {{0x44260465,0x6d4400e3,0x7c2414f3,0xfe0a00fe}},	//   ppo_, _ndia, _otir, _xắt_,
   {{0x7c2402a4,0x63a12a4e,0x6615b967,0x661b0095}},	//   _ntir, _foln, _zuzk, _čuki,
   {{0x4424b968,0x6d443c46,0x660201c2,0x63a1b969}},	//   _itm_, _adia, lmok, _goln,
   {{0x7c24b96a,0x05160081,0xb2264444,0x9f670450}},	//   _atir, ারীর_, _смел, урыз_,
   {{0xac192877,0x38608779,0x7a1500a5,0x2b5a00b3}},	//   кому_, ktir_, _wątk, _acpc_,
   {{0x4424b96b,0xdb1e04c3,0x6d4400f0,0x62880094}},	//   _jtm_, _empí, _ddia, _hrdo,
   {{0xfe0a0019,0x69c800fd,0x46b40096,0x69c60a4b}},	//   _sắt_, èden, ंनाह, _amke,
   {{0x7c240092,0x66022d34,0x00000000,0x00000000}},	//   _etir, kmok, --, --,
   {{0x386038b6,0xbebc00e8,0x6d5a01f9,0x8e470076}},	//   ftir_, ecīg, őtar, _إليك_,
   {{0x9817012b,0x200e0d2a,0x2a7a007e,0xfe0a0023}},	// [e0f0] ابرا, _kifi_, _espb_, _vắt_,
   {{0xd6db3e28,0x6288b96c,0xfc3f0037,0x7bc5601c}},	//   нте_, _ordo, msí_, _umhu,
   {{0x443f04a3,0xd6db57a3,0xfe0a0019,0x63a100a5}},	//   _svu_, хта_, _tắt_, _roln,
   {{0x63a10973,0x00000000,0x00000000,0x00000000}},	//   _soln, --, --, --,
   {{0x63a157b6,0x6288b96d,0x228301e8,0x493a00a1}},	//   _poln, _ardo, _sık_, _בגרו,
   {{0x62881197,0x8c1c006e,0x443f51d2,0xfc3f4232}},	//   _brdo, עווי, _vvu_, isí_,
   {{0xe2993c97,0x63a1647b,0x5b580054,0xea0000de}},	//   тай_, _voln, אשון_, _chặt_,
   {{0x63a100a5,0x200e283d,0x6283b96e,0x48fc030b}},	//   _woln, _aifi_, rvno, लेको_,
   {{0x6288b96f,0x65690027,0x339505bc,0x4f9504d9}},	//   _erdo, _ibeh, _پلاز, арну,
   {{0xb06800e3,0x0e653898,0x9e6501b3,0xae190714}},	//   اصيل_, акон, авод, _नंदन_,
   {{0xf772004f,0x75f808a8,0x28c740c1,0x4299029e}},	//   חקי_, líza, _रेसि, _جناح_,
   {{0x386001cd,0x44246ac0,0x2b5a0231,0x261800a3}},	//   ytir_, _ytm_, _scpc_, _बंसी_,
   {{0x200e026e,0xd1b800cd,0x5576006e,0x75f80042}},	//   _fifi_, _حالا_, בערן_, níza,
   {{0xbcfb0088,0x61e43fa3,0x7c2405db,0x00000000}},	//   mfél, čile, _vtir, --,
   {{0xdb250018,0x6569b970,0xeb9737f2,0xdb1c09a1}},	//   ásár, _obeh, шир_, virä,
   {{0x3860b971,0x13d2058f,0xa92601b6,0x6846107a}},	//   ttir_, _तद्भ, рдал, инба,
   {{0xfbdf0bfe,0x2d9200ac,0xa3e5007a,0x9f470094}},	// [e100] guês_, _inye_, नवा_, _akné_,
   {{0x320f0146,0xf7720037,0xdb1c0076,0x65696b52}},	//   _ligy_, غاء_, rnró, _abeh,
   {{0x38609867,0x2fc7005c,0x66020449,0xdb1e00b3}},	//   stir_, _mmng_, tmok, _impà,
   {{0x3860b972,0xb8cc0033,0x636600d2,0x2d82058f}},	//   ptir_, _কই_, _oční, ndke_,
   {{0x69d6b973,0x66023671,0x62880234,0x00000000}},	//   mnye, rmok, _srdo, --,
   {{0x051600c7,0x66020b62,0x2fc700f9,0xdb2000cd}},	//   ারের_, smok, _nmng_, èwèk,
   {{0x2d920857,0xa59600d6,0x69d60010,0x95960291}},	//   _onye_, _кращ, onye, _краљ,
   {{0x236900e9,0x69d6199e,0x2fc70124,0xb95b0139}},	//   đaja_, nnye, _amng_, _amìj,
   {{0x442400dc,0x73761402,0xbcfb0155,0x25a4033c}},	//   _utm_, _выех, gfél, _ioml_,
   {{0x2d92b974,0x81460260,0x1fa600ae,0x69d600dc}},	//   _anye_, _چنان, рриг, hnye,
   {{0x2d80040c,0x248601c5,0xc2240068,0x212d0036}},	//   _baie_, lvom_, _اکتو, bbeh_,
   {{0x200eb975,0x2fc70085,0x2cab0381,0xdce6007f}},	//   _wifi_, _emng_, tycd_, zeką,
   {{0xa3ca10ed,0x2d80061d,0x2d920154,0x3a2600c4}},	//   _लगा_, _daie_, _dnye_, _čopa_,
   {{0x2d927070,0xfd1f0451,0x2d850034,0xfc3fb976}},	//   _enye_, scì_, śle_, rsí_,
   {{0xf9c7013d,0x1995013d,0xb87b0103,0xfb8401b3}},	//   ащан, бавя, _nyír, цыян,
   {{0x248602e6,0x39153397,0xdb1e00b3,0x24890206}},	//   kvom_, смар, _empà, ťami_,
   {{0xa3d60454,0x3dc900f9,0x00000000,0x00000000}},	// [e110] ाचा_, _imaw_, --, --,
   {{0x2d8001e9,0x69d600b3,0xe70b0286,0x00000000}},	//   _zaie_, anye, نتان_, --,
   {{0x7515054f,0xa8020072,0x00000000,0x00000000}},	//   مواض, íñan, --, --,
   {{0x2419055b,0xb99500e3,0xdb1e002b,0xbcfb0103}},	//   годы_, _الحب, _impá, yfél,
   {{0xb8cc00c7,0x320f01c2,0x24890131,0x784400d3}},	//   _কে_, _rigy_, íam_, _мэрж,
   {{0xfe0a0019,0x75f803be,0x69cd0150,0x6a14001c}},	//   _lắp_, ríza, liae, _دبیر,
   {{0x3875026a,0x0bb800ca,0xdd2c00c6,0x00000000}},	//   şarı_, שלום_, _lėšo, --,
   {{0x224900e9,0x69cd02ad,0x6569a06e,0xfe0a0023}},	//   čak_, niae, _ubeh, _nắp_,
   {{0x78adb977,0x95c8256d,0x2d80b0d3,0x00000000}},	//   nyav, _тура_, _raie_, --,
   {{0x3fb700c7,0xbcfb0088,0x67f00084,0x23b9022b}},	//   ীক্ষ, rfél, täji, _bèje_,
   {{0xbebc0029,0xfe0a00de,0xdee535c1,0xbcfb0155}},	//   ecīb, _bắp_, сони, sfél,
   {{0xed575e6f,0xfe0a00de,0xea0000de,0x260a0096}},	//   бою_, _cắp_, _đắc_, िषयी_,
   {{0x3f69282a,0x69cd0150,0x98a00580,0x61e900b7}},	//   _било_, diae, mbić_, moel,
   {{0x09d00096,0x61e950f8,0x00000000,0x00000000}},	//   सच्य, loel, --, --,
   {{0x2d8000ae,0x24860220,0x2d9200dc,0x69cd14ef}},	//   _taie_, zvom_, _tnye_, fiae,
   {{0x69cdb978,0x2ef8042c,0x2d92010a,0xfe0a00fe}},	//   giae, ürfe_, _unye_, _gắp_,
   {{0x69d6a662,0xb7160037,0x00000000,0x00000000}},	// [e120] rnye, مباش, --, --,
   {{0x61e903a8,0x00000000,0x00000000,0x00000000}},	//   hoel, --, --, --,
   {{0x6b7b0c6a,0x7bce019f,0x61e93fb7,0xaca40174}},	//   _גרינ, mibu, koel, knịk,
   {{0x24860c0b,0x84460037,0x61e923de,0x7bce2bd4}},	//   tvom_, مختل, joel, libu,
   {{0x61e916b4,0x78ad0169,0x7bce0350,0x00000000}},	//   doel, cyav, oibu, --,
   {{0xf99f0c56,0x9f58026a,0x75f80206,0x00000000}},	//   _chèf_, örü_, cízn, --,
   {{0xb2861119,0xe7dd009d,0x7d160150,0x9c870220}},	//   сылк, _मदतप, _ogys, _kočí,
   {{0x75d6177a,0x7bce80a7,0x61e90a00,0x79846352}},	//   _ايرا, hibu, goel, ndiw,
   {{0xf4840979,0x3ce0023e,0x7bce1e59,0x80cb0285}},	//   _بازی, _nxiv_, kibu, _तेदे,
   {{0xfe0a0019,0x31040336,0x673e0103,0x487b006e}},	//   _sắp_, शेषः_, napj, נטיס,
   {{0xbcfb0146,0xe2160b05,0x51860f21,0xa3e51b11}},	//   rfém, _طباع, _гула, नवर_,
   {{0x8cb568b9,0x64420084,0x60410134,0x9f4500c2}},	//   उनलो, osoi, _ịmer, ellä_,
   {{0xac192cbf,0x64422f7d,0x6ce7004b,0x673eb979}},	//   рогу_, nsoi, сіне, kapj,
   {{0x7d160068,0x69da0257,0x7bce6ecd,0x69cd0150}},	//   _egys, éten, gibu, wiae,
   {{0x7f3b0132,0x75f80220,0x5e26097d,0x69cd0178}},	//   _געוו, vízn, _اعتق, tiae,
   {{0x3835013a,0x23ab052f,0x798406a8,0x644200c2}},	//   жнар, _højt_, gdiw, ksoi,
   {{0xdb0501e5,0x69cd02e0,0xa8140ebf,0x7bce0435}},	// [e130] _kohë, riae, здуш, bibu,
   {{0x161d0789,0x78ad0172,0x61e93030,0x69cdb978}},	//   _बंदर_, ryav, zoel, siae,
   {{0x163b0080,0xb8f02fbd,0xa6350565,0x78ad43bd}},	//   اسطة_, _वे_, інді, syav,
   {{0x7afab97a,0xf99f0154,0x00000000,0x00000000}},	//   ütte, _shèf_, --, --,
   {{0x04670ed1,0x61e903ee,0x9f450257,0x344b12d3}},	//   стем, voel, solé_, учен_,
   {{0x75220036,0x00000000,0x00000000,0x00000000}},	//   acoz, --, --, --,
   {{0x61e9b97b,0x683f0065,0x00000000,0x00000000}},	//   toel, _fàdá, --, --,
   {{0x7bce533a,0x75220036,0x41a90b21,0xd9f9007f}},	//   zibu, ccoz, рвин_, ंतित_,
   {{0x9f4500c2,0x7bce2964,0x61e93e6f,0x98a0015c}},	//   yllä_, yibu, roel, rbić_,
   {{0x3e7a0029,0x20110018,0xb33c0078,0x61e409ac}},	//   _būt_, özi_, _joħl, čila,
   {{0x753b0ab2,0xd9fb009d,0xa3d6058f,0x61e9b97c}},	//   _keuz, ्षात_, ाचर_, poel,
   {{0x1d0a22f6,0x7bce02a4,0x8c9607bf,0xed5a5bc6}},	//   иени_, wibu, оргі, шом_,
   {{0x7bceb97d,0xccfa0426,0x6dab01c2,0x00000000}},	//   tibu, рхні_, nƙay, --,
   {{0x753b0036,0x6ee20174,0x248d0a39,0x69dd0357}},	//   _leuz, _ọbel, _mrem_, _ajse,
   {{0x9c8718ed,0x3b0a0392,0x201f037a,0x3e7a00e8}},	//   _počí, рево_, lqui_, _gūt_,
   {{0x3ce00d7d,0x753bb97e,0x7bceb97f,0x75f80220}},	//   _txiv_, _neuz, sibu, vízo,
   {{0x201f0575,0x7bce0350,0x673e2557,0x77ca0077}},	// [e140] nqui_, pibu, tapj, алаг_,
   {{0x3f850060,0x46f6013d,0xdb07003e,0xb4870032}},	//   ndlu_, очет, skjá, _jẹ́ọ,
   {{0x248d03a9,0xa96a1009,0x2c648a94,0x753b3a9d}},	//   _arem_, _кина_, löd_, _beuz,
   {{0x213f063f,0x248db980,0x6442007b,0x00000000}},	//   jauh_, _brem_, tsoi, --,
   {{0x240a47cd,0x248d020a,0xa3d612f4,0xb22604c8}},	//   анди_, _crem_, ाचल_, klæð,
   {{0x75222f88,0xdb05054e,0x248d03a8,0xf487262f}},	//   scoz, _bohè, _drem_, غانی,
   {{0x6442b981,0x248d00ee,0x96635912,0x3f8525a3}},	//   ssoi, _erem_, _окре, ddlu_,
   {{0x39400558,0x248d0939,0x673cb982,0x753bb983}},	//   nais_, _frem_, _herj, _geuz,
   {{0x673c0496,0x248d0087,0x28d0142e,0x00000000}},	//   _kerj, _grem_, _सेमि, --,
   {{0x39404f6f,0x661cb984,0xbfaa00d3,0x673c00b3}},	//   hais_, _kurk, ртие_, _jerj,
   {{0x3940359d,0x673cb985,0xe81c00aa,0x201f0231}},	//   kais_, _merj, _भूसा_, aqui_,
   {{0x63a8582f,0x69da0068,0x3940282c,0x661cb986}},	//   _hodn, étel, jais_, _murk,
   {{0x3940b987,0x0ca84223,0x628a00f2,0x77770063}},	//   dais_, отри_, lvfo, yexx,
   {{0x673c9bd3,0x63a8007e,0xd00700d3,0x00000000}},	//   _nerj, _jodn, _дече_, --,
   {{0x63a813e8,0x661cb988,0x394000f0,0xaff9006e}},	//   _modn, _nurk, fais_, _פּני,
   {{0x2d8500d9,0x79941491,0x63a8023c,0x00000000}},	//   ēles_, мисф, _lodn, --,
   {{0x673c10f3,0x661c03f3,0x753b029a,0x7e6d0095}},	// [e150] _berj, _aurk, _reuz, _ćapi,
   {{0xf7731ea6,0x656000e3,0xc72b00d6,0x249d022e}},	//   بار_, _acmh, ріал_, vxwm_,
   {{0x661c6559,0x248d0d62,0x673c5cb6,0x753b0381}},	//   _curk, _srem_, _derj, _peuz,
   {{0x7e9b0054,0x3940b989,0x661c126e,0x248d02cd}},	//   יסבו, cais_, _durk, _prem_,
   {{0xc86417a8,0xa3d6009d,0xdb170072,0x673cb98a}},	//   _отри, ाचं_, _alxé, _ferj,
   {{0x248d00d3,0x661cb98b,0x63a801ee,0x00000000}},	//   _vrem_, _furk, _codn, --,
   {{0x61e402dd,0x661cb98c,0x63a80146,0x05770a09}},	//   čiln, _gurk, _dodn, _وارد,
   {{0x248db98d,0xdb0500fd,0x91fc01d3,0x6b850231}},	//   _trem_, _cohé, _spār, _lahg,
   {{0xdb1e0084,0xb367013d,0xc21b0378,0x661c14f3}},	//   _ympä, _мъжк, _पूरब_, _zurk,
   {{0x6d5d008a,0x39401f76,0xaec508f9,0x63a8b98e}},	//   egsa, zais_, збол, _godn,
   {{0xe9df02b4,0x201f00ee,0x7645b98f,0x394087ec}},	//   _ojú_, squi_, nshy, yais_,
   {{0x6281b990,0xdb1c00e3,0x394001fa,0x2c644ff4}},	//   _islo, mhré, xais_, töd_,
   {{0x3940b991,0x6b851470,0x6459462c,0x1c43084c}},	//   vais_, _bahg, nuwi, нням,
   {{0xe81f0cce,0xe9df45a0,0x201d0270,0x2c64186b}},	//   _बढ़ा_, _ajú_, _iuwi_, röd_,
   {{0x3940b992,0x8f9a00ca,0x3af500c2,0x6459b993}},	//   tais_, _ליסי, дятс, huwi,
   {{0x673c003d,0x201d0979,0x6459b994,0x69cc0096}},	//   _serj, _kuwi_, kuwi, _सगळी,
   {{0x673cb995,0x661c00c2,0xdbdb0065,0x291903a8}},	// [e160] _perj, _surk, _kàìn, _dgsa_,
   {{0x39408250,0x661cb996,0x7f410364,0x201d0bbd}},	//   sais_, _purk, nalq, _muwi_,
   {{0x673cb997,0x3940b998,0x645924e7,0xaa8a0103}},	//   _verj, pais_, euwi, _انجم_,
   {{0x63a802dd,0x271900b6,0x986a00ae,0x27f10372}},	//   _sodn, třní_, _лимб_, _ekzn_,
   {{0x673c529f,0xc953040a,0x645907ac,0x6281b999}},	//   _terj, _אמר_, guwi, _aslo,
   {{0x60d60138,0x798605bd,0x999f0031,0x9f4500b3}},	//   _žymo, _hakw, čuť_, folí_,
   {{0x63a841f9,0x66e33a5b,0x7986b99a,0x661c008c}},	//   _vodn, _зора, _kakw, _uurk,
   {{0xcb130054,0x61e4033b,0x63a80034,0x6459a6b5}},	//   עלה_, čilo, _wodn, buwi,
   {{0x79869411,0x5ea90081,0x69c1097c,0x2e2100da}},	//   _makw, _ছেলে, रोटी, _aóf_,
   {{0x91780139,0xbcfb020d,0x9f4500d4,0x94bb00ca}},	//   _bẹ́_, ngée, bolí_, _הממת,
   {{0x798624da,0x201904c8,0x00000000,0x00000000}},	//   _oakw, ísir_, --, --,
   {{0x7986b99b,0x9f5c00b3,0xa0a62a72,0x6b850113}},	//   _nakw, _pivó_, _наед, _sahg,
   {{0xdcef00d3,0x5c073546,0xdb050031,0x394b010a}},	//   decă, зява, _dlhý, _rdcs_,
   {{0x7f411275,0xea000023,0x91780032,0xe8d90134}},	//   calq, _đạc_, _fẹ́_, ndụ_,
   {{0x79867645,0x2cb300b6,0x6459024a,0x00000000}},	//   _bakw, _řadě_, zuwi, --,
   {{0xdcee0174,0x6edb00d7,0x00000000,0x00000000}},	//   ọrọl_, _לחופ, --, --,
   {{0x28c7007d,0x7986b99c,0x6d4d546d,0x321e0034}},	// [e170] _रेखि, _dakw, _idaa, _luty_,
   {{0x7c2d0193,0x5ba71146,0x9cd80142,0x00000000}},	//   _itar, _хриз, _מוחה_, --,
   {{0xf7700037,0x1a650103,0x752d0328,0x247d05aa}},	//   طال_, _تیزی_, ñazo, _sňm_,
   {{0xf6501e53,0x645900a6,0x25a90088,0x798665a6}},	//   ائل_, tuwi, ðal_, _gakw,
   {{0xfc4600b6,0x7c2d0090,0x69cf039f,0x00000000}},	//   říve_, _jtar, _imce, --,
   {{0x3869b99d,0x7986b99e,0x9f470220,0x321e00a5}},	//   mtar_, _zakw, _okná_, _buty_,
   {{0xf77200a1,0x7986ac8c,0xdb050131,0x201d00d1}},	//   _שקל_, _yakw, _ilhó, _suwi_,
   {{0x64590270,0x321e00d7,0x6d4d4458,0xe6100281}},	//   puwi, _duty_, _ndaa, _مشق_,
   {{0x7c2d023f,0xc5e917ad,0x75291c64,0x7a1c0154}},	//   _ntar, टकीय_, _ifez, _včti,
   {{0x442db99f,0x38693024,0x321e01c2,0x6d4d026d}},	//   _ite_, itar_, _futy_, _adaa,
   {{0x6281215e,0x7c2db9a0,0x90e712eb,0x3869b9a1}},	//   _uslo, _atar, _کسان, htar_,
   {{0x3869b9a2,0x201d5916,0x64491d15,0x442d5483}},	//   ktar_, _tuwi_, _kvei, _kte_,
   {{0xdb1e002b,0x201d06a8,0x6d4d083e,0x3869b9a3}},	//   _impú, _uuwi_, _ddaa, jtar_,
   {{0x7986b9a4,0xee39232c,0x3869b9a5,0x6d4d1d0d}},	//   _sakw, _днк_, dtar_, _edaa,
   {{0x3869001f,0xca750b2f,0x7c2db9a6,0x7986b9a7}},	//   etar_, нуты, _etar, _pakw,
   {{0x38691bd6,0x442db9a8,0x3f874c43,0xcee712eb}},	//   ftar_, _ote_, _hanu_, _ورژن_,
   {{0x386900e3,0x18670dee,0x442db9a9,0xe7aa1278}},	// [e180] gtar_, мати_, _nte_, овал_,
   {{0x79861ddc,0x69cf2b43,0x7a150034,0x09030291}},	//   _wakw, _emce, _wątp, тпун,
   {{0x442da6b8,0x3f875dac,0x7986b9aa,0xe1f9013f}},	//   _ate_, _manu_, _takw, klų_,
   {{0x89360de1,0x3f870065,0x3869b9ab,0x442d0063}},	//   _تعدا, _lanu_, btar_, _bte_,
   {{0x442d1175,0x397b00ca,0xcb2200a3,0x98b90154}},	//   _cte_, _וטכנ, _मलाड_, _yesč_,
   {{0x28c70e72,0x75297838,0x442d24dd,0x00000000}},	//   _रेटि, _efez, _dte_, --,
   {{0x442db9ac,0xfd6500de,0xe29719e8,0x752906b0}},	//   _ete_, _chuố, дај_, _ffez,
   {{0x3f870694,0xbbbb1fb4,0xd13000e3,0xe1f90138}},	//   _aanu_, _उत्क, دمة_, glų_,
   {{0x30140a8e,0x6e2d0307,0xb145001c,0x00000000}},	//   ндир, _čaba, ریوم_, --,
   {{0x3f8700f0,0xdb1e0428,0x75f8016d,0xe1f900c6}},	//   _canu_, _empú, dízi, alų_,
   {{0x05c207e2,0xc7570266,0x3eb800ea,0x00000000}},	//   _शताब, וייץ_, árt_, --,
   {{0x25a6b9ad,0xa3d60b94,0x442d4f65,0x29020141}},	//   njol_, ाचक_, _yte_, _ozka_,
   {{0x4fc60e2f,0x3869b9ae,0x61e2b9af,0x3f870144}},	//   _оска, xtar_, _ijol, _fanu_,
   {{0xb3450396,0x3f87b9b0,0x69cf03a9,0x9f4500b3}},	//   maçã, _ganu_, _smce, colà_,
   {{0xb34500c9,0xf1b200af,0x61e2038c,0x29020167}},	//   laçã, _जवान, _kjol, _azka_,
   {{0x3869b9b1,0x2369150a,0x3915625b,0x3f87b9b2}},	//   ttar_, đaji_, ембр, _zanu_,
   {{0xb3450396,0x28f80084,0x3869ac1a,0x80d4049d}},	// [e190] naçã, деть_, utar_, _बेमे,
   {{0x3869b9b3,0x442d9a59,0x7d003ad7,0xe1f900c6}},	//   rtar_, _rte_, ümse, zlų_,
   {{0x6449b9b4,0x7bd5b9b5,0x61e2037a,0x06b20033}},	//   _svei, mizu, _ojol, _টেবি,
   {{0x3869b9b6,0x29d7003d,0x61e2b9b7,0x80b300bc}},	//   ptar_, għat_, _njol, ेनमे,
   {{0x23292249,0x3a2605db,0x00000000,0x00000000}},	//   поли_, _čopi_, --, --,
   {{0x7bd53610,0xb345001f,0x3a2100ec,0xe7301a13}},	//   nizu, daçã, _kuhp_, _نصف_,
   {{0x221500ae,0x425200d1,0x00000000,0x00000000}},	//   нфир, هنور, --, --,
   {{0x32060113,0x644923ff,0x3f870a39,0x7bd51a11}},	//   _choy_, _tvei, _sanu_, hizu,
   {{0xe0d9b9b8,0xb3450396,0x442db9b9,0x7bd5b814}},	//   яви_, gaçã, _ute_, kizu,
   {{0xfd650028,0x3fcd0081,0x75f86cf4,0x600632e3}},	//   _thuố, রক্ষ, vízi, нным_,
   {{0xf77200c1,0x25ad1044,0x645e0034,0x61e2b9ba}},	//   נקט_, _koel_, ąpie, _fjol,
   {{0xb3450131,0x6da60d62,0x9f45015e,0x00000000}},	//   baçã, хима, solà_, --,
   {{0xb34500c9,0x7fd536bf,0x61fb01e8,0x7bd5023b}},	//   caçã, _пікі, mlul, fizu,
   {{0xdee5086a,0x61fb8c5f,0x320d026d,0x7bd512cc}},	//   _поли, llul, lmey_, gizu,
   {{0x6373008e,0x6e9500e3,0xdce41197,0xb1120174}},	//   mını, _ألعا, _obić, tụge,
   {{0x6373008e,0x3eb80856,0x25ad8537,0x61fbb9bb}},	//   lını, ørte_, _noel_, nlul,
   {{0x6d469372,0xdbdb0af0,0x7bd512cc,0x61fb007b}},	// [e1a0] maka, _fààn, bizu, ilul,
   {{0x7d048fc9,0x637308bb,0x61fb0060,0xa02600ce}},	//   _izis, nını, hlul, liöö,
   {{0xb34500c9,0xd946188d,0x25ad029a,0x28d000b6}},	//   zaçã, _пени, _boel_, _सेरि,
   {{0x63730555,0x25adb9bc,0x9f4c00d4,0x7cd700d1}},	//   hını, _coel_, rodé_, _آویز_,
   {{0x25ad0305,0x637307aa,0xb3450161,0x61fb0060}},	//   _doel_, kını, xaçã, dlul,
   {{0x69d6b9bd,0x6d46b9be,0xb3450396,0xf1b900d9}},	//   liye, haka, vaçã, ekš_,
   {{0x6d46b9bf,0xbcfb0257,0x39422f54,0x637303a3}},	//   kaka, nfér, _keks_, dını,
   {{0x6d46b9c0,0xb34500c9,0x61fbb9c1,0x69d6b9c2}},	//   jaka, taçã, glul, niye,
   {{0x6d461990,0x61e24e75,0x637303e0,0x765e4a00}},	//   daka, _vjol, fını, lupy,
   {{0xb3450303,0x3dc006a8,0x69d6b9c3,0x50b70037}},	//   raçã, _aliw_, hiye, عديد_,
   {{0x6d469c10,0xd33700a1,0x7bd55768,0x69d6b9c4}},	//   faka, _נראה_, vizu, kiye,
   {{0x6d464132,0xa3cc0336,0xb345001f,0x6562b9c5}},	//   gaka, शोर_, paçã, ngoh,
   {{0x69d69768,0x6ad90966,0x63730511,0x2e460139}},	//   diye, णप्र, bını, _bífá_,
   {{0xbcfb04ea,0xf99fb62e,0x7d0400a5,0x63730587}},	//   ffér, _chèn_, _dzis, cını,
   {{0xda7808cb,0x7d042828,0x7bd516a6,0x69d69768}},	//   нят_, _ezis, rizu, fiye,
   {{0x69c4b9c6,0xceb300a1,0x69d6b9c7,0x4efb00ca}},	//   ghie, _תיק_, giye, _מהוו,
   {{0x25ad01cb,0x7bd501ff,0x00000000,0x00000000}},	// [e1b0] _roel_, pizu, --, --,
   {{0x320d0063,0xa8a404d9,0x25ad51c6,0x7bd50216}},	//   zmey_, ырск, _soel_, qizu,
   {{0x69d6b9c8,0x394201df,0x25ad01d0,0x7d040172}},	//   biye, _feks_, _poel_, _zzis,
   {{0x69c4b9c9,0x63730511,0x69d69ed3,0x39420381}},	//   chie, zını, ciye, _geks_,
   {{0x25ad5268,0x637303a3,0xc86700d6,0x7dc60145}},	//   _voel_, yını, _ятни, _fósf,
   {{0x6d46b9ca,0x798d02ac,0x25ad084e,0x00000000}},	//   zaka, ldaw, _woel_, --,
   {{0x61fbb9cb,0x4426008c,0x25ad09a1,0x00000000}},	//   tlul, aqo_, _toel_, --,
   {{0x798db4aa,0xa22400cd,0x25bf00dc,0xdce4049c}},	//   ndaw, دروه, _ulul_, _ubić,
   {{0x6373008e,0x61fbb9cc,0x798d0044,0x2240007e}},	//   tını, rlul, idaw, ćika_,
   {{0x6d46b9cd,0x69d6b9ce,0x661b0084,0x443f06c0}},	//   waka, ziye, _hiuk, _iwu_,
   {{0x6373436c,0x6d46b9cf,0xed5a08f9,0xeadc00c7}},	//   rını, taka, мон_, _ধর্ম,
   {{0x637335f8,0x236902e6,0x69d6008a,0x443f0134}},	//   sını, đaju_, xiye, _kwu_,
   {{0x6d461a27,0xc8d0110f,0x798db9d0,0xdb1c0088}},	//   raka, _सेंट, ddaw, firð,
   {{0x799d00a1,0x661b163d,0x9f4500b3,0x6373013c}},	//   _answ, _liuk, dolç_, qını,
   {{0x6d464956,0x60c901e8,0x69d6b9d1,0xbb433386}},	//   paka, lzem, tiye, реск,
   {{0x798d019c,0x644b8c9f,0x60d60138,0xdc14008b}},	//   gdaw, ksgi, _žymi, rşıy,
   {{0x69d6b9d2,0xbcfb3ecc,0x443fb9d3,0xe81c009f}},	// [e1c0] riye, sfér, _nwu_, _भूखा_,
   {{0x69d6b9d4,0x6e2301c2,0x644b004d,0x61e4166d}},	//   siye, _kunb, dsgi, čili,
   {{0xbcfbb9d5,0x69c4257e,0x6e2301c2,0x443f57c1}},	//   ngén, phie, _junb, _awu_,
   {{0x6609b9d6,0x7c24024a,0x443f0169,0x7f430372}},	//   _chek, _kuir, _bwu_, _lenq,
   {{0x672300cc,0x661b32c3,0x6562023b,0x6d44016d}},	//   žnja, _diuk, rgoh, _meia,
   {{0xa3cc00a5,0x38601821,0x60c92756,0x6d44b9d7}},	//   शों_, muir_, dzem, _leia,
   {{0x443f0136,0x38600623,0x7c2401b5,0x6e230062}},	//   _ewu_, luir_, _luir, _nunb,
   {{0xe1ef0adb,0x661b0124,0x68ed023b,0xdb050072}},	//   يسي_, _giuk, _ëndë, _johá,
   {{0x386040e2,0x443f00bd,0xdb070120,0x7f4319fd}},	//   nuir_, _gwu_, skjø, _benq,
   {{0x61ed1a30,0x44241844,0xb1120134,0xdb070120}},	//   čala, _ium_, tụbe, pkjø,
   {{0x6e230441,0x51860036,0xa75b006e,0x38603bf8}},	//   _cunb, _аула, ודיר, huir_,
   {{0x4424b9d8,0x6e231821,0x7c2407bc,0xdb050094}},	//   _kum_, _dunb, _buir, _nohá,
   {{0x7c24006b,0x4424b9d9,0x6d440a00,0x6ce70565}},	//   _cuir, _jum_, _deia, тіне,
   {{0x44240283,0x38606080,0x45280081,0x7c2407bc}},	//   _mum_, duir_, মরিক_, _duir,
   {{0x4424b9da,0xac18021c,0x6e23b9db,0xdb050094}},	//   _lum_, тору_, _gunb, _bohá,
   {{0x201c068d,0x7c240013,0x3ce9006c,0xef1801d3}},	//   _hivi_, _fuir, _txav_, ceļa_,
   {{0x4424b9dc,0x201cb9dd,0x9f4c2347,0xdb050103}},	// [e1d0] _num_, _kivi_, hodí_, _dohá,
   {{0x6609a90e,0xf77002fc,0x26e70033,0x6283007f}},	//   _shek, قام_, _করবো_, ywno,
   {{0xd7f81f82,0x60c9b9de,0x98140037,0x661b0e22}},	//   тут_, zzem, شبكا, _piuk,
   {{0x38600dd3,0x644b0149,0x799d03a8,0xdb160b85}},	//   buir_, tsgi, _unsw, åbåt,
   {{0x44240a29,0x33d5097a,0xad9b08a8,0x39497b23}},	//   _cum_, лікт, clúe, maas_,
   {{0x4424b9df,0x3949043e,0x60c9762e,0x644b18f0}},	//   _dum_, laas_, vzem, rsgi,
   {{0x442471cb,0x6609b9e0,0xb364013d,0x661b00c2}},	//   _eum_, _thek, ръчк, _tiuk,
   {{0x60c928fd,0x3949b9e1,0x4424b9e2,0x443fb9e3}},	//   tzem, naas_, _fum_, _twu_,
   {{0x44240013,0x6e23b9e4,0x6d44b9e5,0xf3674a54}},	//   _gum_, _sunb, _reia, _атен,
   {{0xee39117a,0x60c984e0,0x3949008a,0x6d44b9e6}},	//   нно_, rzem, haas_, _seia,
   {{0x442402d6,0x201c01d3,0x3949789b,0x60c9b9e7}},	//   _zum_, _divi_, kaas_, szem,
   {{0xb2ba0130,0xaee30065,0xbcfbb9e8,0x9b96015a}},	//   _אמער, _aiṣi, rgén, گلست,
   {{0x7c2426e0,0x39490694,0x4424b9e9,0x6d44b9ea}},	//   _quir, daas_, _xum_, _veia,
   {{0x7052114c,0xa06608d9,0x6e230135,0x7bc79c52}},	//   _انوا, _саша_, _tunb, ghju,
   {{0xdb052299,0xfc3f08a8,0x2d8400fd,0x65690085}},	//   _pohá, rxía_, ômes_, _oceh,
   {{0x201c00cc,0x3949008a,0x7c24009b,0xf2d200c1}},	//   _zivi_, gaas_, _tuir, צען_,
   {{0xbcfbb9eb,0x98a316bd,0x2d82b9ec,0x161d00c3}},	// [e1e0] ngél, бите, meke_, _बंजर_,
   {{0xb8dc0285,0x4424a02f,0x2d821f91,0x38602b93}},	//   _अथ_, _rum_, leke_, ruir_,
   {{0x442421d0,0x39490f68,0xdb1c0076,0xfc3f0072}},	//   _sum_, baas_, bhrá, nxín_,
   {{0x2d8206c0,0xdb1ca9e0,0x4424b9ed,0x7dc60072}},	//   neke_, chrá, _pum_, _fóse,
   {{0x7e6134b3,0x3860015e,0x7afe0154,0x44242ce7}},	//   hulp, quir_, _hypt, _qum_,
   {{0x2d82b9ee,0x43940077,0xb33c0090,0x00000000}},	//   heke_, ракс, _roħs, --,
   {{0x2d829955,0x201cb9ef,0x668409e5,0xdb1e7c16}},	//   keke_, _rivi_, _خیال, _impó,
   {{0x2d820ea3,0x90541693,0x9f4c00d4,0xf4840a85}},	//   jeke_, авиц, rodí_, _پاری,
   {{0x442400dc,0x201c0660,0x00000000,0x00000000}},	//   _uum_, _pivi_, --, --,
   {{0x53b83ec9,0x307700e3,0x212f0090,0xdcf600a7}},	//   _अविश, احية_, _efgh_, _sayğ,
   {{0x74130391,0x200200d9,0x201cb9f0,0x7e610270}},	//   _اولا, ēki_, _vivi_, gulp,
   {{0xdcf600a7,0x39490188,0x6143020f,0x2d82533a}},	//   _qayğ, xaas_, _геца, geke_,
   {{0xdfda013d,0x201cb9f1,0x5c740243,0x00000000}},	//   _пък_, _tivi_, блят, --,
   {{0x3949008a,0x00000000,0x00000000,0x00000000}},	//   waas_, --, --, --,
   {{0x39497685,0x2d820201,0x539b00a1,0x7e61b9f2}},	//   taas_, beke_, עילו, culp,
   {{0xf99f00de,0x3f8e039f,0xb33c0090,0x2d82460c}},	//   _thèm_, _hafu_, _moħq, ceke_,
   {{0x06b20081,0x3f8eb9f3,0x3949b9f4,0xa80200a7}},	// [e1f0] _টেলি, _kafu_, raas_, ğınc,
   {{0x3949b9f5,0x3f8e0078,0x69da0401,0x00000000}},	//   saas_, _jafu_, éter, --,
   {{0x67230106,0x3707490d,0xfc300281,0x7bc501ff}},	//   žnjo, учав, _وحی_, _ilhu,
   {{0x29e811bc,0x645d2708,0x68fd00f3,0xdb1e0131}},	//   lğan_, _åsik, _tysd, _empó,
   {{0x64a51361,0xdcfd013f,0x7e6101e9,0x00000000}},	//   рала, kesč, zulp, --,
   {{0x42552249,0x2d82019f,0xdb1e0154,0x3f8e0078}},	//   атит, zeke_, _impò, _nafu_,
   {{0x02d8142e,0xfbb800ca,0x00000000,0x00000000}},	//   _भेदभ, רפות_, --, --,
   {{0x020500c9,0xaca50294,0x00000000,0x00000000}},	//   јзин, ghịz, --, --,
   {{0x798f02e5,0x3f8e083e,0x00000000,0x00000000}},	//   _macw, _bafu_, --, --,
   {{0x2d82b9f6,0xd00e0c5e,0x1fb50cc6,0xd0090284}},	//   weke_, ولي_, рсир, ђене_,
   {{0x2d82b9f7,0xd5b90e19,0xe233001c,0xf99f0383}},	//   teke_, _आवाज, _اکتب, _chèk_,
   {{0xf99f01dc,0x7e61020a,0x00000000,0x00000000}},	//   _dhèk_, rulp, --, --,
   {{0x2d82b9f8,0x7e6133aa,0x814c006e,0xa3cc00aa}},	//   reke_, sulp, _טעאַ, शोक_,
   {{0x2d820584,0x09de0096,0xcee80103,0x7a1c022b}},	//   seke_, नच्य, ئرین_, _pōto,
   {{0x2d82b9f9,0x7ff40dd0,0x39330134,0xaa4600c2}},	//   peke_, _اسنا, _ụfụ_, ребл,
   {{0xdb1c2299,0x7bc51f3f,0x88e600ae,0x798f030a}},	//   nkré, _elhu, ажбе, _cacw,
   {{0x798f008a,0xad9b0206,0x47362259,0x4ad600bc}},	// [e200] _dacw, slúc, لراز, _डेरव,
   {{0xeb9a2a84,0x23b901dc,0x2ba700a4,0xe73a0d86}},	//   _рио_, _kèju_, खाणा, теж_,
   {{0x7bdc606b,0xa5260077,0x0686256d,0x798f1544}},	//   miru, амед, рген, _facw,
   {{0x798f0027,0x25a0034f,0x00000000,0x00000000}},	//   _gacw, ñil_, --, --,
   {{0x69c69fe2,0x79840350,0xf1a91d7d,0x00000000}},	//   _ilke, meiw, कानन, --,
   {{0x7bdcb9fa,0x06660281,0x00000000,0x00000000}},	//   niru, _پاسپ, --, --,
   {{0x66e38481,0x3f8e0a4b,0x6d560383,0x31c60284}},	//   _дора, _rafu_, _odya, исив,
   {{0x3f8e0051,0x6d560ab9,0x00000000,0x00000000}},	//   _safu_, _ndya, --, --,
   {{0x3872017a,0xcfa60399,0xdfa60e2c,0x6602b9fb}},	//   ntyr_, ашни, ајно, mlok,
   {{0x6fc401b9,0x7bdc30db,0xb1120174,0xdb1e00d8}},	//   _bòca, jiru, bụne, _alpí,
   {{0x7c3600dd,0x7bdcb9fc,0x6fc401f7,0x6e632458}},	//   _atyr, diru, _còca, отяж,
   {{0x6602b9fd,0x3f8eb9fe,0x629a00c2,0x00000000}},	//   nlok, _wafu_, _irto, --,
   {{0x76430018,0x7bc5022e,0xafe600d3,0x9989007f}},	//   ányz, _plhu, _кодл, ymał_,
   {{0x66020060,0x6d5601dc,0x7bdcb9ff,0x6fc4009c}},	//   hlok, _edya, giru, _fòca,
   {{0xe0e80081,0x6602ba00,0x29e81a4a,0x19590109}},	//   _পরিভ, klok, rğan_, лавы_,
   {{0x39a4088f,0x89370076,0x7c360216,0x00000000}},	//   ошув, شعرا, _ftyr, --,
   {{0x6602ba01,0x7bdcb936,0xdb5b00c2,0xad9b002b}},	// [e210] dlok, biru, _июн_, clúa,
   {{0xc60f03a2,0x960f1efb,0x69c6ba02,0x6602ba03}},	//   िष्य_, िष्ट_, _elke, elok,
   {{0xb8fe0d1b,0x66020088,0x200903e3,0x6bd900d1}},	//   _थे_, flok, _ɗai_, _لوکس_,
   {{0x78a20094,0x6602ba04,0x00000000,0x00000000}},	//   ťova, glok, --, --,
   {{0x24f8055b,0xa87900c1,0x66dc0430,0xd8cb002d}},	//   анцы_, _גאָר, _påkø, _рынд_,
   {{0x629a00c4,0x28d00176,0x66020172,0x00000000}},	//   _brto, _सेटि, alok, --,
   {{0x5b7c0054,0xb5a71cf2,0x9567013d,0xdb1c0364}},	//   דרוא, _край, _възд, chrä,
   {{0x7bdc85c3,0x23d90176,0x6fc401b9,0x00000000}},	//   ziru, _भगवद, _ròca, --,
   {{0x657bba05,0x7dc60037,0x629a029a,0xc4fb03ef}},	//   _ibuh, _nósa, _erto, _شعرا_,
   {{0x248d03e5,0xdb1c2159,0x72420018,0x6fc401ec}},	//   _isem_, skré, _کھول, _pòca,
   {{0x7c363fe4,0xb4e70557,0xe7fa142e,0x3d150285}},	//   _styr, _पशु_, ्तता_, नेसे_,
   {{0x51840fe9,0xb33c0078,0x00000000,0x00000000}},	//   _муча, _inħa, --, --,
   {{0x248d033a,0x213f0496,0x7bdc1cbd,0xa3cb1b11}},	//   _jsem_, mbuh_, tiru, _लता_,
   {{0x6fc401b9,0x00000000,0x00000000,0x00000000}},	//   _tòca, --, --, --,
   {{0xdd110074,0x657b7d87,0x4e350182,0x7bdcac8a}},	//   _výšk, _obuh, _اعتز, riru,
   {{0x7bdc590a,0x7ae10308,0x3e710103,0x248d230b}},	//   siru, últa, mát_, _osem_,
   {{0x3e710730,0x69d80138,0x600f01df,0x2d92010a}},	// [e220] lát_, _įved, rømf, _iaye_,
   {{0xbb860080,0x657b4f72,0xab66036a,0x2d92ba06}},	//   _الدي, _abuh, _увол, _haye_,
   {{0x38721484,0x2d92ba07,0x248dba08,0x3e7110a8}},	//   styr_, _kaye_, _asem_, nát_,
   {{0x5efa006e,0x3f85007b,0x2d920139,0x00000000}},	//   אפעד, helu_, _jaye_, --,
   {{0x6602060f,0x6ba50088,0x3e710018,0x2d92ba09}},	//   rlok, _útgá, hát_, _maye_,
   {{0x3f850292,0x2d92628f,0x3e7110a8,0x2fc707ac}},	//   jelu_, _laye_, kát_, _nlng_,
   {{0x3e710068,0x3f85ba0a,0x248dba0b,0x6602ba0c}},	//   ját_, delu_, _esem_, plok,
   {{0x2d92ba0d,0x2fc72375,0xf99f03a9,0x4a9b006e}},	//   _naye_, _alng_, _dhèw_, ריקג,
   {{0xdce42461,0x2fc70167,0x39400076,0x25a4037a}},	//   _obiđ, _blng_, ibis_, _inml_,
   {{0xb7fa08fa,0x2d920d79,0x3f85ba0e,0xaac800b7}},	//   ्तिम_, _aaye_, gelu_, रनाक,
   {{0xd3370054,0x3e710018,0x386031fb,0x290207ac}},	//   _הרבה_, gát_, hrir_, _lyka_,
   {{0x2d920063,0x7dc60076,0x00000000,0x00000000}},	//   _caye_, _pósa, --, --,
   {{0x3f85ba0f,0x2d92ba10,0x26e400b6,0x5c7449b7}},	//   belu_, _daye_, कपुर_, плят,
   {{0x3e712e16,0xd9b30034,0x39950134,0xa3be33c5}},	//   bát_, ीस्ट, _ụs_, ँघट_,
   {{0x386000b3,0x3e7101f9,0x00000000,0x00000000}},	//   erir_, cát_, --, --,
   {{0x2d9202f1,0x3860a937,0x26e70033,0xdb050206}},	//   _gaye_, frir_, _করলো_, _kohú,
   {{0x6d4f0ede,0xbbeb00bf,0xa3e8009d,0x3dc90bb6}},	// [e230] maca, _مردم_, मचा_, _ilaw_,
   {{0x6d4fba11,0x2d921a69,0x2a98022b,0x290237f9}},	//   laca, _zaye_, _fčb_, _dyka_,
   {{0x2d924b2d,0x3ebe2ba4,0x3940ba12,0x21260ece}},	//   _yaye_, nytt_, bbis_, _ogoh_,
   {{0x6d4f47c1,0x3f850a39,0x25a400b3,0x248d00e2}},	//   naca, zelu_, _cnml_, _psem_,
   {{0x99800dea,0x69df3b77,0x2a980154,0x3e7101f9}},	//   lmiş_, miqe, _zčb_, zát_,
   {{0x248d02dd,0x6d4f1fd9,0x3dc90150,0x6b87023b}},	//   _vsem_, haca, _llaw_, nejg,
   {{0x998003a3,0x6d4f27eb,0xd5ae0018,0x00000000}},	//   nmiş_, kaca, رہے_, --,
   {{0x3e710068,0xa6b20081,0x657b271c,0x6d4f042d}},	//   vát_, _টেকট, _ubuh, jaca,
   {{0x6d4fba13,0x6e2a01bf,0x2d92485d,0x394b00fd}},	//   daca, _aufb, _raye_, _mecs_,
   {{0x3e710018,0x2d92ba14,0x3dc20167,0x9980020e}},	//   tát_, _saye_, wkkw_, kmiş_,
   {{0x59c90c16,0x7d0d02a4,0xf2c70095,0x2d92ba15}},	//   रसार, _azas, _усан, _paye_,
   {{0x3e712299,0x6d4fba16,0x3f854c6e,0x656b0063}},	//   rát_, gaca, selu_, nggh,
   {{0x7d0d0067,0x3e7168fa,0x2fc7005c,0x00e50068}},	//   _czas, sát_, _tlng_, _بتای,
   {{0xa3ac007d,0x3860025a,0x2d926ce1,0x2480008b}},	//   गाय_, vrir_, _waye_, çimi_,
   {{0xdde900bf,0x61e9a33c,0x7d0d36d8,0x394b145c}},	//   _گروه_, onel, _ezas, _becs_,
   {{0x6d4f8556,0x3e5501d3,0x394b00ee,0x3dc900f0}},	//   caca, māt_, _cecs_, _glaw_,
   {{0x20c93245,0x186a03fc,0x3e5500d9,0x386000fd}},	// [e240] िनिध, рази_, lāt_, urir_,
   {{0x61e902dc,0x62810371,0x869a336f,0x3940ba17}},	//   hnel, _oplo, итет_, sbis_,
   {{0x3e550029,0x628101bb,0x61e9013f,0x61fbba18}},	//   nāt_, _nplo, knel, koul,
   {{0x98a63084,0x7e7e0212,0x38601649,0x2902ba19}},	//   _диме, _äppe, prir_, _tyka_,
   {{0x69c403e5,0x61fb171f,0x61e90307,0x64c40034}},	//   mkie, doul, dnel, वनेश,
   {{0xd25a3574,0x69c4ba1a,0x3e5501d3,0x6e24019a}},	//   аци_, lkie, kāt_, _liib,
   {{0x6d4f0390,0x04fc00c7,0x6fc4048b,0x61fb1022}},	//   yaca, েশের_, _dòcl, foul,
   {{0x69c4ba1b,0x61e9038c,0x3e5500d9,0x2005ba1c}},	//   nkie, gnel, dāt_, elli_,
   {{0x7d04ba1d,0x224900cc,0x6281007e,0xdb1e20df}},	//   _nyis, ćaka_, _eplo, _impõ,
   {{0x61e9002d,0xdd090181,0x69df88a5,0x6d4fba1e}},	//   anel, _pôži, ziqe, waca,
   {{0x69c42a60,0x7d04ba1f,0x6d4fafe1,0xc9070251}},	//   kkie, _ayis, taca, _शर्म_,
   {{0x6e24009c,0x61fb49f0,0x7dc60139,0x7d0405bd}},	//   _ciib, coul, _dóso, _byis,
   {{0x6e240b08,0x61e02c1d,0x69c40034,0x7d0405bd}},	//   _diib, miml, dkie, _cyis,
   {{0x60cc07d1,0x61e007aa,0x69c400d9,0x7d0400f9}},	//   ılmı, liml, ekie, _dyis,
   {{0x656b0e3e,0x2e4a008f,0x69cd58b2,0x7dc600ee}},	//   yggh, _тяло_, thae, _góso,
   {{0x61e002e6,0x998007d1,0x3c2f0364,0x7c3d298b}},	//   niml, rmiş_, _tüv_, ppsr,
   {{0x7d0d7bfc,0x69cd49c3,0xfb27001c,0x394b00e8}},	// [e250] _uzas, rhae, _وردپ, _vecs_,
   {{0x61e058d4,0x7bce042c,0x7de40103,0x69cd024a}},	//   himl, chbu, rőse, shae,
   {{0x61e007aa,0x7c2d83ee,0x6d4d005c,0x61fb0a4b}},	//   kiml, _huar, _keaa, youl,
   {{0x69c4ba20,0x60c0347e,0x8afa00ca,0x61fb0072}},	//   ckie, kymm, _להתי, xoul,
   {{0x62810b27,0x7c2d048e,0x18350130,0x69dd003d}},	//   _splo, _juar, _מאָל_, _imse,
   {{0x7647023e,0x3869023b,0x7c2dba21,0x61fb02f1}},	//   _twjy, muar_, _muar, woul,
   {{0x3869ba22,0x7c2dba23,0xe7fa074c,0xb33c0090}},	//   luar_, _luar, ्तरा_, _inħl,
   {{0xdb1e0257,0x7a1c0154,0x61e9020a,0x3e5501d3}},	//   _impô, _pōti, unel, vāt_,
   {{0x61fbba24,0xa3b80018,0x752902a4,0x7c2d6048}},	//   roul, _ڈالر_, _igez, _nuar,
   {{0x69c49763,0x2005ba25,0x61e93500,0x6f030150}},	//   zkie, ulli_, snel, _pync,
   {{0x62817077,0x61fbba26,0x69dd536a,0x3869023b}},	//   _uplo, poul, _omse, huar_,
   {{0x386901e5,0x442d072f,0x4425ba27,0x3eb80149}},	//   kuar_, _kue_, _hil_, ärta_,
   {{0x7c2d351e,0x386900dd,0x442d0033,0xa0a50077}},	//   _cuar, juar_, _jue_, _халд,
   {{0x69dd02ad,0x7c2dba28,0x442509a4,0x3869023b}},	//   _amse, _duar, _jil_, duar_,
   {{0x442d02fd,0xfaa30ba3,0xa3ac009d,0x69c4931c}},	//   _lue_, наро, गात_, tkie,
   {{0x442504f9,0x7529067d,0xba230ef7,0x7c2dba29}},	//   _lil_, _ngez, едск, _fuar,
   {{0x69c405c9,0x7c2d0a5f,0x7c2503e3,0x44252ac3}},	// [e260] rkie, _guar, _fihr, _oil_,
   {{0x69c4ba2a,0x61e0008e,0xdc9b895a,0x69dd0201}},	//   skie, ziml, _פסיכ, _emse,
   {{0x3bbb00a1,0x61e007aa,0x249f0ece,0x7bde1aa3}},	//   _המיד, yiml, _arum_, _impu,
   {{0x442502ad,0x38698682,0x00000000,0x00000000}},	//   _ail_, buar_, --, --,
   {{0x4425ba2b,0x7bde0899,0x61e003e0,0x2a6a0e3e}},	//   _bil_, _kmpu, viml, lubb_,
   {{0x442dba2c,0x644901cb,0x3952ba2d,0x7c380218}},	//   _due_, _dwei, lays_, _čvrl,
   {{0x4425381b,0x249f0088,0x7bde005c,0x61e00367}},	//   _dil_, _erum_, _mmpu, timl,
   {{0x442d0eb8,0x44250049,0x11d800e3,0x3253008f}},	//   _fue_, _eil_, توبة_, хвър,
   {{0x644902e0,0x442d009d,0x4425052e,0x61e003a3}},	//   _gwei, _gue_, _fil_, riml,
   {{0x61e00b88,0x301300c6,0xbfaa10de,0xe3a409b4}},	//   siml, ндыр, стие_, _تشری,
   {{0x386901e5,0x7c2d042b,0x644902e2,0xfbb01677}},	//   zuar_, _suar, _zwei, ञानम,
   {{0x7c252acb,0x63ba00d3,0x2ca0ba2e,0x386901c2}},	//   _sihr, _hotn, _brid_, yuar_,
   {{0x44250233,0x8fa6692d,0x7c2d1a91,0x386900dd}},	//   _yil_, _наде, _quar, xuar_,
   {{0xe10b0130,0x44250188,0x3869023b,0xbcfb00fd}},	//   _פּאָ, _xil_, vuar_, dgét,
   {{0x63ba02dd,0x7c2500c2,0xfc3fb8e5,0x7c2d01c2}},	//   _motn, _vihr, spí_, _wuar,
   {{0x3869074a,0x7c2d0a6c,0x63ba0034,0xfe6f0037}},	//   tuar_, _tuar, _lotn, _صدى_,
   {{0x290f070a,0x2d8bba2f,0x7bde0072,0xfe7800c6}},	// [e270] åga_, mece_, _fmpu, ltį_,
   {{0x442dba30,0x3869074a,0x2d8bba31,0x290701d3}},	//   _rue_, ruar_, lece_, āna_,
   {{0x386970ea,0xf5590e5a,0xfe78013f,0x44252d28}},	//   suar_, قلاب_, ntį_, _ril_,
   {{0x2d9904ee,0x69ddba32,0x2d8b22bf,0x28de0640}},	//   ndse_, _umse, nece_, _नेवि,
   {{0x3869ba33,0x63ba8d53,0xe9df0032,0xef1800e8}},	//   quar_, _botn, _imú_, meļu_,
   {{0x442d025a,0xfe78013f,0x63ba207f,0xbcfb0850}},	//   _vue_, ktį_, _cotn, lgés,
   {{0x4425ba34,0x994d0181,0xf1a90034,0x9f450233}},	//   _vil_, _môžu_, कालन, rolü_,
   {{0x442501aa,0x63a801c5,0x442dba35,0x2d8b053f}},	//   _wil_, _endn, _tue_, jece_,
   {{0x44254012,0x2d8b1f8a,0x16dd33d9,0x442d007a}},	//   _til_, dece_, _मधुब, _uue_,
   {{0x4425ba36,0x60061ad1,0x2d991030,0xcee900c2}},	//   _uil_, мным_, edse_, ждое_,
   {{0xd17500c6,0xaf090f98,0x00000000,0x00000000}},	//   _жылы, تقدم_, --, --,
   {{0xfce60938,0x2ca00128,0x9f450036,0xdb1c02c6}},	//   домо, _prid_, golò_, jkrá,
   {{0x68e900cb,0x7bde0063,0xef1800e8,0x71720286}},	//   _žedn, _pmpu, deļu_, _شهوا,
   {{0x395200a1,0x78a20094,0xe9df0076,0x2d9946a2}},	//   ways_, ťovk, _amú_, adse_,
   {{0xab274447,0x7c220036,0x9f4501f9,0x00000000}},	//   дора_, _èorm, soló_, --,
   {{0x2ca003e5,0x9f450451,0x2d8bba37,0x2a6a25d9}},	//   _trid_, colò_, cece_, rubb_,
   {{0xeb9a007e,0x39520c8d,0x00000000,0x00000000}},	// [e280] _дип_, rays_, --, --,
   {{0x77fa007d,0xbcfb47a1,0x7bde0112,0xc1da00b7}},	//   ्तेक_, rgét, _umpu, _बग्ग,
   {{0xef1801d3,0xb9053d34,0x6fc401b5,0xddc2020a}},	//   beļu_, _भे_, _dòch, culţ,
   {{0xdb1c0094,0x80d40033,0x24840231,0xe5c5004d}},	//   ckrá, দপত্, _ppmm_, нсіо,
   {{0x63ba0087,0xc953040a,0x6d46061d,0x00000000}},	//   _potn, _שמש_, ibka, --,
   {{0x2d8b2562,0x9cd70327,0x63ba00bd,0x00000000}},	//   zece_, וונה_, _qotn, --,
   {{0xf1a9009d,0xbcfb001c,0x2d99057a,0x41a90096}},	//   कांन, ngér, ydse_, कांस,
   {{0xa3ac000f,0xcb1300a1,0x3d0f00a4,0x00000000}},	//   गाह_, כלו_, _ठरले_, --,
   {{0x2d8b013d,0x92be0033,0x00000000,0x00000000}},	//   vece_, ঁছে_, --, --,
   {{0x6442ba38,0x9ed80396,0xdfd0450f,0xdb1c00d4}},	//   mpoi, змот_, ايد_, zkrá,
   {{0x6442a448,0xdd910190,0x00000000,0x00000000}},	//   lpoi, هود_, --, --,
   {{0xfe78013f,0xa3ac0096,0xb7d50065,0x00000000}},	//   rtį_, गाव_, _iṣej, --,
   {{0x2d8b222b,0x5c07013d,0x621b006e,0x2d9969cd}},	//   rece_, дява, _וואק, rdse_,
   {{0xab8408cb,0x2d8b0660,0x6fc400b3,0x00000000}},	//   куск, sece_, _oòci, --,
   {{0x7bc70088,0x3f8c08a9,0xbcfb00fd,0x8ae40120}},	//   rkju, medu_, ggér, вітл,
   {{0x3e780018,0x7bc7ba39,0x3f8cba3a,0x6b970188}},	//   mét_, skju, ledu_, _waxg,
   {{0x2aff0e5e,0xb81519e8,0x48154ce6,0x3e780103}},	// [e290] _शुरु_, едај, емас, lét_,
   {{0xdb1c0088,0xa8a400e5,0x00000000,0x00000000}},	//   skrá, ърск, --, --,
   {{0x601400b3,0x3e7801f9,0xef1800e8,0x00000000}},	//   càme, nét_, peļu_, --,
   {{0x25a904d8,0x00000000,0x00000000,0x00000000}},	//   ñal_, --, --, --,
   {{0xb7d50139,0x63850cc3,0xa92802c6,0x6fc4022b}},	//   _aṣej, егла, _vyžá, _tòch,
   {{0x3f8c3b92,0x3e780018,0xe299947a,0xb4af02d5}},	//   jedu_, két_, зак_, _ओपी_,
   {{0xf220000f,0x3e780018,0x45d5004d,0xdd3200a7}},	//   मगढ़_, jét_, _зовс, _nəşr,
   {{0x69da020d,0x00000000,0x00000000,0x00000000}},	//   étex, --, --, --,
   {{0x60250012,0x7f75002d,0x00000000,0x00000000}},	//   ндиа, нунц, --, --,
   {{0x443f43b4,0xf2c70686,0x6fcd033c,0x00000000}},	//   _itu_, _осен, _búca, --,
   {{0x3e780018,0x5de66924,0x64596310,0xc7b20289}},	//   gét_, ежна, lswi, אבי_,
   {{0x443f73be,0x78a200d4,0xdb050139,0xdbf80285}},	//   _ktu_, ťovi, _lohó, ंक्ड_,
   {{0x315600f5,0x2d9e030b,0x3f8c0284,0x707500c1}},	//   _ניסן_, ěte_, bedu_, _נײַע_,
   {{0x443f1ee3,0x645901c0,0x00000000,0x00000000}},	//   _mtu_, iswi, --, --,
   {{0xc4ab0285,0x753b039f,0x00000000,0x00000000}},	//   चमुख, _ofuz, --, --,
   {{0x443f0857,0x69260831,0x60140428,0x17fa1178}},	//   _otu_, емба, ràme, ्त्व_,
   {{0x443f006c,0x645901c0,0x6fc4015e,0x07a60565}},	// [e2a0] _ntu_, jswi, _sòci, наан,
   {{0x317f061d,0x64597d7c,0x753b063d,0x46f61941}},	//   hfuz_, dswi, _afuz, нчет,
   {{0x443fba3b,0xd9101e49,0x056629db,0x6fcd0072}},	//   _atu_, _چیز_, евен, _xúca,
   {{0xd91003ed,0x644201af,0x7deb00c6,0x2e3a006e}},	//   _نیز_, tpoi, tęsi, לגענ,
   {{0x64592b5e,0xa3ac0b7f,0x5f06023a,0x3e7801f9}},	//   gswi, गाल_, _सुन्_, zét_,
   {{0x443fba3c,0x3e780103,0x753b063d,0x00000000}},	//   _dtu_, yét_, _efuz, --,
   {{0xfe67003f,0x644222e7,0x443f00ac,0x6829013f}},	//   _حد_, spoi, _etu_, _užda,
   {{0x7dc61de7,0x3e780103,0x6442ba3d,0x443f020b}},	//   _fósi, vét_, ppoi, _ftu_,
   {{0x63ab030b,0x443f00a4,0x3f8c0995,0xdb1c17a5}},	//   ální, _gtu_, tedu_, lkrä,
   {{0x3e780018,0xdefa0077,0x629c00b6,0xf1a900b6}},	//   tét_, зым_, _šrou, काउन,
   {{0x3f8cba3e,0xe0cf001c,0xdb1c2271,0x00000000}},	//   redu_, لزی_, nkrä, --,
   {{0x3e78ba3f,0x00000000,0x00000000,0x00000000}},	//   rét_, --, --, --,
   {{0x61e2ba40,0x3e780018,0x3f8cba41,0x0ca8a20f}},	//   _imol, sét_, pedu_, нтри_,
   {{0x6fe60257,0xd9c90be4,0x3e7801f9,0x9f5e03a9}},	//   _décè, रस्ट, pét_, koté_,
   {{0x6602ba42,0x5fa60751,0xb6060218,0xdb1c042c}},	//   kook, _कोयल, _košć, chrü,
   {{0x64402c0a,0x660200aa,0x19941441,0x00000000}},	//   _otmi, jook, лася, --,
   {{0xb60602f7,0x8dfc00ca,0xfc3f00b3,0x00000000}},	// [e2b0] _mošć, _מההת, rxís_, --,
   {{0x62881570,0x65600037,0x443f00e8,0x61e20139}},	//   _opdo, _admh, _rtu_, _lmol,
   {{0x61e2ba43,0xf6531e56,0x64440012,0x443fba44}},	//   _omol, ائط_, ţiil, _stu_,
   {{0xcb12040a,0x37040396,0x6459091f,0xa2a40d61}},	//   _כלי_, учув, tswi, किन्,
   {{0x6288013f,0xa3ac00b7,0xdb1c0076,0xe22f00fe}},	//   _apdo, गां_, bhró, ợđiệ,
   {{0x3949ba45,0x320606a8,0x64594251,0xdb170042}},	//   lbas_, _akoy_, rswi, _loxí,
   {{0x64400dea,0xbe120081,0xe296008f,0x9f5e020d}},	//   _etmi, _সংসদ_, ващ_, coté_,
   {{0x56945779,0x61e200c4,0x63a401c2,0x443fba46}},	//   _щаст, _cmol, ɓinm, _ttu_,
   {{0x443f1c35,0x25ad00ae,0x7fd507bf,0x00000000}},	//   _utu_, _inel_, віні, --,
   {{0xee393cf9,0x00000000,0x00000000,0x00000000}},	//   мно_, --, --, --,
   {{0x9d461c21,0x7e7e0212,0x7c220036,0x25ad76b8}},	//   кенд, _äppl, _èori, _knel_,
   {{0x38696334,0xb6061197,0xdb170072,0x6b85009c}},	//   krar_, _gošć, _coxí, _abhg,
   {{0x320d22d4,0x39491528,0x7de40103,0x38698680}},	//   mley_, dbas_, sőso, jrar_,
   {{0x3869ba47,0x39498722,0x5f050d02,0x320d5410}},	//   drar_, ebas_, _изла, lley_,
   {{0x2d9b00dd,0x62880072,0xa6ec0033,0x38690b85}},	//   _faqe_, _xpdo, _কর্ম_, erar_,
   {{0x25bf002d,0xb222003e,0x8d760246,0xf2d20266}},	//   _noul_, _þætt, _شابا, בעל_,
   {{0xdb1c0037,0x66020357,0xdb1e0216,0x00000000}},	// [e2c0] thró, vook, _kopë, --,
   {{0x46a63c32,0x25ad02a8,0x7bd501bf,0xdb1c1489}},	//   казв, _anel_, chzu, tkrä,
   {{0x39498594,0x25bf02f1,0xe57a08a1,0x6602083e}},	//   bbas_, _boul_, дзе_, took,
   {{0xceb2193b,0x600f4b39,0x04463ba4,0x25ad0036}},	//   ייב_, dømm, ведн, _cnel_,
   {{0xdb1c0f3a,0x25bf0154,0x200c003e,0x20070141}},	//   skrä, _doul_, yldi_, _okni_,
   {{0xf7430aeb,0x25adba48,0x2b58009c,0x66020283}},	//   _веро, _enel_, narc_, sook,
   {{0x37e32082,0x25bf02f1,0x66e6ba49,0xa3de09c4}},	//   _торг, _foul_, _рова, दोष_,
   {{0x2b580a1b,0x320dba4a,0x30a641c3,0x200700cb}},	//   harc_, gley_, вров, _akni_,
   {{0x142678ee,0x2eca1cd4,0xa0670a28,0xdb17002b}},	//   _адам, ान्त, вања_, _roxí,
   {{0x78a624b5,0xb4ce14e5,0x0eea00a9,0xd9bf1244}},	//   _mrkv, शनी_, дьми_, _एक्ट,
   {{0x442c041c,0x2d9b023b,0x320dba4b,0x394900c6}},	//   _iid_, _paqe_, bley_, ybas_,
   {{0x61460ed1,0x32060124,0x3869012a,0x3dd20178}},	//   _реда, _ukoy_, yrar_, _clyw_,
   {{0x7d1600a5,0x442c00d7,0x4cb82458,0x00000000}},	//   _czys, _kid_, вляю_, --,
   {{0x4ea6002d,0x38695368,0x6fc4015e,0xdb1e0113}},	//   _ариа, vrar_, _còct, _kopè,
   {{0x442cba4c,0xa3b3009d,0x257d25c1,0x1ae60081}},	//   _mid_, टात_, náló_, _খুবই_,
   {{0x442cba4d,0x38693024,0x3204ba4e,0x394900c6}},	//   _lid_, trar_, nomy_, ubas_,
   {{0x78a602e6,0x3949ba4f,0x442c401c,0x3f9cba50}},	// [e2d0] _crkv, rbas_, _oid_, _kavu_,
   {{0x3869ba51,0x6fcd1f9f,0x25ad0505,0x442c02ad}},	//   rrar_, _núcl, _snel_, _nid_,
   {{0x25bfba52,0x320d32dd,0x32042ea3,0xa3ac0287}},	//   _poul_, yley_, komy_, गाई_,
   {{0x6e2d260a,0x3869ba53,0xb87b002b,0x320d0643}},	//   _jiab, prar_, _oxíx, xley_,
   {{0x442c4c9d,0x6e2d2375,0xd83802e3,0x225e01ff}},	//   _bid_, _miab, _аэс_, _avtk_,
   {{0x442c008a,0x799d9c99,0x7d0d0169,0x69cd0063}},	//   _cid_, _hasw, _myas, lkae,
   {{0x36d525a4,0x442c00a1,0x799d604e,0x7d0dba54}},	//   _совр, _did_, _kasw, _lyas,
   {{0x442c1b2e,0x600f0856,0x2c1a00aa,0x6e2d6c20}},	//   _eid_, rømm, _मीनू_, _niab,
   {{0x44f50109,0x442c03e5,0x320d0238,0xe4e702ec}},	//   _спас, _fid_, rley_, _рівн,
   {{0x320dba55,0x442cba56,0x6ed30092,0x7dc6002b}},	//   sley_, _gid_, ləbə, _lóst,
   {{0xc7d600a1,0x7d0d781c,0x02d903ef,0x661b0113}},	//   רותי_, _ayas, _ثواب_, _khuk,
   {{0x8c460a22,0x6e2d028d,0x799d1c35,0x7d0d3834}},	//   леме, _ciab, _nasw, _byas,
   {{0x40790130,0x61e9ba57,0x1ae10033,0x7d0d02a4}},	//   _נאַװ, miel, _খুলে_, _cyas,
   {{0x61e9ba58,0x799d0172,0x7d0d02f1,0x63ad03e3}},	//   liel, _aasw, _dyas, ɓanc,
   {{0xada60036,0x2005ba59,0x3f875607,0x09cc0081}},	//   _байл, moli_, _ibnu_, রোফা,
   {{0x61e9ba5a,0xa2a4022d,0x20056106,0x6e2d019c}},	//   niel, कित्, loli_, _giab,
   {{0x60c9456e,0x7d1600a5,0x186703d9,0x7deb0138}},	// [e2e0] nyem, _uzys, лати_, ręst,
   {{0x2005ba5b,0x61e92889,0x661b0239,0x9f45020d}},	//   noli_, hiel, _ahuk, filé_,
   {{0x6d56ba5c,0x61e9ba5d,0x661b01b2,0x2005028d}},	//   _keya, kiel, _bhuk, ioli_,
   {{0x442cba5e,0x661b3aca,0x2005ba5f,0xf1a300a5}},	//   _sid_, _chuk, holi_, _खोलन,
   {{0x100304a9,0x2005ba60,0x6d563c10,0x61e90220}},	//   रकाश_, koli_, _meya, diel,
   {{0xa3de00a5,0x66092190,0x60db01d3,0x661b0634}},	//   दों_, _ekek, dzum, _ehuk,
   {{0x442cba61,0x61e9454d,0x200500f0,0x78a43852}},	//   _vid_, fiel, doli_, lviv,
   {{0x3f9c0029,0xb3a41344,0x61e900a5,0xdb1e0143}},	//   _savu_, _गोरख, giel, _copé,
   {{0x442c0501,0x6e2dba62,0xf48709b4,0x32040146}},	//   _tid_, _riab, _مالی, romy_,
   {{0x2005ba63,0x987b0130,0x3204039f,0x7d0d02a4}},	//   goli_, עריק, somy_, _ryas,
   {{0x61e9ba64,0x6d5634bd,0x3df51896,0x7d0db9e3}},	//   biel, _beya, изос, _syas,
   {{0x61e9ba65,0x60c98d91,0x57c10096,0xfc3f02c6}},	//   ciel, byem, _एव्ह, jvíc_,
   {{0x6d56ba66,0x1c16007a,0x3f9c01d3,0x60c905bd}},	//   _deya, _दीहल_, _tavu_, cyem,
   {{0x20050465,0x6b9eba67,0x7d0d4835,0x6d562ccb}},	//   coli_, _capg, _vyas, _eeya,
   {{0x799d87fd,0x7dc68811,0x6e2d0124,0x6d560154}},	//   _pasw, _póst, _tiab, _feya,
   {{0x6d56ba68,0x7d0d0c45,0x6e4301c3,0x6e2d009c}},	//   _geya, _tyas, _انيم, _uiab,
   {{0xac95007e,0xb4ce09a1,0x629a0090,0x69cd0e22}},	// [e2f0] _тапш, शनो_, _lsto, rkae,
   {{0x61e9ba69,0x629aba6a,0x661b0e69,0xb33c003d}},	//   ziel, _osto, _shuk, _jaħd,
   {{0xa3d8121d,0x799d2911,0x2ca90146,0x56951278}},	//   ासन_, _tasw, _hrad_, рает,
   {{0x20050816,0x788700d9,0x00000000,0x00000000}},	//   zoli_, tīvā, --, --,
   {{0x2d890113,0x20050415,0x629a3f1f,0x00000000}},	//   _mbae_, yoli_, _asto, --,
   {{0x03a51357,0x61e9ba6b,0x69d80138,0xa4e50096}},	//   рико, wiel, _įvei, _कधीच_,
   {{0x2005ba6c,0x291900e7,0x661bba6d,0x61e92325}},	//   voli_, _hzsa_, _thuk, tiel,
   {{0x60c9ba6e,0x660946b6,0x60db5817,0x20053939}},	//   tyem, _ukek, tzum, woli_,
   {{0x61e97b49,0x2005ba6f,0x629ab1e1,0x6d560c56}},	//   riel, toli_, _esto, _reya,
   {{0x61e9ba70,0xb33c02a1,0x8e85008f,0xf99f0383}},	//   siel, _caħd, агое, _chèz_,
   {{0x612b1f8a,0x2005ba71,0x61e9ba72,0x2ca900d3}},	//   _bölü, roli_, piel, _arad_,
   {{0xb2ba00a1,0xa3b3049d,0x8d760781,0xb7c4044c}},	//   _במער, टाव_, جادا, ăţit,
   {{0x4b2300c7,0x200519a6,0x7c380995,0x7df200d9}},	//   _ব্লগ_, poli_, _čvrs, nāsi,
   {{0x629a02ad,0x78a400e5,0x6d560361,0x00000000}},	//   _ysto, vviv, _weya, --,
   {{0x6d569c09,0xb7d50af0,0x39460610,0x68fd0113}},	//   _teya, _aṣoj, ñoso_, _axsd,
   {{0xf2d200c1,0x213f061d,0x3eaa02b6,0x612b0555}},	//   קען_, ncuh_, æbte_, _gölü,
   {{0x6b9e0139,0xe73a23f9,0x00000000,0x00000000}},	// [e300] _tapg, вез_, --, --,
   {{0x3cf10146,0x657b0167,0x78a4411b,0x076a0076}},	//   šová_, _acuh, rviv, ئماً_,
   {{0x248dba73,0xa2b1314f,0x4aba00ae,0xdb050537}},	//   _apem_, _अपग्, _рупя_, _anhæ,
   {{0xa2a4269c,0x32ee0092,0xa3de0034,0x629a0234}},	//   किस्, _rəy_, दोई_, _rsto,
   {{0x998c00c6,0x27f80231,0x00000000,0x00000000}},	//   ūdų_, _tjrn_, --, --,
   {{0x386002bc,0x3940ba74,0xe2f81acf,0xfc3f0328}},	//   msir_, lcis_, лелі_, nvía_,
   {{0xfe063087,0x4e064ff1,0xae06049d,0xd257013f}},	//   रवास_, रवाई_, रवान_, ацы_,
   {{0x3940673c,0x629a174d,0x00000000,0x00000000}},	//   ncis_, _vsto, --, --,
   {{0x3860ba75,0x80b00101,0xdfda013d,0xf99f0154}},	//   nsir_, जमें, вън_, _chèy_,
   {{0x3860025a,0x4ea66752,0x4fc61bc1,0x9f890032}},	//   isir_, арма, рсиа, _kúù_,
   {{0x35ab0ed3,0x2ca90231,0x07370327,0x9f890139}},	//   _घोड़, _srad_, יאים_, _júù_,
   {{0xb33c03e5,0x7de7004d,0x5fa600a4,0x6fcd00da}},	//   _waħd, ріод, _कोरल, _lúch,
   {{0xb33c003d,0x5c742b67,0x91a600fe,0x3940009c}},	//   _taħd, олят, _gió_, dcis_,
   {{0xf99f01dc,0xdb1e0178,0x39400877,0x5fad00a4}},	//   _saè_, _copï, ecis_, _झोपल,
   {{0x9b5829db,0x00000000,0x00000000,0x00000000}},	//   рист_, --, --, --,
   {{0x38600da3,0xb33c009e,0x00000000,0x00000000}},	//   fsir_, _jaħb, --, --,
   {{0x7afe1ba6,0x2ca91f54,0x89384a6f,0xb33c009e}},	// [e310] _expt, _urad_, рпус_, _maħb,
   {{0xd75900b1,0xf773006f,0xcb9900d6,0x7dc61097}},	//   الات_, تار_, _свої_, _hósp,
   {{0x248d0090,0x6fcd0037,0x29070034,0xdd1f02c6}},	//   _spem_, _dúch, łna_, vířo,
   {{0x6d5dba76,0x76ac0139,0x316603a9,0xf53900d4}},	//   nasa, _e̟yo, _ndoz_, _baťa_,
   {{0xdff80e52,0x64a5147c,0x7bc50006,0x7afb0233}},	//   ुवाद_, сала, _kohu, ğutu,
   {{0xf67700cd,0x316601ff,0xa3cc0179,0x42550002}},	//   _پاسخ, _adoz_, _लवण_, бтит,
   {{0x6d5dba77,0x9f5e028d,0xc293010d,0xe81d10e9}},	//   kasa, dotà_, تیاب, _बीया_,
   {{0x96f81c4c,0x7bc5ba78,0xdb0502c3,0x846700e5}},	//   _тест_, _lohu, _inhä, _въже,
   {{0x6d5dba79,0xe8d90134,0x9f450036,0xd4980291}},	//   dasa, daị_, bilì_, _врх_,
   {{0x395900a1,0x7bc5ba7a,0xe81d1e93,0x6b9514f3}},	//   _less_, _nohu, _बीमा_, jezg,
   {{0xee36002d,0xed5a0d9b,0x6d5d341b,0x81d60081}},	//   йнэ_, лон_, fasa, _সদর_,
   {{0xfbc91723,0x63a18ca2,0xfc4600b6,0x38600dff}},	//   _את_, _haln, říme_, ysir_,
   {{0x63a1282c,0x22810018,0x7bc5ba7b,0xa06933d4}},	//   _kaln, lók_, _bohu, _сала_,
   {{0x63a130d9,0x8fa40037,0xcee800d1,0x7bc500fc}},	//   _jaln, _ومنه, ارین_, _cohu,
   {{0xc33209c1,0x15f70179,0xa96a141a,0x91db4422}},	//   לום_, ंचार_, лива_, _बताई,
   {{0x386064d6,0x1a2a44ab,0x2ba8030b,0xfc3f0143}},	//   tsir_, ужби_, _छोरा, svía_,
   {{0x395931c1,0x6c8600e3,0xdb0501bf,0x3940ba7c}},	// [e320] _dess_, _الخم, _anhä, rcis_,
   {{0x63a107ac,0x38600167,0x6eca00a7,0x228101f9}},	//   _naln, rsir_, bəbd, kók_,
   {{0x3860ba7d,0xdb1e025b,0x3e63026a,0xf99f03a9}},	//   ssir_, _kopí, nıt_, _okèh_,
   {{0x250b037f,0x22810103,0x499a3ac9,0x63a101ee}},	//   گرمی_, dók_, _стоя_, _aaln,
   {{0x779400bf,0xb6080031,0x00000000,0x00000000}},	//   _ویرا, _našť, --, --,
   {{0x25a00ec8,0x6d5dba7e,0xf99f00bf,0xd3700037}},	//   žil_, zasa, _akèh_, ذهب_,
   {{0x6d5dba7f,0x69c6ba80,0x6d440034,0x3a3aba81}},	//   yasa, _koke, _ofia, _jupp_,
   {{0x66f700ca,0x69c6ba82,0xb33c0090,0x00000000}},	//   _המלא_, _joke, _qaħb, --,
   {{0xa3d80454,0x6d5dba83,0x69c6013f,0x63a1ba84}},	//   ासद_, vasa, _moke, _faln,
   {{0x22810088,0x389b00a1,0x63a1ba85,0x2e4a008f}},	//   bók_, ניינ, _galn, лямо_,
   {{0x66fa06ae,0x9f5eba86,0x799601b9,0xd36f0037}},	//   ्थिक_, gotá_, keyw, _أهم_,
   {{0x2bd10ff9,0x7bc800aa,0x69c65161,0xe8d90294}},	//   हस्थ, ödun, _noke, lfụ_,
   {{0x6d5d06e1,0x63a10dea,0x7bc5ba87,0xf1a90286}},	//   rasa, _yaln, _pohu, _خاله_,
   {{0x6d5dba88,0x395928e3,0x8fa303fc,0x27180789}},	//   sasa, _sess_, _наче, _थरूर_,
   {{0x69c60ec9,0xcf2600e3,0x682900c6,0x99670565}},	//   _boke, _ارشي, _uždi, йтал,
   {{0x69c646d8,0x5c7500c2,0x6d5dba89,0x06df0033}},	//   _coke, _длит, qasa, _বুঝি,
   {{0x7bc5ba8a,0x22810018,0xdc550281,0x69c6ba8b}},	// [e330] _tohu, zók_, _برعک, _doke,
   {{0x67eb03e5,0xd6db0012,0x7bdc5a54,0xdb050212}},	//   rżjo, лте_, chru, _anhå,
   {{0xa9350c10,0x00000000,0x00000000,0x00000000}},	//   _менш, --, --, --,
   {{0x69c60141,0xd56b0120,0x00000000,0x00000000}},	//   _goke, рiал, --, --,
   {{0xd7fb02ec,0xa87900c1,0xa5bd013f,0x63a15433}},	//   _був_, _דאָר, _siųs, _paln,
   {{0x22810068,0x3e630390,0x69c6039f,0x644b0036}},	//   tók_, yıt_, _zoke, rpgi,
   {{0x657a0080,0x6eca00a7,0x6fa60d75,0x00000000}},	//   úchá, həbb, _कोइं, --,
   {{0x6283042d,0x644b0149,0x228100ea,0x63a119ca}},	//   rtno, ppgi, rók_, _waln,
   {{0x62833472,0x63a1ba8c,0x4f950d72,0x9f4502c6}},	//   stno, _taln, орну, silí_,
   {{0x9e653f98,0x6d443c59,0x4fe92105,0x249f0090}},	//   овод, _sfia, рмон_, _isum_,
   {{0xdb1e0146,0x442700f9,0xf77200ca,0xd12e0103}},	//   _popí, mmn_, וקי_, ٹمی_,
   {{0x2b5a00ee,0x00000000,0x00000000,0x00000000}},	//   _sepc_, --, --, --,
   {{0x7bdca1dd,0x94b70096,0x00000000,0x00000000}},	//   thru, _आपोआ, --, --,
   {{0x69c60878,0xe1f900c6,0x63a401c2,0x00000000}},	//   _soke, lnų_, ɓins, --,
   {{0xfaa32cbf,0x2fc74090,0x69c6ba8d,0x656902c6}},	//   маро, _iong_, _poke, _odeh,
   {{0x7bdc008a,0xe9d71a9c,0x69d80138,0x6ec6030b}},	//   shru, окс_, _įves, ाहरु,
   {{0x2fc713b5,0x57ea11fb,0x61eb0063,0x47c60e20}},	// [e340] _kong_, адам_, _mmgl, обав,
   {{0x2fc7ba8e,0x65690af0,0x95f4014e,0xe8140179}},	//   _jong_, _adeh, ेक्ट_, _तीखा_,
   {{0x2fc7ba8f,0x6449ba90,0xa3b33f50,0x69c6ba91}},	//   _mong_, _atei, टाई_, _toke,
   {{0x2fc7ba92,0x2a050294,0x00000000,0x00000000}},	//   _long_, ịara_, --, --,
   {{0x7de40103,0x649a3ef8,0x27ea037a,0x2fc7010a}},	//   lőss, ртер_, _tmbn_, _oong_,
   {{0x66e68084,0x2fc7ba93,0xb33c003d,0x64490037}},	//   _дога, _nong_, _baħa, _dtei,
   {{0x9f45028d,0x64495063,0x00000000,0x00000000}},	//   dilà_, _etei, --, --,
   {{0xb33c0078,0xe57704a1,0x6449009c,0xc1b826b8}},	//   _daħa, _мзс_, _ftei, слих_,
   {{0xdfd00080,0x2fc7ba94,0x9f4c00fd,0xa3e7023a}},	//   فية_, _bong_, lidé_, मोह_,
   {{0x2fc70019,0x388e01d3,0xb33c009e,0x2d80066a}},	//   _cong_, mērā_, _faħa, _acie_,
   {{0xdefa0077,0x2fc74bfc,0x2ca0ba95,0x601405fe}},	//   рып_, _dong_, _asid_, nàmi,
   {{0xd0eb0096,0xdce400d4,0x00000000,0x00000000}},	//   _जेवण_, _edič, --, --,
   {{0x2fc752e6,0xd7da0096,0x24863cca,0x39520537}},	//   _fong_, णसाच, ntom_, dbys_,
   {{0xfc3f24c7,0x2fc700f3,0x61ed0220,0xa3b30557}},	//   svío_, _gong_, ďale, टाए_,
   {{0x69d8013f,0x200c6848,0x6fcd0314,0x600f01df}},	//   _įver, modi_, _cúcu, rømt,
   {{0x25a40899,0x2fc79821,0x2486161f,0x601400b3}},	//   _naml_, _zong_, ktom_, dàmi,
   {{0x25a602e0,0x2d99ba96,0x2fc737b7,0xdcfd00d9}},	// [e350] ddol_, mese_, _yong_, resē,
   {{0x2a78593b,0x2fc70019,0x200c00f0,0x25a60220}},	//   burb_, _xong_, nodi_, edol_,
   {{0x64490bd8,0xfdff0e50,0x80ac009f,0xe1f900c6}},	//   _stei, _उदास_, जिडे, ynų_,
   {{0x1a9a00c1,0x2d99ba97,0x248614f3,0x4a9a00ca}},	//   _פירע, nese_, ftom_, _פירג,
   {{0x200c94d8,0x2d99028d,0xd7770037,0xb33c0078}},	//   kodi_, iese_, _واسع, _saħa,
   {{0xe0190251,0x2d99ba98,0xf1a30034,0x25a600f0}},	//   _नींद_, hese_, _खोजन, adol_,
   {{0x2fc7ba99,0x2d99ba9a,0x9f4c0257,0x200c086e}},	//   _rong_, kese_, cidé_, dodi_,
   {{0x249f01bb,0x2fc700a1,0x2486006c,0x01650396}},	//   _tsum_, _song_, btom_, чкио,
   {{0x2d99ba9b,0x2fc7ba9c,0x249f01dc,0x64490161}},	//   dese_, _pong_, _usum_, _utei,
   {{0xb4d70490,0x200cba9d,0xa3e7009f,0x2d803caf}},	//   ानी_, godi_, मोश_, _scie_,
   {{0x2d99ba9e,0xf77200c1,0x2fc700de,0x68290138}},	//   fese_, עקט_, _vong_, _uždu,
   {{0x2fc70979,0x2d99ba9f,0xa3e70c3c,0x5dda0f97}},	//   _wong_, gese_, मोर_, сфор_,
   {{0x621a0105,0x61fb002d,0x5576006e,0xb33c0090}},	//   _פונק, mnul, הערן_, _maħn,
   {{0x8fa50ad8,0x600f01df,0x69cb34fe,0x2fc70023}},	//   _хаке, røms, ögen, _uong_,
   {{0x2d99baa0,0x25a698da,0x61fb044c,0x8b23166f}},	//   bese_, ydol_, onul, едре,
   {{0x61fb601a,0x9f4c0314,0x24862e32,0x68460161}},	//   nnul, vidé_, ytom_, знаа,
   {{0x09e33af7,0x24860206,0xdb1e00d8,0x00000000}},	// [e360] хотн, xtom_, _dopá, --,
   {{0x00460134,0x7bd50364,0x7b070103,0x386f0103}},	//   _jụụ_, ckzu, érté, ágra_,
   {{0x61fb6361,0x91db2a06,0xb33c0090,0x6e240aa3}},	//   knul, बसाई, _baħn, _khib,
   {{0x601405fe,0x200c0106,0x248600ca,0xa2bf6935}},	//   ràmi, zodi_, ttom_, वमन्,
   {{0x29370130,0x78a90b14,0x61fb0218,0xc44800d1}},	//   _מאכן_, _ševv, dnul, زیان_,
   {{0x69c43650,0x2d99083e,0x261c034f,0xdb1e0031}},	//   ljie, zese_, cíon_, _zopá,
   {{0x200c00e9,0x5333002d,0x2d99baa1,0x25a40113}},	//   vodi_, нешт, yese_, _taml_,
   {{0x2d9903be,0x61fbbaa2,0x69c4baa3,0x7d040072}},	//   xese_, gnul, njie, _oxis,
   {{0x2d99baa4,0x200cbaa5,0x68e447dc,0x74160e25}},	//   vese_, todi_, nzid, _فورا,
   {{0x6e24baa6,0x2d99baa7,0x61fbbaa8,0x9fb400d2}},	//   _ahib, wese_, anul, _tříd_,
   {{0x2d99baa9,0x00000000,0x00000000,0x00000000}},	//   tese_, --, --, --,
   {{0x67e00149,0x69c4003d,0x9c87033d,0x65620239}},	//   _höjd, jjie, _načí, naoh,
   {{0x2d99baaa,0x6e240694,0x69c4baab,0x200c0036}},	//   rese_, _dhib, djie, podi_,
   {{0x2d99baac,0xfc3fbaad,0x69d606b0,0x68e42647}},	//   sese_, lvík_, ekye, dzid,
   {{0x3a293c43,0x2d99baae,0xba08009f,0x05dd09a1}},	//   tmap_, pese_, वकूफ_, _मतलब,
   {{0x6e240441,0x5a340752,0x7d1600c2,0x64be0096}},	//   _ghib, енст, _fyys, ्हाळ,
   {{0x7e7a0324,0x6d5f02a1,0x00000000,0x00000000}},	// [e370] lutp, _ieqa, --, --,
   {{0x61fb0106,0x67e00212,0x6fdc02d5,0x6143003e}},	//   znul, _nöjd, यसिं, _kíló,
   {{0x3a29baaf,0xdb1e0220,0x61fb7c2a,0x6d5f0052}},	//   pmap_, _topá, ynul, _keqa,
   {{0x7e9b00c1,0xe81d0006,0x25e8009f,0xe3b8020e}},	//   מסבו, _बीरा_, चोली_, _anı_,
   {{0xb4d74035,0x61fb077e,0x03a511a0,0x2fdc0381}},	//   ाने_, vnul, дило, _olvg_,
   {{0xa3e700a5,0x9c870363,0x7c37009e,0x00000000}},	//   मों_, _začí, _jixr, --,
   {{0x61fb08a9,0x78ad00aa,0x6d460212,0xc9000033}},	//   tnul, lvav, ycka, ্ধৃত_,
   {{0x61fbbab0,0x20031d67,0xa6c40033,0x6d5f6567}},	//   unul, čjim_, _এইচট, _neqa,
   {{0x61fb53b4,0x753b0129,0x8f750c10,0x6d4102c6}},	//   rnul, _iguz, муні, ělal,
   {{0x6e24bab1,0x262800d3,0x798d00f0,0x443f0090}},	//   _shib, _uşor_, hfaw, _iuu_,
   {{0x443f068d,0x69dd038c,0x7d160084,0x6d5f88a5}},	//   _huu_, _olse, _syys, _beqa,
   {{0x443fbab2,0x9f470037,0x645b0154,0x7d16007b}},	//   _kuu_, _imní_, _kwui, _pyys,
   {{0x443fbab3,0x4425bab4,0x7c3702a1,0x67e00212}},	//   _juu_, _khl_, _bixr, _höje,
   {{0x443f3a53,0x7c2501b9,0xf99f022b,0xb33c00bd}},	//   _muu_, _chhr, _okès_, _naħl,
   {{0x160d00e2,0x69c4bab5,0xfebb00cd,0x753b08f3}},	//   िकार_, tjie, _داشت_, _oguz,
   {{0x1de20285,0x753bbab6,0x7d0401e9,0x6e240027}},	//   _पतित, _nguz, _txis, _uhib,
   {{0x6b930222,0xb4d7142e,0x2d9205bd,0xdb05022b}},	// [e380] ädgå, ानो_, _ibye_, _lahè,
   {{0x69c4057a,0x753b5eef,0x46f60cba,0x69ddbab7}},	//   sjie, _aguz, мчет, _else,
   {{0x6b9cbab8,0x69c403e5,0x67e00149,0xb33c0078}},	//   merg, pjie, _nöje, _daħl,
   {{0x443f008a,0x93bc00de,0x601d0036,0x63ad0022}},	//   _buu_, _chăn, kèmo, ɓani,
   {{0x249a037f,0x442557b0,0x044342e0,0x645b03a9}},	//   تخاب_, _bhl_, вечн, _cwui,
   {{0x753b6bd0,0xe73a158d,0x442501b9,0x443fbab9}},	//   _eguz, _фев_, _chl_, _duu_,
   {{0x645d003d,0xdced03e0,0xfe672296,0x00000000}},	//   _ħsie, _ocağ, _جد_, --,
   {{0x6b9cbaba,0x68290138,0x443fbabb,0x00000000}},	//   herg, _uždr, _fuu_, --,
   {{0x645b0d2a,0xfc3f003e,0x60f8036a,0x443fbabc}},	//   _gwui, rvík_, яния_, _guu_,
   {{0x2d920154,0xe29a065c,0x4425009c,0x6b9c00f2}},	//   _abye_, _маз_, _ghl_, jerg,
   {{0x6440babd,0x78ad14f3,0x600f01df,0x65601a3a}},	//   _humi, zvav, rømp, _kemh,
   {{0x64409e0d,0x2cb20150,0x7bde0085,0x63a8babe}},	//   _kumi, _bryd_, _alpu, _hadn,
   {{0x7c84490c,0xa3b30efb,0x6440babf,0x673c0357}},	//   куре, _जोड_, _jumi, _ogrj,
   {{0x6440bac0,0x63a8084f,0x6b9c76f9,0x2d9206b0}},	//   _mumi, _jadn, gerg, _ebye_,
   {{0x6440bac1,0x9e070c59,0x494c0134,0xa3e60d77}},	//   _lumi, _очил, _ọdịy, _पतन_,
   {{0xb0d20285,0x2cb2bac2,0x644002ac,0xdb0701f9}},	//   _तथाग, _fryd_, _oumi, ndjé,
   {{0x6440bac3,0x9be700d6,0x7c3714d8,0x63ba0a88}},	// [e390] _numi, _жінк, _tixr, _ontn,
   {{0xf7700678,0x443f00ec,0x78ad3b2a,0x6b9c061d}},	//   لام_, _ruu_, rvav, cerg,
   {{0xb4d700b6,0x443fbac4,0x78ad31e8,0x44250167}},	//   ान्_, _suu_, svav, _rhl_,
   {{0x6440bac5,0x69dd1a63,0x443f72e3,0x63baadbb}},	//   _bumi, _ulse, _puu_, _antn,
   {{0x6440bac6,0x63a8008a,0xf992040a,0xe9df0af0}},	//   _cumi, _badn, _ערך_, _ilú_,
   {{0x6440bac7,0x628a01df,0x3869bac8,0x394b0090}},	//   _dumi, ftfo, msar_, _hfcs_,
   {{0x443f008a,0x59d300c0,0x93bc00de,0x63a8bac9}},	//   _wuu_, _सवार, _thăn, _dadn,
   {{0x6440baca,0x443fbacb,0x29dc0072,0x63ba0364}},	//   _fumi, _tuu_, _lían_, _entn,
   {{0x3869727a,0x394910d9,0x9f8901cd,0x317f01ff}},	//   nsar_, icas_, _búð_, rguz_,
   {{0x38690396,0x6b9c20df,0x93270246,0x39490063}},	//   isar_, xerg, _قران, hcas_,
   {{0x644001bf,0x628a01c0,0xef190686,0x9f4c0ba6}},	//   _zumi, ctfo, ямо_, cidí_,
   {{0x63a83e75,0xed5702ec,0x6440bacc,0x2cb20150}},	//   _zadn, ною_, _yumi, _pryd_,
   {{0x522c0130,0x6eca00a7,0x68fb0995,0x6440008c}},	//   _וואַ, ləbl, _žudn, _xumi,
   {{0x7bc700dd,0xc058015a,0x6b9c0364,0x3949bacd}},	//   gjju, _آشنا_, uerg, ecas_,
   {{0x6b9c18f0,0xb5e80032,0x501a006e,0x291901ee}},	//   rerg, _bẹ̀r, _צוצו, _aysa_,
   {{0xe9df0037,0x6b9c4da6,0x2919030a,0x00000000}},	//   _clú_, serg, _bysa_, --,
   {{0x3a391ad8,0x48e33407,0xdce601d3,0x78a9007e}},	// [e3a0] _disp_, готв, nekļ, _ševr,
   {{0x64400706,0x66e63898,0x394900e1,0x656022fa}},	//   _rumi, ноза, acas_, _semh,
   {{0x63a80dab,0x20034f2f,0x3949023e,0x3869bace}},	//   _radn, čjih_, bcas_, asar_,
   {{0x7ddf01e5,0x644000a6,0x2d82ba77,0x9f4c0094}},	//   _kësa, _pumi, ngke_, vidí_,
   {{0x211e0789,0x7c2e0036,0x6fd6020d,0xfba4097c}},	//   _परेश_, ombr, _fâch, _ओसाम,
   {{0x628abacf,0xa5200096,0xd25a0cfc,0x6fd6020d}},	//   ttfo, _बरीच_, пци_, _gâch,
   {{0x63a8af16,0x764e3135,0xdb050113,0xfbd30289}},	//   _vadn, _utby, _pahé, רתו_,
   {{0x64402d9a,0x63a80188,0x64a60138,0x00000000}},	//   _tumi, _wadn, _паба, --,
   {{0x628a224d,0x2bd100b7,0xb33c02a1,0x7a0500c6}},	//   stfo, _सकला, _jaħk, nėta,
   {{0xddc90034,0x39490314,0x6eca00a7,0xb33c00bd}},	//   łożo, zcas_, bəbl, _maħk,
   {{0x11d600d6,0x59e01101,0x00000000,0x00000000}},	//   _підр, नसार, --, --,
   {{0x7c2ebad0,0x6d4008a9,0x6b850036,0x7a0500c6}},	//   embr, žman, _schg, kėta,
   {{0x68fb0220,0x442e5d0a,0x3a39028d,0x20d30a09}},	//   _ľudo, omf_, _risp_, _متوج,
   {{0x7a0500c6,0x00000000,0x00000000,0x00000000}},	//   dėta, --, --, --,
   {{0x3f9e166d,0x3869006d,0x29dc002b,0x78a6004d}},	//   metu_, wsar_, _vían_, _askv,
   {{0x386977b7,0x7c2e0036,0x7afa7d11,0x00000000}},	//   tsar_, ambr, útta, --,
   {{0x39490b0b,0xc4c40068,0x3869bad1,0xa31d00c3}},	// [e3b0] rcas_, _اے_, usar_, _फर्ज_,
   {{0x3949386c,0x37070950,0x3869bad2,0xb33c00bd}},	//   scas_, нчев, rsar_, _daħk,
   {{0xf7700c5e,0x98141857,0x3869727a,0x34d9030b}},	//   صال_, ابقا, ssar_, भन्द,
   {{0x3869bad3,0x3a39028d,0x3f9e37ba,0x00000000}},	//   psar_, _uisp_, hetu_, --,
   {{0x64a51502,0x6fd600fd,0x25a90206,0x58d4227c}},	//   тала, _tâch, ľal_, _боят,
   {{0x3f9e03c6,0x69cf04a3,0x25a95c64,0xe29909ba}},	//   jetu_, _hoce, žal_, дак_,
   {{0x3f9e01e9,0xdb050143,0x6d4d06b0,0xdb1c1088}},	//   detu_, _inhó, _ofaa, skrö,
   {{0x69cf1428,0x65950077,0xf4850018,0x6d4d06b0}},	//   _joce, _шабу, _لائی, _nfaa,
   {{0x3c240149,0xb95b0139,0x00000000,0x00000000}},	//   höva_, _enìg, --, --,
   {{0x6d4dbad4,0x69cf01d3,0xd00e00ab,0xbcfb0677}},	//   _afaa, _loce, يلي_, raél,
   {{0x442003e3,0xdcfd00e8,0x00000000,0x00000000}},	//   ɓi_, besī, --, --,
   {{0x11f900cd,0x4095a087,0x00000000,0x00000000}},	//   _کوچک_, _аркт, --, --,
   {{0xe0ce0a51,0x3f9e318a,0xddc9031a,0x00000000}},	//   _тв_, betu_, budž, --,
   {{0x2eb52b49,0x6d4d0361,0xab2a0138,0x00000000}},	//   _асис, _efaa, дога_, --,
   {{0xdee501a0,0x6d4d06b0,0xaf76006e,0x63ad03e3}},	//   _шоки, _ffaa, _סעקס_, ɓant,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69cf4a03,0x23672e48,0xa520009d,0xdddb00b6}},	// [e3c0] _doce, kanj_, _बरेच_, jstř,
   {{0x69cf0072,0x4a461b4d,0xd7f900d6,0x2367033b}},	//   _eoce, _инов, нує_, janj_,
   {{0x26dc0579,0x2367015c,0x922102d5,0x69cf02c6}},	//   ávo_, danj_, मताज_, _foce,
   {{0x3f9e6b2f,0x69cfbad5,0xb33c02a1,0x00000000}},	//   zetu_, _goce, _taħk, --,
   {{0x3f9e0a4b,0x00000000,0x00000000,0x00000000}},	//   yetu_, --, --, --,
   {{0xdb0e0102,0x9cd700ca,0xdb0500b3,0x78a40169}},	//   _þjón, כונה_, _inhò, mwiv,
   {{0x3f9e005f,0x32630ae3,0x81ab0033,0xe2971009}},	//   vetu_, атыв, খান_, вај_,
   {{0x79844753,0x7bdc4f9b,0x161a0034,0x00000000}},	//   ngiw, hkru, _फीचर_, --,
   {{0x64a33af5,0x3f9e00e9,0x30140360,0x236700cb}},	//   _ката, tetu_, лдир, banj_,
   {{0xa3e6417a,0xdefa0109,0x236700cc,0xbbd1030b}},	//   _पति_, дым_, canj_, _सकेक,
   {{0xdef41736,0xddc9150a,0x2ee90022,0x877b00ca}},	//   упны, rudž, _ƙafa_, ואיי,
   {{0x3f9ebad6,0xe0da0831,0x660216c7,0x92e40233}},	//   setu_, _ове_, nnok, ışıl,
   {{0xa3e60d0b,0x69cf80b6,0x61e2bad7,0x66022c6f}},	//   _पता_, _roce, _ilol, inok,
   {{0x6602bad8,0x69cfa46e,0x5c04004b,0x7bdc03de}},	//   hnok, _soce, аяса, gkru,
   {{0x61e20113,0x00000000,0x00000000,0x00000000}},	//   _klol, --, --, --,
   {{0x66020018,0x1f3700ca,0xddc800ae,0x201e135a}},	//   jnok, _ברור_, ălţi, llti_,
   {{0x69cf299e,0x201e028d,0x9f5e020d,0x61e20a4b}},	// [e3d0] _voce, olti_, enté_, _mlol,
   {{0xb8cb0d0b,0x7bdc20af,0x61e200b3,0x798406b0}},	//   _कई_, ckru, _llol, agiw,
   {{0x2367bad9,0x61e2b836,0xd57513fc,0xfc3f0072}},	//   vanj_, _olol, гуль, rvíu_,
   {{0x7ddf00dd,0x98650068,0xa2b80d7a,0x7a050138}},	//   _mëso, _میرے_, ्मन्, mėto,
   {{0x7a050138,0xdb050072,0x629a0a61,0x1514004d}},	//   lėto, _mahí, _apto, адця,
   {{0x61e2bada,0xa3b31244,0xfc3f002b,0x66020062}},	//   _alol, _जोश_, lvís_, anok,
   {{0xe2990426,0x2367877a,0x7a0500c6,0x00000000}},	//   хай_, ranj_, nėto, --,
   {{0xa3b32ebd,0x236700e7,0x2ca91c65,0x629a00ee}},	//   _जोर_, sanj_, _osad_, _dpto,
   {{0x2367badb,0x601d05fe,0x25bfbadc,0x7fd50565}},	//   panj_, lèmi, _inul_, гіні,
   {{0xab4a01e9,0xbfc500c2,0x7a050138,0x61e20103}},	//   _kaмe, убок, kėto, _elol,
   {{0xe3b00fba,0xa2d500e3,0x32551476,0xdb051f8b}},	//   _برق_, _حيات, _свер, _bahí,
   {{0x2d8900b3,0x8d760076,0x7a0500c6,0x00000000}},	//   _ccae_, دادا, dėto, --,
   {{0x2245badd,0xe1f90138,0x23650218,0x7bdcaf8c}},	//   _hulk_, mių_, _kelj_, tkru,
   {{0xe1f908a1,0x224501c2,0x8c430243,0x0ffb0781}},	//   lių_, _kulk_, сере, _تعصب_,
   {{0x7bdc5aff,0x2ca9bade,0x00000000,0x00000000}},	//   rkru, _esad_, --, --,
   {{0xe1f908a1,0x601d05fe,0x98a62957,0x3eb800f2}},	//   nių_, dèmi, либе, ærte_,
   {{0xa6ca33e7,0xa9260a0e,0x66020141,0x61fe0131}},	// [e3e0] کوال_, удал, vnok, épli,
   {{0x25bf0012,0xa3b30fef,0xfc3f00b3,0x38cb00d1}},	//   _anul_, _जोल_, avís_, راقی_,
   {{0xe1f901b3,0xb8cb63e1,0xe57a450e,0xf99f0113}},	//   kių_, _कै_, езе_, _ijèn_,
   {{0x25ad02e0,0x6b9b00c4,0x00000000,0x00000000}},	//   _cael_, đuge, --, --,
   {{0x7c3ebadf,0x23650154,0x6602bae0,0x00000000}},	//   _kipr, _belj_, rnok, --,
   {{0x66020c90,0x7c3e00bd,0x2245bae1,0x3dd2030a}},	//   snok, _jipr, _bulk_, _loyw_,
   {{0x25ad0131,0x601d015e,0xdcff0090,0x00000000}},	//   _fael_, cèmi, _taqħ, --,
   {{0x25ad02e0,0xa07424ec,0xe1f90138,0x7c3e0169}},	//   _gael_, агич, gių_, _lipr,
   {{0xdfd00080,0x2edc000d,0x69dc02d5,0xa5070cc6}},	//   قية_, मन्त, _नवनी, _бета_,
   {{0x749b00f5,0xb4e00251,0x7ddf023b,0x2ca9af61}},	//   _אימפ, दनी_, _pëso, _rsad_,
   {{0xe1f9013f,0x3a203da1,0x38170327,0x00000000}},	//   bių_, klip_, רקים_, --,
   {{0x614603fc,0x443e00ca,0xe1f900c6,0x3206063d}},	//   _седа, _hit_, cių_, _ujoy_,
   {{0x3a200270,0x443e1ef2,0x224501cb,0x7c3e093e}},	//   dlip_, _kit_, _zulk_, _bipr,
   {{0x9f341acf,0x7c3ebae2,0xe7bf0081,0x3a2b037a}},	//   _келі, _cipr, _ইত্য, _shcp_,
   {{0x443ebae3,0x7c3e1084,0xda782dfb,0x442cbae4}},	//   _mit_, _dipr, лят_, _mhd_,
   {{0xf99f0154,0x442c030a,0xda7800d4,0x3a20bae5}},	//   _ejèn_, _lhd_, áďa_, glip_,
   {{0x7c3e002b,0x2ca90f83,0x6e2dbae6,0x57f55bb1}},	// [e3f0] _fipr, _usad_, _ihab, апат,
   {{0x443ebae7,0x7c3e019c,0x316601ff,0xe1f900c6}},	//   _nit_, _gipr, _leoz_, zių_,
   {{0x6e2dbae8,0x6d5d01ee,0x6d4f028d,0xdb0500f0}},	//   _khab, obsa, occa, _wahâ,
   {{0x443ebae9,0x65956924,0xa567010d,0x2bc3149b}},	//   _ait_, раду, ادان, शावा,
   {{0xe1f901b3,0x442c08d3,0xdb1e022b,0x7de40103}},	//   vių_, _bhd_, _anpè, tősz,
   {{0x987a00c1,0xa87a0341,0xd7e4004d,0x25ad0df8}},	//   _באשט, _באשר, _лісо, _wael_,
   {{0x443e7bb0,0x67e0070a,0xfa341e49,0x3cfc00a5}},	//   _dit_, _möjl, _خرید, _लेने_,
   {{0x25bf0012,0x443e00f3,0x40953335,0x67e00212}},	//   _unul_, _eit_, арот, _löjl,
   {{0xe1f908a1,0x68ed0fb6,0xe4501be8,0x661b00ac}},	//   rių_, nzad, _فضل_, _ikuk,
   {{0xe1f901b3,0x998908bb,0x443e01e8,0x76470193}},	//   sių_, ylaş_, _git_, _kujy,
   {{0xed5a3277,0x63a3baea,0x7c3ebaeb,0xa2b809c3}},	//   кон_, menn, _ripr, ्मण्,
   {{0x6283baec,0x63a3baed,0x443e0505,0x6e2dbaee}},	//   muno, lenn, _zit_, _chab,
   {{0x660900dd,0x6e2d32bd,0x62837b2e,0x61e917ba}},	//   _mjek, _dhab, luno, mhel,
   {{0x61e95cfe,0x66090ea3,0x656b0129,0x61fbbaef}},	//   lhel, _ljek, hagh, liul,
   {{0x661b3ce4,0xa96a013d,0x7647baf0,0x6283baf1}},	//   _okuk, кива_, _nujy, nuno,
   {{0x63a3baf2,0x6e2d10f0,0x61e9baf3,0x661b3834}},	//   henn, _ghab, nhel, _nkuk,

   {{0x63a3baf4,0x60db0453,0x6283baf5,0x656b1098}},	// [e400] kenn, nyum, huno, dagh,
   {{0x63a3baf6,0x6283570a,0x60c905fe,0x661bbaf7}},	//   jenn, kuno, ixem, _akuk,
   {{0x5b7b0054,0x63a3235d,0x61e9baf8,0x68ed0042}},	//   _בריא, denn, khel, azad,
   {{0x62830009,0xdcf601e8,0x61fb0051,0x443e3763}},	//   duno, _hayı, jiul, _sit_,
   {{0xdcf60b88,0x63a302ad,0x61e937c9,0x61fb00d3}},	//   _kayı, fenn, dhel, diul,
   {{0x6609baf9,0x75290095,0x62837219,0x661b0201}},	//   _ejek, _dzez, funo, _ekuk,
   {{0x443ebafa,0x6283bafb,0xdcf608bb,0xdce6025b}},	//   _vit_, guno, _mayı, dakč,
   {{0x98b201e8,0x91fc00d9,0x660900f3,0x61fb3397}},	//   layı_, _avār, _gjek, giul,
   {{0x443ebafc,0x4fc607ef,0x63a302ad,0x27f800ec}},	//   _tit_, асна, benn, _kmrn_,
   {{0x443e2cbc,0x6e2dbafd,0x6d44a762,0x62830112}},	//   _uit_, _shab, _agia, buno,
   {{0x6283002d,0x6e2d76ca,0x61e9067d,0x91e66561}},	//   cuno, _phab, bhel, _коже,
   {{0x51830058,0x61fb00d3,0x6e2d6417,0x6d44b929}},	//   _душа, ciul, _qhab, _cgia,
   {{0x3eb901d3,0xdcf6008b,0xd7c93ec4,0x998900c4}},	//   āsta_, _bayı, रामच, jmaš_,
   {{0x764006a3,0x6d440a00,0x8fa30399,0x6fb30037}},	//   _limy, _egia, _маче, _ومنا,
   {{0x6e2d0080,0x99676e90,0x9f5e0037,0x6d44009c}},	//   _thab, итал, nntí_, _fgia,
   {{0x68edbafe,0x827700c1,0x6e2d5f1d,0x9f5e0076}},	//   tzad, יעלע_, _uhab, intí_,
   {{0x63a3baff,0x7c9500e3,0x776701fa,0x656bbb00}},	// [e410] yenn, _الخص, _pejx, vagh,
   {{0x68ed4ca3,0xd6db6e90,0x660900d6,0x6283bb01}},	//   rzad, кте_, _sjek, yuno,
   {{0x656b00ac,0xf77000e3,0xdb050f3a,0x95cb0084}},	//   tagh, باق_, _anhö, куда_,
   {{0x361802ec,0x63a3bb02,0xdcf6026a,0x261c05e6}},	//   ацію_, wenn, _zayı, díos_,
   {{0xdcf60390,0x656bbb03,0x22b500d9,0x66090fa3}},	//   _yayı, ragh, _sāk_, _vjek,
   {{0x656b498a,0x261c0610,0xdb0500b6,0x6283bb04}},	//   sagh, fíos_, _zahá, tuno,
   {{0x61e9067d,0x656b0e55,0x63a3bb05,0x6609bb06}},	//   thel, pagh, renn, _tjek,
   {{0x63a3bb07,0x62830ce9,0xc6920130,0x661b0060}},	//   senn, runo, _מאל_, _ukuk,
   {{0x6283bb08,0x61e9bb09,0x20d53006,0x61fb00d3}},	//   suno, rhel, сійс, riul,
   {{0x61e9bb0a,0x61fbbb0b,0xddc900e7,0x6283bb0c}},	//   shel, siul, grdž, puno,
   {{0xee3a078b,0x7ddf01e5,0x61e9067d,0x60db0560}},	//   лно_, _kësh, phel, syum,
   {{0x6441bb0d,0xdcf60702,0xd12e010d,0x682900b6}},	//   _hili, _sayı, ظمی_, _vždy,
   {{0x6441bb0e,0x60c403e5,0xdea10018,0x7ddf023b}},	//   _kili, _ġimg, _کیجی, _mësh,
   {{0xdcf601d4,0x6441b538,0x7ddf023b,0x66190034}},	//   _qayı, _jili, _lësh, howk,
   {{0x6449002b,0x98b203e0,0x00000000,0x00000000}},	//   _luei, vayı_, --, --,
   {{0x6441bb0f,0x7f3a006e,0x656958da,0x91a600fe}},	//   _lili, _געצו, _neeh, _khó_,
   {{0x644100e3,0x249f023e,0xdce40138,0xb33c009e}},	// [e420] _oili, _npum_, _keič, _jaħr,
   {{0x644194dc,0x7640bb10,0x3b8619e8,0x14c8001c}},	//   _nili, _simy, _улог, یهای_,
   {{0x3cfc0034,0x98b20367,0xa9a60a7c,0x261c0072}},	//   _लेते_, rayı_, _линд, xíos_,
   {{0x261c09b3,0x6441bb11,0x7ddf0052,0x00000000}},	//   víos_, _aili, _cësh, --,
   {{0x64413c2e,0x7ddf01e5,0x44fa0103,0x644940bb}},	//   _bili, _dësh, دراج_, _cuei,
   {{0x6441bb12,0x74160081,0x76400169,0x00000000}},	//   _cili, াষ্ট_, _wimy, --,
   {{0xf99f0383,0x764000f9,0xaaba02d5,0xd7e704e6}},	//   _akèy_, _timy, ॉमिक, _умре_,
   {{0x6441bb13,0x90540293,0xb33c00bd,0x261c5bef}},	//   _eili, овиц, _baħr, ríos_,
   {{0x6441bb14,0xa3b32125,0xdd17034c,0xc1b7163d}},	//   _fili, _जोक_, _धुंध_, слых_,
   {{0x64415a28,0x6569029a,0x00000000,0x00000000}},	//   _gili, _zeeh, --, --,
   {{0x200b20df,0x1dc40096,0xa3ad3212,0x0357021e}},	//   écia_, षांत, _औसत_, _היבש_,
   {{0x6441068d,0xb95b0139,0x7ddf0216,0x00000000}},	//   _zili, _anìn, _kësi, --,
   {{0x6441bb15,0x248602ef,0xf1c50179,0xb33c0078}},	//   _yili, nuom_, वारन, _taħs,
   {{0x6441bb16,0x7ddf00dd,0x682b0233,0x00000000}},	//   _xili, _mësi, küda, --,
   {{0x81ab00c7,0x9b5800d3,0x49560134,0x7a0500c6}},	//   খার_, сист_, _ọtụ_, lėti,
   {{0xd25700ca,0xb33c02a1,0x7de7001c,0x00000000}},	//   משלה_, _jaħq, _دستم, --,
   {{0x02a51f88,0x6fdf00fc,0x7a05004b,0x00000000}},	// [e430] _खन्न, _bêch, nėti, --,
   {{0x644906fc,0xe9df00e3,0xdd3100a5,0x8af900e5}},	//   _ruei, _siúd_, _mężc, _внос_,
   {{0x7bc5bb17,0x64412162,0x7ddf0052,0x6569009c}},	//   _inhu, _rili, _pësh, _peeh,
   {{0x19ab0a54,0xf8bf0032,0x7a050138,0x249f0063}},	//   _стоп_, _ayée_, kėti, _ppum_,
   {{0x64495bdb,0x7ddf00dd,0xdb0501e8,0x2509001c}},	//   _quei, _vësh, _bahç, جرای_,
   {{0x6441953e,0x7a05013f,0x42552cf5,0xf99f0113}},	//   _qili, dėti, отит, _ojèk_,
   {{0x64419d73,0x02b309c3,0x78bd00c4,0xc7b200ca}},	//   _vili, ंटेन, _hrsv, _קבל_,
   {{0x6441bb18,0x65943e7b,0xe1f10781,0x93970103}},	//   _wili, _насу, بست_, _گجرا,
   {{0x6441bb19,0x63c400b6,0xb33c0090,0x9f5e016d}},	//   _tili, átní, _daħq, mitê_,
   {{0xcf3900d6,0xdb1e026a,0x644110e4,0x2d99084e}},	//   ичні_, _popü, _uili, efse_,
   {{0x8e0a1720,0x63c402c6,0x23740031,0x415537f2}},	//   инов_, štní, šajú_, _двес,
   {{0xfbc90054,0xb33c003d,0xa2b80285,0x2480bb1a}},	//   _בת_, _taħr, ्मर्, šime_,
   {{0x68300149,0xf99f0113,0x7bd7044c,0x00000000}},	//   läde, _ijèh_, _boxu, --,
   {{0xdee5186d,0x8af70092,0x653a006e,0x9f450143}},	//   _моли, ğənn, יערד, riló_,
   {{0xed5a0465,0x25a6056c,0x34a60557,0xe7ff2010}},	//   _кой_, yeol_, _गन्द, ोचना_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6fdf0257,0x68300364,0x6fcd077d,0x00000000}},	// [e440] _pêch, häde, तापू, --,
   {{0x7bd701ff,0xfc320037,0x5d860504,0xe9df0503}},	//   _goxu, _تحب_, _الکل, _ciúb_,
   {{0xd9462549,0xb95b01b9,0x387202c3,0xba763a1d}},	//   _мени, _gnìo, ssyr_, _باخت,
   {{0x248600e7,0xa52676c3,0xad9b0076,0x64a602b7}},	//   tuom_, омед, miúc, жада,
   {{0x69c64fdd,0xad9b00e3,0xdb1ebb1b,0x7bd70abd}},	//   _inke, liúc, _topó, _yoxu,
   {{0xb33c02a1,0x00000000,0x00000000,0x00000000}},	//   _saħq, --, --, --,
   {{0x26cc01e5,0x68300212,0x533344b2,0xad9b0076}},	//   _çdo_, rädd, мешт, niúc,
   {{0x672e0292,0xe617008f,0x2fc90022,0xd5ad0018}},	//   _izbj, _ддс_, _ɗage_, _مہم_,
   {{0x65620808,0xc05a004d,0xcfa635c1,0x9f5e0231}},	//   mboh, шій_, ошни, entá_,
   {{0x33d50426,0x9f5e0052,0x6d569c47,0x65621b03}},	//   _ніхт, mitë_, _afya, lboh,
   {{0x245000de,0x69c64c92,0x442903e3,0x9f5e0216}},	//   _hàm_, _onke, ɓa_, litë_,
   {{0x29dc00e1,0x7bda601a,0x00000000,0x00000000}},	//   _mías_, ötun, --, --,
   {{0x9f5e0052,0xceb800c6,0x00000000,0x00000000}},	//   nitë_, svę_, --, --,
   {{0x6b9b005f,0x212b0364,0x245001b9,0xf99f0154}},	//   đugo, üche_, _màm_, _tjèk_,
   {{0x2450011b,0xf96b013d,0x236c007e,0xdce60a84}},	//   _làm_, ирай_, _medj_, rakā,
   {{0xa2b21981,0x5c750ac6,0xdce601d3,0x3cfc007a}},	//   _आनन्, _елит, sakā, _लेवे_,
   {{0x68fb0220,0x7bd700a7,0xa3ea0285,0xe89400c2}},	// [e450] _ľuds, _toxu, मसा_, мать,
   {{0x69c669d5,0x3f8c812d,0xcd340037,0x9f5e0052}},	//   _enke, ngdu_, _غريب, ditë_,
   {{0xac380076,0x6d4802c6,0x799d0350,0x00000000}},	//   _بسيط_, ědav, _tbsw, --,
   {{0x29dc11c4,0xdb1e05fe,0x9f5e023b,0x9ad30134}},	//   _días_, _topò, fitë_, hịko,
   {{0x24f802e3,0xf99f026e,0x8cbe007f,0x6fbc00a4}},	//   онцы_, _ibè_, शियो, ्ञां,
   {{0xf8bfbb1c,0x493a00a1,0xf8da00ca,0x683002c3}},	//   _iré_, _לגרו, _החשמ, täde,
   {{0x81b400c7,0x9f5e0428,0x4b7c006e,0x2fc9020b}},	//   ঞান_, mitè_, באוו, _đag_,
   {{0x798dbb1d,0xf1b91197,0x34950d0f,0x9f5e41a8}},	//   ngaw, koše_, _набр, litè_,
   {{0x657b05bd,0x2458007b,0x798d0350,0xf99f0139}},	//   _iduh, _мать_, igaw, _mbè_,
   {{0x1e850ce5,0x7ddf00dd,0xf1b900cc,0x645b0231}},	//   плом, _mësu, doše_, _itui,
   {{0x7a050138,0xa3b82519,0x37bd0033,0x798d01dc}},	//   lėtu, _باقر_, _আকার, kgaw,
   {{0xd1b81823,0xcfe900cd,0x44271489,0x78ad1a8b}},	//   _وانا_, _گفته_, lln_, kwav,
   {{0xf1b9015c,0x60c41275,0x6e920103,0x660b03a9}},	//   goše_, _àimp, ولیا, ingk,
   {{0xf99f0065,0x00000000,0x00000000,0x00000000}},	//   _abè_, --, --, --,
   {{0xab2a48ea,0x9f5e023b,0xf8bf0af0,0xee490023}},	//   сова_, zitë_, _aré_, _kẽm_,
   {{0xad9b0080,0x798dbb1e,0x29dc03be,0x8b66010d}},	//   riúc, ggaw, _rías_, _کاظم,
   {{0x98a3062a,0xf1b900cc,0x44270167,0xf8bf0076}},	// [e460] ните, coše_, kln_, _cré_,
   {{0x657b1a78,0x29dc0042,0xf99f10fe,0xf8bf0381}},	//   _aduh, _pías_, _ebè_, _dré_,
   {{0xf8bf0d79,0xba7603c5,0x245000fe,0x2bf700ca}},	//   _eré_, _عادت, _sàm_, _זמין_,
   {{0x29dc04d8,0x645b009c,0x9f5e0052,0xf99f0d79}},	//   _vías_, _btui, titë_, _gbè_,
   {{0x649a5fdd,0x657b0124,0x62831044,0x69da020d}},	//   стер_, _dduh, erno, êteu,
   {{0x3860048e,0x660b3c15,0x9f5e00dd,0x657b0294}},	//   mpir_, angk, ritë_, _eduh,
   {{0x46a311c0,0x9f5e023b,0x7ddf0052,0xd2570fe9}},	//   _парв, sitë_, _këst, пцы_,
   {{0x9f5ebb1f,0x2fc70113,0x3a2200dc,0x2450020b}},	//   mité_, _anng_, _jkkp_, _tàm_,
   {{0x9f5ebb20,0x3cfc13db,0x764e409f,0xdb070052}},	//   lité_, _लेले_, _huby, tejë,
   {{0xb4d80961,0x6602bb21,0x764e3834,0x443801f7}},	//   ाही_, liok, _kuby, _òr_,
   {{0xbcfb33c3,0x9f5e4468,0x8146082c,0x798d00f9}},	//   gbén, nité_, _فنان, ygaw,
   {{0x63aa0088,0x764e3834,0x2fc7010a,0x78ad0167}},	//   lefn, _muby, _enng_, ywav,
   {{0xdb1e022b,0x764ebb22,0x628a007b,0x62981f35}},	//   _anpà, _luby, lufo, ltvo,
   {{0x764e0c56,0x63aa0088,0x307b0089,0x798d01c2}},	//   _ouby, nefn, _פאונ, wgaw,
   {{0x201ebb23,0x628a006d,0x62980a2c,0x798dbb24}},	//   moti_, nufo, ntvo, tgaw,
   {{0xf8bf4a85,0x9f5e0257,0x78ad0172,0x62980629}},	//   _pré_, dité_, twav, itvo,
   {{0x798d0185,0x2c2700d6,0x6d405c56,0x7d7c0289}},	// [e470] rgaw, _ньог, žmar, _הנחו,
   {{0x201e522a,0x9f47025b,0x764e3f75,0x9f5e020d}},	//   noti_, _plné_, _buby, fité_,
   {{0x645bbb25,0x63aa0150,0xd6db008f,0x3dc9211d}},	//   _stui, defn, щта_, _knaw_,
   {{0x764ebb26,0xa2c016e2,0xf8bf2728,0x201ebb27}},	//   _duby, विन्, _tré_, hoti_,
   {{0x3e4c000d,0x628302ad,0x201ebb28,0xb9220294}},	//   _děti_, wrno, koti_, _mkpị_,
   {{0x0fe70081,0x7a050138,0x3a291cc6,0x224601ff}},	//   _পদ্ধ, rėtu, llap_, _aiok_,
   {{0x9f5ebb29,0x201e66af,0x764e34aa,0xe2990f5f}},	//   cité_, doti_, _guby, цай_,
   {{0x24800039,0x60c4bb2a,0x200c00aa,0xc8d10592}},	//   šima_, _šima, endi_, _सपाट,
   {{0x6b9c02ad,0x645b00f9,0x3a290270,0x224601ff}},	//   yfrg, _utui, ilap_, _diok_,
   {{0x201e0f8c,0xb95b0065,0xb4e909b0,0x00000000}},	//   goti_, _bnìk, मनी_, --,
   {{0x3a29bb2b,0xe7f502b0,0x78b801d3,0x683000bc}},	//   klap_, _इतना_, āvvi, näda,
   {{0x200c028d,0xed57036c,0x22460ece,0x3c2402c3}},	//   andi_, мою_, _giok_, hövt_,
   {{0x3a2956ae,0x51840565,0xb95b0065,0xee3713fc}},	//   dlap_, _чуха, _enìk, ьню_,
   {{0x660201e9,0xddc4010a,0x201e1ad8,0x22460062}},	//   ziok, _kiiŋ, coti_, _ziok_,
   {{0x8c431167,0x320d14d0,0xef1f0092,0x9f5e020d}},	//   тере, oney_, şüb_, xité_,
   {{0x9f5e04ea,0x764e02a4,0xad9b0037,0x3d190e1f}},	//   vité_, _ruby, liún, _युके_,
   {{0xd37800e9,0xd7c902e8,0x765cbb2c,0x6e24023f}},	// [e480] _hoće_, रांच, _stry, _ikib,
   {{0x66e62742,0x9f5e96f7,0xad9b0076,0xba5600e5}},	//   моза, tité_, niún, _отмъ,
   {{0x86c60080,0x386000ee,0x4e0234d8,0x3e4c02c6}},	//   بيان, spir_, _लगाई_, _pěti_,
   {{0x9f5e04ea,0x452a062a,0xad9b0037,0x2fc90022}},	//   rité_, ожен_, hiún, _ɗaga_,
   {{0xb4d817ff,0x9f5e0257,0x776e023e,0x6602bb2d}},	//   ाहे_, sité_, _tebx, riok,
   {{0x6602bb2e,0xd25a11d9,0x320d03c3,0x764ea5eb}},	//   siok, оци_, eney_, _tuby,
   {{0x765cbb2f,0xf7431da3,0xdb070018,0x201ebb30}},	//   _utry, _аеро, tejé, voti_,
   {{0x628a0063,0x62985530,0x69d687ab,0x320d7b3f}},	//   rufo, rtvo, njye, gney_,
   {{0x629803d6,0x68e4bb31,0xdb050139,0x201ebb32}},	//   stvo, nyid, _dahù, toti_,
   {{0x6e24048e,0x660000f9,0xad9b0037,0x2486a662}},	//   _akib, _hmmk, giún, mrom_,
   {{0x3c240149,0x3a290009,0xdd950138,0x68e45bae}},	//   hövs_, ylap_, наны, hyid,
   {{0x6e361af5,0x00e604e6,0xd3780357,0x6448bb33}},	//   _chyb, _ожен, _doće_, _hidi,
   {{0x201e0010,0x6448a59e,0xdb0ebb34,0x00000000}},	//   poti_, _kidi, ndbæ, --,
   {{0x6e240a15,0xdf0a147c,0x6448bb35,0x7fb8001c}},	//   _ekib, _мэйл_, _jidi, _رهبر_,
   {{0x6448bb36,0x60c22efd,0x248601b9,0xf1b90095}},	//   _midi, _hrom, hrom_, loša_,
   {{0x1de3000c,0x60c2bb37,0x8cc609c3,0x2d8f02b6}},	//   _पवित, _krom, ामखो, _øge_,
   {{0x7b672a6e,0x64480076,0xb4d806eb,0x3a29bb38}},	// [e490] _отне, _oidi, ाहो_, rlap_,
   {{0x3a29bb39,0x24864205,0x6e3d07ee,0x60c218c7}},	//   slap_, drom_, lmsb, _mrom,
   {{0xf4140033,0x9f4c037a,0x320d008c,0x00000000}},	//   িতার_, lidó_, yney_, --,
   {{0x6448bb3a,0x60c28514,0x68300212,0x00000000}},	//   _aidi, _orom, räda, --,
   {{0x6448bb3b,0xb4e9087c,0xd4693084,0x3eb901d3}},	//   _bidi, मने_, чиле_, āsti_,
   {{0xc6a752c3,0x64480188,0x69ddbb3c,0x00000000}},	//   _орби, _cidi, _hose, --,
   {{0x6d4d0694,0x69ddbb3d,0x387e01d3,0xa2b8077d}},	//   _ogaa, _kose, _ātri_, ्मग्,
   {{0x69ddbb3e,0x60c2bb3f,0x6d4dbb40,0x9e480220}},	//   _jose, _brom, _ngaa, _keďž,
   {{0x6448bb41,0x69ddbb42,0x6e360150,0x320dbb43}},	//   _fidi, _mose, _rhyb, rney_,
   {{0x60c20d9a,0x6d4d3b3c,0x6448bb44,0x6e24bb45}},	//   _drom, _agaa, _gidi, _skib,
   {{0xad9b00e3,0x60c2bb46,0xa2c00096,0x3204007f}},	//   riún, _erom, विण्, bimy_,
   {{0x69ddbb47,0xad9b0080,0x7c250694,0xd378084f}},	//   _nose, siún, _akhr, _voće_,
   {{0x61e93581,0x76490063,0x3a2081aa,0x60c2bb48}},	//   mkel, _miey, voip_, _grom,
   {{0xe51000aa,0x6e3d9512,0x76490063,0xad9b0037}},	//   ़पति_, amsb, _liey, liúl,
   {{0x2005bb49,0xf1d306ae,0x161f0775,0x69ddbb4a}},	//   mili_, थापन, यकार_, _bose,
   {{0xf2d20132,0x61e9bb4b,0x69ddbb4c,0xa2c03ec9}},	//   נען_, nkel, _cose, वित्,
   {{0xa84a52c6,0x69dd92a4,0xb4e900b7,0x61e901c0}},	// [e4a0] سلام_, _dose, मनो_, ikel,
   {{0x5fb70557,0x61e9bb4d,0xad9b0076,0x68f60034}},	//   _असफल, hkel, hiúl, rzyd,
   {{0x61e9bb4e,0x69ddbb4f,0x68e40918,0x7bde0451}},	//   kkel, _fose, syid, _iopu,
   {{0x69dd1d0c,0x7ae12a40,0x2005756f,0x75298af6}},	//   _gose, älte, hili_, _byez,
   {{0x20053061,0x7bdebb50,0x6448bb51,0x439400c2}},	//   kili_, _kopu, _pidi, валс,
   {{0x2005ae0d,0x2480bb52,0x2486bb53,0x61e90371}},	//   jili_, šimo_, rrom_, ekel,
   {{0x6448360a,0x2486bb54,0x7529063d,0x61e918f0}},	//   _vidi, srom_, _eyez, fkel,
   {{0xe643ae87,0x7bde0084,0x6448a4be,0x69dd01f2}},	//   _бесп, _lopu, _widi, _xose,
   {{0x6448070a,0xa3d004f1,0x31570037,0x09c50033}},	//   _tidi, षाद_, رجية_, _একমা,
   {{0x20050b88,0xa2c00d88,0x2d800032,0x320400a5}},	//   gili_, विद्, _adie_, simy_,
   {{0x211a11a2,0x9f5e0037,0xf1b95ecd,0x1b050033}},	//   _کتاب_, ontú_, soša_, _শুনে_,
   {{0x61e90924,0xc33300ca,0xad9b0037,0x00000000}},	//   ckel, _עוף_, ciúl, --,
   {{0x2005bb55,0xafe62383,0x7bde084e,0xe9df033c}},	//   bili_, _подл, _bopu, _diúl_,
   {{0x69ddbb56,0x9f4c0231,0x00000000,0x00000000}},	//   _sose, ridó_, --, --,
   {{0xdeef0d4f,0x09c50081,0xf1c5030b,0x16bc3212}},	//   _сы_, _একবা, वाचन, ोमोब,
   {{0xf1a6110f,0x3cfc0006,0x6d4d008a,0x99cf0081}},	//   _कॉमन, _लेके_, _ugaa, রস্ক,
   {{0x76490063,0x41b802d5,0x04f20033,0x69dd0141}},	// [e4b0] _riey, _आसनस, জপুর_, _vose,
   {{0xf7701a13,0x7c2502fa,0x7bde0090,0x61e912c3}},	//   مام_, _ukhr, _gopu, zkel,
   {{0x57a4013f,0xb4e90285,0x569500c2,0x61e9bb57}},	//   ышта, मन्_, тает, ykel,
   {{0x75290154,0x2b1a00b6,0x00000000,0x00000000}},	//   _pyez, _मुटु_, --, --,
   {{0x4425056c,0x20054102,0xb4bd0ff9,0x63ba56b2}},	//   _pkl_, yili_, ेमे_, _batn,
   {{0x03a50a29,0x63ba2343,0x20050092,0x23290236}},	//   тико, _catn, xili_, моли_,
   {{0x61e9bb58,0xb5a7186f,0xad9b0037,0x25a4007e}},	//   tkel, _прай, tiúl, _fbml_,
   {{0x2005bb59,0x163500c2,0x63a400e7,0x68300364}},	//   wili_, _ребя, đina, hädl,
   {{0x61e9531b,0x63ba4df3,0x44250f09,0x00000000}},	//   rkel, _fatn, _tkl_, --,
   {{0x61e90c5f,0x63ba01cd,0xe9df00e3,0x44250167}},	//   skel, _gatn, _siúl_, _ukl_,
   {{0x2005bb5a,0x35c60378,0x2ca972b7,0xfbd500b6}},	//   rili_, _रोड़, _apad_, दानम,
   {{0x63ba00dc,0xdbd50032,0x1d0a1110,0x7bde5ef9}},	//   _zatn, _gúús, деми_, _sopu,
   {{0xad9b016d,0x63ba0167,0x5ff50562,0x00000000}},	//   ciúm, _yatn, _изду, --,
   {{0x2005bb5b,0xafe2007b,0x00000000,0x00000000}},	//   qili_, _вошл, --, --,
   {{0xab272156,0x00000000,0x00000000,0x00000000}},	//   вора_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bde6485,0x25bd02ad,0x673503e5,0x3eb901d3}},	// [e4c0] _topu, ddwl_, _azzj, āstu_,
   {{0x98a31a53,0xdb1c023b,0xf1b900e8,0x00000000}},	//   рифе, ndrë, košo_, --,
   {{0x63ba03ce,0xc81502ec,0xf98685d8,0xf1b901d3}},	//   _ratn, уєть, _игно, jošo_,
   {{0x63ba08c5,0x7c2e19ce,0xf1b900e8,0xdb0e02c3}},	//   _satn, llbr, došo_, rdbä,
   {{0x63babb5c,0x2b0602b0,0x00000000,0x00000000}},	//   _patn, _हेतु_, --, --,
   {{0xdb0702c6,0x87b9007b,0x82a6007b,0x00000000}},	//   zejí, _пуст_, вшие, --,
   {{0xfba41362,0x63ba23ff,0x00000000,0x00000000}},	//   ख्यम, _vatn, --, --,
   {{0xbbdf244d,0xdb0500d4,0x00000000,0x00000000}},	//   _नक्क, _nahý, --, --,
   {{0x63babb5d,0x5edf0033,0xa44637f2,0x00000000}},	//   _tatn, _ফেলে, _анад, --,
   {{0xef1f026a,0x1da50ded,0x9ed8001f,0x00000000}},	//   ğün_, ग्नत, емот_, --,
   {{0x2ca90063,0xef1f03e0,0xd36f001c,0x00000000}},	//   _spad_, şün_, _ذهن_, --,
   {{0x24891b33,0x7e7a18ef,0xdb1c0052,0x067b006e}},	//   šame_, rstp, adrë, ונטל,
   {{0x5c07013d,0x6fb60037,0x2a050294,0xdb07034f}},	//   вява, _لمشا, ịaka_, rejí,
   {{0xdb07030b,0x00000000,0x00000000,0x00000000}},	//   sejí, --, --, --,
   {{0x9b581b82,0x9f5e6c5f,0x2bd51687,0x2019201c}},	//   тист_, mità_, दाबा, ésie_,
   {{0x9f5e6755,0x996425a9,0x20b6023a,0x00000000}},	//   lità_, итул, _अनाध, --,
   {{0x6d5d0103,0x10170018,0x6d5f02a1,0x995400d3}},	// [e4d0] mcsa, _سکیں_, _ifqa, ркуц,
   {{0x9f5e2fce,0x109b00ca,0x683002c3,0xdb0500d8}},	//   nità_, ובמב, lädj, _zahý,
   {{0xf7703a1d,0x00000000,0x00000000,0x00000000}},	//   زال_, --, --, --,
   {{0x6d5d0103,0x80b70bf5,0x00000000,0x00000000}},	//   ncsa, ्टमे, --, --,
   {{0x69cf809a,0x1da516e2,0x4584004d,0x64a58842}},	//   _ince, ग्यत, ргів, уала,
   {{0x59d100c3,0xe29900ae,0x00000000,0x00000000}},	//   हावर, еак_, --, --,
   {{0x9f5e3af8,0xa2c000a5,0x36d40686,0xa3d902d5}},	//   dità_, विष्, _корр, डॉग_,
   {{0xd378150a,0x442e04e2,0x8504009d,0xf4850103}},	//   _voća_, alf_, _शेवट_, _مائی,
   {{0xbcfb49f0,0xc61f0096,0x00000000,0x00000000}},	//   ncéd, यकीय_, --, --,
   {{0xa2c0034d,0x9f5e0036,0x9f450076,0xdb0e00ee}},	//   विश्, gità_, mhlú_, bebè,
   {{0x69cf4945,0xa3d00ed5,0x2459020b,0x00000000}},	//   _once, षार_, _hèm_, --,
   {{0x765500a5,0x24590019,0xa2c042d4,0x00000000}},	//   _muzy, _kèm_, विर्, --,
   {{0xe0ce3fcf,0x2d9e0034,0x24590383,0x00000000}},	//   _ув_, ęte_, _jèm_, --,
   {{0x9f5e0465,0x2d9e00b6,0x245934e5,0x7655022b}},	//   cità_, řte_, _mèm_, _ouzy,
   {{0x657900bd,0xf8bf0018,0x3eb901d3,0xcf240d83}},	//   kawh, _szép_, āsts_, _پروي,
   {{0xdb1cbb5e,0x7ae102c3,0x00000000,0x00000000}},	//   ndré, älta, --, --,
   {{0xdb0e003e,0x245901dc,0x6e2601f9,0xc7a673cd}},	// [e4e0] ndbú, _nèm_, mokb, лиак,
   {{0xb8dc33d9,0x67f20088,0x60c4bb5f,0x46f61da9}},	//   _आन_, _bæja, _šimk, лчет,
   {{0x9f5e00d4,0xe7f50285,0x00000000,0x00000000}},	//   nitá_, _इतरा_, --, --,
   {{0xd5b9021a,0x80a400aa,0x00000000,0x00000000}},	//   ксі_, _कहले, --, --,
   {{0x2eb06dc1,0xbcfb020d,0xa4d40120,0x00000000}},	//   _जन्त, ccéd, ролі, --,
   {{0x63a402ef,0xd7f20076,0x6e2601cb,0x00000000}},	//   đino, _اكس_, hokb, --,
   {{0x9f5ebb60,0xe737530e,0x2bd5045f,0x628a18f0}},	//   vità_, _бер_, दाता, urfo,
   {{0x245902f1,0x2ba400c3,0x442e008c,0x628a1e8f}},	//   _fèm_, ख्ता, slf_, rrfo,
   {{0x9f5e162d,0x463b00c1,0x604649cc,0xe45f0233}},	//   tità_, _טעלע, лхоз, _çöp_,
   {{0x5276345a,0x09e12183,0xad9b00e3,0x21f10146}},	//   _буду, _नव्य, miúi, _váha_,
   {{0x9f5e294c,0x25fb0b94,0x29dc0af3,0xad9b00e3}},	//   rità_, लोकी_, _díaz_, liúi,
   {{0x9f5e008f,0x867b00ca,0x9989007f,0x245902f1}},	//   sità_, ערכו, znał_, _yèm_,
   {{0xcd0741bc,0xae041c83,0xad9b0037,0x9f5e0428}},	//   учни, शोधन_, niúi, pità_,
   {{0x61e20006,0x6c542d33,0xab950831,0x30830037}},	//   _hool, скру, јављ, _الوف,
   {{0xc4c4bb61,0xad9b0037,0x9f5e32c7,0xf1b808d4}},	//   _کے_, hiúi, citá_, _आसान,
   {{0x8277006e,0x00000000,0x00000000,0x00000000}},	//   טעלע_, --, --, --,
   {{0xcfb70033,0x26e20033,0xb6060218,0x478b40cd}},	// [e4f0] জারন, _গেলো_, _mašć, есем_,
   {{0x61e2bb62,0xad9b0037,0x24590023,0xb60600c4}},	//   _lool, diúi, _rèm_, _lašć,
   {{0x657902c9,0xf77079d3,0x24591c45,0xf1c41d96}},	//   tawh, ثاق_, _sèm_, वयान,
   {{0x61e25f42,0x99800031,0x69cf00d7,0x24590154}},	//   _nool, tliť_, _unce, _pèm_,
   {{0xad9b00e3,0x6579bb63,0xdb172ebe,0xa3d00085}},	//   giúi, rawh, _maxí, षां_,
   {{0x32060bb6,0x62651720,0x00000000,0x00000000}},	//   _amoy_, авка, --, --,
   {{0x61e2b6bb,0x255e0174,0xb6060234,0x00000000}},	//   _bool, _ịle_, _bašć, --,
   {{0x245906a3,0x61e25d15,0x9f5e0094,0x11e5972d}},	//   _tèm_, _cool, vitá_, ржим,
   {{0x61e2bb64,0xad9b0037,0x660b9990,0x2054004b}},	//   _dool, ciúi, migk, йтэр,
   {{0x660b0709,0x249f00bd,0xef1f0342,0xff25007e}},	//   ligk, _iqum_, şüm_, импо,
   {{0x02d90814,0x61e2b3b3,0x3255249c,0x3ea50d86}},	//   _جواب_, _fool, _твер, шинг,
   {{0x660b3d79,0x6cc601b6,0x61e2bb65,0x3f8b5c70}},	//   nigk, айма, _gool, şcu_,
   {{0x44270837,0x7ae101bf,0x200b00fd,0x249f00bd}},	//   oon_, ältn, écis_, _jqum_,
   {{0x4427bb66,0x1ef900e3,0x64430037,0x660b01bf}},	//   non_, _لعبة_, nmni, higk,
   {{0xab2a5c37,0x6443bb67,0x4427bb68,0x660b019c}},	//   това_, imni, ion_, kigk,
   {{0x4427bb69,0x248015fe,0x61e2008a,0xdb1e00dd}},	//   hon_, šimi_, _xool, _hapë,
   {{0xa80632f8,0x660b0364,0x97560291,0xdb1e0052}},	// [e500] азал, digk, атељ, _kapë,
   {{0x442729bf,0x644300a5,0xbc7b00ca,0xd7760076}},	//   jon_, jmni, _שנית, شائع,
   {{0x25bfbb6a,0xf99f0383,0xbcfb020d,0x98a700e8}},	//   _baul_, _imèn_, rcée, ānā_,
   {{0xad9b00e3,0xe5a6002d,0x660b5c07,0x00000000}},	//   tiúi, риди, gigk, --,
   {{0x61e203cf,0x248000e3,0x628105e8,0x649a5e41}},	//   _rool, éim_, _avlo, ттер_,
   {{0x4427bb6b,0x61e26800,0xad9b0037,0x68220031}},	//   gon_, _sool, riúi, hôdz,
   {{0x66e63840,0xad9b00e3,0x660bbb6c,0x61e201cc}},	//   _това, siúi, bigk, _pool,
   {{0x25bf0498,0x30a633c2,0x248988b5,0x2007bb6d}},	//   _gaul_, аров, šama_, _amni_,
   {{0x4427bb6e,0xdfd00080,0x94a90867,0x61e200aa}},	//   bon_, كية_, _مطلق_, _vool,
   {{0x4427bb6f,0x20070063,0xb6050094,0x00000000}},	//   con_, _cmni_, _višň, --,
   {{0xdefa00c6,0x20190472,0x61e252a1,0x3fc8110a}},	//   тып_, ésia_, _tool, ندگی_,
   {{0x10a60392,0x28c90c38,0xf99f05aa,0x443eb294}},	//   _видн, रिमि, _amèn_, _hht_,
   {{0x443ebb70,0x442caf0a,0x00d70470,0x00000000}},	//   _kht_, _kkd_, _نبوت_, --,
   {{0x998900a5,0x26fc0081,0x442c00c4,0xdb1e1c45}},	//   znań_, _এখনো_, _jkd_, _kapè,
   {{0x7ac41bec,0x200c3fd4,0x443e181f,0xaae8004d}},	//   осте, midi_, _mht_, аєте_,
   {{0x4427bb71,0x443e7cf1,0x7bda2490,0x5d850037}},	//   zon_, _lht_, ötur, _الظل,
   {{0x4427bb72,0x6e2d0193,0xa3b60034,0xb4b500c3}},	// [e510] yon_, _ikab, ज़ा_, _जने_,
   {{0xb767313c,0xb8ff030b,0x38698785,0x28c900aa}},	//   ртай, _थप_, rpar_, रिबि,
   {{0x4427bb73,0x660b02e2,0xa3d0007a,0x25bfbb74}},	//   von_, tigk, षाई_, _paul_,
   {{0x200c068d,0x38690572,0x2d99bb75,0x443e627e}},	//   hidi_, ppar_, ngse_, _aht_,
   {{0xd49b0a29,0x9f436f08,0x443e03ab,0x442c1df6}},	//   тре_, ójú_, _bht_, _bkd_,
   {{0x200c010a,0x660b01bf,0x68ed041c,0x25fb19af}},	//   jidi_, sigk, myad, लोजी_,
   {{0x68ed5c3f,0x443e01af,0x6e2d2ea3,0x64436284}},	//   lyad, _dht_, _okab, rmni,
   {{0x4427bb76,0x68ed008a,0xef1f026a,0x40952549}},	//   son_, oyad, şük_, брот,
   {{0x68edbb77,0x6609bb78,0x442793c0,0x200c8fc6}},	//   nyad, _imek, pon_, fidi_,
   {{0x753b00e9,0x6e2d4681,0x4427008a,0x200c4296}},	//   _izuz, _akab, qon_, gidi_,
   {{0x68ed041c,0x28c90285,0x00000000,0x00000000}},	//   hyad, रिडि, --, --,
   {{0x7c3e01e5,0xc6920130,0xa1592f03,0xcfb70033}},	//   _shpr, האט_, _саду_, জাইন,
   {{0x66090129,0x661bbb79,0x200c7cde,0x61fb0973}},	//   _mmek, _mjuk, bidi_, mhul,
   {{0x200cbb7a,0x68ed4ebd,0x2d990db1,0x200700e7}},	//   cidi_, dyad, agse_, _umni_,
   {{0x6e951f42,0xa3a905cd,0x66090106,0x5e9500e3}},	//   _العا, ग्य_, _omek, _العط,
   {{0x66090134,0x753b0294,0x661bbb7b,0x68ed0188}},	//   _nmek, _ozuz, _njuk, fyad,
   {{0x81cc0081,0x753b0129,0x68ed008c,0xf99f02f1}},	// [e520] _রকম_, _nzuz, gyad, _imèl_,
   {{0x66090010,0x994700d3,0xdb1c2fb6,0x60db0072}},	//   _amek, спуб_, ldrí, ixum,
   {{0x61fb0e7a,0x5b5700c1,0x753bbb7c,0xd3784072}},	//   khul, _לייב_, _azuz, _reć_,
   {{0xdb1c4467,0x200c0010,0xd71900df,0x26cabb7d}},	//   ndrí, zidi_, _दशरथ_, _vrbo_,
   {{0x61fbb9f6,0x68ed008a,0x661b3360,0xd37800cb}},	//   dhul, cyad, _djuk, _peć_,
   {{0x6609712f,0x29000010,0x443e00a7,0x69c4bb7e}},	//   _emek, mzia_, _qht_, ldie,
   {{0xd37802e6,0x200c0465,0x60cb009c,0x7e64bb7f}},	//   _već_, vidi_, _argm, _čipo,
   {{0x61fbbb80,0x69c4bb81,0x200cbb82,0xda7b006e}},	//   ghul, ndie, widi_, אנקר,
   {{0x2900bb83,0x78a40451,0x442c00e7,0x406237dc}},	//   nzia_, ntiv, _tkd_, _bọọl,
   {{0x6e2d01c5,0x28c9121d,0x6d568120,0x6ee60076}},	//   _skab, रिति, _agya, مسجل,
   {{0x5f3802ec,0x200cbb84,0x78a40673,0xdd9133c6}},	//   рпня_, ridi_, htiv, وود_,
   {{0x61fbbb85,0x68ed0044,0x60c404e9,0xd73700ca}},	//   chul, yyad, _šimu, מטית_,
   {{0x69c403e5,0x2d991715,0x200cbb86,0xa2c00acc}},	//   ddie, rgse_, pidi_, विक्,
   {{0x6d5618cb,0x40620294,0x69c401d3,0xf99f0154}},	//   _egya, _gọọl, edie, _emèl_,
   {{0xec340a8d,0xcfa900cd,0x6e2d003d,0x69c4000b}},	//   їнсь, _خانم_, _tkab, fdie,
   {{0x6e2d674b,0xf1b900d9,0x69c44a2b,0xf1bd11c6}},	//   _ukab, toši_, gdie, ्ययन,
   {{0x7c97006f,0x998900c4,0x00000000,0x00000000}},	// [e530] _اشعا, glaš_, --, --,
   {{0x661b0572,0xa8a41ad1,0x1da5102d,0x69c402b1}},	//   _sjuk, ярск, ग्रत, adie,
   {{0x2900bb87,0x76b901b6,0x68ed5c5e,0x255e0134}},	//   azia_, рлер_, syad, _ịla_,
   {{0xd24600bf,0x9999013f,0xe7f50096,0x680f00c6}},	//   _زن_, _visų_, _इतका_, _sėdė,
   {{0x78a4bb88,0xd126048f,0x68ed0188,0x039500e8}},	//   ctiv, _آم_, qyad, žīmā_,
   {{0x2489bb89,0x60cd1ea1,0xdb1e00cd,0xf8bf026e}},	//   šamo_, _šamo, _sapé, _isé_,
   {{0x61fb0060,0xdb1e0161,0xa2c00285,0x56940077}},	//   thul, _papé, विग्, _нарт,
   {{0x66090051,0xa5f81ad1,0x6eff0032,0x60db0062}},	//   _umek, _лесу_, _lábé, txum,
   {{0x2019016d,0x00000000,0x00000000,0x00000000}},	//   ésio_, --, --, --,
   {{0x61fb2020,0x60090277,0x69c40220,0x657bbb8a}},	//   shul, рном_, zdie, _heuh,
   {{0x623536e6,0x61fb0201,0x60c40138,0xe4480037}},	//   _дежу, phul, _šimt, _اللى_,
   {{0x9f4500b6,0xf8bf014b,0x645b2279,0x628327cd}},	//   chlý_, _osé_, _kuui, msno,
   {{0xc0e509b9,0x62837377,0xe9df033c,0x00000000}},	//   _фолк, lsno, _liús_, --,
   {{0x645b0131,0xda660076,0x69c4bb8b,0x00000000}},	//   _muui, قاري, wdie, --,
   {{0x60c9bb8c,0xf8bf24e0,0x1ea800d1,0x6441030a}},	//   lvem, _asé_, _هايي_, _mhli,
   {{0x78a4bb8d,0x6d560068,0x290002a7,0xbcfb00e3}},	//   ttiv, _ugya, tzia_, scéa,
   {{0x98a31839,0x69c4bb8e,0x64415cd6,0xf1b222fe}},	// [e540] мите, rdie, _ohli, וסן_,
   {{0x69c4bb8f,0x25ad55e3,0x29000181,0x9cb3001c}},	//   sdie, _abel_, rzia_, _کمیت,
   {{0xbcfbbb90,0x569300d6,0x69c42e97,0xdb0e042c}},	//   ncén, даєт, pdie, ndbü,
   {{0x645b8cae,0xad9b0037,0x62830381,0x26de00ee}},	//   _buui, liúr, dsno, _àtom_,
   {{0x6441003b,0xa3b6000f,0x21f80103,0x65620052}},	//   _bhli, ज़ल_, _néha_, rcoh,
   {{0x326610f7,0x65620477,0x64419d80,0x201900fd}},	//   отив, scoh, _chli, ésil_,
   {{0xfc3f0fb6,0xa2bd2cb6,0x2bcb030b,0x644109f7}},	//   ntía_, _वैद्, ायता, _dhli,
   {{0xd37802e6,0x6441166b,0x7cf10032,0x00000000}},	//   _moći_, _ehli, _jórú, --,
   {{0x41a616f8,0xef1801d3,0x64a60b21,0xf1b901d3}},	//   क्षस, daļa_, _фаза, jošu_,
   {{0xb4d60f53,0x765c8d91,0xdb0e01cd,0x6441151d}},	//   िमी_, _kury, ndbó, _ghli,
   {{0xd37803ce,0x2bde052c,0x765c2548,0xfbde02c6}},	//   _noći_, माना, _jury, मानम,
   {{0x765c5720,0x64410031,0x63b8bb91,0xf1a60ed5}},	//   _mury, _zhli, levn, क्शन,
   {{0x6298bb92,0x5c74067f,0x00000000,0x00000000}},	//   luvo, млят, --, --,
   {{0x63b8bb93,0xdb150103,0xc04f097a,0x625500bd}},	//   nevn, lezé, _іі_, _iġor,
   {{0xc1ee05d4,0x3950013c,0x629834fb,0xa2c00861}},	//   _जवाब_, ənsə_, nuvo, विट्,
   {{0xd37802e6,0x91fc01d3,0x00000000,0x00000000}},	//   _doći_, _stāj, --, --,
   {{0xb0bc02d5,0x2e32003e,0x625500bd,0x80cd0ff9}},	// [e550] ्टिग, gáfu_, _jġor, तिये,
   {{0x765c023f,0x63b8bb94,0xf770006f,0xdb170092}},	//   _bury, jevn, نام_, _naxç,
   {{0xd6db0ba3,0xdb150068,0xf4020081,0x35b502d8}},	//   шта_, kezé, ৎকার_, збер,
   {{0x64410a02,0xdb150103,0x765c53ac,0x7bc54835}},	//   _shli, jezé, _dury, _hahu,
   {{0x7bc5048c,0x9f4c0037,0x6830042c,0xf8bf13c6}},	//   _kahu, ghdú_, tädt, _usé_,
   {{0x7bc70103,0x62831f6d,0x7bc500aa,0x3959080e}},	//   ndju, tsno, _jahu, _hgss_,
   {{0x7bc52a6f,0x0587007e,0x765c008a,0x28c919af}},	//   _mahu, _муам, _gury, रिवि,
   {{0x4095a2bc,0xdb1cbb95,0x7bc5bb96,0xa2c01f88}},	//   прот, ndrá, _lahu, विज्,
   {{0x628304de,0xfbcb42d4,0x60090120,0x00000000}},	//   ssno, ायाम, йним_, --,
   {{0x7bc5620e,0xaf05013d,0x60c994a6,0x6441bb97}},	//   _nahu, зпол, rvem, _uhli,
   {{0xed5a4487,0x60c90234,0x7bc72222,0x00000000}},	//   йон_, svem, ddju, --,
   {{0xd1310080,0xf1b901d3,0x7bd7063d,0x00000000}},	//   _كما_, tošu_, _anxu, --,
   {{0x7bc5023f,0xf1b90128,0x00000000,0x00000000}},	//   _bahu, meš_, --, --,
   {{0x9f47023b,0xcb67002d,0xf1b93a5c,0x8fa20a95}},	//   _jonë_, заре_, leš_, _заше,
   {{0x7bc5bb98,0x34b81d7d,0x0f7a00a1,0x6b9c0167}},	//   _dahu, _इन्द, _הרצל, rgrg,
   {{0x09e34241,0x786625a7,0x63b80b18,0xfc3f0610}},	//   носн, зказ, zevn, rtía_,
   {{0x2d82bb99,0x765c12b7,0xfc3f04d8,0xa3bd2171}},	// [e560] make_, _sury, stía_, ेया_,
   {{0x2d820dcf,0xfc3f00e3,0x7bc5b6e9,0x9ce70018}},	//   lake_, ltín_, _gahu, _روپے_,
   {{0x41bd02e8,0xf1bd244d,0xdb1e0c56,0x7e64705a}},	//   ्यास, ्यान, _enpò, _čipk,
   {{0xfc3fbb9a,0x7bc5acdc,0xa3a92231,0x28c93542}},	//   ntín_, _zahu, ग्स_, रिशि,
   {{0x7bc5740f,0x63b80579,0xf1b9472a,0x3e6100de}},	//   _yahu, tevn, deš_, _lót_,
   {{0x629808a1,0x69c6bb9b,0x2d823673,0x765c00a5}},	//   tuvo, _hake, hake_, _tury,
   {{0x2d820979,0x69c6bb9c,0x63b8030b,0xdb1501f9}},	//   kake_, _kake, revn, tezé,
   {{0x69c6bb9d,0xdb1e0038,0x64a61824,0x63b8bb9e}},	//   _jake, _napí, _наба, sevn,
   {{0x69c60bcc,0x2d82bb9f,0x7c2e93ae,0x63b80094}},	//   _make, dake_, kobr, pevn,
   {{0xe9df0019,0x2ef40b0a,0xf99f0113,0xdb1c02c6}},	//   _khúc_, дзор, _emèh_, zdrá,
   {{0xdd950109,0x7bc5007a,0x69c612ba,0xf1b993ae}},	//   маны, _rahu, _oake, beš_,
   {{0xdb1e0428,0x7bc59cbc,0xf1b90244,0x442ebba0}},	//   _capí, _sahu, ceš_, lof_,
   {{0x7bc5bba1,0x7c2e0072,0xdb0e6cab,0xdb1c003e}},	//   _pahu, fobr, nebæ, ndræ,
   {{0x7c2e04a3,0x60c2bba2,0x9980013f,0xf1da0971}},	//   gobr, _isom, klių_, भावन,
   {{0x69c6bba3,0x2d82bba4,0x1ddd0557,0x7bc7bba5}},	//   _bake, bake_, यादत, rdju,
   {{0x69c60533,0x2486bba6,0x442e01f4,0x7bc530ff}},	//   _cake, ksom_, hof_, _wahu,
   {{0x7bc52129,0xd378005f,0x7c2ebba7,0xbd450c5e}},	// [e570] _tahu, _hoću_, bobr, _تنظي,
   {{0xd6db0aad,0xdb1e035d,0x60c22822,0x9f4702f1}},	//   йте_, _zapí, _msom, _bonè_,
   {{0x69c6bba8,0xe9df0019,0xa7fb334c,0x3e610023}},	//   _fake, _chúc_, _nuñe, _xót_,
   {{0xe9df0028,0x9f47023b,0x95f902d5,0x69c62d3b}},	//   _giúp_, _sonë_, ्फेट_, _gake,
   {{0x64a5bba9,0xf1b90128,0x8cd00034,0x60c20bbd}},	//   фала, veš_, दियो, _nsom,
   {{0x69c60ab2,0x2d82bbaa,0x63ad0e94,0x09c50033}},	//   _zake, zake_, đano, _একটা,
   {{0xea000028,0xddcd00a5,0x60c24458,0xd3780039}},	//   _hoạt_, _miał, _asom, _noću_,
   {{0x7c2e1206,0x3e61bbab,0x3f9e00e8,0x62880381}},	//   zobr, _rót_, egtu_, _dvdo,
   {{0x3494105c,0x9f4700dd,0xf1b902dd,0x60c20018}},	//   _патр, _tonë_, reš_, _csom,
   {{0x2d82068d,0xdb1e0161,0xbcfb0072,0x3e61868e}},	//   wake_, _japã, rcél, _pót_,
   {{0x2d82bbac,0xdb1e7631,0xea000019,0x7c2e0559}},	//   take_, _papí, _loạt_, vobr,
   {{0xa3a90a30,0x7c2e047c,0x3e61868e,0xdce40090}},	//   ग्र_, wobr, _vót_, _ufiċ,
   {{0x7c2ebbad,0x2d82bbae,0x69c60302,0x522a0130}},	//   tobr, rake_, _rake, _ווײַ,
   {{0x69c6bbaf,0x2d82bbb0,0xfc3f2750,0xddcd00a5}},	//   _sake, sake_, stín_, _ciał,
   {{0x69c607e1,0x2d82bbb1,0xfaa3bbb2,0x2fc70124}},	//   _pake, pake_, каро, _iang_,
   {{0x7c2ebbb3,0xc8c90789,0x61ebbbb4,0xe8fa0a3a}},	//   sobr, रिंट, _jogl, олб_,
   {{0x61eb3371,0x2fc7072f,0x69c6bbb5,0x752403e5}},	// [e580] _mogl, _kang_, _vake, żizz,
   {{0x26d102e6,0xe9df0019,0x69c6bbb6,0xdb1e0131}},	//   _brzo_, _phúc_, _wake, _capã,
   {{0x2fc7bbb7,0x9980013f,0x69c6bbb8,0x4a46164d}},	//   _mang_, ulių_, _take, _онов,
   {{0x61eb0021,0x2fc71c04,0x2486286f,0x9f5e0052}},	//   _nogl, _lang_, tsom_, thtë_,
   {{0x442ea0c5,0x2d800006,0x998000c6,0xbcfb014b}},	//   tof_, _meie_, slių_, ycém,
   {{0x2fc7bbb9,0x24860572,0xe9df0019,0xdb0e02b6}},	//   _nang_, rsom_, _thúc_, rebæ,
   {{0x9f5e01e5,0x96633d7c,0x99890181,0x61ebbbba}},	//   shtë_, _аксе, slať_, _bogl,
   {{0x442ebbbb,0x61eb7db0,0x80b20081,0xf743235c}},	//   sof_, _cogl, জিস্, _ресо,
   {{0x2fc7bbbc,0x00000000,0x00000000,0x00000000}},	//   _bang_, --, --, --,
   {{0x2fc70023,0x44380076,0x00000000,0x00000000}},	//   _cang_, _ór_, --, --,
   {{0x61ebbbbd,0xdb0e0222,0x2fc7bbbe,0xa3bd10cf}},	//   _fogl, nebä, _dang_, ेयर_,
   {{0x72161574,0x61eb02ad,0x2fc70150,0x99890034}},	//   _غذائ, _gogl, _eang_, ział_,
   {{0x79840010,0x60c2bbbf,0x2fc75411,0x2bcb2b6e}},	//   daiw, _usom, _fang_, ायला,
   {{0x2fc740d5,0x00000000,0x00000000,0x00000000}},	//   _gang_, --, --, --,
   {{0x62a2025b,0xa3b0009d,0x66020201,0x61eb01fa}},	//   _útoč, ट्य_, khok, _yogl,
   {{0x2fc7bbc0,0x2d800090,0x20140034,0x2489bbc1}},	//   _zang_, _geie_, ścić_, šami_,
   {{0x2fc743b4,0xe9df0019,0x660295be,0xdcff00e8}},	// [e590] _yang_, _chúa_, dhok, āvēj,
   {{0xb907417e,0x3e5e0090,0x1ddd1024,0x201e003e}},	//   _मऊ_, _aċti_, यावत, nnti_,
   {{0xa3e220cd,0x201e0084,0x99890034,0xf4140033}},	//   धान_, inti_, riał_, াকার_,
   {{0x9989007f,0x224600fe,0x3dc901ee,0x00000000}},	//   siał_, _nhok_, _jaaw_, --,
   {{0x61eb0660,0x00000000,0x00000000,0x00000000}},	//   _rogl, --, --, --,
   {{0x61eb3a07,0x2246171d,0x7279007e,0x00000000}},	//   _sogl, _ahok_, псис_, --,
   {{0x6b7c0054,0xe2993c97,0x4255bbc2,0x659504a1}},	//   חרונ, чай_, нтит, _паву,
   {{0xdb1c0396,0x2fc7bbc3,0x201e1479,0x6602158f}},	//   ferê, _sang_, enti_, chok,
   {{0x61eb9d6f,0x2fc734e1,0xdb1e2b64,0xe3b0001c}},	//   _vogl, _pang_, _mapá, _چرم_,
   {{0xe3b00979,0x2d8000f3,0x00000000,0x00000000}},	//   _نرم_, _seie_, --, --,
   {{0x61ebbbc4,0x2fc7bbc5,0x2ca900dc,0x6da6001f}},	//   _togl, _vang_, _aqad_, нина,
   {{0x91fc00d9,0xdb1e025b,0x201e1974,0x630400cd}},	//   _stāv, _napá, anti_, _جومل,
   {{0x5184224a,0x2fc7bbc6,0xed35004b,0xdb0e5509}},	//   _руха, _tang_, вэрэ, ndbö,
   {{0x224d1016,0x2fc7009d,0x21f10094,0x3ced00aa}},	//   lmek_, _uang_, _váhu_, äeva_,
   {{0x2d80007a,0x3f8500b6,0xdce40090,0x9f5e00d4}},	//   _teie_, malu_, _ddiġ, nitý_,
   {{0x3f8506ee,0xe1f901b3,0x224d01e8,0xdb1c0216}},	//   lalu_, nkų_, nmek_, lerë,
   {{0x63ad02e6,0x224d0087,0xdb0501bf,0xdb170072}},	// [e5a0] đanj, imek_, _abhä, _xaxú,
   {{0x3f850542,0xfd47163d,0xdb1c0052,0x00000000}},	//   nalu_, _язык_, nerë, --,
   {{0x66024bdb,0xc0490023,0x224d0233,0xa96a01a0}},	//   thok, _sườn_, kmek_, _нина_,
   {{0xf5390038,0x9f5c05aa,0x3f85bbc7,0x14ca00c2}},	//   _byť_, _elvè_, halu_, зыки_,
   {{0x3f85bbc8,0x201e00c2,0xc95501b3,0x6e240350}},	//   kalu_, ynti_, _атры, _mjib,
   {{0x3f8500cc,0x660208c2,0xc0490019,0xdb1e0146}},	//   jalu_, shok, _vườn_, _zapá,
   {{0x3f85bbc9,0x9f47025b,0xf7430832,0x26de007e}},	//   dalu_, _plný_, _беро, _štof_,
   {{0xdb1cbbca,0xf99f0154,0x6e240113,0x68e426c4}},	//   terê, _elèf_, _njib, oxid,
   {{0xdfd0054f,0x80bc02e8,0xbddb0257,0xc8c933d9}},	//   لية_, ्टें, llèg, रिएट,
   {{0x6e24bbcb,0xa2e6124c,0x201e7702,0x3dc901c2}},	//   _ajib, _позд, unti_, _saaw_,
   {{0x6d44bbcc,0x2246001c,0x3a203cb9,0x00000000}},	//   _azia, _thok_, knip_, --,
   {{0x645abbcd,0xe9df0139,0x628a01df,0xa7fb01ff}},	//   _hiti, _ahún_, msfo, _muña,
   {{0x645abbce,0x3f85512b,0x6e24bbcf,0x6f0600fd}},	//   _kiti, balu_, _djib, _bébé,
   {{0x6d440d1b,0x6e240174,0x645a1a1e,0xbcfbbbd0}},	//   _dzia, _ejib, _jiti, ncéi,
   {{0x645abbd1,0x03d700ca,0xe9df0037,0x00000000}},	//   _miti, עולם_, _dhún_, --,
   {{0xa3b0007d,0x645abbd2,0x62989967,0x6e240216}},	//   ट्त_, _liti, irvo, _gjib,
   {{0xab87734e,0x08410032,0x645abbd3,0xb955008f}},	// [e5b0] _пунк, _adìẹ_, _oiti, тващ,
   {{0x6e3d06cd,0x63ad1100,0x628abbd4,0x9f5e034f}},	//   llsb, đank, ksfo, mitó_,
   {{0xa7fb0610,0x9f5e00e1,0x2bde0096,0x224dbbd5}},	//   _cuña, litó_, मारा, ymek_,
   {{0x7afa0400,0x645abbd6,0x628a17d2,0x644800c2}},	//   øtte, _aiti, dsfo, _ahdi,
   {{0x69dd1043,0x645a30ee,0x629801c0,0x644801b9}},	//   _inse, _biti, ervo, _bhdi,
   {{0x74150e5a,0xdb1cbbd7,0x3fcb0081,0x645abbd8}},	//   ضوعا, ferè, _লক্ষ, _citi,
   {{0x645a0484,0x78adbbd9,0x9f4d08bb,0x224d01e8}},	//   _diti, ltav, ünün_, tmek_,
   {{0x3f85bbda,0xe1f9013f,0x645a0037,0xe4e700d6}},	//   walu_, ukų_, _eiti, _пізн,
   {{0x224dbbdb,0x78adbbdc,0x645abbdd,0x3f85bbde}},	//   rmek_, ntav, _fiti, talu_,
   {{0x245500bf,0x645a02c9,0x765b0009,0x5fdb33dc}},	//   _شناس, _giti, _hiuy, बाइल,
   {{0x69ddbbdf,0x248d0939,0x78ad1d94,0x6d440018}},	//   _onse, _hvem_, htav, _szia,
   {{0x78ad24e5,0x645a21a9,0x3f8500aa,0xc3320341}},	//   ktav, _ziti, salu_, _דוב_,
   {{0x64480084,0x61e9bbe0,0x78ad023b,0xf65200c1}},	//   _yhdi, mjel, jtav, יצט_,
   {{0x69ddbbe1,0x61e9bbe2,0x3e5e00bd,0x63a30085}},	//   _anse, ljel, _aċtu_, ngnn,
   {{0x3a2001af,0x9f470146,0xa3e20096,0x47ca0033}},	//   tnip_, _koní_, धात_, রামী,
   {{0x61fb0e7a,0x61e94a02,0xba23434e,0x3eaa030b}},	//   nkul, njel, адск, žití_,
   {{0x9f5e0487,0x4425007e,0x753b31ab,0x1c46002d}},	// [e5c0] citó_, _ojl_, _nyuz, _иним,
   {{0x61e9bbe3,0x7649008a,0xa7fb0610,0xf99f0154}},	//   hjel, _ahey, _puña, _alèd_,
   {{0x61fb7c24,0x248d002d,0x645abbe4,0x61e900d6}},	//   kkul, _avem_, _riti, kjel,
   {{0x645a8c8c,0xa2d5099d,0xc1bd04f8,0x7e6d24b5}},	//   _siti, भिन्, ्योग, _čapl,
   {{0x61e9029b,0x645a14b1,0xe5a3a3a9,0x78ad0428}},	//   djel, _piti, ричи, ctav,
   {{0xdb1c4d6a,0x628a0407,0x7bce091f,0xdb1e0428}},	//   terè, tsfo, ndbu, _capç,
   {{0x645abbe5,0x66e31d5c,0xdb1c167e,0x61e9004d}},	//   _viti, _кора, feré, fjel,
   {{0x61e9bbe6,0x628a112f,0x61fbbbe7,0x645abbe8}},	//   gjel, rsfo, gkul, _witi,
   {{0x91fc00d9,0x673c023b,0x628a66bd,0xdb050383}},	//   _stās, _hyrj, ssfo, _echè,
   {{0x61fbbbe9,0x645a0371,0x2d9205aa,0x9f5e0314}},	//   akul, _uiti, _adye_, vitó_,
   {{0x61e92a07,0xfc3f0e4b,0x248d05db,0x658702c3}},	//   bjel, stík_, _zvem_, _örhä,
   {{0x61e90dd9,0x645d028d,0x7bde0062,0xe9df0076}},	//   cjel, _èsic, _anpu, _chúl_,
   {{0xa3e60251,0x6e3d808e,0x6ef80139,0x78ad50d5}},	//   _बचा_, rlsb, _búbú, xtav,
   {{0xac2431d9,0x20050094,0xdfcf0037,0x00000000}},	//   афск, chli_, _وين_, --,
   {{0xdeef0ff8,0x9f5e2e40,0xdb1e0220,0x19950f5f}},	//   _ты_, sitó_, _napä, лавя,
   {{0x78ad0d64,0x63ad03ce,0x0f5700a1,0x63a80167}},	//   ttav, đani, _ביום_, _lcdn,
   {{0xc4c40068,0x57b50832,0xc9840d86,0x00000000}},	// [e5d0] _بے_, лбат, руси, --,
   {{0xb8cb0251,0x673c23ff,0x7649bbea,0x60040154}},	//   _गम_, _byrj, _shey, _fòme,
   {{0xcf930130,0xa3d60efd,0xf770048f,0x7c3515f2}},	//   שטע_, ियन_, تاق_, mozr,
   {{0x69dd02dc,0xa3b00176,0x78ad003e,0x8afa00ca}},	//   _unse, ट्स_, ptav, _נהרי,
   {{0xe9df0d79,0x61e9bbeb,0x588402e3,0xdb1c0103}},	//   _inú_, vjel, _выса, veré,
   {{0xdb05bbec,0x753b0094,0xee3f0094,0x80d6097c}},	//   _aché, _vyuz, hlý_, बिने,
   {{0xdb1c05e6,0x61e9bbed,0xad9b0037,0x61fbbbee}},	//   teré, tjel, thúl, tkul,
   {{0xf1da007d,0x61fb3c41,0xdb0e0072,0x7ae81489}},	//   भागन, ukul, tebú, ädti,
   {{0x61e9bbef,0x205517b9,0x28c9022d,0x9f5e0036}},	//   rjel, лтор, रिटि, vitò_,
   {{0x61fbbbf0,0xdb055f86,0x248900d9,0xa7fb8a14}},	//   skul, _tchè, šams_, _muño,
   {{0x61e90ea3,0x7c350031,0x00000000,0x00000000}},	//   pjel, dozr, --, --,
   {{0x2005bbf1,0xcf49026a,0x02fa006e,0xfbc90327}},	//   shli_, _ışık_, _אלעמ, _מת_,
   {{0xa7fb037a,0xdb0e0430,0x3e68014b,0xed570120}},	//   _nuño, lebø, _eût_, лою_,
   {{0x409200e3,0x7bce034f,0x3e68020d,0x7516006e}},	//   _الور, udbu, _fût_, אַלע_,
   {{0xab275999,0x9987015c,0x9f5e028d,0x7bcebbf2}},	//   гора_, _šiša_, pitò_, rdbu,
   {{0x316dbbf3,0xf3f10065,0x00000000,0x00000000}},	//   ncez_, _lọ_, --, --,
   {{0xa3d6218b,0x673c00c2,0x48e3008f,0xdb152c85}},	// [e5e0] ियम_, _syrj, ботв, rezá,
   {{0x3a39bbf4,0xe9df0139,0x5aca146c,0xdb0e00f3}},	//   _eksp_, _enú_, _злом_, kebø,
   {{0xdb150143,0x00000000,0x00000000,0x00000000}},	//   pezá, --, --, --,
   {{0xc9760241,0x94aa21fd,0x09e6386f,0x1f36006e}},	//   _حادث, етка_, _сомн, ארער_,
   {{0x4e3700c1,0x9f470139,0x00000000,0x00000000}},	//   אָגן_, _lonà_, --, --,
   {{0xdb0553b9,0x9f4e0154,0x79861cab,0x00000000}},	//   _sché, _fofè_, _hekw, --,
   {{0xd25a0318,0x798600dc,0x1daa0096,0xdb0e0430}},	//   нци_, _kekw, _काढत, gebø,
   {{0x79866859,0xa7850018,0x66190034,0x98a7007f}},	//   _jekw, _مشہو, ciwk, łną_,
   {{0x79860129,0x60cd007e,0x6281030a,0x00000000}},	//   _mekw, _šamr, _ewlo, --,
   {{0x79860294,0x25a60270,0x9f450094,0x67db00e8}},	//   _lekw, lgol_, sklý_, _gājē,
   {{0x6d40026a,0xdb05014b,0xd36f0286,0xf83700d7}},	//   üman, _tché, _رهن_, רנית_,
   {{0xa3b02014,0x25a6bbf5,0x9f4700ee,0x63a401c2}},	//   ट्र_, ngol_, _donà_, ɗina,
   {{0xbddb00ee,0x7c350206,0x00000000,0x00000000}},	//   elèc, tozr, --, --,
   {{0xee3f0094,0x5eaf0033,0x00000000,0x00000000}},	//   slý_, টিজে, --, --,
   {{0x3ffb0130,0xfc3f838a,0x7986bbf6,0xee3f0094}},	//   _אפגע, ktív_, _bekw, plý_,
   {{0xa7fb00e1,0x13cd0033,0xa2d5030b,0x49750450}},	//   _puño, লায়, भित्, рлас,
   {{0x481555ce,0x2d8bbbf7,0xd7e00096,0x7986bbf8}},	// [e5f0] амас, mace_, नांच, _dekw,
   {{0x64460138,0x2d8bbbf9,0xb8dd1926,0x370722f6}},	//   _ūkin, lace_, _आह_, лчев,
   {{0xf7700602,0x9f4742d2,0x26150206,0xea00020b}},	//   سال_, _koná_, sťom_, _loẹt_,
   {{0x8f370341,0x79861044,0xe51600bc,0xbbc55c65}},	//   נטאג_, _gekw, _देहि_, _लघुक,
   {{0x26d8bbfa,0xa2bd0f62,0x63858561,0xb5c20120}},	//   _erro_, _वैज्, агла, ійшл,
   {{0x69cf8e1b,0xa3b00ccb,0xe2992223,0xddd900bd}},	//   _hace, ट्ल_, вак_, _avvż,
   {{0x2d8bbbfb,0x69cfbbfc,0x38af0511,0x26c50036}},	//   kace_, _kace, lür_, _èlo_,
   {{0x69cf9c08,0xe5161203,0xc24500f6,0xdb0e00f2}},	//   _jace, _देवि_, јник, rebø,
   {{0xade40789,0x38af0491,0x3ebc0154,0x2d8bbbfd}},	//   गासन_, nür_, _apvt_, dace_,
   {{0x41a70789,0x69cf30e1,0xf0760103,0x6ff50036}},	//   _गावस, _lace, جیوں_, рчих,
   {{0xa3e20b42,0xdced009e,0x38af173c,0x00000000}},	//   धार_, _ffaċ, hür_, --,
   {{0x69cfbbfe,0x2d8bbbff,0x248000ae,0x38af071d}},	//   _nace, gace_, ţime_, kür_,
   {{0x79860078,0xef1801d3,0x8c461da9,0xa3e90d7e}},	//   _rekw, daļu_, иеме, याप_,
   {{0x38af008e,0x7986bc00,0x69cf0124,0xef67008f}},	//   dür_, _sekw, _aace, _съдо,
   {{0x69cfbc01,0x78bd129d,0x49730129,0x25a600f0}},	//   _bace, _apsv, _ụtụ_, ygol_,
   {{0x38af36be,0x69262155,0x69cfbc02,0x2d8bbc03}},	//   für_, амба, _cace, cace_,
   {{0xe8f74c3e,0xdb1c9be2,0x69cf0044,0x18a6246d}},	// [e600] алт_, merí, _dace, разм,
   {{0xdb1c11ce,0x60040c56,0x69cf0090,0x3f87830e}},	//   lerí, _kòma, _eace, _jenu_,
   {{0xa3e91757,0x69cf857b,0x05665565,0xa3a9030b}},	//   यान_, _face, авен, ग्छ_,
   {{0x3f87bc04,0xdb1c04d8,0x98a62ba7,0x69cfbc05}},	//   _lenu_, nerí, _киме, _gace,
   {{0x25a600ee,0x8cd908d4,0x53e64c82,0x6e2601f9}},	//   rgol_, मियो, ицка, inkb,
   {{0x69c4bc06,0x2d8b030b,0x25a60150,0x69cf191d}},	//   leie, zace_, sgol_, _zace,
   {{0x442004a3,0x3f98003e,0xdb1c0161,0xbcfb8dce}},	//   đi_, órum_, lerâ, ncér,
   {{0xdb1c1ea5,0x69cf03be,0xe5a311d9,0x69c4bc07}},	//   jerí, _xace, _миси, neie,
   {{0xdb1c2d18,0x2d8bbc08,0x3f87bc09,0x546a022a}},	//   derí, vace_, _benu_, _разм_,
   {{0xdefa0fdf,0x6abe00d6,0x2d8b006d,0x250b001c}},	//   вым_, _oppf, wace_, _شرقی_,
   {{0x2d8b00b6,0xdb1c22a4,0x78a43744,0x3f87bc0a}},	//   tace_, ferí, huiv, _denu_,
   {{0x78a40329,0xf1a9001c,0xfe7800c6,0x38af028e}},	//   kuiv, _ماهه_, rpį_, yür_,
   {{0x61e273d5,0x2d8bbc0b,0x614301c9,0x3f87bc0c}},	//   _inol, race_, _деца, _fenu_,
   {{0x69cfbc0d,0xa3e91677,0x2d8bbc0e,0x600406a3}},	//   _sace, याय_, sace_, _fòma,
   {{0x69cfbc0f,0x2d8b3e37,0x6e940080,0xa3ae143d}},	//   _pace, pace_, _البا, _कान_,
   {{0x3f8c8246,0xdb1c04d8,0x3f87bc10,0x38af6227}},	//   ladu_, cerí, _zenu_, tür_,
   {{0xa3d65c52,0xa3e91492,0x3f871b24,0x478b0423}},	// [e610] िया_, याम_, _yenu_, всем_,
   {{0x38af07aa,0x3f8c7b26,0x69cfbc11,0x00000000}},	//   rür_, nadu_, _wace, --,
   {{0xb5fd015c,0xf1b92cea,0xe71900e3,0x69c43d39}},	//   _liše, liše_, ديات_, beie,
   {{0xb7c600d9,0xd6d8bc12,0x3f8c6950,0x78a40036}},	//   _apģē, шту_, hadu_, buiv,
   {{0x81d500c7,0xf1b92cea,0xdb170072,0xfc3f0072}},	//   _সকল_, niše_, _taxó, btít_,
   {{0x5f0900b7,0x798d82ad,0x320600b3,0xf8bf0113}},	//   ानम्_, laaw, _aloy_, _ipé_,
   {{0x56941cfe,0xdb1c0a43,0xe2a81f11,0x3f8c008c}},	//   _март, yerí, لاين_, dadu_,
   {{0x00850459,0x163408d1,0xdb0e6c94,0x798d82ad}},	//   блио, _деся, ékér, naaw,
   {{0xfc3f8428,0x03c70084,0x83fc007e,0xdb1c406b}},	//   ntís_, _всем, _siđe, verí,
   {{0xa3ae0454,0x63ad03ce,0xf1b900cc,0x61e2bc13}},	//   _काय_, đans, diše_, _enol,
   {{0xdb1c0fb6,0x3f8700fd,0x798d6901,0x44f90033}},	//   terí, _venu_, kaaw, _অধিক_,
   {{0x6443bc14,0x83fc0039,0x32551165,0x3f87bc15}},	//   llni, _viđe, _увер, _wenu_,
   {{0xa3ae2f8f,0x44270091,0x3f870257,0xdb1c0610}},	//   _काम_, onn_, _tenu_, rerí,
   {{0x2d9e165f,0xdb1cbc16,0x69c40313,0x3f8cbc17}},	//   şte_, serí, weie, cadu_,
   {{0x44273470,0x09e6455b,0xdb1cbc18,0x69c4bc19}},	//   inn_, бовн, derã, teie,
   {{0xc332004f,0x3ea5bc1a,0x798d6aa7,0x896666d2}},	//   פון_, mult_, gaaw, скаж,
   {{0x69c4adfa,0xc04400de,0xf1b900e7,0x60c90027}},	// [e620] reie, _đoạt_, ciše_, nwem,
   {{0x25ad00d3,0x69c48260,0x78a40036,0x00000000}},	//   _acel_, seie, ruiv, --,
   {{0x3ea50006,0x6abe1d10,0x7afc023b,0xb8ef0296}},	//   nult_, _uppf, qyrt, _वै_,
   {{0xad9b00e3,0xdb1c05fe,0x60c98450,0x3f8c0146}},	//   thúi, merà, kwem, zadu_,
   {{0x78a40ba0,0x91a60139,0xb87b0065,0xdb1c6e38}},	//   quiv, _ako̟_, _aríf, berã,
   {{0x3ea5bc1b,0xaca40174,0xdb1c016d,0xe73abc1c}},	//   kult_, _adịw, cerã, _бег_,
   {{0xd25000bf,0x764238d9,0x3ea5bc1d,0x3f8cbc1e}},	//   ونت_, ploy, jult_, vadu_,
   {{0x44270fab,0x30a62820,0xa07423a3,0x6443bc1f}},	//   ann_, бров, огич, alni,
   {{0x60c90201,0x3f8c4e7f,0x00000000,0x00000000}},	//   gwem, tadu_, --, --,
   {{0xb5fd00e9,0xf1b902e6,0x224f0072,0xdb1cbc20}},	//   _više, više_, _ehgk_, ndró,
   {{0x50d603ed,0x28cf000c,0x443ebc21,0xdc190034}},	//   _گزار, _सैनि, _ikt_, _głęb,
   {{0xf1b9042d,0xa2d505d6,0x61e2bc22,0x442c0027}},	//   tiše_, भिर्, _unol, _hjd_,
   {{0xdddb2224,0x316601ff,0x3ea5014b,0x00000000}},	//   lptū, _igoz_, ault_, --,
   {{0xf1b903d6,0x443ebc23,0x7bd810d9,0x798d0283}},	//   riše_, _jkt_, _óvul, waaw,
   {{0xa3e90454,0x201e16a2,0x66026ff3,0xfc3f04d8}},	//   यात_, miti_, kkok, guía_,
   {{0x201ebc24,0x26df04a3,0xf99f0154,0xddc4007f}},	//   liti_, _čuo_, _elèn_, _chiń,
   {{0x443ebc25,0x44274c6d,0x798d399b,0x442c145c}},	// [e630] _okt_, ynn_, raaw, _ojd_,
   {{0xb76724c0,0x261b007a,0x798d0517,0xfc3f414c}},	//   стай, _मगही_, saaw, buía_,
   {{0xb87b2b75,0xfc3f0428,0x6e2d00e7,0x60c9bc26}},	//   _oríg, stís_, _kjab, zwem,
   {{0x7afabc27,0xa9c700bf,0x7bd59d58,0x442c0106}},	//   ätte, _ازدو, ldzu, _ajd_,
   {{0x201ebc28,0xd49b3f6c,0xe3654444,0xdb1c1f1d}},	//   kiti_, уре_, окли, merá,
   {{0x201e00cb,0xc7c7008f,0x7bd5a3d8,0xdb1c7043}},	//   jiti_, _усми, ndzu, lerá,
   {{0x442701b5,0x443ea065,0x660201c2,0xf1da0861}},	//   rnn_, _dkt_, bkok, _मोहन,
   {{0xdb1c128f,0x409524e9,0x1dd91fbb,0x6e2d00cd}},	//   nerá, орот, _बोलत, _njab,
   {{0x6609321e,0x201e0010,0x661bbc29,0x7bc70f1f}},	//   _ilek, fiti_, _imuk, keju,
   {{0x3ea5007a,0x6e2d7ed5,0x201ebc2a,0x68ed5b59}},	//   tult_, _ajab, giti_, ixad,
   {{0xa3d60971,0x1dd5009d,0xbddb45b0,0x3a29bc2b}},	//   ियर_, धयंत, rlèn, knap_,
   {{0xed5a0114,0xc6920089,0xb87b0031,0x3ea556ef}},	//   ион_, ואט_, _kríd, rult_,
   {{0xdb1cbc2c,0x6609bc2d,0x3a291d1e,0x661b0b07}},	//   derá, _mlek, dnap_, _mmuk,
   {{0x201e08a9,0xdb1c05fe,0xbddb00fd,0x6602bc2e}},	//   citi_, terà, llèl, zkok,
   {{0x66090006,0xdd9200fb,0x8c431525,0x661b0a15}},	//   _olek, _ہوں_, фере, _omuk,
   {{0x660900ac,0x3a290103,0xdb1c97a9,0x00000000}},	//   _nlek, gnap_, gerá, --,
   {{0x2bb20782,0xa7fb0143,0xfc3f002b,0x00000000}},	// [e640] _जापा, _zuñi, muín_, --,
   {{0x661b0ab9,0x39420138,0x7f8c006e,0x7e64007b}},	//   _amuk, _vyks_, ָנאַ, _hiip,
   {{0x06ca3153,0xdb1c3850,0x6609503d,0xfc3f0610}},	//   ргей_, berá, _blek, quía_,
   {{0x201e0106,0xdb1c9be2,0x7c3c0a06,0x443e066a}},	//   ziti_, cerá, lorr, _skt_,
   {{0x66021114,0xb1240081,0x201ebc2f,0x8e570341}},	//   rkok, _পর্ব_, yiti_, קינג_,
   {{0x6004009c,0x661b6ecd,0x38b43341,0x7e6400ce}},	//   _còml, _emuk, mär_, _liip,
   {{0x38b40704,0x6609bc30,0x2bb25d46,0x78b6bc31}},	//   lär_, _flek, _जाना, ltyv,
   {{0x201e00cd,0x443e0085,0x7c3c0634,0x69d6bc32}},	//   witi_, _wkt_, horr, ndye,
   {{0x201e02e6,0x6d440d7d,0x7c3cbc33,0x2900bc34}},	//   titi_, _nyia, korr, nyia_,
   {{0xdb1c0871,0x2d820567,0x6e2d2088,0x27f80381}},	//   zerá, ebke_, _sjab, _jorn_,
   {{0x443cbc35,0x7c3cbc36,0x38b40212,0x2c6f1fbe}},	//   mov_, dorr, här_, _süd_,
   {{0xae160e72,0x443cbc37,0x200cbc38,0x78b6013f}},	//   दोलन_, lov_, shdi_, ktyv,
   {{0xdb1c0143,0x7bc70e22,0x7c3c4965,0xdced00bd}},	//   verá, teju, forr, _mdaħ,
   {{0x443cbc39,0x7c3c0a00,0x60c223c0,0xdb057174}},	//   nov_, gorr, _ipom, _achá,
   {{0x7bc7bc3a,0xa2a202d5,0xf1b90268,0xdb1c5374}},	//   reju, _गिफ्, liša_, terá,
   {{0x38b40222,0x7bc73c06,0x69d6019c,0xf1bc0be4}},	//   fär_, seju, gdye, ्जिन,
   {{0x443c6110,0x7c3cbc3b,0xf1b96ac8,0x3a290018}},	// [e650] kov_, borr, niša_, rnap_,
   {{0xd6db30cc,0x443c0038,0x661bbc3c,0x6609004d}},	//   ите_, jov_, _smuk, _slek,
   {{0xa3e94275,0x443cbc35,0x6609048d,0xa3ae046e}},	//   यास_, dov_, _plek, कलन_,
   {{0xd2462761,0x38b40222,0xe9df0019,0xb87bbc3d}},	//   _سن_, bär_, _chút_, _príd,
   {{0xd12600e3,0x27f8bc3e,0x443c7357,0x600d05e6}},	//   _أم_, _forn_, fov_, _húme,
   {{0xf1b9042d,0xb5fd033b,0x83fc00c4,0x63a401c2}},	//   diša_, _diša, _piđa, ɗink,
   {{0x60c2078e,0x6e3dbc3f,0xa3bc278e,0x66b43a8c}},	//   _apom, kosb, ेज़_, _обру,
   {{0x661b023f,0xa3e90378,0x83fc0106,0x7c3c3d7d}},	//   _umuk, याह_, _viđa, zorr,
   {{0x7e640084,0x443cbc40,0xd24e08ba,0x92ab0033}},	//   _riip, bov_, دني_, গবে_,
   {{0x443cbc41,0x6009032d,0x320d0188,0xad9b003e}},	//   cov_, сном_, shey_, khús,
   {{0x26150038,0x6d4410dd,0xee3a7e1f,0xdb1c0428}},	//   sťou_, _syia, йно_, merç,
   {{0xa3e904a9,0xbddb04ea,0xd12e0260,0x78b60084}},	//   याव_, blèm, ئمی_, ytyv,
   {{0x7c3cbc42,0x25bf0113,0x02d3007f,0x644100bd}},	//   torr, _mbul_, थिकभ, _kkli,
   {{0x61f9008a,0x600d0072,0x60db019f,0x63ad01c2}},	//   _howl, _búme, mvum, ɗanc,
   {{0x63bc01e8,0x09e600d6,0x61f901af,0xdb1c0740}},	//   _örne, повн, _kowl, _üzün,
   {{0x443cbc43,0x78b60084,0xfc3f0af3,0x6569bc44}},	//   zov_, ttyv, quín_, _ngeh,
   {{0x7c3cbc45,0xb95b0139,0x6441191d,0x61f95f99}},	// [e660] porr, _abìb, _okli, _mowl,
   {{0x443c006c,0x25bf1b63,0x61f9bc46,0x21f10146}},	//   xov_, _abul_, _lowl, _váhy_,
   {{0xe9df0028,0x443c4092,0x78b600c2,0x20050270}},	//   _phút_, vov_, styv, ikli_,
   {{0x2bca1a94,0xdb052351,0xb5fd0995,0xa2a20285}},	//   ाजवा, _uchá, _piša, _गिब्,
   {{0x443c199c,0xe5166100,0x798460b6,0xd4e300c2}},	//   tov_, _देखि_, mbiw, еющи,
   {{0xb5fd0995,0x25bf1a0d,0xf1b90d12,0xa7fb6722}},	//   _viša, _ebul_, viša_, _buñu,
   {{0x443cbc47,0x60c25be4,0x6458bc48,0x78a40313}},	//   rov_, _spom, rmvi, lriv,
   {{0x443cbc49,0x30a61bb8,0xb5fd0087,0xc1810018}},	//   sov_, пров, _hišn, پیوٹ,
   {{0x61f9025e,0x443c56a5,0xb5fd0106,0x9f4e842a}},	//   _dowl, pov_, _kišn, _sofà_,
   {{0x6e980058,0xdb1e0890,0xdcef01d3,0xc8b7006e}},	//   овор_, _japó, sacī, פּחה_,
   {{0xa3e91085,0x6f0102ad,0x61f9bc4a,0xdcf60092}},	//   यार_, gylc, _fowl, _peyğ,
   {{0x61f9003d,0x60040383,0x3f83003e,0x644100d2}},	//   _gowl, _kòmk, ðjur_, _zkli,
   {{0x6e3d0103,0x60c20be5,0xc05a00c6,0x00000000}},	//   rosb, _upom, _лік_, --,
   {{0x2bb2009d,0x78a4032e,0x2005026a,0x3ce000f3}},	//   _जाणा, driv, ckli_, _driv_,
   {{0x7ac4bc4b,0x897a0129,0x78a400bc,0x81cf0033}},	//   нсте, _ọgụg, eriv, শার_,
   {{0x7afa0149,0x3ce0a121,0xad9b003e,0x99800357}},	//   ätta, _friv_, rhús, tniš_,
   {{0x69340b26,0xd8790037,0xfc3f002b,0xad9b01cd}},	// [e670] енту, زمات_, quío_, shús,
   {{0xb87b0181,0xf77033c6,0xdb1e1de1,0x394701d3}},	//   _príb, هام_, _capó, āns_,
   {{0x2bb21e9f,0x6d4108bb,0xdb1c01bf,0x59f9013d}},	//   _जाता, şlad, gerä, _деня_,
   {{0x64410ced,0x78a4bc4c,0xb87b0037,0x60db0138}},	//   _skli, briv, _críc, yvum,
   {{0x78a4608c,0xa3ae0251,0x99f603c2,0x61f9bc4d}},	//   criv, _काश_, _חזרה_, _rowl,
   {{0xe9df0076,0xb4ad087c,0x466b15e9,0xdb1c0212}},	//   _thús_, _कमी_, _грам_, berä,
   {{0xa3ae0e4c,0x62630018,0x7bd7bc4e,0x425546ff}},	//   _कार_, _főol, _maxu, мтит,
   {{0xdb1c016d,0x00e5370d,0x6569063d,0xdb1ebc4f}},	//   serç, джин, _ugeh, _kapò,
   {{0x9f5e0080,0x81cf0081,0xdb1c014b,0x24f800ae}},	//   chtú_, শাল_, perç, _енты_,
   {{0xad9b01ab,0xdb1e03be,0xb5fd08c5,0x9f4e0a82}},	//   skúl, _xapó, _kišo, _sofá_,
   {{0x6da61407,0x60c40029,0x82870037,0xada60609}},	//   мина, _ģime, _رجال, манл,
   {{0x3f9c00e7,0xb8050033,0x63ad01c2,0x28e000a4}},	//   _edvu_, োচিত_, ɗana, निमि,
   {{0x7bd70634,0x6ff50037,0x2bb200aa,0xdb0e02c3}},	//   _baxu, _يستط, _जादा, nebö,
   {{0x290c00e8,0x00000000,0x00000000,0x00000000}},	//   _āda_, --, --, --,
   {{0x81b40081,0xbb4372b0,0x3f85bc50,0xa3ae00bc}},	//   _ছোট_, верк, mblu_, कलत_,
   {{0x78a40012,0xa3e90252,0xc33202f8,0x6aa18811}},	//   triv, याँ_, דול_, álfa,
   {{0xa3ae1362,0x6004009c,0x786604a1,0x78a409a1}},	// [e680] _काल_, _bòmh, дказ, uriv,
   {{0x60040013,0x07a32c37,0x7bd701ff,0x83fc0559}},	//   _còmh, каун, _gaxu, _riđo,
   {{0xb5fd2f54,0xf9860161,0xb87b0220,0x78a4286f}},	//   _višn, _огно, _príc, sriv,
   {{0x78a400e9,0x6004009c,0x64a6085f,0x68e9bc51}},	//   priv, _eòmh, дада, _šede,
   {{0xa3e93ad1,0x7bd70092,0xdb1eb5b5,0xf4cc0033}},	//   यां_, _yaxu, _tapó, লম্ব,
   {{0xfc3f0933,0xdb1c0084,0xa3ae0096,0x7c2e4893}},	//   oría_, perä, _काळ_, nnbr,
   {{0xb87bbc52,0x2bc01fb4,0x07a319e8,0xfbc01462}},	//   _tríc, श्या, _јасн, श्यम,
   {{0x3f8e0a39,0xfc3f1de1,0x7ae117d2,0x00000000}},	//   _sefu_, iría_, ålti, --,
   {{0xb5fd03ce,0xfa1c00fe,0x644600c6,0x00000000}},	//   _mišl, _đất_, _ūkiu, --,
   {{0xa3e950a4,0x60040154,0xf95700ca,0x2ef42b16}},	//   याः_, _kòmi, וספת_, езор,
   {{0xf8ab417a,0xad9b0031,0x63060452,0x00000000}},	//   _चम्प, skúm, _توال, --,
   {{0xfc3f14e2,0xb5fd0307,0xceb81c8a,0x7c2e18f0}},	//   dría_, _nišl, rtę_, enbr,
   {{0x7afa0222,0x11690260,0xfc3f0328,0xceb813ff}},	//   ättn, _علوی_, ería_, stę_,
   {{0xdb1e06a3,0xfc3f0328,0xce9400e5,0xa3ae00bc}},	//   _rapò, fría_, _закъ, कलि_,
   {{0x27ed0019,0xfc3f04d8,0x2019bc53,0x394d02ef}},	//   _đen_, gría_, ësie_, _šes_,
   {{0x7bd7008a,0xb5fd00e7,0xa3e509c3,0x3d3800ac}},	//   _waxu, _rišo, _बोन_, ọwa_,
   {{0xdb0502e2,0xa3ae0efd,0xfc3f0610,0x7bd75856}},	// [e690] _schä, कला_, aría_, _taxu,
   {{0xfc3f0890,0xb87b24c7,0xb5fd0128,0x8858062a}},	//   bría_, _cría, _pišo, диус_,
   {{0x23d908c0,0xdb1c02b9,0x600405fe,0x6b95bc54}},	//   _योगद, terå, _còmi, mazg,
   {{0x78a20618,0x62983a10,0xb5fd0995,0x600400b3}},	//   šova, dsvo, _višo, _dòmi,
   {{0x629abc55,0xe00e02e8,0x64a5615f,0xb87b305b}},	//   _avto, िसाद_, хала, _fría,
   {{0xdb1c0212,0x600402f1,0x6b950a06,0x6298bc56}},	//   rdrö, _fòmi, nazg, fsvo,
   {{0x442902e6,0xaad8030b,0x78ad00c2,0x629864a2}},	//   đa_, डिएक, luav, gsvo,
   {{0x200e23d4,0x69cdb4d1,0x644a5d61,0x00000000}},	//   _alfi_, neae, alfi, --,
   {{0x78adbc57,0x63ad0044,0x9f470037,0x657b0027}},	//   nuav, ɗann, _inné_, _ifuh,
   {{0xb5fd211b,0x764b626c,0x69cd09a1,0x00000000}},	//   _mišm, llgy, heae, --,
   {{0x47ca0033,0x99800031,0xf99f05aa,0x00000000}},	//   রাচী, lniť_, _odè_, --,
   {{0x248d4733,0xdca61e79,0x200e0036,0xa3b50096}},	//   _kwem_, нами, _elfi_, _झाड_,
   {{0x8fa59513,0x78ad358c,0x657b0027,0x00000000}},	//   _зале, juav, _mfuh, --,
   {{0xfc3f04d8,0x09a80096,0xb5fd015c,0x6b950103}},	//   tría_, गल्य, _sišl, gazg,
   {{0x48bf0081,0x7c2ebc58,0xb5fd00c4,0xca560291}},	//   উটোর, rnbr, _pišl, етањ,
   {{0xfc3f04d8,0x7c3602ef,0xdb1c014b,0x765800c6}},	//   rría_, _šarč, nfré, įvyk,
   {{0x98a316bd,0x656d0220,0x16c8102d,0xb5fd0218}},	// [e6a0] лите, ľahl, रब्ब, _višl,
   {{0x7d060084,0x657b0174,0x6e260009,0xf99f23c0}},	//   myks, _afuh, likb, _edè_,
   {{0x39ea6ab3,0xa3e90775,0xb4e80f38,0x7bce7e49}},	//   _едно_, याई_, यम्_, mebu,
   {{0x186a08d1,0x7bdc0a03,0x600400ee,0xb87b0139}},	//   _нами_, ldru, _vòmi, _irín,
   {{0x2d9296d9,0xdb150143,0xc8b60fe9,0xb87b5d30}},	//   _meye_, bezó, _ясны, _tría,
   {{0x7bdcbc59,0x6e260ab2,0x229a00d9,0x6298bc5a}},	//   ndru, hikb, tīk_, tsvo,
   {{0xe805009d,0x53340084,0xb5fd6404,0xae10007f}},	//   _शकता_, ъект, _mišj, ासान_,
   {{0x20bd0067,0xd2571736,0x7bcebc5b,0x629824a9}},	//   ्बंध, нцы_, hebu, rsvo,
   {{0x7bcebc5c,0x600d2b39,0xe3b212eb,0x63b7023b}},	//   kebu, _súma, _مرا_, çanë,
   {{0x61eb1b68,0x7642008a,0x00000000,0x00000000}},	//   _engl, looy, --, --,
   {{0x8f3422ee,0x91e61bb8,0xd36f0190,0x2d924a6c}},	//   тенц, _поже, _اهم_, _beye_,
   {{0x76420188,0x3eac02b6,0x7bdcbc5d,0xd6e20033}},	//   nooy, rudt_, edru, _যথায,
   {{0xb87bbc5e,0x2d92bc5f,0x7bdc5b8c,0xdb1c0031}},	//   _arín, _deye_, fdru, zdrô,
   {{0x7bcebc60,0x645d028d,0xa3d602d5,0x7642008c}},	//   gebu, _èsit, ियट_, hooy,
   {{0x8ff71e49,0x99800181,0x61eb0150,0xa3ae00c3}},	//   _سرور_, zniť_, _yngl, _काई_,
   {{0x79960112,0xfc3f0072,0x7642008c,0x78ad7472}},	//   gayw, crín_, jooy, tuav,
   {{0x97a71c17,0x9c39008f,0x7642008a,0x7bce156d}},	// [e6b0] ерел, _опит_, dooy, bebu,
   {{0xc02e0019,0x00000000,0x00000000,0x00000000}},	//   _điệu_, --, --, --,
   {{0x2d92068d,0x69cdbc61,0xcf9300c1,0x248d0313}},	//   _yeye_, peae, רטע_, _swem_,
   {{0xa64712eb,0x76420188,0xc8a9121d,0x99800031}},	//   رخان, gooy, _छटपट, tniť_,
   {{0x78ad028d,0xb5fd033b,0x386a0154,0x09d70033}},	//   quav, _hišk, _fibr_, হাদা,
   {{0x99800220,0x61eb0090,0x00000000,0x00000000}},	//   rniť_, _sngl, --, --,
   {{0x76420188,0x7bc50113,0x99800031,0x00000000}},	//   booy, _mbhu, sniť_, --,
   {{0xb5fdbc62,0xf99f0c56,0x7bce00a5,0x7c2711a6}},	//   _mišk, _elèv_, zebu, hijr,
   {{0xf99f022b,0x0ee902d5,0x2bb200a4,0x2721bc63}},	//   _flèv_, टम्स_, _जाला, _मधुर_,
   {{0xa2a90b61,0x7d0602e3,0xfc3f0143,0x15ef00c3}},	//   _टिप्, vyks, drío_, छावर_,
   {{0x4427bc64,0x64436df1,0x2d920c56,0xb5fd0307}},	//   min_, moni, _peye_, _nišk,
   {{0x64430372,0x7d0602fd,0x442700db,0x61ebbc65}},	//   loni, tyks, lin_, _ungl,
   {{0x64430006,0xed5702ec,0x442710f0,0x7bdc3b6c}},	//   ooni, кою_, oin_, tdru,
   {{0x4427bc66,0x6443bc67,0x8fa54e08,0xb87bbc68}},	//   nin_, noni, _раке, _prín,
   {{0x7bdc0b7c,0xb5fd02dd,0xae1f0b42,0x4427bc69}},	//   rdru, _višj, मोहन_, iin_,
   {{0x7bce03ec,0x6443bc6a,0xb87b00e3,0x7bdc357f}},	//   sebu, honi, _crío, sdru,
   {{0x44277a28,0x64434312,0x6e241f6e,0x87ba007b}},	// [e6c0] kin_, koni, _imib, дует_,
   {{0x64432751,0x4427bc6b,0x6d560063,0xb87b0037}},	//   joni, jin_, _izya, _trín,
   {{0x7642008a,0xb87b5bef,0xa3d516e2,0xe9df0065}},	//   tooy, _frío, िजन_, _ikún_,
   {{0x225f061d,0x6ea4072d,0x44270076,0xf743036a}},	//   jmuk_, _किसु, ein_, шехо,
   {{0x4427bc6c,0x76420188,0xcd77006e,0xa3ae007a}},	//   fin_, rooy, דענק_, कलल_,
   {{0xe1f9013f,0xc448001c,0x9d1b0327,0x2a6000bc}},	//   ejų_, ریان_, וונט, lmib_,
   {{0xd25a0ac6,0x224d0167,0x92b30037,0xdb1c0ac9}},	//   мци_, flek_, لحيا, gerø,
   {{0x4427006b,0x7642008a,0x26d80167,0xa2b300b6}},	//   ain_, qooy, _isro_, _इमर्,
   {{0x4427bc6d,0xdfd0054f,0x6443bc6e,0xe3ba0277}},	//   bin_, مية_, boni, _оба_,
   {{0x44272bc2,0x224dbc6f,0x212bbc70,0x6e240103}},	//   cin_, alek_, úcha_, _amib,
   {{0x645a01e8,0x201900dd,0x224dbc71,0xb95b0139}},	//   _ihti, ësia_, blek_, _abìl,
   {{0xd378031a,0x9f5c00b3,0x600400b3,0xa3bca1b3}},	//   _daće_, _jové_, _ròmu, ेजक_,
   {{0x660004eb,0xf1b300a1,0xd01a8561,0x00000000}},	//   _momk, _כסף_, _офк_, --,
   {{0xb5fd2782,0x9f582c0e,0x6e24019b,0xfc3f03be}},	//   _pišk, óró_, _emib, rrío_,
   {{0xdb230b88,0xb87b0080,0xd3780106,0x9f47037a}},	//   _ürün, _prío, _gaće_, _donó_,
   {{0x9f5c0871,0x5a34a2bc,0x6443bc72,0xb5fd00cb}},	//   _nové_, анст, zoni, _višk,
   {{0x4427bc73,0x2d99bc74,0x9f470032,0x995552be}},	// [e6d0] yin_, mase_, _fonó_, укац,
   {{0x4427bc75,0x6d4dbc76,0xf99f05aa,0x224d7dd4}},	//   xin_, _iyaa, _alèt_, zlek_,
   {{0x4427bc77,0x2a60023e,0x2d9900ae,0x6b680103}},	//   vin_, bmib_, oase_, _végü,
   {{0x6443bc78,0x44272ce8,0x2af2030b,0x6d4d083e}},	//   woni, win_, ीहरु_, _kyaa,
   {{0x2bc006ae,0x44270bb0,0x628102ef,0xd49b3e28}},	//   श्वा, tin_, _stlo, фре_,
   {{0x2d99bc79,0x4427374c,0x6d4d06b0,0xdb1c004d}},	//   hase_, uin_, _myaa, terø,
   {{0x44270652,0x69ddbc7a,0x6443bc7b,0x6d4d0361}},	//   rin_, _kase, roni, _lyaa,
   {{0x4427202b,0x645abc7c,0xe0d91a57,0xda13030b}},	//   sin_, _ehti, еви_, ठसित_,
   {{0x69ddbc7d,0x44271641,0x224dbc7e,0x6d4d2b27}},	//   _mase, pin_, rlek_, _nyaa,
   {{0x69ddbc7f,0x44273dd9,0x224dbc80,0xf0760018}},	//   _lase, qin_, slek_, دیوں_,
   {{0x6d4d0694,0x765b0028,0x224d90e4,0x2019013f}},	//   _ayaa, _khuy, plek_, ėsi_,
   {{0x69dd6d48,0x6d411f8a,0x7c250080,0xb87b0181}},	//   _nase, ğlan, _amhr, _príl,
   {{0x6d4107d1,0xa0a50138,0x10a5078b,0x645a00c2}},	//   şlan, _салд, _силн, _yhti,
   {{0x44255070,0x6d4d00f9,0xb87b0487,0x29090124}},	//   _jml_, _dyaa, _crím, dyaa_,
   {{0x69ddbc81,0x2fc700f9,0x6d4d0361,0x61fb0a4b}},	//   _base, _ibng_, _eyaa, ojul,
   {{0xceb20054,0x61fbbc82,0x7e6dbc83,0xa3e502d5}},	//   _היה_, njul, _giap, _बोस_,
   {{0x6d4d0361,0x57ea0219,0x69dd6d63,0xb87b01cd}},	// [e6e0] _gyaa, ндам_, _dase, _frím,
   {{0x61fb743f,0x7649a3c2,0x67160109,0x9d1b0266}},	//   hjul, _akey, льеф, _נויט,
   {{0x2c6f03e5,0x55e63574,0x2ca0052f,0x7bde09a4}},	//   _iżda_, ложб, _hvid_, _iapu,
   {{0x765b011b,0x69ddbc84,0x7bdebc85,0x2bc01e05}},	//   _chuy, _gase, _hapu, श्रा,
   {{0x7bdea85a,0xa426333f,0x80d3009f,0x69c401cb}},	//   _kapu, лькл, _बैले, mfie,
   {{0x69ddbc86,0x2d9908a8,0xf7465f3b,0xfc3f0042}},	//   _zase, zase_, _бего, buíu_,
   {{0x7bdebc87,0x68e40f31,0x0cb16bbd,0x69dd4513}},	//   _mapu, lvid, _जम्म, _yase,
   {{0x2d99a322,0x7bdebc88,0x69c4bc89,0x4425bc8a}},	//   xase_, _lapu, nfie, _eml_,
   {{0x68e44772,0x13b600cd,0x7e6d00e5,0xb87b0139}},	//   nvid, _مصاح, _riap, _aríj,
   {{0x7e6d2c09,0xa3ae000f,0xd0730037,0xa3dc0096}},	//   _siap, _काट_, حديث, _तोच_,
   {{0x2d99bc8b,0x630633ce,0x6d4d061d,0x68e43c28}},	//   tase_, _حوال, _syaa, hvid,
   {{0x90e6212c,0xb5fd011d,0x7bde0270,0x320d4af3}},	//   _مستن, _piši, _aapu, ckey_,
   {{0x2d99bc8c,0xa3e902e8,0x69ddbc8d,0xb87b673a}},	//   rase_, याच_, _rase, _prím,
   {{0x68e4bc8e,0x7bde2910,0xb5fd02dd,0x2d99002b}},	//   dvid, _capu, _viši, sase_,
   {{0x3a292c09,0x2d99bc8f,0x7bde005a,0x6016001f}},	//   tiap_, pase_, _dapu, _câme,
   {{0x59df1592,0xb5fd07c0,0x69ddbc90,0x5c755cb1}},	//   _पोखर, _tiši, _qase, _клит,
   {{0x69dd5eb9,0x290f8cb2,0x37ab0832,0xb95b0065}},	// [e6f0] _vase, ága_, етен_, _ibìk,
   {{0xf1b92e48,0x69dd9c10,0x3a29005c,0x7bde001c}},	//   riši_, _wase, siap_, _gapu,
   {{0x69ddbc91,0x76b9002d,0xa3ae00aa,0xd6d10421}},	//   _tase, тлер_, _काज_, تقا_,
   {{0x3ce90501,0xf1b92a1e,0xd6d80109,0x7bde0660}},	//   _krav_, piši_, ыту_, _zapu,
   {{0x798d3d7a,0x442502e5,0x2ed106ec,0x7bde5f59}},	//   mbaw, _pml_, _तन्त, _yapu,
   {{0x3ce900cc,0xb5fd33db,0x78ad023b,0x23296e54}},	//   _mrav_, _nišv, mrav, коли_,
   {{0x765b0019,0x78adbc92,0xf10d00b7,0x00000000}},	//   _thuy, lrav, िन्द_, --,
   {{0x020522de,0x212b0161,0x44250090,0x78ad0036}},	//   рзин, úcho_, _wml_, orav,
   {{0x3ce9023e,0x61fbbc93,0x442500e8,0x320d1dbd}},	//   _nrav_, rjul, _tml_, rkey_,
   {{0xb87b0181,0x60090277,0x44251d91,0x22400206}},	//   _príj, тном_, _uml_, čika_,
   {{0x7bde0d67,0x69c4bc94,0x26c1bc95,0x68e4033b}},	//   _rapu, yfie, ntho_, zvid,
   {{0x60160161,0x78ad351f,0x3ce9bc96,0xfc3f0206}},	//   _câmb, krav, _brav_, brík_,
   {{0x7bdebc97,0x68e40257,0x3eac0629,0x6016020a}},	//   _papu, xvid, ardt_, _dâmb,
   {{0x78ad21b8,0x92d70081,0xa13600c1,0xd3780d62}},	//   drav, ামী_, _דאנק_, _kaća_,
   {{0xeb970f99,0x7bdebc98,0x6996013d,0xe9df016d}},	//   рис_, _vapu, ирах, _baú_,
   {{0xdb1c0220,0x798dbc99,0x7bde0a4b,0xb95b0139}},	//   cerý, gbaw, _wapu, _gbìk,
   {{0x69c4bc9a,0x3ce9bc9b,0x7bdea039,0x2ca004a3}},	// [e700] rfie, _grav_, _tapu, _uvid_,
   {{0x68e413a5,0x07a62341,0xa3e51362,0x60160f21}},	//   rvid, ражн, _बोल_, _zâmb,
   {{0x6b9cbc9c,0x78ad028d,0x69c4bc9d,0x5976022a}},	//   marg, arav, pfie, _выгу,
   {{0x1a9b006e,0x6b9cbc9e,0x38710095,0xba9b00ca}},	//   _ביטע, larg, _žorž_, _בסטי,
   {{0xf1b901ac,0x78ad137f,0x59df0d75,0x5d7b006e}},	//   nišu_, crav, _पोटर, דאנק,
   {{0x66e60465,0xdb1c0018,0x02a6069c,0x6b9cbc9f}},	//   _кога, kerü, арим, narg,
   {{0x28ac0557,0xc7a31ff9,0xe7c60096,0x59ba007f}},	//   _चिडि, _фиск, र्णप, इलपर,
   {{0x6b9c113a,0xc48630cc,0xe643625b,0xdb1c0103}},	//   harg, _влак, _десп, derü,
   {{0x6b9c159b,0x00000000,0x00000000,0x00000000}},	//   karg, --, --, --,
   {{0x6016002d,0x60041f27,0x238902c6,0xf1b9007e}},	//   _sâmb, _còmp, čují_, dišu_,
   {{0x08570054,0x6d4108bb,0xb87b0220,0x6b9cbca0}},	//   שבים_, ğlam, _prík, darg,
   {{0x3ce90b27,0x6d4108bb,0xa3ae009f,0xf1b90a39}},	//   _prav_, şlam, कलक_, fišu_,
   {{0x6b9cbca1,0x628a01cb,0x998900d2,0x00000000}},	//   farg, lpfo, chař_, --,
   {{0x6b9cbca2,0x26c100f0,0x798d0124,0x09af0096}},	//   garg, ytho_, wbaw, टल्य,
   {{0xda78001d,0xbebc0029,0xdb1cacf1,0x00000000}},	//   ият_, dzīg, deró, --,
   {{0x78adbca3,0x3ce91d21,0x9dab008f,0xf1b9007e}},	//   trav, _trav_, _ръка_, bišu_,
   {{0x6b9c597b,0x798d3edf,0x32d80023,0x9f4701cd}},	// [e710] barg, rbaw, _lũy_, _inná_,
   {{0x6b9c1946,0xb5fd0146,0xdd9100cd,0x78adbca4}},	//   carg, _lišt, _بوک_, rrav,
   {{0x8ae402ec,0xfc3f08a8,0xdc3c00ca,0x7bd5bca5}},	//   _діял, buír_, _בעזר, mezu,
   {{0xb5fd02e6,0x26c10154,0x9f5c0094,0x00000000}},	//   _ništ, rtho_, _noví_, --,
   {{0x26c10113,0xdb1c0143,0xd37800c4,0x7afa02c3}},	//   stho_, beró, _saća_, ättv,
   {{0xb87b0072,0x87e7007b,0x925900d1,0x00000000}},	//   _asíg, _тюме, گشتر_, --,
   {{0x9f5c00ee,0x20190216,0x00000000,0x00000000}},	//   _boví_, ësim_, --, --,
   {{0xb5fd015c,0x7bd5019f,0xcb3800ca,0xfba70d7e}},	//   _pišu, hezu, ינוק_, कृतम,
   {{0x600d2a96,0x7a33003d,0x7bc702ef,0xe7ab02d5}},	//   _húmi, għti, kfju, _चयाप,
   {{0x43940fe3,0xaffe00de,0x04590037,0xf1b9bca6}},	//   _маус, _phướ, _صلاة_, višu_,
   {{0x2eb608e7,0x59a7009d,0x6b9cbca7,0x5f450037}},	//   _अमृत, गणार, varg, إنجل,
   {{0x6b9c00cd,0xe9df00de,0xdb0501dc,0xf1b90a39}},	//   warg, _thúy_, _idhè, tišu_,
   {{0x308500e3,0x6b9cbca8,0xafe500ba,0x8fa5001c}},	//   _التف, targ, _голл, _همشه,
   {{0xaffe0019,0xf1b90b18,0xab2a0ffa,0x1c39007b}},	//   _thướ, rišu_, гога_, аясь_,
   {{0xfc3f03be,0x6b9cbca9,0xe456006e,0x2ef802db}},	//   tuír_, rarg, מישט_, ärft_,
   {{0x6b9c2c2e,0xf1b91197,0xb87b023c,0xdb0500d8}},	//   sarg, pišu_, _osíd, _uchý,
   {{0x1b200081,0x6b9cbcaa,0xdb1cbcab,0xfc3f0042}},	// [e720] _মুখে_, parg, teró, ruír_,
   {{0x3cfb040a,0xfc3f0042,0xb90000c3,0x00000000}},	//   _עלינ, suír_, _दन_, --,
   {{0x387900e7,0x205600c1,0xdb0500d1,0x7c2e0ac1}},	//   _eusr_, ציעל_, _ndhè, mibr,
   {{0x7c2ebcac,0xe5a308d9,0xceb20130,0x05663617}},	//   libr, зици, ליב_, бвен,
   {{0x69d601e8,0xdb05014b,0xad9b00b3,0xdb1c007f}},	//   meye, _adhè, ljúc, peró,
   {{0x69d601e8,0xb95b0065,0xb87b0065,0x044313fc}},	//   leye, _abìw, _aríw, печн,
   {{0x81e10033,0x8cda007f,0x00000000,0x00000000}},	//   দান_, _पैसो, --, --,
   {{0x69d6bcad,0x00000000,0x00000000,0x00000000}},	//   neye, --, --, --,
   {{0xdb0502e2,0xb5fd0138,0x7c2e0167,0x99800138}},	//   _schü, _višt, kibr, lnių_,
   {{0xa20803e0,0x3f989aba,0x628a059a,0xf507002d}},	//   ılış_, úru_, ppfo, _унул_,
   {{0x6016001f,0x644abcae,0xdb1c003e,0xb5fd00d2}},	//   _câma, mofi, lfræ, _tišt,
   {{0x442ebcaf,0x63a80167,0xe2a93a89,0xdb05009c}},	//   lif_, _hddn, _ضامن_, _ochò,
   {{0x7bd5bcb0,0xdb050113,0x69d6041c,0x00000000}},	//   tezu, _idhé, deye, --,
   {{0xdb0500dd,0x9f5e00dd,0x4e9300cd,0x442ebcb1}},	//   _udhë, njtë_, _کشور, nif_,
   {{0x3f9ebcb2,0xdb070120,0xb5fd00c6,0x99890206}},	//   matu_, ngjø, _mišr, hnať_,
   {{0x3f9e02a7,0x644a25aa,0x7bd50201,0x600d01cd}},	//   latu_, hofi, sezu, _rúmi,
   {{0x61e2a62b,0x644abcb3,0x779917e9,0x00000000}},	// [e730] _maol, kofi, икар_, --,
   {{0x3f9ebcb4,0x61e2bcb5,0x99890220,0x20c2003e}},	//   natu_, _laol, dnať_, iði_,
   {{0x7ac726d0,0x442ebcb6,0x69d6bcb7,0xaa592863}},	//   _успе, dif_, beye, _вину_,
   {{0x3f9e1a10,0xdebb0341,0x6aa10088,0x63a803e3}},	//   hatu_, רמאל, álfu, _addn,
   {{0x3f9e02a7,0xcc340068,0x644a006d,0x789312eb}},	//   katu_, _ذریع, fofi, _ریاض,
   {{0xd7fb00c9,0xdb050257,0x644a00f0,0x442e2ad7}},	//   _сум_, _adhé, gofi, gif_,
   {{0x61e2bcb8,0xdc380130,0x3f9e02a7,0x28dd397e}},	//   _baol, זאגט_, datu_, _नैति,
   {{0x20c20102,0x61e2151d,0x80a96cb6,0x7c2e007e}},	//   fði_, _caol, авив_, zibr,
   {{0x20c20102,0x644abcb9,0xe7c6063c,0x61e2009c}},	//   gði_, bofi, र्वप, _daol,
   {{0xbebc0029,0x3f9e61da,0x764b03c3,0x644a343b}},	//   dzīb, gatu_, logy, cofi,
   {{0x61e20503,0xee3a3a7a,0x02d90688,0x69d6bcba}},	//   _faol, ино_, _خواب_, yeye,
   {{0x92b40260,0x61e20037,0x69c90f35,0x320601ee}},	//   _رحما, _gaol, _हॉली, _gooy_,
   {{0x8fa5ba49,0x3f9ebcbb,0x41c202d5,0x7c2e014b}},	//   _дале, batu_, _वॉटस, tibr,
   {{0xdb1c0088,0x3f9ebcbc,0x3f6911db,0x998000c6}},	//   ferð, catu_, _кило_, ynių_,
   {{0xdb1c0102,0xcb6a50fd,0x69d601e8,0x99890031}},	//   gerð, раве_, teye, znať_,
   {{0x20070a00,0xe9da1d2e,0x3a2b009c,0x2d9b039f}},	//   _honi_, јка_, _cmcp_, _geqe_,
   {{0x2007bcbd,0xd91009b4,0xe8fa371f,0x69d6bcbe}},	// [e740] _koni_, ریس_, шла_, reye,
   {{0x99890181,0x3b832917,0x7afa0212,0x69d6bcbf}},	//   vnať_, _ольг, ätts, seye,
   {{0x764b5b95,0x200700c2,0x69d602f1,0x25bf009c}},	//   fogy, _moni_, peye, _bcul_,
   {{0x2007bcc0,0x3f9e5b11,0x76a00065,0x442e0063}},	//   _loni_, zatu_, _aáyá, wif_,
   {{0x92e60081,0x91a60139,0x9980013f,0x64a312d1}},	//   _পথে_, _ajo̟_, snių_, дача,
   {{0xdb1c0088,0xb87b0220,0x61e21fc0,0x3f9e01c8}},	//   rfræ, _prív, _saol, xatu_,
   {{0x644abcc1,0x61e2bcc2,0xff470190,0xdb1c003e}},	//   rofi, _paol, _آخ_, sfræ,
   {{0x30a60217,0x9f5c18ed,0x3f9ebcc3,0xdd140031}},	//   оров, _nová_, watu_, pĺňa,
   {{0x3f9ebcc4,0x644a0051,0xd3440504,0xd0100076}},	//   tatu_, pofi, _کفای, فلة_,
   {{0x20c20682,0x20186cc8,0x20076e02,0xaaab0378}},	//   rði_, óri_, _coni_, _छिलक,
   {{0x3f9e7848,0x61e200bc,0x2007bcc5,0xddc40090}},	//   ratu_, _taol, _doni_, _funż,
   {{0x3f9ebcc6,0xdb1c0088,0x7c3e0079,0x20070154}},	//   satu_, verð, _ajpr, _eoni_,
   {{0x3f9e2762,0x91360018,0x9ccb00c6,0x442c0537}},	//   patu_, _براؤ, шына_, _kmd_,
   {{0x224908a9,0x68fb05fe,0xdfcf0037,0x63ad0d2a}},	//   čake_, _àudi, _ليه_, ɗans,
   {{0x442c0f20,0x799f0b08,0x5fb700a1,0x764b2f91}},	//   _mmd_, taqw, _והוא_, yogy,
   {{0x200708c5,0x7bda00fd,0x442c0565,0x7bc800bc}},	//   _zoni_, ôtur, _lmd_, õdur,
   {{0x7afa0149,0x442c0154,0x20070113,0x443e0167}},	// [e750] ättr, _omd_, _yoni_, _ojt_,
   {{0x6aa10102,0x478b061b,0x79860154,0xb8d300a8}},	//   álfs, рсам_, _efkw, _टि_,
   {{0xb87b00b3,0x81e10033,0x3a2b020b,0x00000000}},	//   _arít, দাত_, _tmcp_, --,
   {{0x3f9c8c9b,0xb87b0139,0x27e301c2,0x6fca02d5}},	//   _levu_, _brít, _wajn_, त्तू,
   {{0x443e63ac,0x201e0188,0xb5fd0234,0x6016020a}},	//   _bjt_, khti_, _dišp, _râmn,
   {{0x799d07ac,0x942506c4,0x764b030a,0x442cbcc7}},	//   _hesw, ямле, sogy, _cmd_,
   {{0x659501b3,0x442c5b60,0x6e2d063d,0x61c60285}},	//   _наву, _dmd_, _omab, लभूष,
   {{0x2007bcc8,0xb87b003e,0x660203a9,0x25bf00d1}},	//   _soni_, _frít, cjok, _ucul_,
   {{0xb87b0065,0x661bbcc9,0x090d0033,0x00000000}},	//   _irís, _iluk, _সেতু_, --,
   {{0x6e2d2775,0x799d26a1,0x660901a2,0x661b62d7}},	//   _amab, _lesw, _hoek, _hluk,
   {{0x661b7e55,0x66095846,0x59cb13ae,0xc7b2006e}},	//   _kluk, _koek, ाभार, עבט_,
   {{0x82370018,0x2a69023e,0x66093d35,0x799d58da}},	//   _برطا, jmab_, _joek, _nesw,
   {{0x317a00f5,0xa3df009d,0x600d0131,0x661b89e3}},	//   _האנד, _तसा_, _súmu, _mluk,
   {{0x201e28f6,0x6609bcca,0x6e2d5784,0x44dd0154}},	//   chti_, _loek, _emab, _mň_,
   {{0x661bbccb,0x6b6316bd,0xdce603a3,0xa3cd81ec}},	//   _oluk, екра, rakı, ष्य_,
   {{0x3ce0022e,0x78a4bccc,0x661b0172,0x224d01c8}},	//   _tsiv_, tsiv, _nluk, noek_,
   {{0x799d01bf,0xa9675894,0xfbd10033,0xfc3f1d90}},	// [e760] _desw, зита_, ায়ত, grís_,
   {{0xa3cd0336,0x6d56006d,0x224d7999,0x600dbccd}},	//   ष्म_, _iyya, hoek_, _túmu,
   {{0x66090db8,0x224d2552,0x442c01dc,0xb87b7e4a}},	//   _boek, koek_, _rmd_, _brís,
   {{0xb87bbcce,0x44dd0383,0x799d0313,0xf99f022b}},	//   _prít, _bň_, _gesw, _joèl_,
   {{0x01c30081,0xd90d0d83,0x224dbccf,0x66091030}},	//   ্যাদ, _پیل_, doek_, _doek,
   {{0x661b007a,0x3fe60081,0x78a2035d,0x2bc01178}},	//   _eluk, _পক্ষ, šovs, श्चा,
   {{0x661bbcd0,0xb87b01cd,0x29000042,0x3f9c4226}},	//   _fluk, _frís, lxia_, _revu_,
   {{0xdb1c76c1,0x44dd0383,0x8cad007f,0x224d01c8}},	//   berö, _fň_, _जिलो, goek_,
   {{0xdfd0054f,0x76430068,0x0ef42b8a,0x3a2000f9}},	//   نية_, énye, इम्स_, ihip_,
   {{0x660926f1,0x251b00f5,0xe0cf08ba,0x6b9e084e}},	//   _zoek, _הומא, ازي_, _nepg,
   {{0x224d6461,0x6d560d2a,0x7e760124,0xa3e5277c}},	//   boek_, _ayya, _biyp, _बोट_,
   {{0xa3cd5516,0xf27b0054,0x201e023b,0x321f3cc8}},	//   ष्ठ_, _הראש, shti_, chuy_,
   {{0x63bc0212,0x7e6401dc,0xfc3f0610,0x799d0178}},	//   _örns, _dhip, esía_, _resw,
   {{0x9a871778,0x7e641281,0x6b9e0169,0x799d0154}},	//   зуал, _ehip, _cepg, _sesw,
   {{0xdb1cbcd1,0xb4a90dba,0x00000000,0x00000000}},	//   ngrè, _खट्_, --, --,
   {{0x6e2dbcd2,0x7f3b006e,0x0f5700d7,0x600d0503}},	//   _umab, _לעוו, _מיום_, _fúms,
   {{0xb95b0065,0x66090a88,0x2c6402c3,0xa3e54e2e}},	// [e770] _abìr, _roek, född_, _बोझ_,
   {{0x224d0ab2,0x6609bcd3,0x661b0407,0x2f220032}},	//   zoek_, _soek, _sluk, _gégé_,
   {{0xb87b2ba9,0x2ca908dc,0x6e3dbcd4,0x661b7fb8}},	//   _prís, _hvad_, onsb, _pluk,
   {{0x3a20bcd5,0x6e3d0c09,0x80d30033,0x224d0062}},	//   chip_, nnsb, তিত্, xoek_,
   {{0x629a9e0d,0xdb1c0149,0xe8eb0037,0x49740392}},	//   _awto, rfrå, _ارجو_, _плюс,
   {{0x76430103,0xe3b80092,0x69cd0150,0xdb1c05e8}},	//   ényb, _alıb_, lfae, sfrå,
   {{0x66090934,0x248f0063,0xb95b0032,0x321f00fe}},	//   _toek, spgm_, _gbìr, thuy_,
   {{0x601f0257,0xf99f0383,0x6e3d01cb,0x201c007b}},	//   _même, _alèz_, jnsb, _alvi_,
   {{0x224dbcd6,0x68200149,0xf99f23c0,0x25adbcd7}},	//   roek_, _född, _blèz_, _idel_,
   {{0x443101d4,0x6e3d22d4,0x224dbcd8,0xc87f01bf}},	//   _öz_, ensb, soek_, _muß_,
   {{0x63a3bcd9,0xa3cd034d,0x1f6500d6,0xa29400d6}},	//   mann, ष्ण_, ьком, _захі,
   {{0xd12e0de1,0xf99f0154,0xb0d800c3,0x201cbcda}},	//   امی_, _elèz_, _बैकग, _elvi_,
   {{0x61e9bcdb,0x63a30036,0x00000000,0x00000000}},	//   mdel, oann, --, --,
   {{0x61e902fe,0xddcd00d3,0x60c9bcdc,0x6e3d02ac}},	//   ldel, _piaţ, mtem, ansb,
   {{0x60c9bcdd,0x69cd41ac,0x63a302e7,0x248d0124}},	//   ltem, ffae, iann, _ltem_,
   {{0xddcd002d,0x6d4401bb,0xdb1c6ab6,0x290001e9}},	//   _viaţ, _txia, ngré, txia_,
   {{0x63a30e95,0x61e9bcde,0x6b6700fd,0x6ea10096}},	// [e780] kann, idel, tégé, _कौतु,
   {{0x60c9bcdf,0xb87b0181,0x63a3bce0,0x61e90084}},	//   item, _prír, jann, hdel,
   {{0x63a3bce1,0xdb0502dc,0x765902ad,0x6d41026a}},	//   dann, _schö, flwy, şlat,
   {{0x61e9bce2,0x6b670018,0x60c906a3,0x7bdc9afc}},	//   jdel, ségé, ktem, leru,
   {{0x61e96396,0x63a3bce3,0xfc3f0037,0xe5a300d3}},	//   ddel, fann, isín_, тичи,
   {{0x7bdc7652,0x61e90a2c,0xb4de007a,0x60c9bce4}},	//   neru, edel, _तनी_, dtem,
   {{0x61e9ad4b,0x59e20ff9,0x7bdc00ae,0x321d03a8}},	//   fdel, _पसार, ieru, _blwy_,
   {{0x7bdcbce5,0x63a3134a,0xd257055b,0xdb250103}},	//   heru, aann, мцы_, ésér,
   {{0x63a3bce6,0x30140423,0x60c95fb9,0x6e3d0c89}},	//   bann, едпр, gtem, vnsb,
   {{0x224900e9,0x63a3bce7,0x7bdcbce8,0x6820bce9}},	//   čaka_, cann, jeru, _föde,
   {{0x7bdcbcea,0x741300d0,0x80bd00c7,0x68edbceb}},	//   deru, _جولا, ্টগ্, zvad,
   {{0xd37802e6,0x2005023e,0x68ed0a7f,0x6abcbcec}},	//   _naći_, ajli_, yvad, durf,
   {{0x60c9025a,0xb87b3a4c,0x6e3d0596,0x38780cc2}},	//   ctem, _asín, rnsb, _oirr_,
   {{0x201900dd,0x6abc00f0,0x09a70096,0x00000000}},	//   ësit_, furf, गण्य, --,
   {{0x81e10081,0xd5a40018,0xb4bb074c,0x02dc00c0}},	//   দার_, _پہ_, _अम्_, _मनोन,
   {{0x63a392fc,0x68ed1a4a,0x79960f5a,0x25a001cd}},	//   zann, tvad, gbyw, ðill_,
   {{0x7bdcbced,0xee3f0074,0x30bc00c7,0x7d000212}},	// [e790] beru, mný_, _অনুস, ämst,
   {{0xee3f0074,0x61e98867,0x7bdc4fbc,0x9c3800c2}},	//   lný_, zdel, ceru, _опыт_,
   {{0x61e9bcee,0x68edbcef,0x7bc50a4b,0x63a3bcf0}},	//   ydel, svad, _ichu, vann,
   {{0x7ae5074a,0xee3f0074,0x63a324ae,0x60c92012}},	//   _isht, nný_, wann, ytem,
   {{0x63a3ac75,0x68200222,0x24f9022a,0x61e9bcf1}},	//   tann, _söde, янды_, vdel,
   {{0x7ae50052,0x61e90231,0x02c51cf2,0x00000000}},	//   _ksht, wdel, ейко, --,
   {{0xee3f025b,0x7bc552cd,0x00000000,0x00000000}},	//   kný_, _mchu, --, --,
   {{0x63a3bcf2,0x60c9bcf3,0xee3f0579,0x7ae50051}},	//   sann, ttem, jný_, _msht,
   {{0xee3f0897,0x61e90337,0x7bc50146,0x248d00dc}},	//   dný_, rdel, _ochu, _utem_,
   {{0x60c9bcf4,0x7bc5bcf5,0x63a3026d,0x93bc00ae}},	//   rtem, _nchu, qann, _clăd,
   {{0x69d0007d,0x61e9bcf6,0xdb1c034f,0x00000000}},	//   ड्डी, pdel, sfrú, --,
   {{0xfbc90054,0x7bdc67bb,0x7bc5bcf7,0x63a149ee}},	//   _לת_, weru, _achu, _heln,
   {{0x9f47074a,0x7bdcbcf8,0x6281027f,0x63a1bcf9}},	//   _kanë_, teru, _hulo, _keln,
   {{0x9f47074a,0x6281a873,0x6abc2ca7,0x7bdc0364}},	//   _janë_, _kulo, turf, ueru,
   {{0xee3f18ed,0x7bdc65ee,0x7e562383,0x63a100d9}},	//   bný_, reru, _птиц, _meln,
   {{0xb87b0038,0x62810517,0xee3f0146,0x09e31969}},	//   _príp, _mulo, cný_, лосн,
   {{0x7ae5074a,0x39461c77,0x6d410390,0x6e3b00a1}},	// [e7a0] _esht, ços_, şlar, _מתקד,
   {{0x57e76d70,0x7bdc0052,0x00000000,0x00000000}},	//   ндум_, qeru, --, --,
   {{0x28ac022d,0x6281bcfa,0xa2c10285,0xc8ac0096}},	//   _चिकि, _nulo, रूम्, _चिकट,
   {{0x25a0054f,0x2a79061d,0xb87b1094,0x5ab700c1}},	//   úil_, _gisb_, _tríp, _אלטע_,
   {{0xb97b00a1,0xb6080146,0x69c607ee,0xf53900d8}},	//   _מרכז, _nešť, _icke, _peťa_,
   {{0x62812eec,0xee3f0146,0x63a1046e,0x3878009c}},	//   _bulo, zný_, _celn, _uirr_,
   {{0x2bd20d7e,0x6281bcfb,0x63a1bcfc,0xfbd20469}},	//   द्या, _culo, _deln, द्यम,
   {{0x62810bb6,0x63a1007a,0x60f8008f,0xc7af0018}},	//   _dulo, _eeln, дния_, _پڑے_,
   {{0xee3f18ed,0xc05a01b3,0x62818105,0x63a1bcfd}},	//   vný_, зін_, _eulo, _feln,
   {{0x628101c2,0x63a1bcfe,0x490800c3,0x9f4705aa}},	//   _fulo, _geln, _सपनो_, _kanè_,
   {{0xee3f0074,0xe29778ee,0x6281bcff,0xdd95004b}},	//   tný_, _зах_, _gulo, каны,
   {{0x7bc5bd00,0x00000000,0x00000000,0x00000000}},	//   _schu, --, --, --,
   {{0xee3f0618,0x60160161,0x62810634,0xdb15003e}},	//   rný_, _lâmi, _zulo, _íbúa,
   {{0xee3f025b,0x7a2300aa,0x69c61d79,0x9be41acf}},	//   sný_, _mõte, _acke, ліск,
   {{0xee3f025b,0x628100b3,0x22ac00b6,0x27ff0023}},	//   pný_, _xulo, něk_, _đun_,
   {{0x9b58004d,0x00000000,0x00000000,0x00000000}},	//   хист_, --, --, --,
   {{0x200ebd01,0x9f5c0181,0x26d8bd02,0x3ebe004d}},	// [e7b0] _kofi_, _novú_, _apro_, lutt_,
   {{0xb9090fef,0x7bc5068d,0x29071419,0x66191783}},	//   _मन_, _uchu, ćna_, wkwk,
   {{0xf3ff011b,0x7ae501e5,0x3ebe004d,0x9f470216}},	//   _đã_, _usht, nutt_, _ranë_,
   {{0x2b0e030b,0x62815639,0x200e2773,0x00000000}},	//   ठहरु_, _rulo, _lofi_, --,
   {{0x62816fcd,0x63a12c2e,0x1dd300a8,0x36050281}},	//   _sulo, _peln, ध्यत, _یوسف,
   {{0xe3b303ed,0x6281a9a0,0x29360130,0x27ea009c}},	//   ارش_, _pulo, _יארן_, _gabn_,
   {{0x81ea0f71,0x92e80037,0x63a12224,0x3ebe87c8}},	//   মান_, فريق_, _veln, jutt_,
   {{0x63a10381,0xdb1c13ea,0x62810216,0x00000000}},	//   _weln, rfrø, _vulo, --,
   {{0xe3b31574,0x9f47023b,0x200e0154,0x6b820294}},	//   _مرض_, _tanë_, _bofi_, ọgid,
   {{0x6281bd03,0x3e7b00e4,0x69df0216,0x200e018f}},	//   _tulo, _rūta_, heqe, _cofi_,
   {{0x62810270,0x263800e7,0x3ebe00f3,0x00000000}},	//   _uulo, mčor_, gutt_, --,
   {{0x9f4730ea,0x237400b1,0xd05f00a7,0x51870fe9}},	//   _jané_, _صالح, _əvəz, _чужа,
   {{0xd3780e94,0x9f470131,0x00000000,0x00000000}},	//   _daću_, _mané_, --, --,
   {{0x320f07d9,0x3ebe009e,0x61eb093e,0x9f470113}},	//   _hogy_, butt_, _hagl, _lané_,
   {{0xe80504dd,0xfe4600d3,0x61eb03a9,0xa1f9007e}},	//   राना_, _инко, _kagl, šćuš,
   {{0x61ebbd04,0x4a431b4b,0x9f4500d4,0x00000000}},	//   _jagl, ансв, ndlí_, --,
   {{0x61ebbd05,0x00000000,0x00000000,0x00000000}},	// [e7c0] _magl, --, --, --,
   {{0xe3b8008b,0x61eb0d90,0xbebc01d3,0x395c01d3}},	//   _alın_, _lagl, dzīj, āvs_,
   {{0x36890077,0x3d65010d,0x6fd30034,0x9f470113}},	//   есін_, _لطیف, ब्यू, _bané_,
   {{0x61eb0d1f,0x22ac030b,0x68200149,0xdb1c305b}},	//   _nagl, věk_, _döda, ngrí,
   {{0x9f470146,0x7a3b007b,0x00000000,0x00000000}},	//   _dané_, sätä, --, --,
   {{0xa7da0979,0x69c4bd06,0x93bc00ae,0x4aa9001c}},	//   _توسط_, lgie, _slăb, _تایپ_,
   {{0x02a3022a,0x61ebbd07,0x6234594b,0x2d80bd08}},	//   арым, _bagl, леку, _ogie_,
   {{0xe3b200cd,0x61ebbd09,0x78b10088,0x9f47037a}},	//   _چرا_, _cagl, _ákvæ, _gané_,
   {{0x61ebbd0a,0xad9b003e,0xe7cf0096,0x68e4bd0b}},	//   _dagl, sjúk, स्वप, nwid,
   {{0xa3ba0190,0xe8052fbd,0x69df0052,0x61eb4764}},	//   _زائر_, राया_, zeqe, _eagl,
   {{0x81d70f71,0x61eb4012,0x539b0327,0xa2c1397e}},	//   ায়_, _fagl, _חיבו, रूद्,
   {{0x61eb038f,0x200e03e3,0x68e4bd0c,0x93bc020a}},	//   _gagl, _wofi_, kwid, _flăc,
   {{0xdfd40077,0xe805030b,0x23c913ae,0x200e01c2}},	//   _болы, रामा_, _रामद, _tofi_,
   {{0x61e001e8,0xdfd00037,0x3ebe0364,0x68e47929}},	//   leml, _طيب_, putt_, dwid,
   {{0x2bd20557,0xfbd200b6,0x307b006e,0x60c0bd0d}},	//   द्धा, द्धम, _קאונ, lumm,
   {{0x69c4bd0e,0x61e0bd0f,0x00000000,0x00000000}},	//   ggie, neml, --, --,
   {{0x60c00f05,0xaa58002d,0x52bf0179,0x5887004b}},	// [e7d0] numm, титу_, _एम्स, тыба,
   {{0x2bd21388,0x7d5800ca,0x7d030139,0x00000000}},	//   द्दा, _ביחד_, _ẹrù, --,
   {{0x12bd0081,0x25ff009d,0xdce40090,0xdcef0342}},	//   _আন্দ, ळाली_, _ifiġ, macı,
   {{0x60c0bd10,0x69df0201,0x61e0033b,0x28ac2337}},	//   kumm, qeqe, jeml, _चिचि,
   {{0xe8df00ef,0xa8a400c9,0x60c0bd11,0x61eb0150}},	//   _thực_, _врск, jumm, _ragl,
   {{0x61eb6c50,0x60c0bd12,0x24840364,0x78ad0973}},	//   _sagl, dumm, _dumm_, msav,
   {{0x61eb7640,0x78adbd13,0x24840167,0x21290206}},	//   _pagl, lsav, _eumm_, _ťah_,
   {{0x93bc00d3,0x26c107ac,0x80be0033,0x61e001f9}},	//   _plăc, muho_, ্বন্, geml,
   {{0x61eb028d,0x30750cc6,0x26c10270,0x03c7002d}},	//   _vagl, луос, luho_, _асем,
   {{0x61eb646b,0x1dc60096,0x4f094444,0xd02200ae}},	//   _wagl, _वाहत, енон_, ймый,
   {{0x61ebbd14,0x6da621fd,0x2ba70034,0x28b70ff9}},	//   _tagl, лина, _औज़ा, ेंडि,
   {{0x60c0bd15,0x00000000,0x00000000,0x00000000}},	//   bumm, --, --, --,
   {{0x518401b6,0x78ad4f61,0x6443bd16,0x25a0003e}},	//   _туха, jsav, onni, ðili_,
   {{0x78ad0429,0x6ef70134,0x81ea0033,0x225fbd17}},	//   dsav, _ụbo, মাণ_, lluk_,
   {{0x64439432,0xe6d20378,0xab2a0f5e,0x69c40313}},	//   inni, _सहेज, хова_, tgie,
   {{0x69c40029,0x6e9200e3,0x5fcf2cb6,0x225fbd18}},	//   ugie, _اليا, त्रल, nluk_,
   {{0x6e241fd6,0x9f5c05aa,0x78ad40d6,0xc966008f}},	// [e7e0] _ilib, _anvè_, gsav, увай,
   {{0x225f159d,0x69c40acb,0x248400b7,0xebe6001f}},	//   hluk_, sgie, _rumm_, _сооп,
   {{0x225fbd19,0x09b00081,0x7d09023b,0x26c10270}},	//   kluk_, ঙ্গা, _tërë, guho_,
   {{0x644300a5,0x225fa463,0x00000000,0x00000000}},	//   enni, jluk_, --, --,
   {{0x764286b3,0x649a2569,0xb4ae00a4,0x00000000}},	//   rnoy, хтер_, कळे_, --,
   {{0x6e240990,0x26c1bd1a,0x2a60bd1b,0x76420350}},	//   _llib, buho_, llib_, snoy,
   {{0x6e24bd1c,0x61e019a8,0x475900ae,0x518618d4}},	//   _olib, teml, _артя_, лупа,
   {{0x64432e9d,0x521401a0,0x7afa00c2,0x28c80980}},	//   anni, рдит, ätty, िंपि,
   {{0x61e025d1,0x463b0130,0xdcef008b,0x644301c2}},	//   reml, _נעמע, yacı, bnni,
   {{0x6e24bd1d,0x60c092a6,0x61e02ad2,0x442702db}},	//   _alib, rumm, seml, chn_,
   {{0x60c0bd1e,0xb33c03e5,0x645abd1f,0x93cb0018}},	//   summ, _ieħo, _ikti, _سالہ_,
   {{0x10a60131,0x6e2400e3,0x78ad700f,0xb87b0031}},	//   _бидн, _clib, ysav, _psík,
   {{0x81ea0033,0x40961009,0xa3e8136b,0x62850206}},	//   মাদ_, _срет, _बसा_, íhov,
   {{0x6e24a836,0xa2ab0096,0x6298029a,0xb33c02a1}},	//   _elib, ींच्, opvo, _jeħo,
   {{0x501b040a,0xfe70010d,0x656f2347,0x6e240154}},	//   _אוגו, تدی_, _úchv, _flib,
   {{0x3ce90197,0x78adbd20,0x63aa003e,0x2bb10e4c}},	//   _tsav_, tsav, hafn, _जयका,
   {{0x6443bd21,0x7e6d0124,0xe3b80e63,0x3835828d}},	// [e7f0] ynni, _ihap, _alım_, анар,
   {{0x201e7293,0x225f6c95,0x00000000,0x00000000}},	//   nkti_, zluk_, --, --,
   {{0x78adbd22,0xb87b37b9,0x2a6012f5,0xd6db02e3}},	//   ssav, _kríz, blib_, эта_,
   {{0x7afa01c5,0xeef7040a,0x64482acb,0xceb30089}},	//   ætte, טמבר_, _ajdi, מיע_,
   {{0x2bd23fdd,0x225f00cc,0x7e6d8a17,0x62980f5a}},	//   द्वा, vluk_, _mhap, epvo,
   {{0x7bc7003e,0x6443007b,0xdb1c119e,0x225f0350}},	//   ngju, unni, lgrá, wluk_,
   {{0xdb1c124d,0xa349013d,0x225fbd23,0x786b047e}},	//   ográ, ъзка_, tluk_, güve,
   {{0xe1ff0328,0x4b3800ca,0xdb1cbd24,0x00000000}},	//   ñó_, טרול_, ngrá, --,
   {{0x225f1172,0xaaa502d5,0xdd140031,0x614507f0}},	//   rluk_, गीतक, kúša, репа,
   {{0x7e6d0129,0x225fbd25,0x6e24bd26,0xe8df00fe}},	//   _ahap, sluk_, _slib, _giục_,
   {{0x43840080,0x4425bd27,0xb87b31ca,0x9f470154}},	//   _المق, _ill_, _epíg, _annò_,
   {{0x7e6d1dc2,0x3eb8109d,0x44250154,0xb33c00bd}},	//   _chap, árta_, _hll_, _meħl,
   {{0x7e6d00cd,0xa0a50450,0x765b0350,0x3a29001c}},	//   _dhap, _талд, _mkuy, dhap_,
   {{0x7bc7003e,0x6d5f023b,0x5576006e,0x65690027}},	//   ggju, _dyqa, יערן_, _mzeh,
   {{0xfaa6550f,0x765b1b20,0x4425bd28,0x26c70428}},	//   рабо, _okuy, _mll_, ànol_,
   {{0xceb800a5,0x6e2428c0,0x765b012d,0xba237b30}},	//   rzęt_, _ulib, _nkuy, одск,

   {{0xfce60ba4,0x44257f0b,0x090600c6,0x9f47034f}},	// [e800] _топо, _oll_, шпан, _maní_,
   {{0x4425023e,0x7a23007a,0x2c7c0065,0x765b45f3}},	//   _nll_, _võta, _dádì_, _akuy,
   {{0x3bbb00a1,0x7c3c041c,0x6569063d,0xf99f0154}},	//   _במיד, mirr, _azeh, _poèt_,
   {{0x4425004f,0x9f5c0343,0x3a290ab2,0x2bd21c83}},	//   _all_, _nový_, chap_, द्रा,
   {{0x26170231,0x201e7e08,0x00000000,0x00000000}},	//   _aços_, ykti_, --, --,
   {{0x18a307ca,0x7c3c005c,0x656902ef,0x4425037a}},	//   _фарм, nirr, _dzeh, _cll_,
   {{0x4425005c,0xb87b0065,0xb7db0327,0x63aa00f0}},	//   _dll_, _asíw, _שקלי, rafn,
   {{0x44250472,0xb95b0139,0x63aa0088,0x9f4700b3}},	//   _ell_, _abìy, safn, _caní_,
   {{0x9f470146,0x99990206,0x7c3c7944,0xb33c00bd}},	//   _daní_, _ujsť_, kirr, _teħo,
   {{0x92d500c7,0x201e2224,0x7e6d00ca,0x16040096}},	//   িয়ে_, ukti_, _shap, ळावर_,
   {{0x201e013f,0xb87b0220,0x7e6dbd29,0x443cbd2a}},	//   rkti_, _príz, _phap, miv_,
   {{0x443c6281,0x00000000,0x00000000,0x00000000}},	//   liv_, --, --, --,
   {{0x4094054f,0x62880220,0x44250052,0x3e4f007f}},	//   _التر, _hudo, _yll_, jęte_,
   {{0x645801ac,0x6288b4a5,0xbebc0029,0x7c3c01e9}},	//   novi, _kudo, dzīv, girr,
   {{0x63a81208,0x7e6d033f,0x9a8716e6,0x7bc7bd2b}},	//   _medn, _thap, ругл, rgju,
   {{0x7e6d215e,0x443cbd2c,0x63a811be,0x6288bd2d}},	//   _uhap, hiv_, _ledn, _mudo,
   {{0x64580335,0x443c3598,0x6e3d1cab,0x6820042c}},	// [e810] kovi, kiv_, misb, _tödl,
   {{0x6e3dbd2e,0x645857f8,0x3ec300b6,0x6288ba80}},	//   lisb, jovi, _ústí_, _oudo,
   {{0xcfe10081,0x628800e1,0x7d1d0853,0x76b91894}},	//   বাচন, _nudo, lyss, улер_,
   {{0xd2460867,0xdb050018,0x06840565,0x3f7900c1}},	//   _رن_, _nehé, ігін, אָנע,
   {{0x65600150,0x63a8b7f9,0x24e700f6,0x6288bd2f}},	//   _cymh, _bedn, рцег, _audo,
   {{0x6288bd30,0xb4e70b89,0xe3b100cd,0x99820383}},	//   _budo, _बनी_, سرت_, _ankň_,
   {{0x9f4700b6,0x63a80117,0x628849b8,0x6e3d1c36}},	//   _paní_, _dedn, _cudo, kisb,
   {{0xa2d8007d,0x765b0201,0xddc40087,0xe8050096}},	//   _महर्, _ukuy, _ohiš, रावा_,
   {{0x64580542,0x765900a5,0x34940d9b,0x65600150}},	//   bovi, mowy, _матр, _gymh,
   {{0x6458083d,0x44255482,0x76590034,0x63a8009c}},	//   covi, _ull_, lowy, _gedn,
   {{0x62880694,0xdb050018,0x26d301e9,0x9f4e022b}},	//   _gudo, _fehé, ntxo_, _jafè_,
   {{0x81b100c7,0xb87b0072,0x76590034,0x25fd030b}},	//   ঞ্জ_, _eríx, nowy, _रोमी_,
   {{0xee373f19,0xd7c70378,0x307511b7,0x7c3cbd31}},	//   сня_, _लांच, _лукс, tirr,
   {{0x62880113,0x00000000,0x00000000,0x00000000}},	//   _yudo, --, --, --,
   {{0xff530e8c,0x81ea00c7,0x4e951790,0xab271d5c}},	//   _بخش_, মার_, _اشتر, бора_,
   {{0xbb43364a,0x645800cc,0x598602d8,0x76590034}},	//   ческ, zovi, слаб, jowy,
   {{0xe8fa055b,0x765900a5,0xa3e8007a,0x00000000}},	// [e820] ыла_, dowy, _बसल_, --,
   {{0x443c01bb,0xf209009f,0x3a2024b7,0x81b10033}},	//   xiv_, वाड़_, skip_, ঞ্চ_,
   {{0x63a8a247,0x645800cc,0x443c6b44,0x9f4e361d}},	//   _redn, vovi, viv_, _cafè_,
   {{0x63a8bd32,0x452a43d0,0x6016001f,0x9f4700b3}},	//   _sedn, лжен_, _lâmp, _manà_,
   {{0x98a000a5,0x7a23007a,0x68210134,0x280300b6}},	//   dzić_, _mõtl, _ịdek, ární_,
   {{0x9cd700a1,0x6288bd33,0x9f4e0052,0x83f86ab4}},	//   מונה_, _pudo, _qafë_, рекс_,
   {{0x443c0501,0x8bf200c7,0x63a80b27,0xd25a1b4d}},	//   riv_, ঞাপন_, _vedn, лци_,
   {{0x443c2002,0x80be0033,0x63a84f2d,0x7659007f}},	//   siv_, ্বস্, _wedn, cowy,
   {{0x645800e9,0x0f20110f,0x63a802dd,0x9f4e06a3}},	//   povi, मन्स_, _tedn, _zafè_,
   {{0x6288bd34,0x601600d3,0x8006020f,0x9ed8016d}},	//   _tudo, _câmp, счие, амот_,
   {{0x6d403c09,0x6e3d50f2,0xe0cf015a,0xdb1c17a5}},	//   úman, tisb, وزی_, ngrä,
   {{0xde59325f,0x7d1d007b,0xbebc01d3,0x2bdb04f8}},	//   рамі_, tyss, dzīt, म्ना,
   {{0x6e3d8c9f,0x5c07008f,0x463b006e,0x25d7006e}},	//   risb, бява, רעכע, זוכן_,
   {{0x6e3d01cb,0x7d1d1e95,0x7659007f,0x00000000}},	//   sisb, ryss, zowy, --,
   {{0xa3cd0a30,0x9f5c016d,0x7d1d0de9,0x27f10141}},	//   ष्ट_, _vovó_, syss, _razn_,
   {{0x99991e00,0x6e4400c9,0x7d0900c2,0x7afa04c8}},	//   ркат_, _нејз, äess, ætta,
   {{0xb4e71244,0xe805009d,0x48155541,0xb8150291}},	// [e830] _बने_, राला_, омас, одај,
   {{0x2cb4030b,0x2baa0096,0xfbaa02c6,0x76590034}},	//   řadí_, करणा, करणम, wowy,
   {{0x765900a5,0xb87b1ba6,0xf7480037,0x9f470065}},	//   towy, _apíc, ملكي_, _kaná_,
   {{0xe3b807d1,0x3e7b01b3,0xf770006f,0xdb07033d}},	//   _adı_, _būti_, رال_, nají,
   {{0xa5091c16,0x638519e8,0x765900a5,0x9f450313}},	//   рела_, огла, rowy, gelê_,
   {{0xe8942c37,0x76590034,0xdb07762a,0x93bc044c}},	//   _харь, sowy, hají, _flăm,
   {{0x8c1c2865,0x6d4103a3,0xdb07030b,0x2bdbbd35}},	//   רווי, ğlay, kají, म्या,
   {{0x6d410dea,0x20182e7e,0x00000000,0x00000000}},	//   şlay, örin_, --, --,
   {{0x98a021d5,0xdb0700b6,0x4105004d,0xa507004d}},	//   rzić_, dají, ізов, _уявл,
   {{0x225d171d,0x00000000,0x00000000,0x00000000}},	//   _wkwk_, --, --, --,
   {{0x69c0016d,0x3f69141a,0x69cf0154,0x5e4a0cf5}},	//   _ômeg, рино_, _occe, ипом_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2eee00e7,0xb4e700c3,0x7bdb00e7,0x9f470094}},	//   _esff_, _बनो_, đuun, _daná_,
   {{0x02dd022d,0x22490106,0x69dd32e8,0x9f450216}},	//   _महाभ, čaku_, _abse, nelë_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bdb000c,0x9f47037a,0xbebc01d3,0x00000000}},	//   म्बा, _ganá_, rzīt, --,
   {{0xe7aa0950,0x249d022e,0x3ea700f0,0xd88400d1}},	// [e840] ивал_, jpwm_, _hwnt_, سهای,
   {{0x69cf013d,0x7d1b01bf,0xdb1c0212,0x201300ee}},	//   _ecce, äuse, tgrä, _òxid_,
   {{0x46ea0e3a,0x06ea00d3,0xf986007b,0x3e7b00e8}},	//   рден_, рмек_, _мгно, _sūti_,
   {{0x0566016a,0xd49a4919,0x2b17030b,0x09060396}},	//   овен, арк_, नहरु_, _дпмн,
   {{0xe8f72246,0x6ec00ff9,0x62821044,0xdb1c0c19}},	//   _для_, _विभु, _rioo, sgrä,
   {{0xdb0702c6,0x00000000,0x00000000,0x00000000}},	//   zají, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb33c00bd,0xb1140284,0x00000000,0x00000000}},	//   _jeħi, змиш, --, --,
   {{0xfdee0034,0xdb0700b6,0x62821570,0x039600ae}},	//   ज़नस_, vají, _vioo, _дрея,
   {{0xd01a0f84,0xb33c02a1,0x7bde02ac,0xf3ca212f}},	//   рфи_, _leħi, _nbpu, _خبره_,
   {{0x6ef70174,0xe297339a,0x25ff0096,0xdb0702c6}},	//   _ọbu, _дах_, ळाची_, tají,
   {{0x629abd36,0xb33c02a1,0x00000000,0x00000000}},	//   _itto, _neħi, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a23007a,0x644abd37,0x9f341acf,0x2905020a}},	//   _võtm, nnfi, _нелі, _ăla_,
   {{0xb0240019,0x644a0037,0xe80e1358,0x00000000}},	//   _giườ, infi, साना_, --,
   {{0xddeb001c,0xe70b00d1,0x00000000,0x00000000}},	//   _ضربه_, یتان_, --, --,
   {{0x69dd1d66,0xfbd3439d,0xab87002d,0x8d770504}},	// [e850] _vbse, _तापम, _мунк, _باغا,
   {{0x629a0465,0xe61602dd,0xb87b0065,0xb80541e8}},	//   _otto, _čišč, _asír, राइम_,
   {{0x98ac00d9,0x2ca901c2,0x25af00f9,0x1995246d}},	//   ālās_, _hwad_, tagl_, _наня,
   {{0x69cf00e5,0x2ca901c2,0x68fd0113,0x3afa0142}},	//   _ucce, _kwad_, _trsd, _פּיע,
   {{0x629abd38,0x64a53ae2,0xe9df0032,0xa3e7007f}},	//   _atto, чала, _ibú_, यजल_,
   {{0x3e72025b,0x320600f9,0xe8df0023,0x78700212}},	//   máte_, _anoy_, _nhức_, täve,
   {{0x68ed57cf,0x200900de,0x3e720146,0x2bd30469}},	//   lwad, _đai_, láte_, _ताना,
   {{0x69cd2227,0x00000000,0x00000000,0x00000000}},	//   ngae, --, --, --,
   {{0x629a8e63,0x442e00e7,0x68edb0ac,0xd5fb0023}},	//   _etto, bhf_, nwad, _giú,
   {{0x25ad15b9,0xe8df0028,0xb87b0103,0xea0000fe}},	//   _heel_, _chức_, _zsír, _trầu_,
   {{0x961d0029,0x25ad3fdf,0x2ca9bd39,0x764b0150}},	//   _ziņa, _keel_, _awad_, ongy,
   {{0xfe720391,0xfce602ec,0x68edbd3a,0x3e720a7f}},	//   عدد_, помо, kwad, káte_,
   {{0xc1040080,0x25ad0694,0x61e9a193,0x9f5c00b3}},	//   _يومي, _meel_, meel, _envà_,
   {{0xa09a1b83,0x3e72025b,0xeb974a4e,0x317a00a1}},	//   _היסט, dáte_, зир_, _פרסמ,
   {{0x2007bd3b,0xab2756f6,0x22910830,0x68ed47fd}},	//   _inni_, пора_, _ják_, ewad,
   {{0x1dc602e8,0x3e7b0029,0x61e93e00,0x69cd490b}},	//   _वाटत, _būtu_, neel, ggae,
   {{0x2edb0d43,0x9f452722,0xe8ff00fc,0x00000000}},	// [e860] _बहुत, delé_, _crû_, --,
   {{0x61e920ae,0x7e93020a,0x3cfb021e,0x69cd01ff}},	//   heel, _zăpa, _פלינ, agae,
   {{0x61e9bd3c,0xdb0e0113,0x25ad0188,0x9f450103}},	//   keel, kabé, _beel_, felé_,
   {{0xd6cf177a,0x68200149,0x25ad0188,0x6e2600f9}},	//   طقه_, _nödv, _ceel_, nkkb,
   {{0x25ad0db8,0x61e9043e,0xd5af012b,0x68ed9ae4}},	//   _deel_, deel, افه_, cwad,
   {{0x7bcebd3d,0x961d0029,0x02a62bfa,0x7bdc00d3}},	//   ngbu, _viņa, прим, nfru,
   {{0x66e388b7,0x61e90134,0x25ad00a1,0xdb0e2733}},	//   _пора, feel, _feel_, fabé,
   {{0x20070465,0x25adb244,0xc1ea00d6,0x9f454340}},	//   _anni_, _geel_, ське_, celé_,
   {{0x1dc6009d,0x24850b87,0x60c997b2,0xe8df00de}},	//   _वाजत, _film_, guem, _phức_,
   {{0x20180088,0x6ec00287,0xb03300c2,0xe366002d}},	//   ðri_, _विदु, еньш, _екзи,
   {{0x61e92851,0x443ea793,0x75220018,0x91e61c16}},	//   beel, _imt_, lyoz, _ноже,
   {{0x61e947cc,0x7c3e47b9,0x998205aa,0x7a2300bc}},	//   ceel, _ampr, _ankō_, _võtk,
   {{0xe8df0028,0xdb050fb6,0x5c070f5f,0x443e0503}},	//   _thức_, _vehí, пява, _kmt_,
   {{0x68fb001f,0x442c061d,0x717b00ca,0x3e7202c6}},	//   _áudi, _jld_, _הנדס, váte_,
   {{0x7e86033a,0x1dc60096,0x3fdb00ca,0xf99a0294}},	//   íspě, _वाचत, _הקוב, _ọpụp,
   {{0xb87b0139,0x7a2a0220,0x3e720146,0x34dc045f}},	//   _asíp, _pýta, táte_, _यहूद,
   {{0x442c00a1,0x69cd9000,0x6e2d06a8,0x9f45bd3e}},	// [e870] _old_, rgae, _ilab, velé_,
   {{0x68edbd3f,0xb87b9fd3,0x3e720094,0x7a2a02c6}},	//   rwad, _epín, ráte_, _výta,
   {{0x6e2d97f7,0x9f45030b,0x68ed2f0f,0x61e95e92}},	//   _klab, telé_, swad, yeel,
   {{0x1dad1349,0xd7740f36,0x442c44eb,0x443e40d7}},	//   चरित, رالع, _ald_, _amt_,
   {{0x25ad7d74,0x248d00c9,0x442c5c3d,0x61e9588f}},	//   _veel_, _quem_, _bld_, veel,
   {{0x61e9bd40,0x2a69bd41,0xb95b0065,0x443ebd42}},	//   weel, llab_, _adìg, _cmt_,
   {{0xe3b00adc,0x6e2dbd43,0x61e99cc2,0x25adbd44}},	//   اره_, _olab, teel, _teel_,
   {{0x02dd10ed,0x3ede00ac,0x443e00bc,0x442c87c4}},	//   _महीन, _chọọ_, _emt_, _eld_,
   {{0x4900000d,0x61e9bd45,0xdb0e538a,0x248d00bc}},	//   रियो_, reel, rabé, _uuem_,
   {{0x61e90e22,0xa3d42657,0x386300dc,0x443e1ed3}},	//   seel, _поуч, _jkjr_, _gmt_,
   {{0x6e2dbd46,0x2a69bd47,0x661bbd48,0x61e97d4b}},	//   _blab, klab_, _kouk, peel,
   {{0x6443bd49,0x661b0084,0x3ede0134,0x6e2d036b}},	//   lini, _jouk, _ghọọ_, _clab,
   {{0x60c92e00,0xb4bb009f,0x6443009b,0x225f04de}},	//   quem, _आटो_, oini, mouk_,
   {{0x7afc00e9,0x6443bd4a,0x224d0018,0x3b0a0084}},	//   tvrt, nini, lnek_, оего_,
   {{0xa3df00a8,0x66097432,0x224dbd4b,0x7bdcbd4c}},	//   ध्य_, _onek, onek_, rfru,
   {{0x7bdc22a4,0x2a69023e,0x224d0018,0xe1f9013f}},	//   sfru, glab_, nnek_, ndų_,
   {{0x6443bd4d,0xd9430d89,0x2bdb3abb,0x7e64674b}},	// [e880] kini, вети, म्हा, _ikip,
   {{0x6443bd4e,0x66096c87,0x2a6900f9,0x75220239}},	//   jini, _anek, alab_, vyoz,
   {{0x6443bd4f,0x224d0068,0x2a69bd50,0x661b02f1}},	//   dini, knek_, blab_, _bouk,
   {{0x81e200c7,0xb33c03e5,0xb87b0094,0xdb1c09af}},	//   _ফোন_, _meħt, _upín, dgrø,
   {{0x224d0103,0x661b022b,0xa3d20592,0x7e64024a}},	//   dnek_, _douk, _वाद_, _mkip,
   {{0x6443bd51,0xe3b807aa,0x4427005c,0x66099f34}},	//   gini, _alır_, gkn_, _enek,
   {{0xbddb0472,0x7e6406a3,0x442c01cb,0xb33c00bd}},	//   dièn, _okip, _vld_, _neħt,
   {{0xaca40af0,0x2902bd52,0x26d80167,0x224d0103}},	//   _afọw, _krka_, _iqro_, gnek_,
   {{0x6443bd53,0x961d0029,0xdfd00037,0x442700dc}},	//   bini, _ziņo, هية_, bkn_,
   {{0x3f1423a3,0x7e640051,0xdb050146,0xbddb04c1}},	//   едос, _akip, _lehá, gièn,
   {{0x3eb800fb,0x6e2d01dc,0x27f80178,0x6d5a020a}},	//   ért_, _plab, _marn_, ştal,
   {{0x26c7005f,0x29024dfb,0x60e70212,0xdced02a1}},	//   šnog_, _orka_, örmå, _jfaħ,
   {{0x03f10033,0xdced0090,0x7ff30a85,0xe0d40142}},	//   চারী_, _mfaħ, رسیا, _נײַ_,
   {{0xbddb05fe,0x7a3100d6,0xf99f0154,0x00000000}},	//   cièn, _måte, _enèl_, --,
   {{0x7a3131c1,0x290227eb,0xdced0357,0x76401f9e}},	//   _låte, _arka_, _izač, _ommy,
   {{0x6443bd54,0x3e5600d9,0x29020b14,0xb87b5593}},	//   zini, tāte_, _brka_, _epíl,
   {{0x6443028e,0x61e24d0a,0x27f8a122,0x98750cfc}},	// [e890] yini, _mbol, _barn_, елац,
   {{0x661bbd55,0x224d0018,0x27f8bd56,0x47c70081}},	//   _souk, znek_, _carn_, র্নী,
   {{0x6443bd57,0x661bbd58,0x61e203f1,0x201c037a}},	//   vini, _pouk, _obol, _movi_,
   {{0x290208a9,0x2bdb022d,0x6443bd59,0x7a310ec9}},	//   _frka_, म्रा, wini, _båte,
   {{0x6443bd5a,0x290200cc,0x44271d49,0x27f800f0}},	//   tini, _grka_, tkn_, _farn_,
   {{0x201c0335,0x36d54564,0x68200149,0x7640af18}},	//   _novi_, _погр, _döds, _emmy,
   {{0x64432d74,0x224d0018,0x661b0084,0x442702fa}},	//   rini, tnek_, _touk, rkn_,
   {{0x6443bd5b,0x660927c5,0x442700dc,0x3a291cab}},	//   sini, _unek, skn_, nkap_,
   {{0x6443bd5c,0x25bf2bb2,0x7fd536bf,0x224dbd5d}},	//   pini, _idul_, ніні, rnek_,
   {{0x7e64bd5e,0x6443067d,0x6ec0049d,0x224dbd5f}},	//   _skip, qini, _विशु, snek_,
   {{0xfe460a67,0xbddb0472,0xd24e09e5,0x201c02ef}},	//   енно, rièn, شنی_, _dovi_,
   {{0xed5a6eb1,0x6ec005a5,0x61e20af0,0x00000000}},	//   зом_, _विरु, _gbol, --,
   {{0x61fb005a,0x2d8409a1,0xdb0700bc,0x68320537}},	//   mdul, äme_, hajä, _hæde,
   {{0x09ba02e8,0x61f9bd60,0x60dba7fb,0x683202b6}},	//   ेल्य, _hawl, mtum, _kæde,
   {{0x60dbbd61,0xa3d20296,0xf99f01dc,0x25a60555}},	//   ltum, _वास_, _enèm_, ybol_,
   {{0x61fb992d,0x3a293afd,0xed5a1cb1,0xbddb45b0}},	//   ndul, gkap_, _ной_, nièl,
   {{0x6832052f,0x6f030146,0x644135a0,0x7a31169c}},	// [e8a0] _læde, _hrnc, _omli, _båtb,
   {{0x6c340018,0x7d04960d,0x27f802a1,0x00000000}},	//   _شہزا, _iris, _qarn_, --,
   {{0x60db0d80,0x7d04bd62,0xdb050018,0x23c90354}},	//   htum, _hris, _tehá, _राजद,
   {{0x7d047ba5,0xa3d20e72,0x321d00a5,0x29020b18}},	//   _kris, _वाह_, _nowy_, _trka_,
   {{0x27f8bd63,0x61fbbd64,0x00000000,0x00000000}},	//   _tarn_, ddul, --, --,
   {{0x7d040051,0x61e20036,0x9f473c09,0x78a43852}},	//   _mris, _sbol, _danú_, mpiv,
   {{0x2bd3009d,0x201c0036,0x78a40036,0xa3df0285}},	//   _तासा, _rovi_, lpiv, ध्ध_,
   {{0x7d04bd65,0x93bc00d3,0x28c73f50,0x61fb1ba1}},	//   _oris, _alăt, _लिमि, gdul,
   {{0x61f90694,0x60dbbd66,0x29000428,0xe805009d}},	//   _dawl, gtum, nvia_, राचा_,
   {{0xa3df3ec9,0x53a60076,0x93bc044c,0x00000000}},	//   ध्द_, _أماك, _clăt, --,
   {{0x61fb3418,0x6f030a9e,0x2ca00063,0x7d0440b7}},	//   bdul, _crnc, _atid_, _aris,
   {{0x61e22533,0x00000000,0x00000000,0x00000000}},	//   _ubol, --, --, --,
   {{0x7a23007a,0x9f4e0139,0x7a2a0094,0xd00a007e}},	//   _mõtt, _dafá_, _výtl, _неде_,
   {{0x7d041406,0x3e724b00,0xb09b00ca,0x00f700ca}},	//   _dris, ráta_, _ציור, _נמוך_,
   {{0x7d04bd67,0x2cea2235,0xdb5800c2,0x6f030095}},	//   _eris, टबॉल_, еют_, _grnc,
   {{0x7d044287,0xbeec00c3,0xd9cb0285,0x00000000}},	//   _fris, जबीन_, िलेट, --,
   {{0x3a29bbbb,0x5c7537fa,0xb4df0285,0x00000000}},	// [e8b0] rkap_, _илит, _तहे_, --,
   {{0x3a292af1,0x68200149,0x38780154,0x61fb0103}},	//   skap_, _södr, _chrr_, zdul,
   {{0xdcfd0390,0xc5d516dd,0x85380022,0x290012f1}},	//   ması, віль, ɗɗiy, avia_,
   {{0xdcfd0491,0x2c7602b6,0x00000000,0x00000000}},	//   lası, ræde_, --, --,
   {{0x3e5600d9,0x68323229,0x7d0400a7,0x98a9007f}},	//   nāta_, _sæde, _xris, dzać_,
   {{0xdcfd008e,0x61f90172,0xd7f800d3,0x00000000}},	//   nası, _sawl, _пус_, --,
   {{0xdce40067,0x61f93b3a,0xa3d202d5,0xb3d2009d}},	//   _dzię, _pawl, _वार_, _सारख,
   {{0x05d80789,0x60db8db9,0x61fb93f9,0x7afa003e}},	//   _डायब, ttum, udul, ætti,
   {{0x212b0882,0x34952cb3,0xdcfd0dea,0x61fbbd68}},	//   ách_, _разр, kası, rdul,
   {{0x60dbbd69,0x4ae2009f,0x601e00b6,0x64413388}},	//   rtum, _पहलव, _námě, _umli,
   {{0x34d158a0,0x2ca00477,0x47c70081,0x6da65cac}},	//   _समुद, _stid_, র্থী, кина,
   {{0x270101b3,0xbbaa0ded,0x98a90034,0x80dc0033}},	//   _mėn_, कर्क, czać_, বিজ্,
   {{0xdcfd071d,0xdb0e424a,0xee37400f,0x3e5600e8}},	//   fası, rabí, тня_, gāta_,
   {{0x628b00f9,0x2900028d,0x7d0468fb,0xa136006e}},	//   _higo, vvia_, _vris, _באנק_,
   {{0x2bd30f8f,0x628b359c,0xeb97120a,0x3ce90154}},	//   _तारा, _kigo, тис_, _epav_,
   {{0x2900bd6a,0x628bbd6b,0xc3320796,0x00000000}},	//   tvia_, _jigo, בול_, --,
   {{0xf1b20130,0x60c97db0,0x628b1a87,0x6e3d023b}},	// [e8c0] יסן_, nrem, _migo, ërbe,
   {{0x628b013f,0x29001894,0x60c90257,0x656f0146}},	//   _ligo, rvia_, irem, _úchy,
   {{0x99990068,0xbddb1022,0xfaa6097a,0xdb1c0696}},	//   _első_, zièm, _шано, ngrü,
   {{0x64a685d8,0x601e02c6,0xfc3f0143,0x00000000}},	//   вада, _zámě, mpía_, --,
   {{0x7a230006,0xbddb0257,0x34d109c4,0xfc3f002b}},	//   _võtt, xièm, _समृद, lpía_,
   {{0x07a32a05,0x628b00ec,0xf99f00d1,0x07ba0037}},	//   _варн, _aigo, _anèh_, _زهرة_,
   {{0xf7460dcc,0x628bbd6c,0x779100d0,0x7a23007a}},	//   _рево, _bigo, _ایما, _tõtt,
   {{0x60f852d3,0xf5060318,0xa3e20455,0xdcfd008e}},	//   ения_, _избо, _फॉर_, zası,
   {{0xdcfd01d4,0x628bbd6d,0xfbb80081,0x2bd33c80}},	//   yası, _digo, _জানত, _ताला,
   {{0xf99f0113,0x98a90034,0xdcfd00a7,0x7a3100f3}},	//   _enèh_, szać_, xası, _måta,
   {{0x7a3105e8,0x60c90143,0xdcfd008b,0xf1b901d3}},	//   _låta, arem, vası, ekšu_,
   {{0xc0aa0f36,0x814300cd,0xd36f0604,0x6e64004c}},	//   _قاتل_, اپیم, _بهم_, итяж,
   {{0xdcfd0511,0xecc7008f,0xdb156e49,0x78700212}},	//   tası, ъщно, mazé, tävl,
   {{0x09cb2cb6,0x628bb0d1,0x22980103,0x63b801df}},	//   िल्य, _zigo, _kék_, navn,
   {{0xdcfd07d1,0x35d800aa,0x00000000,0x00000000}},	//   rası, _डाढ़, --, --,
   {{0x79a40084,0x63b8181f,0x7a312452,0x39a4001f}},	//   ируе, havn, _båta, ишув,
   {{0xb3d20455,0xa3d23350,0x6280771f,0x49750a18}},	// [e8d0] _सांख, वला_, immo, улас,
   {{0x63b802dd,0xb5fd00c4,0x383400ae,0xdcfd00a7}},	//   javn, _ekšl, анур, qası,
   {{0x63b800e9,0xdb050149,0x58841845,0x229803a9}},	//   davn, _behå, рыта, _nék_,
   {{0xdb070220,0x7a2300aa,0xa53500c2,0x60c9bd6e}},	//   kajú, _võts, лнеч, yrem,
   {{0x63b80430,0xf99f026e,0x5a162252,0x00000000}},	//   favn, _ifè_, _עקשן_, --,
   {{0x60c900e9,0x628b026a,0xf773015a,0xdb070031}},	//   vrem, _sigo, _ناز_, dajú,
   {{0x628b03a8,0xe1f10037,0x00000000,0x00000000}},	//   _pigo, مسة_, --, --,
   {{0xc1b900e3,0x9f4c034f,0x00000000,0x00000000}},	//   رابط_, cedé_, --, --,
   {{0x60c93435,0x628b1cc0,0x9f5900d2,0x00000000}},	//   urem, _vigo, ěsí_, --,
   {{0x60c9bd6f,0xa2ca2014,0xef193277,0x6fd8009d}},	//   rrem, संख्, емо_, _माणू,
   {{0xe7f61827,0x628b022b,0x5f4500e3,0x60c90565}},	//   ीयता_, _tigo, انجل, srem,
   {{0xdca62edd,0xe80a00a5,0x23df2ebd,0x60c95809}},	//   лами, _होना_, प्रद, prem,
   {{0xf1b92a1e,0xafe50dd8,0xb4f9006e,0xdb1c042c}},	//   maš_, _болл, עפֿי, sgrü,
   {{0x9f0500bf,0xf1b9bd70,0xd0400092,0x557600c1}},	//   _موتو, laš_, kumə, טערן_,
   {{0xf8bf00fc,0x00000000,0x00000000,0x00000000}},	//   _avé_, --, --, --,
   {{0x63b80ca7,0xf1b9153a,0x7a310073,0x6d40221e}},	//   zavn, naš_, _påta, úmas,
   {{0xe09e0134,0xfc3f1ba6,0xdb1c00b3,0x09060fe9}},	// [e8e0] _kọọ_, mpín_, ggrò, ыпан,
   {{0xe73a1d68,0xe8f701b6,0xf99f02f1,0xb8ec33c5}},	//   нез_, ылу_, _efè_, _रट_,
   {{0xa3ba1152,0xdb070220,0xa3d200aa,0x3e5601d3}},	//   _अजब_, zajú, वलस_, nāto_,
   {{0x7afa01cd,0x7e93020a,0x7c2eaea4,0x93bc044c}},	//   ættu, _căpi, lkbr, _alăp,
   {{0xa92800b6,0x7a2a003e,0xa3b4013f,0x00000000}},	//   _držá, _nýti, аблі, --,
   {{0xdb070220,0xe09e0134,0x7c2e1030,0x69d601f9}},	//   vajú, _nọọ_, nkbr, lgye,
   {{0x533408d1,0x68f60150,0x2d92010a,0x248c0141}},	//   рейт, lwyd, _ogye_, _vidm_,
   {{0xf7530604,0x69d6bd71,0xddcf020a,0x248c0381}},	//   _انفج, ngye, docş, _widm_,
   {{0x2611009d,0x25fd0409,0xb0345b74,0x68f600f0}},	//   णारी_, _रोटी_, иниш, nwyd,
   {{0xf1a4045f,0xdb0e0103,0xdb070220,0x41a4206b}},	//   _ग्रन, zabá, rajú, _ग्रस,
   {{0x33930080,0xf1b91fce,0x74130037,0x81e90033}},	//   _المز, baš_, _دولا, ময়_,
   {{0x2cb20150,0xdd910037,0x38bb0065,0x7c2e05c2}},	//   _bwyd_, توح_, _jàrá_, ekbr,
   {{0x2cb2030a,0x3d0f0285,0x00000000,0x00000000}},	//   _cwyd_, ामें_, --, --,
   {{0x9f5c023b,0xe09e0174,0x961d00d9,0x2d92178b}},	//   _javë_, _gọọ_, _viņi, _egye_,
   {{0x28c702e8,0xf8bf000d,0xa3e6009d,0xdb0e1e6a}},	//   _लिहि, _své_, य्य_, tabá,
   {{0x2d920361,0x2cb200f0,0x69d66dbf,0x229100c4}},	//   _ggye_, _fwyd_, ggye, _uške_,
   {{0x68f602ad,0x644abd72,0x391511c0,0xe09e0174}},	// [e8f0] gwyd, kifi, шмар, _yọọ_,
   {{0x25fd02e8,0x6832052f,0x57b400d6,0x644a0239}},	//   _रोजी_, _pæda, йбут, jifi,
   {{0xf1b902dd,0x81cc0081,0xc6a728c2,0x7bc50052}},	//   ljše_, শ্য_, урзи, _idhu,
   {{0xd5fb00fe,0x9f5c0231,0xf8bf02c6,0xdb1c00ee}},	//   _khủ, _pavê_, _tvé_, pgrò,
   {{0x644a7545,0xf1b90087,0x998205aa,0xb87b03be}},	//   fifi, njše_, _ankņ_, _osíx,
   {{0xd90e0068,0x644abd73,0x22461e72,0x00000000}},	//   _کیے_, gifi, _amok_, --,
   {{0xf1b90995,0x1dc50096,0x7bc50350,0x00000000}},	//   taš_, वणात, _mdhu, --,
   {{0xe09e0174,0x26d30072,0xb2251720,0xe8130d75}},	//   _sọọ_, muxo_, рмил, ठावा_,
   {{0x2055051b,0x644a02a4,0x9f470146,0xdcee01d3}},	//   итор, bifi, _daný_, ājīb,
   {{0x644abd74,0xe3b000cd,0x764b11b9,0x6ec0009d}},	//   cifi, _فرم_, ligy, _विखु,
   {{0x2bdc277c,0xef1600d3,0xa3ab2397,0x7a4100d2}},	//   _बाबा, амэ_, _क्य_, _zítř,
   {{0x81cc0081,0x7bc5bd75,0x764b0bb6,0xb87b002b}},	//   শ্ব_, _adhu, nigy, _esíx,
   {{0x9f4c008f,0xe09e0134,0x6aa50076,0x7c66109d}},	//   ledì_, _tọọ_, _athf, لاسل,
   {{0x69cb6a26,0x4fa51510,0x913a006e,0xb87b02c6}},	//   ógen, _тикв, _בענק, _zpív,
   {{0xae1e000f,0x290f0222,0x9f4c008f,0x7ae30149}},	//   _बचपन_, ågan_, nedì_, _äntl,
   {{0x644abd76,0xc332040a,0x7bc50113,0x2d923170}},	//   zifi, קון_, _edhu, _ugye_,
   {{0xada900e3,0x87ba00c2,0xe8fa00e5,0x00000000}},	// [e900] _صديق_, вует_, ъла_, --,
   {{0x68f66096,0x644a3b03,0x6e240037,0x69d601f9}},	//   rwyd, xifi, _hoib, sgye,
   {{0x103600c1,0x09e6329e,0x5fdd5c52,0x68f600f0}},	//   סטעם_, _конн, _मानल, swyd,
   {{0x81ab0033,0x7a38bd77,0x764b06b0,0x00000000}},	//   কৃত_, _bíte, gigy, --,
   {{0x644a4de0,0x25a942be,0xb4c2009f,0x3e793210}},	//   tifi, ñala_, ्ढे_, néta_,
   {{0x0ec5110f,0xf2c6235c,0x26d303be,0x61ae142e}},	//   _विंड, асин, buxo_, घर्ष,
   {{0x764b00a6,0x15e70789,0xdb1e1515,0xc5d60120}},	//   bigy, _टॉवर_, _odpí, _візь,
   {{0xe80a8380,0xa3d20179,0x6e2400da,0x00000000}},	//   _होता_, _वाक_, _noib, --,
   {{0x1da71c0a,0xd01000e3,0x100a0037,0x64a318b6}},	//   _क्षत, كلة_, نتدى_, _мата,
   {{0x6600bd78,0x44e00d79,0x66021415,0x91a60034}},	//   _hamk, mò_, ldok, _ट्रै,
   {{0x645a09a4,0x44e01637,0x44e200de,0x660000d4}},	//   _ijti, lò_, _hư_, _kamk,
   {{0x6602bd79,0x6e244486,0x6600bd7a,0x3e720037}},	//   ndok, _coib, _jamk, náth_,
   {{0x409610fb,0x44e0bd7b,0x6e2407bc,0x66000094}},	//   _трет, nò_, _doib, _mamk,
   {{0x78a903a3,0x66001216,0x69c60188,0x9f47015e}},	//   _çevi, _lamk, _adke, _canó_,
   {{0x78a6003e,0xdddd0034,0x6e36bd7c,0x8ff70018}},	//   _atkv, rosł, _flyb, _ضرور_,
   {{0x0dcb2917,0x66004100,0xbdb519e8,0x6e24bd7d}},	//   _руки_, _namk, _убиј, _goib,
   {{0x5fdd0d0b,0x7e6db408,0x9f4705aa,0x64481842}},	// [e910] _मामल, _ikap, _abnè_, _omdi,
   {{0x44e037f8,0x9f47058a,0xa8142a72,0xf99f022b}},	//   dò_, _ganó_, одуш, _anèt_,
   {{0xfbdc02e8,0xf7700241,0x2bf600ca,0x7e6d010a}},	//   _बातम, وام_, _המתן_, _kkap,
   {{0x60c204eb,0x9f4c008f,0x66000167,0x6602bd7e}},	//   _ovom, vedì_, _camk, gdok,
   {{0x44e20019,0x66008680,0x7e6d0051,0xa3d20096}},	//   _cư_, _damk, _mkap, वलं_,
   {{0x26d303be,0xdb050c08,0x44e200de,0x229100e7}},	//   puxo_, _behø, _dư_, _aška_,
   {{0x972500cd,0x7a2a025b,0x660016ce,0x7e6d0179}},	//   _افزو, _výtv, _famk, _okap,
   {{0xe1f900b8,0xb87b0072,0x7e6d0270,0x7a380610}},	//   уги_, _epít, _nkap, _títe,
   {{0x76491c15,0x44e0028d,0x26c10188,0xe534007b}},	//   _imey, cò_, lsho_, _деть,
   {{0x7e6dbd7f,0x660000a5,0x60c20211,0x2bdc0557}},	//   _akap, _zamk, _dvom, _बाधा,
   {{0x6e240080,0x6fd8009d,0x4425036b,0xfeb900cd}},	//   _poib, _मारू, _iol_, داخت_,
   {{0x44250dc6,0xdb15499e,0x201e0052,0x9f4c309e}},	//   _hol_, gazí, ajti_, cedí_,
   {{0x4425bd80,0x224d5b2b,0x7c250364,0xf1dc0569}},	//   _kol_, miek_, _bohr, _यातन,
   {{0x224dbd81,0x7e6dbd82,0xdd990220,0x7e93044c}},	//   liek_, _ekap, ľňa_, _săpu,
   {{0x09a90081,0x8c431a51,0x7c2535b5,0x9f95007a}},	//   _ওয়া, чере, _dohr, _müük_,
   {{0x224dbd83,0x44250b87,0x7a2a01cd,0x9f450324}},	//   niek_, _lol_, _nýtt, relä_,
   {{0x19b901b3,0x4425008c,0x68fd039f,0x6600bd84}},	// [e920] русь_, _ool_, _cssd, _ramk,
   {{0x66000102,0x80cf178c,0x44250a4f,0x44e03411}},	//   _samk, _दिने, _nol_, vò_,
   {{0x44e20019,0x657b6f51,0x224d6c41,0x66020537}},	//   _sư_, _azuh, kiek_, tdok,
   {{0x44e0401d,0x05ba1d28,0x7c250031,0x7afe0078}},	//   tò_, ادات_, _zohr, _ispt,
   {{0x4425bd85,0xe8df0028,0x6fd8000f,0x290b007e}},	//   _bol_, _phục_, _मालू, _grca_,
   {{0x4425bd86,0x68e40501,0x44e09b11,0x7649bd87}},	//   _col_, mtid, rò_, _emey,
   {{0x4425bd88,0x68e487c8,0x60c204a3,0xc5ed00c7}},	//   _dol_, ltid, _svom, ওয়া_,
   {{0x44e200ef,0x644d00fd,0x224d9a5d,0x44253bf8}},	//   _tư_, éair, giek_, _eol_,
   {{0x55540068,0xdced005f,0xa507098f,0x442568fb}},	//   _بھار, _izać, _лета_, _fol_,
   {{0x7e6d0b6a,0xa3d22183,0xd4910023,0x68e4452d}},	//   _skap, _वाट_, _gì_, itid,
   {{0x68e400aa,0xc7b300ca,0x2d9e00b6,0x7c250364}},	//   htid, הבת_, ěten_, _rohr,
   {{0x90e600bf,0x60c200cc,0x68e4007a,0xdb1cbd89}},	//   _هستن, _tvom, ktid, parê,
   {{0x44250dea,0x412a02ec,0x7e93002d,0x626500e3}},	//   _yol_, _щодо_, _săpt, _بالق,
   {{0x629a1a7e,0x80a400cd,0x394001d3,0x645809ad}},	//   _kuto, _همچن, dzis_, nnvi,
   {{0xa3e006ed,0x4ea60a0e,0xf1b90087,0x68e4bd8a}},	//   _थान_, _урла, ljša_, etid,
   {{0x63ba15d7,0x629a1a90,0xb4e80251,0x31790034}},	//   _letn, _muto, _बहू_, ższe_,
   {{0xf1b90087,0x629e0146,0x68e4081d,0xe918004d}},	// [e930] njša_, ípoj, gtid, боті_,
   {{0x629abd8b,0x224d2807,0x7d0dbd8c,0x63ba3828}},	//   _outo, ziek_, _iras, _netn,
   {{0x2baf0b2b,0x442502ae,0x68e45c46,0x25a90143}},	//   _ज्या, _rol_, atid, ñalo_,
   {{0x68e4008c,0x26c1bd8d,0xa3ab0096,0xdb1c03a9}},	//   btid, rsho_, कुन_, darè,
   {{0x4425420e,0x68e41f72,0x224d0220,0x290b00ae}},	//   _pol_, ctid, viek_, _urca_,
   {{0x629abd8e,0x63ba0ca7,0xdb1c160c,0x224d0034}},	//   _buto, _cetn, rgrö, wiek_,
   {{0x224d5cf3,0xdb1cbd8f,0x44252198,0xd4910023}},	//   tiek_, varë, _vol_, _vì_,
   {{0x442590b6,0x7d0dbd90,0xa4d500d6,0x629a8af6}},	//   _wol_, _oras, _мобі, _duto,
   {{0xdb1c01e5,0x224d02a7,0x545502b3,0x69dc023a}},	//   tarë, riek_, _дват, _फासी,
   {{0x224dbd91,0x4425001f,0xb95b0065,0x99820383}},	//   siek_, _uol_, _adìk, _dakň_,
   {{0x7d0d5cfc,0x629a6eec,0x224d29ea,0xdb1e00d4}},	//   _aras, _guto, piek_, _odpá,
   {{0x7d0d85f5,0x765902e0,0x68e4081d,0x1d0a00e5}},	//   _bras, nnwy, ytid, аеми_,
   {{0x1ddb3856,0x61e9bd92,0xe81c000d,0x3e5600d9}},	//   _भारत, mfel, नामा_, nāti_,
   {{0x7d0d5efd,0x61e90c09,0xdb1c1d90,0xdb0d0146}},	//   _dras, lfel, laré, _škál,
   {{0x7d0dbd93,0x26c70106,0xa3d20096,0xa3d1023a}},	//   _eras, šnoj_, _वाघ_, _वयन_,
   {{0x61e91762,0x68e4bd94,0xb5320139,0x6e3d042c}},	//   nfel, ttid, _bẹ́l, chsb,
   {{0x602500b6,0x7a380072,0xb4e80aa1,0x61e90364}},	// [e940] _témě, _cíta, _बहे_, ifel,
   {{0x2005aa15,0x394000ae,0xa3ab1592,0x63660031}},	//   ndli_, rzis_, कुम_, nčné,
   {{0xbddb04ea,0x63ba1484,0x7d0d7091,0x765900f0}},	//   mièr, _retn, _zras, fnwy,
   {{0xac9714df,0xbddb025a,0x61e90126,0x629abd95}},	//   _دنیا_, lièr, jfel, _ruto,
   {{0xdb15bd96,0xdb170072,0x61e98583,0x3e5601d3}},	//   mazá, _rexé, dfel, gāti_,
   {{0x629a0335,0x48f90130,0x7bdcbd97,0xbddb025a}},	//   _puto, _פּרא, ngru, nièr,
   {{0x3e722ce2,0x64580973,0x7a310572,0x00000000}},	//   látu_, rnvi, _båth, --,
   {{0x61e90068,0x44440018,0x2005152e,0xb87b0094}},	//   gfel, _کررہ, edli_, _upír,
   {{0x7bdc1c82,0x32020181,0x3e720146,0x2d9e00d2}},	//   kgru, ľky_, nátu_, ětel_,
   {{0x32020074,0xdb1c78b5,0x629a0b87,0x8f0a00d3}},	//   žky_, parè, _tuto, ахма_,
   {{0x91e636f2,0xe7e2007d,0x629a07ac,0xbddb014b}},	//   _може, _पानप, _uuto, dièr,
   {{0x7d0dbd98,0x98b20067,0x2005bd99,0x3e720094}},	//   _pras, czyć_, adli_, kátu_,
   {{0x7bdc01bf,0x5c073bba,0x00000000,0x00000000}},	//   fgru, оява, --, --,
   {{0xe80abd9a,0x7d0d00dd,0x26c70181,0x7bdcbd9b}},	//   _होला_, _vras, ánok_, ggru,
   {{0x628201bb,0x2bdc0e28,0x0dcb1941,0x765900f0}},	//   _khoo, _बारा, _купи_, ynwy,
   {{0x7d0d2cc5,0xaca30294,0x290900e7,0x99992543}},	//   _tras, _ahụg, tvaa_, скат_,
   {{0x7d0d1825,0x7bdc002b,0xc4c40103,0xfe7007e8}},	// [e950] _uras, bgru, _جے_, _جدو_,
   {{0x6282bd9c,0x7a38bd9d,0xbddb020d,0x2909007b}},	//   _lhoo, _víta, cièr, rvaa_,
   {{0x56950084,0x290900c2,0x61e9bd9e,0xdb150031}},	//   чает, svaa_, yfel, bazá,
   {{0x3e5600d9,0xfad600a1,0xdb150072,0xdb077637}},	//   tāti_, _צורך_, cazá, sajó,
   {{0x03a51a53,0xa50905b8,0x04040033,0x61e93b69}},	//   пило, села_, লানী_, vfel,
   {{0x96d302d5,0x03a52c37,0xe299088c,0x628241be}},	//   _डिपॉ, чико, бак_, _ahoo,
   {{0x68f903a3,0x9f5c0146,0x61e9bd9f,0xf4850103}},	//   şadı, _baví_, tfel, _ہائی,
   {{0x628200a1,0xa3ab0c3c,0xbddb020d,0x00000000}},	//   _choo, _क्र_, zièr, --,
   {{0xc3cb003f,0x6282008a,0x61e91f2b,0x98b200a5}},	//   _نظام_, _dhoo, rfel, rzyć_,
   {{0x61e9bda0,0x98b20034,0xdb0e2728,0x2d9e02c6}},	//   sfel, szyć_, rabú, ětem_,
   {{0xfd4d0028,0xbddb0257,0xdb1c00fd,0xe298004d}},	//   _triệ, vièr, paré, _дає_,
   {{0x200319d0,0x6282009c,0x1da7023a,0x2449007f}},	//   žji_, _ghoo, कुलत, dźmi_,
   {{0xbddb025a,0xf1b902dd,0xc19a00a1,0x02db2231}},	//   tièr, ljšo_, _השני, _यमुन,
   {{0xb0680391,0x2bdc0096,0xae1e00aa,0xc0040120}},	//   _وصول_, _बाळा, _बचवन_, _опік,
   {{0x7bdc1a02,0xbddb0257,0xdb831525,0xf1b9033b}},	//   rgru, rièr, егри, njšo_,
   {{0x7bdc0429,0xee3f025b,0x160b0789,0xba23090f}},	//   sgru, chý_, _सोलर_, ндск,
   {{0xdb15bda1,0x998902ef,0xbddb020d,0x00000000}},	// [e960] razá, tkaš_, pièr, --,
   {{0x3e720074,0xb8650103,0xb7da00b9,0xb33c0090}},	//   rátu_, والو, صوصا_, _teħx,
   {{0x04040081,0x9989031a,0xa9a642c7,0xbf79020b}},	//   লামী_, rkaš_, _нинд, _đuốc_,
   {{0x6aa30610,0x63820076,0xceb22252,0x00000000}},	//   _énfa, _líní, גיא_, --,
   {{0x5398007b,0x27e60d2a,0x628234eb,0x00000000}},	//   овля_, ƙon_, _rhoo, --,
   {{0x2902a09e,0x04436eaa,0xd499004d,0x6282a061}},	//   _iska_, нечн, ірі_, _shoo,
   {{0x62820197,0x78a908bb,0xb0240023,0x45d600ae}},	//   _phoo, _çevr, _nhườ, _нцат,
   {{0x75840260,0x714600e5,0x00000000,0x00000000}},	//   _قیام, зхож, --, --,
   {{0x3e5600d9,0x26dabda2,0x00000000,0x00000000}},	//   nātu_, lupo_, --, --,
   {{0xdefa1ad1,0x73e30284,0x00000000,0x00000000}},	//   бым_, _поуз, --, --,
   {{0x62820197,0x5fdd0cf6,0x2d80a8e3,0x833a0478}},	//   _thoo, _मारल, _azie_, _учат_,
   {{0x290200aa,0xc1e31152,0xd37b006e,0x31790034}},	//   _oska_, _गायब_, _פראט, ższa_,
   {{0x94050092,0x638238e9,0x69d80138,0xa3c20096}},	//   _ailə_, _fíní, ėvel, _्या_,
   {{0x26da00f9,0x3e5600e8,0x8aa73e7b,0x00000000}},	//   kupo_, dātu_, зрад, --,
   {{0x7b640e1d,0x2d8000ac,0x7a380037,0x00000000}},	//   етте, _ezie_, _vítn, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x320607ac,0x00000000,0x00000000,0x00000000}},	// [e970] _maoy_, --, --, --,
   {{0x80cf009d,0xb60600c4,0xed5800d7,0x00000000}},	//   _दिसे, _lešć, _מבחר_, --,
   {{0xf1dc02e8,0xfbd202f8,0x48f91317,0x26c7000d}},	//   _यांन, _בתי_, _उनको_, éno_,
   {{0xb8d30f71,0xcf9300c1,0x25a102c6,0x00000000}},	//   _টি_, גטע_, ěhlo_, --,
   {{0xa3b902d5,0xe53400d6,0xd5fb0023,0x3a2b0154}},	//   चरल_, нець, _chú, _iocp_,
   {{0x61e2bda3,0x3e480018,0x7a380653,0xdb170042}},	//   _acol, lőtt_, _lítl, _lexí,
   {{0x753c0092,0x26da028d,0xb60600c4,0x9474001c}},	//   _ərzi, cupo_, _bešć, ردها,
   {{0x394d0682,0xfbe30033,0x25a60036,0x80a90120}},	//   _þess_, য়িত, ccol_, овив_,
   {{0x7fd53006,0xa4d400d6,0x6289bda4,0xdb05033c}},	//   міні, _поті, rmeo, _dfhé,
   {{0xb02400de,0x80dc0034,0x2c7602b6,0x25bf0365}},	//   _phườ, पढ़े, pædi_, _heul_,
   {{0xfbe30081,0x249f0027,0x73c408ba,0x90e433e7}},	//   য়াত, _huum_, _سينم, وسین,
   {{0x200b1f83,0x7ec233c3,0x61e20076,0x249f00bc}},	//   ści_, _sípá, _gcol, _kuum_,
   {{0x2baf1a09,0x61fbb9b2,0x25bf02ac,0x412900d3}},	//   जुभा, meul, _meul_, _фоло_,
   {{0xb0240028,0x3c3400c2,0x4e1c0034,0x8c95013f}},	//   _thườ, _kävi_, याहै_, ерсі,
   {{0xeb97380e,0x224f0167,0x9f5c0428,0x60dbbda5}},	//   дир_, _kmgk_, _gavà_, luum,
   {{0xed5a067c,0x25bf07db,0x2007bda6,0x7a387843}},	//   _мой_, _neul_, _hani_, _víto,
   {{0xdb1c2c74,0x200721df,0x2baf13ae,0xddd600d8}},	// [e980] marí, _kani_, _ज्वा, _chyť,
   {{0x7a380472,0xdb1c1ba6,0x7d04bda7,0x2ca00161}},	//   _títo, larí, _isis, _iuid_,
   {{0x8c1b0132,0x2007bda8,0x49ba097d,0x2ca00126}},	//   _וויי, _mani_, _واحد_, _huid_,
   {{0x60db0b6c,0x2ca00006,0xdb1c24c7,0xb8e40081}},	//   kuum, _kuid_, narí, _এম_,
   {{0x6e3d00dd,0x290214f3,0x4de300b6,0xdb1c0072}},	//   ërbi, _uska_, ट्टै_, iarí,
   {{0x2ca0bda9,0x20071b24,0x69c4b5d5,0x7d040239}},	//   _muid_, _nani_, laie, _msis,
   {{0xae0e06e4,0x3e5600d9,0x38a40704,0x4e0e2231}},	//   ियान_, nāts_, _hör_, ियाई_,
   {{0x7d042624,0x38a4bdaa,0x20077b23,0xdb1c35ec}},	//   _osis, _kör_, _aani_, jarí,
   {{0x2007bdab,0xdb1703be,0xdb1c2a10,0xb606007e}},	//   _bani_, _rexí, darí, _vešć,
   {{0x2007bdac,0xdfd000ab,0x69c4875e,0x29000134}},	//   _cani_, ديد_, haie, iwia_,
   {{0x93430f99,0x38a40149,0x61fb6c0e,0x249f0174}},	//   _инфе, _lör_, beul, _zuum_,
   {{0x442cbdad,0xdb1c2a10,0x99800138,0x2ca0009c}},	//   _hod_, garí, nkių_, _buid_,
   {{0x442c02e6,0x2ca010f0,0x7a313502,0x20075457}},	//   _kod_, _cuid_, _mått, _fani_,
   {{0x2007bdae,0x205600d6,0x2ca00449,0xdb1e03a9}},	//   _gani_, _ютер, _duid_, _kepè,
   {{0x442cbdaf,0x7d04bdb0,0xc1080028,0xdb1c2c74}},	//   _mod_, _esis, _hỗ_, barí,
   {{0x442cbdb1,0x38a40222,0x7c3ebdb2,0x20074594}},	//   _lod_, _bör_, _elpr, _zani_,
   {{0x200701e8,0x76420821,0x5c75014d,0x443e50cd}},	// [e990] _yani_, dhoy, _плит, _olt_,
   {{0xe6100814,0x25bf025a,0x38a40212,0x61fb15e7}},	//   یشن_, _seul_, _dör_, zeul,
   {{0x249f0154,0x2ca00126,0xc10800de,0x69c40062}},	//   _suum_, _zuid_, _lỗ_, baie,
   {{0x38a46fb3,0x80cf009d,0x442c033c,0x69c46f5e}},	//   _för_, _दिले, _aod_, caie,
   {{0x442c02e0,0x38a4070a,0x6e2d019c,0x443e2fc6}},	//   _bod_, _gör_, _moab, _blt_,
   {{0xd3780067,0x63850f57,0xe299188b,0x25b2564a}},	//   _być_, нгла, пак_, ıyla_,
   {{0x442cbdb3,0x61fbbdb4,0x2ba70ff9,0x45d500a9}},	//   _dod_, teul, _खलना, _повс,
   {{0x20071114,0x443e6961,0x60dbbdb5,0xdb1e0428}},	//   _sani_, _elt_, tuum, _depè,
   {{0x442c02e0,0x661b198f,0x2007bdb6,0xdb1c3850}},	//   _fod_, _inuk, _pani_, varí,
   {{0x44e98f7b,0x442c089a,0x60dbbdb7,0xc1080023}},	//   mú_, _god_, ruum, _dỗ_,
   {{0x2ca00665,0xdb1cbdb8,0x2007bdb9,0x64430a1b}},	//   _suid_, tarí, _vani_, mhni,
   {{0x20072bc2,0xa3ab1244,0x2bb80e1f,0x6e2d0cc0}},	//   _wani_, कुर_, अर्थ, _coab,
   {{0x2007bdba,0x442cbdbb,0xdb1e00dd,0xc1080019}},	//   _tani_, _yod_, _tepë, _gỗ_,
   {{0x38a40149,0xdb1c1946,0x69cf60a2,0x660900aa}},	//   _rör_, sarí, _adce, _laek,
   {{0x6d460067,0xe80a0067,0x629938f1,0x60c990af}},	//   szka, _होगा_, _kiwo, lsem,
   {{0x7d04bdbc,0xdb260068,0x6299005c,0x661b06c0}},	//   _tsis, _épít, _jiwo, _nnuk,
   {{0x69c4bdbd,0x44e9bdbe,0xd9431e6d,0xed5a0c28}},	// [e9a0] raie, jú_, гети, _хоп_,
   {{0x661b7130,0x60c9bdbf,0x1aff0081,0x69c4bdc0}},	//   _anuk, isem, _উপরে_, saie,
   {{0x6443475d,0x660905e3,0x38b60139,0x442c00d7}},	//   dhni, _baek, _bùrò_, _rod_,
   {{0xdb1ebdc1,0x442c543d,0x60c90f06,0x667612eb}},	//   _repè, _sod_, ksem, ردار,
   {{0xd25000cd,0xdb1c255b,0x9f450031,0x60c902b6}},	//   ینت_, barã, velý_, jsem,
   {{0xa3ab121d,0xa2a440c1,0x66e644ab,0x64431909}},	//   कुल_, _चंद्, _пога, ghni,
   {{0x81e900c7,0x442c104f,0x443e227a,0x76420201}},	//   য়ন_, _vod_, _vlt_, phoy,
   {{0x6fdd0789,0x62990044,0x99890220,0x6443bdc2}},	//   _माउं, _ciwo, skať_, ahni,
   {{0xe21300e3,0x442cbdc3,0x629901dc,0xdb1e00ee}},	//   طبيع, _tod_, _diwo, _depé,
   {{0x63b3025b,0x64a31894,0x442c07ac,0x6e2d002b}},	//   čení, _сафа, _uod_, _soab,
   {{0x60c9032c,0x085700ca,0x00000000,0x00000000}},	//   asem, תבים_, --, --,
   {{0x11e900e3,0x6299010a,0xdb1cbdc4,0x60c9044c}},	//   _يعني_, _giwo, darà, bsem,
   {{0xe0d400c1,0x7e640154,0x0cab00e5,0x60c90103}},	//   _סײַ_, _djip, ятни_, csem,
   {{0x7e640383,0xb3e00851,0x629991dc,0xdb1c0231}},	//   _ejip, नलिख, _ziwo, xarã,
   {{0xdb1c0db4,0x3e640233,0x00000000,0x00000000}},	//   garà, sıta_, --, --,
   {{0xa8a70084,0x6b9e0072,0x9d720129,0x00000000}},	//   ержк, _egpg, ọlọt, --,
   {{0xdb1c0161,0xa3e00f35,0x23e00980,0x660900bc}},	// [e9b0] tarã, थला_, _नांद, _raek,
   {{0x7e7d0b84,0x44e90181,0xdb1c05fe,0x2a601350}},	//   llsp, vú_, barà, anib_,
   {{0xd6dbbdc5,0x7bc7bdc6,0xdced0039,0xe7191487}},	//   ята_, maju, _izađ, بيات_,
   {{0xdb05070a,0x60c9943b,0x7bc74218,0x44e9bdc7}},	//   _behö, ysem, laju, tú_,
   {{0xdb1c7eb2,0x6443bdc8,0xc9840642,0xdb1e00fd}},	//   mará, thni, _бури, _repé,
   {{0x44e9bdc9,0x6299bdca,0x7bc7bdcb,0xdb1c0088}},	//   rú_, _siwo, naju, lará,
   {{0x68ed0b0b,0x44e96c72,0xf1b902dd,0x2fc50856}},	//   ltad, sú_, ljši_, valg_,
   {{0x60c9bdcc,0x661b0335,0x6443bdcd,0xb8030081}},	//   tsem, _unuk, shni, _উচিত_,
   {{0x3949bdce,0xe6645e3d,0xdb0502e2,0x60c90257}},	//   nzas_, _стро, _gehö, usem,
   {{0x60c97076,0x68edbccd,0x7bc700cc,0x68320537}},	//   rsem, itad, jaju, _hædr,
   {{0x60c9bdcf,0x7bc703ce,0x68edbdd0,0x9f450314}},	//   ssem, daju, htad, veló_,
   {{0xed5a4941,0x68edbdd1,0x657b009d,0x2fc50c08}},	//   дом_, ktad, _kyuh, salg_,
   {{0xdb1c682d,0xc6920089,0x321d02ac,0xc0e500e5}},	//   dará, יאט_, _inwy_, _ролк,
   {{0x307900c1,0x09ca0096,0x394901d3,0xd0110018}},	//   _קאַנ, िण्य, dzas_, _ضلع_,
   {{0xfaa60b1e,0xf8bfbdd2,0x205600c1,0x3949037a}},	//   табо, _awé_, _ביסל_, ezas_,
   {{0x68edbdd3,0x3b0700c9,0xdb1c1d32,0xf2d200c1}},	//   ftad, њето_, gará, יעל_,
   {{0x6569023b,0x644100c2,0xe9df0032,0x68edbdd4}},	// [e9c0] _nxeh, _olli, _amús_, gtad,
   {{0x7a383bf0,0x25ad191e,0x68320537,0xdb1c00b3}},	//   _míti, _afel_, _ræds, parà,
   {{0x7a380102,0x290f0149,0x657b2190,0x7a310f63}},	//   _líti, ågar_, _ayuh, _våtr,
   {{0x75d30080,0x947300d0,0xe9a60114,0x7d16bdd5}},	//   ليما, یدوا, _шамп, _krys,
   {{0x68ed255c,0xd4e30084,0x200c02ad,0x7a38bdd6}},	//   ctad, ающи, yddi_, _níti,
   {{0x07a604f5,0x29120027,0x00000000,0x00000000}},	//   _јавн, mvya_, --, --,
   {{0x68320430,0x969601b6,0x00000000,0x00000000}},	//   _fædr, _араш, --, --,
   {{0xd7e2030b,0x22810088,0x644159af,0xb33c0090}},	//   _पाँच, sókn_, _elli, _ngħe,
   {{0x7a38035d,0x7bc70239,0x64a6bdd7,0xae210ff9}},	//   _cíti, yaju, _раза, यासन_,
   {{0xdb1c04d8,0x7eb8007e,0x9f450036,0x320d008c}},	//   zará, нгос_, velò_, adey_,
   {{0x7bc703ce,0x2bdc1362,0xa3e7bdd8,0x481500c1}},	//   vaju, _बाजा, _भात_, אַרן_,
   {{0xf77300a1,0x7d164ada,0x7bc72822,0x320d0188}},	//   יקת_, _brys, waju, cdey_,
   {{0xe046160b,0xd7e20e28,0x7d1659af,0x644138ea}},	//   _инди, _पांच, _crys, _ylli,
   {{0x64580630,0x7d16913b,0x5c742458,0xd00f109d}},	//   nivi, _drys, илят, _ولن_,
   {{0xdb1cbdd9,0x7bc7a757,0x5f730421,0xa3e033dc}},	//   tará, raju, _پاور, _थाई_,
   {{0x68edbdda,0xcbe300c7,0x7bc7002d,0x6458166d}},	//   ttad, য়েছ, saju, hivi,
   {{0xdb1c22f2,0x64580d67,0x7d1661fa,0x69340e48}},	// [e9d0] rará, kivi, _grys, анту,
   {{0x39490fb6,0x6e3dbddb,0xdb1c06cb,0x9f5e023b}},	//   rzas_, lksb, sará, jetë_,
   {{0xdb1cbddc,0x657b2fc5,0xb87b0072,0x3dd200f0}},	//   pará, _syuh, _mpíx, _ydyw_,
   {{0xe7ff02b0,0xb9090081,0x6e3d18ef,0x320d008c}},	//   _उसका_, _মন_, nksb, xdey_,
   {{0xd1261790,0x58d40465,0x89da02f8,0x7bc5bddd}},	//   _ام_, _коят, _אחרי, _kehu,
   {{0x320d008c,0x7bc51175,0x00000000,0x00000000}},	//   wdey_, _jehu, --, --,
   {{0x7a380161,0x7bc57622,0xdb0700f3,0x00000000}},	//   _síti, _mehu, gbjø, --,
   {{0x96f811d9,0xe9df002b,0x65955a5c,0x6e3d6035}},	//   _шест_, _flúe_, _бабу, jksb,
   {{0x64583809,0xe4d90103,0xd059004d,0x657b0113}},	//   bivi, _سوات_, ерні_, _uyuh,
   {{0x7659053c,0x7a380bfe,0x7bc5b654,0x64416138}},	//   liwy, _víti, _nehu, _ulli,
   {{0x8eb200cd,0x00000000,0x00000000,0x00000000}},	//   یمیش, --, --, --,
   {{0x7d16bdde,0x765900f0,0x320d008c,0x7bc50231}},	//   _prys, niwy, qdey_, _aehu,
   {{0x7bc503ee,0xee37002d,0x463a006e,0x681b01d3}},	//   _behu, уня_, גערע, _kādē,
   {{0xd00607f3,0x7d160185,0x3b0a00c2,0x60dbbddf}},	//   _беше_, _vrys, него_, mrum,
   {{0xdea1110a,0x60dbbde0,0xcb674000,0x7bc5023b}},	//   _دیجی, lrum, гаре_, _dehu,
   {{0x7d16030a,0x64587d87,0x6e3d1e71,0x9f5e0216}},	//   _trys, zivi, cksb, zetë_,
   {{0x76590150,0x3e79003e,0xe8fa00c6,0x00000000}},	// [e9e0] diwy, rétt_, эла_, --,
   {{0x7bc504e2,0x9cbb0266,0x6458af75,0x7659084e}},	//   _gehu, _רציח, xivi, eiwy,
   {{0x6458bde1,0x60dbbde2,0x4422bde3,0xdb1c016d}},	//   vivi, hrum, _đk_, darç,
   {{0x64a611a1,0x44220103,0x60db9ba9,0xdb1c003e}},	//   гада, _ők_, krum, taræ,
   {{0x81e90f71,0x7bc50194,0x9f5e023b,0x89360037}},	//   য়া_, _yehu, tetë_, _إعجا,
   {{0x07a30467,0x69c6355f,0x83f82b99,0x07ba0037}},	//   _гарн, _heke, текс_, _سهرة_,
   {{0x69c6bde4,0x81b50033,0x9f5e0216,0x60db09a1}},	//   _keke, _জয়_, retë_, erum,
   {{0x6458bde5,0x60db91f7,0xdb1e0094,0x80cf0034}},	//   sivi, frum, _nepí, _दिखे,
   {{0xc4865e39,0x645800c2,0xc566037e,0x69c63177}},	//   _блак, pivi, _скак, _meke,
   {{0x9f5ebde6,0xaca50174,0x00000000,0x00000000}},	//   leté_, saịz, --, --,
   {{0x04930037,0xb7db006e,0x398b0032,0x7bc5bde7}},	//   _اللح, עקטי, _kòsí_, _rehu,
   {{0x69c6bde8,0x7bc5063f,0x60db0090,0x6ce707bf}},	//   _neke, _sehu, brum, ліге,
   {{0x60db31fa,0xd24f00e3,0xade600aa,0x2be908e7}},	//   crum, _عنه_, _कारन_, _जादू_,
   {{0x9f5e0257,0x2a790063,0x69c601ff,0x7659007f}},	//   heté_, _sksb_, _aeke, ziwy,
   {{0x69c6bde9,0xab950291,0x7a38003e,0x9f5e03a9}},	//   _beke, рављ, _lítu, keté_,
   {{0x200ebdea,0x78a61100,0x69c6bdeb,0x7ed30246}},	//   _hafi_, _bukv, _ceke, _ازوا,
   {{0x69c6bdec,0x200e19e4,0xb9990c2b,0x7bc5bded}},	// [e9f0] _deke, _kafi_, твах_, _tehu,
   {{0xee3f030b,0x27f80090,0x69c66a8c,0x200e7a2a}},	//   lký_, _cbrn_, _eeke, _jafi_,
   {{0x200e1114,0x69c6106a,0xa2a40fef,0x60c20361}},	//   _mafi_, _feke, _चूल्, _lwom,
   {{0x69c65e94,0x200e01c2,0xee3f0094,0x79820034}},	//   _geke, _lafi_, nký_, żowa,
   {{0xa5090d06,0x00000000,0x00000000,0x00000000}},	//   тела_, --, --, --,
   {{0x69c60505,0x200e00dc,0xee3f0146,0x1be9030b}},	//   _zeke, _nafi_, hký_, ञ्चल_,
   {{0x249e0154,0x290b00b3,0x60c2bdee,0xee3f3ebd}},	//   _ditm_, _hsca_, _awom, kký_,
   {{0xa3e705a7,0xd5f90130,0x60c23683,0x62800095}},	//   _भाव_, _שפּר, _bwom, glmo,
   {{0x681b00d9,0xdb1e598a,0xee3f0094,0xd24e0037}},	//   _tādē, _repí, dký_, بني_,
   {{0xb4c1007d,0x60db4298,0x200e2dd9,0x62800381}},	//   ंठी_, rrum, _cafi_, almo,
   {{0x3f69545a,0x200e36cc,0x9e662917,0x60c20172}},	//   тино_, _dafi_, ивод, _ewom,
   {{0x60db8823,0x6f18037d,0x60c205aa,0x290b00ee}},	//   prum, _drvc, _fwom, _osca_,
   {{0x69c6112d,0xb33c02a1,0x60c2bdef,0x200e007b}},	//   _reke, _igħa, _gwom, ömiä_,
   {{0x69c6bdf0,0xafe204c9,0x00000000,0x00000000}},	//   _seke, _дошл, --, --,
   {{0x69c65bf1,0x290b028d,0x59e1007f,0x6602024a}},	//   _peke, _asca_, _फाखर, yeok,
   {{0xee3f0871,0x200e0044,0xb33c003d,0x2fc7bdf1}},	//   cký_, _zafi_, _jgħa, _heng_,
   {{0x2fc7bdf2,0x61eb5a3b,0x47c69c31,0x200e0044}},	// [ea00] _keng_, _mcgl, ибав, _yafi_,
   {{0x3ea70505,0x69c60ab2,0x2fc70706,0x9f4713c6}},	//   _kunt_, _weke, _jeng_, _acné_,
   {{0x69c63ade,0x2fc7bdf3,0xdb05052f,0x29193600}},	//   _teke, _meng_, _afhæ, _ersa_,
   {{0x320f0068,0x3ea7bdf4,0xeef6006e,0x2fc78f3f}},	//   _nagy_, _munt_, ימער_, _leng_,
   {{0x9f5e00fd,0xdb1e00ee,0x07a611c0,0x3ea70ac9}},	//   reté_, _hepà, _вагн, _lunt_,
   {{0x2fc700bf,0x68e49876,0x66022c6f,0xb33c0078}},	//   _neng_, muid, seok, _agħa,
   {{0xa3e7074c,0x68e420ae,0x200e03e3,0xb33c00bd}},	//   _भार_, luid, _rafi_, _bgħa,
   {{0x7a380b0b,0x200ebdf5,0x60c206a3,0x2fc703a9}},	//   _títu, _safi_, _pwom, _aeng_,
   {{0xe8df00ef,0xfbc60b94,0x68e4850b,0x51860426}},	//   _việc_, वराम, nuid, шука,
   {{0x7afe00d6,0x249e0332,0x2fc7bdf6,0x7870007b}},	//   _oppt, _uitm_, _ceng_, tävy,
   {{0x2fc793fd,0xe8df00de,0x2d8000dc,0x3e720094}},	//   _deng_, _tiệc_, _ayie_, láty_,
   {{0x60c23743,0xd6d80033,0x68e41341,0xdb1c00b3}},	//   _twom, _সহায, kuid, mbrè,
   {{0x200e006d,0x22468cd1,0x776e225b,0x3e720094}},	//   _tafi_, _ilok_, _lxbx, náty_,
   {{0xee3f0368,0xe0fb00a1,0x2fc7bdf7,0x68e4bdf8}},	//   ský_, _סלול, _geng_, duid,
   {{0x224604dc,0x81e90033,0x3ea701cb,0x442e0381}},	//   _klok_, য়র_, _gunt_, ijf_,
   {{0x3ea000f9,0x3e720146,0x2919bdf9,0x9f9b00ca}},	//   _giit_, káty_, _prsa_, _בסופ,
   {{0x97a7002d,0x2fc70113,0x2d890350,0x00000000}},	// [ea10] арел, _yeng_, _uzae_, --,
   {{0x3d140096,0x3e7202c6,0x00000000,0x00000000}},	//   दिरे_, dáty_, --, --,
   {{0x22460991,0x81de0081,0x78ba02c6,0x00000000}},	//   _olok_, দ্য_, _čtve, --,
   {{0x32040067,0x68e49eaf,0x7d0d01c2,0x291905db}},	//   jemy_, buid, _ksas, _trsa_,
   {{0xb4c1007d,0x38c90260,0x38bd0065,0x68e40328}},	//   ंठे_, _حاجی_, _dárò_, cuid,
   {{0x224690aa,0x1cb800a1,0xdb1e0145,0x7d0d0a4b}},	//   _alok_, סלול_, _hepá, _msas,
   {{0x2ca900f9,0x4cb00033,0xdb150143,0x2fc7bdfa}},	//   _luad_, জীপু, mazó, _reng_,
   {{0x2fc761f9,0x3ea70222,0x7d0d2050,0x3e720146}},	//   _seng_, _runt_, _osas, báty_,
   {{0x3ea70a29,0x320f00fb,0xe81c0096,0x2fc733c1}},	//   _sunt_, _vagy_, नाचा_, _peng_,
   {{0x3ea7bdfb,0x3ea0007a,0x224608d3,0x00000000}},	//   _punt_, _siit_, _elok_, --,
   {{0x2246bdfc,0xa3ac0abe,0x320f0146,0xb33c003d}},	//   _flok_, _गलत_, _tagy_, _tgħa,
   {{0x2909ad1a,0x7bd708a8,0x2ca91d49,0xdb1ebdfd}},	//   kwaa_, _adxu, _buad_, _nepá,
   {{0x2fc74063,0x30a7456f,0x4274071c,0xdb1c31a5}},	//   _teng_, _трев, _بالآ, mbré,
   {{0x61e90908,0x81ae0081,0xaf490391,0x3dd803e5}},	//   lgel, করণ_, _مشعل_, _żewġ_,
   {{0x200575bd,0x7d0d3264,0xbb4305c7,0x61e900f0}},	//   meli_, _esas, перк, ogel,
   {{0x61e90b5a,0x2005bdfe,0x68e41f84,0x2ca92a83}},	//   ngel, leli_, tuid, _fuad_,
   {{0x6e24bdff,0xdb170072,0x61e94bcb,0x00000000}},	// [ea20] _inib, _xexú, igel, --,
   {{0xdb1522e7,0x68e4be00,0x3e720094,0x61e9042c}},	//   gazó, ruid, váty_, hgel,
   {{0x7afe1d10,0x7bcebe01,0xa3ab0251,0x12e20081}},	//   _uppt, mabu, कुछ_, _মন্দ,
   {{0x80d84d14,0x7bcebe02,0x2005be03,0x2ca9022e}},	//   _मिले, labu, heli_, _yuad_,
   {{0x2005496f,0x644a00e3,0x61e90188,0xdb050023}},	//   keli_, thfi, dgel, _nghê,
   {{0x2005748e,0x7bcea09f,0x3e720618,0x61e9157c}},	//   jeli_, nabu, ráty_, egel,
   {{0x6e24be04,0x61e93ddf,0x8c1b00ca,0x22460270}},	//   _onib, fgel, טוסי, _plok_,
   {{0x61e93320,0x7bcebe05,0x9663002d,0x7a3800b6}},	//   ggel, habu, _ексе, _zítr,
   {{0x7bce5dbd,0x80d8009d,0x2005be06,0x442e037a}},	//   kabu, _मिळे, feli_, pjf_,
   {{0x2005be07,0x7bce0060,0xfd4d020b,0x00000000}},	//   geli_, jabu, _thoắ, --,
   {{0x43862204,0x645abe08,0x6e3693d3,0x6448be09}},	//   _الاق, _imti, _boyb, _ildi,
   {{0x2ca90063,0xf99f0113,0x3f8201d3,0x479b0142}},	//   _puad_, _kaèt_, āku_, טייס,
   {{0x91e314fa,0x2ca9257e,0xd8510065,0xdb1e002b}},	//   _хоче, _quad_, _bọ̀_, _repá,
   {{0x9f5ebe0a,0x2005be0b,0xdb1e1ba6,0x50960291}},	//   letí_, celi_, _sepá, _уређ,
   {{0xa3d00a35,0x9f4c6165,0xb33c009e,0x7ff700ca}},	//   _वजन_, redó_, _mgħo, _הזוג_,
   {{0x2aa824dc,0x29090051,0x7f830037,0x6e240113}},	//   стро_, twaa_, _علين, _gnib,
   {{0x383515c3,0x7bce571e,0x621b006e,0x645a010a}},	// [ea30] онар, babu, נומק, _omti,
   {{0x9998002d,0x81ae0033,0x7bce0fca,0xb33c00bd}},	//   скут_, করি_, cabu, _ngħo,
   {{0xdb15be0c,0x61e98934,0xdc38006e,0x69cd00c2}},	//   razó, ygel, _לאזט_, paae,
   {{0x2005be0d,0x644802a7,0xceb300c1,0xa5f94aaa}},	//   zeli_, _aldi, ליע_, реду_,
   {{0x20050060,0x7ae715fe,0x7e6dbe0e,0x61e900e7}},	//   yeli_, lujt, _mjap, vgel,
   {{0x42d90624,0x987900c1,0x2005115d,0x8ccb42d4}},	//   афия_, _כאָט, xeli_, तीयो,
   {{0x61e9b472,0xa3b8009f,0xfd4a13d8,0xa2290b7a}},	//   tgel, चड़_, _bulọ, ижка_,
   {{0xe0d90a52,0x20051b24,0x64483156,0x7bcebe0f}},	//   ави_, weli_, _eldi, zabu,
   {{0x61e9be10,0x7bce6ccb,0xa3e70096,0xdb1c04c8}},	//   rgel, yabu, _भाऊ_, rbré,
   {{0x7ae742c9,0x61e9be11,0x6e36be12,0xd7660068}},	//   kujt, sgel, _soyb, _انہی,
   {{0x81de00c7,0x61e91570,0x644300a5,0x2005be13}},	//   দ্ধ_, pgel, mkni, reli_,
   {{0x64430501,0x442516a2,0x7ae7025b,0x7bce70ec}},	//   lkni, _hnl_, dujt, wabu,
   {{0x7bce636b,0x764903a9,0x765b0172,0x16c60285}},	//   tabu, _mley, _mmuy, _लब्ब,
   {{0x64430bc6,0x7e6d0372,0xb33c003d,0x225f361e}},	//   nkni, _ejap, _ogħl, liuk_,
   {{0xa3e70d0b,0x7bcebe14,0xf21e0251,0xeb9abe15}},	//   _भाई_, rabu, _मोड़_, рив_,
   {{0x6e24be16,0x7bce8a6c,0xa2cc0789,0x00000000}},	//   _unib, sabu, _सबस्, --,
   {{0x7bce1d33,0xb33c0078,0x44250988,0x38cb00d1}},	// [ea40] pabu, _agħl, _onl_, لالی_,
   {{0xb90209a1,0x67210995,0x765b6cfa,0x7649071d}},	//   _धि_, _šlja, _amuy, _aley,
   {{0xdb0500de,0x2a69023e,0x224d00f9,0xab2a36c9}},	//   _nghè, bnab_, khek_, _тона_,
   {{0x5efa0130,0x4425be17,0xd5b0006f,0x76495b04}},	//   יפעד, _anl_, رفت_, _cley,
   {{0x7642005c,0x2c0f009d,0xb33c02a1,0xd05b0d2a}},	//   rkoy, ायचं_, _egħl, ntuɓ,
   {{0x7649026e,0x2bbf0469,0x442500ee,0x765b06b0}},	//   _eley, ्रया, _cnl_, _emuy,
   {{0x68f60313,0x7649be18,0x224d02ac,0xdc9b0142}},	//   ltyd, _fley, fhek_, ביסל,
   {{0x76490088,0xb95b0af0,0xb88202c6,0x44251ee2}},	//   _gley, _adìy, řída, _enl_,
   {{0x2bbf2183,0x661d0088,0x3218030b,0x68f62405}},	//   ्रमा, _óska, ěry_, ntyd,
   {{0x64430222,0xdced07aa,0xa3e700bc,0x60dd0072}},	//   ckni, _ayağ, _भाए_, ásma,
   {{0xc7b30054,0x3eb8023b,0x2a69be19,0x224d0113}},	//   ובת_, ërt_, ynab_, bhek_,
   {{0xdb1f04c8,0x41260018,0x74c1034d,0x7ae7739c}},	//   ðvík, _وفاق, रीकृ, vujt,
   {{0xa06a0831,0x22570688,0xa0b81055,0x00000000}},	//   _када_, _بلند_, _углу_, --,
   {{0x7ae71c5f,0x2d8500e8,0x2bb80076,0x7c37009e}},	//   tujt, āle_, قافة_, _qoxr,
   {{0x7e6d02ac,0x68f602ac,0x00000000,0x00000000}},	//   _tjap, etyd, --, --,
   {{0x7ae7bdad,0x42db00c1,0xbda733e7,0x7e6d024a}},	//   rujt, יקלע, _بحثو, _ujap,
   {{0x37ab0476,0x7ae739a2,0x39400103,0x64430ac9}},	// [ea50] атен_, sujt, gyis_, ykni,
   {{0x7ae700d4,0xb33c0078,0x2a6900f9,0xb91100fe}},	//   pujt, _agħm, snab_, _khoả_,
   {{0x7649be1a,0x290200c4,0xf99f03a9,0xcd340a85}},	//   _pley, _epka_, _paès_, _فریب,
   {{0x8f9b00a1,0xdb0500fe,0xbddb014b,0x4efb0142}},	//   ביבי, _nghé, chèt, שלאג,
   {{0x442500d3,0xc984002d,0x25a90128,0xe534036c}},	//   _pnl_, _жури, žalo_, мець,
   {{0x7e7dbe1b,0xb33c0090,0xe458004d,0x00000000}},	//   hosp, _egħm, ожі_, --,
   {{0x644309ce,0x224dbe1c,0xdb1e0364,0x44250381}},	//   rkni, thek_, _gepä, _vnl_,
   {{0x765b023f,0x6443516e,0x00c95be3,0x27e900ae}},	//   _umuy, skni, блик_, şină_,
   {{0x7e7dbe1d,0x225fa2a8,0xddc4015c,0xf4870284}},	//   dosp, riuk_, _njiš, _дужн,
   {{0x8f7500d6,0x93271454,0x00000000,0x00000000}},	//   зумі, _وران, --, --,
   {{0x224d55e3,0x201902c6,0xd4980120,0x6f62002d}},	//   phek_, ěsi_, _єру_, евэз,
   {{0x3ea40222,0x2a600188,0x12fa00ca,0x7e7d2652}},	//   ömt_, xiib_, _להעב, gosp,
   {{0xe1670037,0x61fb0415,0x00000000,0x00000000}},	//   _بداي, mful, --, --,
   {{0xd47900c1,0x61fb0ac9,0x9f5e00b3,0xdbd70f06}},	//   מאָל, lful, betà_, jääk,
   {{0xd00e054f,0x8b231491,0x00000000,0x00000000}},	//   _إلى_, ндре, --, --,
   {{0x9f960089,0x2bd8030b,0x81e90033,0x89aa4d95}},	//   _צדקה_, _भएका, য়ক_, скав_,
   {{0xdb1c642b,0x3a3900d4,0x00000000,0x00000000}},	// [ea60] mbrí, _dosp_, --, --,
   {{0x68f66692,0x6f030b14,0x2a600188,0xb33c02a1}},	//   rtyd, _kpnc, siib_, _dgħj,
   {{0x8cb20455,0x39461dfc,0x68f635bc,0xd7ef0037}},	//   _इंडो, šos_, styd, اكم_,
   {{0x3a391fce,0x98a6002d,0x95c700d3,0x00000000}},	//   _gosp_, _ниме, пуша_, --,
   {{0x69c4be1e,0xdb1c00e3,0x1a9b00c1,0x61fb0973}},	//   mbie, ibrí, _ליטע, dful,
   {{0x69c4be1f,0x7d04083e,0x3d1d00b7,0xf8bf003e}},	//   lbie, _mpis, मिते_, _bréf_,
   {{0x6ada009f,0x28e200b6,0x2bbf00a8,0xd25a00e5}},	//   _बटोर, _पिडि, ्रता, йци_,
   {{0x7d04305d,0x68e408ec,0x69c42ba3,0x07a37954}},	//   _opis, orid, nbie, _часн,
   {{0x624701ff,0x00000000,0x00000000,0x00000000}},	//   _iñol, --, --, --,
   {{0x645d013f,0x68e407bc,0x9ed8661b,0x99890128}},	//   _įsig, irid, омот_, njaš_,
   {{0x68e49305,0x7d040350,0x6d4009af,0xbddb001c}},	//   hrid, _apis, øman, dhèr,
   {{0x648d00e3,0x68e46073,0x69c4043f,0x7d04033c}},	//   núin, krid, jbie, _bpis,
   {{0x69c445c2,0x518308f9,0x6282641b,0x00000000}},	//   dbie, _пуша, _ikoo, --,
   {{0x2ca5be20,0x69c41d09,0xb4ba030b,0xbddb00fd}},	//   öld_, ebie, _अझै_, thès,
   {{0xd5cc22a3,0x68e4007a,0x3ffb00a1,0xaca30134}},	//   ाराज, erid, _הפוע, _nkụg,
   {{0x81de00c7,0xaa580b7b,0x6aa60063,0x67211912}},	//   দ্র_, пису_, _cikf, _šljo,
   {{0x68e4be21,0xdbd700c2,0x3eae0085,0x26d8173c}},	// [ea70] grid, tääk, _huft_, _avro_,
   {{0x37ab4d79,0xbddb00fd,0x69c4037a,0xa8141372}},	//   стан_, chèr, abie, ндуш,
   {{0x69c4be22,0x442b0019,0x68e400aa,0x212b0023}},	//   bbie, _đc_, arid, ̣ch_,
   {{0x6282be23,0xd246096a,0x00000000,0x00000000}},	//   _nkoo, _شن_, --, --,
   {{0x26d8be24,0x1c2200a5,0x3eae42f0,0x69cf01d3}},	//   _evro_, माचल_, _luft_, _iece,
   {{0x6282be25,0xd7f82ba7,0x0574015a,0x3cfc0327}},	//   _akoo, _нус_, راند, צלונ,
   {{0x69cf0496,0x61fb06c5,0x645d00c6,0x7dd801f9}},	//   _kece, tful, _įsid, núsí,
   {{0x69cf008a,0x2fce0154,0x26c1be26,0x244b00f3}},	//   _jece, _aefg_, mpho_, _døma_,
   {{0x61fb2085,0xfbbf09c4,0x93a7002d,0x26c10231}},	//   rful, ्राम, _ешед, lpho_,
   {{0x09aa17ff,0x69cfbe27,0x61fb0429,0x2be90096}},	//   _कल्य, _lece, sful, _जागू_,
   {{0x69dd2102,0x7d04be28,0x49140ed3,0x2d8c0034}},	//   _odse, _spis, _नैनो_, ędem_,
   {{0x69cf3d46,0x68e40206,0x3eaeae96,0x8cb202d5}},	//   _nece, yrid, _duft_, _इंदो,
   {{0x205557ff,0x629b028d,0xd1b80470,0x76ac026a}},	//   _откр, mmuo, _رانا_, _işye,
   {{0x69dd5070,0x7d0402dd,0x6289af5b,0x68e413ea}},	//   _adse, _vpis, lleo, vrid,
   {{0xdca30c43,0x7d040067,0x69c4be29,0xddcb005f}},	//   тари, _wpis, tbie, žišn,
   {{0x7ae10068,0x69cfbe2a,0xf99f05aa,0x26dc0206}},	//   álta, _cece, _obèd_, ávom_,
   {{0x7d0402e6,0x78a70ab2,0xda650190,0x68e4be2b}},	// [ea80] _upis, _bijv, رافي, urid,
   {{0xb8f643b2,0x69c4be2c,0x68e460c8,0xd884001c}},	//   _सब_, sbie, rrid, رهای,
   {{0x62897c82,0x69cf5d2e,0xe61a545b,0x68e4009c}},	//   kleo, _fece, жде_, srid,
   {{0xa3d005d4,0x69cfbe2d,0x5ee0034c,0xceb20142}},	//   _वजह_, _gece, _किस्_, דיא_,
   {{0xb33c00bd,0xe5a30e3a,0x15ff0179,0xf8bf033c}},	//   _igħi, вици, ोज़र_, _créd_,
   {{0x62820665,0xf1bf46b4,0xdb072e0e,0x22b501d3}},	//   _skoo, ñán_, rbjö, _sāka_,
   {{0x161904a9,0x628902ad,0xdb0500de,0xdb1c27d7}},	//   _नोकर_, fleo, _nghì, maró,
   {{0x37e30081,0xb33c03e5,0x41e60426,0x6289390f}},	//   ন্দর, _jgħi, фіка, gleo,
   {{0x95834a54,0x3f87008a,0x62820167,0x12770076}},	//   _алте, _aynu_, _vkoo, بحوث_,
   {{0xdb1c0037,0x00000000,0x00000000,0x00000000}},	//   naró, --, --, --,
   {{0x2bbf0be4,0x6289033c,0x6148003e,0x00000000}},	//   ्रसा, bleo, félö, --,
   {{0xbddb0257,0xb33c003d,0x212902ef,0x62890bee}},	//   thèq, _ngħi, _šahe_, cleo,
   {{0xdc3a0702,0x62805b64,0x3f8701ee,0x00000000}},	//   _açıl, momo, _eynu_, --,
   {{0x62803491,0x28b502d5,0xe167001c,0x7d1d02b6}},	//   lomo, _अंबि, _تضمی, rvss,
   {{0x200cbe2e,0x69cf2b75,0x78a701cb,0x8aa72f0c}},	//   medi_, _pece, _rijv, драд,
   {{0x1da71376,0xdb1200e3,0x200c2b95,0xdb17037a}},	//   _गणपत, ógái, ledi_, _sexó,
   {{0x69cf1155,0xb33c02a1,0xe8df020b,0x00000000}},	// [ea90] _vece, _dgħi, _thọc_, --,
   {{0x200cbe2f,0x62805de7,0x81e70033,0x00000000}},	//   nedi_, homo, ম্প_, --,
   {{0x6280479d,0x3ea96c3c,0x78a701c0,0xb8d6149b}},	//   komo, _kiat_, _vijv, _चू_,
   {{0xb93500c9,0x69dd052f,0x2bbf022d,0x7bd53581}},	//   _земј, _udse, ्रवा, lazu,
   {{0x6280a641,0x2ab502b6,0xe9df0031,0x645d00c6}},	//   domo, _håb_, _idú_, _įsib,
   {{0x200c0292,0x3ea92f6b,0xf8bf39d8,0x37c50037}},	//   jedi_, _liat_, _crée_, _سيرف,
   {{0x27f8025b,0xe784be30,0x68edbe31,0xdb1e6165}},	//   žený_, _ауто, luad, _sepú,
   {{0x3ea90496,0x6280013f,0xdb0500fe,0x81e70033}},	//   _niat_, gomo, _nghí, ম্ন_,
   {{0x9f5e0084,0x629b013f,0x25ad4700,0x2d8902ac}},	//   hetä_, rmuo, _igel_, _nyae_,
   {{0x1bee04a9,0x200c0b8b,0x62890634,0x629b10e0}},	//   _जाइल_, gedi_, sleo, smuo,
   {{0x6289be32,0x7bd5be33,0x00000000,0x00000000}},	//   pleo, dazu, --, --,
   {{0xf77200f5,0x248500f9,0x765903e0,0x3ea90172}},	//   רקט_, _hklm_, _çayı, _ciat_,
   {{0x61d600a1,0x200c2a1f,0x3ea94393,0x22ae007f}},	//   _נוסף_, bedi_, _diat_, _ręki_,
   {{0x68ed1f84,0x200cbe34,0x26dc0031,0x320d0188}},	//   duad, cedi_, ávok_, leey_,
   {{0xf8bf308d,0xa3c205d4,0x28e200b7,0x00000000}},	//   _até_, ूरत_, _पिहि, --,
   {{0xc33209c1,0xf2d200c1,0x629c0036,0x4ae10096}},	//   נון_, טעל_, _èrot, _फिरव,
   {{0x68ed26de,0x7bd510b1,0x97c600d3,0x4c8645b1}},	// [eaa0] guad, bazu, ейзе, _плив,
   {{0x6d46765e,0x7e666c54,0x7d5700ca,0x7bd500ae}},	//   myka, likp, _נייד_, cazu,
   {{0x6d460fe9,0xb33c003d,0xd7760037,0x27e70076}},	//   lyka, _tgħi, رائع, ónna_,
   {{0xdb1c0042,0xe802007a,0x68ed0231,0x00000000}},	//   saró, _रउवा_, buad, --,
   {{0x7c3e2281,0x68ed0fb6,0x69d69ae4,0x6280be35}},	//   _kopr, cuad, maye, vomo,
   {{0x28b51362,0x7c3e00d9,0x69d6be36,0x25ad0381}},	//   _अंति, _jopr, laye, _egel_,
   {{0x6fd605d4,0x62803f43,0xe8e000de,0x1bee0096}},	//   _मजबू, tomo, _ruột_, _जाईल_,
   {{0xd2572d03,0x69d623dc,0x7bd546e1,0x200cbe37}},	//   ець_, naye, zazu, wedi_,
   {{0x50662ca3,0x998003e5,0x7bd55046,0x200c026a}},	//   етна, jjiż_, yazu, tedi_,
   {{0x6280357c,0x69d6be38,0x3ea9be39,0x7c3ebe3a}},	//   somo, haye, _siat_, _nopr,
   {{0x442c08dc,0x200cbe3b,0x69d6be3c,0x6280be3d}},	//   _ind_, redi_, kaye, pomo,
   {{0x200c08d0,0x443e00a1,0x442cbe3e,0xa25a02a3}},	//   sedi_, _hot_, _hnd_, _عشاء_,
   {{0x443e2782,0x200cbe3f,0x38b600bb,0x5c07013d}},	//   _kot_, pedi_, _nær_, нява,
   {{0x31570130,0x7c3e1dbe,0xe8020469,0x7ae10103}},	//   _אידן_, _copr, र्मा_, álto,
   {{0x443ebe40,0x7c3e28d9,0x7bd53ccf,0xc4c400fb}},	//   _mot_, _dopr, razu, _گے_,
   {{0x69d6be41,0x443ebe42,0x98a700e7,0x38b608ca}},	//   gaye, _lot_, _điđa_, _bær_,
   {{0x442c02e0,0x6ca72887,0xc4c40068,0x6e2dbe43}},	// [eab0] _ond_, _прож, _دے_, _inab,
   {{0x443e004f,0x28e2007d,0x2bee00a5,0x68ed0cc2}},	//   _not_, _पिरि, _जाएं_, ruad,
   {{0xbbbf099d,0x68ed010a,0x69d6be44,0xe8020006}},	//   ्रीक, suad, baye, _रउरा_,
   {{0x442c7456,0x38b62e7b,0x69d6be45,0xb33c02a1}},	//   _and_, _fær_, caye, _jgħu,
   {{0x68edbe46,0x38b60088,0xcc3400d0,0x442c0085}},	//   quad, _gær_, _شریع, _bnd_,
   {{0x442c429e,0x7e6600e7,0xdddd007f,0x62470062}},	//   _cnd_, zikp, nisł, _iñoi,
   {{0x443e2b1d,0x6d46007f,0x6e2d063d,0x86f60103}},	//   _dot_, zyka, _onab, _لکنس_,
   {{0x442c00a1,0x6e2d1d30,0xd36e0037,0x25ad09bd}},	//   _end_, _nnab, تهى_, _ugel_,
   {{0x443ebe47,0x442c009c,0x320d008c,0x841500e5}},	//   _fot_, _fnd_, reey_, _имах,
   {{0x6e2dbe48,0x661bbe49,0x443ebe4a,0x644a48fc}},	//   _anab, _hauk, _got_, ckfi,
   {{0x661bbe4b,0xaca30294,0xdb1c0088,0xc7b2040a}},	//   _kauk, _chọg, jarð, יבי_,
   {{0x7c3ebe4c,0x2f540bb9,0x661b24e5,0x443ebe4d}},	//   _sopr, утьс, _jauk, _zot_,
   {{0x443e0154,0xb33c02a1,0x0d991402,0x661bbe4e}},	//   _yot_, _dgħu, етры_, _mauk,
   {{0x661bbe4f,0x69d6be50,0xc0e267a5,0x2d8c00d9}},	//   _lauk, waye, _тошк, āde_,
   {{0x38b60ac9,0xdb1c003e,0xaca30174,0x6b630086}},	//   _sær_, garð, _ghọg, акра,
   {{0x661bbe51,0x6d46147c,0x44fb0131,0x24500139}},	//   _nauk, pyka, kê_, _màma_,
   {{0x69d6be52,0xa3c12231,0x7aee9274,0x7c3e01e8}},	// [eac0] raye, ंडा_, subt, _topr,
   {{0x0b460002,0x69d6be53,0x38b60939,0x60db4638}},	//   _анон, saye, _vær_, isum,
   {{0x443ebe54,0x661b0d87,0x5c3700ca,0xf8bf014b}},	//   _rot_, _bauk, _סרטן_, _préc_,
   {{0x443ebe55,0x38b6be56,0x60db0673,0x442c4f85}},	//   _sot_, _tær_, ksum, _snd_,
   {{0x661bbe57,0x443ebe58,0x00000000,0x00000000}},	//   _dauk, _pot_, --, --,
   {{0x8d5b00a1,0x7d0902a5,0x76ac026a,0xdb1c77d4}},	//   וכני, çesi, _eşya, rbræ,
   {{0x443ebe59,0x442c0019,0xdbcd003e,0xa3c1034c}},	//   _vot_, _vnd_, _móðu, ंड़_,
   {{0x2450009c,0x661bb9b4,0x52142e0f,0xb88402c6}},	//   _dàma_, _gauk, удит, _dvíř,
   {{0x6fd605d4,0xd0100080,0x66024a02,0xb5050f36}},	//   _मजदू, ملة_, mfok, _مظلو,
   {{0x442cbe5a,0x6e2d070a,0x70540260,0x67210039}},	//   _und_, _snab, اندا, _šlji,
   {{0x7640be5b,0x1df9055b,0xd34500cd,0x661b2d17}},	//   _komy, нены_, _میوه_, _yauk,
   {{0xe80268b9,0xc8e20789,0xdd0e0f35,0xdb1c003e}},	//   र्ता_, _पिंट, िबंध_, varð,
   {{0xb884030b,0x764000f9,0x60db007e,0x3f82007f}},	//   _zvíř, _momy, csum, łku_,
   {{0x1dc30d61,0x60cd026a,0xbbbf0469,0x60c20027}},	//   _व्रत, _çama, ्रेक, _itom,
   {{0x7e640167,0x764001dc,0xb33c0090,0x6e3f00bd}},	//   _fmip, _oomy, _tgħu, _toqb,
   {{0x201c0103,0xf8bf00d1,0x2c6d00e7,0xba740037}},	//   _havi_, _aréa_, džde_, لاقت,
   {{0x201c2a1e,0x661b022a,0x1da73ec9,0x61e2be5c}},	// [ead0] _kavi_, _rauk, _गणित, _mdol,
   {{0x661bbe5d,0x201c00cb,0xdbcd0088,0x75224c54}},	//   _sauk, _javi_, _góðu, dvoz,
   {{0x61e2be5e,0x661b1eec,0x201cb64a,0x97a7ae6f}},	//   _odol, _pauk, _mavi_, трал,
   {{0x60c2be5f,0x201c0c56,0x61e2be60,0x60db1192}},	//   _otom, _lavi_, _ndol, ysum,
   {{0x66d90065,0x764008b6,0x752200c4,0x60c20415}},	//   _bùká, _domy, gvoz, _ntom,
   {{0x61e2be61,0x291903e5,0x39490270,0x661ba99b}},	//   _adol, _issa_, myas_, _wauk,
   {{0x60c2be62,0x661b634e,0x3949027f,0x3206020b}},	//   _atom, _tauk, lyas_, _bboy_,
   {{0x60db7397,0x21260167,0x76400154,0xdb1e0031}},	//   tsum, _broh_, _gomy, _nepý,
   {{0x201c00e9,0x39490a69,0x7fd507bf,0x00850fd6}},	//   _bavi_, nyas_, ліні, ллио,
   {{0xf4841eac,0x0495003f,0x2a6901bb,0x201c00e5}},	//   _кухн, _صلاح, hiab_, _cavi_,
   {{0x60dbbe63,0x201c0131,0x212603a9,0x60c21b99}},	//   ssum, _davi_, _eroh_, _etom,
   {{0x29195c3b,0x64412bd4,0x39494c6c,0x21260364}},	//   _ossa_, _holi, kyas_, _froh_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6441020d,0xfba50569,0x394951aa,0x61e21c5c}},	//   _joli, _गृहम, dyas_, _zdol,
   {{0x09e62877,0x2919294b,0x3ce90096,0x752213be}},	//   ловн, _assa_, _जिथे_, zvoz,
   {{0x6441484a,0x224d0103,0x7e64039f,0x1c0000aa}},	//   _loli, nkek_, _umip, _लउकल_,
   {{0x0e9b00a1,0x9e6501f9,0x6441026d,0x291900fc}},	// [eae0] _אשקל, _خاون, _ooli, _cssa_,
   {{0x6441be64,0x69cb003e,0x201c1d9f,0x25bf01c2}},	//   _noli, ðger, _xavi_, _aful_,
   {{0x2919a3dc,0x764000a5,0x224d0018,0x7bfb00c1}},	//   _essa_, _pomy, kkek_, _אפיצ,
   {{0xd01c0081,0x644101c2,0x31790034,0xdb1c09b5}},	//   তায়_, _aoli, ższy_, rbrä,
   {{0x64410f04,0x660250ef,0x04463574,0x752d0031}},	//   _boli, rfok, ледн, ťazn,
   {{0x2900411d,0x224d0167,0x9989173c,0x7d7b0142}},	//   mtia_, ekek_, ldaş_, ענסו,
   {{0x3d1640c1,0x290005fe,0x96969289,0x59b80789}},	//   _पैसे_, ltia_, _браш, _अलार,
   {{0x7791037f,0x6441099f,0x99890491,0x26dc00d4}},	//   _بیما, _eoli, ndaş_, ávou_,
   {{0x29008e8d,0xdb1c0131,0x3e6b0154,0x61e20147}},	//   ntia_, marõ, _lòtè_, _vdol,
   {{0x2900a464,0x224d01ff,0x64a6065c,0x93b500fe}},	//   itia_, akek_, _саза, _hãn,
   {{0xa3c1110f,0x290000c2,0xde5900d6,0x201c057a}},	//   ंडर_, htia_, вані_, _vavi_,
   {{0x2a6901fa,0x29000a19,0x00000000,0x00000000}},	//   xiab_, ktia_, --, --,
   {{0x60c2be65,0x201c2bbe,0x00000000,0x00000000}},	//   _utom, _tavi_, --, --,
   {{0x644143fa,0x6458be66,0x29190062,0x13d80033}},	//   _xoli, nhvi, _rssa_, _সাড়,
   {{0xce95013d,0x7ac4004d,0x2d840364,0xdb1c020d}},	//   _какъ, йсте, ümer_, ncrè,
   {{0x7ae8315d,0x00000000,0x00000000,0x00000000}},	//   ádta, --, --, --,
   {{0x52d109d0,0x19580109,0x00000000,0x00000000}},	// [eaf0] _सब्स, гаты_, --, --,
   {{0x7d0db408,0x2a690197,0x00000000,0x00000000}},	//   _ipas, siab_, --, --,
   {{0x6441be67,0xdb1e0b0b,0x2900be68,0x8d740470}},	//   _roli, _depó, atia_, _نایا,
   {{0x2bbf3245,0x6441226a,0x7d0d0134,0x394906a8}},	//   ्रका, _soli, _kpas, pyas_,
   {{0xa3c1000f,0x2900002d,0x291902ac,0x6d5d0539}},	//   ंडल_, ctia_, _ussa_, nzsa,
   {{0x80c300c7,0x68ed01b5,0x67210a9e,0x97d803ef}},	//   _শিল্, mrad, _šlju, _مظفر_,
   {{0x6441419a,0x68edbe69,0x7bd70072,0xd3d80604}},	//   _voli, lrad, _mexu, ابها_,
   {{0xc245b643,0x7bd74f65,0x68ed0a02,0x69cd1df6}},	//   рник, _lexu, orad, nbae,
   {{0x68edbe6a,0x64414160,0xe0d60895,0x6ec100d9}},	//   nrad, _toli, авы_, _mēbe,
   {{0x68edbe6b,0xaf051689,0x3e6f007b,0x7529be6c}},	//   irad, апол, yötä_, _irez,
   {{0x68ed0897,0xd37100e3,0x7d0d7ab9,0x7f7542b9}},	//   hrad, _بها_, _apas, рупц,
   {{0x68edbe6d,0xd13100e3,0x752930d1,0x76590150}},	//   krad, _وما_, _krez, nhwy,
   {{0x68ed16aa,0x463a006e,0x52840037,0x628b039f}},	//   jrad, דערע, _النك, _ikgo,
   {{0x8fa51c03,0x752901ac,0xa069129e,0xbc1901ce}},	//   _кале, _mrez, _шала_, лісі_,
   {{0x05d5110f,0x6609be6e,0xdb1ebe6f,0x60c90120}},	//   दराब, _obek, _repó, lpem,
   {{0x2900be70,0x68edbe71,0xdb1cbe72,0x7529be73}},	//   ttia_, frad, ncré, _orez,
   {{0x68ed1cf5,0x98e60037,0x99891e6b,0x69230231}},	// [eb00] grad, شكاو, rdaş_, омта,
   {{0x60c9025a,0x29004bf4,0xdb1e02f1,0x6609be74}},	//   ipem, rtia_, _depò, _abek,
   {{0x7bdc94e8,0x7529be75,0x68edbe76,0xb87b02c6}},	//   maru, _arez, arad, _svíc,
   {{0x75295007,0x8f9a00a1,0xa526282a,0x290000ae}},	//   _brez, דיעי, имед, ptia_,
   {{0x6aa43069,0x68910068,0x7529be77,0x7bd701fa}},	//   mmif, _کیلئ, _crez, _yexu,
   {{0x240700ae,0x3ce900a5,0xd90d00cd,0x75299b50}},	//   инчи_, _जिसे_, _سیم_, _drez,
   {{0x66e35aa7,0x7529404c,0xe3cf0033,0xe7370131}},	//   _мора, _erez, _রাখব, _кер_,
   {{0x76595345,0x7bdc39fb,0xe8140378,0x67020174}},	//   chwy, haru, ड़वा_, _ọkwe,
   {{0x7bdcbe78,0x752912fa,0x7aee0087,0x6247037a}},	//   karu, _grez, hrbt, _años,
   {{0x660991ce,0x7bdc0e69,0xa2e63a69,0xcfa605cb}},	//   _zbek, jaru, _вожд, ишни,
   {{0x7d0d0335,0x68ed038d,0x7bd703be,0xf99f05aa}},	//   _spas, zrad, _rexu, _abèl_,
   {{0xe4db030b,0x6aa4023b,0xd186345a,0x6d222235}},	//   zšíř, jmif, _клей, मिंग_,
   {{0x7bdcbe79,0x224b042c,0x00000000,0x00000000}},	//   faru, öcke_, --, --,
   {{0x7bdcbe7a,0x7c870870,0x248c00dc,0x68edbe7b}},	//   garu, руме, _jkdm_, vrad,
   {{0xc5d70081,0x6fcc0285,0x624701c8,0xaa67a283}},	//   _হাসপ, _द्यू, _iñor, атак,
   {{0x0f5700ca,0x645d0138,0x2459020d,0x25a000d2}},	//   _כיום_, _įsim, _ième_, žily_,
   {{0x7bdc7303,0x7d0dbe7c,0x69cd00dc,0x68edbe7d}},	// [eb10] baru, _upas, rbae, urad,
   {{0x752900dd,0x7bdc00d3,0xe80200a8,0x00000000}},	//   _rrez, caru, र्ला_, --,
   {{0xd12614df,0x68ed0149,0xfbd200a1,0xc6a72383}},	//   _کم_, srad, _מתי_, арди,
   {{0x68edbe7e,0x569500c2,0x2459014b,0xb55900d3}},	//   prad, щает, _mème_, лиеф_,
   {{0xf8bf1e6f,0xe7f00251,0x42e30033,0x68ed54fa}},	//   _krém_, _चाचा_, _মহেশ, qrad,
   {{0x75296a76,0x58d40dfb,0x00000000,0x00000000}},	//   _vrez, _форт, --, --,
   {{0x03a500c2,0x7af501c8,0x00000000,0x00000000}},	//   щико, nuzt, --, --,
   {{0xeb7800a1,0x7bdcbe7f,0x75292250,0x07d80018}},	//   יעוץ_, zaru, _trez, _مذہب_,
   {{0x0fd9022c,0x7bdc0875,0x60c9be80,0x00000000}},	//   льны_, yaru, upem, --,
   {{0xdb1c06ad,0x7bdc044c,0x7af501ff,0x00000000}},	//   scré, xaru, kuzt, --,
   {{0x33950308,0x0eaa007b,0x69c10154,0x00000000}},	//   _الاز, лкой_, _ğlen, --,
   {{0x60c9be81,0x7bdc8ad0,0x6284031a,0x3e720d7c}},	//   ppem, waru, čioc, kšte_,
   {{0x645d00c6,0xd0090307,0x00000000,0x00000000}},	//   _įsij, _беле_, --, --,
   {{0xfbc31543,0x24590154,0x9f5e02c6,0x0c7900c2}},	//   збро, _fème_, letý_, ассы_,
   {{0x7bdc8f13,0x200201d4,0x3e720206,0x7af501ff}},	//   raru, əki_, ešte_, guzt,
   {{0x7bdcbe82,0xe1f9013f,0xc33200a1,0xe8e00019}},	//   saru, ngų_, הול_, _suốt_,
   {{0xe8140251,0x00000000,0x00000000,0x00000000}},	// [eb20] ड़ला_, --, --, --,
   {{0xe73a0a54,0x00000000,0x00000000,0x00000000}},	//   лез_, --, --, --,
   {{0xbc680068,0xfa6a3168,0x3ea007ac,0x648d0037}},	//   _مجھے_, _банк_, _khit_, húis,
   {{0x54e60037,0x00000000,0x00000000,0x00000000}},	//   مستق, --, --, --,
   {{0xd625054f,0xe3cf0033,0x22b50a84,0xe8e000fe}},	//   تعلي, _রাজব, _māku_, _tuốt_,
   {{0x68460b11,0xe85603ef,0x53341cf2,0x00000000}},	//   _унга, _انسد, жект, --,
   {{0xdb1c02b6,0xb7db00d7,0x00000000,0x00000000}},	//   gbrø, _תקלי, --, --,
   {{0x3ce900a5,0xd257055b,0x00000000,0x00000000}},	//   _जिले_, йцы_, --, --,
   {{0xdfd0054f,0x6fe2000d,0xb6a34460,0xdbda0131}},	//   وية_, jící, _хитл, nçói,
   {{0x3ea04228,0xe1f90138,0xdce401d3,0x50b70037}},	//   _ahit_, agų_, _dziļ, حديد_,
   {{0xe2ca0020,0x20020067,0x3ea0009c,0xbfaa00c2}},	//   _след_, ęki_, _bhit_, ытие_,
   {{0x877b0089,0x539b0327,0xa3c20179,0x00000000}},	//   ראטי, _גיבו, ूरक_, --,
   {{0x3ea0009c,0x8cd4023a,0x00000000,0x00000000}},	//   _dhit_, बीलो, --, --,
   {{0x7af503f3,0x3a220174,0x645d0138,0x998919d0}},	//   tuzt, _aakp_, _įsik, tjaž_,
   {{0x22466bc5,0x78a90036,0x00000000,0x00000000}},	//   _kook_, _èevi, --, --,
   {{0x78ba030b,0x3ea00072,0x386a03a8,0x7af501ff}},	//   _čtvr, _ghit_, _ambr_, ruzt,
   {{0x3e7209ac,0x224645cd,0x00000000,0x00000000}},	// [eb30] ušte_, _mook_, --, --,
   {{0x2246451f,0x261300de,0x5c7516e6,0x44d60034}},	//   _look_, _ảo_, _флот, dł_,
   {{0x625c6c52,0xe1f90138,0xb09b00ca,0x38ad00c4}},	//   _géog, ygų_, ניבר, _hžrk_,
   {{0x3e72175b,0x9f5e037a,0x7e6f014b,0x00000000}},	//   pšte_, letó_, nicp, --,
   {{0x22be0134,0x69df019f,0x26c70138,0x2d80014b}},	//   _ọkpa_, maqe, ūno_, _xxie_,
   {{0x386a1d49,0x00000000,0x00000000,0x00000000}},	//   _gmbr_, --, --, --,
   {{0x44d60067,0x224600a1,0x00000000,0x00000000}},	//   ał_, _book_, --, --,
   {{0xe1f9013f,0x69df023b,0x2246852b,0x24500441}},	//   ugų_, naqe, _cook_, _làmh_,
   {{0x212bbe83,0xe1f900c6,0x224601cb,0xaef20033}},	//   ích_, rgų_, _dook_, _জনগণ_,
   {{0x94770b9f,0x648d0076,0x245001ec,0x22b500e8}},	//   _ادرا, rúis, _nàmh_, _sāku_,
   {{0xe80b00e2,0x244b01df,0x53340c79,0x4375001c}},	//   स्या_, _dømt_, _нефт, _بهار,
   {{0x59a902d5,0xa6e2003e,0x00000000,0x00000000}},	//   कधार, æðil, --, --,
   {{0x80c30f71,0xafe500c2,0x28b56afb,0xdb0a0031}},	//   _শিক্, _долл, _अंगि, ľník,
   {{0x61fbbe84,0xf1b20341,0xdb0a1054,0xb87b01cd}},	//   lgul, _חסד_, žník, _svín,
   {{0x69df023b,0x3ea07534,0x6fe202c6,0x3ce606eb}},	//   faqe, _thit_, sící, _झटके_,
   {{0x61fb2b7f,0x3ced01ac,0x49ca001f,0x31af03e0}},	//   ngul, ševa_, рлан_, _gözü_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [eb40] --, --, --, --,
   {{0xd37800e7,0x7d0400bd,0x60c40231,0x00000000}},	//   _heće_, _iqis, _éime, --,
   {{0x2bd013b4,0x6e240256,0x69df2e74,0x00000000}},	//   _त्या, _kaib, baqe, --,
   {{0xb87b003e,0x452a015f,0x645f0216,0xdb1c0231}},	//   _hvíl, ижен_, ëqin, ncrí,
   {{0x6e241ba1,0x22468363,0x29040052,0xe4a6294a}},	//   _maib, _rook_, _ëma_, орко,
   {{0x68e4038b,0x6e245d90,0xc1d2009d,0x2246005c}},	//   msid, _laib, सर्ग, _sook_,
   {{0xd25a1756,0x68e40f05,0x22460bb6,0xdddd0031}},	//   ици_, lsid, _pook_, losť,
   {{0xd37802e6,0x61fb0283,0x6e24be85,0x69c4411b}},	//   _neće_, ggul, _naib, ncie,
   {{0x68e4be86,0xdddd0220,0x22b501d3,0x73360103}},	//   nsid, nosť, _sākt_, _ڈرائ,
   {{0x31af07aa,0x22460da7,0x61fb7291,0x6e240381}},	//   _sözü_, _wook_, agul, _aaib,
   {{0x38170054,0x6e24be87,0xd7bb0341,0x224600ca}},	//   חקים_, _baib, יציר, _took_,
   {{0x6448be88,0x6e24152f,0x6fd60096,0x69c40034}},	//   _hodi, _caib, _मजकू, jcie,
   {{0x61e00587,0x6e240441,0x64483763,0xa3be0285}},	//   maml, _daib, _kodi, _इला_,
   {{0x6448be89,0xd14900d0,0xd00f00e3,0x68e40b81}},	//   _jodi, _دشمن_, _لله_, dsid,
   {{0x6448620a,0x68e49000,0x6e240257,0x9f5e5b8f}},	//   _modi, esid, _faib, retó_,
   {{0xddc40b88,0x6e24a4da,0xfbd00018,0x00000000}},	//   _iliş, _gaib, فتہ_, --,
   {{0x69df023b,0x68e4be8a,0x7e6dbe8b,0x7cf100a7}},	// [eb50] raqe, gsid, _imap, _qırğ,
   {{0x64481be6,0xf72b7f94,0xb5fd02ef,0x61e0bca9}},	//   _nodi, ицей_, _imši, haml,
   {{0x87e40084,0xe3d80081,0x501b00a1,0x61e031c2}},	//   ьюте, _সাংব, שובו, kaml,
   {{0x69c4183b,0x645a4890,0x644801b9,0xfb1a00ca}},	//   ccie, _alti, _aodi, _פורמ,
   {{0x672e0222,0x7c25026a,0x69dd00ae,0x26d82903}},	//   _erbj, _kahr, _iese, _ewro_,
   {{0x7c2502dc,0x6448be8c,0xbbb9030b,0xe787513f}},	//   _jahr, _codi, _आलोक, _дубо,
   {{0x69dd1bd6,0x644803ce,0xd6c300bf,0x99990220}},	//   _kese, _dodi, _آمری, _dosť_,
   {{0x64480167,0x61e001a8,0xe0d900c2,0x78bd02ac}},	//   _eodi, gaml, бви_, _kusv,
   {{0xe80b06ae,0x69dd3f38,0x6e24054f,0x41b500fb}},	//   स्था_, _mese, _raib, _ہمار,
   {{0x644802e6,0x7c251b32,0x6e24be8d,0x7e6d6eb8}},	//   _godi, _nahr, _saib, _amap,
   {{0x69c400a5,0x442502a1,0x6e240270,0xa207008b}},	//   ycie, _ial_, _paib, şmış_,
   {{0x64430335,0x69ddbe8e,0x4425be8f,0xe80b2fc2}},	//   ljni, _nese, _hal_, स्ता_,
   {{0xd37800e9,0x4425be90,0x7c25049e,0x6e244533}},	//   _veće_, _kal_, _bahr, _vaib,
   {{0xb0420019,0xdb1cbe91,0x78b500cc,0x8b0800b6}},	//   _thưở, scrí, _nizv, jdří,
   {{0x4425be92,0x69dd9743,0x765bbe93,0x09b403a2}},	//   _mal_, _bese, _oluy, ंख्य,
   {{0x78b500d9,0x69ddbe94,0x69c400d9,0x68e41a5b}},	//   _aizv, _cese, ucie, tsid,
   {{0x7c2502dc,0x69c4be95,0x672e007e,0x38cb0281}},	// [eb60] _fahr, rcie, _srbj, مالی_,
   {{0x68e421ad,0x69c44820,0x397902ec,0xc07900de}},	//   rsid, scie, істю_, _điệp_,
   {{0x68e4be96,0x69ddbe97,0x3bbb00a1,0xe8020b7f}},	//   ssid, _fese, _למיד, र्गा_,
   {{0x6448be98,0x69dd2cfe,0x7c250343,0x44250188}},	//   _sodi, _gese, _zahr, _aal_,
   {{0x7bde113a,0x27e155bf,0x225fbe99,0x61e003e0}},	//   _kepu, bahn_, dhuk_, vaml,
   {{0x44257544,0x7bde18c4,0x64482ada,0x6abe4fd9}},	//   _cal_, _jepu, _qodi, _kupf,
   {{0x4425be9a,0x7bde0134,0xdb1c5cee,0x69dd0adf}},	//   _dal_, _mepu, mbró, _yese,
   {{0x7bde4311,0x765b0113,0xcb130327,0x6abe0079}},	//   _lepu, _gluy, גלה_, _mupf,
   {{0x4425be9b,0x64485e04,0x61e0be9c,0x645d0138}},	//   _fal_, _todi, raml, _įsiv,
   {{0x4425be9d,0x645a9ed8,0x61e04a75,0x7e6d0124}},	//   _gal_, _ulti, saml, _smap,
   {{0xd9a901e4,0x6abe0169,0x00000000,0x00000000}},	//   _कण्ट, _nupf, --, --,
   {{0x4425104f,0x7c25be9e,0x61e0013c,0x225f67e9}},	//   _zal_, _sahr, qaml, chuk_,
   {{0x69ddbe9f,0x44255148,0x7c250063,0x7bde02ac}},	//   _rese, _yal_, _pahr, _bepu,
   {{0x69dd14f7,0x3ced08a9,0x4425448b,0x7bde01d3}},	//   _sese, ševo_, _xal_, _cepu,
   {{0x7bdebea0,0x69dd0498,0x78b53343,0x9f620084}},	//   _depu, _pese, _rizv, ävän_,
   {{0x7c2502e2,0x7e6d55c7,0x2f9700ca,0x6abe05bd}},	//   _wahr, _umap, _מכון_, _dupf,
   {{0x69ddbea1,0xda1e17e5,0xf4d70033,0x6443007f}},	// [eb70] _vese, _पसरत_, _সম্ব, yjni,
   {{0x69dd10a5,0x7bde03ee,0x765b05c2,0x00000000}},	//   _wese, _gepu, _sluy, --,
   {{0xe71900e3,0xc0530341,0x69ddbea2,0x6abe0193}},	//   تيات_, עזע_, _tese, _gupf,
   {{0x4425bea3,0x2a603fe9,0x7e7dbea4,0xa3cf009d}},	//   _sal_, chib_, nnsp, वुन_,
   {{0x442506f5,0x78b50090,0x00000000,0x00000000}},	//   _pal_, _tizv, --, --,
   {{0x4425003d,0x3a290270,0xe3b1001c,0xa49301f9}},	//   _qal_, ldap_, پرت_, ریات,
   {{0x44253c86,0x290900c2,0xd5fb00fe,0x644302c3}},	//   _val_, ltaa_, _chụ, rjni,
   {{0x569432ac,0x3a290533,0xddc44072,0xf8bf01dc}},	//   _заст, ndap_, _omiš, _kué_,
   {{0x2909676d,0x4425052e,0x442700ec,0x00000000}},	//   ntaa_, _tal_, pdn_, --,
   {{0xaec50731,0xb95b0139,0x2a600063,0x4425298e}},	//   мбол, _afìk, zhib_, _ual_,
   {{0x29090084,0x7bdebea5,0x3ce90154,0x2f5400ae}},	//   htaa_, _repu, _avav_, етяс,
   {{0x7bde0cd0,0x2a605d91,0x1ee70068,0xdb1c0364}},	//   _sepu, xhib_, _ہوتی_, rbrü,
   {{0x7bde2d0e,0x2d84bea6,0x2fc70113,0x00000000}},	//   _pepu, çme_, _tfng_, --,
   {{0x78600068,0x394001fa,0x7e7d18f0,0x3952007b}},	//   _köve, vxis_, ansp, vyys_,
   {{0x41d10454,0xa3e50ccb,0xab270c58,0xa3c5152c}},	//   _सभास, _भजन_, мора_, _एलन_,
   {{0xe80b14e5,0x7bde0294,0x2909346f,0x394000b3}},	//   स्सा_, _wepu, ftaa_, txis_,
   {{0x7bde39a0,0x29090188,0xf8bf034f,0x00000000}},	// [eb80] _tepu, gtaa_, _cué_, --,
   {{0x2a601a4a,0xd37804e9,0x7bde0350,0x60cd0233}},	//   shib_, _leća_, _uepu, _çamu,
   {{0x78600018,0xdb1c00e3,0xb6c50c10,0x395200c2}},	//   _növe, rbró, есій, syys_,
   {{0xe80200a3,0x7afc0847,0xf8bf05e6,0x29090188}},	//   र्जा_, murt, _fué_, btaa_,
   {{0x69d6bea7,0x94aa3e1e,0x1fe30081,0x7afc01c8}},	//   mbye, отка_, _মানস, lurt,
   {{0xa6e20088,0x3e720138,0xd5fb00fe,0x628400c6}},	//   æðsl, kšto_, _phụ, čiom,
   {{0xe803009f,0x645d0138,0x00000000,0x00000000}},	//   _लाता_, _įsit, --, --,
   {{0x30ea0eea,0xc7a308d8,0x69d602f1,0x721700e5}},	//   офон_, _риск, nbye, джър_,
   {{0xf503013d,0x7afcbea8,0x23cf000c,0x53cf1bc3}},	//   _изто, hurt, _स्वद, _स्वश,
   {{0x7afcbea9,0xe8023245,0xc057004d,0x3dc902a1}},	//   kurt, र्चा_, дію_, _sfaw_,
   {{0xe810009d,0xddc40106,0x21290dd9,0x227901f3}},	//   ठ्या_, _smiš, _šaht_, _کلنگ_,
   {{0x7afc77f3,0xc7b300ca,0x68f65759,0x6458beaa}},	//   durt, כבת_, kryd, lkvi,
   {{0x5066133d,0x7e7d2c28,0xed5801b3,0x60170294}},	//   _отка, rnsp, доў_, ụmak,
   {{0xe57100c1,0xd6df0034,0x00000000,0x00000000}},	//   אַל_, ółka_, --, --,
   {{0x7afcbeab,0xa2d200a4,0xd5de1e05,0x9e670076}},	//   gurt, णीच्, मराज, _يابن,
   {{0x29090d64,0x786001d4,0xe8020557,0x6282010a}},	//   ttaa_, _növb, र्घा_, _jjoo,
   {{0xf8bf0eb8,0xa3cf8380,0xaca30174,0x3a29beac}},	// [eb90] _qué_, वुड_, _ajụg, rdap_,
   {{0x2909676d,0x5c742a6a,0x7afc6232,0xb8f7007a}},	//   rtaa_, _альт, burt, _सऽ_,
   {{0x29090d64,0x0c740b3d,0x8bd60054,0x62840138}},	//   staa_, _جديد, _אותו_, čioj,
   {{0x68f6bead,0xfe1000de,0xf8bf00fd,0x2c6d02ef}},	//   bryd, _lắng_, _tué_, dždi_,
   {{0xe5040037,0x6aad07ee,0xceb400ca,0x00000000}},	//   نبوي, mmaf, דיף_, --,
   {{0x03a51995,0xfe100019,0x62823eb3,0xd378049c}},	//   нило, _nắng_, _ajoo, _seća_,
   {{0xd37800c4,0x00000000,0x00000000,0x00000000}},	//   _peća_, --, --, --,
   {{0xe8100ff9,0x65954441,0xfbb800a1,0x00000000}},	//   ठ्ठा_, _забу, ופות_, --,
   {{0xd37802e6,0xf1b90dd9,0xf8bf0139,0xafe50392}},	//   _veća_, ješe_, _irés_, нопл,
   {{0x60092f17,0x645806c5,0x752d0220,0x62820172}},	//   чном_, ckvi, ťazs, _ejoo,
   {{0xbcfb0068,0xe3b32761,0x7d16beae,0x00000000}},	//   szél, _شرط_, _spys, --,
   {{0x3f9901d3,0x3e7200c6,0x2d96022a,0x00000000}},	//   āsu_, ršto_, ергс, --,
   {{0xee371eac,0x7afc0022,0x916c020b,0x00000000}},	//   хня_, wurt, _gồm_, --,
   {{0x7afcbeaf,0xe0060b89,0xfe1000de,0x629b0150}},	//   turt, _शायद_, _gắng_, lluo,
   {{0x1e961a18,0x6fd524eb,0xdca3002d,0x3f79006e}},	//   _прир, _म्यू, уари, _מאַס,
   {{0x3dda0081,0x2bd00296,0x68f6beb0,0x7afc5eb1}},	//   _থাকল, _त्रा, tryd, rurt,
   {{0xe8fa0805,0x6a8309b9,0x65b62326,0x7afc25a8}},	// [eba0] яла_, улта, _mühü, surt,
   {{0xb88218ed,0x7afcbeb1,0x69d601df,0x625c020d}},	//   _čísl, purt, sbye, _néon,
   {{0xe61a2914,0x00000000,0x00000000,0x00000000}},	//   зде_, --, --, --,
   {{0x98a0015c,0x550605b8,0x68f62feb,0xd946162b}},	//   kvić_, ечка, pryd, _земи,
   {{0xad9b3ce8,0x26c50113,0x645814f3,0x645d00c6}},	//   lfúr, _élon_, tkvi, _įsir,
   {{0xdceb0106,0xd4671012,0x0443277b,0xb4e000c3}},	//   šićn, ниче_, лечн, _दबी_,
   {{0xc79501b3,0x64580d8e,0x625c020d,0x07a360dc}},	//   _арты, rkvi, _déon, _барн,
   {{0x179b0341,0xa50a1c03,0xf99f0139,0xf8bf00fe}},	//   _זילב, _неба_, _gbès_, _trét_,
   {{0xe0cf00d0,0xc4863967,0x98a000c4,0x00000000}},	//   یزی_, _злак, gvić_, --,
   {{0x66020103,0x75222ae7,0x00000000,0x00000000}},	//   lgok, mwoz, --, --,
   {{0x81df0f71,0x1df91119,0xfe1000de,0x3f9801cd}},	//   _তার_, мены_, _vắng_, æru_,
   {{0x6602067d,0xd37802ef,0x518600ae,0x00000000}},	//   ngok, _hećo_, _пула, --,
   {{0xfe6e1e49,0xa32000c3,0x00000000,0x00000000}},	//   تگو_, _मनुज_, --, --,
   {{0x212601dc,0x61e25a43,0x00000000,0x00000000}},	//   _isoh_, _heol, --, --,
   {{0x60c202fd,0xfaa75ac0,0xab950acf,0x8aa77cbf}},	//   _huom, ешан, тиві, ерад,
   {{0x201ebeb2,0x60c2b3c0,0x66e700b6,0x26c70031}},	//   leti_, _kuom, _léká, ínom_,
   {{0x60c200c2,0x6280084e,0x00000000,0x00000000}},	// [ebb0] _juom, inmo, --, --,
   {{0x201ebeb3,0x61e29332,0x3b55002d,0x60c20a4b}},	//   neti_, _leol, _акор, _muom,
   {{0x3ea92fcf,0x60c200c2,0x629b0124,0xf8bf5635}},	//   _khat_, _luom, yluo, _prés_,
   {{0xfb1a07d9,0xd5750a18,0x201ebeb4,0x6280029a}},	//   _کریں_, куль, heti_, jnmo,
   {{0x60c201b3,0x5a342c37,0x3a2b0036,0x00000000}},	//   _nuom, _снят, _iacp_, --,
   {{0x201ebeb5,0x3ea907ac,0x62800381,0x66020634}},	//   jeti_, _lhat_, enmo, agok,
   {{0xf8bf00fd,0xe78405e1,0x21260154,0x5c3800ca}},	//   _trés_, _буто, _asoh_, תרון_,
   {{0x3ea90019,0x61e20037,0x629b82ed,0x00000000}},	//   _nhat_, _ceol, uluo, --,
   {{0x60c20036,0x201ebeb6,0xd24e0190,0x00000000}},	//   _cuom, feti_, تني_, --,
   {{0x85740f2e,0x60c2013f,0x201e658d,0x62807d57}},	//   _слух, _duom, geti_, anmo,
   {{0x2608000d,0x200b00a5,0xf1d213ae,0x41d206ec}},	//   _हामी_, ęci_, _ध्वन, _ध्वस,
   {{0x27e303e5,0x3ea97d1f,0x26c3005f,0x3a2b0350}},	//   _lejn_, _chat_, _mujo_, _nacp_,
   {{0x201ebeb7,0x26fe02b0,0x26c30033,0x60c203e3}},	//   beti_, _उम्र_, _lujo_, _guom,
   {{0x201ebeb8,0x68ff00a7,0x9f450216,0xb4fa00ca}},	//   ceti_, duqd, nalë_, ופשי,
   {{0xfe0a0b89,0x09e617e9,0xeb97117c,0x00000000}},	//   _वापस_, ковн, вир_, --,
   {{0xc33200a1,0x61e203be,0x2c6d02ef,0xc0b900b6}},	//   סון_, _xeol, dždu_, řádá,
   {{0x27e303e5,0xad9b08a8,0xa8062f68,0x26d10a00}},	// [ebc0] _bejn_, lgún, кзал, _atzo_,
   {{0x29190270,0x7d570266,0xed5700ca,0xbc6a0d7f}},	//   _dpsa_, _סייד_, _סביר_, _آمدن_,
   {{0x7c3e0a00,0xb8e90378,0x26c30161,0x27e30078}},	//   _inpr, _लू_, _cujo_, _dejn_,
   {{0x201ebeb9,0x3ce00383,0xc6080a43,0x00000000}},	//   zeti_, _kwiv_, _রোজা_, --,
   {{0x27e304f9,0x61e20150,0x201e42ec,0x2d8f052f}},	//   _fejn_, _reol, yeti_, _øget_,
   {{0x61e2beba,0x29000051,0x26c30239,0x7c2e4bf9}},	//   _seol, muia_, _fujo_, ndbr,
   {{0x60c20d64,0x201ebebb,0xf7432753,0x61e29aa5}},	//   _suom, veti_, _керо, _peol,
   {{0x3ced0335,0x78bc0084,0x625c06aa,0x201e406e}},	//   ševi_, _hirv, _géol, weti_,
   {{0x201ebebc,0x62800149,0x30a60d9b,0x78bc65d3}},	//   teti_, rnmo, кров, _kirv,
   {{0x27e303e5,0xb4250688,0x3dc000f9,0x3ea95ce9}},	//   _xejn_, _معمو, _agiw_, _shat_,
   {{0x442c4450,0x3ea900de,0x5226002d,0x443eaac5}},	//   _iad_, _phat_, _афла, _int_,
   {{0x442c3220,0x60c22787,0xb87b0088,0x7c3e0c05}},	//   _had_, _tuom, _hvít, _anpr,
   {{0x442cbebd,0x201e7c3a,0xc69300ca,0x7c2e0381}},	//   _kad_, peti_, שאר_, fdbr,
   {{0x3ea9004f,0xd01052c6,0x442cbebe,0x5f73001c}},	//   _what_, _طلب_, _jad_, اایر,
   {{0x3ea91723,0x7ac40606,0xa3200006,0xefb000bf}},	//   _that_, исте, _मनोज_, _دیدگ,
   {{0x442c01c5,0x7c3eaf9f,0xb1130174,0x443e01d3}},	//   _lad_, _enpr, _mụnw, _lnt_,
   {{0x443ebebf,0x2d8f0257,0x78bc02ef,0x29001f4a}},	// [ebd0] _ont_, _âge_, _birv, guia_,
   {{0xf1b924e5,0x443e00dc,0x7d0d25f5,0x26c300ee}},	//   neša_, _nnt_, _iqas, _pujo_,
   {{0x6e2dbec0,0x2bd904f8,0x442e0150,0x78bc1a5c}},	//   _kaab, _ब्या, ddf_, _dirv,
   {{0x442c025e,0x443ebec1,0x290000d3,0x41b40d77}},	//   _aad_, _ant_, buia_, ुशास,
   {{0x6e2d434b,0x442c0703,0x7d0d00bd,0x2900044c}},	//   _maab, _bad_, _jqas, cuia_,
   {{0x442c0422,0x81df00c7,0x443e2b39,0x26080ed3}},	//   _cad_, _তাই_, _cnt_, _हाथी_,
   {{0x68ed118e,0xe299bec2,0xaca30134,0x442c59dd}},	//   lsad, нак_, _nkọg, _dad_,
   {{0x78bc0491,0x6e2db09a,0xb87b0072,0x442c0131}},	//   _zirv, _naab, _evít, _ead_,
   {{0x68ed75a2,0x442c0514,0x6abd03f5,0x3e620037}},	//   nsad, _fad_, _misf, _nóta_,
   {{0x442cbec3,0x68ed001f,0xd7aa07d5,0x443e1e7d}},	//   _gad_, isad, _करमच, _gnt_,
   {{0x6e2d0b6c,0x29000010,0x3ce006a3,0x8ff900cd}},	//   _baab, zuia_, _swiv_, ورگر_,
   {{0x68ed0b85,0x6abdbec4,0x6e2d0188,0x9f450146}},	//   ksad, _nisf, _caab, nalé_,
   {{0x6e2d546d,0x442c00a7,0x443e0233,0xf1b900c4}},	//   _daab, _yad_, _ynt_, beša_,
   {{0x68ed008a,0x442c0188,0x61e900b7,0x6abd0503}},	//   dsad, _xad_, lael, _aisf,
   {{0x660904a3,0x7c2e87d8,0x6e2dbec5,0x6abd07ee}},	//   _ocek, rdbr, _faab, _bisf,
   {{0x78bc3082,0x6e2d1ed1,0x61e90051,0x6f010034}},	//   _sirv, _gaab, nael, mulc,
   {{0x6abd3a2f,0x7e64b30d,0x3863005c,0x2d8501e8}},	// [ebe0] _disf, _ilip, _bljr_, şler_,
   {{0x61e9bec6,0x20c900de,0x290000d3,0x2bd00592}},	//   hael, _múi_, ruia_, तुशा,
   {{0x7e642fc6,0xb87b9954,0x6e2d3fdc,0x7bdc9715}},	//   _klip, _avís, _yaab, mbru,
   {{0x68ed008a,0xb87b00b6,0x6b7b22fe,0x62990134}},	//   bsad, _svít, _טרינ, _nkwo,
   {{0x2900642b,0x442cbec7,0x24f682e2,0x20c90019}},	//   quia_, _pad_, учер, _núi_,
   {{0x7bdc51d9,0x6299768f,0x442c5b02,0x443e02a0}},	//   nbru, _akwo, _qad_, _qnt_,
   {{0x442cbec8,0x2c160ff9,0x443e0138,0x75297d91}},	//   _vad_, द्यं_, _vnt_, _esez,
   {{0x442c7a11,0x32546321,0x61e9bec9,0x82a600c2}},	//   _wad_, рвир, gael, ышле,
   {{0x442cbeca,0x443e24f9,0x20c90023,0x6e2dbecb}},	//   _tad_, _tnt_, _cúi_, _raab,
   {{0xdefa2371,0x7e647b06,0x6e2d54ab,0xb9090129}},	//   ным_, _alip, _saab, _achị_,
   {{0x6e2da9fb,0x7bdc0170,0x4ab40096,0x00000000}},	//   _paab, dbru, ंगाव, --,
   {{0x6e2d008a,0x6e9500d6,0xbfa700c2,0x61e9916a}},	//   _qaab, риму, ытые_, cael,
   {{0x22930080,0x68ed0188,0xf1b90218,0xb7e400a3}},	//   _النس, xsad, peša_, गराम_,
   {{0x6e2d0bf2,0x7e640201,0x3e620037,0x69ba0034}},	//   _waab, _elip, _vóta_, ्शनी,
   {{0x309b0054,0x6e2d73d9,0x6f010143,0x68ed008c}},	//   _רשומ, _taab, culc, wsad,
   {{0x68edbecc,0x7e64becd,0x99800031,0x5bb8007b}},	//   tsad, _glip, zdiť_, улся_,
   {{0x98751a9c,0x7bdc0d21,0x9f451054,0x7afc0037}},	// [ebf0] алац, bbru, valé_, arrt,
   {{0x68edbece,0x7e6400e7,0x2c667bd6,0x26c50113}},	//   rsad, _zlip, _pôde_, _élok_,
   {{0x68edbecf,0x97a710e8,0x7e6400c2,0x61e90a4b}},	//   ssad, урал, _ylip, yael,
   {{0x3ced0477,0x5695007b,0xaa5913dd,0x00000000}},	//   ševu_, шает, _риму_, --,
   {{0xd1265d50,0x68ed008c,0x58870ab3,0xf1bf02c6}},	//   _بم_, qsad, _быва, žák_,
   {{0xa8790130,0xc4843006,0x61e90051,0x2a69023e}},	//   _יאָר, блік, wael, lhab_,
   {{0xfd580294,0x9f510511,0x61e9bed0,0x99800206}},	//   _braụ, üzü_, tael, rdiť_,
   {{0x2ce50789,0x3e720a39,0x00000000,0x00000000}},	//   _कबूल_, pšti_, --, --,
   {{0x61e9bed1,0xe6645fdd,0x394903be,0x7bdc13ea}},	//   rael, _утро, nxas_, ybru,
   {{0x3949bed2,0x20553031,0x7e64256f,0x7ebf0a84}},	//   ixas_, ртир, _slip, _rūpa,
   {{0x8fa51300,0xfe460084,0x2005008f,0xae0a0789}},	//   ране, анно, rgli_, _वादन_,
   {{0xed5a136c,0x20c90019,0x629904ff,0x00000000}},	//   вом_, _túi_, _ukwo, --,
   {{0xc0e50c0d,0xf8bf03a9,0xa69600ca,0x7bdc5534}},	//   _толк, _asém_, שכרה_, tbru,
   {{0x224d0087,0x6f0190bb,0x26150285,0xdde500e8}},	//   ljek_, pulc, फ्ती_, āpša,
   {{0xeb9a1057,0x78600253,0xddcd0b88,0xf99f05aa}},	//   тив_, _dövl, _ulaş, _ayè_,
   {{0x7bdc2b31,0x7e64b12c,0x6eca245a,0xf99f05aa}},	//   sbru, _ulip, _संतु, _byè_,

   {{0xeabf01b9,0x7bdcb6db,0x00000000,0x00000000}},	// [ec00] _diù_, pbru, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeabf0441,0xbb460c37,0xfaa61d57,0x8d850d7f}},	//   _fiù_, _тенк, _вано, _نشین,
   {{0x6441227a,0xeabf00e5,0xf99f0383,0x25a00131}},	//   _anli, _giù_, _fyè_, üilo_,
   {{0xe53403fb,0xf9920867,0xcb970d5b,0x00000000}},	//   сель, _ذبح_, _منیش_, --,
   {{0xb60202c6,0x04580037,0xf53900d8,0x00000000}},	//   _řádk, طلبة_, _drť_, --,
   {{0x24806361,0x3266017b,0xb66f0139,0x00000000}},	//   đim_, итив, _kẹ̀y, --,
   {{0xd2570084,0xd576141b,0xddcd09ac,0x64414cda}},	//   ицы_, _кузь, _omaš, _enli,
   {{0x26da00c2,0x29120735,0xdb24003e,0x81e80033}},	//   lppo_, ntya_, _ósæm, _বাদ_,
   {{0xd7aa0789,0x2a691a47,0x32ca0019,0xd37814f3}},	//   _कराच, zhab_, _tùy_, _leći_,
   {{0x50b700e3,0x224d5b67,0xe80700c3,0x4ea73386}},	//   جديد_, bjek_, शलता_, ирма,
   {{0x2a696ee9,0x628400c6,0x00000000,0x00000000}},	//   xhab_, čios, --, --,
   {{0xeabf01b9,0x00000000,0x00000000,0x00000000}},	//   _riù_, --, --, --,
   {{0xb87b0065,0x515b00ca,0x2d8524fa,0x00000000}},	//   _awín, _בכדו, ăle_, --,
   {{0xeabf0020,0xdb5802fd,0xee870084,0x2c160285}},	//   _più_, ают_, _выпо, द्धं_,
   {{0xe81904f1,0x7afa3e43,0x8f9b00a1,0xf99f06a3}},	//   न्ना_, átta, _שיהי, _pyè_,
   {{0x7e7dbed3,0x9f470231,0xf1b30142,0x39490231}},	// [ec10] misp, _nenê_, ַסע_, uxas_,
   {{0x1c16009d,0x2a690167,0x7e7dbed4,0x3949002b}},	//   द्दल_, shab_, lisp, rxas_,
   {{0xc5d53006,0x7bc5bed5,0x29120172,0x00000000}},	//   біль, _ighu, atya_, --,
   {{0x7e7d1c35,0xe8d900ac,0xf99f05aa,0x00000000}},	//   nisp, nyị_, _tyè_, --,
   {{0x224d03c6,0x26080251,0x6d5d03a8,0x64410062}},	//   vjek_, _हारी_, nysa, _pnli,
   {{0x7e7dbed6,0xbcfb0103,0x24090243,0x00000000}},	//   hisp, lzés, унки_, --,
   {{0x7ebf01d3,0x224dbed7,0x7cfe01cd,0x00000000}},	//   _rūpn, tjek_, _kærð, --,
   {{0x569401b3,0xc2453277,0x7e7d00cc,0x316d01e9}},	//   _даст, сник, jisp, tzez_,
   {{0x7e7dbed8,0x661b04da,0x225f581c,0xa1120037}},	//   disp, _ibuk, rkuk_, كويت,
   {{0x442300fb,0x753b03f3,0x6d5d4cca,0x224d0268}},	//   _új_, _iruz, dysa, sjek_,
   {{0x543409b4,0xe8193ec9,0x2054008f,0xbcfb0103}},	//   _برقر, न्या_, ютър, zzét,
   {{0x7e7d7745,0x6ed3020a,0x00000000,0x00000000}},	//   gisp, _răbd, --, --,
   {{0xd37802e6,0x9f47023b,0x661b001c,0x6d5d19e5}},	//   _reći_, _kenë_, _mbuk, gysa,
   {{0x9f4700dd,0xc0b20019,0x60db0201,0xd378007e}},	//   _jenë_, _mười_, mpum, _seći_,
   {{0x661bbed9,0xcaa600e3,0xd3782c0a,0x7e7dae9e}},	//   _obuk, مصري, _peći_, bisp,
   {{0x753b1100,0xbcfb0103,0x6d5d0ac1,0x00000000}},	//   _oruz, gzés, bysa, --,
   {{0xd37803ce,0x2f110018,0x39460161,0xa3e7277c}},	// [ec20] _veći_, lág_, ãos_, परा_,
   {{0x7d0602fd,0x29120018,0x661bbeda,0x2a6002b6}},	//   muks, rtya_, _abuk, skib_,
   {{0xb1130129,0x291248b2,0x7d06bedb,0x661b7344}},	//   _bụkw, stya_, luks, _bbuk,
   {{0x69da00d3,0x26da0350,0x00000000,0x00000000}},	//   _ştef, rppo_, --, --,
   {{0xc0b20028,0x89360391,0x7d06bedc,0x753b0b0b}},	//   _cười_, _اعجا, nuks, _cruz,
   {{0x7e7dbe0d,0x661bbedd,0x3358002d,0x00000000}},	//   zisp, _ebuk, иалэ_, --,
   {{0xf99f01dc,0x753b88d2,0xf487010d,0x7d06bede}},	//   _acèh_, _eruz, حانی, huks,
   {{0x60f84367,0x2900bedf,0xb1130174,0x7d06bee0}},	//   ания_, oria_, _gụkw, kuks,
   {{0xc05a097a,0x26cabee1,0x753b6ad3,0x60db5511}},	//   гін_, _hubo_, _gruz, gpum,
   {{0x7d06bee2,0x2ef403fc,0x26ca0201,0x661b0052}},	//   duks, озор, _kubo_, _zbuk,
   {{0x6aa4008e,0x889b0341,0x9f45037a,0x00000000}},	//   klif, רביי, balí_, --,
   {{0x6d5d00c2,0x26cabee3,0x27ea009c,0x9f470154}},	//   tysa, _mubo_, _lebn_, _menè_,
   {{0x7e7d2c8e,0xa3cf0006,0xe8191f77,0x249e0063}},	//   risp, वुक_, न्डा_, _kktm_,
   {{0x26d818bb,0x2900bee4,0x6d5d3da9,0x7e7dbee5}},	//   _otro_, dria_, rysa, sisp,
   {{0xf3f10023,0x307b00ca,0x00000000,0x00000000}},	//   _học_, _תאונ, --, --,
   {{0x2bd90557,0x6aa40858,0x7d06bee6,0x38c90068}},	//   _ब्रा, glif, buks, لائی_,
   {{0x2900bee7,0xbcfb0018,0xb1130134,0x26d80036}},	// [ec30] gria_, rzés, _rụkw, _atro_,
   {{0x69d90455,0x9f47022b,0x753b0216,0x26ca028a}},	//   _फ्री, _benè_, _rruz, _bubo_,
   {{0x29005d2e,0x37ab0284,0x8a19002d,0xb1130174}},	//   aria_, утан_, _конс_, _pụkw,
   {{0x29003f3d,0x753b042d,0xadfb1687,0x7c270537}},	//   bria_, _pruz, ्लिन_, lejr,
   {{0x2f110018,0x81c30081,0x672e052f,0x2900a293}},	//   zág_, ্রম_, _esbj, cria_,
   {{0x9f4701e5,0x58d4106b,0xf7731f11,0xd37800c4}},	//   _qenë_, _хорт, _فاز_, _leću_,
   {{0xb1130294,0x4dfb0d77,0xae0a007a,0x850500d1}},	//   _tụkw, ्लाई_, _वालन_, _ژورن,
   {{0xd37800e9,0x661b271c,0x60db671f,0x6b7c0796}},	//   _neću_, _ubuk, tpum, טרונ,
   {{0x26ca16a2,0x753b02a4,0x6fda0096,0x7e8b007f}},	//   _zubo_, _uruz, _म्हं, tępn,
   {{0x2bd91161,0xe3b30241,0xef190291,0x6aa4bba7}},	//   _ब्ला, _فرض_, амо_, zlif,
   {{0xbba8033a,0x81e800c7,0x6e260103,0x60db0f18}},	//   _गरेक, _বার_, tekb, spum,
   {{0x7d060d64,0xe8196eef,0x60db01a5,0x60cd0076}},	//   tuks, न्ता_, ppum, _éamo,
   {{0x2f110068,0x4427bee8,0x9f47020d,0x6e260103}},	//   ság_, oen_, _mené_, rekb,
   {{0x7d06bee9,0x6aa4030a,0x61eb4f34,0x25ad0154}},	//   ruks, wlif, _hegl, _mzel_,
   {{0x60cb0088,0xa09a006e,0x61ebbeea,0xbcfb0103}},	//   _hugm, _דיסט, _kegl, gyéb,
   {{0x4427beeb,0x2900beec,0x6289beed,0xf1d1009f}},	//   hen_, tria_, nneo, _हलफन,
   {{0x61ebbeee,0x26cabb6a,0xbcfb0018,0x60cb0d62}},	// [ec40] _megl, _subo_, szér, _jugm,
   {{0x290003f3,0x61ebbeef,0x60c301c2,0x2bd900a4}},	//   rria_, _legl, _jinm, बुदा,
   {{0xbc6a1e49,0xe5c61824,0xa3180251,0x25ad00e7}},	//   _ممکن_, осло, _दहेज_, _azel_,
   {{0x29006289,0x44278c89,0x60c30167,0xd9460582}},	//   pria_, een_, _linm, _деми,
   {{0x44275dd2,0x28c30455,0x9f4703a9,0x6fc9a130}},	//   fen_, _वंचि, _dené_, रशां,
   {{0x4427bef0,0x66e68dec,0xe819000d,0x649a1469}},	//   gen_, _мога, न्दा_, штер_,
   {{0x61eb17d4,0x26d801df,0x25adbef1,0x60cb790c}},	//   _begl, _utro_, _ezel_, _augm,
   {{0x60c310f0,0x41e60426,0xf99f0154,0x9f4700b3}},	//   _ainm, ціка, _abèy_, _gené_,
   {{0x44272422,0x61eb0465,0x3fc809b4,0xf8af0018}},	//   ben_, _degl, یدگی_, _سکے_,
   {{0x4427bef2,0x60cb1100,0x60c34c43,0x26c4bef3}},	//   cen_, _dugm, _cinm, _himo_,
   {{0x60c319e4,0x3ea007ac,0x26c4bef4,0x60cb01b9}},	//   _dinm, _bkit_, _kimo_, _eugm,
   {{0x60c36cb1,0x62890a6c,0x61eb8f26,0x3ea000dc}},	//   _einm, cneo, _gegl, _ckit_,
   {{0xd378005f,0x6280bef5,0x60cb019c,0x3ea00167}},	//   _veću_, mimo, _gugm, _dkit_,
   {{0x35cc0336,0x271702c6,0x9f4511b2,0x60c300da}},	//   ़खड़, něná_, balà_, _ginm,
   {{0x7c27bef6,0x81c30033,0x9f4500ee,0x9f4c01dc}},	//   rejr, ্রণ_, calà_, kadé_,
   {{0x4427bef7,0x26c42a78,0x63a702b6,0x8cf53ebe}},	//   zen_, _nimo_, _øjne, _езиц,
   {{0x4427bef8,0xf4e50081,0x3eb91c7e,0x00000000}},	// [ec50] yen_, _নম্ব, mmst_, --,
   {{0x4427bef9,0x6280befa,0x17fb0037,0x200cbefb}},	//   xen_, himo, شرطة_, ngdi_,
   {{0x442701c0,0x26c40065,0xc5d80174,0xd5d80134}},	//   ven_, _bimo_, _ịrụb, _ịrụr,
   {{0x4427befc,0xa3dd13cc,0x1daf0096,0x26c4022b}},	//   wen_, थुन_, _घरात, _cimo_,
   {{0x26c400f9,0x00000000,0x00000000,0x00000000}},	//   _dimo_, --, --, --,
   {{0x4427befd,0x61ebbefe,0x22460063,0x25ad033b}},	//   uen_, _segl, _anok_, _vzel_,
   {{0x61eb005f,0x29090084,0x60c302f1,0x9f4500b3}},	//   _pegl, luaa_, _rinm, xalà_,
   {{0x78600018,0x60c3beff,0x28af0034,0x00000000}},	//   _rövi, _sinm, _जीति, --,
   {{0x4427bf00,0x61eba899,0x5ba8077d,0x44f400d3}},	//   pen_, _vegl, _गर्व, _оптс,
   {{0x9f450990,0xe5c440ca,0x442700dd,0x3ea0bf01}},	//   talà_, _істо, qen_, _skit_,
   {{0x62800328,0x60c30ac9,0x3ea682da,0x3ea00090}},	//   bimo, _vinm, зинг, _pkit_,
   {{0x628004d8,0x60cbbf02,0xd19c00ac,0x26c400b3}},	//   cimo, _tugm, ịbụl_, _ximo_,
   {{0x80de0033,0x3ce9009c,0x60c3020b,0x91870076}},	//   _মিথ্, _cwav_, _tinm, _بجام,
   {{0xc1720054,0x6ab42918,0x3e620088,0xf1b90268}},	//   _אחד_, ंग्र, _móti_, ješi_,
   {{0x09e60f50,0xbb432753,0xcb6700d3,0xe9df003e}},	//   зобн, нерк, паре_, _snúa_,
   {{0x32d1011b,0x49ca5566,0x9f450610,0x3ea00eac}},	//   _máy_, слан_, calá_, _ukit_,
   {{0x7af50018,0x3ce905aa,0x32d1020b,0x00000000}},	// [ec60] aszt, _gwav_, _láy_, --,
   {{0x44e900a5,0x6280bf03,0x26c4bf04,0x6e360188}},	//   dź_, zimo, _simo_, _hayb,
   {{0x6e3601e8,0x212d895b,0x25a400f0,0x3ec50367}},	//   _kayb, hweh_, _syml_, _üstü_,
   {{0x3a29009c,0x00000000,0x00000000,0x00000000}},	//   ceap_, --, --, --,
   {{0x64a61787,0xe8192999,0x62807451,0x6e36bf05}},	//   пада, न्हा_, vimo, _mayb,
   {{0x2608009f,0x320d0188,0x81c30033,0x00000000}},	//   _हाकी_, egey_, ্রা_, --,
   {{0x62801f84,0x26c49363,0x9f580367,0x26dc05f1}},	//   timo, _timo_, ürü_, ívod_,
   {{0x1dbe009d,0x46a31249,0x38b402c3,0x320d01ee}},	//   ोशात, _засв, färg_, ggey_,
   {{0x628001ce,0x9f450146,0x00000000,0x00000000}},	//   rimo, valá_, --, --,
   {{0x62803610,0x7af5007f,0x00000000,0x00000000}},	//   simo, yszt, --, --,
   {{0x6e36bf06,0x6e95002d,0x4abe0be4,0x32d10023}},	//   _bayb, дину, ्दाव, _gáy_,
   {{0x645a5768,0x20020e63,0x2c6f042c,0x3ce9022b}},	//   _hoti, şki_, _müde_, _pwav_,
   {{0x645a0d64,0x656226fc,0xf1bf00d2,0xfd47013f}},	//   _koti, nyoh, žár_, чэнн,
   {{0x91bb00a1,0x625c014b,0xa3cc00b7,0xb17d00d2}},	//   _המדי, _géor, रखि_, raťt,
   {{0x64480449,0xe8100179,0x00000000,0x00000000}},	//   _mndi, ालना_, --, --,
   {{0x645abf07,0x7af50034,0x64480009,0x3ce9016d}},	//   _loti, rszt, _lndi, _twav_,
   {{0xa3cc1860,0x64484bb9,0x7e6d991c,0x5ed10033}},	// [ec70] रखा_, _ondi, _ilap, থীদে,
   {{0x645aad2c,0x7e6d8979,0x656269a7,0xb90500aa}},	//   _noti, _hlap, dyoh, _नऽ_,
   {{0xb87b70f9,0x212d0169,0x00000000,0x00000000}},	//   _kvíz, zweh_, --, --,
   {{0x6448bf08,0x645a009c,0x2bd900b6,0x00000000}},	//   _andi, _aoti, बुरा, --,
   {{0x645abf09,0x7e6d0113,0x2bb50096,0x00000000}},	//   _boti, _mlap, ंधका, --,
   {{0xdfc60080,0x03a50e20,0x7e6d9650,0x38b402c3}},	//   _لي_, мило, _llap, gärd_,
   {{0x645a4105,0x65620124,0x625c020d,0x6a7102c3}},	//   _doti, ayoh, _réor, _våff,
   {{0xe0d93dba,0x32d10019,0x6448154c,0x16140285}},	//   ови_, _váy_, _endi, _डायर_,
   {{0x645a1ff3,0x320d0abd,0x7649008c,0x20d200eb}},	//   _foti, rgey_, _iney, _câi_,
   {{0x7e6d0068,0xb87b00d4,0x6f654dff,0x00000000}},	//   _alap, _avíz, двоз, --,
   {{0xb87b0139,0x765b2f1b,0x7e6d084e,0x7bc80880}},	//   _etíg, _kouy, _blap, žduk,
   {{0x6e360694,0x645a00dd,0x68f60150,0x765b0154}},	//   _qayb, _zoti, ysyd, _jouy,
   {{0x201805fe,0x38b4042c,0x64484df3,0x7e6d2533}},	//   òric_, läre_, _yndi, _dlap,
   {{0x4e0a0251,0x645a0131,0x60c41097,0x3f693340}},	//   _वाकई_, _xoti, _éimp, _мило_,
   {{0x6e3601af,0x38b4042c,0xfaa60138,0xddc4078e}},	//   _tayb, näre_, даво, _foiş,
   {{0x4cdd0081,0x7e6d2c81,0x764906b0,0x765b02f1}},	//   _বিরু, _glap, _nney, _nouy,
   {{0xfaa36a40,0x38b40364,0x9f470031,0x7c371a4a}},	// [ec80] тато, häre_, _mení_, _faxr,
   {{0x68f65b45,0x76490154,0x9c870094,0x65620239}},	//   rsyd, _aney, _vyčí, vyoh,
   {{0x765b4aa4,0x38b40212,0xdb2400c2,0x00000000}},	//   _bouy, värd_, äräs, --,
   {{0x9f47000d,0x645a7f94,0x64480da3,0x26dc00d9}},	//   _není_, _soti, _sndi, īvo_,
   {{0xb90300c7,0x28af0851,0x6aa3016d,0x6d4b00b3}},	//   _নয়_, _जीवि, _ênfa, _àgat,
   {{0x656202a4,0xd467bf0a,0x7b400b14,0x645a11bc}},	//   ryoh, миче_, pćuć, _qoti,
   {{0x645aa46a,0x765b06a3,0x65623642,0xb87b003e}},	//   _voti, _fouy, syoh, _stíg,
   {{0x32b70080,0xd25000e3,0x65620124,0x76490154}},	//   ودية_, انة_, pyoh, _gney,
   {{0x645a0a7f,0x442a0042,0x00000000,0x00000000}},	//   _toti, _ºb_, --, --,
   {{0x7e6d1e06,0x6448bf0b,0x15f853b8,0x00000000}},	//   _slap, _undi, ुलकर_, --,
   {{0xd9ee39d4,0x765b8157,0x62550139,0xc4c50076}},	//   जरात_, _youy, _láoy, _ستكو,
   {{0x4ad2007d,0xa40e0fef,0x787202b6,0x625c020d}},	//   _दूधव, _साँप_, _hævd, _géop,
   {{0xb17d0031,0x63a403e3,0x161300b7,0x39420120}},	//   saťr, ƙins, ण्टर_, _nrks_,
   {{0x21260332,0x80d50081,0x5fd200bc,0x786000a7}},	//   _ipoh_, _দিচ্, _सलिल, _mövs,
   {{0x20190253,0x260f0251,0xdeef00ae,0x7e6d875b}},	//   əsi_, _डाली_, _шы_, _tlap,
   {{0x7e6dbf0c,0x2d9e00ae,0x7d0600c4,0x00000000}},	//   _ulap, ştea_, brks, --,
   {{0xa40e09d0,0x940e007a,0xdff25dfe,0x63a8032e}},	// [ec90] _सांप_, _सांच_, _आजाद_, _lydn,
   {{0x37ab0c59,0x765b05aa,0x00000000,0x00000000}},	//   отен_, _souy, --, --,
   {{0x45dc0134,0x765b022b,0x3942058f,0x00000000}},	//   _ịpụ_, _pouy, _erks_, --,
   {{0xd7df07ad,0x645e0222,0xe7df167f,0x2c6d0146}},	//   _प्रच, öpin, _प्रप, vždy_,
   {{0xd5fb0174,0x2a6900a4,0x94250208,0x286b0c37}},	//   _akụ, mkab_, емле, _дрво_,
   {{0x9475001c,0x60cd0131,0x05960d7f,0x38b4042c}},	//   رگذا, _éami, رانگ, täre_,
   {{0x765b0c56,0x24890106,0x63a800f0,0x80de0033}},	//   _touy, đam_, _cydn, _মিষ্,
   {{0x2a6902b1,0x3a39022b,0x98a0007f,0x7afa01cd}},	//   nkab_, _jasp_, twić_, átti,
   {{0x9f47037a,0x3a390231,0x00000000,0x00000000}},	//   _vení_, _masp_, --, --,
   {{0x26d10201,0x6eca00b6,0x00000000,0x00000000}},	//   _kuzo_, _संखु, --, --,
   {{0x20180990,0x2a69007a,0x53a30034,0x63a800f0}},	//   òria_, kkab_, _ओडिश, _gydn,
   {{0x3e620088,0x26d1bb10,0x80de0033,0x00000000}},	//   _nótt_, _muzo_, _মির্, --,
   {{0x7872052f,0xddc405db,0x00000000,0x00000000}},	//   _hæve, _bliš, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd00e0080,0x291943b5,0xf1b901d3,0xad9b002b}},	//   _الى_, _aqsa_, rešu_, ugúr,
   {{0x2a690124,0x3a3900ee,0x06de0033,0xddc4023c}},	//   gkab_, _casp_, _ডিলি, _eliš,
   {{0x6e24023f,0x26d101e9,0xaac5007f,0x00000000}},	// [eca0] _ibib, _auzo_, लआजक, --,
   {{0x6d443a71,0xddc40095,0x26d1037a,0x9f4c1054}},	//   _iria, _gliš, _buzo_, zadí_,
   {{0x6d440031,0xdbc700bc,0x00000000,0x00000000}},	//   _hria, _söök, --, --,
   {{0xb8f600c7,0x9f4e022b,0x38af042c,0x6d44bf0d}},	//   _সব_, _defè_, büro_, _kria,
   {{0xe534bf0e,0x786001d4,0x9f4c0146,0x6e243ebb}},	//   тель, _dövr, vadí_, _mbib,
   {{0xe6603ed0,0x63a8010a,0x3a3905db,0x7c3c0216}},	//   ırış, _pydn, _zasp_, ndrr,
   {{0x3940032e,0x26d1575b,0x6e240129,0x68e459fe}},	//   lvis_, _guzo_, _obib, lpid,
   {{0x6d44bf0f,0xdbc7007a,0x7c2ebf10,0x786000a7}},	//   _oria, _töök, hebr, _tövs,
   {{0x3940bf11,0x6d44023e,0x3ce0022e,0x9f4c2347}},	//   nvis_, _nria, _ntiv_, radí_,
   {{0x7c2ebf12,0xd2500260,0x6e24bf13,0x5f040ccb}},	//   jebr, انک_, _abib, _विद्_,
   {{0x6d4402ad,0x201e0088,0xdef708a1,0x7c2e2b31}},	//   _aria, rfti_, ныя_, debr,
   {{0x442e7e62,0x63a40b88,0xddc40087,0x78600092}},	//   lef_, ğind, _sliš, _mövq,
   {{0x2f180068,0x6d4400c9,0x63a40511,0x39400d62}},	//   ség_, _cria, şind, jvis_,
   {{0x7c2e0b7c,0x62820d7d,0x6e249ab4,0x39404796}},	//   gebr, _hmoo, _ebib, dvis_,
   {{0x2ba40ed3,0x6d44520d,0x3a3900e7,0xa6e70023}},	//   _खुदा, _eria, _pasp_, _chứ,
   {{0x442eb10f,0x6d44bf14,0x26d100e7,0x673b00e8}},	//   hef_, _fria, _ruzo_, _ņujo,
   {{0x39401484,0x6d44638f,0xf8071c94,0x2a69bf15}},	// [ecb0] gvis_, _gria, ечен, rkab_,
   {{0x2a69bf16,0x7c2e34b6,0x6e3d093e,0x442e004d}},	//   skab_, cebr, ldsb, jef_,
   {{0x442ebf17,0x9f4c0428,0x6d440220,0x3a2d0072}},	//   def_, nadà_, _zria, _ºep_,
   {{0x6e3d2085,0xb87b0139,0x68f2003e,0xc8f500e5}},	//   ndsb, _awít, úkdó, _измъ,
   {{0x442eaeff,0x64cb0469,0x6e3d04e2,0xddec00c1}},	//   fef_, ादेश, idsb, פֿאָ,
   {{0x6aadbf18,0x62820f20,0x26d10051,0x7d1d7a3d}},	//   llaf, _amoo, _tuzo_, itss,
   {{0xe299415c,0xfbd400ca,0x7c25009c,0x00000000}},	//   мак_, נתק_, _mbhr, --,
   {{0xc24522ff,0x7d1d012a,0x60ca02a1,0x3125008f}},	//   тник, ktss, _aifm, вдиг,
   {{0x38b40149,0x786000a7,0x9f452e00,0xa4d5004d}},	//   lära_, _zövq, mblé_, _розі,
   {{0x6aad01bf,0x7c2e0042,0x25b20233,0x78720537}},	//   hlaf, xebr, üyle_, _tæve,
   {{0x68e40a00,0x6d44033f,0x3ce007d0,0x38b40212}},	//   zpid, _sria, _stiv_, nära_,
   {{0x6d440038,0x7d1d9e9d,0x7c25033c,0x24870027}},	//   _pria, ftss, _abhr, linm_,
   {{0x61e9bf19,0x7c2e0c89,0x442500f9,0x7d0f007e}},	//   mbel, tebr, _kbl_, gucs,
   {{0xab2a0426,0x69dd02ce,0x61e91ca6,0x7529294f}},	//   мога_, _afse, lbel, _mpez,
   {{0x44250088,0x2c740149,0x7d1d279f,0x6aa60063}},	//   _mbl_, _rädd_, atss, _pkkf,
   {{0xf2d200c1,0x61e9bf1a,0x7c2e1483,0x442e74e8}},	//   שען_, nbel, sebr, zef_,
   {{0x6d440a34,0x69a22235,0x61e900f9,0x442e01c2}},	// [ecc0] _uria, _कुशी, ibel, yef_,
   {{0x68e40a00,0x9f4c0031,0x61e900dc,0x4da80033}},	//   rpid, ladá_, hbel, _গণপূ,
   {{0x8a060cd7,0xd6d9004d,0x39400501,0x68e4bf1b}},	//   _изне, еті_, svis_, spid,
   {{0x9f4c08ec,0x68e4bf1c,0x61e9bf1d,0x7afa003e}},	//   nadá_, ppid, jbel, áttu,
   {{0xceb3040a,0x00000000,0x00000000,0x00000000}},	//   ביא_, --, --, --,
   {{0x61e96de0,0x38b40212,0x442500da,0x628200ca}},	//   ebel, bära_, _cbl_, _smoo,
   {{0x442e02ad,0x4425078e,0x17c700ae,0x61e901cd}},	//   ref_, _dbl_, _агри_, fbel,
   {{0x442ebf1e,0x61e9a97b,0x326300c2,0x442501b9}},	//   sef_, gbel, итыв, _ebl_,
   {{0x28d800e2,0x9f4c03be,0x442501af,0x442e0451}},	//   _भूमि, dadá_, _fbl_, pef_,
   {{0xdefa1736,0x9f4c0428,0xb3560103,0x00000000}},	//   мым_, tadà_, _لیتا_, --,
   {{0xe47500ae,0xbebd00e8,0x00000000,0x00000000}},	//   _сутэ, ntīg, --, --,
   {{0x91e6016e,0x83fc005f,0x7d1d13f8,0x6e3d0629}},	//   _роде, _dođe, ttss, udsb,
   {{0x6e3d20ab,0x00000000,0x00000000,0x00000000}},	//   rdsb, --, --, --,
   {{0xddcd05db,0x7c870e05,0x00000000,0x00000000}},	//   _umaž, туме, --, --,
   {{0x69cf01b9,0x7d1d1088,0x7b640120,0x00000000}},	//   _pgce, stss, атте, --,
   {{0xb5fd0c0b,0x290968cd,0xbcfb01f9,0x6a7801cd}},	//   _koše, traa_, nyék, _líff,
   {{0xd759110a,0x3ea90808,0x2c1b1152,0xa3a900aa}},	// [ecd0] کلات_, _ikat_, _बापू_, _गुन_,
   {{0x61e933ef,0xb76727a5,0x2909a8e6,0x3ea90113}},	//   zbel, ктей, rraa_, _hkat_,
   {{0x7529bf1f,0x7eb6bf20,0xb5fd0039,0x61e9bf21}},	//   _spez, lápa, _loše, ybel,
   {{0x24f96621,0xb9e4004d,0x6aa4014b,0x6908020e}},	//   енды_, _віри, coif, ürdü,
   {{0x7eb6310c,0xfd1f401d,0xb5fd49d1,0x442501ce}},	//   nápa, ntì_, _noše, _pbl_,
   {{0x61e9bf22,0x38b400bc,0xa8790142,0x00000000}},	//   wbel, pära_, _טאָר, --,
   {{0xddcd0090,0x59a70caf,0xe73002fc,0x4425058f}},	//   _amaż, _कुतर, _وصف_, _vbl_,
   {{0x83fc00e9,0x6d4100d9,0x61e92906,0xf3f100fe}},	//   _rođe, ālaj, ubel, _mọi_,
   {{0x44253dd5,0x00000000,0x00000000,0x00000000}},	//   _tbl_, --, --, --,
   {{0x61e60b88,0x83fc015c,0xd5b82018,0x5f040bf5}},	//   ıkla, _pođe, _рсс_, _विश्_,
   {{0x6aa40a4b,0x61e90b8e,0x82150308,0x63a40233}},	//   yoif, pbel, _مواص, ğinc,
   {{0x83fc04a3,0xcee8015a,0x2d9e2af9,0x63a4071d}},	//   _vođe, کرین_, ştem_, şinc,
   {{0x91051c1b,0x3ea9005c,0x224f01dc,0x78a58a07}},	//   _спле, _dkat_, _ingk_, kohv,
   {{0x6abe04f8,0x25ad5f93,0xddcb044c,0x00000000}},	//   ्द्र, _myel_, ţişa, --,
   {{0x5a96204e,0x9f4c030b,0x1614009f,0xab270bd0}},	//   граф, padá_, _डालर_, лора_,
   {{0xa3bb007a,0x6a710429,0x00000000,0x00000000}},	//   _घरन_, _påfa, --, --,
   {{0x3946bf23,0x2ba41cff,0x00000000,0x00000000}},	// [ece0] íos_, _खुरा, --, --,
   {{0x2c660031,0xb8660103,0x6aa4014b,0x00000000}},	//   _pôdu_, دارو, soif, --,
   {{0x5c370341,0xe7e3009f,0xf3f100fe,0x6aa4024a}},	//   _גרין_, गड़ा_, _gọi_, poif,
   {{0xbebd00d9,0x00000000,0x00000000,0x00000000}},	//   rtīg, --, --, --,
   {{0x7c3e626f,0xbebd01d3,0x62890ac9,0xe8f700ae}},	//   _kapr, stīg, dieo, _йля_,
   {{0x9f4701e8,0x64a302b7,0x07a6083c,0x81f00033}},	//   _genç_, бача, _багн, _টাইপ_,
   {{0x7c3e8cf7,0x7eb60146,0x25ad0113,0x932601c3}},	//   _mapr, zápa, _eyel_, ارتن,
   {{0x7c3ebf24,0xb5fd49d1,0x26cd0023,0x25ad022b}},	//   _lapr, _poše, _gieo_, _fyel_,
   {{0x2912bf25,0x00000000,0x00000000,0x00000000}},	//   nuya_, --, --, --,
   {{0x3ea9bf26,0x201800bc,0x00000000,0x00000000}},	//   _skat_, üri_, --, --,
   {{0x2c1b6724,0x443e796c,0x2ba413ae,0xa2e6283b}},	//   _बाबू_, _iat_, _खुला, _соед,
   {{0x443e02f4,0x38af01e8,0x539b0089,0x291271a5}},	//   _hat_, türk_, _איבו, kuya_,
   {{0x443ebf27,0x5c073c32,0xa06a5136,0xee3f0094}},	//   _kat_, лява, _пада_, rdý_,
   {{0xdfcf0080,0x443ebf28,0xfd1f028d,0xa3a91f88}},	//   _فيه_, _jat_, rtì_, _गुड_,
   {{0x443e169c,0x7c3e0c56,0x8cd53212,0xfd1f0036}},	//   _mat_, _dapr, _यूरो, stì_,
   {{0x443e0067,0x5a35001f,0x291201b2,0x6f04009c}},	//   _lat_, јнат, fuya_, _āich,
   {{0x443e5675,0x7c875cac,0x57f50c37,0xb87b033c}},	// [ecf0] _oat_, _буне, ипат, _dtín,
   {{0x13cc0081,0x25ad0154,0x443e0133,0x00000000}},	//   রুয়, _ryel_, _nat_, --,
   {{0x473500d3,0x9f4700ee,0x25ad05aa,0x00000000}},	//   рнес, _venç_, _syel_, --,
   {{0x7c3e6eb0,0xa3ca0ed3,0x291236d8,0x248500dc}},	//   _zapr, ोशन_, buya_, _smlm_,
   {{0x6e3f00bd,0x443e0cd6,0x7c3e026a,0xe3b800a7}},	//   _maqb, _bat_, _yapr, _azı_,
   {{0x443e00ca,0x78720537,0x0445232c,0x00000000}},	//   _cat_, _hævn, рекн, --,
   {{0x443ebf29,0x62891a6b,0x224f00dc,0xc3040037}},	//   _dat_, tieo, _pngk_, مبيو,
   {{0xa3a9034d,0x787202b6,0x443e00ca,0xaab53344}},	//   _गुण_, _jævn, _eat_, ंतिक,
   {{0x443e00ca,0x661b0079,0x62890c89,0x25ad0113}},	//   _fat_, _icuk, rieo, _uyel_,
   {{0x443ea1aa,0x753bbf2a,0x4f2504a1,0xe9df0032}},	//   _gat_, _isuz, адоб, _inúu_,
   {{0x7c3e9c4f,0x224f0063,0x6a780231,0x291229e4}},	//   _rapr, _tngk_, _hífe, zuya_,
   {{0x7c3ebf2b,0x7872052f,0x2912bf2c,0x319e0129}},	//   _sapr, _nævn, yuya_, ịza_,
   {{0x7c3ebf2d,0x61fbbf2e,0x7ae543d5,0x443e373d}},	//   _papr, maul, _atht, _yat_,
   {{0x317a0341,0x443e0428,0x61fb363b,0xb87bb54c}},	//   _באנד, _xat_, laul, _stín,
   {{0x6b63430b,0x6a78003e,0x2912bf2f,0x1a66001c}},	//   окра, _lífe, wuya_, لیدی_,
   {{0x61fb8eb5,0x7c3e1b45,0x8f9a0327,0x26dc2e92}},	//   naul, _wapr, _ביצי, ívom_,
   {{0xe9d73947,0x7c3e8245,0x9f450037,0x60db0060}},	// [ed00] рку_, _tapr, iblí_, nqum,
   {{0x61fbbf30,0x661b0027,0xb87b0076,0x29121577}},	//   haul, _acuk, _dtío, ruya_,
   {{0x443e02f4,0x7e646510,0x753b012d,0xb87b5593}},	//   _rat_, _koip, _asuz, _etío,
   {{0x0bb7040a,0x754643a9,0xe9a61720,0x7f8c006e}},	//   _כלים_, инез, _вамп, ענאַ,
   {{0x443ebf31,0xe81e0251,0x61fb113a,0xd3f00032}},	//   _pat_, _पापा_, daul, _aṣẹg,
   {{0x443ebf32,0x84380037,0xddc4007f,0x29021206}},	//   _qat_, اكثر_, _bliź, _ivka_,
   {{0x443ebf33,0xd4670831,0x6d4101d3,0x290000d8}},	//   _vat_, рије_, ālai, lsia_,
   {{0x443e8608,0x442000b6,0x83fc0095,0x32541111}},	//   _wat_, ři_, _dođa, свир,
   {{0x443e04f9,0x2900bf34,0x1da5009d,0xb27302ec}},	//   _tat_, nsia_, _गुंत, ільш,
   {{0x26d8bf35,0x29000084,0x69b9009d,0x443e01b9}},	//   _kuro_, isia_, ्धती, _uat_,
   {{0x7640bf36,0x75220068,0x1df91736,0x290018c4}},	//   _kamy, ltoz, лены_, hsia_,
   {{0xb5fd0d5d,0x290002fd,0x61fb6c0e,0x26d884d8}},	//   _koša, ksia_, caul, _muro_,
   {{0x29001b1e,0x61e24c65,0xf27b0796,0xb5fd0a39}},	//   jsia_, _ifol, _בראש, _joša,
   {{0x26d80bfe,0x7ebd0257,0x63ad03e3,0x60cd0231}},	//   _ouro_, dépe, ƙant, _éamp,
   {{0xbebd0029,0x2900058f,0x91fa023a,0x6e3f0078}},	//   rtīb, esia_, _एजाज_, _taqb,
   {{0xbebd0029,0x9f450146,0xb87b0139,0x29000350}},	//   stīb, nalý_, _etíl, fsia_,
   {{0xdebc00a1,0x27f84bcb,0x7ebd0103,0x2d8f00bc}},	// [ed10] _במהל, _bern_, gépe, _äge_,
   {{0x085400d6,0x06de0033,0x9c3911b4,0x61fb10f6}},	//   овую, _ডিজি, _спот_, zaul,
   {{0xec360054,0x26d800eb,0x2900492d,0x764053ed}},	//   _האתר_, _curo_, asia_, _bamy,
   {{0x26d8bb1c,0x83fc04a3,0x69a21179,0x76405c99}},	//   _duro_, _rođa, _कुकी, _camy,
   {{0xf8db0378,0x2900bf37,0x7640022b,0x45450037}},	//   _बढिय, csia_, _damy, إنتق,
   {{0xb5fd03ce,0xe81e2235,0x27f801bf,0x61e27129}},	//   _doša, _पाया_, _gern_, _afol,
   {{0xe7ed02e8,0x26d8bf38,0x96f833d4,0x61fbbf39}},	//   _च्या_, _guro_, _вест_, taul,
   {{0xeb9800a1,0x7640013f,0x83fc015c,0xf8db152c}},	//   ידור_, _gamy, _vođa, _बढाय,
   {{0x61fbbf3a,0x7522bf3b,0x00000000,0x00000000}},	//   raul, ctoz, --, --,
   {{0x20550e1b,0xcea900c1,0xd3a71b04,0x61fbbf3c}},	//   стир, _װי_, _креп, saul,
   {{0x61fbbf3d,0x141a0089,0x644100f9,0x26d8002b}},	//   paul, _תועב, _iali, _xuro_,
   {{0x6443040f,0x2900440c,0xed5a5a64,0xb87bbf3e}},	//   ldni, ysia_, гом_, _stíl,
   {{0xdd920d74,0x3f8b0034,0x627b0034,0xa059071c}},	//   سوس_, ńcu_, głoś, _مؤثر_,
   {{0x28db0d0b,0x9f472dc0,0x6443bf3f,0x6441bf40}},	//   _बढ़ि, _menú_, ndni, _jali,
   {{0x394b2f7c,0x7e64a726,0x00000000,0x00000000}},	//   _arcs_, _toip, --, --,
   {{0x6441bf41,0x225f1bd6,0x29001dfe,0xeabf5b13}},	//   _lali, njuk_, tsia_, _chù_,
   {{0x290078b6,0x26d800ee,0xbebd01d3,0x764000c6}},	// [ed20] usia_, _suro_, stīc, _ramy,
   {{0x64410979,0x26d87b2e,0xbddb0990,0x29009e66}},	//   _nali, _puro_, ndèn, rsia_,
   {{0x64430149,0x27f800f3,0xe81e00bc,0x7d0400f2}},	//   ddni, _vern_, _पाठा_, _hvis,
   {{0xb5fd1386,0x6443bf42,0x6441bf43,0x2900bf44}},	//   _poša, edni, _aali, psia_,
   {{0x786001d4,0x9f450244,0x225f0018,0x26d801c2}},	//   _mövz, valý_, djuk_, _wuro_,
   {{0x75220018,0x64411173,0x26d8bf45,0x6a6a0146}},	//   rtoz, _cali, _turo_, _výfu,
   {{0x6441bf46,0x0877006e,0x61f9033c,0x00000000}},	//   _dali, _פעלט_, _bewl, --,
   {{0xe6960080,0x7d042cc8,0x20070103,0x6441058f}},	//   _الرد, _ovis, _adni_, _eali,
   {{0x315a0037,0x61fd04c8,0x00000000,0x00000000}},	//   اجعة_, ðsla, --, --,
   {{0x6441bf47,0x0eea004d,0xf99f00ee,0x98a9007f}},	//   _gali, льми_, _odèn_, rwać_,
   {{0x7d0475b4,0xb5fd11dc,0x6fb400d1,0xa30b0103}},	//   _avis, _mošn, تمدا, _مرنے_,
   {{0xc3b700c1,0x00000000,0x00000000,0x00000000}},	//   _פלאץ_, --, --, --,
   {{0x644187cc,0x9f4700e5,0x2d9f020d,0x2a600113}},	//   _yali, _menù_, çue_, djib_,
   {{0x6441448b,0x9f45034f,0x7c290e94,0x00000000}},	//   _xali, galó_, đero, --,
   {{0xeabf0019,0x5f934406,0xa3cb0034,0xdb5812d1}},	//   _phù_, _ништ, रेप_, бют_,
   {{0x64431c7f,0x00000000,0x00000000,0x00000000}},	//   zdni, --, --, --,
   {{0xb5fd26dd,0x6e2dbf48,0x7e7d0037,0x644300f2}},	// [ed30] _bošn, _ibab, mhsp, ydni,
   {{0x81bd0081,0x6d4d4f15,0x9f45309e,0x442cbf49}},	//   _আলম_, _iraa, caló_, _nbd_,
   {{0xeabf00de,0x6441bf4a,0x7d040206,0x3b5400ae}},	//   _thù_, _rali, _zvis, _екэр,
   {{0x6d4d844b,0x442cbf4b,0x00000000,0x00000000}},	//   _kraa, _abd_, --, --,
   {{0x6441bf4c,0xa3cb0e4c,0x6e2dbf4d,0xe3e901f3}},	//   _pali, रेन_, _mbab, لکان_,
   {{0x68edbf4e,0x442c2343,0x64415673,0x83fc00cc}},	//   mpad, _cbd_, _qali, _dođo,
   {{0x6441bf4f,0x64430501,0x8c1c13b6,0x3949bf50}},	//   _vali, rdni, אווי, lvas_,
   {{0x64411fae,0x6d4dbf51,0x68ed2cd5,0xbcfb0103}},	//   _wali, _oraa, opad, nyés,
   {{0x66099984,0x68ed8319,0x3ce901fa,0xe0d608a1}},	//   _idek, npad, _ntav_, овы_,
   {{0xaf0510ab,0x6e2dae6c,0x68ed49aa,0x3949bf52}},	//   опол, _abab, ipad, ivas_,
   {{0x7d0993af,0x66090146,0x7d045474,0x394900aa}},	//   šesl, _kdek, _svis, hvas_,
   {{0x6d4dbcde,0x63ad028e,0xddcd0117,0x7bd7063d}},	//   _braa, ğand, _slaš, _agxu,
   {{0xddcdbf53,0x763a0130,0xb5fd0995,0x63ad071d}},	//   _plaš, בערג, _lošo, şand,
   {{0x6d4d04ee,0xdfdb008f,0x6e2d0415,0x00000000}},	//   _draa, _съд_, _ebab, --,
   {{0xbb43275d,0x6d4dbf54,0xcb670012,0x00000000}},	//   мерк, _eraa, оаре_, --,
   {{0x66090129,0x6d4d715f,0x6e2dbf55,0x7d0406cd}},	//   _ndek, _fraa, _gbab, _tvis,
   {{0x6d4d685e,0x68ed1098,0x2a790167,0x8c461372}},	// [ed40] _graa, gpad, _dlsb_, _депе,
   {{0x83fc007e,0xbebd00e8,0x6e2d00d4,0xddc416aa}},	//   _rođo, ntīn, _zbab, _kliž,
   {{0x442cbf56,0x68ed0037,0xe73a2ea7,0xa3a90dc4}},	//   _rbd_, apad, рее_, _गुल_,
   {{0xd62a1d0b,0x8f9a00ca,0x442c34ec,0xcf9200ca}},	//   роде_, ביעי, _sbd_, וטב_,
   {{0x660906b0,0xbcfb0103,0x69b4136b,0x6ac60ff9}},	//   _ddek, lyér, _आरटी, लगीर,
   {{0x66090294,0x3d12009d,0x83fc015c,0x6ab606c5}},	//   _edek, _तिने_, _vođo, llyf,
   {{0xbcfb0103,0x00000000,0x00000000,0x00000000}},	//   nyér, --, --, --,
   {{0xfbd300a1,0xf48412eb,0x291200f9,0x00000000}},	//   ותו_, _کاری, orya_, --,
   {{0xa2da0714,0x93bc00d3,0x2c1b121d,0xdce701d3}},	//   _पूर्, _scăd, _बालू_, ēlīg,
   {{0xddc40fee,0x6609278c,0x395700ca,0x2d820031}},	//   _bliž, _zdek, קשים_, dzke_,
   {{0xb7db0341,0x7e7db1b6,0x9f5e0052,0x6d4d009c}},	//   יקיי, thsp, matë_, _sraa,
   {{0x6d4d6bc5,0x3949013f,0xe29212eb,0xc2ed00d2}},	//   _praa, yvas_, _غذا_, žící,
   {{0xe0180861,0x00000000,0x00000000,0x00000000}},	//   _दाऊद_, --, --, --,
   {{0x6d4d15b9,0x7e7d64a2,0x9f5e0216,0x00000000}},	//   _vraa, shsp, natë_, --,
   {{0x6d4d1044,0x00000000,0x00000000,0x00000000}},	//   _wraa, --, --, --,
   {{0x6d4d9bf3,0x6e2d3a09,0x9df900d3,0x59b9023a}},	//   _traa, _ubab, _унит_, _आरआर,
   {{0xb5fd30c7,0x3ce9320e,0xdd91015a,0x38c90470}},	// [ed50] _došl, _utav_, _سود_, مائی_,
   {{0x68ed9864,0xa3cb1efb,0x9f5e0052,0xd04300a7}},	//   rpad, रेड_, jatë_, _binə,
   {{0xc6a71a54,0x39495c8a,0x9f5e0216,0x29120154}},	//   орди, svas_, datë_, arya_,
   {{0x68ed0149,0x2c7d0af0,0xcb12006e,0xb5fd007e}},	//   ppad, _dìde_, _אלט_, _vošo,
   {{0x73e50465,0x660901e5,0xd1260080,0x981700cd}},	//   полз, _vdek, _ثم_, _وبسا,
   {{0x81c20033,0xb5fd0234,0x9f5e7bb4,0x00000000}},	//   ্ডা_, _tošo, ratê_, --,
   {{0x61fd0653,0x00000000,0x00000000,0x00000000}},	//   ðslo, --, --, --,
   {{0xb87b1054,0xb5fd78ee,0x00000000,0x00000000}},	//   _stíh, _košm, --, --,
   {{0xe1f10421,0x00000000,0x00000000,0x00000000}},	//   وسک_, --, --, --,
   {{0xe3b30241,0x9f850f57,0x6aad00d4,0x38b44880}},	//   _قرض_, згод, hoaf, täri_,
   {{0x9f5e0c56,0x6b8300fe,0xe81e0179,0x7eb60231}},	//   natè_, _ýngh, _पासा_, lápi,
   {{0xb87b037a,0x6da60284,0xbebd01d3,0xc3010033}},	//   _huíd, зима, stīn, _এমপি_,
   {{0x57b802d5,0x1c203212,0x315800e3,0xee3700d6}},	//   _अर्ह, _बादल_, _وجهة_, чня_,
   {{0x60c4028d,0x9f0508ba,0x38b400c2,0x629b4a13}},	//   _èimp, _فوتو, päri_, lnuo,
   {{0xb5fd1b30,0x2d823e15,0x7ebd014b,0xfbc300b8}},	//   _pošl, szke_, sépa, ебро,
   {{0xe9da16d9,0xe81e0096,0xada67a20,0x291200f9}},	//   ска_, _पाहा_, _найл, trya_,
   {{0x98a01b32,0x7afb007e,0x6ab6bf57,0xa3cb274c}},	// [ed60] stič_, ćuta, rlyf, रेत_,
   {{0xb9040e50,0x499900d6,0x6ab678a4,0x00000000}},	//   _पं_, іття_, slyf, --,
   {{0x25bf0b0b,0xc2f00081,0x59b00034,0x7d0640d6}},	//   _azul_, _টিভি_, _फ़रवर, lsks,
   {{0x3e7b00dd,0xaabf00b6,0x7ae303a9,0x5693004d}},	//   _këta_, ्षणक, _énta, наєт,
   {{0x48e3571b,0x9f5e023b,0x1fc8023a,0x7d06032e}},	//   _появ, tatë_, _रण्ड, nsks,
   {{0x25bf005c,0xb87b034f,0x52a402d5,0x79840a4b}},	//   _dzul_, _cuíd, ऑक्स, mziw,
   {{0x9f5e00dd,0x07a3065c,0xddc40090,0x987b006e}},	//   ratë_, _зарн, _aliż, _פאלט,
   {{0xddc4007f,0x00000000,0x00000000,0x00000000}},	//   _bliż, --, --, --,
   {{0x79840060,0x9f5e292a,0x93bc078e,0x00000000}},	//   nziw, patë_, _abăt, --,
   {{0x44380682,0x44e201cd,0x2fd801df,0x43460f54}},	//   _úr_, _ið_, ørg_, _незв,
   {{0x09b905a5,0xddc400bd,0xd9b909c4,0xa3cb32f6}},	//   _आर्य, _eliż, _आर्ट, रेद_,
   {{0x66020051,0x59be0be4,0x9f5e0094,0x00000000}},	//   naok, ्धार, naté_, --,
   {{0x9f5e06a3,0x6f020065,0xe2a90411,0x00000000}},	//   zatè_, _bíbá, _بالن_, --,
   {{0x6ab51362,0x9f5e0094,0x7984007f,0x5577006e}},	//   ंत्र, haté_, dziw, לעכן_,
   {{0x3d12009d,0x6602bf58,0x160c0096,0x394200d7}},	//   _तिथे_, kaok, हणार_, _asks_,
   {{0x69da00d3,0xfd470018,0x9f5e0763,0x201e00e4}},	//   _şter, _ٹیسٹ_, jaté_, lgti_,
   {{0xf99300bf,0x195804d9,0xbebd00e8,0xdd920103}},	// [ed70] ربر_, паты_, ntīm, _لوٹ_,
   {{0x201e01b3,0x3eb91c7e,0x26c402ef,0x6a780139}},	//   ngti_, llst_, _ahmo_, _fífo,
   {{0x44e2bf59,0xb904007d,0xb87b137f,0x386a033b}},	//   _að_, _पू_, _ruíd, _dobr_,
   {{0x628066a7,0x19590109,0xb87b002b,0x78730233}},	//   jhmo, _дамы_, _suíd, _sıvı,
   {{0x04450fa5,0xb87b002b,0xd46968f6,0x00000000}},	//   делн, _puíd, жиле_, --,
   {{0x7eb60103,0xb5fd0e9e,0x3eb9042c,0x629e014b}},	//   rápi, _košk, hlst_, épon,
   {{0x9f5ebf5a,0xb5fd02fb,0x49190034,0xe695007b}},	//   baté_, _jošk, यूरो_, _живы,
   {{0xb5fd0b27,0xd5ae0018,0x201e19db,0x9f5c0231}},	//   _mošk, اہے_, egti_, _tevê_,
   {{0x81b50f71,0xf4f70103,0xb5fd0117,0x00000000}},	//   ছেন_, _رواں_, _lošk, --,
   {{0xbddb0113,0x00000000,0x00000000,0x00000000}},	//   bdèk, --, --, --,
   {{0xaabf11c6,0x6280023e,0xbea612d1,0x644b04e9}},	//   ्षाक, bhmo, данк, ćnič,
   {{0x38b40212,0x6280756f,0x00000000,0x00000000}},	//   lärt_, chmo, --, --,
   {{0xe81e17ff,0xd009194c,0x6145bf5b,0xb81e0285}},	//   _पाला_, _деле_, _цела, _पालम_,
   {{0xb5fd042d,0x7afb0a39,0x6735009e,0x7d06bf5c}},	//   _bošk, ćutn, _opzj, rsks,
   {{0x09e65616,0x20180031,0xebe307f0,0x9f5c022b}},	//   добн, órie_, тосп, _nevè_,
   {{0xc3320054,0x9f47bf5d,0x3ea0023b,0x321f16d5}},	//   כול_, _menü_, _ujit_, nguy_,
   {{0x63a40b88,0x6e2405bd,0x9f5e00d4,0xddcd00d8}},	// [ed80] ğini, _icib, vaté_, _plať,
   {{0x6d446d00,0x63a4680c,0x66029ff8,0x00000000}},	//   _isia, şini, waok, --,
   {{0x9f5e2c69,0x6602bf5e,0x00000000,0x00000000}},	//   taté_, taok, --, --,
   {{0x7c3c0a00,0x386a00f0,0x319e0294,0x7c2e2473}},	//   lerr, _wobr_, ịzi_, lfbr,
   {{0xa3cb046e,0x9f5e2342,0x6280023e,0x321f078e}},	//   रेस_, raté_, vhmo, dguy_,
   {{0x7c3c4ad2,0x6d44024a,0x38b402c3,0x00000000}},	//   nerr, _msia, gärt_, --,
   {{0x628000dd,0xf7432b85,0x9f5ebf5f,0x00000000}},	//   thmo, _иеро, paté_, --,
   {{0x7c3c7779,0x6d44b942,0x7c2993af,0x9695018a}},	//   herr, _osia, đeri, _зруш,
   {{0x7c3cbf60,0x14260161,0xa2da1d7d,0x68e400a7}},	//   kerr, _одам, _पंक्, nqid,
   {{0x6280023b,0x7c3c8682,0x63ad008b,0x6e2456b0}},	//   shmo, jerr, şana, _acib,
   {{0x6d44bf61,0x3817040a,0xdb0b0491,0x66004b5f}},	//   _asia, וקים_, ünüz, _kemk,
   {{0x644808a7,0x443c7ccc,0x442e5842,0xe0da0ef1}},	//   _hadi, lev_, lff_, _двд_,
   {{0x64485895,0x645a0124,0x7c3cbf62,0xb5fd1b32}},	//   _kadi, _knti, ferr, _sošk,
   {{0x6448561b,0xb5fd551d,0x442e22d4,0x443c007a}},	//   _jadi, _pošk, nff_, nev_,
   {{0xe2070034,0x6d44bf63,0x442e00f0,0xcfaa001c}},	//   spół_, _esia, iff_, _باشم_,
   {{0x32045dc2,0x83fc0106,0x443cad92,0x6e450037}},	//   namy_, _dođi, hev_, _أنظم,
   {{0x7c3cbf64,0x443cbf65,0x645a015e,0x394000f9}},	// [ed90] berr, kev_, _onti, gwis_,
   {{0x3e7b01e5,0x443c011d,0x7d1d4f0f,0x7c3c61f8}},	//   _këto_, jev_, muss, cerr,
   {{0x7d1d62ca,0xd1480019,0x443cbf66,0xb5fd00e7}},	//   luss, _lễ_, dev_, _hoši,
   {{0xb5fd1cf3,0x6e3d44ff,0xb87b0139,0x442e18f0}},	//   _koši, nesb, _atít, eff_,
   {{0x6448bf67,0xe3b807aa,0x7e6d0009,0x32040034}},	//   _badi, _ayı_, _moap, damy_,
   {{0xdfc61170,0x645a005c,0x443c00aa,0x660001ff}},	//   _مي_, _cnti, gev_, _eemk,
   {{0x6448bf68,0xb5fd0995,0x66007377,0xd404004d}},	//   _dadi, _loši, _femk, тячи,
   {{0x7c3c6bc6,0xb1451839,0x7e6d002d,0x7d1d49b3}},	//   zerr, енил, _noap, kuss,
   {{0x7c251af5,0x6448006d,0x765b22d4,0x81d70081}},	//   _ochr, _fadi, _inuy, ়ুন_,
   {{0x6448bf69,0xd1480028,0x7d1d65e0,0x443c0087}},	//   _gadi, _dễ_, duss, cev_,
   {{0x3ce04aa4,0xa3cb034d,0x4adb0e4c,0x00000000}},	//   _suiv_, रेश_, _मंगव, --,
   {{0x29090084,0x32040034,0x290b0559,0x7c255fbe}},	//   ksaa_, camy_, _ovca_, _achr,
   {{0x7d1dbf6a,0x61e9bf6b,0xa3cb030b,0xb87b0042}},	//   guss, mcel, रेर_, _xuíc,
   {{0x8fa547b0,0x61e9bf6c,0x64484c47,0x83fc14f3}},	//   _пале, lcel, _xadi, _pođi,
   {{0x2005bf6d,0x7c3c2525,0x44254bdc,0x765b06b0}},	//   mali_, rerr, _mcl_, _onuy,
   {{0x61e9bf6e,0x6d440197,0x7c3c0809,0x20052824}},	//   ncel, _tsia, serr, lali_,
   {{0x443c0253,0x08c6311c,0x7d1d0d4d,0xf2d200c1}},	// [eda0] yev_, ебан, cuss, רען_,
   {{0x2005bf6f,0x394000a5,0xbcfb0072,0x3204007f}},	//   nali_, rwis_, oxén, zamy_,
   {{0xabfb0054,0xf7721823,0x660000a4,0x7bde0124}},	//   _מהיר, داء_, _pemk, _igpu,
   {{0x6448bf70,0x2005694c,0x645a0063,0xf5061165}},	//   _sadi, hali_, _snti, ездо,
   {{0x443c2782,0x200567a2,0x4abf007d,0x6448bf71}},	//   tev_, kali_, ्षरव, _padi,
   {{0x20051da1,0x6448926d,0xd1480023,0x2c660031}},	//   jali_, _qadi, _rễ_, _pôdy_,
   {{0x443c0b97,0x2005bf72,0x6448bf73,0x442e02ad}},	//   rev_, dali_, _vadi, rff_,
   {{0xcb130054,0x443c595d,0x6448bf74,0x7bde0063}},	//   אלה_, sev_, _wadi, _lgpu,
   {{0x6448bf75,0x2005bf76,0x32040034,0xe5a31e61}},	//   _tadi, fali_, ramy_, _бити,
   {{0x2005bf77,0x320400dc,0x645a94d0,0x64480239}},	//   gali_, samy_, _unti, _uadi,
   {{0x61e93aab,0xb4cc1006,0x7d1dbf78,0xe9df0328}},	//   bcel, रगी_, wuss, _baúl_,
   {{0x7c257fa3,0x7d1d4cd2,0x29090694,0xb5fd0660}},	//   _schr, tuss, ysaa_, _poši,
   {{0x2005712e,0x7d1d0483,0xa11300b9,0x9f5e7e22}},	//   bali_, uuss, _مونت, patï_,
   {{0x2005bf79,0xbcfb002b,0x9f5e1515,0x7ae2007e}},	//   cali_, bxén, latí_, _čotr,
   {{0x7d1dbf7a,0x39ee0857,0xbb580290,0x00000000}},	//   suss, _ọzọ_, нарх_, --,
   {{0x7d1dbf7b,0xb5fd031a,0x66e50138,0x2909348f}},	//   puss, _toši, _dėkl, tsaa_,
   {{0x38b40222,0x61fd04c8,0xf8b10a85,0x00000000}},	// [edb0] värr_, ðsli, لکس_, --,
   {{0x7c250ec4,0x7d0d078e,0x9f5e00d4,0xd6d9007f}},	//   _uchr, _ivas, hatí_, _sił_,
   {{0x290900c2,0xd7590037,0x61e900eb,0x6a1500d3}},	//   ssaa_, بلات_, ycel, _имну,
   {{0x2005bf7c,0x9f5e0220,0x00000000,0x00000000}},	//   zali_, jatí_, --, --,
   {{0x20050283,0x4974297a,0x1beb007f,0xb87b0503}},	//   yali_, _бляс, जुअल_, _dtír,
   {{0x764900ec,0x9f45014b,0x00000000,0x00000000}},	//   _waey, sclé_, --, --,
   {{0xa3cb0067,0x7649bf7d,0xb87b04d8,0xd46600e5}},	//   रें_, _taey, _guía, тище_,
   {{0x2005bf7e,0xa56200cd,0x7d0d04d6,0x00000000}},	//   wali_, _چگون, _ovas, --,
   {{0x61e934d2,0x41020084,0xe9df167e,0xe8d90174}},	//   rcel, азыв, _raúl_, azụ_,
   {{0x7ebd04ea,0x61e9bf7f,0xe9df0143,0x00000000}},	//   léph, scel, _saúl_, --,
   {{0x2005bf80,0x20186e42,0x7d0d1d4b,0xf45600a1}},	//   rali_, ória_, _avas, _שיער_,
   {{0xfce61589,0x2c740364,0xc7d600ca,0x7ebd014b}},	//   комо, _lädt_, כותי_, néph,
   {{0x200529d3,0xfd1f028d,0x66e50138,0x7d0dbf81}},	//   pali_, guì_, _sėkl, _cvas,
   {{0x20050415,0x224d12c3,0x7d0d0138,0xe1f900c6}},	//   qali_, ldek_, _dvas, lbų_,
   {{0x7d0d26ae,0x2b150686,0x09d90033,0x00000000}},	//   _evas, льтр, ধুমা, --,
   {{0x224dbf82,0xb5fd005f,0x6a713229,0x2bde3845}},	//   ndek_, _košu, _såfr, _मलका,
   {{0x290c01d3,0xdea2001c,0xbcfb002b,0x7ebd01f9}},	// [edc0] _ādas_, _میگی, nxél, zépk,
   {{0x92dc00c7,0x6d5605bd,0x00000000,0x00000000}},	//   তীয়_, _irya, --, --,
   {{0x394d0335,0x6a780088,0x7d09005f,0x2a69409f}},	//   _šest_, _lífi, šest, bjab_,
   {{0x940700a7,0xa3d40469,0x63ad020e,0x00000000}},	//   minə_, सेफ_, ğanl, --,
   {{0x63ad0511,0x940700a7,0xa3d418ff,0x6d562008}},	//   şanl, linə_, सेन_, _jrya,
   {{0x02ca00b6,0xb4cc3e2a,0x0fa200b6,0x69c60062}},	//   ाग्न, रगे_, _ओखलढ, _izke,
   {{0x02a600d3,0x9407013c,0x00000000,0x00000000}},	//   крим, ninə_, --, --,
   {{0x6d560db0,0x6a780143,0x224d029a,0xc7a30120}},	//   _orya, _bífi, gdek_, _тиск,
   {{0x9f5e0094,0xb5fd0206,0x00000000,0x00000000}},	//   ratí_, _pošv, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0d04a3,0x6d56bacc,0x50d30037,0x422600d3}},	//   _svas, _arya, جزير, _адев,
   {{0xc7b3040a,0xddd600b6,0x6a784571,0xfd1f028d}},	//   יבת_, _slyš, _fífi, tuì_,
   {{0xbebd00d9,0x4034013f,0xddc4762e,0xddd673c9}},	//   ktīv, _белс, _poiš, _plyš,
   {{0x628201bb,0x8f5400cd,0x66e5013f,0xfd1f0036}},	//   _hloo, _منتش, _sėkm, ruì_,
   {{0xb5fd00e9,0x69c603f3,0x6d565908,0x6282453a}},	//   _košt, _azke, _erya, _kloo,
   {{0xb87b00b3,0x00000000,0x00000000,0x00000000}},	//   _atíp, --, --, --,
   {{0x628201bb,0xaca30174,0xf80700d6,0xead400a9}},	// [edd0] _mloo, _alụg, вчен, роть,
   {{0x7e7d084e,0x09c302d5,0x940700a7,0xa2c9074c}},	//   lksp, _शरीय, binə_, _हीन्,
   {{0x62820af0,0x69c60a00,0xe1f90138,0x00000000}},	//   _oloo, _ezke, ybų_, --,
   {{0x6282023e,0x4b7a0089,0xf77008ba,0x9f5c02c6}},	//   _nloo, _נארו, غال_, _neví_,
   {{0x7ae50084,0xa825110a,0x25a9bf83,0xa2c600b6}},	//   _huht, _مکان, çal_, ातन्,
   {{0x628282ad,0x03a53e93,0x25a9003d,0x63ad008b}},	//   _aloo, лило, ħal_, şanm,
   {{0x7ae50006,0x224d0305,0x628240e9,0xb5fd033b}},	//   _juht, tdek_, _bloo, _bošt,
   {{0x236900e9,0x20180032,0x7ae53a8d,0xc24500c2}},	//   ćaj_, órin_, _muht, уник,
   {{0x20c20088,0xe1f90138,0x224dbf84,0xc692021e}},	//   rðin_, rbų_, rdek_, _האן_,
   {{0x940701d4,0x95c80bd0,0x212d00dc,0x25a00076}},	//   yinə_, _руса_, rteh_, úile_,
   {{0xa2f56ae6,0x628200ca,0xb87b0076,0x4ab500b6}},	//   _спеч, _floo, _luío, ूताव,
   {{0xddcd025b,0xf38c006e,0x2eb500ae,0x00000000}},	//   _dlaž, _קראָ, исяс, --,
   {{0x61fb3990,0xb87b0bf8,0x61fd003e,0xdb050094}},	//   mbul, _ruín, ðslu, _vyhý,
   {{0x61fb4b5d,0x753b023f,0x7e7dbf85,0x94070092}},	//   lbul, _mpuz, ërpr, tinə_,
   {{0x30da00c1,0x09be0c3c,0x98a00a39,0xddcd05db}},	//   _אַהע, ्ध्य, ltić_, _glaž,
   {{0x940701d4,0xb87b00e3,0x7e7d227a,0x61fb1577}},	//   rinə_, _buío, cksp, nbul,
   {{0x940701d4,0xa81a0068,0x98a00335,0x81b50081}},	// [ede0] sinə_, فتار_, ntić_, ছের_,
   {{0xa84a0076,0x00000000,0x00000000,0x00000000}},	//   علام_, --, --, --,
   {{0xe61a03fc,0x61fb4051,0xeb9a99ac,0x00000000}},	//   еде_, kbul, _чин_, --,
   {{0xa96a1312,0x95ca105b,0xa3c93fdd,0x84e6004d}},	//   _зима_, нула_, ोधन_, годж,
   {{0x6aa400d3,0x98a0049c,0xe5a31111,0xb87b033c}},	//   mnif, jtić_, бици, _guío,
   {{0x62822eb0,0xbebd01d3,0xd467002d,0x9f5e0094}},	//   _sloo, ltīt, личе_, hatá_,
   {{0xb5fd13ad,0x6282bf86,0xf487001c,0xe61a4ba7}},	//   _pošt, _ploo, دانی, _пдв_,
   {{0x61fb0fa0,0x98a0050d,0x75d608ba,0x851c009f}},	//   gbul, ftić_, _ميزا, _निपट_,
   {{0xddcd084f,0x83fc150a,0x2018001f,0x628204e2}},	//   _slaž, _anđe, ório_, _vloo,
   {{0xddcd831e,0x83fc192a,0x61fb399b,0xe4d7001c}},	//   _plaž, _vođs, abul, _موقت_,
   {{0x61fb0517,0x2fd80212,0x6aa4bf87,0x8f340cb0}},	//   bbul, ärg_, knif, шенц,
   {{0x91e60084,0x7ae30113,0x00000000,0x00000000}},	//   _соде, _énti, --, --,
   {{0x7ae54207,0x61e20415,0xb7f601e4,0xd041013c}},	//   _suht, _igol, ेराम_, hmlə,
   {{0x7ae503cf,0xa3cb034d,0xd1c90d7f,0x7e7d0b6a}},	//   _puht, रेक_, _شبنم_, sksp,
   {{0x8aa700b4,0xb87b0080,0xddcd1386,0xc879002d}},	//   град, _suío, _ulaž, _îşi_,
   {{0x6aa40e13,0x98a909ac,0x1f132259,0x2db60129}},	//   gnif, rtač_, _ابوج, ọkụ_,
   {{0x98a9104b,0x3ea90063,0x38c90281,0x7642020e}},	// [edf0] stač_, _ijat_, نائی_, deoy,
   {{0x61fb55c8,0x68e603e3,0x37ab261f,0x98a902ef}},	//   zbul, _dukd, нтен_, ptač_,
   {{0x61e2ac07,0x753b0357,0x828b0065,0x00000000}},	//   _ogol, _spuz, _látọ, --,
   {{0x61e2bf88,0x635c00d3,0x6aa426e0,0x00000000}},	//   _ngol, _mănă, cnif, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e2bf89,0x4d7c00c1,0x98a00095,0x657900d7}},	//   _agol, ערגע, vtić_, rywh,
   {{0x9f5c00b3,0x43690077,0x7d1d1489,0x00000000}},	//   _nevà_, тайн_, hrss, --,
   {{0x3f8c00e7,0x3dc90063,0xbb3c0266,0x7522010a}},	//   dzdu_, _ozaw_, געהי, buoz,
   {{0xb4270688,0xd53806f6,0x798d0022,0xe7d10285}},	//   _معاو, _مثلا_, nzaw, थेरप,
   {{0x25bf01d4,0x660b1d1e,0x3ea900c2,0x61e2bf8a}},	//   _iyul_, lagk, _ajat_, _egol,
   {{0x2054055b,0x98a01386,0x644368df,0xa3cb009d}},	//   стыр, stić_, meni, रेख_,
   {{0x64436e9d,0x660b00a6,0x2cba00ec,0x31350a99}},	//   leni, nagk, _skpd_, _ведр,
   {{0x6cc600d6,0xfce62c22,0x66e500c6,0x9f5e0231}},	//   ийма, рого, _dėki, ratá_,
   {{0x6443bf8b,0x629b013f,0x44270da3,0x61e20087}},	//   neni, liuo, ngn_, _zgol,
   {{0xa09a0341,0xdca30478,0x68e6a527,0x660b019c}},	//   _ביסט, цари, _sukd, kagk,
   {{0x64434c41,0x629b013f,0x3ea90052,0x25ad01ff}},	//   heni, niuo, _gjat_, _oxel_,
   {{0xe9da1300,0x64432aa6,0x200701e5,0x673c0268}},	// [ee00] тка_, keni, _keni_, _sprj,
   {{0x64430954,0xbebd0029,0x200700dd,0x97560291}},	//   jeni, stīt, _jeni_, итељ,
   {{0x6443bf8c,0x2cb80429,0x629b0138,0x3afc0139}},	//   deni, mord_, kiuo, _dàpò_,
   {{0x7d04bf8d,0x2cb8bf8e,0x26cdbf8f,0x1f36006e}},	//   _kwis, lord_, _cheo_, ירער_,
   {{0x64433243,0xe801009f,0x9f4e0383,0x7d045b50}},	//   feni, _लड़का_, _jefò_, _jwis,
   {{0x7d041639,0x2007bf90,0xd7f200e3,0x2cb80572}},	//   _mwis, _neni_, _ذكر_, nord_,
   {{0xd4090037,0x07a304fd,0x00000000,0x00000000}},	//   اتهم_, _дарн, --, --,
   {{0xd257bf91,0xddcd57e0,0x629b00c6,0x66e3013f}},	//   аць_, _plaż, giuo, _фота,
   {{0x30a6364a,0x6443bf92,0x2007bf93,0x506601b3}},	//   иров, beni, _beni_, атна,
   {{0x2007bf94,0x213d00f9,0x2cb83696,0x656f020d}},	//   _ceni_, _dpwh_, jord_, _àcha,
   {{0xb5fd00e7,0x2007bf95,0x7d040078,0x987b006e}},	//   _košp, _deni_, _awis, דריק,
   {{0x442c01f7,0x7761002b,0x7d04bf96,0xefcc026a}},	//   _hcd_, _álxe, _bwis, _ışığ,
   {{0x6a780088,0xb87b00e3,0x2007b4c5,0x2cb83794}},	//   _lífs, _suím, _feni_, ford_,
   {{0x2007adde,0x442c022b,0x2cb8bf97,0x3a2b0131}},	//   _geni_, _jcd_, gord_, _sccp_,
   {{0x200cbf98,0x3a2b0090,0x00000000,0x00000000}},	//   madi_, _pccp_, --, --,
   {{0x200cbf99,0x64431799,0x20071197,0xa3cb22a3}},	//   ladi_, zeni, _zeni_, रेट_,
   {{0x2007436c,0x2cb80f05,0x64438b0e,0x80c90081}},	// [ee10] _yeni_, bord_, yeni, রদর্,
   {{0x200c1ce5,0x6d4dbf9a,0x3eb90d95,0x64433959}},	//   nadi_, _isaa, lost_, xeni,
   {{0x7d0402dc,0x64438846,0x3ce901fa,0x44eb01df}},	//   _zwis, veni, _huav_, _sø_,
   {{0x200cbf9b,0x3ce9023e,0x64432ead,0x4fd900c1}},	//   hadi_, _kuav_, weni, אַנד,
   {{0x6443bf9c,0xe61800f3,0x200cbf9d,0xa3d44660}},	//   teni, рді_, kadi_, सेस_,
   {{0x3eb9bf9e,0x6d4d068d,0x200ca7c1,0x660bbf9f}},	//   host_, _msaa, jadi_, sagk,
   {{0x6443bfa0,0x26cd00ef,0x62890080,0x3eb9bfa1}},	//   reni, _theo_, theo, kost_,
   {{0x3e7b00dd,0x200780c9,0x3a298a45,0x3eb908c5}},	//   _këtu_, _seni_, ngap_, jost_,
   {{0x629bbfa2,0x3eb92029,0x3ce9022e,0x20070c3b}},	//   riuo, dost_, _nuav_, _peni_,
   {{0x14740080,0x200c43fa,0x2007023b,0x64430052}},	//   _والج, gadi_, _qeni_, qeni,
   {{0x160b06ae,0x6d4dbad4,0x200752c1,0x237902a3}},	//   _हजार_, _asaa, _veni_, _حماد_,
   {{0x3949006d,0xfd1f0036,0x6a78003e,0x2007010a}},	//   kwas_, frì_, _lífr, _weni_,
   {{0x200c0484,0x6609bfa3,0x3ce9006c,0x20075957}},	//   badi_, _meek, _cuav_, _teni_,
   {{0x6609bfa4,0xab2a7cbf,0x3ce9022e,0x200c6637}},	//   _leek, лога_, _duav_, cadi_,
   {{0x8fa25b80,0xc05200a1,0x9ef500e3,0x6d4d083e}},	//   _наше, _מזג_, _استش, _esaa,
   {{0x4f160132,0x3a29063f,0x66092721,0x3eb9030a}},	//   _פֿון_, ggap_, _neek, cost_,
   {{0x49ca0d62,0x7e64bfa5,0x39492375,0xfd1f0036}},	// [ee20] улан_, _inip, gwas_, crì_,
   {{0xe9d73429,0x81ac0033,0x38630169,0x7ebd037a}},	//   ску_, _গরম_, _cnjr_, sépt,
   {{0x6609bfa6,0x7e646bab,0x62990283,0x442cbfa7}},	//   _beek, _knip, _omwo, _rcd_,
   {{0x3ce91071,0x6b81038c,0x200c0e94,0x5fba00c1}},	//   _yuav_, ølge, zadi_, אצענ,
   {{0x200c4807,0x3ce901fa,0x7e640350,0x00000000}},	//   yadi_, _xuav_, _mnip, --,
   {{0x62993128,0x7aed0103,0x00000000,0x00000000}},	//   _amwo, _öltö, --, --,
   {{0x33170080,0x200cbb89,0x7e640032,0x66090134}},	//   مزيد_, vadi_, _onip, _feek,
   {{0x50f40dcc,0x200cbfa8,0x96953db3,0x7e760270}},	//   озит, wadi_, _друш, _noyp,
   {{0x3eb9617c,0x200cbfa9,0x2912152a,0xe1ef012b}},	//   vost_, tadi_, nsya_, رسي_,
   {{0xdefa022c,0x442c1d09,0xb5fd02ef,0x3f1400be}},	//   лым_, _ucd_, _inša, одос,
   {{0x200c4756,0x3ce901bb,0x3eb93e75,0x7e760eaa}},	//   radi_, _suav_, tost_, _boyp,
   {{0x200cbfaa,0x3ce9006c,0xddc401d3,0x7afc033b}},	//   sadi_, _puav_, _maiņ, dprt,
   {{0xa13300bf,0x3ce9006c,0x00000000,0x00000000}},	//   _فروش, _quav_, --, --,
   {{0x200c2e3d,0x68fb023b,0x7e640032,0x00000000}},	//   qadi_, _çudi, _enip, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4d595d,0x139b00c1,0x3ce90197,0xfd1f028d}},	//   _tsaa, אבלע, _tuav_, prì_,
   {{0x6609bfab,0x3a290085,0x66e50138,0x6d4dbfac}},	// [ee30] _reek, rgap_, _lėkt, _usaa,
   {{0x68ed0188,0x66091a5b,0x3949bfad,0x3b131cdf}},	//   rqad, _seek, rwas_, _tvxq_,
   {{0x394901af,0xa2ad023a,0x29120172,0x00000000}},	//   swas_, ुकम्, asya_, --,
   {{0x6725061d,0x66ca0094,0x00000000,0x00000000}},	//   ruhj, týka, --, --,
   {{0xd12639d9,0x660900aa,0x24090451,0x00000000}},	//   _تم_, _veek, анли_, --,
   {{0x1bfb2cb6,0x6609bfae,0x22ac00b6,0xad9b0072}},	//   ्रिल_, _week, věka_, laús,
   {{0xa3d4009d,0x66099620,0x0ec90557,0x00000000}},	//   सेल_, _teek, रताड, --,
   {{0xc7b200a1,0x00000000,0x00000000,0x00000000}},	//   _חבל_, --, --, --,
   {{0xc42b0241,0x940e01d4,0xe5731ea6,0x5ba613ae}},	//   _مثال_, hifə_, _عطر_, _ऐश्व,
   {{0x7e76037a,0x6009444f,0x00000000,0x00000000}},	//   _soyp, шном_, --, --,
   {{0xbebd0029,0xcdc90105,0xfe4627c9,0xd24e0504}},	//   drīb, _סך_, онно, رنی_,
   {{0x629905bd,0x3f8b007f,0x00000000,0x00000000}},	//   _umwo, ącu_, --, --,
   {{0x2d840074,0x3f832af0,0x00000000,0x00000000}},	//   áme_, šju_, --, --,
   {{0x2b410154,0x00000000,0x00000000,0x00000000}},	//   _bphc_, --, --, --,
   {{0x7ebd020d,0x2d840e4b,0x00000000,0x00000000}},	//   répr, šme_, --, --,
   {{0x7e64118e,0x3946016d,0xada60fbe,0x3aee0e4b}},	//   _unip, çoso_, _майл, _výp_,
   {{0x316d01ff,0x00000000,0x00000000,0x00000000}},	// [ee40] nxez_, --, --, --,
   {{0xeabf0032,0x29125db9,0xbb4600d3,0x7d16bfaf}},	//   _ekù_, rsya_, _деок, _ivys,
   {{0x3ce3009f,0x20180031,0xe9df0231,0xf5ea34df}},	//   _टूटे_, órii_, _baús_, амел_,
   {{0xa2c90285,0x56930120,0x00000000,0x00000000}},	//   _हील्, маєт, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4420074e,0xa2c6009d,0xa3d40789,0x7ebd01f9}},	//   ği_, ातल्, सें_, képp,
   {{0x1fcf00c7,0x442035a3,0x32b70037,0x260b0096}},	//   রশাস, şi_, يدية_, ारणी_,
   {{0xdcea02c6,0xe5a30e2d,0x940e013c,0x00000000}},	//   čněj, _жити, zifə_, --,
   {{0x66020a00,0x44380013,0x38787e1c,0x26c6601d}},	//   lbok, _ùr_, _jorr_, lloo_,
   {{0x44f000ef,0x3878302f,0xf1c602c6,0x9f5e01f9}},	//   _hà_, _morr_, _řádu_, latú_,
   {{0xd25000d0,0x66022fca,0xa3c90336,0x443e941c}},	//   _سنت_, nbok, ोधर_, _hbt_,
   {{0x61a5084a,0xb95b0139,0xd12f0037,0x443e0125}},	//   खपृष, _ayìn, _لمن_, _kbt_,
   {{0x44f0bfb0,0xbf1400bf,0x443e1197,0xee3f0146}},	//   _mà_, _فوتب, _jbt_, mným_,
   {{0x44f0011b,0xee3f025b,0x75220146,0x00000000}},	//   _là_, lným_, hroz, --,
   {{0x443ebfb1,0x0cb4007f,0x940e013c,0x00000000}},	//   _lbt_, ंकॉम, rifə_, --,
   {{0x44f00649,0xee3f0146,0xc4ca007f,0x660220ab}},	// [ee50] _nà_, nným_, िताओ, dbok,
   {{0x387803ea,0x27e700d6,0xd7fb0aa8,0x6d5f009e}},	//   _corr_, ønn_, руа_, _irqa,
   {{0x44f00139,0x7d161515,0x00000000,0x00000000}},	//   _aà_, _zvys, --, --,
   {{0x44f0161e,0x6602bf12,0xee3f0e43,0x00000000}},	//   _bà_, gbok, kným_, --,
   {{0x44f00019,0x7522bfb2,0xee3f0146,0x2c1f009f}},	//   _cà_, groz, jným_, _बयां_,
   {{0x44f0bfb3,0xee3f135f,0x69cfbfb4,0xb97a00ca}},	//   _dà_, dným_, _izce, _הנשי,
   {{0x8c4401d4,0x44f0009c,0xe9df00b3,0x6602010a}},	//   əşdi, _eà_, _taús_, bbok,
   {{0x44f00d79,0x6d5f0092,0x6a7117d2,0x316d0062}},	//   _fà_, _orqa, _påfy, txez_,
   {{0x44f06593,0x2735017a,0x661b12e6,0x74f81cfb}},	//   _gà_, lån_, _iduk, _метр_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5f388a,0x7bc5bfb5,0x317f00dc,0x81dc0033}},	//   _arqa, _nyhu, syuz_, তুল_,
   {{0xee3f0146,0xe3b2006e,0x00000000,0x00000000}},	//   bným_, _אױב_, --, --,
   {{0x81a71363,0x44f00023,0x0d836cce,0xee3f0094}},	//   _بحال, _xà_, елян, cným_,
   {{0xaff933e7,0x00000000,0x00000000,0x00000000}},	//   _افغا_, --, --, --,
   {{0x3d1804f1,0x39425412,0x7bc50178,0x661b063d}},	//   _भटके_, _spks_, _cyhu, _oduk,
   {{0x64860088,0x661b03a9,0x2a790178,0x7bc503a8}},	//   _aðil, _nduk, _cosb_, _dyhu,
   {{0xd9433f1d,0xa9670ac6,0xaec3008f,0x387802c3}},	// [ee60] нети, пита_, _ябъл, _porr_,
   {{0x3ea20331,0x44f0a33e,0xbcfb08a8,0x13e30081}},	//   likt_, _rà_, rxét, নুয়,
   {{0xb8f31362,0x44f0026e,0x2d82057a,0x443e0449}},	//   _ही_, _sà_, lyke_, _rbt_,
   {{0x44f0662b,0xe7ee0251,0xe7b300cd,0x443e0161}},	//   _pà_, _जलवा_, رمند, _sbt_,
   {{0x3878aa3a,0x443e00dc,0x661b06b0,0x00000000}},	//   _torr_, _pbt_, _dduk, --,
   {{0x44f0561d,0x628b01ce,0x3ea20ab2,0x2900aeef}},	//   _và_, _algo, hikt_, mpia_,
   {{0x44f00649,0xf7430e2d,0xe727002d,0xe7e30c17}},	//   _wà_, _перо, _норд_, _कृपा_,
   {{0x44f0bfb6,0xee3f025b,0x60f82a6e,0x443e00dc}},	//   _tà_, tným_, ония_, _wbt_,
   {{0x7ae64948,0x8506037f,0x6d44023e,0x629c0138}},	//   _mikt, _روان, _npia, _įrod,
   {{0x672308a9,0xf8be1827,0x628b4613,0x7ae6bfb7}},	//   šnje, ्तिय, _elgo, _likt,
   {{0x3d0f009d,0x74130f36,0x644abfb8,0xee3f0146}},	//   तीने_, _سونا, mefi, sným_,
   {{0x7ae6bfb9,0x6458bfba,0xd24f001c,0x29000085}},	//   _nikt, ldvi, _منم_, kpia_,
   {{0xf8be00b7,0x601826fd,0xe80f00b6,0x00000000}},	//   ्ताय, _доля_, िरमा_, --,
   {{0x644abfbb,0x7ae6bfbc,0x39a300aa,0x7c2e1e8f}},	//   nefi, _aikt, _कs_, ggbr,
   {{0x3edf0134,0x7ae6bfbd,0x20180031,0x00000000}},	//   _amụọ_, _bikt, óriu_, --,
   {{0x644a0150,0x27350212,0x7bc500d4,0x78be0381}},	//   hefi, vån_, _vyhu, eopv,
   {{0x69c602b9,0x260b009f,0x2eee2423,0x78be02ac}},	// [ee70] _cyke, ारसी_, _huff_, fopv,
   {{0x644a5609,0x200e0022,0xed600138,0x69c60212}},	//   jefi, _jefi_, įžti_, _dyke,
   {{0x6d5d13b9,0x65600973,0xf3f1020b,0x00000000}},	//   lvsa, _armh, _lạc_, --,
   {{0x27350222,0x395200c2,0xfd620174,0x1a650103}},	//   rån_, änsä_, _nkwọ, _تیری_,
   {{0xee470031,0x69cf00e8,0x00000000,0x00000000}},	//   chýň_, _uzce, --, --,
   {{0xfd620134,0x644a3f2e,0x20c201cd,0x2eee0072}},	//   _akwọ, gefi, iðis_, _ouff_,
   {{0xe2990138,0x93bc020a,0xe738007b,0x66d10727}},	//   жай_, _scăr, _неё_, råkb,
   {{0x6aadbfbe,0x661bbfbf,0x645801cb,0x6e3d029a}},	//   nnaf, _uduk, advi, jfsb,
   {{0xd12e00e3,0x644a41f5,0xc4f808ba,0x3ea2169c}},	//   لمي_, befi, _فعلا_, vikt_,
   {{0x76593f0d,0x644abfc0,0xef192cf5,0x00000000}},	//   ldwy, cefi, омо_, --,
   {{0x6d44013d,0x200e0383,0x3ea201d3,0x68e7029a}},	//   _spia, _defi_, tikt_, _mijd,
   {{0x290002e5,0xaf981ad1,0x68e701c0,0xad9b003e}},	//   ypia_, ятых_, _lijd, rbún,
   {{0x7ae6bfc1,0xdb1e0146,0x3ea22548,0x61eb7a33}},	//   _rikt, _vypí, rikt_, _iggl,
   {{0x7ae6bfc2,0x3ea20f63,0x69c66692,0x2d82a366}},	//   _sikt, sikt_, _ryke, ryke_,
   {{0xfce34b32,0x644192cd,0x2005bc8a,0x7ae68817}},	//   торо, _mbli, mbli_, _pikt,
   {{0x764b0018,0x64580146,0x644a996b,0xfa67041f}},	//   jegy, zdvi, zefi, маск_,
   {{0x7ae60b6a,0x68e70126,0x765902ad,0x3ea00072}},	// [ee80] _vikt, _bijd, ddwy, _imit_,
   {{0x7ae6262a,0x69c600d8,0x00000000,0x00000000}},	//   _wikt, _vyke, --, --,
   {{0xd70a0565,0x7ae6bfc3,0xbcfb0018,0x78be0371}},	//   інде_, _tikt, tvég, ropv,
   {{0x29000e38,0x6441bfc4,0xb87b0161,0xd9100260}},	//   ppia_, _abli, _suít, _میر_,
   {{0x6aa40051,0x6441009c,0x644a0379,0x1fba16f8}},	//   miif, _bbli, tefi, _उड्ड,
   {{0x74140391,0xe1ff04d8,0x61eb0349,0x6aa4bfc5}},	//   روبا, ñón_, _aggl, liif,
   {{0x177902fd,0x3ea071f6,0x200e45f5,0x764bbfc6}},	//   _есть_, _omit_, _refi_, begy,
   {{0x68e701c0,0x2eee02ac,0x200e9fc7,0x6aa45b02}},	//   _zijd, _ruff_, _sefi_, niif,
   {{0x79849c74,0x321d0150,0xb87b002b,0xb97b006e}},	//   nyiw, _ddwy_, _guís, ַנטי,
   {{0x3ea00068,0x61eb7847,0x94230b21,0x61f903a8}},	//   _amit_, _eggl, _амфе, _efwl,
   {{0x98a900a5,0x9346004d,0x2fc700eb,0x61f9030a}},	//   stać_, _інде, _cyng_, _ffwl,
   {{0xbd6b1cb1,0x2ca301c0,0x644183ac,0xe2aa03c5}},	//   орге_, wijd_, _zbli, _باطن_,
   {{0x2ca30505,0x200504f9,0xbebd01d3,0x6aa4008c}},	//   tijd_, bbli_, brīn, diif,
   {{0x2eee0212,0x6d5d0537,0x00000000,0x00000000}},	//   _tuff_, rvsa, --, --,
   {{0x68e70ab2,0x2ca30126,0x8ff72729,0x00000000}},	//   _rijd, rijd_, _غرور_, --,
   {{0xbcfb0018,0xc98718d4,0x68e70350,0x3ea0033c}},	//   tvéd, музи, _sijd, _gmit_,
   {{0x6aad14dd,0x5ea400e3,0xb8330139,0x127b00c1}},	// [ee90] rnaf, _جميل, _ajúṣ, קאמע,
   {{0x7d0dbfc7,0xd795008f,0x212100a4,0x98a40284}},	//   _iwas, низъ, _मिसळ_, виђе,
   {{0x764bbfc8,0x7984010a,0x644509a1,0x00000000}},	//   tegy, ayiw, õhim, --,
   {{0x7d0dbfc9,0x29191528,0x68e701c0,0x35b52290}},	//   _kwas, _tvsa_, _wijd, нбер,
   {{0x68e70505,0x799600a5,0x76593f0d,0x764b3572}},	//   _tijd, czyw, rdwy, regy,
   {{0x7d0d2bf4,0x752b029a,0x00000000,0x00000000}},	//   _mwas, rugz, --, --,
   {{0x28be5fbb,0x56952917,0xa3d902d5,0x7d0d4944}},	//   ्तरि, _завт, ठें_, _lwas,
   {{0xd24e00e3,0xe3b01f11,0x67d4007e,0x7d0d4944}},	//   منى_, جره_, _росу, _owas,
   {{0x63530092,0xbebd00e8,0x7d0d4d16,0x2fc73f88}},	//   _mənə, trīn, _nwas, _syng_,
   {{0x3ea0bfca,0x644130e6,0x24995f34,0xa3d700aa}},	//   _smit_, _ubli, _عناد_, _सरप_,
   {{0x3dc9152a,0x7d0da4ac,0x20057b97,0x3f692105}},	//   _ayaw_, _awas, rbli_, чино_,
   {{0xdd1e00d3,0x7d0dbfcb,0x61eb152d,0x2018003e}},	//   _câşt, _bwas, _uggl, órir_,
   {{0x20c20102,0x5fd10d0d,0x224d0634,0xb80f0d61}},	//   rðir_, _हरवल, meek_, िराम_,
   {{0x224d0a00,0x7afe061d,0x317a0266,0x7d0d084e}},	//   leek_, _ptpt, _מאנד, _dwas,
   {{0xcb671067,0x60c100f9,0x7d0d74b5,0xceb9010a}},	//   наре_, molm, _ewas, guęs_,
   {{0x9f5e0094,0xa3d7009f,0x7d0d0154,0x60c10abd}},	//   natý_, _सरन_, _fwas, lolm,
   {{0x7d0d02e0,0x6aa493f5,0x00000000,0x00000000}},	// [eea0] _gwas, riif, --, --,
   {{0x6d563a13,0x224d01c0,0x79960034,0x9f5e0094}},	//   _isya, heek_, rzyw, hatý_,
   {{0xbcfb00fd,0x7ceb0078,0x3f85030a,0x4c8300d3}},	//   rvée, _iżra, nylu_, _слэв,
   {{0x60c1057e,0xe612010d,0x83fc0d62,0x9f5e0094}},	//   holm, اشا_, _inđi, jatý_,
   {{0x64a63ba4,0xe89b008e,0xa3e21d96,0x3dc9006c}},	//   нада, _çağı, नेन_, _xyaw_,
   {{0x672303ce,0x6d5600f9,0x39520150,0x66d1169c}},	//   šnja, _msya, mwys_, råka,
   {{0x39520150,0xe8be009d,0x851c5660,0xbebd00e8}},	//   lwys_, ्तीच, _निकट_, rtīz,
   {{0x66e30859,0x09e40081,0x224d875e,0x66e65136}},	//   _боса, _ফ্যা, geek_, _чоба,
   {{0xc05a2f0c,0xa3d40c54,0xf1db0096,0x395200f0}},	//   пін_, सेज_, मेलन, nwys_,
   {{0x7d0d0435,0x80ca007f,0x8937006e,0xf3f100fe}},	//   _rwas, _सीखे, עריע_, _hạn_,
   {{0x6d563487,0x6e9541c3,0x224d5c04,0x3f8a0094}},	//   _asya, вину, beek_, ábu_,
   {{0x645abfcc,0xf3ff00de,0x649401f7,0xdd9102a3}},	//   _hati, _đãi_, _bàig, لوج_,
   {{0x645a1a7e,0x83fc02ef,0x225100b6,0x60c10036}},	//   _kati, _anđi, ánků_, bolm,
   {{0x9f58bfcd,0x635301d4,0x60c11c9a,0x645a6c3c}},	//   úró_, _sənə, colm, _jati,
   {{0xaa674587,0x645a1641,0x5b241546,0xc87f042c}},	//   нтак, _mati, льта, _mußt_,
   {{0x645a154c,0x7d0dbfce,0x7af50063,0x8aa403fb}},	//   _lati, _twas, rqzt, груд,
   {{0x7e6dbfcf,0x7ebd0103,0x7d0d08c2,0xc984090f}},	// [eeb0] _inap, képz, _uwas, луфи,
   {{0x645abfd0,0x6f0d007f,0x7e6d01cd,0x00000000}},	//   _nati, _łaci, _hnap, --,
   {{0x7e6d032e,0xf3f100de,0x9f5e037a,0x649401b9}},	//   _knap, _bạn_, mató_, _màid,
   {{0x9f5e4d31,0x649401b5,0x224d875e,0xbddb0154}},	//   lató_, _làid, xeek_, beèt,
   {{0xddc400d3,0xdfc601dc,0x7e6d411d,0xe3b800a7}},	//   _iniţ, _چي_, _mnap, _axı_,
   {{0x645abfd1,0x224d159f,0x634a00a7,0xb4bb09a1}},	//   _cati, week_, _mənf, घवे_,
   {{0x60c1bfd2,0x224dbfd3,0x7e6d58c9,0x645a93c0}},	//   volm, teek_, _onap, _dati,
   {{0x9f5e0018,0x7e6d0134,0x752400cb,0x59d502d5}},	//   ható_, _nnap, šiza, _दरार,
   {{0xb3eb046b,0x224d4ad0,0x649401ec,0x28b8009f}},	//   _فعال_, reek_, _bàid, _आदमि,
   {{0x7e6dbfd4,0x224d022b,0xe7c5063c,0x628900f2}},	//   _anap, seek_, _वडाप, skeo,
   {{0x60c13660,0xb4cd0e28,0x765b006d,0x93270e27}},	//   rolm, रती_, _kauy, _سران,
   {{0x645abfd5,0x7e6d2ae3,0xdc0a0176,0x41750037}},	//   _zati, _cnap, वर्ड_, _لاتس,
   {{0x50b58b28,0xe1f01487,0x645abfd6,0x61fb71a5}},	//   _иску, _اسم_, _yati, mcul,
   {{0x6494064b,0x645a0092,0x765b0044,0x9f5e0103}},	//   _gàid, _xati, _lauy, gató_,
   {{0xaac6300d,0x80ca007f,0x00000000,0x00000000}},	//   نترن, _सीटे, --, --,
   {{0x765b006d,0x7e6d0036,0x00000000,0x00000000}},	//   _nauy, _gnap, --, --,
   {{0x61fb7ddd,0xea000023,0xc21200ca,0x66d802c6}},	// [eec0] icul, _ngất_, יהן_, níke,
   {{0xe9d73947,0x39520185,0x66ec0092,0x7c8519e8}},	//   тку_, rwys_, _aşka, _буџе,
   {{0x645abfd7,0xe3b804a8,0xc8b500c6,0x8c1b2252}},	//   _rati, _adın_, усты, _קוטי,
   {{0x9bb700a1,0x68ed013f,0x645a3f1f,0x067500ae}},	//   _יהיה_, _žodž, _sati, лучя,
   {{0x645abfd8,0x95530037,0x00000000,0x00000000}},	//   _pati, لخوا, --, --,
   {{0x645a2ce7,0x00000000,0x00000000,0x00000000}},	//   _qati, --, --, --,
   {{0x645abfd9,0x18a301b6,0x07a64d13,0x039600e5}},	//   _vati, _тарм, _равн, ърдя,
   {{0xcb1300a1,0x645abfda,0x35730018,0xaad8023a}},	//   בלה_, _wati, _چھوڑ, _भीमक,
   {{0x645abfdb,0x273c00da,0x649401b9,0xdb1e007b}},	//   _tati, lín_, _pàid, _hypä,
   {{0xdb1e007b,0x00000000,0x00000000,0x00000000}},	//   _kypä, --, --, --,
   {{0x273c7e4a,0x765b0113,0x00000000,0x00000000}},	//   nín_, _yauy, --, --,
   {{0xb2833566,0x6f1a225b,0x2902007e,0xad9b003e}},	//   _вышк, rstc, _otka_, lbúi,
   {{0x9f5e0018,0x7e6d033b,0x273c6130,0xd5e90065}},	//   tató_, _vnap, hín_, _ilẹ,
   {{0x273c3e6a,0x00000000,0x00000000,0x00000000}},	//   kín_, --, --, --,
   {{0x9f5e05fe,0x273c0220,0xe8d90134,0x6efe00e8}},	//   rató_, jín_, nyụ_, _bībe,
   {{0x316603ce,0x273c0181,0xd5fb0134,0x7761002b}},	//   _kroz_, dín_, _mmụ, _álxi,
   {{0x224600cd,0x2ab7003d,0x9f5e034f,0x00000000}},	// [eed0] _mbok_, għba_, pató_, --,
   {{0x7d1b2218,0x765b006d,0x273c3a4c,0x634a0092}},	//   áusu, _sauy, fín_, _kənd,
   {{0xb8fa1926,0x22460034,0x27e70212,0x8b671aaa}},	//   _डी_, _obok_, änn_, _شادم,
   {{0x672302e6,0xbebd01d3,0x634a00a7,0x31660062}},	//   šnjo, drīk, _zəng, _oroz_,
   {{0x454500e3,0x961d01d3,0x7c4a00f3,0x00000000}},	//   انتق, _noņe, _åprø, --,
   {{0xb4cd0e72,0x273cbfdc,0x85b80037,0x394b0a4b}},	//   रते_, bín_, خامس_, _ipcs_,
   {{0x44290f28,0x273cbfdd,0x765b0d2a,0x00000000}},	//   ğa_, cín_, _tauy, --,
   {{0x442907aa,0x31660106,0xf3f100fe,0xe8e000fe}},	//   şa_, _broz_, _tạo_, _đỉa_,
   {{0x83fc0095,0x101503fb,0x649401f7,0xddc6007f}},	//   _anđu, льня, _dàib, zekł,
   {{0x2055015f,0x44f90113,0x634a00a7,0x00000000}},	//   утир, _iè_, _bənd, --,
   {{0x7c380222,0x44f90019,0x9eaaa901,0x634a0092}},	//   _övri, _hè_, евна_, _rəng,
   {{0x44f935a6,0x00000000,0x00000000,0x00000000}},	//   _kè_, --, --, --,
   {{0x273c2299,0x25e60034,0x44f9026e,0x7c280850}},	//   zín_, जेपी_, _jè_, ódro,
   {{0x44f9388c,0x6cd600e3,0x225f649a,0x213f0063}},	//   _mè_, اقسا, lduk_, mtuh_,
   {{0x44f9bfde,0xeb9a0e38,0x273c8bf9,0x00000000}},	//   _lè_, хив_, xín_, --,
   {{0x225f26f7,0x273c0220,0xfaa313a4,0x00000000}},	//   nduk_, vín_, басо, --,
   {{0x213f005a,0x44f9bfdf,0x6e243532,0x66d10ec9}},	// [eee0] ntuh_, _nè_, _idib, råkl,
   {{0x273c386a,0x7d040169,0xc8ca046b,0xb4cd0d29}},	//   tín_, _itis, روان_, रतो_,
   {{0xfaa63a69,0xbcfb00fd,0xe7f5009f,0xa6e900fe}},	//   _бано, nvén, ेड़ा_, _thự,
   {{0x44f91b86,0x273c68ef,0x225fbfe0,0x2b5a00b3}},	//   _bè_, rín_, jduk_, _ispc_,
   {{0x76421d49,0x44f90451,0x81a80081,0x273c3176}},	//   rfoy, _cè_, _খুন_, sín_,
   {{0x44f935c4,0x2a60007a,0x273c6869,0x39400138}},	//   _dè_, ldib_, pín_, mtis_,
   {{0x3940bfe1,0x439401b3,0x66190034,0x6e240174}},	//   ltis_, райс, bawk, _odib,
   {{0x44f90c3e,0x7d0400cc,0x6e2421e9,0x6b81004d}},	//   _fè_, _otis, _ndib, ølgi,
   {{0x3940bfe2,0xc61006ed,0x225d03e5,0x68ee01c2}},	//   ntis_, ारीय_, _dawk_, _kibd,
   {{0x6e240a00,0x395700a1,0x68ee003d,0x39400138}},	//   _adib, נשים_, _jibd, itis_,
   {{0x7d04bfe3,0x394000aa,0x81e50033,0x68ee009e}},	//   _atis, htis_, বুল_, _mibd,
   {{0x39406c87,0x68ee041c,0x00000000,0x00000000}},	//   ktis_, _libd, --, --,
   {{0xb5fd2e85,0xeda700c8,0x2a600188,0x6e240150}},	//   _inšt, ушно, ddib_, _ddib,
   {{0x6e240092,0x3137040a,0xbebd01d3,0x68ee009e}},	//   _edib, _ערוך_, ksīg, _nibd,
   {{0x7d040073,0x39402224,0x7f580077,0x225d0113}},	//   _etis, etis_, _райс_, _yawk_,
   {{0x2b5a00b3,0x8c4400a7,0x00000000,0x00000000}},	//   _dspc_, əşmi, --, --,
   {{0xf8070b91,0x64480146,0x39400138,0x49750265}},	// [eef0] гчен, _obdi, gtis_, шлас,
   {{0xddc403ce,0x44f902b4,0x6d4dbfe4,0x634a0092}},	//   _uniš, _rè_, _ipaa, _mənb,
   {{0x44f93895,0x501b00a1,0x68ee0bb6,0x2a600bb6}},	//   _sè_, גובו, _dibd, bdib_,
   {{0x44f9bfe5,0x6448bfe6,0xb4bf0167,0x3940015e}},	//   _pè_, _abdi, ीत्_, btis_,
   {{0xbcfb0018,0xfd1f3535,0xd90f05bc,0xa3e21f88}},	//   zvén, nsì_, _ریا_, नेस_,
   {{0x29090084,0x638500c2,0x1abd0081,0x44f902f1}},	//   mpaa_, игла, _আওয়া, _vè_,
   {{0x44f97f63,0xe8d600a1,0x7af74c9f,0xe1f100e3}},	//   _wè_, _כושר_, _juxt, يسة_,
   {{0x44f93895,0x31250036,0x7af700a7,0x00000000}},	//   _tè_, адиг, _muxt, --,
   {{0x81a800c7,0x225fbfe7,0xdbe206e4,0x6fca00c3}},	//   _খুব_, rduk_, _खण्ड_, _सुबू,
   {{0xe8e00028,0x69cf20bb,0x656900f9,0x7c2503a9}},	//   _địa_, _myce, _ireh, _ndhr,
   {{0x7d04bfe8,0x6d4dbfe9,0x32552c37,0x6b4c0103}},	//   _stis, _apaa, _ввер, _mögö,
   {{0xbcfb0018,0x7c2503ea,0x3940bfea,0x6569bfeb}},	//   rvén, _adhr, ytis_, _kreh,
   {{0x76490051,0x69cf022b,0x46560142,0x00000000}},	//   _mbey, _nyce, בױרן_, --,
   {{0xafe50084,0xab2a4111,0xc19a00ca,0x7d049269}},	//   _колл, кога_, _בשני, _vtis,
   {{0x7649bfec,0x93bc00ae,0x44255853,0x6d4d1b99}},	//   _obey, _scăz, _mdl_, _epaa,
   {{0x3940bfed,0x44255675,0x656919d0,0x6926002d}},	//   ttis_, _ldl_, _oreh, имба,
   {{0x7d040542,0x7aef4768,0x78210096,0x4425030a}},	// [ef00] _utis, _dict, मणूक_, _odl_,
   {{0x3940bfee,0xed4f00cd,0x764905fb,0xdce45716}},	//   rtis_, _کپی_, _abey, _krič,
   {{0x3940bfef,0x7aef436f,0x649400b3,0x634a00a7}},	//   stis_, _fict, _nàia, _mənc,
   {{0x39407f41,0x05661a29,0x55061693,0x6569304e}},	//   ptis_, ивен, ачка, _breh,
   {{0x68ee03e5,0x7ae4b7c0,0x83fc007e,0x09e40033}},	//   _tibd, mmit, _lađe, _ফ্রা,
   {{0x656901bf,0x7ae443a6,0x3afc0023,0x7af7037a}},	//   _dreh, lmit, _kíp_, _yuxt,
   {{0x83fc1419,0x234809b4,0x4425209a,0xfdd302d5}},	//   _nađe, استی_, _ddl_, _सर्फ,
   {{0x7ae4bff0,0x6b8305fe,0x59ba02d5,0xa2ab0096}},	//   nmit, _ànge, _इशार, _जगण्,
   {{0x65697fdb,0x7ae457f2,0x3afcbff1,0x91c900b6}},	//   _greh, imit, _líp_, _हुदै,
   {{0x7ae41c49,0x4425020b,0x53a601b6,0x00000000}},	//   hmit, _gdl_, _казб, --,
   {{0x6d4d03ee,0xa3e22f4f,0x7e7d0063,0x260b0096}},	//   _spaa, नेश_, tjsp, ारची_,
   {{0x2d8b00a5,0x7ae40128,0x614601b3,0x6d4d06b0}},	//   tyce_, jmit, _веда, _ppaa,
   {{0xa3e21c0a,0x3eabbff2,0xa2ab1678,0x6f08044c}},	//   नेर_, rict_, _जगत्, spdc,
   {{0x634a01d4,0xc0e31231,0x7ae4650c,0x69cf007f}},	//   _gənc, _дочк, emit, _ryce,
   {{0x0b88534f,0x7aefa289,0x83fc0580,0x8aa77f3e}},	//   асти_, _pict, _gađe, арад,
   {{0x7ae4019c,0xbea41fdb,0xb5fdbff3,0x66d10b85}},	//   gmit, _мајк, _kaše, råkk,
   {{0x3ea90ea3,0x6b5c0160,0x7aef59bb,0xdd91001c}},	// [ef10] _imat_, _pågå, _vict, _رود_,
   {{0xa3d73212,0x7af7034f,0xf8070c9a,0x69cf0094}},	//   _सरल_, _tuxt, рчан, _vyce,
   {{0xd7f8007e,0x7ce00149,0x29090051,0x66ca0031}},	//   руу_, förf, spaa_, výkr,
   {{0xd24616cc,0x65690c00,0xb87b2226,0x290900c2}},	//   _عن_, _preh, _juíz, ppaa_,
   {{0x442510de,0xbebd00d9,0x00000000,0x00000000}},	//   _pdl_, brīv, --, --,
   {{0xbebd00d9,0x58d4008f,0xe7871aad,0xd7fb2fad}},	//   nsīb, _моят, _кубо, _шум_,
   {{0xd7950080,0x3ea90084,0xa3d70096,0xd763001c}},	//   _الأخ, _omat_, _सरळ_, _بنزی,
   {{0x16340ff8,0x83fc01ac,0xb5fd6ed0,0xfbb8040a}},	//   _меся, _rađe, _baše, יפות_,
   {{0x83fc14f3,0x798dbff4,0x320d56c6,0xf3f100de}},	//   _sađe, nyaw, rbey_, _lại_,
   {{0xdce40954,0x3ea96ec5,0xf1b908a9,0x7ae42091}},	//   _prič, _amat_, jaše_, zmit,
   {{0xb4e3250d,0xd3a78d96,0xaec67a20,0xf1b9015c}},	//   नगी_, _трап, йбол, daše_,
   {{0x1d0a2363,0xbebd00d9,0x212d023b,0x24850073}},	//   леми_, esīb, preh_, _holm_,
   {{0x2485007a,0x41291352,0x26cd0a4b,0xaa7b0094}},	//   _kolm_, _соло_, _mkeo_, _ohýb,
   {{0xdce4025b,0xfc0354b5,0xf1b9050d,0x3ea903a9}},	//   _trič, зпро, gaše_, _emat_,
   {{0x634a0092,0xeb970b21,0x7ae41c49,0xdca312d3}},	//   _kəna, бир_, tmit, чари,
   {{0xed5a545a,0x629b00c2,0x6d41020a,0x6aad6739}},	//   _бои_, nhuo, ălar, giaf,
   {{0xe9da0c58,0x634a0092,0xc3110033,0x7c96001c}},	// [ef20] ука_, _məna, সূচি_, _هشدا,
   {{0xc61004f8,0xaa7b0220,0x3afc00fe,0x7d7b0266}},	//   ार्य_, _chýb, _típ_, _עניו,
   {{0x41ce030b,0x98a002ef,0x91c95dfe,0x798d0172}},	//   _हुनस, hrić_, _हुसै, ayaw,
   {{0x26df0010,0x98a00284,0xb87b03be,0x649401f7}},	//   _chuo_, krić_, _xuíz, _càin,
   {{0x98a00b14,0x6494009c,0x798d0027,0x68e5009c}},	//   jrić_, _dàin, cyaw, bmhd,
   {{0xb8960080,0x98a0005f,0x6494009c,0x24851ac3}},	//   _السع, drić_, _eàin, _colm_,
   {{0xa3e206eb,0x649401f7,0x7ddf0065,0xa278007b}},	//   नें_, _fàin, _kàsí, ибку_,
   {{0xe6431a54,0xb5fd1d80,0x634a00a7,0x2ee00350}},	//   _несп, _paše, _cəna, _nhif_,
   {{0xd01000e3,0xb5fd0211,0x66d80146,0x90986bef}},	//   ولة_, _inšp, líko, ивит_,
   {{0xb87b03be,0x3ea9258e,0x26df01c2,0x656f002b}},	//   _suíz, _smat_, _zhuo_, _ácha,
   {{0x66d8025b,0x443e5675,0xbebd01d3,0xf1b90580}},	//   níko, _ict_, krīt, vaše_,
   {{0x6602bff5,0x7d160150,0x7ce0160c,0x05dc0abe}},	//   ncok, _bwys, hörd, _बराब,
   {{0xf1b90106,0x60c869ed,0xdceb0031,0x443e0131}},	//   taše_, podm, žičo, _kct_,
   {{0x672300e9,0xc0aa0177,0x98a90995,0xfaf30037}},	//   šnji, _حاصل_, trač_, كثر_,
   {{0x201ebff6,0x66020167,0xf1b9004b,0x6aadbff7}},	//   mati_, kcok, raše_, tiaf,
   {{0x201ebff8,0x3ea94263,0x7d790018,0x66d82347}},	//   lati_, _umat_, _نمبر_, díko,
   {{0x443ebff9,0x7ce01683,0x64940441,0xad9b01cd}},	// [ef30] _oct_, förd, _ràin, rbús,
   {{0x798db121,0x81e50081,0x6d5f17f4,0x443eb294}},	//   ryaw, বুক_, _isqa, _nct_,
   {{0x23a71362,0x798d1613,0xadfd009f,0x69c10034}},	//   _केंद, syaw, _एलान_, _śled,
   {{0x3eb949bf,0xf770003f,0x443e00ca,0x7ddf0032}},	//   nnst_, عال_, _act_, _gàsí,
   {{0x201ebffa,0x2a3a0130,0xa2c7397e,0x3eb900a1}},	//   kati_, _דערמ, ावस्, inst_,
   {{0x98a00335,0xd4691d2f,0x634a00a7,0x443e0503}},	//   vrić_, рике_, _səna, _cct_,
   {{0xa5c300a5,0x629b46d9,0x752201ff,0xd6db00e5}},	//   _łódz, thuo, asoz, _бта_,
   {{0xcfce00c7,0x3863bffb,0x98a00a9e,0x7ce00ee2}},	//   রধান, _hajr_, trić_, möre,
   {{0x443e0072,0xaca30174,0x2ee00150,0x386302a1}},	//   _fct_, _alọg, _rhif_, _kajr_,
   {{0x201ebffc,0x2ed20d61,0xaca30129,0x3eb93f15}},	//   gati_, सत्त, _blọg, enst_,
   {{0x661b0ab2,0x6d5f43b5,0x56b500c1,0x09ad0033}},	//   _keuk, _asqa, ַפֿן_, _কুমা,
   {{0x7d1602ad,0x25f00fef,0x7af80103,0x661b112f}},	//   _pwys, ुँची_, _évti, _jeuk,
   {{0x7ce001bf,0x7c3e007e,0x661b0231,0xb5fd05db}},	//   höre, _pcpr, _meuk, _zašc,
   {{0x201ebffd,0x661b643b,0xb87b015e,0x7ce00ee2}},	//   cati_, _leuk, _guíx, köre,
   {{0xe51904dd,0x28bf1dae,0x46c900b6,0x00000000}},	//   नीति_, ्वनि, िकाह, --,
   {{0x83fc00e9,0x661bbffe,0x2dcb0294,0xd01e0033}},	//   _mađa, _neuk, ụlọ_, _দায়_,
   {{0xed5a29ab,0xd9435b80,0x649401f7,0x7ce0bfff}},	// [ef40] _топ_, мети, _bàil, törd,
   {{0x7ce00149,0x7e64c000,0x649401f7,0x2b3a00d3}},	//   före, _haip, _càil, _кямэ_,
   {{0x7e64c001,0x661b1030,0xc81500d6,0x7ce0c002}},	//   _kaip, _beuk, яєть, göre,
   {{0x7bde762e,0x443ec003,0x0eca097c,0x75220062}},	//   _izpu, _sct_, रविड, tsoz,
   {{0x7e6420c1,0x661b3694,0x634a00a7,0xddcd008b}},	//   _maip, _deuk, _cənn, _maaş,
   {{0x7e64c004,0x6d4602fa,0x6c7a00c1,0x62994c80}},	//   _laip, itka, שאַפ, _alwo,
   {{0x6d464f97,0x0eca0e19,0x00000000,0x00000000}},	//   htka, रवाड, --, --,
   {{0x09de13b4,0x201e2d96,0x7e64c005,0x3a20c006}},	//   _मराठ, wati_, _naip, naip_,
   {{0x443e76ca,0x6d44023e,0xa50744ab,0x6d4654ec}},	//   _tct_, _nqia, _мета_, jtka,
   {{0xdb1e025a,0x7e767cf1,0xf4870100,0xb87b0072}},	//   _expé, _anyp, _والی, _quíx,
   {{0xd7d002e8,0x7e640174,0x83fc0335,0xe3e800cd}},	//   _तुमच, _baip, _gađa, _اکشن_,
   {{0xb5fd08a9,0x7e64c007,0xeeaba0e8,0xbcfb0076}},	//   _kaša, _caip, рток_, lvéi,
   {{0x201e0947,0xb5fd08a9,0x6fca17d3,0x649401b5}},	//   pati_, _jaša, _सुरू, _làim,
   {{0xcce7054f,0x64583ad7,0xb5fd02ef,0x29000085}},	//   تسجي, nevi, _maša, dqia_,
   {{0x6d4606ee,0xf1b90580,0x7ce00149,0x6e951e9e}},	//   atka, maša_, förb, _нику,
   {{0x201c0a39,0x386d04a8,0x65600381,0x649401f7}},	//   _hevi_, _şer_, _osmh, _sàil,
   {{0xb5fd1419,0x6458022a,0x14ca02c6,0x649401b9}},	// [ef50] _naša, kevi, ाकाण, _pàil,
   {{0x64581a36,0xf1b90660,0x7ce00704,0xb9200134}},	//   jevi, naša_, töre, larị_,
   {{0x6560009c,0x2bd20096,0x7e640a4b,0x661b007b}},	//   _asmh, _दुपा, _yaip, _peuk,
   {{0x6e3d0e74,0x201c08d0,0x83fc0106,0xb5fd09ac}},	//   ngsb, _levi_, _rađa, _baša,
   {{0x260a000f,0x3d0f009d,0xeabf0065,0x7ce002c3}},	//   ाड़ी_, तीचे_, _ijù_, söre,
   {{0x64580371,0xf1b900cb,0xb5fd0559,0xb92000ac}},	//   gevi, jaša_, _daša, harị_,
   {{0x661b366c,0x68fd0bc6,0xb92000ac,0xa3570281}},	//   _teuk, _husd, karị_, تیاط_,
   {{0x201c02ef,0x3bbc00a1,0x644a028d,0x67255458}},	//   _aevi_, ימוד, affi, mshj,
   {{0xdb0a0074,0x64580ac9,0x201c7f71,0x200903e3}},	//   čnéh, bevi, _bevi_, _ƙai_,
   {{0xd24e00d0,0x64587f2c,0x201c0cf0,0xf1b9031a}},	//   پنی_, cevi, _cevi_, gaša_,
   {{0x201cc008,0x7e64c009,0x4abd0ded,0x644157b0}},	//   _devi_, _paip, ्काव, _icli,
   {{0xed5a248d,0x6d4605c4,0x765900f0,0x649d00ee}},	//   бом_, ttka, newy, _dèie,
   {{0xdd92012b,0x239001d3,0xf1b9015c,0x6d46ab49}},	//   روس_, _vējš_, baša_, utka,
   {{0x8fa53947,0xe0d8004d,0x7e640a4b,0x649d00ee}},	//   _нале, _дві_, _waip, _fèie,
   {{0x68fd02e2,0x3a20013f,0x7e64b145,0xeb970058}},	//   _ausd, taip_, _taip, пир_,
   {{0x68f500d9,0x67256265,0x7fe800b9,0x244f0e63}},	//   _aizd, dshj, _ظروف_, lımı_,
   {{0x68f507aa,0x645801d4,0xdeb700a1,0x3a200037}},	// [ef60] _bizd, yevi, _מפקח_, raip_,
   {{0x244f0587,0x29000052,0xeabf0139,0xf1ce009f}},	//   nımı_, rqia_, _ejù_, _हँसन,
   {{0x68f50431,0xabfb0327,0xdb240421,0x645821ad}},	//   _dizd, _להיר, _توجی, vevi,
   {{0xb5fd282c,0x76590313,0x7b050031,0x6441c00a}},	//   _paša, gewy, žuté, _acli,
   {{0x244f01e8,0x68fd0085,0x2007adcb,0x00000000}},	//   kımı_, _gusd, _ofni_, --,
   {{0x64a35951,0x7afe01e5,0xb4d61fbb,0xb5fd2a6c}},	//   нача, _kupt, सते_, _vaša,
   {{0x289b00f5,0x2f01c00b,0x201c0383,0x644a00f0}},	//   _פילא, _nóg_, _revi_, rffi,
   {{0x6458c00c,0x201cc00d,0x20070167,0x4ece0033}},	//   sevi, _sevi_, _afni_, রগুল,
   {{0x7afe002d,0xe5a300ae,0x00000000,0x00000000}},	//   _lupt, _зити, --, --,
   {{0x2bd20b94,0x67220029,0xf8cc00a5,0x5f941300}},	//   _दुभा, ņoju, ़किय, диот,
   {{0x442c44d8,0x7afe1ae5,0xb5fd2a4e,0xf1b9191d}},	//   _idd_, _nupt, _mašn, raša_,
   {{0x20070102,0x3f820995,0x649d00b3,0x321d0f5a}},	//   _efni_, ćku_, _vèie, _gewy_,
   {{0x201c2780,0x3ea4023b,0x6d5d01c0,0x442c037a}},	//   _tevi_, ëjta_, uwsa, _kdd_,
   {{0xe7be16f8,0x68fdc00e,0x67250216,0x442c014b}},	//   ्थाप, _rusd, yshj, _jdd_,
   {{0x442c006d,0x7afe00d3,0x66d80088,0xb9200134}},	//   _mdd_, _cupt, ríkj, parị_,
   {{0x62860673,0x68f50511,0x68fd82c1,0x442c1175}},	//   ökoh, _sizd, _pusd, _ldd_,
   {{0x83fc00cc,0x68f5c00f,0xf8b10260,0x6e2d3cc2}},	// [ef70] _nađo, _pizd, نکس_, _idab,
   {{0x7d0d753b,0xb4d60096,0xd7fb083c,0x00000000}},	//   _itas, सतो_, суа_, --,
   {{0x59f902fd,0xf0930130,0x7afe0849,0xb5fd00e7}},	//   _меня_, ענע_, _gupt, _dašn,
   {{0x442c0054,0x940c01d4,0xe7301629,0xddcd0087}},	//   _add_, _ildə_, اصل_, _znaš,
   {{0x290b0018,0xd12600b1,0xb5fd0234,0x442c014b}},	//   _utca_, _جم_, _fašn, _bdd_,
   {{0x2a690006,0x39491fb2,0xddcd010a,0x442c00fd}},	//   ldab_, mtas_, _abaŋ, _cdd_,
   {{0x3949c010,0x6e2d02e6,0x64410332,0x22980113}},	//   ltas_, _odab, _vcli, _céko_,
   {{0x442c10f8,0x2a690006,0x7d0d010a,0x3949013f}},	//   _edd_, ndab_, _otas, otas_,
   {{0x3949c011,0x244f008b,0x7d0d02a4,0x7ce00212}},	//   ntas_, tımı_, _ntas, höra,
   {{0x26cfc012,0x6e2dc013,0xe8d90857,0x2f010076}},	//   logo_, _adab, kwọ_, _póg_,
   {{0xd25100e3,0x244f0587,0x09ba0789,0x3949c014}},	//   _لنا_, rımı_, _इश्य, htas_,
   {{0x3949b5dc,0x26cf8d88,0xddcd0106,0x2a69023e}},	//   ktas_, nogo_, _snaš, jdab_,
   {{0xe0ce57d7,0x7afe0106,0x244f026a,0x50450396}},	//   _ав_, _supt, pımı_, _желб,
   {{0x442cb08a,0x7ce00149,0x26cfa738,0xa283001c}},	//   _xdd_, föra, hogo_, _آیکو,
   {{0xcee90e8c,0x38ad0253,0x316d44c2,0xb5fd0941}},	//   ترین_, _görə_, lvez_, _našo,
   {{0x628bc015,0xa3e22ebd,0x39494c2a,0x3b07001f}},	//   _jogo, नेट_, ftas_, ќето_,
   {{0x628b0b27,0x26cf068d,0x3949c016,0xb5fdc017}},	// [ef80] _mogo, dogo_, gtas_, _pašn,
   {{0x6609c018,0xddc40244,0x316d020d,0x2a79039f}},	//   _afek, _kniž, ivez_, _ensb_,
   {{0x3949c019,0x26cf1097,0xfaa60138,0x75294fb1}},	//   atas_, fogo_, _жано, _avez,
   {{0x628b3089,0x26cf1801,0xbc3a0103,0x00000000}},	//   _nogo, gogo_, _اسکا_, --,
   {{0x394909d3,0x64a6273f,0x6d940220,0xb5fd3360}},	//   ctas_, мада, _fľaš, _tašn,
   {{0x628b0350,0x69c60090,0x6d560350,0x291218fd}},	//   _aogo, _ixke, _mpya, mpya_,
   {{0x628bc01a,0x7529c01b,0xbcfb0018,0x26cf7541}},	//   _bogo, _evez, lvét, bogo_,
   {{0x628b1ba6,0x22428afe,0xf99f022b,0xa686013f}},	//   _cogo, ükk_, _ofèl_, _ўлад,
   {{0x041d0081,0x442c022b,0xb5fd0094,0x50f4336f}},	//   _নারী_, _tdd_, _mašl, нзит,
   {{0x442c066a,0x297b0142,0x00000000,0x00000000}},	//   _udd_, קטיא, --, --,
   {{0x7529b41d,0x7d0d9044,0xf83700a1,0x628b687e}},	//   _zvez, _stas, ונית_, _fogo,
   {{0xe7e60067,0x628b02a7,0x3949013f,0x634a0092}},	//   _करना_, _gogo, ytas_, _lənk,
   {{0x41e2034d,0xf1e200df,0x3949065b,0x7bda41ba}},	//   _परिस, _परिन, xtas_, ütun,
   {{0xa3e5049d,0xdb1e0072,0xba1700b6,0x7ce01b80}},	//   _नरम_, _expí, तर्फ_, töra,
   {{0xdfd000e3,0xb5fd00e7,0x1bd4117a,0x2a790063}},	//   _حيث_, _bašl, воря, _pnsb_,
   {{0x628ba322,0x3949084d,0x2eca000c,0xdced0335}},	//   _xogo, ttas_, रवृत, _irač,
   {{0xdced0074,0xddc40211,0x39496ad3,0x7d0dc01c}},	// [ef90] _hrač, _zniž, utas_, _utas,
   {{0x7bc50d7d,0x7bc0020e,0xb5fd3e30,0xdced05db}},	//   _txhu, ğmur, _pašo, _krač,
   {{0xe7ea007d,0x870400d6,0x26cf0169,0xea0000fe}},	//   झेला_, вяче, togo_, _ngặt_,
   {{0x39492e2d,0xdced08c5,0xb5fd7306,0xa3e2030b}},	//   ptas_, _mrač, _vašo, नेछ_,
   {{0x6abd0179,0xdd320092,0xd90f0260,0x27ff0233}},	//   ्कीर, _məşq, _ضیا_, _şunu_,
   {{0xd91a00a1,0xb5fd1999,0x7ce017a5,0xb4c9007f}},	//   _מושל, _zašl, hörn, ईवे_,
   {{0x628b02fb,0x7ce0186b,0x61e2063d,0xe29901b6}},	//   _pogo, körn, _azol, зай_,
   {{0xc245185c,0x7ce00088,0x28bf896a,0x26d90042}},	//   хник, jörn, ्ववि, _óso_,
   {{0x316d025a,0x628b1528,0x75294f05,0xddc479dc}},	//   uvez_, _vogo, _uvez, _sniž,
   {{0xdced084f,0x93bc00d3,0x316d416f,0x66d801cd}},	//   _brač, _adău, rvez_, víki,
   {{0x7aed048e,0xc0a80fb7,0x628bc01d,0xe7e30096}},	//   kmat, بايل_, _togo, केचा_,
   {{0xed5a1c58,0xdced16aa,0xf7720142,0x628b00c6}},	//   пом_, _drač, אקט_, _uogo,
   {{0x7aedc01e,0xdb0a030b,0xb5fd031a,0x8d760037}},	//   dmat, čníh, _našm, راحا,
   {{0xddc402a1,0x66d8003e,0xdced0141,0x75f60342}},	//   _iniż, ríki, _frač, _hüzü,
   {{0xdced0039,0xb5fd01d3,0x25a60063,0x00000000}},	//   _grač, _pašl, zzol_, --,
   {{0xb866010d,0xdce40a39,0x00000000,0x00000000}},	//   کارو, _orić, --, --,
   {{0xdced2a1e,0x6e26c01f,0x510c006e,0x38a40364}},	// [efa0] _zrač, makb, ַהאַ, _jörg_,
   {{0x6e26c020,0x7aedc021,0x07a621b9,0x38a40088}},	//   lakb, amat, назн, _mörg_,
   {{0x6f0b00d3,0xb5fd00e7,0x3ea019c2,0x7aed71da}},	//   _încă, _tašl, _klit_, bmat,
   {{0xd7ef0037,0xe1e71516,0x98c0026a,0x6e261193}},	//   حكم_, _مس_, ırıp_, nakb,
   {{0xbcfbc022,0x3ea00090,0x66d10727,0x6aa4024a}},	//   lvér, _mlit_, råkp, mhif,
   {{0xf3661da3,0x34ca009f,0x3ea00428,0x6e26c023}},	//   етин, ाकेद, _llit_, hakb,
   {{0x61e20068,0xbcfb03be,0xcc3b006e,0x37e30120}},	//   _szol, nvér, לעסט, _борг,
   {{0x2902c024,0x754901f9,0x00000000,0x00000000}},	//   _kuka_, öszö, --, --,
   {{0x5bbd1677,0x634a01d4,0x6e2609a4,0x75f6013c}},	//   _ईश्व, _məni, dakb, _düzü,
   {{0x2902c025,0x3ea000cd,0xdced1405,0x3a2203a9}},	//   _muka_, _alit_, _prač, _lekp_,
   {{0x93aa071c,0xdfd00037,0x7ce08a94,0xda200d75}},	//   _عاطف_, شيح_, törn, बरात_,
   {{0xdced2956,0x76424864,0x7aed026d,0x7ce002c3}},	//   _vrač, ngoy, xmat, föro,
   {{0x7aed645c,0x656201bf,0xf8bf00b6,0x6aa447c3}},	//   vmat, nwoh, _svém_, dhif,
   {{0xe04a00bf,0x7aedc026,0x673e5b92,0x7eb64582}},	//   _رشته_, wmat, kupj, ršpa,
   {{0x7aed5d92,0x75f601e8,0xdced0335,0x29020c09}},	//   tmat, _yüzü, _urač, _auka_,
   {{0x2902048e,0xb5fd01d3,0x6aa40036,0x7aed4433}},	//   _buka_, _pašm, ghif, umat,
   {{0x7aed0dfc,0x200b0067,0x1958055b,0x29020899}},	// [efb0] rmat, ście_, наты_, _cuka_,
   {{0x290225fe,0x290f00d9,0x26c408c5,0xc6190e52}},	//   _duka_, īga_, _ajmo_, दर्य_,
   {{0x7aed00b7,0xdce40234,0x00000000,0x00000000}},	//   pmat, _srić, --, --,
   {{0x6aa45f27,0xd7c801c3,0x29026111,0xdce40995}},	//   chif, رونه_, _fuka_, _prić,
   {{0x386a1a6b,0xd4690da5,0x00000000,0x00000000}},	//   _fabr_, диле_, --, --,
   {{0x22980088,0x64cbac22,0x34cb030b,0x75f60555}},	//   _fékk_, िवेश, िवेद, _süzü,
   {{0x64a20084,0x753c00d9,0x29020afe,0x38a400a7}},	//   раща, _ārze, _zuka_, _dörd_,
   {{0xe7e60f73,0xb5fd69ed,0x22460113,0x3959026a}},	//   _करता_, _mašk, _ccok_, _kpss_,
   {{0x7ce05fb7,0x44f50204,0xb5fd033b,0x98a9007f}},	//   förl, _апас, _lašk, grać_,
   {{0xd3a71d7b,0x2ebc0640,0xf99f0154,0x05b600b6}},	//   _преп, ोक्त, _afèk_, _आइतब,
   {{0x6e260bb6,0xb5fd00cc,0x09de277c,0x6494009c}},	//   takb, _našk, _मर्य, _càiu,
   {{0x98a900a5,0x39590063,0x6443075b,0x2bd5278e}},	//   brać_, _opss_, lgni, _धड़ा,
   {{0x6145139c,0x39590d62,0x442701e9,0x38a40364}},	//   _рела, _npss_, oan_, _höre_,
   {{0x634a0092,0xfce6117c,0x7f850076,0x00000000}},	//   _səni, того, _للتن, --,
   {{0x29022612,0x44272c5c,0x644331b5,0x6e260096}},	//   _suka_, ian_, igni, pakb,
   {{0xdd921857,0x3ea000a6,0x629b02e3,0xc33200ca}},	//   _نوع_, _ulit_, nkuo, יול_,
   {{0x44270496,0x6f0377df,0x7c273e0b,0x2a6b0350}},	// [efc0] kan_, _hunc, bajr, _dacb_,
   {{0x6f03113a,0x6aa4151c,0x38cb0470,0x6e2400f0}},	//   _kunc, shif, والی_, _heib,
   {{0x7d0404ee,0x6e2402fa,0x29020022,0x213f0063}},	//   _huis, _keib, _wuka_, huuh_,
   {{0x6f03c027,0x7d040010,0x29026590,0x4427c028}},	//   _munc, _kuis, _tuka_, ean_,
   {{0x4427c029,0x7d040ab2,0x764248d9,0xa0270033}},	//   fan_, _juis, rgoy, _মানব_,
   {{0x7d048978,0x6e24b1b9,0x44270d18,0x64430222}},	//   _muis, _leib, gan_, ggni,
   {{0x6f030b0b,0x7d043ba3,0x61f70092,0x3940c02a}},	//   _nunc, _luis, əblə, luis_,
   {{0x68fc0068,0x4427c02b,0x83fc042d,0x7d04014b}},	//   _hird, aan_, _mađi, _ouis,
   {{0x442700db,0x394095ac,0x7ce0a719,0x7d0424f9}},	//   ban_, nuis_, törl, _nuis,
   {{0x442755aa,0x38a40222,0x2ee9005c,0x7ce00704}},	//   can_, _före_, _shaf_, förm,
   {{0x38a40b88,0x6f03c02c,0xc2462863,0x39406bb5}},	//   _göre_, _cunc, _анек, huis_,
   {{0x6f03c02d,0x52761363,0x6e241de1,0x7d0427aa}},	//   _dunc, _جائز, _ceib, _buis,
   {{0x7d045d38,0x6f0300b3,0x00000000,0x00000000}},	//   _cuis, _eunc, --, --,
   {{0x7d0435a5,0xb5fd3b97,0x6abd16f8,0xd1970796}},	//   _duis, _pašk, ्क्र, _בכדי_,
   {{0x7d04c02e,0x6f03c02f,0x99bf0081,0x644800e7}},	//   _euis, _gunc, _আরেক, _mcdi,
   {{0x4427057c,0x5a342046,0x7d041a70,0x68fc0a1b}},	//   zan_, инст, _fuis, _aird,
   {{0x3eb905a7,0x7d040575,0x497502e3,0x3940c030}},	// [efd0] mist_, _guis, ылас, guis_,
   {{0x3eb9c031,0x4427c032,0xb5fd998d,0x7e6d0673}},	//   list_, xan_, _tašk, _haap,
   {{0x4427c033,0x7e6dc034,0xb5fd0b18,0x68fc1f2a}},	//   van_, _kaap, _haši, _dird,
   {{0xb5fd0542,0x7e6d5da0,0x68fc0a9a,0x39401cab}},	//   _kaši, _jaap, _eird, buis_,
   {{0x4427c035,0x7e6d1494,0x6d4f054e,0x29844f3d}},	//   tan_, _maap, ntca, _кырг,
   {{0xb5fd6725,0xdfc60080,0x44271e90,0x67d5100c}},	//   _maši, _هي_, uan_, _богу,
   {{0x7c253f29,0x225f00a4,0x3eb9c036,0x6443c037}},	//   _mehr, teuk_, kist_, rgni,
   {{0x44273aa8,0x36d58a24,0x569401b3,0x69ddc038}},	//   san_, _собр, _каст, _kyse,
   {{0x6f030335,0x6e249952,0x7c2501c2,0x225f1570}},	//   _sunc, _reib, _oehr, reuk_,
   {{0x6f03c039,0xb5fda13a,0x4427a8d2,0xf99200a1}},	//   _punc, _naši, qan_, צרי_,
   {{0x69dd02fe,0x7d049024,0x7ea63964,0x7ce00149}},	//   _lyse, _suis, _lópe, börj,
   {{0x3eb9c03a,0x44253988,0xbddb05fe,0x6d4f201b}},	//   gist_, _hel_, rgèn, ftca,
   {{0x4425c03b,0x7d045ec0,0x69dd8b85,0xb5fd0fa3}},	//   _kel_, _quis, _nyse, _baši,
   {{0x442502e6,0x7afdc03c,0x3ebe0068,0xe8bf000c}},	//   _jel_, _aist, őtt_, ्वोच,
   {{0x7c25003d,0xc05200a1,0x69dd0555,0x3eb9c03d}},	//   _dehr, _הזו_, _ayse, bist_,
   {{0x7d04c03e,0x68fc7b5d,0x44257683,0x69dd3b07}},	//   _tuis, _sird, _lel_, _byse,
   {{0x7afdc03f,0x6d4f01cb,0x3edb00c1,0xee371402}},	// [efe0] _dist, ctca, _אַזא, _сны_,
   {{0x44250020,0xe9d798c8,0x3b861087,0x7afd02ad}},	//   _nel_, уку_, _блог, _eist,
   {{0x7afd8cd6,0x6ac60f43,0x656912ac,0x68fc8029}},	//   _fist, _مقدم, _aseh, _vird,
   {{0x394004ea,0x7afdc040,0x5f060da9,0xfbd300a1}},	//   puis_, _gist, _संस्_, _לתת_,
   {{0xe7e60251,0x68fc00d9,0x3940c041,0x69ddc042}},	//   _करवा_, _tird, quis_, _gyse,
   {{0x4425c043,0x7afd0181,0xb4ce0de7,0x00000000}},	//   _cel_, _zist, रवे_, --,
   {{0x44255398,0xc8db00a1,0x64940441,0x07d8001c}},	//   _del_, _נקלט, _bàir, _شهرک_,
   {{0x7afd1f09,0x4425194a,0x649401f7,0x7ce002c3}},	//   _xist, _eel_, _càir, förk,
   {{0x44254ff7,0xe6930080,0x09c40033,0x2bdb1e93}},	//   _fel_, _القد, ্ধকা, _मुना,
   {{0x2e2400ef,0x7e6d01a5,0x649401b9,0x3eb966d1}},	//   _đườn, _saap, _eàir, wist_,
   {{0x32460f43,0x7e6d0d79,0xb5fd78ee,0x2d99057a}},	//   _مناف, _paap, _raši, wyse_,
   {{0x7c25c044,0x2d990138,0x80b6007a,0x64940441}},	//   _sehr, tyse_, _ऋगवे, _gàir,
   {{0x7afdc045,0x99bf0081,0x212b00e3,0xb5fd2c5a}},	//   _rist, _আর্ক, ácht_, _paši,
   {{0x2d99c046,0x200e1cb2,0x69dd99ec,0x30760291}},	//   ryse_, _uffi_, _ryse, _људс,
   {{0x3eb9c047,0x447b00c1,0x7e6d553d,0x709b006e}},	//   pist_, ענלע, _taap, _אױגו,
   {{0x7afd00dc,0x386101bf,0x7c250364,0xc9871c21}},	//   _qist, wehr_, _wehr, лузи,
   {{0xf1b96559,0x7afd0d63,0x7c25c048,0xe9df00da}},	// [eff0] taši_, _vist, _tehr, _gcúl_,
   {{0x7afd43bf,0x69dd0094,0xb4ce00b7,0x9c470120}},	//   _wist, _vyse, रवो_, _схил,
   {{0x7afdc049,0x69dd5a58,0x3a2907ac,0xa9240138}},	//   _tist, _wyse, paap_, _įžei,
   {{0x7afdc04a,0xaa671d62,0xd2460246,0xd00600d1}},	//   _uist, _сток, _ظن_, _ژل_,
   {{0x442516c8,0xa2b300a5,0xb5fd1523,0x7ce00212}},	//   _pel_, इफस्, _lašv, förh,
   {{0xd4910023,0x22980065,0x00000000,0x00000000}},	//   _tìm_, _méku_, --, --,
   {{0x442500bb,0xddc40138,0x98a00138,0x64940013}},	//   _vel_, _maiš, usią_, _pàir,
   {{0x44251f04,0xd6c34f89,0xddc4013f,0x65950fe3}},	//   _wel_, _امری, _laiš, _кабу,
   {{0x84470f43,0x38a40149,0x95cb07b3,0xf99f0154}},	//   _مخال, _höra_, _чува_, _efèv_,
   {{0x4425c04b,0x38a40222,0xddc408c5,0x409500c2}},	//   _uel_, _köra_, _naiš, ррит,
   {{0xaec600c2,0x5fcf0dba,0xdb2303a9,0x649401f7}},	//   ибол, _सुखल, _èrèn, _tàir,
   {{0x291d0174,0x531a00ca,0x7bde0154,0x6494009c}},	//   ̣waa_, _יועצ, _rypu, _uàir,
   {{0x2bdb000f,0x9fa2003e,0xee370243,0x7c3a0072}},	//   _मुबा, síða_, шня_, ótro,
   {{0x61e601e8,0x659a00c1,0x913a0266,0x7bde00b3}},	//   ükle, דישק, _יענק, _pypu,
   {{0x8a060870,0x00000000,0x00000000,0x00000000}},	//   изве, --, --, --,
   {{0x7bde0146,0xfd630294,0x6f0d00d4,0x00000000}},	//   _vypu, netị, _čach, --,

   {{0x7ce03224,0xd9462312,0xb5fd05db,0x7bde007f}},	// [f000] höri, рези, _zašv, _wypu,
   {{0xdbdf003e,0xddc417b1,0x00000000,0x00000000}},	//   _tíði, _gaiš, --, --,
   {{0x6e36030b,0x59d8049d,0xdc3b00ca,0x291f0216}},	//   _kdyb, _भँवर, _בעיר, _çuan_,
   {{0x98a02461,0xe737456f,0xb4ce0285,0x00000000}},	//   ksić_, рец_, रव्_, --,
   {{0x25a016cc,0xa80600c2,0x8e570266,0x7ce00339}},	//   áil_, _взгл, שינג_, törh,
   {{0x7ce05429,0xe71a08ba,0x38a40212,0xe4c33ac9}},	//   föri, _ليست_, _föra_, ойчи,
   {{0x38a4070a,0x25a0134c,0x395200c6,0xb7da00d1}},	//   _göra_, šil_, ltys_, _شورا_,
   {{0xcb1300a1,0x634a00a7,0x00000000,0x00000000}},	//   חלה_, _səns, --, --,
   {{0x395201b3,0xe5a302ec,0x04466368,0x00000000}},	//   ntys_, _дити, _везн, --,
   {{0xb5fd0029,0x92c80081,0xf1b91528,0xc95300d7}},	//   _pašv, োগে_, jašu_, קמת_,
   {{0x787900c1,0x228631d9,0x8c010033,0x645a066b}},	//   אָרו, _вулг, ্রমন_, _ibti,
   {{0x26c63075,0x00000000,0x00000000,0x00000000}},	//   nnoo_, --, --, --,
   {{0x62820188,0x1cbb0452,0x91e32a5f,0xfaff02ac}},	//   _inoo, ناسب_, _доце, _rië_,
   {{0x628201fa,0xfa230081,0xf1b90095,0x00000000}},	//   _hnoo, _ফাইল_, gašu_, --,
   {{0x62820371,0x601700ca,0x645a01ff,0xddc400c6}},	//   _knoo, _דחוף_, _mbti, _vaiš,
   {{0xb3450396,0xb5fd5eb6,0x6e360034,0x38a40212}},	//   luçã, _kašt, _gdyb, _röra_,
   {{0xf8071681,0x645ac04c,0xb5fd8315,0x62820095}},	// [f010] ачен, _obti, _jašt, _mnoo,
   {{0x2bd20e72,0xb5fd005f,0x645e00aa,0x6b9c01cd}},	//   _दुका, _mašt, õpil, byrg,
   {{0x62820517,0xb065007b,0xb5fd2c06,0x7ea601cd}},	//   _onoo, lmää, _lašt, _hópa,
   {{0x645ac04d,0x7ea6003e,0x62820361,0xd6180f98}},	//   _abti, _kópa, _nnoo, لتها_,
   {{0x6c7800d0,0xb5fd04ad,0x2bdb00a5,0xc98705ed}},	//   _صحیح_, _našt, _मुता, _туни,
   {{0x6282554f,0x645a034f,0x38a40212,0xb7171f11}},	//   _anoo, _cbti, _hörn_, _نظرت,
   {{0xb34500c9,0xddc400ae,0x4375020f,0xd7c90037}},	//   duçã, _obiş, султ, _صوره_,
   {{0xb5fdc04e,0x224b02e2,0x7ce0c04f,0x628201ee}},	//   _bašt, ück_, röri, _cnoo,
   {{0x5fcf0789,0x20030128,0x765bc050,0xb5fd38b7}},	//   _सुजल, žjim_, _ibuy, _pašu,
   {{0x10a50ed8,0x6282c051,0x1287001c,0x657b05bd}},	//   сион, _enoo, امکی_, _iruh,
   {{0x7d168798,0x1fb50fe9,0x00000000,0x00000000}},	//   _stys, сспр, --, --,
   {{0x395200c2,0x69cf03a9,0x00000000,0x00000000}},	//   ytys_, _oxce, --, --,
   {{0x765b270d,0xc10800de,0xf1b9077e,0xee3f0146}},	//   _mbuy, _hỗn_, tašu_, chým_,
   {{0x98a7000d,0xb345001f,0x1d0708f9,0x657b0350}},	//   čně_, cuçã, сери_, _mruh,
   {{0xb5fd02e6,0x38a40088,0x765b0283,0xf99f00b3}},	//   _zašt, _börn_, _obuy, _ofès_,
   {{0xbebd01d3,0xad9b0131,0x8f9a00ca,0x0d86174e}},	//   usīt, rcúr, _תיקי, _глин,
   {{0x8c460fd5,0xf1b900e7,0x213fc052,0x7e660134}},	// [f020] _лепе, pašu_, nruh_, mekp,
   {{0x6d460efa,0x765bc053,0x39524848,0x05db00c3}},	//   muka, _abuy, rtys_, _बड़ब,
   {{0x69cf22d3,0x6d4b0149,0x395232e3,0xe61a23f9}},	//   _exce, _ägar, stys_, где_,
   {{0x7c2e3b93,0x213fc054,0x657bc055,0xd6d9004d}},	//   labr, kruh_, _bruh, аті_,
   {{0x6d46c056,0x7ae402a1,0x05ba0076,0x00000000}},	//   nuka, mlit, ددات_, --,
   {{0x657b0871,0x7ae40cbc,0xb5fd013f,0x7c2ec057}},	//   _druh, llit, _rašt, nabr,
   {{0x6d464c17,0x3e7f00c2,0x7ae400bc,0xf74330fd}},	//   huka, _jätä_, olit, _неро,
   {{0x6d4603b4,0xb5fd01b3,0x6b830fb6,0x7ae49713}},	//   kuka, _pašt, _ánge, nlit,
   {{0x6d462cb2,0xddcd3fa8,0x7ae41909,0x7c2e80e0}},	//   juka, _snaž, ilit, kabr,
   {{0x6d4646fa,0x7ae43c49,0x39400091,0xdce400c4}},	//   duka, hlit, iris_, _oriđ,
   {{0xb4e40f78,0x201e013f,0x7c2e0138,0x74130604}},	//   नती_, rbti_, dabr, _رونا,
   {{0x442ec058,0x6d466180,0xdced005f,0x39401957}},	//   laf_, fuka, _krać, kris_,
   {{0xf19402fd,0xd01200cd,0x6d46c059,0x00000000}},	//   _филь, _فلش_, guka, --,
   {{0x442ec05a,0x3940c05b,0x7c2e01cd,0x7ae488fd}},	//   naf_, dris_, gabr, elit,
   {{0x387102e5,0x7ae45ce6,0x39405da0,0x6e950c5b}},	//   _razr_, flit, eris_, _мику,
   {{0x6d46c05c,0xe821048a,0x1dda08fa,0x442e23b4}},	//   buka, यर्थ_, _युवत, haf_,
   {{0x442e0665,0x26c70257,0xa3df1757,0x6d460035}},	// [f030] kaf_, énom_, _धुन_, cuka,
   {{0x442e03e3,0xf8070109,0x7ae40632,0x6f0a03e3}},	//   jaf_, счан, alit, _kufc,
   {{0x7ae4c05d,0x3940c05e,0x442e1a6e,0x6909007e}},	//   blit, aris_, daf_, _ožeg,
   {{0x39400331,0xdced00e9,0x657b0146,0x6e2f008c}},	//   bris_, _brać, _pruh, nacb,
   {{0x24f90109,0x4efc00c1,0x61e2c05f,0x442e1544}},	//   анды_, אלאג, _nyol, faf_,
   {{0x2ecf00c7,0x32060124,0x833900c2,0x291901af}},	//   রতিষ, _agoy_, ачит_, _itsa_,
   {{0x61e2c060,0x212603a9,0x3ea2003e,0x61fe00a7}},	//   _ayol, _awoh_, ykkt_, əzlə,
   {{0x290304f9,0x6d461114,0x290b113c,0x765b271c}},	//   _hija_, yuka, _kuca_, _ubuy,
   {{0x657b023f,0x3f7700d3,0xa3e50bd9,0x7c2e00a7}},	//   _uruh, _său_, _नरक_, yabr,
   {{0x3ea926f7,0x442e00f0,0x61e20154,0x290b51fb}},	//   _alat_, caf_, _dyol, _muca_,
   {{0x2903302f,0x3ea9c061,0x290b36ed,0x3e8a2776}},	//   _mija_, _blat_, _luca_, айно_,
   {{0x29033d42,0x764b4d8e,0x291900aa,0x60c800aa}},	//   _lija_, nggy, _otsa_, andm,
   {{0x77e60b95,0x6aad0a40,0x2919022e,0x7c2ec062}},	//   _कर्क_, dhaf, _ntsa_, tabr,
   {{0x3f77002d,0x3f9e1672,0x8fa51cfb,0x6ae214db}},	//   _tău_, bytu_, _мале, पत्र,
   {{0x6d464b10,0x7ae4c063,0x20070154,0x290b00ee}},	//   suka, tlit, _igni_, _auca_,
   {{0x3940c064,0x7c2e8c9f,0x290b8e3f,0x442e611d}},	//   tris_, sabr, _buca_, zaf_,
   {{0x29030b4b,0x7ae4450b,0x442e02ad,0x290b33fe}},	// [f040] _bija_, rlit, yaf_, _cuca_,
   {{0x3e7f0084,0x7a3f0649,0x290300cc,0x290b2ab6}},	//   _tätä_, _pàtà, _cija_, _duca_,
   {{0x7ae4c065,0x2903023b,0x6aad042c,0x00000000}},	//   plit, _dija_, bhaf, --,
   {{0x6aadc066,0x2f5a0130,0xdced005f,0x7d770688}},	//   chaf, ידענ, _prać, _امیر_,
   {{0x20070465,0x2903c067,0x2003033b,0x290b02a4}},	//   _ogni_, _fija_, žjih_, _guca_,
   {{0xdced02e6,0x54b7116d,0xb4e40b89,0x25f1009f}},	//   _vrać, огія_, नते_, ेशजी_,
   {{0x644a084e,0xe737263d,0x61e20027,0x229100d4}},	//   rgfi, _мер_, _syol, _háky_,
   {{0x442e02ad,0x20071a3a,0x29033a78,0x290bb3d4}},	//   saf_, _agni_, _zija_, _yuca_,
   {{0x21040d0b,0xdddd0034,0xa3d6030b,0x50664ea4}},	//   रदेश_, zesł, _सडक_, отна,
   {{0x61e206a3,0x3ea907bc,0x442e0078,0x2ee0232a}},	//   _vyol, _slat_, qaf_, _akif_,
   {{0x4ada009d,0xa2e66eaa,0x73360018,0x987b021e}},	//   ढवाव, _дожд, _ذرائ, בריק,
   {{0x442c0537,0x32060270,0x7eb601d3,0x3f9e3773}},	//   _hed_, _ugoy_, kšpu, rytu_,
   {{0x442c0038,0xf99f03a9,0x6f0400ae,0x212603a9}},	//   _ked_, _agèn_, _diic, _uwoh_,
   {{0x442c103b,0xa06714f2,0x7d1dc068,0x3f9e74e8}},	//   _jed_, _мача_, rpss, pytu_,
   {{0x442c16f4,0x6f040d9c,0x290bc069,0xd25901d3}},	//   _med_, _fiic, _suca_, liņa_,
   {{0x290b08a9,0x7ce0190f,0x3ea97b2e,0x798d01fa}},	//   _puca_, förs, _ulat_, txaw,
   {{0x81dc0081,0x442c02ad,0x255e00d9,0x2903ac72}},	// [f050] ণের_, _oed_, nālā_, _pija_,
   {{0x6aadc06a,0xab873006,0x442c4bf9,0x26cd0dd9}},	//   shaf, _думк, _ned_, _sjeo_,
   {{0x6e2d0991,0x6aad0088,0x7d0d686f,0x3cf80037}},	//   _keab, phaf, _huas, _بعيد_,
   {{0x7d0d18c4,0x41ca009d,0xe81b1117,0xcf93006e}},	//   _kuas, ापास, _प्रा_, וטע_,
   {{0xa5671b49,0x2903382c,0x6e2d05ad,0x442c00ca}},	//   تدان, _tija_, _meab, _bed_,
   {{0x6e2d4450,0x98481ad1,0x3949005c,0x7d0dc06b}},	//   _leab, _мяса_, muas_, _muas,
   {{0x3949c06c,0x95050018,0xd04e0092,0x998200e8}},	//   luas_, _کہتے_, _ödən, _iekš_,
   {{0xe3b00604,0x442cc06d,0x26cd0a39,0x6e2d00c6}},	//   خره_, _eed_, _ujeo_, _neab,
   {{0x05770979,0x7d0d0080,0x39490328,0x7cf201df}},	//   _بازد, _nuas, nuas_, lære,
   {{0xdce40067,0x26dd9ada,0x442c0013,0xa3b6000c}},	//   _ksią, lowo_, _ged_, _चेक_,
   {{0x2bdb0f42,0x3949022e,0x7cf201df,0x6e2d7855}},	//   _मुला, huas_, nære, _beab,
   {{0x752926e6,0x394902e7,0x7d0d53cf,0x26dd54e9}},	//   _kwez, kuas_, _buas, nowo_,
   {{0x6e2dc06e,0x7d0d03d3,0xd0095bc8,0x6f040231}},	//   _deab, _cuas, _леле_, _viic,
   {{0x7529417d,0x711a00a1,0xdce40034,0x7d0d8a46}},	//   _mwez, _הוספ, _osią, _duas,
   {{0x6e2d0080,0x7cf24b39,0x75290201,0x46db0034}},	//   _feab, værd, _lwez, यकाह,
   {{0x6609327f,0x7d0d7fd6,0x2bdb0096,0x8f9a0327}},	//   _ngek, _fuas, _मुळा, _ליצי,
   {{0xf2d20130,0x394909d3,0x7d0d8aeb,0x75290134}},	// [f060] גען_, guas_, _guas, _nwez,
   {{0x629904bd,0x6aa4038c,0x60c107aa,0x4d7b00c1}},	//   _lowo, skif, nilm, _פריע,
   {{0xdc9b193b,0xc5f6099d,0x442c00a1,0x7529c06f}},	//   _הייל, ेश्य_, _red_, _awez,
   {{0x442c74ce,0x6299c070,0x26ddc071,0x690902ef}},	//   _sed_, _nowo, gowo_, _džeb,
   {{0xe5a304e6,0x7e76006c,0x60c14d7a,0x442cc072}},	//   ници, _mayp, kilm, _ped_,
   {{0x442c04f9,0x6609c073,0x7cf201df,0x38a41df0}},	//   _qed_, _egek, bære, _mörk_,
   {{0x442c58b6,0x60c107aa,0x26dd0479,0x75290294}},	//   _ved_, dilm, bowo_, _ewez,
   {{0xfa970130,0x6299c074,0xb9090019,0x3253008f}},	//   ִדיש_, _cowo, _nghị_, евър,
   {{0x6e2d6d70,0x629900a5,0x04460f97,0xef240090}},	//   _reab, _dowo, _неан, _meżż_,
   {{0xf48411a2,0x200907e7,0xd25901d3,0x60c1b875}},	//   _تاری, _şair_, riņa_, gilm,
   {{0x7d0d005a,0x085700a1,0x629910fe,0x6e2d6727}},	//   _suas, הבים_, _fowo, _peab,
   {{0x7d0d06ee,0x62997129,0xeeab5be9,0x3949023e}},	//   _puas, _gowo, сток_, yuas_,
   {{0x7d0d0e08,0x60c1c075,0x2d800396,0x3949023e}},	//   _quas, bilm, _crie_, xuas_,
   {{0x2d800db8,0x629926a1,0x26dd007f,0x00000000}},	//   _drie_, _zowo, zowo_, --,
   {{0x905b00ca,0x7d0d037a,0xc05300ca,0x00000000}},	//   _הכות, _wuas, _נזק_, --,
   {{0x7cf21484,0x39492027,0x2d80038c,0x7d0d1ac3}},	//   være, tuas_, _frie_, _tuas,
   {{0x2d80022b,0x00000000,0x00000000,0x00000000}},	// [f070] _grie_, --, --, --,
   {{0x7cf201df,0x75290169,0xb4c800b6,0xa3cc5d46}},	//   tære, _rwez, ोको_, रपा_,
   {{0x8d180814,0x26ddc076,0x3949006c,0x067506c4}},	//   _وزیر_, towo_, suas_, дуля,
   {{0x39490da3,0x7529597c,0x60c13076,0x7cf20537}},	//   puas_, _pwez, zilm, rære,
   {{0xf6500678,0xb60900d9,0x60c10555,0x26ddc077}},	//   ائم_, višķ, yilm, rowo_,
   {{0x7b0800e3,0x629901bf,0x26dd9f61,0xbddb00ee}},	//   _óstá, _sowo, sowo_, lgès,
   {{0x629900a5,0xb60901d3,0x60c11577,0x00000000}},	//   _powo, tišķ, vilm, --,
   {{0x75290b58,0x00000000,0x00000000,0x00000000}},	//   _twez, --, --, --,
   {{0x7529068d,0x60c1c078,0x7ce03c84,0x00000000}},	//   _uwez, tilm, körp, --,
   {{0x6299c079,0x7e7600f9,0x7c22007e,0x00000000}},	//   _wowo, _sayp, _đoro, --,
   {{0x60c135f8,0xf41200ca,0x721900ae,0x6e460c37}},	//   rilm, _ספא_, _джер_, менз,
   {{0x2d8001b3,0x60c1c07a,0xfd4b0174,0xed5a3283}},	//   _prie_, silm, _uloọ, оом_,
   {{0x6d5603e3,0xf2d80281,0x63a3030a,0x8636006e}},	//   _qqya, _عظمت_, lynn, וארג_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3bd5007b,0x6fb20076,0x00000000,0x00000000}},	//   еютс, _لموا, --, --,
   {{0xf2120174,0x2d8001f7,0x66ec0336,0x00000000}},	//   _họrọ, _trie_, _छींक_, --,
   {{0x68f500e7,0xd6d30033,0x2b5500d1,0xb9062cc3}},	// [f080] _bhzd, ়তায, ویید_, дзак,
   {{0xbddb05fe,0xb8660dd0,0x63a32e7e,0xfc06007b}},	//   rgèt, بارو, kynn, _оппо,
   {{0xb3a90555,0x7c3e0381,0x00000000,0x00000000}},	//   çılı, _idpr, --, --,
   {{0x9f9600a1,0x63a382ed,0xddcdc07b,0x00000000}},	//   ודעה_, dynn, _haaš, --,
   {{0x23c340c1,0x955301f3,0x00000000,0x00000000}},	//   _वेबद, نخوا, --, --,
   {{0x6d46005c,0x63a30150,0xf2120134,0xcdb700ca}},	//   irka, fynn, _nọrọ, ופנה_,
   {{0x63a300d6,0x3878009b,0xbddb0352,0x31a6896a}},	//   gynn, _iarr_, ngèr, गन्ध,
   {{0x3878486e,0xd13a00c2,0x26c2c07c,0x00000000}},	//   _harr_, охо_, _öko_, --,
   {{0x7c3e1548,0x00000000,0x00000000,0x00000000}},	//   _odpr, --, --, --,
   {{0x63a30150,0x634a0092,0x649400ee,0x6d460218}},	//   bynn, _mənz, _nàix, drka,
   {{0xc1080028,0xf2120134,0x38784f65,0x6d4641be}},	//   _mỗi_, _dọrọ, _marr_, erka,
   {{0xc1080028,0x6d461fce,0xd12f010d,0x6d480034}},	//   _lỗi_, frka, _چمن_, ądan,
   {{0xd9e3007d,0xf2120e62,0x6aa300ae,0x6ce7004d}},	//   _कुढत_, _fọrọ, _înfi, діве,
   {{0xdce400a5,0x443e057c,0xdfd40109,0xfc6400e5}},	//   _księ, _jdt_, _полы, късн,
   {{0x6d460808,0xc1080019,0xad9b0220,0xbddb020d}},	//   arka, _nỗi_, ncúz, ggèr,
   {{0x6d460995,0x7c3e0079,0x634a00a7,0x00000000}},	//   brka, _edpr, _bənz, --,
   {{0x387800e3,0x19580226,0xd25900e8,0x63a3007f}},	// [f090] _barr_, маты_, ziņo_, zynn,
   {{0x1b1e0081,0x29074478,0x6b752b49,0x443e0227}},	//   _ফিরে_, öna_, _злоу, _ndt_,
   {{0xae1c32d1,0x387801ee,0x00000000,0x00000000}},	//   भुवन_, _darr_, --, --,
   {{0xdb1e0042,0x19950f5f,0x387801ec,0x7bd700bd}},	//   _expó, _замя, _earr_, _ixxu,
   {{0x387803a8,0x2a790090,0x63a300f0,0x7cf2004d}},	//   _farr_, _iasb_, wynn, læra,
   {{0x38780383,0x6ef60072,0x443e1cc0,0x00000000}},	//   _garr_, mábe, _cdt_, --,
   {{0x25a90087,0x9f4b90dd,0xf8b200d7,0x00000000}},	//   šal_, ülük_, _גשם_, --,
   {{0x6d462452,0x63a33c5e,0x3f5848a9,0x443e1dbd}},	//   yrka, rynn, déu_, _edt_,
   {{0x212b06a3,0x41051b4d,0xb3df009f,0x443e0036}},	//   èch_, нзив, _पुरख, _fdt_,
   {{0x3f580161,0x753b0079,0x443e895c,0xc6160033}},	//   féu_, _ivuz, _gdt_, ারণা_,
   {{0xd2510cc8,0x4427037a,0x7ea67034,0x2bdb00a3}},	//   _منا_, mbn_, _hópi, _मँगा,
   {{0x7ea60031,0x9f470216,0x03780e27,0x00000000}},	//   _kópi, _hynë_, _زحمت_, --,
   {{0x628bc07d,0x0d83245c,0x661b0051,0x26cf01e9}},	//   _ingo, глян, _mfuk, ingo_,
   {{0x3f582df7,0x6ef60042,0x753b728e,0x6d46c07e}},	//   béu_, dábe, _mvuz, rrka,
   {{0xeb9a22f9,0x752206e9,0x661bb8ec,0xfaf60ed4}},	//   чив_, zpoz, _ofuk, ечаю,
   {{0xc3320796,0x8a061fdb,0xc1080023,0x661b06b0}},	//   טול_, езбе, _rỗi_, _nfuk,
   {{0xe9d71bd8,0xd9432549,0x6da600ae,0x44270167}},	// [f0a0] ект_, лети, _чипа, kbn_,
   {{0x2bdb24eb,0x661b42ce,0x660d211b,0x7522007e}},	//   _मुका, _afuk, žakl, vpoz,
   {{0x628bc07f,0xe6662cad,0x753b05bd,0x38780216}},	//   _ongo, етло, _avuz, _varr_,
   {{0xdce40138,0x443e2a65,0x6ef67df8,0x634a00a7}},	//   _priė, _sdt_, bábe, _tənz,
   {{0xf9921e49,0x7e64c080,0x1a9b00c1,0x7ea6001f}},	//   _صبح_, _mbip, _זיכע, _cópi,
   {{0x628bc081,0x661b0172,0x34bc0285,0x26cf12cc}},	//   _ango, _efuk, ्चेद, ango_,
   {{0xd62a0acf,0x62050092,0x290a07ac,0x661b00bd}},	//   _нове_, ərlə, _iiba_, _ffuk,
   {{0x7e640294,0x290a0103,0xe60a001c,0x00000000}},	//   _nbip, _hiba_, _رزرو_, --,
   {{0x290a08d5,0x443e1c40,0x6d400143,0x60f800e5}},	//   _kiba_, _tdt_, ámal, мния_,
   {{0x628bc082,0xdfda013d,0x290a55d3,0xe5060037}},	//   _engo, зъм_, _jiba_, _أبري,
   {{0x690900cc,0xf8b30327,0x290a2ba1,0x6ef60072}},	//   _ožen, רשת_, _miba_, zábe,
   {{0x234b0100,0x290a05fb,0x7ae600f9,0x93250260}},	//   _رسمی_, _liba_, _nkkt, _شرمن,
   {{0x25a6c083,0xbcfb014b,0xf237006e,0x6ef60072}},	//   nyol_, ntég, _טראץ_, xábe,
   {{0x290a023f,0x7e645080,0x3f580161,0x6ef6002b}},	//   _niba_, _ebip, péu_, vábe,
   {{0xfbdb06ed,0x9a873457,0x1bd41bf9,0xee3f02c6}},	//   _मुखम, нуал, горя, lkým_,
   {{0x290a00d3,0x6ef60042,0x6d5a020a,0x9f4700d4}},	//   _aiba_, tábe, ătar, _uzná_,
   {{0x69093bbd,0x290a01e2,0x7e7d11fc,0x00000000}},	// [f0b0] _džen, _biba_, mdsp, --,
   {{0x7e7d29fb,0x5b150d5e,0x6ef603be,0x6d4f0ff4}},	//   ldsp, _имот, rábe, muca,
   {{0xe70b11a2,0x290ac084,0x6d5d49f5,0x44270b14}},	//   ستان_, _diba_, ltsa, vbn_,
   {{0x26cf4424,0x6d5d0f06,0xbb3a2252,0x00000000}},	//   ungo_, otsa, _קערי, --,
   {{0x6d5dc085,0x3a2902fa,0x7e7d4e43,0xe8d900ac}},	//   ntsa, mbap_, idsp, ntị_,
   {{0x7aedc086,0xe7330192,0xdced005f,0xe5a25b74}},	//   llat, _مصر_, _krađ, риши,
   {{0x0ee1007d,0xe29958c0,0x8c1c0054,0x6d5d0006}},	//   नवाड, дай_, לוגי, htsa,
   {{0x7ea600c9,0x7aedc087,0x7e7d01c5,0x6d4fc088}},	//   _tópi, nlat, jdsp, kuca,
   {{0x6d4f04a3,0x6d5d6f77,0x7aed2e13,0x44270085}},	//   juca, jtsa, ilat, pbn_,
   {{0x39490ba0,0x6d4fc089,0x7aedc08a,0x6d400143}},	//   iras_, duca, hlat, ámam,
   {{0x6ef60068,0x64410a69,0x645e05fe,0x32554147}},	//   vább, _idli, òpie, _авер,
   {{0x38a41680,0x39495b6b,0x628bc08b,0x6d5d0970}},	//   _hört_, kras_, _ungo, ftsa,
   {{0xee3f0074,0x2d840618,0x6d4f015c,0x38a4539e}},	//   ckým_, íme_, guca, _kört_,
   {{0x10a211a0,0x7e7d02ac,0x00000000,0x00000000}},	//   _вишн, adsp, --, --,
   {{0x1d071c16,0x3949c08c,0x6ef60018,0x6d5d2cee}},	//   тери_, eras_, rább, atsa,
   {{0x394908ec,0xe7e50251,0x6d4fc08d,0x290a0372}},	//   fras_, _कड़ा_, buca, _siba_,
   {{0x3949a03d,0x6d4fc08e,0x290a7637,0x81e30033}},	// [f0c0] gras_, cuca, _piba_, ফের_,
   {{0xdd310092,0x61eb04c8,0x00000000,0x00000000}},	//   ləşd, _mygl, --, --,
   {{0xdced03ce,0x320f03a9,0x394994f4,0x7aed4a6a}},	//   _građ, _oggy_, aras_, blat,
   {{0x3949309c,0x7aedc08f,0x76a900d6,0xfaa61689}},	//   bras_, clat, нтів_, _рамо,
   {{0x7ae40d64,0x290a25fa,0x3943313c,0x3ea09156}},	//   moit, _tiba_, _княг, _moit_,
   {{0x7ae40084,0xf4d00033,0x5453004d,0xdce400d4}},	//   loit, িত্ব, ивіт, _opič,
   {{0x3ea001a2,0x38a4026a,0x7ea6003e,0x6d4f0034}},	//   _ooit_, _dört_, _hópu, zuca,
   {{0xf77709c1,0xee3f0181,0x7ae4c090,0xb6a3014d}},	//   _בעלי_, tkým_, noit, _кисл,
   {{0xb6a30c64,0x26c4c091,0xbcfb020d,0x6d400095}},	//   _титл, _immo_, ltée, šmaj,
   {{0x7ae40084,0x6d5d023e,0x00000000,0x00000000}},	//   hoit, vtsa, --, --,
   {{0x7ae42585,0xf83700a1,0xbcfb0257,0xee3f0146}},	//   koit, כנית_, ntée, ským_,
   {{0x7ae402fd,0x6d5dc092,0x3ea001b9,0x3949018a}},	//   joit, ttsa, _coit_, yras_,
   {{0x3ea0025a,0x2bdb007a,0x7e7d0429,0x6d5d439f}},	//   _doit_, _मुजा, rdsp, utsa,
   {{0x4034455b,0x394900c9,0x6d5d0e9f,0x6d4fc054}},	//   _секс, vras_, rtsa, ruca,
   {{0x9f580084,0xc339030b,0x69090477,0x6d5d0ac9}},	//   ärä_, žívá, _džel, stsa,
   {{0x3949139f,0x6d4f04a3,0x7ae4c093,0x6ab600f0}},	//   tras_, puca, goit, ghyf,
   {{0x7aed88f2,0x7ea60072,0x6f0d009c,0xf8bf014b}},	// [f0d0] rlat, _cópu, _iiac, _ltée_,
   {{0x6ef648fd,0xd79500e5,0x8c6700ae,0x60c800b3}},	//   mába, лизъ, _ртид, nidm,
   {{0x7ae450d9,0xdced1711,0x6ef60018,0x645705fe}},	//   boit, _urađ, lába, òxim,
   {{0x60c829cb,0x7ae408a8,0x7c22007e,0x38a432ee}},	//   hidm, coit, _đori, _börs_,
   {{0xe7e5007d,0xd1260f43,0x6ef60103,0x6aad03e3}},	//   _कडवा_, _دم_, nába, mkaf,
   {{0x6aad00b7,0x6f0d7e5c,0x26c40381,0x61ebc094}},	//   lkaf, _liac, _emmo_, _rygl,
   {{0x2ca118c4,0xd5bf01d3,0xbcfb00fd,0x49170285}},	//   _mohd_, _šādu_, ctée, _भूतो_,
   {{0x6aadc095,0x6ef60103,0x4ee50033,0x38a402c3}},	//   nkaf, kába, নগুল, _förs_,
   {{0x2f1a0029,0x6ef60018,0x38a40149,0x00e502b3}},	//   _rīga_, jába, _görs_, лжин,
   {{0x3ea004ea,0x7ae4c096,0xe4530246,0xe8d90174}},	//   _soit_, zoit, _خضر_, ktọ_,
   {{0x1eca1880,0xb5fd01b3,0x61eb00a5,0x7ae40239}},	//   елни_, _rašy, _wygl, yoit,
   {{0x7fb300a7,0x313551ad,0x6aad0381,0x61eb6e82}},	//   nəqə, _бедр, jkaf, _tygl,
   {{0x3ea0a095,0x7ae47ad0,0x6f0dc097,0x61451c0e}},	//   _voit_, voit, _diac, _села,
   {{0x38b6052f,0xe1f00192,0x6f0d028d,0xd04100a7}},	//   _kære_, _بسم_, _eiac, ynlə,
   {{0x3ea0a32b,0x6f0d009b,0xcb67002d,0xa3c9034c}},	//   _toit_, _fiac, ларе_, _लेम_,
   {{0x69095ecd,0x6f0d008f,0x2d9600c2,0xede50174}},	//   _džem, _giac, _брос, ụrịm_,
   {{0xceb4025c,0xe8fa1502,0x38b6038c,0x7ae4c098}},	// [f0e0] _ilə_, ела_, _lære_, roit,
   {{0x48c40f71,0x47bf0081,0x7ae400c2,0xb4dd030b}},	//   ্ত্র, ্থনী, soit, णको_,
   {{0x7ae487da,0x38b600f2,0xbcfb020d,0x2d8f00ee}},	//   poit, _nære_, utée, _àger_,
   {{0xbcfb00fd,0x443800c6,0x9f4a02c3,0x00000000}},	//   rtée, _žr_, _åmål_, --,
   {{0x8e570c6a,0x64a6333f,0x629b00e7,0xbcfb020d}},	//   רינג_, лада, djuo, stée,
   {{0xd37a15a7,0x38b601df,0x6aa300ae,0xbcfb00fd}},	//   ечи_, _bære_, _înfr, ptée,
   {{0x38b6052f,0x38a40149,0x430a0095,0x07a30231}},	//   _værd_, _förr_, нхим_, _ларн,
   {{0x66e64177,0x57e70396,0x6ef601f9,0x38a402c3}},	//   _соба, _сдсм_, yába, _törs_,
   {{0xd0100080,0x6f0d0080,0xc05a02b7,0x68fc5d4e}},	//   يلة_, _riac, нін_, _khrd,
   {{0x2ee95e88,0xbcfb01f9,0x00000000,0x00000000}},	//   _skaf_, ztéb, --, --,
   {{0x6f0d904d,0x645a33bc,0x3f870039,0x5ff41146}},	//   _piac, _icti, _crnu_, рзну,
   {{0x91860adb,0x6ef68cc3,0x63600129,0xb5fd05db}},	//   _مجتم, tába, _ịnwe, _obšl,
   {{0x6f0d0181,0x690933db,0x1c192397,0x00000000}},	//   _viac, _džej, _दलदल_, --,
   {{0xceb401d4,0xb17b00f5,0x6ef69322,0x6280c099}},	//   _elə_, _נטור, rába, ldmo,
   {{0x6ef60018,0x6f0d009c,0x2cb3020b,0x00000000}},	//   sába, _tiac, _vlxd_, --,
   {{0x8aa4322e,0xd25900e8,0x6ef6660e,0x6f0d009c}},	//   бруд, tiņi_, pába, _uiac,
   {{0x38350cfc,0xf84b686c,0x3f8700cc,0xbcfb020d}},	// [f0f0] инар, ечей_, _zrnu_, rtéb,
   {{0x201e022b,0x6aad0429,0x25e8009f,0x00000000}},	//   ncti_, skaf, _जड़ी_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x17f8054f,0xf8bf0113,0x7c3702ac,0x2b4c02c6}},	//   اركة_, _awét_, _hexr, ádce_,
   {{0xa56400ab,0xe61800f3,0x7fb3013c,0x7d16020b}},	//   مدون, уді_, rəqə, _xuys,
   {{0xd4692311,0xdb1e0131,0x628005c2,0x38b600f2}},	//   тике_, _expõ, edmo, _pære_,
   {{0x37f800d3,0x62800381,0x00000000,0x00000000}},	//   _берэ_, fdmo, --, --,
   {{0x38b658b6,0xb1453119,0xe8e00019,0x6b880f3c}},	//   _være_, анил, _đứa_, ådgi,
   {{0xe0d91121,0xd6d83974,0x69cb097c,0xf7700103}},	//   кви_, _стр_, _सेमी, _واہ_,
   {{0x05de1c0a,0x1f6533fd,0x657bbf2f,0x6e3603e3}},	//   _फुटब, аком, _isuh, _seyb,
   {{0x6e3600f9,0xb4fa006e,0x6d5f11bc,0x00000000}},	//   _peyb, _ספעי, _aqqa, --,
   {{0x6e36008a,0x2d8901ec,0xde065d83,0x00000000}},	//   _qeyb, _brae_, ипни, --,
   {{0x59a5009d,0x2d891e8c,0xa3c900aa,0x273c0139}},	//   _गॅलर, _crae_, _लेत_, _káná_,
   {{0x7cf201c5,0x6909c09a,0x00000000,0x00000000}},	//   mærk, _džek, --, --,
   {{0x46b5178c,0xea5a0396,0x7e7f0113,0x3eb9009c}},	//   ंसाह, крај_, _faqp, bhst_,
   {{0x3eb902e2,0x3a260231,0xaa4703bf,0x00000000}},	//   chst_, рмаг, ипса_, --,
   {{0x3b070cba,0xa96a1629,0x213f00dc,0x2d8900b3}},	// [f100] рето_, ضمام_, nsuh_, _grae_,
   {{0xd25901d3,0x270e0eeb,0xa96707ce,0x00000000}},	//   miņu_, िद्र_, рифа_, --,
   {{0x7c3cc09b,0x657b2293,0x69dd309e,0xd25900e8}},	//   marr, _asuh, _exse, liņu_,
   {{0x7c3c0a00,0x9f47030b,0x95ca013f,0x00000000}},	//   larr, _nyní_, кула_, --,
   {{0x978400cd,0xd25900e8,0xdb1e0231,0x7c3c0062}},	//   _گیاه, niņu_, _expô, oarr,
   {{0x7c3cc09c,0x39400197,0x765b00b3,0x6efd01f9}},	//   narr, msis_, _ecuy, mébe,
   {{0xa6960a28,0xf74323c3,0x39408ff5,0xe73700c2}},	//   _крај, _меро, lsis_, _вес_,
   {{0x7c3cabce,0x3940c09d,0x3a204d6c,0x66e30058}},	//   harr, osis_, ncip_, _доса,
   {{0x7c3c03f3,0x6280088f,0x3940c09e,0xf50a9aac}},	//   karr, rdmo, nsis_, _анал_,
   {{0x7c3cc09f,0xa0a6246b,0x3940be81,0x65620052}},	//   jarr, ршил, isis_, mtoh,
   {{0x7c3c1e1c,0x3817028c,0x80c80081,0x69091528}},	//   darr, יקים_, রকল্, _džeh,
   {{0xa1860895,0x3940a129,0x6efd0103,0x2d8900b7}},	//   _выкл, ksis_, kébe, _prae_,
   {{0x7c3c02a7,0x656291a1,0x6efd0103,0x00000000}},	//   farr, ntoh, jébe, --,
   {{0x7c3c03f3,0x6458c0a0,0x443cc0a1,0x2d890185}},	//   garr, ngvi, nav_, _vrae_,
   {{0xa3cc02e8,0x39400f20,0x00000000,0x00000000}},	//   रपट_, esis_, --, --,
   {{0x443c0197,0x25600c56,0x2d895a88,0x6562023b}},	//   hav_, kòl_, _trae_, ktoh,
   {{0x443c02e6,0xae03110f,0x656200dd,0x78270037}},	// [f110] kav_, रेशन_, jtoh, لعال,
   {{0x7c3c2f0b,0x1a6500cd,0x37ab0c59,0x443c230b}},	//   carr, _گیری_, ктен_, jav_,
   {{0x443cc0a2,0x3e860103,0x39406739,0x69d8042c}},	//   dav_, sítő_, asis_, ßver,
   {{0x39400197,0x6d4f0503,0x65620052,0x224601dc}},	//   bsis_, orca, ftoh, _ndok_,
   {{0x98b30092,0x443c5202,0x00000000,0x00000000}},	//   şdır_, fav_, --, --,
   {{0x7cf2052f,0x443cc0a3,0xf79500d3,0x383500d3}},	//   værk, gav_, _лагэ, _ынгр,
   {{0xd25901d3,0x291953e9,0x67d4355a,0x25e7023a}},	//   ziņu_, _husa_, _дору, _छुरी_,
   {{0x7c3c740c,0x29195855,0x6b830610,0x7cf20f04}},	//   zarr, _kusa_, _ángu, tærk,
   {{0x443c02e6,0x29111bbd,0x7c3c0062,0xf8bf0113}},	//   bav_, _kiza_, yarr, _uwés_,
   {{0x2919c0a4,0x7c3c465b,0x92c90033,0x1ac40635}},	//   _musa_, xarr, োতে_, _षष्ठ,
   {{0x2911c0a5,0x2919c0a6,0x14d60796,0x6efd01f9}},	//   _miza_, _lusa_, _פועל_, zébe,
   {{0x6e3d02c9,0x6ef610d9,0x39408dad,0x7ea600ee}},	//   gasb, rábo, ysis_, _cópp,
   {{0xe7f40a30,0x7c3c02a7,0xa0698e6d,0x29192608}},	//   _अर्थ_, tarr, _бала_, _nusa_,
   {{0x6efdc0a7,0x29110106,0x3a390113,0xd25900e8}},	//   vébe, _niza_, _aesp_, riņu_,
   {{0x7c3c006d,0x6d4f07bc,0x2919019c,0x7cf20856}},	//   rarr, arca, _ausa_, næri,
   {{0x7c3c87f3,0x2919a52b,0x25600c56,0x6efd0018}},	//   sarr, _busa_, yòl_, tébe,
   {{0x7c3cc0a8,0xbcfb0037,0x29190d2a,0xfaa32877}},	// [f120] parr, stéa, _cusa_, чато,
   {{0xeb9a0831,0x7c3c0078,0x6efd0103,0x2911295c}},	//   _био_, qarr, rébe, _ciza_,
   {{0xbb8600e3,0x3940c0a9,0x25600c56,0xe7eb009f}},	//   _الجي, ssis_, wòl_, _जुदा_,
   {{0xe73708c3,0x443cc0aa,0x2911037a,0x56160033}},	//   сец_, wav_, _eiza_, ার্ক_,
   {{0x443cc0ab,0x2919023f,0x291128be,0x6bd70421}},	//   tav_, _gusa_, _fiza_, _نویس_,
   {{0x2911c0ac,0x65629290,0x38b6003e,0x9d1b0266}},	//   _giza_, rtoh, _færa_, אוסט,
   {{0x961d0029,0x656238ea,0x64587604,0x7cf20537}},	//   _saņe, stoh, rgvi, gæri,
   {{0x6562023b,0x29113759,0x961d01d3,0x29190113}},	//   ptoh, _ziza_, _paņe, _yusa_,
   {{0xd9fa030b,0x6e3d2666,0xb3a9020e,0x5a9b006e}},	//   ्धित_, vasb, çırı, רשפא,
   {{0x6e3d1cab,0xf99300ca,0xa3c900bc,0x6d4f00c4}},	//   wasb, פרת_, _लेव_, vrca,
   {{0x6448c0ad,0x389b0089,0xd0100037,0x6e3d02ac}},	//   _iddi, איינ, بلد_, tasb,
   {{0x6d4f00cc,0xa3d5009f,0xb7db0327,0x00000000}},	//   trca, सपर_, רקטי, --,
   {{0x3a390244,0xc0e65276,0x61f60037,0xfe030e4c}},	//   _resp_, _лодк, _اساء, रेंस_,
   {{0xf8bf9254,0x9f34004d,0x3f9800aa,0xdced0090}},	//   _atén_, _декі, ärus_, _ipaċ,
   {{0x291927c5,0x6aa605e8,0xdddd0103,0x6e3d01cb}},	//   _susa_, _bokf, reső, pasb,
   {{0x2919c0ae,0x8aa40f80,0x64480062,0x6d4f0234}},	//   _pusa_, пруд, _lddi, prca,
   {{0x19590109,0x6448c0af,0x99998446,0x7e6d0372}},	// [f130] разы_, _oddi, шкат_, _ibap,
   {{0xa3b80179,0x3a390381,0x00000000,0x00000000}},	//   ङना_, _wesp_, --, --,
   {{0xb0650084,0x62820172,0x29190113,0x00000000}},	//   llää, _oaoo, _wusa_, --,
   {{0x35f51057,0x6448c0b0,0xdced013f,0x29191c5d}},	//   опер, _addi, _praė, _tusa_,
   {{0x64a513a4,0xd5672dc8,0x454b37fa,0x7e6d4b5f}},	//   жала, степ, учем_, _mbap,
   {{0x76590150,0xfbd009e5,0x81cc0081,0xf99200ca}},	//   sgwy, _آتی_, _শুভ_, _קרם_,
   {{0x045600e3,0x68fa00ca,0x5c5c006e,0x2bcf0096}},	//   زلية_, _כלשה, אדוק, _हेमा,
   {{0x6448303c,0x6e3b01cd,0xc6a73283,0x00000000}},	//   _eddi, ðubl, _урги, --,
   {{0x7649c0b1,0x26cf61f8,0x69091a30,0xb5fd103b}},	//   _idey, migo_, _džev, _obši,
   {{0x26cfb4d4,0x7e6dae6c,0x6e240036,0x75298d7b}},	//   ligo_, _abap, _sfib, _itez,
   {{0x6d440220,0xb4e51b79,0x3f690582,0xf2e70f80}},	//   _svia, नवी_, шино_, _людо,
   {{0x26cf9de1,0x2a69023e,0xdce401d3,0x00000000}},	//   nigo_, jfab_, _oriģ, --,
   {{0xbcfb0068,0x21a50562,0xe29f0088,0x2a69033c}},	//   rtén, _филм, öðu_, dfab_,
   {{0x6c360080,0x26cfc0b2,0x212d00dc,0x44250231}},	//   تفسا, higo_, mpeh_, _jfl_,
   {{0x644d03e3,0x44257604,0x7649008c,0x26cf0027}},	//   ɗait, _mfl_, _odey, kigo_,
   {{0x6d40c0b3,0x7e6d321e,0x26cf0087,0x764903a9}},	//   ámas, _gbap, jigo_, _ndey,
   {{0x26cfc0b4,0x75290875,0x442501cd,0x6d440206}},	// [f140] digo_, _ntez, _ofl_, _uvia,
   {{0x76492ccb,0x00000000,0x00000000,0x00000000}},	//   _adey, --, --, --,
   {{0xe61a125c,0xf7720b05,0x2a6901fa,0xfaa6a20f}},	//   аде_, باء_, bfab_, _дано,
   {{0x366a37f2,0x26cf0027,0x00000000,0x00000000}},	//   радо_, gigo_, --, --,
   {{0x85760b05,0x7ae101f9,0x2cba0381,0x5506098a}},	//   تدائ, élte, _klpd_, очка,
   {{0x2d800383,0x7af60084,0x7ae90087,0xddcf00d3}},	//   _msie_, llyt, čete, lecţ,
   {{0xb4ca00a5,0x26cf3996,0x7529270d,0xdc9b0a41}},	//   _लगी_, bigo_, _etez, ייסל,
   {{0xc2984087,0x442501af,0x2bed009f,0x6b8313a9}},	//   ских_, _efl_, _आँसू_, _ânge,
   {{0xddcf020a,0x00000000,0x00000000,0x00000000}},	//   iecţ, --, --, --,
   {{0x7af600f0,0x92ca0033,0x6448041c,0xc0e70076}},	//   hlyt, লকে_, _uddi, يفين_,
   {{0xb4d60454,0x2d80c0b5,0x00000000,0x00000000}},	//   ाची_, _asie_, --, --,
   {{0x216a0ce5,0xe297007e,0x00000000,0x00000000}},	//   _види_, _мах_, --, --,
   {{0x2d80033c,0x00000000,0x00000000,0x00000000}},	//   _csie_, --, --, --,
   {{0x26cf5092,0xa2a60285,0x61e2039f,0x00000000}},	//   zigo_, टॉर्, _ixol, --,
   {{0x0b885d11,0x7af60973,0xb06500c2,0x8aa7100c}},	//   ости_, flyt, slää, орад,
   {{0x6d480067,0x2d80002b,0xf1bf0031,0x6efd01dc}},	//   ądar, _fsie_, žšej_, béba,
   {{0x26cf21a3,0xb955008f,0x14db00a4,0x38b60537}},	// [f150] vigo_, яващ, _बदलण, _værn_,
   {{0xa2ca10e9,0x3ea900de,0x26cfc0b6,0x60dac0b7}},	//   तोत्, _hoat_, wigo_, nntm,
   {{0x26cfc0b8,0x78a72461,0xa3c902b0,0xddc40b18}},	//   tigo_, _vojv, _लें_, _ibiš,
   {{0x4b7a0130,0x98a90d62,0x9f4b0103,0xf2120139}},	//   _פארו, mpač_, ülék_, _gọgọ,
   {{0x26cf13a9,0xceb400c1,0xd83b00c6,0x7989003d}},	//   rigo_, ויף_, _вэб_, _ġeww,
   {{0x7d7c00f5,0x7aed5f4e,0xdced35b5,0x26cf170c}},	//   ינדו, loat, _opač, sigo_,
   {{0x5c3800a1,0x290302ef,0x61e22e80,0x26cfb3c0}},	//   חרון_, _ihja_, _axol, pigo_,
   {{0xc245014d,0x3b0900a7,0x7bdc006e,0xe2990231}},	//   чник, nmaq_, יקוו, саи_,
   {{0xddc404fa,0x8467008f,0xdced00c6,0x26cd0350}},	//   _obiš, _мъже, _apač, _imeo_,
   {{0x64571f84,0x44250154,0xdce4003d,0x7aedacbf}},	//   óxid, _ufl_, _oriġ, hoat,
   {{0xf1a800cd,0x7aed01ff,0x212d1813,0xc0a80037}},	//   مایه_, koat, speh_, تايل_,
   {{0x24850429,0x7aed0231,0x395203a8,0xbcfb01f9}},	//   _halm_, joat, yrys_, stél,
   {{0x24856540,0x26cd0350,0x290301cb,0x7cf20537}},	//   _kalm_, _mmeo_, _ohja_, kært,
   {{0xc21200ca,0x98a0007e,0xff25007b,0x00000000}},	//   _נהג_, mpić_, _емко, --,
   {{0xddcf00d3,0xfce300a9,0xa09a006e,0x6ef60042}},	//   tecţ, хоро, _ליסט, hábi,
   {{0xee3a180b,0xaa7b0088,0x395200f0,0xaac60179}},	//   _уни_, _skýr, trys_, रोंक,
   {{0x3e5b00a1,0x6f040134,0xddcf00d3,0x00000000}},	// [f160] _הדפס, _ihic, recţ, --,
   {{0xb4ca0d0b,0x6d460f05,0xab663d02,0xd910010d}},	//   _लगे_, mska, _евол, ئیس_,
   {{0x6d460f3c,0x7c3e0029,0xe8075e07,0x7aedc0b9}},	//   lska, _iepr, वेला_, boat,
   {{0xeafa09b4,0xa3e614e5,0x3952c0ba,0xd7ef0037}},	//   _درخت_, _युग_, prys_, دكم_,
   {{0x6d46611f,0x7c3ec0bb,0xdbce07aa,0x6f04151d}},	//   nska, _kepr, _bıça, _mhic,
   {{0xb4d60454,0xf7460f11,0x6d46c0bc,0x7c3e0194}},	//   ाचे_, _него, iska, _jepr,
   {{0x2ca51ee7,0x2485005c,0x69c4009e,0x7c3e0383}},	//   öldi_, _dalm_, lzie, _mepr,
   {{0x6d46c0bd,0x6aa4990a,0x626600e3,0x6f040294}},	//   kska, njif, سابق, _nhic,
   {{0x69c4c0be,0xdcedc07b,0x6d46c0bf,0xd04100a7}},	//   nzie, _spač, jska, lilə,
   {{0x6d46c0c0,0x3b090092,0x3ea9c0c1,0x6f040169}},	//   dska, zmaq_, _soat_, _ahic,
   {{0xd04101d4,0x443e00d9,0x6f0401f7,0x7aed0a4b}},	//   nilə, _iet_, _bhic, yoat,
   {{0x443e1db5,0x6f040fd7,0x2485029a,0x3b0900a7}},	//   _het_, _chic, _zalm_, xmaq_,
   {{0xbcfb0074,0x50b700bf,0x443ec0c2,0xf0b700bf}},	//   stém, زدید_, _ket_, زایش_,
   {{0x69c49ccd,0x6f040134,0x212b0037,0xd0410092}},	//   dzie, _ehic, íche_, kilə,
   {{0x443e1db5,0x6d465553,0x3b090092,0x7aed0877}},	//   _met_, aska, tmaq_, toat,
   {{0x443ec0c3,0xcff70341,0xd0410092,0x6f0400ae}},	//   _let_, _מצוה_, dilə, _ghic,
   {{0xdd910979,0x3b090092,0x20c00441,0xdb070103}},	// [f170] _شود_, rmaq_, _còig_, gyjá,
   {{0x7c3e0d50,0x443e32e8,0x26cd077e,0xddc400e7}},	//   _gepr, _net_, _smeo_, _ubiš,
   {{0x69c40cc0,0x7aed8968,0xdd020995,0x3b09013c}},	//   azie, poat, _žućk, pmaq_,
   {{0xae01000f,0x2485c0c4,0x443e058f,0x7cf200f2}},	//   _ईरान_, _salm_, _aet_, bærs,
   {{0x443ec0c5,0x6909197e,0xe9450260,0x248500d7}},	//   _bet_, _džer, _ترجی, _palm_,
   {{0x443ec0c6,0x69090138,0xd041013c,0x6ef60956}},	//   _cet_, _ežer, bilə, rábi,
   {{0x443e34cb,0x6d465fbc,0x68f80103,0xd0410092}},	//   _det_, zska, őadá, cilə,
   {{0x443e01a2,0x6d468a3d,0x26cd0095,0x41b5004d}},	//   _eet_, yska, _umeo_, дсот,
   {{0x443ec0c7,0xaca30129,0x661b0169,0x2485c0c8}},	//   _fet_, _anọg, _iguk, _talm_,
   {{0x443ec0c9,0x6f04008c,0x2ef20f5a,0x999900d2}},	//   _get_, _shic, _skyf_, _lesů_,
   {{0xdee60303,0x64430707,0x69c4771f,0x98a0080e}},	//   дони, mani, zzie, spić_,
   {{0x6443c0ca,0x443e0ab2,0x7c3e0ece,0x6d4627cd}},	//   lani, _zet_, _sepr, tska,
   {{0x62990305,0x6d4685de,0xd0410092,0x443e00a1}},	//   _inwo, uska, zilə, _yet_,
   {{0x6d46c0cb,0x6f04004f,0x6443c0cc,0xfd5f0019}},	//   rska, _whic, nani, _huyệ,
   {{0x7c3e01e5,0x6d46a04f,0x64430036,0x6f04a728}},	//   _vepr, sska, iani, _thic,
   {{0x6289c0cd,0x69c4c0ce,0x225f0498,0x6d46c0cf}},	//   ndeo, tzie, nguk_, pska,
   {{0x6443c0d0,0xf2d20105,0x20e10be4,0xda6500e3}},	// [f180] kani, דען_, _पदाध, عافي,
   {{0x69c4735f,0x7ae900e9,0xfd5f0019,0x661b1900}},	//   rzie, četa, _luyệ, _aguk,
   {{0x6443a6dc,0x443ec0d1,0x6299199b,0x69c45530}},	//   dani, _ret_, _onwo, szie,
   {{0xd04101d4,0x443e26a4,0xd6d901ce,0x2d92023b}},	//   rilə, _set_, пті_, _krye_,
   {{0x6443694c,0x1c22009f,0x628900f0,0x443e00ca}},	//   fani, _मलाल_, ddeo, _pet_,
   {{0x62990c05,0x843800e3,0x443e0216,0x2a6000bc}},	//   _anwo, أكثر_, _qet_, lgib_,
   {{0x443ec0d2,0xf487010d,0xd7f20037,0xd90d0018}},	//   _vet_, بانی, _شكر_, _ایل_,
   {{0x29180044,0x225f0918,0xf2120134,0x2a60c0d3}},	//   _hira_, gguk_, _rọbọ, ngib_,
   {{0x2918af32,0x443ec0d4,0x64578b00,0xfd5f0019}},	//   _kira_, _tet_, óxic, _duyệ,
   {{0x29180694,0xbcfb0018,0x62990150,0x92be0033}},	//   _jira_, rték, _enwo, ঁচে_,
   {{0x0857040a,0x2d920169,0xddcd0094,0x75200350}},	//   ובים_, _arye_, _zdaň, _humz,
   {{0x2918c0d5,0x7d170063,0x22930037,0x75200a58}},	//   _lira_, _sixs, _للمس, _kumz,
   {{0x2f1a00e8,0x29180090,0x00000000,0x00000000}},	//   _rīgu_, _oira_, --, --,
   {{0x29180af0,0x7e6400ec,0xbca50037,0x00000000}},	//   _nira_, _ecip, رمزي, --,
   {{0xbcfb0076,0x2fc901c2,0x2d920172,0xac1800be}},	//   ntéi, _ƙage_, _erye_, дору_,
   {{0xe1880028,0x34db009d,0x5f041fdb,0x764073c9}},	//   _kỳ_, _बद्द, _изја, _nemy,
   {{0x7e7dc0d6,0x98b92284,0x2bcf00a3,0x2d8500e8}},	// [f190] mesp, плат_, _हेरा, āles_,
   {{0x6d5d9004,0x6443c0d7,0x291878c0,0x22440b14}},	//   musa, xani, _cira_, hamk_,
   {{0x64432ba9,0x291803f3,0x69090039,0x76400de9}},	//   vani, _dira_, _džep, _bemy,
   {{0x64431f83,0xcf9300c1,0x7e7d8121,0x6b85c0d8}},	//   wani, כטע_, nesp, _ishg,
   {{0x6443263e,0x6d5dc0d9,0x2918c0da,0x6ef63906}},	//   tani, nusa, _fira_, cábu,
   {{0x2918c0db,0xd0060068,0xf5920018,0x3949c0dc}},	//   _gira_, _مل_, الوج, msas_,
   {{0xa3c9218b,0x6443c0dd,0x6d5dc0de,0x76400154}},	//   _लेख_, rani, husa, _femy,
   {{0x715923a3,0x2918097f,0x3a29658c,0x7e7d48b8}},	//   прос_, _zira_, ncap_, jesp,
   {{0x7e7d526d,0x6ea302d5,0x75200239,0x753b0169}},	//   desp, गानु, _gumz, _uwuz,
   {{0x29180432,0x3949c0df,0x7e64750b,0x6d5dc0e0}},	//   _xira_, isas_, _scip, dusa,
   {{0xfd5f0019,0x644101d3,0x3f910e43,0x7640a082}},	//   _tuyệ, _ieli, ízu_, _yemy,
   {{0x3949359d,0x64413b37,0x7e7da8ab,0xee370c10}},	//   ksas_, _heli, gesp, нню_,
   {{0x6441c0e1,0x6d5dc0e2,0xd0a80260,0x20d504a1}},	//   _keli, gusa, سطین_, _пікс,
   {{0x315600f5,0x6441055c,0x2d92057a,0x38b602b6}},	//   _ניצן_, _jeli, _vrye_, _værk_,
   {{0x64412c09,0xeabfc0e3,0xa2a602d5,0x3949c0e4}},	//   _meli, _blù_, टॉक्, esas_,
   {{0x29182c7b,0xfd4a013d,0xeabf009c,0x3eb90364}},	//   _sira_, _език_, _clù_, ckst_,
   {{0x6d5d0cb0,0x2918b7c7,0xeabf01b9,0x2a6000bc}},	// [f1a0] cusa, _pira_, _dlù_, rgib_,
   {{0x6441c0e5,0xe8f7b89c,0x29180052,0x25690076}},	//   _neli, елу_, _qira_, dúl_,
   {{0x29186181,0xf0b6006e,0xeabf01b9,0x3949010b}},	//   _vira_, עלער_, _flù_, asas_,
   {{0x291803ec,0x75200239,0x6ea30285,0x00000000}},	//   _wira_, _pumz, गायु, --,
   {{0x6441c0e6,0x25080281,0xf99f0154,0x00000000}},	//   _beli, ورتی_, _ogèy_, --,
   {{0x6441c0e7,0x7e7d1b5a,0x7ebf023b,0x7986c0e8}},	//   _celi, zesp, _mëpa, _iskw,
   {{0xc5f100c7,0x6d5d0364,0xd4670291,0x7e7d047e}},	//   জেলা_, zusa, хије_, yesp,
   {{0x6d5d0bb6,0x6441007a,0x78200006,0xbcfb7c0c}},	//   yusa, _eeli, _बलुक_, rtéi,
   {{0xbcfb54ba,0x5066085a,0x00000000,0x00000000}},	//   stéi, нтна, --, --,
   {{0x6441c0e9,0x78ae770b,0x6d5d00aa,0xfbb200d2}},	//   _geli, _jobv, vusa, ीनाम,
   {{0x7e7d1e95,0x0f2306c4,0x32020094,0x6d5d1a48}},	//   tesp, льям, ťky_, wusa,
   {{0x6d5d3639,0x828900d6,0xe1880023,0xa3c906eb}},	//   tusa, _осіб_, _tỳ_, _लेट_,
   {{0x6441973d,0x3b1900bd,0x3eb9c0ea,0x00000000}},	//   _yeli, _risq_, rkst_, --,
   {{0x2abc0032,0x38b6003e,0xda0700c3,0x5ff49032}},	//   _bíbo_, _færi_, _शरबत_, _излу,
   {{0x6d5d6702,0xa2a4080f,0xdb2300d1,0xd0f700d7}},	//   susa, काप्, اوری, _רמות_,
   {{0x6d5dc0eb,0x3949c0ec,0x442c05db,0x539b00ca}},	//   pusa, tsas_, _lfd_, הילו,
   {{0x38c90018,0x39490271,0x00000000,0x00000000}},	// [f1b0] وائی_, usas_, --, --,
   {{0x81e20033,0x63610129,0x3b19003d,0x00000000}},	//   _ধরা_, ịnih, _wisq_, --,
   {{0x3949c0ed,0x798683df,0xd8740e00,0xdced0995}},	//   ssas_, _eskw, طالب, _usađ,
   {{0xc5d500d6,0x461500cd,0x442c0583,0x78ae05db}},	//   кіль, نوار, _afd_, _eobv,
   {{0x64417104,0x09db0081,0xa2a40d61,0xd1260d7f}},	//   _peli, _দরকা, कान्, _خم_,
   {{0x442c1f72,0x6441023b,0xdb07007b,0xbcfb014b}},	//   _cfd_, _qeli, syjä, buée,
   {{0x61fc0092,0x2d8c00e8,0x00000000,0x00000000}},	//   ərli, ādei_, --, --,
   {{0x6441c0ee,0x442c3f17,0x1db300c3,0x3cf30096}},	//   _weli, _efd_, ुनात, ंकडे_,
   {{0x644136c6,0xc69200c1,0xa1560291,0x05740d59}},	//   _teli, _דאן_, вању_, _مالد,
   {{0x4095188d,0x6e2d00b3,0x6441101e,0x45d42458}},	//   трит, _afab, _ueli, _соус,
   {{0x600900c2,0x6d4d6c22,0x662802c3,0x7ebf0216}},	//   ьном_, _avaa, _åskå, _sëpa,
   {{0x38b60102,0x623513dc,0x442c0027,0xba3b2bc7}},	//   _væri_, _реду, _zfd_, _moïs,
   {{0x0d99055b,0x0d8319e0,0x628b0072,0x00853d77}},	//   нтры_, алян, _iago, _алло,
   {{0x628bc0ef,0xa15600ca,0x6e2d01ff,0x00000000}},	//   _hago, _יבנה_, _efab, --,
   {{0x8c431357,0x628b4ed7,0x316d0257,0x99800138}},	//   ресе, _kago, ltez_, ybių_,
   {{0x628bc0f0,0x7db603d9,0xcebb03e3,0x316d037a}},	//   _jago, _асоц, _tuƙa_, otez_,
   {{0x628b1619,0x316d5f7a,0xd946120a,0x6aaf0036}},	// [f1c0] _mago, ntez_, тези, _docf,
   {{0xed590579,0x6efd0018,0x26c7023b,0xbcfb00fd}},	//   áže_, yébk, ënon_, tuée,
   {{0x6fc102d5,0x442c02ac,0x316d0062,0x00000000}},	//   शनिं, _rfd_, htez_, --,
   {{0xb6cb0103,0x442c007f,0x00000000,0x00000000}},	//   وانے_, _sfd_, --, --,
   {{0x64a64268,0x05d21ae6,0x2bb209a1,0xd90d0103}},	//   када, _देशब, ीनवा, زیہ_,
   {{0x628b00f9,0x00000000,0x00000000,0x00000000}},	//   _aago, --, --, --,
   {{0x628bc0f1,0x07a30fd5,0xbcfb00fd,0xf743007b}},	//   _bago, _карн, quée, _весо,
   {{0xbcfb0018,0xe7eb009f,0x628bc0f2,0xa4eb007f}},	//   ltét, _जुटा_, _cago, टवॉच_,
   {{0x628b02a7,0xc05a097a,0x00000000,0x00000000}},	//   _dago, мін_, --, --,
   {{0x628b010a,0xf5480129,0xf5070012,0xf8bf014b}},	//   _eago, mụ_, _анул_, _tuée_,
   {{0xa0a300c6,0x2fc901c2,0xf5480294,0x96b63856}},	//   ршыл, _ƙaga_, lụ_, _अकाउ,
   {{0x628bc0f3,0x26c60167,0xe3160037,0xe8070179}},	//   _gago, nhoo_, _شباب, वेटा_,
   {{0x316d025a,0x62803691,0xd1300470,0x1154008f}},	//   ctez_, memo, _امت_, _склю,
   {{0x628b837b,0x62805605,0x63600294,0x38b601cd}},	//   _zago, lemo, _ịnye, _kæru_,
   {{0x628b4efb,0xf5480294,0x00000000,0x00000000}},	//   _yago, hụ_, --, --,
   {{0x62809b18,0x290a008c,0x00000000,0x00000000}},	//   nemo, _ahba_, --, --,
   {{0x79840270,0xbcfb037a,0x6d4d024a,0x00000000}},	// [f1d0] gwiw, ruéb, _uvaa, --,
   {{0x628001b6,0xf54806c0,0x2d890079,0x6efd0231}},	//   hemo, dụ_, _isae_, débi,
   {{0x6280c0f4,0x2d9d0072,0x00000000,0x00000000}},	//   kemo, _áweb_, --, --,
   {{0xf5480174,0x7ebf0052,0xaaad074c,0x798405bd}},	//   fụ_, _mëpo, _टकटक, bwiw,
   {{0x628b4387,0xf5480174,0xe8070285,0x00000000}},	//   _rago, gụ_, वेजा_, --,
   {{0x628b4ca2,0xe73314ea,0x00000000,0x00000000}},	//   _sago, _نصر_, --, --,
   {{0x628bbb6a,0x58d40636,0xbcfb0018,0xd7f8075f}},	//   _pago, _торт, ltés, _аут_,
   {{0x316d0257,0xf5480129,0x00000000,0x00000000}},	//   ttez_, bụ_, --, --,
   {{0xbcfb0068,0xdb150018,0x316d0257,0x00000000}},	//   ntés, gyzé, utez_, --,
   {{0x316dbdbd,0x628b31ab,0x3e7e00fe,0x00000000}},	//   rtez_, _wago, _ắt_, --,
   {{0x628bc0f5,0x62800d9f,0x316d6f49,0xd0480092}},	//   _tago, bemo, stez_, nidə,
   {{0xed5a4941,0x62800d9f,0xf2120e62,0x316d0c35}},	//   ном_, cemo, _kọlọ, ptez_,
   {{0xd04800a7,0xbcfb01f9,0x00000000,0x00000000}},	//   hidə, jtés, --, --,
   {{0xbfb50246,0x657b0079,0xa06900e5,0x00000000}},	//   _محبت, _mpuh, _чака_, --,
   {{0x3f87015c,0x5ea60037,0xf54800ac,0xe0d000d1}},	//   _usnu_, _ممثل, zụ_, _بزن_,
   {{0x0e661b77,0x290a00dd,0x9e661612,0x38b633df}},	//   _скин, _shba_, _свид, _lært_,
   {{0x3ea022d4,0xfe3700ca,0x1a06131b,0x00000000}},	// [f1e0] _init_, _גרפי_, упам, --,
   {{0x6280c0f6,0x33250036,0x291c0212,0x38b613c8}},	//   zemo, _oulx_, öva_, _nært_,
   {{0x3ea016e3,0x657b0270,0xf8bf00b3,0xbb46007b}},	//   _knit_, _apuh, _atés_, _щенк,
   {{0xfaa60ed1,0x628008a8,0xbcfb31a5,0x8646020f}},	//   _само, xemo, stét, ундж,
   {{0x62800bfe,0x7ae4c0f7,0x3ea00167,0x7d1e5b29}},	//   vemo, mnit, _mnit_, _kips,
   {{0x7ae4c0f8,0xbcfb0103,0x5334013f,0x690b002b}},	//   lnit, ltér, аект, güed,
   {{0x62804e48,0x27f70074,0xbcfb003e,0x66e6007e}},	//   temo, čené_, bréf, _бова,
   {{0x7ae408a3,0x7d1e002d,0x96950c58,0x38b6003e}},	//   nnit, _lips, _круш, _væru_,
   {{0x7ae4af5b,0x628060c8,0x20070063,0x38b601cd}},	//   init, remo, _azni_, _fært_,
   {{0x7ae4c0f9,0x20c00441,0x3ea0c0fa,0x3d00007f}},	//   hnit, _eòin_, _anit_, ोगों_,
   {{0x7ae409a6,0x644ac0fb,0x2018032c,0x20c0009c}},	//   knit, mafi, äri_, _fòin_,
   {{0x61469589,0x7ae41cc9,0x9ec700d1,0x00000000}},	//   _беда, jnit, ازده, --,
   {{0x7ae4c0fc,0x3b0000a7,0x3ea00131,0x00000000}},	//   dnit, dliq_, _dnit_, --,
   {{0x40345334,0x5f942007,0x644ac0fd,0x32da0065}},	//   _текс, _викт, nafi, _fàyè_,
   {{0x60da0d17,0x22460167,0xbcfb0328,0x7ae41849}},	//   mitm, _keok_, guéa, fnit,
   {{0xfebb00bf,0x5a350114,0x644aac9b,0x7ae43c5d}},	//   _ساعت_, рнат, hafi, gnit,
   {{0x644a3cd3,0x200b00a5,0x19580ab3,0x74a702d5}},	// [f1f0] kafi, ęcie_, латы_, चामृ,
   {{0x7ae4c0fe,0xbcfb0103,0x387801b9,0x644ac0ff}},	//   anit, rtés, _cbrr_, jafi,
   {{0x64570b0b,0x644ac100,0xf80705b6,0x6d4fc101}},	//   óxim, dafi, учан, lsca,
   {{0xbcfb72b1,0x6d5dc102,0xaa95004d,0x38b64a75}},	//   ctér, orsa, _тимч, _sært_,
   {{0xe5a51525,0x6d4f00e3,0x6f0d0527,0x644a0d2a}},	//   рили, nsca, _mhac, fafi,
   {{0x644a7773,0xd7fb0818,0x00000000,0x00000000}},	//   gafi, _зуб_, --, --,
   {{0x38b602ec,0x6d5d042c,0x60da1206,0x00000000}},	//   _vært_, hrsa, ditm, --,
   {{0x290104f9,0x6d5d1197,0x6f0d87bb,0xe2990036}},	//   llha_, krsa, _nhac, таи_,
   {{0x91e57480,0x6727006d,0x645e60d3,0x659449cc}},	//   ропе, _hujj, ópic, _лату,
   {{0x764bc103,0x6f0d0169,0x66094653,0x3ea04592}},	//   lagy, _ahac, _izek, _snit_,
   {{0x7d1e31e8,0x6f0d03ea,0x67270022,0xfd4a0134}},	//   _rips, _bhac, _jujj, balị,
   {{0x6f0dc104,0x7d1ec105,0xef17002d,0x67270517}},	//   _chac, _sips, имэ_, _mujj,
   {{0x6f0dc106,0x7ae40e7e,0x67270361,0x6d4f3001}},	//   _dhac, vnit, _lujj, gsca,
   {{0x764b5688,0x6609063d,0x60da173c,0x60c801f7}},	//   hagy, _mzek, citm, chdm,
   {{0x6d5db679,0xbcfb20cc,0x6f0d09f7,0x6d4fc107}},	//   arsa, ttér, _fhac, asca,
   {{0x6f0d879b,0x3ea000ca,0x6aad003e,0x7d1e0381}},	//   _ghac, _unit_, gjaf, _wips,
   {{0x7d1e057e,0x2d8c00d9,0x7ae49b79,0x644a1b99}},	// [f200] _tips, ādes_, rnit, yafi,
   {{0xbcfbc108,0x6727083e,0xe8c7539a,0x644a008c}},	//   stér, _bujj, агул_, xafi,
   {{0x5c5b0054,0xbcfb045e,0x644a0092,0x66098247}},	//   _בדיק, ptér, vafi, _azek,
   {{0x6d440034,0x644a8a1a,0x656201af,0xf54f0174}},	//   _kwia, wafi, tuoh, pụli_,
   {{0x66090067,0x644ac109,0x7bce9625,0xa2a411d7}},	//   _czek, tafi, lzbu, कास्,
   {{0xd37a4fb4,0x22460085,0xc44800cd,0xd94382e2}},	//   вчи_, _seok_, ایان_, _фери,
   {{0x6609c10a,0xf2c6007e,0x67270361,0x6e247432}},	//   _ezek, исин, _gujj, _ogib,
   {{0x644ac10b,0xbcfb3894,0x6e24c10c,0x2abc0139}},	//   safi, prég, _ngib, _bíbi_,
   {{0x60f8013d,0xaca40065,0x644a2dec,0x3cf8c10d}},	//   лния_, _arọw, pafi, korv_,
   {{0x6d5d08a9,0x6e241764,0x7ae90218,0x6f0d13e2}},	//   vrsa, _agib, četi, _shac,
   {{0x6f0d4157,0x3f980146,0xf99f0154,0x4386001c}},	//   _phac, íru_, _azèl_, _خلاق,
   {{0xaca40174,0x6448c10e,0xbcfb0072,0xe8d90294}},	//   _drọw, _hedi, guén, trị_,
   {{0xa1580d62,0x6d5dc10f,0x3cf3231a,0x68e5020b}},	//   _салу_, ursa, ंकले_, ynhd,
   {{0x64480d95,0x6d4f0503,0x91bb00ca,0x99990031}},	//   _jedi, rsca, _במדי, _jesť_,
   {{0x6f0d713d,0xf99f0154,0xaa59004d,0x01e80033}},	//   _thac, _ezèl_, ливу_, _পরিদ,
   {{0x644817d2,0x1b191119,0x8aa4117a,0xbcfb034f}},	//   _ledi, ужбы_, оруд, cuén,
   {{0x6d4400a5,0x672703e3,0x7e6d3759,0xdced02a1}},	// [f210] _gwia, _sujj, _icap, _jqaċ,
   {{0x6448c110,0x4ddc00a1,0x6e242174,0x66090034}},	//   _nedi, _שחזו, _zgib, _rzek,
   {{0x66090103,0x6d44007f,0xbcfb020d,0xab950076}},	//   _szek, _zwia, grée, _الجغ,
   {{0x2b5e02c6,0x99890117,0x00000000,0x00000000}},	//   átce_, mbaž_, --, --,
   {{0x64481c81,0x764b1474,0x356b3457,0xd4d908a1}},	//   _bedi, ragy, трен_, лькі_,
   {{0xdfc6c111,0x04420636,0x64482243,0x6727083e}},	//   _في_, пешн, _cedi, _tujj,
   {{0xbcfb020d,0xe8d90294,0x7afd05db,0x764bc112}},	//   crée, gwụ_, _kkst, pagy,
   {{0x66090634,0x6448c113,0x00000000,0x00000000}},	//   _tzek, _eedi, --, --,
   {{0xeaaa006e,0xf99f0154,0x00000000,0x00000000}},	//   רױפֿ, _ozèm_, --, --,
   {{0x6448c114,0x26dd0283,0x60d80042,0x7649008c}},	//   _gedi, liwo_, _cmvm, _heey,
   {{0x25db04dd,0x349411c0,0x6d44c115,0xdce40206}},	//   _खेती_, _фахр, _swia, _priľ,
   {{0x26dd8281,0x7bce0146,0x6448be33,0xd49100fe}},	//   niwo_, vzbu, _zedi, _hà_,
   {{0xa2a404f8,0x6448574c,0x75296722,0xdd0f013c}},	//   कार्, _yedi, _juez, _qışq,
   {{0x76490694,0x7bcec116,0xa5da00c1,0xa2d31358}},	//   _leey, tzbu, אַלי, बोर्,
   {{0xd49100de,0x752101d3,0xa3aa049d,0xfaa62569}},	//   _mà_, _milz, खमय_, баво,
   {{0xd49100de,0x7c250063,0xf8bf0042,0x6e24404b}},	//   _là_, _eghr, _quén_, _ugib,
   {{0x6d442edf,0x26dd01c2,0x6720009e,0x00000000}},	// [f220] _uwia, diwo_, _rimj, --,
   {{0x7afdc117,0x6c8600e3,0xbcfb0257,0x75210231}},	//   _ekst, _الدم, trée, _nilz,
   {{0x78b50335,0x6448a7e9,0xdb1c023b,0x7649554f}},	//   _dozv, _redi, nyrë, _beey,
   {{0x64487652,0x6efdc118,0xbcfb020d,0x7649026d}},	//   _sedi, lébr, rrée, _ceey,
   {{0x64484287,0x673b005f,0x75212c18,0xd49100fe}},	//   _pedi, _čuje, _bilz, _bà_,
   {{0x6fca05d4,0x6cf8074c,0x6efd014b,0x660000d4}},	//   ानमं, ंकिग_, nébr, _vymk,
   {{0x6448a8f3,0xdb1c0052,0x67203f9b,0x41d03559}},	//   _vedi, jyrë, _timj, _तेजस,
   {{0x4425c119,0x76490b5b,0xdd2d0138,0x00000000}},	//   _egl_, _geey, vėžy, --,
   {{0x39527828,0x75290072,0x64481917,0xb6bb00ca}},	//   nsys_, _guez, _tedi, _עצמי,
   {{0x7e6dc11a,0xfbc80455,0xbcfb0072,0x9f541ad2}},	//   _scap, रनाम, guél, овоч,
   {{0x2d8008a1,0xa5071543,0x7649083e,0x224dc11b}},	//   _apie_, _уефа_, _yeey, baek_,
   {{0x490f0fef,0xcebb01c2,0x7521c11c,0x8143015a}},	//   _तीनो_, _kuƙi_, _zilz, _کنون,
   {{0x200b0067,0x26c70052,0x00000000,0x00000000}},	//   ęcia_, ënoi_, --, --,
   {{0x1fa60dc9,0x6ce736bf,0x6efd464f,0xf1a900d1}},	//   _григ, сіме, gébr, _خامه_,
   {{0x78b50074,0x3a360129,0x2a690167,0x7ebf0216}},	//   _rozv, _ọgụ_, tgab_, _lëpi,
   {{0x7e6d4a02,0xada60031,0x78b505db,0x7f3b006e}},	//   _ucap, _spúš, _sozv, _געהו,
   {{0x7c250063,0x2a694304,0x78270076,0x00000000}},	// [f230] _tghr, rgab_, معال, --,
   {{0x7649041c,0x00000000,0x00000000,0x00000000}},	//   _seey, --, --, --,
   {{0xddcd0034,0x569500c2,0x752907ee,0xf99f0383}},	//   _udał, жает, _suez, _syèd_,
   {{0x8f9b00ca,0x3f9c14f3,0x7649008c,0x39521d91}},	//   טיבי, _mrvu_, _qeey, bsys_,
   {{0x98c501e8,0x94251538,0x61e43b84,0x7521c11d}},	//   ştır_, омле, _žiln, _pilz,
   {{0x7649332c,0xe35935c1,0x2d9900bc,0xe3b000d1}},	//   _weey, ашиш_, ivse_, کره_,
   {{0xd49100de,0x44252cee,0x00000000,0x00000000}},	//   _và_, _vgl_, --, --,
   {{0x6b830161,0xd299004b,0xf99f0154,0x00000000}},	//   _ângu, рткі_, _tyèd_, --,
   {{0x059500cd,0x44250510,0x3f9c00aa,0xddc402a1}},	//   _بازگ, _tgl_, _arvu_, _qbiż,
   {{0xe0d92a3b,0x443100a7,0xdb1c023b,0x4425bdb9}},	//   рво_, _üz_, tyrë, _ugl_,
   {{0xd009016a,0xbef7009d,0x248706a3,0x3f9c00c4}},	//   рене_, ीतून_, menm_, _crvu_,
   {{0x3f9c00c4,0x6e2902c6,0x0cb40287,0x00000000}},	//   _drvu_, žebn, ुस्म, --,
   {{0x61ed042d,0x00000000,0x00000000,0x00000000}},	//   _žalf, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6efd020d,0x799d26b5,0x798f041c,0xdb1c0216}},	//   rébr, _arsw, _ascw, qyrë,
   {{0xbcfb014b,0x00000000,0x00000000,0x00000000}},	//   tréc, --, --, --,
   {{0xdce402a1,0xa96a0095,0xcee9001c,0x2bc80285}},	// [f240] _esiġ, риза_, _درون_, रनहा,
   {{0x39520178,0x6d5605bd,0x00000000,0x00000000}},	//   rsys_, _ivya, --, --,
   {{0xd7ff00ae,0x562a3a8c,0x00000000,0x00000000}},	//   _ţări_, ажем_, --, --,
   {{0xbcfb0257,0x98af00d9,0x395200d8,0x91c901e4}},	//   préc, īgā_, psys_, िनाई,
   {{0x94aa4d18,0xddcd00a5,0x41d902d5,0x645e13a9}},	//   итка_, _gdań, _बेलस, ópio,
   {{0x43940231,0x61e400d8,0x00000000,0x00000000}},	//   закс, _žilo, --, --,
   {{0xd46715de,0xdb151f20,0xe71a00d1,0x00000000}},	//   ције_, lyzá, _نيست_, --,
   {{0xcebb01c2,0xfbe80023,0x00000000,0x00000000}},	//   _tuƙi_, _đề_, --, --,
   {{0xcb135074,0x045a09b4,0x00000000,0x00000000}},	//   ולה_, _نجات_, --, --,
   {{0x3f9c02e6,0xb4637712,0xb97b021e,0xa50a180b}},	//   _prvu_, _окул, סניי, _теза_,
   {{0x6d56022b,0xd1b70018,0x78a10154,0x00000000}},	//   _avya, مایا_, _ólve, --,
   {{0x7642c11e,0xbcfb0113,0x7c2814f3,0x00000000}},	//   nboy, dréa, ždrl, --,
   {{0xf65300a1,0x171b00c1,0xdce402a1,0x6562c11f}},	//   וצר_, יוטע, _ssiġ, nroh,
   {{0x61ed013f,0x6fb60037,0x25a0007b,0x20d30076}},	//   _žalg, _ومشا, äily_, _يتوج,
   {{0xbcfb4229,0x80a300d1,0x00000000,0x00000000}},	//   gréa, _زمين, --, --,
   {{0x690b0472,0x00000000,0x00000000,0x00000000}},	//   güen, --, --, --,
   {{0x645a0220,0x59de0d7e,0x00000000,0x00000000}},	// [f250] _odti, _नेदर, --, --,
   {{0xf8073bf9,0x6562c120,0xa3aa00b6,0x645e0072}},	//   очен, droh, खमा_, ópil,
   {{0x37ab1e46,0x602d0103,0x7d0700e7,0xbcfb020d}},	//   штан_, _hőmé, mljs, créa,
   {{0x0f7b00a1,0x645a061d,0xeabf0441,0xabfa00ca}},	//   שראל, _adti, _diùc_, _להתר,
   {{0x64a575d3,0x00000000,0x00000000,0x00000000}},	//   зала, --, --, --,
   {{0xab98001c,0x645a01ff,0xf99f0032,0x6fca2172}},	//   _اخیر_, _cdti, _irè_, ानां,
   {{0x7642250c,0x798d083e,0x00000000,0x00000000}},	//   bboy, lwaw, --, --,
   {{0xd2a902fd,0x2d84026a,0x7ebf0052,0xdffe0336}},	//   ские_, çmek_, _këpu, _उड़द_,
   {{0xa3db0da9,0x213900dd,0xdc1806e4,0x00000000}},	//   _ढेर_, ësh_, _दण्ड_, --,
   {{0x98bd50a4,0x753bc121,0xf8bd50d7,0x00000000}},	//   ोसिए, _ituz, ोसिय, --,
   {{0x6443c122,0x8fa5277b,0x00000000,0x00000000}},	//   mbni, чане, --, --,
   {{0xe29802ec,0xf99f6ace,0x7b13a15b,0x60ca02db}},	//   _має_, _orè_, nçud, _elfm,
   {{0xe0cec123,0x7ebf0052,0x3eab00d4,0x260f00a4}},	//   _зв_, _nëpu, _šité_, तेची_,
   {{0x213f0496,0x40871fdb,0x913a00a1,0xbcfb002b}},	//   mpuh_, _фудб, _העסק, tréa,
   {{0xf99f5acf,0x00000000,0x00000000,0x00000000}},	//   _arè_, --, --, --,
   {{0x8b230326,0xaf76006e,0xbcfb020d,0x28de0442}},	//   едсе, _זעקס_, rréa, फोनि,
   {{0xf98323d0,0x798d2fc3,0x753b7d0a,0xf99f0113}},	// [f260] нгто, gwaw, _ntuz, _crè_,
   {{0x765bc124,0x2d92022b,0x00000000,0x00000000}},	//   _aduy, _isye_, --, --,
   {{0x753b5478,0xf99f02f1,0x66e63a7a,0x29e2009e}},	//   _atuz, _erè_, пожа, _sħaħ_,
   {{0x690b25da,0xf99f0c56,0x798d0517,0x65627a86}},	//   qüen, _frè_, bwaw, troh,
   {{0xa50a2249,0x765b0172,0xf99f0154,0xa533018a}},	//   беда_, _dduy, _grè_, еніч,
   {{0x39401e8f,0x7afb0087,0x2d9202f1,0x6562c125}},	//   mpis_, čute, _msye_, rroh,
   {{0xbcfb0103,0x753b0172,0xb62a00fe,0x00000000}},	//   krén, _etuz, _chợđ, --,
   {{0x994c0038,0x6562c126,0xd379004d,0x3d230065}},	//   _môže_, proh, ючі_, _kéwì_,
   {{0x672e00e7,0x64430212,0x7faa00a7,0x291a0350}},	//   _hubj, bbni, vəqq, ompa_,
   {{0x26c6c127,0xbf0504f1,0x9405013c,0x00000000}},	//   lkoo_, रत्न_, _lalə_, --,
   {{0xb4e8009d,0xb226004c,0x2d9205aa,0x7d0702ef}},	//   मची_, _емел, _asye_, vljs,
   {{0x6b9c0106,0x0b000081,0x26c6008c,0xbcfb0437}},	//   dvrg, ্দুল_, nkoo_, grén,
   {{0x68fe0ab2,0x91d4382d,0x7b13014b,0x3de00033}},	//   kopd, _बेचै, nçue, _যুবল,
   {{0x01370341,0x2ceb0cd1,0x690b0072,0xb1130120}},	//   _צרות_, сьмо_, güel, _зміш,
   {{0x2d920154,0x307b00ca,0x26c6007b,0x7ee700ae}},	//   _esye_, _האונ, kkoo_, _нцие,
   {{0x59de2172,0x3d230032,0xbcfb0103,0xf1b00096}},	//   _नेहर, _béwì_, ntéz, _जपान,
   {{0x394007ac,0x98b9016d,0x6aac1515,0x3ea99b04}},	// [f270] gpis_, олат_, _šofé, _inat_,
   {{0x7e7d0a2c,0x798d10ca,0xf99f02f1,0x00000000}},	//   lfsp, rwaw, _vrè_, --,
   {{0x753b7438,0x41c800b6,0x00000000,0x00000000}},	//   _stuz, ाईँस, --, --,
   {{0xa63400d6,0xf99f06a3,0x672e0078,0x2bd63856}},	//   енці, _trè_, _dubj, _डेटा,
   {{0x7aed0a75,0xc9840424,0x8c190421,0x3a390154}},	//   mnat, _пури, _ديگر_, _ifsp_,
   {{0x83393457,0x2eba2581,0x3959034f,0xe5a20036}},	//   очит_, _उक्त, _ivss_, тиши,
   {{0x6443c128,0x20c90088,0xe4500037,0xbcfbc129}},	//   rbni, _búin_, اضه_, guéi,
   {{0x7aedc12a,0x569474da,0x2480005f,0x7e7d01c0}},	//   nnat, _паст, đima_, jfsp,
   {{0x61ed005f,0xf48721a1,0x7aed203f,0x753b05bd}},	//   _žalb, _нужн, inat, _utuz,
   {{0x629d0181,0x3ea905fe,0x3b0902e7,0x7aed00f0}},	//   ôsob, _anat_, hlaq_, hnat,
   {{0x3e8a2a6e,0x656bc12b,0x39402052,0x7aed187d}},	//   ойно_, lugh, zpis_, knat,
   {{0x32e306a3,0x3940003e,0xee370226,0x00000000}},	//   _dèyè_, ypis_, мню_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7aed5fe0,0xbddb0113,0x00000000,0x00000000}},	//   enat, mbèl, --, --,
   {{0xeb9744ab,0xbcfbc12c,0x26cd2f05,0x1d07311c}},	//   мир_, prén, _oleo_, фери_,
   {{0x7aedc12d,0x21270019,0x3940005f,0x3a3902a1}},	//   gnat, _hinh_, tpis_, _cfsp_,
   {{0x212700ef,0x09e34564,0xa3e40455,0x672ec12e}},	// [f280] _kinh_, вотн, _पेन_, _subj,
   {{0x7aed80a7,0xa3bf274c,0x3ea91fce,0x6d9221d5}},	//   anat, ुना_, _znat_, ržać,
   {{0x21270028,0x68fe01cb,0x212fc12f,0x7aedc130}},	//   _minh_, ropd, _lugh_, bnat,
   {{0x21270028,0x39400c53,0x656b0451,0x68fec131}},	//   _linh_, ppis_, fugh, sopd,
   {{0x7ae4b2e0,0x20c90076,0x6f040350,0x00000000}},	//   miit, _rúin_, _mkic, --,
   {{0x7ae4198c,0x21270019,0xb4e8009d,0xed590146}},	//   liit, _ninh_, मचे_, áži_,
   {{0xd823311c,0x6f040880,0x26cd0154,0x673c0117}},	//   _адри, _okic, _fleo_, _utrj,
   {{0xdce60146,0x78bcc132,0x6b830212,0x2127009c}},	//   dukč, _horv, _änge, _ainh_,
   {{0x78bc322d,0x21270019,0x69c47269,0x20070233}},	//   _korv, _binh_, nyie, _ayni_,
   {{0x7aed02e6,0x7ae4b5ff,0x6f042bff,0x3cf8007f}},	//   znat, hiit, _akic, ंकों_,
   {{0x20c900e3,0x21270019,0x442c0167,0x7aedc133}},	//   _iúil_, _dinh_, _igd_, ynat,
   {{0xa1c60c0d,0x752803ab,0x7ae40239,0xa3e41f88}},	//   _обед, _hidz, jiit, _पेय_,
   {{0x7aed2281,0x6282c134,0x20070092,0x78bc057a}},	//   vnat, _iboo, _eyni_, _oorv,
   {{0x7c84c135,0x6f04bb10,0xbcfb0072,0x00000000}},	//   кусе, _ekic, ntéx, --,
   {{0x3b09009e,0xc0592f0c,0x00000000,0x00000000}},	//   tlaq_, _хіі_, --, --,
   {{0x3ea90270,0x7ce90b14,0x75283f81,0x20c9033c}},	//   _unat_, džre, _lidz, _lúil_,
   {{0x7aedc136,0x2bff1244,0xaca300ac,0x628206b0}},	// [f290] rnat, _शुरू_, _abụg, _mboo,
   {{0x21270028,0x273703e5,0x75287b2f,0x62820124}},	//   _xinh_, _aħna_, _nidz, _lboo,
   {{0x7d050da3,0x78bc1428,0x6d4d0483,0x6f1d029a}},	//   _ikhs, _dorv, _hwaa, omsc,
   {{0xa29e000d,0x6d4d39b4,0x75280167,0x9967008f}},	//   _खोल्, _kwaa, _aidz, _отгл,
   {{0x78bc2c03,0xca242b49,0x442cc137,0x6e2d0124}},	//   _forv, _афри, _bgd_, _mgab,
   {{0x628282ad,0x656b3ab2,0x6d4d42ce,0x20c90076}},	//   _aboo, rugh, _mwaa, _cúil_,
   {{0x21270023,0x6d4d083e,0x20c90076,0x6e2d6205}},	//   _rinh_, _lwaa, _dúil_, _ogab,
   {{0x212700ef,0x6e2d479d,0x2d4d0618,0x2901025b}},	//   _sinh_, _ngab, kže_, loha_,
   {{0x15f330c3,0x6abdbd2b,0x6d4d0129,0xbcfb0072}},	//   _आखिर_, _mosf, _nwaa, trél,
   {{0x6f041424,0x2d4dc138,0x6e2d0115,0x75280113}},	//   _skic, dže_, _agab, _gidz,
   {{0x6d4d63b6,0x21270019,0x66090167,0xf8b20327}},	//   _awaa, _vinh_, _hyek, אשי_,
   {{0x62820032,0x61ea0103,0x6d4d083e,0x66090517}},	//   _gboo, ámlá, _bwaa, _kyek,
   {{0x67290067,0x21270028,0x2bc806e4,0x290100aa}},	//   _miej, _tinh_, रन्थ, koha_,
   {{0x6d4d0a88,0x6f1d68ee,0x6e2d01b2,0x629901ee}},	//   _dwaa, amsc, _egab, _hawo,
   {{0x6299c139,0xdee600a9,0x6abd0a39,0x316da379}},	//   _kawo, _поки, _bosf, luez_,
   {{0x78bcc13a,0x629bc13b,0x61e40181,0x672917b5}},	//   _sorv, nduo, _žili, _niej,
   {{0xe9da28b9,0xdca60ed1,0x6609c13c,0x7ae41cbd}},	// [f2a0] чка_, _запи, _nyek, riit,
   {{0x62996bfe,0x7ae41d84,0xf99f022b,0x29010350}},	//   _lawo, siit, _iyèl_, goha_,
   {{0x6d4d0ab2,0x75284218,0x66090201,0xb80a0037}},	//   _zwaa, _ridz, _ayek, أيام_,
   {{0x6299c13d,0xd04101d4,0x20c900e3,0x66090361}},	//   _nawo, rhlə, _súil_, _byek,
   {{0xe5a3121c,0x442cba2b,0x65941ea8,0x78bc0ac9}},	//   лици, _pgd_, талу, _torv,
   {{0x66090154,0x2480015c,0xf99f0383,0x316d01ff}},	//   _dyek, đimo_, _myèl_, duez_,
   {{0x62997a8a,0x752801d3,0x2ca7002b,0x442c0120}},	//   _bawo, _vidz, _ónde_, _vgd_,
   {{0x752800a5,0xd25000e3,0x629bbd66,0xf5ea00ae}},	//   _widz, جنة_, gduo, _ембл_,
   {{0x6299c13e,0x66090361,0x00000000,0x00000000}},	//   _dawo, _gyek, --, --,
   {{0xbcfb2c6c,0x6e2dc13f,0x442c0085,0x20c001b9}},	//   trém, _sgab, _ugd_, _ròis_,
   {{0x6d4d0185,0x71fa0281,0x29180090,0x00000000}},	//   _swaa, _کراس_, _mhra_, --,
   {{0x629922fd,0xf99f022b,0x20c00441,0xbcfb020d}},	//   _gawo, _byèl_, _còir_, rrém,
   {{0x29180078,0x6f1d02db,0x98a30383,0x29010169}},	//   _ohra_, rmsc, _sijč_, yoha_,
   {{0x2d4d1197,0x629900a5,0x62801507,0xddcd0090}},	//   rže_, _zawo, lfmo, _ibaż,
   {{0x6299001b,0x2f120103,0x0b88002d,0x20c001b9}},	//   _yawo, sága_, нсти_, _fòir_,
   {{0x6d4d39b4,0x29180085,0x29010124,0xf99f05aa}},	//   _twaa, _ahra_, woha_, _fyèl_,
   {{0xe9f80120,0x29014230,0x68e50233,0x6d4d18fd}},	// [f2b0] енті_, toha_, tihd, _uwaa,
   {{0x629b0138,0xe4e5045f,0x672916c3,0x6609010a}},	//   zduo, _औषधि_, _siej, _ryek,
   {{0xec360054,0x66091613,0xe81c1101,0x2901c140}},	//   _באתר_, _syek, भेला_, roha_,
   {{0x291800f9,0xb8c8245a,0xf77007e8,0x66090113}},	//   _ehra_, _खो_, صام_, _pyek,
   {{0x9f5c02fd,0x67290890,0xd0060018,0xb5fd0117}},	//   _hyvä_, _viej, _چل_, _odše,
   {{0x629923c0,0x291801b9,0xbcfb037a,0x6729007f}},	//   _sawo, _ghra_, mués, _wiej,
   {{0x6299573e,0xef1f0555,0xc1c90285,0x00000000}},	//   _pawo, kmü_, िन्ग, --,
   {{0xddcd003d,0x656402ef,0xb5ca0032,0x660905aa}},	//   _bbaż, šiha, _kẹ́t, _tyek,
   {{0x629b01b3,0x36d40084,0xe535007b,0x00000000}},	//   rduo, _сотр, _резь, --,
   {{0xf99f0154,0xb60400ae,0x316d0062,0xbddb0113}},	//   _nyèm_, _сяск, ruez_, mbèh,
   {{0x644b2cc8,0xf99f06a3,0x629921f3,0xb2750086}},	//   čnič, _syèl_, _tawo, _алеш,
   {{0xed5a248d,0xdee6385a,0xfe720037,0x00000000}},	//   мом_, томи, جدد_, --,
   {{0x316d025a,0xf1d90034,0x7bc701cd,0x00000000}},	//   quez_, _बेचन, eyju, --,
   {{0x71d60089,0x00000000,0x00000000,0x00000000}},	//   _בונד_, --, --, --,
   {{0xe7e102e8,0x6d400155,0x7afb0117,0x8f1600ae}},	//   _गेला_, ímab, čutn, _ифич,
   {{0xc33209c1,0x00000000,0x00000000,0x00000000}},	//   שון_, --, --, --,
   {{0x3b0701c9,0xeabf00de,0x0eaf02d5,0x29186c4a}},	// [f2c0] тето_, _giùm_, टारड, _phra_,
   {{0x07a60f1e,0x00000000,0x00000000,0x00000000}},	//   казн, --, --, --,
   {{0xc00f0023,0xbcfb00d4,0x00000000,0x00000000}},	//   _đuối_, dréh, --, --,
   {{0xdd1100b6,0x2bf700ca,0xf99f05aa,0x00000000}},	//   mýšl, _ימין_, _zyèm_, --,
   {{0x19f900ae,0x61ed8076,0x00000000,0x00000000}},	//   _зэрь_, _žaln, --, --,
   {{0x25a40124,0xf8bf00de,0xbcfb0231,0x00000000}},	//   _vrml_, _quét_, quét, --,
   {{0x7e0f0179,0xfe7f00b3,0x289b006e,0x00000000}},	//   _सर्ग_, diïn_, _קילא, --,
   {{0xb8650068,0xdced02a1,0x00000000,0x00000000}},	//   _لاہو, _msaġ, --, --,
   {{0xbcfb0146,0x69c00131,0xa52618d4,0x00000000}},	//   bréh, _àmed, _амад, --,
   {{0x30a60624,0x93461728,0x00000000,0x00000000}},	//   трив, _анже, --, --,
   {{0x6458c141,0x085700a1,0x443e181f,0x691000aa}},	//   mavi, כבים_, _ift_, väel,
   {{0x6458c142,0xe24600e3,0xdce600d9,0x7c3e02b6}},	//   lavi, _شخصي, vukā, _afpr,
   {{0x200200a5,0x443e0018,0xbcfb0018,0xc6930266}},	//   łki_, _kft_, nség, באר_,
   {{0x64580f2e,0x3157006e,0xfe7f00b3,0xdb1c00d4}},	//   navi, _יידן_, ciïn_, vyrá,
   {{0x6d46c143,0xf09300ca,0xfc460206,0xf99f0154}},	//   apka, _כנס_, _číta_, _vyèm_,
   {{0xbcfb0fea,0x6458c144,0x32d10139,0x6d4000d4}},	//   guér, havi, _káya_, ímac,
   {{0x5a3422ff,0xdced02a1,0x443e7ae5,0xbcfb0076}},	// [f2d0] рнут, _esaġ, _oft_, hréi,
   {{0x64580941,0x6d5d1aa7,0x2b4100fe,0x06ca0033}},	//   javi, mssa, _tthc_, লোমি,
   {{0x32d10af0,0x05db007f,0x00000000,0x00000000}},	//   _láya_, _मेजब, --, --,
   {{0xbcfb0850,0x24853653,0xadc40032,0xdea40d2a}},	//   dréi, _sblm_, _abẹw, _bunƙ,
   {{0xbcfbc145,0x3cf80688,0x6d5d65fa,0xdea401c2}},	//   gség, _سعید_, nssa, _cunƙ,
   {{0xb97a0054,0x6d5dc146,0x64582db5,0xf7730068}},	//   _אנשי, issa, gavi, _پاس_,
   {{0x443e0d4d,0x679300d1,0x1cbc0142,0xfe7f00b3}},	//   _dft_, _خیاط, ומגע, viïn_,
   {{0x81de00c7,0xe3a600cd,0x6d5f0abd,0x32d10139}},	//   _দুই_, اشوی, _ovqa, _báya_,
   {{0x35f51acf,0xbcfb020d,0x659460dc,0xf99f05aa}},	//   _спар, préh, _кату, _syèj_,
   {{0x2ecc1c83,0x76590113,0x40950cba,0xbcfb17d5}},	//   ास्त, lawy, урит, bréi,
   {{0xd2510080,0x6d5d00c2,0xceea0058,0xba3b0313}},	//   _هنا_, essa, едне_, _kaïd,
   {{0xc332004f,0x656b00d3,0x67350542,0x6f0f0124}},	//   _הוא_, orgh, _muzj, glcc,
   {{0x01650848,0x7afb0087,0xa069554c,0x6d4900d3}},	//   _скло, čutl, _зала_, ţean,
   {{0x515a00a1,0xa3ca007f,0x00000000,0x00000000}},	//   _טכנו, रैक_, --, --,
   {{0xbcfb0018,0xbea60f80,0x6b6300d6,0x8c43060b}},	//   zség, _байк, йкра, сесе,
   {{0xd00e0080,0xa3d40c17,0xbcfb0103,0x6d464ab2}},	//   _علي_, हनत_, ység, ppka,
   {{0x6458c147,0x6da6180b,0x200b0034,0x317f01e9}},	// [f2e0] yavi, _сипа, ęciu_, ntuz_,
   {{0x317f01e9,0x7b1300a7,0xa90a0076,0x00000000}},	//   ituz_, lçul, ريال_, --,
   {{0x3f5100d9,0x2f190018,0x64586780,0xdea401c2}},	//   nšu_, sége_, vavi, _sunƙ,
   {{0xbcfbc148,0x443eab49,0x8ec60033,0x7b13013c}},	//   tség, _sft_, শোরগ, nçul,
   {{0xbddb020d,0x9c8700d4,0x66fc05db,0x00000000}},	//   ccèd, _určí, jčke, --,
   {{0xbcfbc149,0x3f5101d3,0x00000000,0x00000000}},	//   tréi, kšu_, --, --,
   {{0xbcfb0068,0xa3e40abe,0x929d00a5,0x3f51007e}},	//   sség, _पेश_, woła, jšu_,
   {{0x6458250f,0x7e640010,0x6d5d6660,0xdea401c2}},	//   savi, _ndip, yssa, _tunƙ,
   {{0x3f510029,0x6d4401bb,0x443e0ec7,0xe5a31a0c}},	//   ešu_, _ntia, _tft_, _лити,
   {{0x7e647c5d,0xb603025b,0xe97b00c1,0x64580092}},	//   _adip, ýšen, עניש, qavi,
   {{0x2286041e,0x33f60084,0x2ef50a22,0xbcfb00fd}},	//   _булг, _счас, изор, nsée,
   {{0x6d5d0429,0xbcfb014b,0x26c5014b,0x00000000}},	//   tssa, isée, _îlot_, --,
   {{0x6d5dc14a,0xdced009e,0x7e64030a,0x00000000}},	//   ussa, _jsaħ, _ddip, --,
   {{0x67229290,0x940c00a7,0xdced009e,0x6d4400da}},	//   hmoj, _sadə_, _msaħ, _dtia,
   {{0xd5a407d9,0x6d4401ff,0xcb1b0396,0x1bd400ae}},	//   _کہ_, _etia, еќа_, боря,
   {{0x3d1a0251,0x63a8042d,0x6d5d6ab7,0x6b9b007f}},	//   _मीठे_, _mrdn, pssa, ługo,
   {{0x085514fa,0x286b129c,0xa8554ab5,0xba3b000b}},	// [f2f0] иваю, ерео_, икач, _naïe,
   {{0x63a8adbb,0xe6c002e6,0xa3d40852,0xaa7b00d8}},	//   _ordn, _čišć, हना_, _zmýl,
   {{0x96355736,0xb90d0065,0xec150a85,0x97a701b6}},	//   анец, _kikẹ_, _خودد, ырал,
   {{0xbcfb00fd,0xdced02a1,0xe70b001c,0xba3b020d}},	//   sséd, _bsaħ, رتان_, _qaïd,
   {{0x286b07c8,0x4a5a00ca,0x63a800a7,0xb065007b}},	//   _прво_, _בדרו, _ardn, nnää,
   {{0x64a5550a,0x672200c6,0x690b002b,0x93951454}},	//   рака, amoj, güet, لجبا,
   {{0xe299393e,0x39492c5a,0x32d5075f,0xdb05022b}},	//   вай_, lpas_, ицис, _arhé,
   {{0x05150f71,0xd05a0092,0x394900c2,0x3f510995}},	//   াদের_, mitə, opas_, všu_,
   {{0x50b56924,0x39490abf,0x317f01ff,0x00000000}},	//   асну, npas_, utuz_, --,
   {{0x9f854766,0x317f0a00,0x39490956,0x6ad209c4}},	//   агод, rtuz_, ipas_, _सत्र,
   {{0x6d44c14b,0x63a800cc,0x7afb0087,0x2002026a}},	//   _stia, _grdn, čutj, şkin_,
   {{0x3f5101d3,0x200e00eb,0x733a0142,0x39490f5a}},	//   ršu_, _dyfi_, _סענס, kpas_,
   {{0x224d0479,0x20d500d6,0x823403c5,0xe0ce6ab2}},	//   mbek_, _війс, _ارما, _дв_,
   {{0xc5f200a1,0xa0691fc4,0x7ae600dc,0x224dc14c}},	//   קדם_, _рака_, _smkt, lbek_,
   {{0xfbc32b49,0x6b830212,0x60c301b5,0xca560284}},	//   обро, _ängl, _ionm, итањ,
   {{0xaa464906,0x4a462db3,0x38c80d7f,0x316d014b}},	//   реал, рнав, گاری_, orez_,
   {{0x7d0704eb,0x60c309b2,0x88e6942b,0x394906a8}},	// [f300] bojs, _konm, ажае, gpas_,
   {{0x38c8037f,0x61e60088,0x52d20965,0xebe60396}},	//   داری_, úkli, _तत्स, _вооп,
   {{0x394917d5,0x81cb0033,0x3ea0a072,0xf772415a}},	//   apas_, রছি_, _kait_, تاء_,
   {{0x4aca110f,0xe5c6344a,0x6441c14d,0xaaca00aa}},	//   _रविव, исло, _afli, _रविक,
   {{0x6722c14e,0xbcfb0257,0x224d007e,0xa5da0037}},	//   rmoj, ssée, dbek_, خبار_,
   {{0xa29e000d,0x60c302f1,0xf36603fc,0x3ea0c14f}},	//   _खोज्, _nonm, атин, _lait_,
   {{0x316db13d,0xbcfb020d,0x00000000,0x00000000}},	//   erez_, prév, --, --,
   {{0x7af60084,0xdb1c0e3e,0x2489042d,0x32d10139}},	//   nnyt, byrå, đama_, _dáyo_,
   {{0x63a85214,0x64410150,0x60c309c2,0xbcfb020d}},	//   _wrdn, _ffli, _bonm, nséc,
   {{0x60c30fb6,0xf48403ed,0x25a6c150,0x2bc90096}},	//   _conm, _داری, mvol_, रहमा,
   {{0x26c40044,0x03a3545b,0x7d07023b,0x83690018}},	//   _komo_, _мифо, vojs, _مصنف_,
   {{0x3ea003ea,0x7afb033b,0x91b7001c,0x26c4c151}},	//   _cait_, čutk, _چطور_, _jomo_,
   {{0x25a61570,0x316d00ae,0x60c33228,0xba3b1695}},	//   nvol_, crez_, _fonm, _laïc,
   {{0x7d02054f,0x26c4c152,0x60c3022b,0xf99f0154}},	//   _íosl, _lomo_, _gonm, _kyèv_,
   {{0x3ea010af,0xd0f50789,0x7d07015c,0x5ba42357}},	//   _fait_, ीकरण_, rojs, ортз,
   {{0x5a35016e,0x60c30381,0x60dac153,0x25a602ac}},	//   снат, _zonm, lhtm, kvol_,
   {{0x7afa0102,0x7c876368,0xbcfb003e,0x6f0d024a}},	// [f310] étta, _куне, frét, _ikac,
   {{0x39494d2f,0x3ea00a00,0x97a700ae,0x58bb0037}},	//   rpas_, _zait_, ирел, خارج_,
   {{0x26c40b27,0xfc460146,0x6f0d010a,0xb8080037}},	//   _bomo_, číte_, _kkac, ليكم_,
   {{0x26c40b0b,0x39490572,0xd05a00a7,0x2d8f020d}},	//   _como_, ppas_, ritə, _âges_,
   {{0xd05a0092,0x26c40051,0x644101bf,0xe5a52e0f}},	//   sitə, _domo_, _pfli, сили,
   {{0x316d025a,0xbcfb0257,0x64410124,0xf4873168}},	//   vrez_, crét, _qfli, рудн,
   {{0x6f0dc154,0x26c40065,0x00000000,0x00000000}},	//   _okac, _fomo_, --, --,
   {{0x7aedc155,0x316d0257,0x04e70081,0x26c40063}},	//   niat, trez_, খকের_, _gomo_,
   {{0x2002008e,0x3ea0b582,0x316d014b,0x60c3c156}},	//   şkil_, _rait_, urez_, _ponm,
   {{0x14770a09,0x316dbdbd,0x6f0d2939,0x3ea08c30}},	//   _خارج, rrez_, _akac, _sait_,
   {{0x850406fa,0x3ea02c7b,0xedd017ad,0xbea68481}},	//   _بولن, _pait_, हन्छ, банк,
   {{0x316d007f,0x799d0090,0x7aed01ff,0x60c3022b}},	//   prez_, _ossw, jiat, _wonm,
   {{0x7d1e05db,0x7aed09bc,0x2bba1677,0x2169be15}},	//   _phps, diat, _उपहा, _сили_,
   {{0x2d8216a2,0x60dac157,0x22930018,0x3ea000ca}},	//   rtke_, chtm, _دلچس, _wait_,
   {{0x2d820e9e,0x799d010a,0x7af6169c,0x06f700c3}},	//   stke_, _assw, tnyt, ंचाव_,
   {{0x7aedc158,0x7f3a0130,0x1ee812eb,0x3ea00037}},	//   giat, _געקו, _خوبی_, _uait_,
   {{0x5d860080,0xe8fa1ca7,0x661b0129,0x2bba034d}},	// [f320] _الخل, гла_, _nzuk, _उपवा,
   {{0x26c4c159,0x7af60e3e,0xbcfb49f0,0x00000000}},	//   _somo_, snyt, rséc, --,
   {{0x7aed5380,0xbcfb003e,0x661b0634,0x799d0361}},	//   biat, rrét, _azuk, _essw,
   {{0x667600e3,0x7aedc15a,0x25a6c15b,0xbcfb003e}},	//   إدار, ciat, tvol_, srét,
   {{0xb33c00bd,0x19b900ae,0xbcfb0231,0xe7e80285}},	//   _irħi, _курь_, crés, _टेरा_,
   {{0xc95309c1,0x6d5602ad,0x25a6895c,0x628b0027}},	//   _ממש_, _mwya, rvol_, _abgo,
   {{0x25a65268,0xbcfb674d,0x0ec80d75,0x00000000}},	//   svol_, nséa, _लवंड, --,
   {{0x26c4013d,0x6aa48585,0x25a60a88,0xbcfb0076}},	//   _uomo_, ndif, pvol_, iséa,
   {{0xc05a0426,0x79848677,0x7bce0146,0xc5c60033}},	//   лін_, ntiw, hybu, _শেরপ,
   {{0x7aed73d5,0x7afb0087,0x7642034f,0x3d02007f}},	//   ziat, čuti, lcoy, लकों_,
   {{0x60da0350,0x645a01d3,0xd04100a7,0x73360076}},	//   rhtm, _ieti, nklə, _طرائ,
   {{0x645ac15c,0xe3b10068,0x60da023b,0x539b00ca}},	//   _heti, _کرے_, shtm, _תיאו,
   {{0x645a10e3,0x7aedc15d,0xd24f00e3,0x6aa40150}},	//   _keti, viat, _أنه_, ddif,
   {{0x7aed0034,0x6e360103,0x645a6138,0xa3bf0096}},	//   wiat, _egyb, _jeti, ुनच_,
   {{0x2f120103,0x7aed0cd6,0xd00f0037,0x75b40096}},	//   zági_, tiat, _كله_, ंमुळ,
   {{0x645a3fa3,0x61ed7689,0xbcfb0018,0x6d560150}},	//   _leti, _žali, trés, _fwya,
   {{0x798406a8,0x1ef80037,0x273e00fc,0x20c90503}},	// [f330] gtiw, _دعوة_, _aïn_, _iúir_,
   {{0x4aa9007d,0x7aedc15e,0xb33c02a1,0xa3ab1e93}},	//   _चोरव, siat, _erħi, खिम_,
   {{0x661b0067,0x7aedc15f,0x2d92166d,0x77990ef1}},	//   _szuk, piat, čneš_, ркер_,
   {{0xbcfb025a,0x645a01b9,0x1b170033,0x00000000}},	//   prés, _aeti, _দূরে_, --,
   {{0x645a38ff,0x2bd1007a,0x356b0c59,0x7afd01cb}},	//   _beti, सनका, урен_, _ijst,
   {{0x24890542,0xf99f7461,0x7afd0381,0x201c00d4}},	//   đamo_, _dyèt_, _hjst, _ozvi_,
   {{0x2f120018,0xc7c47f94,0x00000000,0x00000000}},	//   sági_, _ести, --, --,
   {{0x645a668b,0x661b01ff,0xb145117f,0x00000000}},	//   _eeti, _tzuk, онил, --,
   {{0xe0d91456,0x661bc160,0x00000000,0x00000000}},	//   иви_, _uzuk, --, --,
   {{0x645ac161,0x1f65108f,0x78a58c9f,0x20c90076}},	//   _geti, оком, ndhv, _rúis_,
   {{0xdbf2000d,0x69100006,0x753b024a,0x7afd0141}},	//   _příp, päev, _huuz, _ojst,
   {{0x753b0010,0x8234001c,0x20c9033c,0x00000000}},	//   _kuuz, _فرها, _cúir_, --,
   {{0x645a07d1,0x69cb01c5,0x753b010a,0x00000000}},	//   _yeti, øgel, _juuz, --,
   {{0x7afd00e7,0x753bb258,0x64436f61,0x225fc162}},	//   _ajst, _muuz, ncni, lauk_,
   {{0xda5a0476,0xf99f10fe,0xea5a0396,0xeb9a6aed}},	//   ираш_, _asè_, ирај_, шив_,
   {{0x25ad44a6,0x225f080e,0x6fc6030b,0x7bce0034}},	//   _orel_, nauk_, ाहरू, rybu,
   {{0x753b0174,0x98ab0233,0x00000000,0x00000000}},	// [f340] _nuuz, _avcı_, --, --,
   {{0x7984c163,0x186a0a7c,0x691000bc,0x6eef0154}},	//   rtiw, ражи_, jäet, _tòbè,
   {{0x7984c058,0x645a5244,0xf99f5acf,0xadee0386}},	//   stiw, _reti, _esè_, _चेतन_,
   {{0x268a054f,0x645a2c09,0xb7c00139,0x753b06b0}},	//   شخصي_, _seti, _aṣá, _buuz,
   {{0x645ac164,0x659600e3,0xba480138,0xd041013c}},	//   _peti, تجار, grįž, sklə,
   {{0x53342064,0x65623fc8,0xeabf01ec,0x2d9202ac}},	//   пект, rsoh, _fiùs_, _mpye_,
   {{0x39401d49,0xf4870470,0x645a543e,0x6d400094}},	//   lqis_, تانی, _veti, ímaj,
   {{0x8bfc0033,0x32d801dc,0xd141007f,0x645a022b}},	//   _ইরান_, _béya_, knąć_, _weti,
   {{0x645a9c69,0x673c00c2,0x66fc0117,0x27ea00c6}},	//   _teti, _hurj, lčko, žinė_,
   {{0x2a60006c,0x673c3b64,0x7a410065,0x79b700ca}},	//   haib_, _kurj, _kátó, קליד_,
   {{0x66fc033b,0x2d9205aa,0x673c166d,0x320a0034}},	//   nčko, _apye_, _jurj, łby_,
   {{0xb3570103,0x539b1777,0x00000000,0x00000000}},	//   _بیٹا_, _כיבו, --, --,
   {{0xc33300ca,0x673c78c2,0x00000000,0x00000000}},	//   _חוף_, _lurj, --, --,
   {{0xe57100c1,0xd12f01b3,0x00000000,0x00000000}},	//   ײַך_, _іх_, --, --,
   {{0x66fc141f,0xac190291,0x673c0d75,0xdefb0fe9}},	//   jčko, сову_, _nurj, _вып_,
   {{0xa3ab2a24,0x7a390077,0x988500b6,0x644c00a7}},	//   खित_, спар_, _vůči_, əniş,
   {{0x49752f68,0xb33c009e,0x9f040076,0x66fc0206}},	// [f350] ялас, _irħu, _تويو, ečko,
   {{0x7e7d0f04,0x37ab261f,0xa9bb0179,0xec6b35c1}},	//   lgsp, итен_, _ईपीए, _трик_,
   {{0x2a6002e7,0xf99f06a3,0x765b0167,0x753b3635}},	//   baib_, _pyès_, _peuy, _suuz,
   {{0x41ca37b3,0x7e7d00f2,0x673c0c45,0x753b0350}},	//   िहास, ngsp, _durj, _puuz,
   {{0xc98400ae,0x2aba00d7,0x00000000,0x00000000}},	//   _оури, _המרא, --, --,
   {{0x03a533a2,0x673c009e,0x7a410830,0x6b850113}},	//   зико, _furj, _fátó, _kqhg,
   {{0x673cc165,0xf99f022b,0x00000000,0x00000000}},	//   _gurj, _tyès_, --, --,
   {{0xc7b2004f,0x753b0134,0x3a39007e,0x569400d3}},	//   _אבל_, _tuuz, _jgsp_, _оаст,
   {{0xd49b44b2,0xc8ff0033,0x225fc166,0xf48707bf}},	//   _вре_, ্গীত_, rauk_, _мужн,
   {{0x39590270,0x00000000,0x00000000,0x00000000}},	//   _mwss_, --, --, --,
   {{0xb5fd2052,0x9f58003e,0xd00963f1,0x00000000}},	//   _odšk, ærð_, сене_, --,
   {{0xfaff0910,0xa3e404dd,0x61ed7440,0x2a60023e}},	//   _një_, _पेट_, _žalu, xaib_,
   {{0xbddb15c9,0xf1a72e57,0xbcfb39b6,0x213f0063}},	//   scèn, _френ, trép, qquh_,
   {{0x6cd60080,0x386101bf,0xba3b00fc,0x00000000}},	//   أقسا, jahr_, _baïo, --,
   {{0xd141007f,0x00000000,0x00000000,0x00000000}},	//   snąć_, --, --, --,
   {{0x3946113e,0x32d10139,0x00000000,0x00000000}},	//   знаг, _báyi_, --, --,
   {{0x386101bf,0x00000000,0x00000000,0x00000000}},	// [f360] fahr_, --, --, --,
   {{0xe9d7534f,0x673c0673,0xb5fd00e7,0xee3f0094}},	//   чку_, _purj, _kešf, ndýn_,
   {{0x98aa00ae,0x3f670218,0x657901cb,0x4c3b00d7}},	//   _aibă_, nđu_, euwh, _לתיב,
   {{0xfaff00dd,0xeaf9142e,0x66fc103b,0x63bc00ee}},	//   _gjë_, ्कृत_, rčko, _àrni,
   {{0xa3e41ae6,0x673c03e3,0x00000000,0x00000000}},	//   _पेज_, _wurj, --, --,
   {{0x5fcb0f35,0x6fcb02d5,0x673cc167,0x13941cf2}},	//   ाहाल, ाहां, _turj, дикю,
   {{0x39860231,0x00000000,0x00000000,0x00000000}},	//   lôs_, --, --, --,
   {{0xe3af046b,0x46a30f6a,0x48f600b6,0x00000000}},	//   ارو_, _пасв, ्वको_, --,
   {{0x7d0e4a75,0xe1660037,0x5436212c,0x00000000}},	//   kobs, أدبي, _فرار, --,
   {{0x2ed500c3,0xaa7b0220,0x03a621be,0x54670636}},	//   दस्त, _umýv, _низо, _наум_,
   {{0xb4d822f1,0x3f630084,0xf1f700cd,0xa3e409c3}},	//   ासी_, нтяб, قعیت_, _पेच_,
   {{0x333b00ca,0x6aa60350,0x7b13015e,0x00000000}},	//   _התאמ, _nakf, nçut, --,
   {{0x628201c0,0x7e7d86b4,0x00000000,0x00000000}},	//   _icoo, rgsp, --, --,
   {{0xdcef00d3,0x00000000,0x00000000,0x00000000}},	//   ducă, --, --, --,
   {{0x9b5800d3,0x6aa62c28,0xe8d90134,0x6ad50033}},	//   зист_, _bakf, ntụ_, ঠোফো,
   {{0x60ca83d5,0x68ee05fe,0x6ffb00ca,0x0f7b00ca}},	//   _hofm, _ambd, _להופ, _האהב,
   {{0x7e6d8448,0xaf3400d1,0x00000000,0x00000000}},	// [f370] _idap, _ثروت, --, --,
   {{0x6d4dc168,0x6f0f00e5,0x7d0e0407,0x66d30555}},	//   _itaa, locc, cobs, _içki,
   {{0x6aa60167,0xf7990281,0xbcfb014b,0x00000000}},	//   _fakf, تناب_, nsém, --,
   {{0x6f0f00e5,0xfaff00dd,0x39860131,0x6d49020a}},	//   nocc, _ujë_, bôs_, ţeau,
   {{0x64a53333,0xa2c00c38,0x6d4d0167,0x1a680470}},	//   дала, वान्, _jtaa, _ریلی_,
   {{0x6d4d0051,0xe8d90294,0xa8a40b36,0x00000000}},	//   _mtaa, ftụ_, _прск, --,
   {{0xb0b00789,0xf8b20796,0x62820090,0x00000000}},	//   जयनग, _בשם_, _bcoo, --,
   {{0x7e6db91a,0x660d00aa,0x62820062,0x6d4d06b0}},	//   _ndap, üaks, _ccoo, _otaa,
   {{0xc6920341,0x3f4100b3,0x6f0f028d,0xe8d90129}},	//   _באן_, _sóu_, docc, atụ_,
   {{0xbddb020d,0x65690027,0xe0d10037,0x00000000}},	//   rcèl, _iveh, ئزة_, --,
   {{0x6d4dc169,0x5f0600d6,0x00000000,0x00000000}},	//   _ataa, дзна, --, --,
   {{0x3f670307,0x03780260,0x6f0f0036,0x00000000}},	//   rđu_, _رحمت_, gocc, --,
   {{0xa0690c3f,0xb33c02a1,0x629b0350,0xba3b00fc}},	//   _дала_, _isħa, meuo, _caïm,
   {{0x78a70941,0xee3701b3,0x7e6d03a9,0xddc4020a}},	//   _najv, ьня_, _edap, _adiţ,
   {{0x7d0e2fc6,0x6f0f0451,0x6d4d083e,0x8c433c1f}},	//   robs, bocc, _etaa, тесе,
   {{0x7b3c04eb,0xdce4031a,0x98b1022b,0x629b00f0}},	//   _očuv, _ivič, _dizč_, neuo,
   {{0x6aa60233,0x2bba0a50,0x00000000,0x00000000}},	// [f380] _vakf, _उपका, --, --,
   {{0xddc400d3,0x76498a1c,0x6aa662d3,0xe6c909ac}},	//   _ediţ, _afey, _wakf, _čašć,
   {{0x28c40455,0x6aa63bd7,0x78a70141,0x00000000}},	//   लॉगि, _takf, _dajv, --,
   {{0xe61a31f6,0x7e6d00dc,0x3986016d,0xdb0500d4}},	//   оде_, _xdap, pôs_, _trhá,
   {{0x83fc0580,0xa2b1007f,0x4d7b0142,0x00000000}},	//   _međe, _अफ़्, ַרקע, --,
   {{0xb4d8007d,0xa533004d,0x00000000,0x00000000}},	//   ासे_, вніч, --, --,
   {{0x7791110a,0xb17d0206,0x00000000,0x00000000}},	//   _میلا, vzťa, --, --,
   {{0x291a037a,0x416a0284,0x00000000,0x00000000}},	//   llpa_, ојом_, --, --,
   {{0xcb1300a1,0x26c60085,0x60ca009c,0x05ba0076}},	//   כלה_, mjoo_, _pofm, _بدأت_,
   {{0xba3b00ee,0x7b130052,0xa1270076,0x3e889fd3}},	//   _raïm, nçur, وكيل_, yító_,
   {{0x6d4daa6f,0xdce4025b,0xa0a30077,0x6f0f0451}},	//   _staa, _cvič, тшыл, tocc,
   {{0x25a4707e,0x83fc0095,0x26c60381,0x6282039f}},	//   _ksml_, _ceđe, njoo_, _ucoo,
   {{0xbcfb020d,0x0cab085f,0xb7d50065,0xdce400d8}},	//   ssém, отви_, _iṣek, _evič,
   {{0x6f0f00e5,0x3e8801f9,0x00000000,0x00000000}},	//   socc, tító_, --, --,
   {{0xbbc9000d,0x78a70b14,0x6f0f5dab,0x6d3402f3}},	//   रहेक, _rajv, pocc, терф,
   {{0x3e8801f9,0x6d4d083e,0x5fcb1f88,0x7e6d406e}},	//   rító_, _ttaa, ाहरल, _udap,
   {{0xeabf00de,0x3e880103,0x6d4d77d7,0xb5fd374d}},	// [f390] _chùa_, sító_, _utaa, _keše,
   {{0x3ea91507,0xa3c00b3f,0xad270308,0x6d49044c}},	//   _haat_, ुहा_, _تربو, ţeas,
   {{0x6d407043,0x8c44001f,0x25a40381,0x3ea90381}},	//   ímav, _шеќе, _asml_, _kaat_,
   {{0xb5fd038d,0x501b00ca,0x332600fe,0x00000000}},	//   _leše, חובו, _nhox_, --,
   {{0x3ea9043e,0x7bd50094,0xb065007b,0xa3e1023a}},	//   _maat_, lyzu, niää, नैन_,
   {{0x3ea91d19,0xa3ab05cd,0x6b830e74,0x7d020076}},	//   _laat_, खिल_, _ängs, _íost,
   {{0x290302a1,0xe78400ae,0x00000000,0x00000000}},	//   _ijja_, _иуто, --, --,
   {{0x3ea9274b,0x62800212,0x515500ae,0x00000000}},	//   _naat_, ggmo, нтоу, --,
   {{0x7afa0102,0x629b00f0,0xddc40031,0x83fc0234}},	//   étti, reuo, _odiš, _ređe,
   {{0x629b0150,0x62800381,0x00000000,0x00000000}},	//   seuo, agmo, --, --,
   {{0x32553602,0x81e70081,0x3ea9112d,0x929d0034}},	//   _звер, _মুখ_, _baat_, wołu,
   {{0xe0bf0033,0x7ce202ac,0x00000000,0x00000000}},	//   ইসেন, _môre, --, --,
   {{0x5d6700c2,0xd0d51278,0x2903083e,0x00000000}},	//   ниям_, _подъ, _ojja_, --,
   {{0x332dc16a,0x00000000,0x00000000,0x00000000}},	//   lmex_, --, --, --,
   {{0x69cb17a5,0x7a2a01f9,0x00000000,0x00000000}},	//   ägen, köté, --, --,
   {{0x3ea90505,0x2fd84f94,0x29030283,0xfaa3013f}},	//   _gaat_, ørge_, _ajja_, ласо,
   {{0xc3325074,0x8c461a77,0xa2c0077d,0x09e302e3}},	// [f3a0] רון_, _пепе, वात्, готн,
   {{0x7e66c16b,0x7d57006e,0x6e240201,0x26df05db}},	//   lakp, _רייד_, _izib, _aluo_,
   {{0x7c3e0124,0x7d1c0063,0xeabf0065,0x3ea959e1}},	//   _igpr, mlrs, _ihùn_, _yaat_,
   {{0x28c402d5,0x7e6607ac,0x29037732,0x66e3018a}},	//   लॉजि, nakp, _ejja_, лоха,
   {{0x68340b14,0x7ae4705b,0x00000000,0x00000000}},	//   dždž, mhit, --, --,
   {{0xdb0501bf,0x6e240350,0x491800a3,0x3494004b}},	//   _erhä, _mzib, _बीचो_, такр,
   {{0xb5fd3836,0x969600c9,0x2f190018,0xd90d010d}},	//   _reše, _праш, ségi_, _بیل_,
   {{0x6b830149,0x31c6117c,0x7c3a0206,0x6e2412ed}},	//   _ånge, есов, ľtrh, _ozib,
   {{0x7e6602e7,0x69d601c2,0x343a0b9f,0x3ea902ac}},	//   dakp, nyye, _فساد_, _raat_,
   {{0x3ea9c16c,0x63b70428,0xbcfb0103,0xc05704a1}},	//   _saat_, çanè, rsék, нію_,
   {{0x443ec16d,0x7ae4101e,0x2018003e,0x32e400fe}},	//   _igt_, khit, æri_, _đườ,
   {{0x753a02a7,0x6e24010a,0x7ae4033b,0x00000000}},	//   _hitz, _bzib, jhit, --,
   {{0x7ae4c16e,0xc2e90308,0x7173001c,0x7af60a4b}},	//   dhit, _تعلم_, _مهنا, diyt,
   {{0x3ea90b8e,0x6e2400e7,0x2ee00b12,0x7ae400bc}},	//   _waat_, _dzib, _elif_, ehit,
   {{0x3ea90991,0x6e242828,0xbcfb0076,0x6fe600fd}},	//   _taat_, _ezib, nséi, _décé,
   {{0x3da700f7,0x753a0a00,0x7cd80511,0x7ae4c16f}},	//   _зроб, _litz, _ağrı, ghit,
   {{0x5a350fa5,0x6e2405db,0xfc300103,0x00000000}},	// [f3b0] тнат, _gzib, لحہ_, --,
   {{0x2bba000c,0x394f0029,0xf8073bf9,0x6f1dc170}},	//   _उपचा, īgs_, нчен, llsc,
   {{0x7ae4019f,0x6e24010a,0x00000000,0x00000000}},	//   bhit, _zzib, --, --,
   {{0x443e057a,0x753a0a00,0x7ae4c171,0xf65336c2}},	//   _agt_, _aitz, chit, ائض_,
   {{0x443e0096,0x753a0a05,0xe5a515db,0x00000000}},	//   _bgt_, _bitz, тили, --,
   {{0x443e44dd,0x798dc172,0x6f1d0364,0xdb1c003e}},	//   _cgt_, mtaw, hlsc, lyrð,
   {{0xc1c9030b,0x753a0a00,0x443e0143,0xdb050212}},	//   ाङ्ग, _ditz, _dgt_, _erhå,
   {{0x443e01cb,0x39420167,0x753a0062,0x798d0350}},	//   _egt_, _yuks_, _eitz, otaw,
   {{0x798dc173,0x443e002b,0x6729677b,0x26dc01d3}},	//   ntaw, _fgt_, _ihej, īvot_,
   {{0x76590150,0x6f1d240a,0x2485037a,0x660902a1}},	//   lbwy, elsc, _uclm_, _ixek,
   {{0x6729023e,0x661b6252,0x29010161,0x22950037}},	//   _khej, _hyuk, inha_, _للاس,
   {{0x92eb0f43,0x753a0a00,0x798d0d1f,0x661b06b0}},	//   _عراق_, _zitz, ktaw, _kyuk,
   {{0x6aad9bd0,0xfdc00081,0x09d60081,0x798d023e}},	//   ddaf, উন্ড, _সেনা, jtaw,
   {{0x661b0b58,0x660902a1,0x7e6609a1,0x6aad0381}},	//   _myuk, _mxek, sakp, edaf,
   {{0x2d9e025b,0x7ae4c174,0x5f06008f,0x291354bc}},	//   ňte_, thit, _изка, doxa_,
   {{0x69c40a00,0x6f040085,0x798d0022,0x673b00c6}},	//   txie, _ujic, ftaw, _niuj,
   {{0x61e9c175,0x7ae42f4f,0xf2d200c1,0x661bc176}},	// [f3c0] nzel, rhit, בען_, _nyuk,
   {{0x7d7b09c1,0x7ae41c35,0xbebb023b,0x67290027}},	//   _קניו, shit, smët, _ahej,
   {{0x7ae45228,0xcc7700a1,0x7f430428,0x753a443b}},	//   phit, _בעיה_, _junq, _ritz,
   {{0x753a02e2,0x798d4c19,0x6d440239,0xcf92006e}},	//   _sitz, btaw, _kuia, שטא_,
   {{0xa2c0099d,0x673b0d17,0x753ac177,0x61e901c0}},	//   वास्, _diuj, _pitz, jzel,
   {{0x7e64c178,0xd90d0068,0x6d442279,0x61e956cc}},	//   _leip, _ٹیم_, _muia, dzel,
   {{0x6609c179,0x443e00de,0x61e901cb,0xb5fd0117}},	//   _exek, _vgt_, ezel, _pešc,
   {{0xbcfbc17a,0xbebb023b,0x753a0364,0x7e64c17b}},	//   rséi, hmër, _witz, _neip,
   {{0x7f4309e9,0x7ae300ae,0xb33c0090,0xb7d5026e}},	//   _aunq, _înte, _isħm, _iṣak,
   {{0x753a0ab2,0x6729c17c,0x443e63bf,0xbebb023b}},	//   _uitz, _zhej, _ugt_, jmër,
   {{0x044321b6,0x03a302ec,0x7f4303be,0x61e901ff}},	//   _техн, _вихо, _cunq, azel,
   {{0x7f43008f,0x73361363,0x7e642b39,0xeabf0441}},	//   _dunq, _شرائ, _ceip, _chùl_,
   {{0x291804de,0x6d44016d,0x61e90034,0x91e32249}},	//   _okra_, _cuia, czel, _коце,
   {{0x6fb439d9,0x40a8010d,0x291800dc,0x29130201}},	//   _ممتا, _سختی_, _nkra_, xoxa_,
   {{0xa3ab2c5f,0xb5fd1c54,0xac185912,0x00000000}},	//   खिए_, _meša, вору_, --,
   {{0x3863052f,0x798d6223,0x6d44009c,0xbebb0216}},	//   _sejr_, ttaw, _fuia, rmës,
   {{0x6aad4837,0x09d60033,0x798d0022,0xef1f020e}},	// [f3d0] rdaf, _সেবা, utaw, mlü_,
   {{0x798dc17d,0x661b03a9,0x6729023b,0xef1f008b}},	//   rtaw, _ryuk, _shej, llü_,
   {{0x798dc17e,0x661b0496,0x06751af8,0x61e90d8d}},	//   staw, _syuk, гуля, zzel,
   {{0xf7701850,0xcf9300c1,0x201c0332,0x2918009c}},	//   زام_, יטע_, _myvi_, _ekra_,
   {{0x442502f1,0xa4d500d6,0x83fc0095,0x356b00d3}},	//   _szl_, лоді, _ređa, френ_,
   {{0xd0060080,0x057400e3,0x61e9033b,0x4ddc00ca}},	//   _هل_, شاهد, vzel, וחדו,
   {{0xb5fd0c27,0xf4840884,0xef1f07aa,0x70dc030b}},	//   _deša, ручн, klü_, यसैल,
   {{0x61e95abe,0xd1851612,0x67290027,0x66090634}},	//   tzel, глий, _uhej, _txek,
   {{0x7e647d58,0x69c0014b,0x20d51acf,0x00000000}},	//   _reip, _àmet, гінс, --,
   {{0x7e64010b,0x61e9c17f,0xeabf01ec,0x2a697803}},	//   _seip, rzel, _shùl_, haab_,
   {{0x6441c180,0x61e9c181,0x5ecd0033,0x7e640f18}},	//   _igli, szel, াসনে, _peip,
   {{0x61e90103,0x2ede02d5,0x26dd199b,0x42140129}},	//   pzel, मसेत, nkwo_, ịsọ_,
   {{0xa2c00469,0xd12e00cd,0xeabf3cd6,0xcdf6163d}},	//   वार्, تمی_, _chùm_, учны,
   {{0x7172001c,0x7cf400a7,0x9d431aad,0x4df50208}},	//   _اهوا, _kürə, серд, ряют,
   {{0x3bd50084,0x75ea0018,0x7e646be3,0x83fc2f54}},	//   аютс, _közé, _teip, _leđn,
   {{0xe7f905cd,0xef1f0092,0x224d54b6,0x7ce20031}},	//   ्पना_, clü_, ncek_, _dôra,
   {{0xf2d200c1,0x316d4eb2,0x6b9b00d3,0x64411e00}},	// [f3e0] זען_, nsez_, ăuga, _ogli,
   {{0x644100cd,0x3ea21305,0xbd5b00ca,0x2d825f28}},	//   _ngli, lekt_, _רכיש, muke_,
   {{0x2a6924ad,0xb5fd104b,0x69cb02b6,0xfa6a6ff6}},	//   baab_, _reša, øger, _панк_,
   {{0x64418aed,0x76a9004d,0x98b9020a,0xeabf009c}},	//   _agli, ктів_, _pusă_, _gnù_,
   {{0xb5fd6741,0x2d82c182,0xbcfb020d,0x00000000}},	//   _peša, nuke_, rsév, --,
   {{0x291e0018,0xd9b202d5,0xef1f0367,0x2918c183}},	//   _óta_, ीमीट, zlü_, _ukra_,
   {{0xb5fd4334,0x2d8269ea,0xaa7b02c6,0xa2c009a0}},	//   _veša, huke_, _mlýn, वाल्,
   {{0xe73707ec,0x64416f3c,0xae04097c,0x69c06c99}},	//   _бес_, _egli, रपान_, _àmes,
   {{0xb5fd1528,0x3ea23987,0x638a016d,0xf50a007b}},	//   _teša, dekt_, _bênç, _знал_,
   {{0xc7af0068,0x2d826204,0xa0a616e6,0x00000000}},	//   _بڑے_, duke_, ушил, --,
   {{0xba3b1b59,0xc91700ca,0x3d180285,0x2a69008c}},	//   _haït, רחית_, पकने_, yaab_,
   {{0x51860204,0x753d0103,0x78ae00e8,0x2d82563a}},	//   _бука, _észr, _labv, fuke_,
   {{0xef1f01e8,0xb5fd2174,0x2d825f7f,0x00000000}},	//   rlü_, _lešn, guke_, --,
   {{0x1fa61824,0x2a690188,0x3ead00b6,0xef1f0233}},	//   _бриг, waab_, žet_, slü_,
   {{0xe8141fbb,0xac195334,0xbbdf023a,0x2a697413}},	//   _तुला_, тову_, ननेक, taab_,
   {{0x4a554e42,0x2d82c184,0x00000000,0x00000000}},	//   ркас, buke_, --, --,
   {{0xadb9001c,0xe9750037,0x2a69008c,0x2d820ca9}},	// [f3f0] _شهدا_, شهاد, raab_, cuke_,
   {{0x270d0789,0x2a69008c,0x26dd0174,0x940a00a7}},	//   िक्र_, saab_, wkwo_, şmən_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8aa71361,0x35b51a9c,0x2a69008c,0x00000000}},	//   _срод, ибер, qaab_, --,
   {{0x298b2976,0x7cf40092,0x3949003d,0xa2ce00c3}},	//   _ясно_, _sürə, qqas_, _तवज्,
   {{0x2ee21c83,0xa3c300d2,0x2ca302c3,0x00000000}},	//   _पत्त, _váží_, nejd_, --,
   {{0x2d826dcd,0x3ea2013c,0x00000000,0x00000000}},	//   zuke_, yekt_, --, --,
   {{0xc2454936,0x316d0634,0x41b5109d,0x6aaf026d}},	//   шник, tsez_, لمعر, _jacf,
   {{0xa48700e3,0x6aaf01f7,0x224dc185,0x00e500d3}},	//   _مجان, _macf, rcek_, ижин,
   {{0xe0d90609,0x644101af,0xd12e06f6,0x3ea2029a}},	//   тво_, _ugli, ومي_, wekt_,
   {{0x316d025a,0x03780103,0x62750037,0xd0095ddf}},	//   ssez_, _محنت_, _نهائ, тене_,
   {{0x2d82007a,0x61260088,0x63bc003e,0x799d084e}},	//   tuke_, rðla, _árna, _opsw,
   {{0x3ea2c186,0xb5fd0d62,0xb9250032,0xa15804a1}},	//   rekt_, _mešo, _dupẹ_, _бачу_,
   {{0x2d821386,0xed57002d,0x28c90efb,0x7ff500cd}},	//   ruke_, рор_, राफि, _پستا,
   {{0x2d82c187,0x3ea24f39,0xfaf6084c,0xaca30065}},	//   suke_, pekt_, ачаю, _gbọg,
   {{0x2d827179,0x80da0081,0xb90a00ac,0x80db00b7}},	//   puke_, যোদ্, bakọ_, _पकडे,

   {{0xe9d70636,0x78663574,0x44320023,0x44200023}},	// [f400] акт_, иказ, ̀y_, ́i_,
   {{0x6d56246c,0x98b80154,0x97b600ae,0x3aff00ce}},	//   _itya, _tirč_, исеш, täpä_,
   {{0x6299c188,0x6c7b22fe,0x7c2901c2,0x5ea90033}},	//   _obwo, _בריד, ƙera, গারে,
   {{0x5a960303,0xa3a8009f,0x398f026a,0x00000000}},	//   _троф, खौफ_, büs_, --,
   {{0x7ceb02e2,0x60c40022,0x7ae3020a,0x6aa4024a}},	//   _dürf, _ɗimb, _înta, meif,
   {{0xb5fd050d,0x6299010a,0x6aa4c189,0x00000000}},	//   _tešn, _abwo, leif, --,
   {{0x272700aa,0xbddb00fd,0xb4e600a4,0x00000000}},	//   sõna_, ncèr, _पती_, --,
   {{0xa3100775,0xbcfb283f,0x6d560172,0x224200f3}},	//   ावेज_, nsér, _otya, økk_,
   {{0xc05a07bf,0x6d564db0,0x9f4d00d2,0x79840350}},	//   кін_, _ntya, ěným_, nuiw,
   {{0x0cc100c7,0x67224e4a,0x6b9e02ec,0xba3b057a}},	//   _উত্ত, lloj, _oppg, _kaïr,
   {{0x92e40081,0x3f1513fc,0x67221577,0xba3b02ac}},	//   _নদী_, йдос, oloj, _jaïr,
   {{0xd9f800a4,0xdc2e04a8,0x79840f5a,0x00000000}},	//   ूपात_, _sığa, kuiw, --,
   {{0x23690106,0xf8c900b7,0x7cebc18a,0xb5fd0146}},	//   ćaje_, रामय, _jürg, _nešl,
   {{0x7ceb00bc,0x7c878276,0x2262007f,0x7984084e}},	//   _mürg, шуме, ńską_, duiw,
   {{0x7f840080,0x67220138,0x8f3523aa,0x6d56010a}},	//   _العن, kloj, _лекц, _etya,
   {{0x7ce20072,0xb5fd0fa3,0xb90a0174,0x93bc010a}},	//   _fôro, _bešl, pakọ_, _kyăb,
   {{0x2ca30095,0x09cd0033,0x8d950076,0x00000000}},	// [f410] pejd_, _রেজা, _الخش, --,
   {{0x261a0b89,0xdced0128,0x398f0233,0x63ba2c28}},	//   _बड़ी_, _kvač, rüs_, _ortn,
   {{0xba3bc18b,0xf773082c,0xc6a7007e,0x00000000}},	//   _païs, تاذ_, ирди, --,
   {{0x7ceb01bf,0x672240e8,0xdc560401,0xba190076}},	//   _bürg, gloj, _پریک, _ميجا_,
   {{0xb5fd0e94,0x02c500b6,0x39460076,0x00000000}},	//   _vešo, वासभ, íost_, --,
   {{0x588401b6,0xb4e10034,0x7ceb0364,0x64a5243c}},	//   _мыса, दसे_, _würf, сака,
   {{0xe299758a,0xbcfb0257,0xe3b3001c,0x28f800ae}},	//   гай_, nséq, ترش_, _терь_,
   {{0x7ceb042c,0x00000000,0x00000000,0x00000000}},	//   _hürd, --, --, --,
   {{0x7ceb03e0,0xeabf00fe,0x00000000,0x00000000}},	//   _kürd, _chùi_, --, --,
   {{0x25ad00f0,0xdce400c4,0x70c90291,0x6aa4a467}},	//   _isel_, _ivić, угог_, zeif,
   {{0x7d0700e7,0x79840239,0x6d5602ac,0x6aa40350}},	//   dnjs, zuiw, _stya, yeif,
   {{0xed5a4941,0x67171a94,0x6299023f,0x7ce20220}},	//   лом_, तविक_, _ubwo, _pôro,
   {{0x6d4b04ea,0x225f39a0,0xddd40031,0x93bc010a}},	//   _égal, mbuk_, ťažn, _gyăb,
   {{0x7bdc8817,0xa0690396,0x628911c8,0x6aa40364}},	//   tyru, _сака_, lgeo, weif,
   {{0xcb032301,0xf99f83f5,0x60c30120,0x4b260037}},	//   रचंड_, _apè_, _innm, معرف,
   {{0x612f1484,0x9e6602ff,0x0e660c37,0x25ad11dc}},	//   følg, _увид, _укин, _osel_,
   {{0x3f850517,0x6aa423a8,0xc332040a,0xab270686}},	// [f420] lulu_, reif, לול_, сота_,
   {{0xb4e60251,0xac860c79,0x5e570100,0x6aa44d4b}},	//   _पते_, _угол, _پلیس_, seif,
   {{0x6b9ec18c,0xe3b80491,0xdb150146,0x3f85c18d}},	//   _uppg, _ayın_, žbác, nulu_,
   {{0x612f00f2,0xb5fd00c6,0x649102c6,0x317f01ff}},	//   bølg, _tešl, _lžič, kruz_,
   {{0x3f857693,0x7ceb0018,0x60c30037,0xa596008f}},	//   hulu_, _fürd, _onnm, срещ,
   {{0x3f85c18e,0x28c913ae,0x0ee20336,0x00000000}},	//   kulu_, राणि, _पतझड, --,
   {{0x25ad1f2c,0x00000000,0x00000000,0x00000000}},	//   _esel_, --, --, --,
   {{0xcfd000c7,0x68fe02c9,0xa3c90b89,0x63ba4f88}},	//   ানমন, lipd, _ऊपर_, _vrtn,
   {{0xddcd0880,0xfc460094,0x26c4037a,0x3cf9009f}},	//   _odaš, _čína_, _inmo_, _उगले_,
   {{0x291a746f,0x3f8506b0,0x7ceb026a,0x00000000}},	//   nopa_, fulu_, _küre, --,
   {{0x3f85c18f,0x8f351057,0x64a308f9,0x28c909a0}},	//   gulu_, женц, _хаха, राति,
   {{0xceeb0037,0x60c3022b,0x291a02c3,0x59c800a8}},	//   اردن_, _ennm, hopa_, रमार,
   {{0x317fc190,0x291abef4,0x00000000,0x00000000}},	//   cruz_, kopa_, --, --,
   {{0xa2d40f35,0x3f85c191,0xa2c00096,0x7ce273a0}},	//   यॉर्, bulu_, वाक्, _fôrm,
   {{0x2bc800ae,0xe0fb00ca,0xe81d023a,0x3f850a60}},	//   буто_, _גלגל, _बँधा_, culu_,
   {{0x7ceb008b,0x6ee62a6b,0x00000000,0x00000000}},	//   _sürd, _tóba, --, --,
   {{0x6f0d039f,0x00000000,0x00000000,0x00000000}},	// [f430] _ijac, --, --, --,
   {{0x28c91344,0x291a3cd0,0xfc4700b6,0xb33c0090}},	//   राधि, gopa_, číst_, _isħu,
   {{0x7ae300d3,0xf7700e5a,0x6ead0034,0xdce414f3}},	//   _înto, فان_, ज़पु, _svić,
   {{0x7cebc192,0xdb1f00c2,0x60c401c2,0xa3bc00c3}},	//   _würd, äväk, _ɗima, इटन_,
   {{0xb5fd01b3,0x3f85c193,0x7aedc194,0x28c91cff}},	//   _iešk, zulu_, mhat, रादि,
   {{0x7aedc195,0x23c4250d,0x87e70fbe,0x317f028e}},	//   lhat, वमंद, _любе, vruz_,
   {{0x2ee9c196,0x6f0d015c,0x6289000b,0x7ceb7f09}},	//   _olaf_, _ojac, tgeo, _güre,
   {{0x3b0902a1,0x25ad0167,0xb5fd1db9,0xa2c008c0}},	//   nnaq_, _tsel_, _ješk, वाग्,
   {{0x225f1a27,0xe5c70058,0x6e2d0384,0x3f850060}},	//   rbuk_, _усво, _nzab, wulu_,
   {{0x10a51525,0x3eb20092,0x225f2cf8,0x2ee900dc}},	//   цион, _sayt_, sbuk_, _alaf_,
   {{0x7aed067d,0x1eca08c3,0x3255248d,0x6e2dc197}},	//   khat, ални_, _двер, _azab,
   {{0x7d1e058f,0xf77200c1,0x823400cd,0xb5fd1e4d}},	//   _skps, וקט_, _کرما, _nešk,
   {{0x7aed05bc,0x3f856571,0x2169007e,0x6f0d0e94}},	//   dhat, sulu_, _тили_, _djac,
   {{0x3f85c198,0x6e2d2cea,0x39430381,0x6f0d392c}},	//   pulu_, _dzab, _nijs_, _ejac,
   {{0x8c43171b,0x6e2dc199,0xb5fd6c1a,0x3f85bb5b}},	//   дере, _ezab, _bešk, qulu_,
   {{0x7aed1aba,0xb4e606ed,0x0d860084,0x394b00b3}},	//   ghat, _पत्_, _длин, _bucs_,
   {{0xe8fa344d,0x7ceb0b88,0x291a0141,0x394b00ee}},	// [f440] ала_, _süre, topa_, _cucs_,
   {{0x394b02cd,0xed5902c6,0x6e24460c,0x7ceba903}},	//   _ducs_, íže_, _iyib, _püre,
   {{0x7d1c6eb0,0xab2a02ec,0x68fe0063,0x464a0c59}},	//   mors, _вона_, ripd, азен_,
   {{0xe5c600c2,0x7d1c01f9,0xe9df0af0,0x68fe00c4}},	//   жско, lors, _igún_, sipd,
   {{0x2b5ac19a,0x7ae400c6,0x27f600d2,0x00000000}},	//   _htpc_, mkit, _ženě_, --,
   {{0xd37a04e6,0x7d1c02ec,0x7ae46220,0x7cebc19b}},	//   ачи_, nors, lkit, _türe,
   {{0x24800b88,0x7ae41093,0x00000000,0x00000000}},	//   ğim_, okit, --, --,
   {{0x7ae4c19c,0x24800b88,0x6e242478,0x6ab6030a}},	//   nkit, şim_, _oyib, ndyf,
   {{0x23691419,0x83fc9fe9,0x7ae401e9,0x39940149}},	//   ćaja_, _međi, ikit, näs_,
   {{0x7aed0018,0x83fc08c5,0x7d1c277e,0x6f0d0381}},	//   zhat, _leđi, jors, _sjac,
   {{0x6e2d0068,0x64480124,0x7ae400c2,0x224600dc}},	//   _szab, _igdi, kkit, _tgok_,
   {{0x799600a5,0x224600f9,0x6e240193,0x399400c2}},	//   ktyw, _ugok_, _byib, käs_,
   {{0x7d1c17d2,0x6e2405bd,0xb5fd7a8d,0x69c01726}},	//   fors, _cyib, _rešk, _šmen,
   {{0x7d1c0542,0x394b00ee,0x7ae4285a,0xbcfb014b}},	//   gors, _rucs_, ekit, xpéd,
   {{0x7aedc19d,0x3edf06c0,0xb5fd0b18,0x394b00ee}},	//   that, _abụọ_, _pešk, _sucs_,
   {{0xb6060ea3,0x7ae4259e,0x6d5d1a88,0xd1380138}},	//   _kršć, gkit, ppsa, lmą_,
   {{0x7aedc19e,0x6f1dc19f,0xb5fd030b,0x6e2d0193}},	// [f450] rhat, mosc, _vešk, _uzab,
   {{0x7aedc1a0,0xa2a1110f,0x7d1c008f,0x7ae406b0}},	//   shat, _कॉन्, cors, akit,
   {{0xb5fd02e6,0x7aedc1a1,0x7e6d005c,0x6d452375}},	//   _tešk, phat, _keap, _iiha,
   {{0x6f1d667a,0x6d45c1a2,0x28c9049d,0x3943029a}},	//   nosc, _hiha, राहि, _wijs_,
   {{0x7cf00222,0x63a1025b,0x7ceb0092,0x499309b4}},	//   _därf, _spln, _gürc, _زیار,
   {{0x6d455ce4,0x7e6d1c5d,0xb5fd5c4a,0x6f1d0076}},	//   _jiha, _leap, _ješi, hosc,
   {{0x6d45c1a3,0xb5fd1efa,0x0442c1a4,0xdced0031}},	//   _miha, _meši, нешн, _opaľ,
   {{0x6d452688,0x7e6dc1a5,0x2901c1a6,0x2d82038c}},	//   _liha, _neap, liha_, yrke_,
   {{0x7d1c0b88,0x44450018,0x6d4501e9,0xddc6033b}},	//   yors, _فراہ, _oiha, kakš,
   {{0xb5fd7f3e,0x6d45c1a7,0x7ae40634,0x25bf09f0}},	//   _neši, _niha, zkit, _irul_,
   {{0x7ae401b3,0x7afd000b,0x7d1c5282,0x63a10146}},	//   ykit, _omst, vors, _upln,
   {{0x7e6d378c,0x6f1d2a3d,0x7d1cc1a8,0x25bf18f0}},	//   _ceap, gosc, wors, _krul_,
   {{0x7cf00006,0x6d45c1a9,0xb5fd031a,0x290106e3}},	//   _järg, _biha, _beši, kiha_,
   {{0x78b50995,0xe1f0029e,0x6d4503a3,0x7cf0007a}},	//   _nazv, _جسم_, _ciha, _märg,
   {{0x6d45685c,0x7d1c0068,0xb5fd013f,0xa2c0009d}},	//   _diha, rors, _deši, वाच्,
   {{0x7d1c2c6d,0x6f1d028d,0x7e6d77e3,0x399400c2}},	//   sors, cosc, _geap, täs_,
   {{0x6d450af0,0x7ae4c1aa,0xbebb0052,0x84eb0179}},	// [f460] _fiha, rkit, ymëz, जघाट_,
   {{0x7ae456b7,0x6d4563d5,0x290102c9,0x7649010a}},	//   skit, _giha, giha_, _agey,
   {{0x2d8f0149,0x69cb34fe,0x70a9030b,0x31a800c3}},	//   _äger_, äger, _कसैल, _कन्ध,
   {{0xe7370114,0xd9461d18,0x6d4528e0,0xd138402f}},	//   пех_, _неми, _ziha, zmą_,
   {{0x2901c1ab,0xd1380138,0x3ea002db,0x6d4502a4}},	//   biha_, ymą_, _mbit_, _yiha,
   {{0x4425000d,0xbcfb020d,0x79840d0a,0x78b505db}},	//   _byl_, ppée, mriw, _gazv,
   {{0xdc3600c1,0x07a39100,0x28c9023a,0xdcb100fe}},	//   האַט_, _парн, रारि, ổi_,
   {{0x7cf00212,0x7ceb0092,0xd2500037,0x764906b0}},	//   _färg, _müra, خنة_, _ggey,
   {{0x6f1d1500,0x44253728,0x7cf000bc,0x6569030a}},	//   vosc, _eyl_, _kärd, _gweh,
   {{0x60f802ec,0x3ea00383,0x261500aa,0xddc402a1}},	//   іння_, _abit_, _फुटी_, _ddiż,
   {{0xb5fdc1ac,0x6d451ec9,0xd13852ce,0x6d4d008c}},	//   _reši, _riha, rmą_, _suaa,
   {{0x6d45c1ad,0xd1380138,0x6d4d0167,0x2f450129}},	//   _siha, smą_, _puaa, _ịgba_,
   {{0x6d452429,0xb5fd8c9b,0x29010ff4,0x44250313}},	//   _piha, _peši, yiha_, _zyl_,
   {{0xd12f02ec,0x317b13b6,0x7e6d00ca,0xe7ef00b6}},	//   _їх_, _פרומ, _weap, चनमा_,
   {{0x50b700e3,0x6d459b77,0x7e6dc1ae,0xb5fd0031}},	//   _ردود_, _viha, _teap, _veši,
   {{0x7c250871,0x2d9f436b,0x25a40634,0x929d007f}},	//   _vyhr, çues_, _opml_, piłe,
   {{0xdb240103,0xb5fdc1af,0x69c00072,0x798400d1}},	// [f470] írás, _teši, _ámel, griw,
   {{0x3eab00a1,0x63ad0034,0x2d995556,0x5fb000b6}},	//   lect_, łani, mtse_, _जनाल,
   {{0x29012b1a,0x2d8b15ec,0x5eb00033,0x569500c2}},	//   riha_, luce_, টারে, дает,
   {{0x3eb901c5,0x7afd01bf,0x2901c1b0,0x2d99000b}},	//   ndst_, _umst, siha_, otse_,
   {{0x83fc03ce,0xe81d000f,0x3eab002d,0x7cf00149}},	//   _među, _बुरा_, iect_, _färd,
   {{0x03a516e6,0x2d998b7b,0x942500ae,0x4425c15b}},	//   дико, itse_, ммле, _pyl_,
   {{0xe7840284,0xb5fdb7ae,0x00000000,0x00000000}},	//   _путо, _nešv, --, --,
   {{0x3eab0bcc,0xdced00e8,0x2d8bc1b1,0x2d9900bc}},	//   ject_, _apaļ, kuce_, ktse_,
   {{0x6ed102d5,0x4425c1b2,0x3ea000bd,0x7cf00324}},	//   धानु, _wyl_, _rbit_, _häre,
   {{0xddc4013f,0x2d8b1173,0x6009032d,0x2d990027}},	//   _neiš, duce_, жном_, dtse_,
   {{0x27350222,0x7cf00006,0x3eabc1b3,0x9eaa1111}},	//   gång_, _järe, fect_, овна_,
   {{0x441a00c1,0x141a00c1,0xa2e4004d,0x200b044c}},	//   _וועס, _וועב, _поєд, ăci_,
   {{0x2d8b03ce,0x7ceb0233,0x00000000,0x00000000}},	//   guce_, _süra, --, --,
   {{0xc17200a1,0x273e00d2,0xed590206,0x2a720350}},	//   _יחד_, _vůni_, íža_, wayb_,
   {{0x9d430cc6,0xe81d009f,0x2d997119,0x2ca1009c}},	//   терд, _बुला_, atse_, _dbhd_,
   {{0x91d1033a,0x2d8bc1b4,0x41d10096,0x3ea00783}},	//   _तपाई, buce_, _तपास, _ubit_,
   {{0x394619e0,0x79840239,0x3b070c59,0x00000000}},	// [f480] днаг, uriw, фето_, --,
   {{0x49990084,0xcc8a001c,0x7cf03341,0x613400ee}},	//   ятся_, _بنده_, _bäre, ràlg,
   {{0x7cf00222,0x09d60081,0x6287004b,0x00000000}},	//   _värd, _সেখা, ėjoj, --,
   {{0x7cf00222,0x6fb0099d,0xc6a307c8,0x2d5400bc}},	//   _däre, _जनसं, врши, _käe_,
   {{0x24580836,0xeabf009c,0x659300d1,0x00000000}},	//   паль_, _thùr_, نجور, --,
   {{0x2d5400bc,0x00000000,0x00000000,0x00000000}},	//   _mäe_, --, --, --,
   {{0x9696002d,0x3eab037a,0x7cf000bc,0x00000000}},	//   _ораш, yect_, _kärb, --,
   {{0x27e70856,0x7cebb97a,0x00000000,0x00000000}},	//   ønne_, _nürn, --, --,
   {{0x2d540673,0xd0860012,0x69c00094,0x00000000}},	//   _näe_, мыни, _šmej, --,
   {{0xf65100fb,0x16040971,0x2d8b1197,0x54360e5a}},	//   _لئے_, _शेयर_, vuce_, _قرار,
   {{0x645a7bfd,0xddc40138,0x273501df,0x3eab00ca}},	//   _ifti, _reiš, bånd_, tect_,
   {{0x2d8bc1b5,0x518600d3,0x2d9901c2,0x7cf01ee2}},	//   tuce_, _жука, ttse_, _närb,
   {{0x3eab59bb,0x7ae300ae,0x80da0033,0x80080018}},	//   rect_, _înti, যোগ্, ترکہ_,
   {{0x28d217ff,0x2d999f18,0x2d8b1760,0x27350429}},	//   साफि, rtse_, ruce_, måne_,
   {{0x28d202d5,0x7cf009b5,0x3eab00ca,0x27350537}},	//   सानि, _bärb, pect_, låne_,
   {{0x3f8c4788,0x2d8bc1b6,0x00000000,0x00000000}},	//   mudu_, puce_, --, --,
   {{0xb5fd000d,0x3f8c003d,0x442900fe,0xa3b51176}},	// [f490] _ješt, ludu_, ́a_, _चैन_,
   {{0xb5fd2f54,0xc8c903b3,0xa3ce030b,0x68ee009c}},	//   _mešt, राइट, शमा_, _clbd,
   {{0x3f8c02e6,0xb5fd0146,0x7cf0042c,0x613400ee}},	//   nudu_, _lešt, _färb, càle,
   {{0x645a041c,0x7cf07f36,0x26c91ba6,0x5ecd0033}},	//   _afti, _väre, ñao_, াসকে,
   {{0xb5fd02e6,0x7cf001bf,0x3f8c0d2a,0x5a440138}},	//   _nešt, _wäre, hudu_, _аэра,
   {{0x3f8c02e7,0x98c40084,0x6aadc1b7,0xb1130174}},	//   kudu_, _иссл, leaf, pụis,
   {{0x27350149,0xb5fd033b,0xaa7b003e,0x3f8c0d0a}},	//   tånd_, _rešu, _flýt, judu_,
   {{0x645a0682,0xdb0501bf,0x3f8cc1b8,0xb5fd4480}},	//   _efti, _erhö, dudu_, _bešt,
   {{0x31790068,0xb5fd0357,0x6d5f00bd,0x95570452}},	//   ész_, _pešu, _ntqa, _آخرا,
   {{0xddc416ad,0x1f651057,0xb5fd0a7f,0x28d204f8}},	//   _afiş, нком, _dešt, सायि,
   {{0x3f8cc1b9,0x2c1f0096,0xd4980077,0x5f062bcf}},	//   gudu_, _मुलं_, _юрт_, езна,
   {{0xb5fd1912,0xa3bc1757,0x3275006e,0x929d007f}},	//   _fešt, इटर_, _װײַל_, biła,
   {{0xc332004f,0xfc460146,0x765badc1,0x6aad3f6d}},	//   _עוד_, číme_, _mfuy, deaf,
   {{0x6ee608a8,0x3f8cc1ba,0x613405fe,0x8b660103}},	//   _móbi, budu_, tàle, فارم,
   {{0xfaa6288d,0x765b0172,0x6d5f039f,0x3f8c2ddc}},	//   наво, _ofuy, _etqa, cudu_,
   {{0xb5e80139,0x6aad0a07,0x645816aa,0x00000000}},	//   _bẹ́r, geaf, zcvi, --,
   {{0x27180631,0xbcfb2d28,0x00000000,0x00000000}},	// [f4a0] nčne_, mpén, --, --,
   {{0xa2a10789,0x3c663006,0x7aef037a,0xee3701b3}},	//   _कॉस्, _яког, _elct, _яны_,
   {{0x06860231,0xc6a61e9e,0xb895008f,0x61f700a7}},	//   еген, ерли, ъртъ, _əxla,
   {{0x6b7b00a1,0xb5e80032,0x6aadbf3b,0x00000000}},	//   _צרכנ, _fẹ́r, ceaf, --,
   {{0x86232c37,0x00000000,0x00000000,0x00000000}},	//   льше, --, --, --,
   {{0xb5fd0181,0xb4ea269c,0x656200d8,0x27180141}},	//   _rešt, मसे_, rpoh, dčne_,
   {{0xfd690129,0xa3d408d8,0xb5fd033b,0x27180206}},	//   _bipụ, тойч, _sešt, ečne_,
   {{0xb5fd366a,0x85580281,0x394a01ec,0x3f8c0095}},	//   _pešt, _قیصر_, _hibs_, vudu_,
   {{0x80c90033,0x6f0629e4,0x00000000,0x00000000}},	//   াউন্, dikc, --, --,
   {{0x67222d3c,0xb5fd29f9,0x69fb0327,0x5577006e}},	//   looj, _vešt, פליק, _נעבן_,
   {{0xa0a301b6,0xe1ef00cd,0x612f181f,0x7ceb11bc}},	//   ушыл, لسی_, møll, _dürl,
   {{0x3f8cc1bb,0x929d007f,0x00000000,0x00000000}},	//   rudu_, piła, --, --,
   {{0xc0e60747,0x3f8c005f,0xb95b0032,0x00000000}},	//   _подк, sudu_, _arìn, --,
   {{0x672201fa,0x63a800dc,0xfd690134,0x3f8c0234}},	//   hooj, _kpdn, _zipụ, pudu_,
   {{0x80cd009f,0x672b056e,0x6e2009a1,0x00000000}},	//   तारे, ylgj, ümbr, --,
   {{0xe7fa00aa,0x7cf0042c,0x27470065,0x00000000}},	//   _एइजा_, _pärc, _mìnì_, --,
   {{0xfeb800bf,0xdcf60031,0xb520023a,0x6aad372f}},	// [f4b0] _سايت_, _zvyč, मकाय_, reaf,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0702e6,0x656001b9,0xcc5600ca,0xb06500bc}},	//   mijs, _atmh, _בבתי_, lhää,
   {{0x7d07c1bc,0x39b2022b,0x7bc502a1,0xbebb0216}},	//   lijs, _fņs_, _irhu, alëv,
   {{0x7cf002c3,0xe7300076,0x00000000,0x00000000}},	//   _hära, حصل_, --, --,
   {{0x7d07084f,0x2a690096,0xf7730d74,0x64a51502}},	//   nijs, lbab_, _مار_, така,
   {{0x9474001c,0x29030216,0x2b4b0350,0xc6a726d0}},	//   ادها, _imja_, _kicc_, _праи,
   {{0x635101d3,0xb88300d4,0x7d07c1bd,0xb5fd00c6}},	//   _jāni, stíč, hijs, _dešr,
   {{0x7cf00222,0x26cd034f,0x7ae300ae,0x9f4c00d4}},	//   _lära, _ineo_, _întu, vzdá_,
   {{0xa2a10f42,0x27181f54,0x225802c6,0x7d070141}},	//   _कॉर्, rčne_, ěrka_, jijs,
   {{0x12e700d6,0x7bc5023e,0x53a40037,0x272700aa}},	//   _підг, _nrhu, _مملك, sõnu_,
   {{0x752310bd,0x2cba0f5a,0x335800d3,0x00000000}},	//   lonz, _sapd_, _чацэ_, --,
   {{0xdce402e6,0x7ceb01e8,0x7d072e48,0x3ebb0090}},	//   _sviđ, _türl, fijs, _daqt_,
   {{0xda1c0336,0xbcfb0669,0x2b4bc1be,0x7cf002c3}},	//   _भुगत_, spén, _aicc_, _bära,
   {{0xab2a0f5e,0xeb97380e,0x5a960109,0xfc030077}},	//   дова_, кир_, краф, апро,
   {{0x6a830231,0x61340428,0xb95b009c,0x7a38003e}},	//   илса, màla, _crìo, _nútí,
   {{0xee3a0465,0x75235751,0x7d070e94,0x6f046de3}},	// [f4c0] _юни_, konz, bijs, _imic,
   {{0x7d0725ed,0xb95b00ef,0xa2a15c52,0x75230a4b}},	//   cijs, _trìn, क्त्, jonz,
   {{0xdce403d6,0x7523028d,0x2a690d2a,0xeabf0032}},	//   _uviđ, donz, bbab_, _ikùn_,
   {{0x6d4b2db1,0x224f0085,0x60cd03e3,0xf1d10861}},	//   _égar, _nggk_, _ɗama, तमान,
   {{0x80b202e8,0x8e570341,0x6b830212,0x6f04007e}},	//   _असले, דינג_, _ångr, _mmic,
   {{0x26cd068d,0x752326e3,0x2b40c1bf,0x69c60090}},	//   _eneo_, gonz, lmic_, _irke,
   {{0x6f0400e5,0x2ef2084e,0xdb05014b,0xbebb084e}},	//   _omic, _olyf_, _sphé, doën,
   {{0x66e3162b,0x78bcc1c0,0xdb0f0103,0xc1b80fec}},	//   _коса, _harv, ődöt, елих_,
   {{0x66e3251c,0x09e40081,0x78bc1264,0x7ceb008b}},	//   _тота, _নেতা, _karv, _sürm,
   {{0x6f0464d5,0x30a3004d,0x75230027,0x69c60840}},	//   _amic, арюв, conz, _mrke,
   {{0x7d0700e7,0x6ee60328,0x0fd00033,0x3af50120}},	//   vijs, _lóbu, ান্ধ, _håpe_,
   {{0x78bcc1c1,0x7d0701c0,0x6f0400c4,0x442c0350}},	//   _larv, wijs, _cmic, _iyd_,
   {{0x442c02e0,0xf0b700bf,0x7d07108b,0x7cf0c10d}},	//   _hyd_, رایش_, tijs, _sära,
   {{0x7cf00006,0x78bcc1c2,0x3ebb03e5,0x6f04c1c3}},	//   _pära, _narv, _waqt_, _emic,
   {{0xa2b809b0,0x2b4b00dc,0x013700ca,0xb95b009c}},	//   ्यप्, _picc_, _שרות_, _prìo,
   {{0x7b64160b,0x7d071cb4,0x7cf000aa,0xeabf0065}},	//   ртре, sijs, _vära, _ekùn_,
   {{0x78bc99d4,0x442c038c,0x236908c5,0xf9900e00}},	// [f4d0] _barv, _lyd_, ćaji_, قبل_,
   {{0x7bc502ef,0x7cf00212,0x6e2d630a,0x78bc22d3}},	//   _trhu, _härn, _iyab, _carv,
   {{0x69c6c1c4,0x7cf0a505,0x1dcb009f,0xf7701108}},	//   _erke, _kärn, ामकत, قان_,
   {{0x7af6025b,0x7cf00149,0x95992cdd,0x98b901d3}},	//   chyt, _järn, етку_, _pusē_,
   {{0x78bc3229,0xa2b80be4,0x690b003d,0xbebb023b}},	//   _farv, ्यन्, rżeb, llës,
   {{0x7aedc1c5,0x442c02ad,0xb4bd0ed3,0x62823cbb}},	//   lkat, _byd_, इये_, _adoo,
   {{0x67d41ad5,0x7523c1c6,0x442c0150,0x21270063}},	//   _кору, ronz, _cyd_, _rknh_,
   {{0x7aedc1c7,0x69c60160,0x442c60f5,0x248908bb}},	//   nkat, _yrke, _dyd_, şam_,
   {{0x7aed01b3,0xe0d10260,0x6e2d8890,0x628206b0}},	//   ikat, مزد_, _nyab, _ddoo,
   {{0x6ff301d4,0x2cb100b6,0x6282010a,0x442c00f0}},	//   ləcə, jezd_, _edoo, _fyd_,
   {{0x6e360067,0x7aedc1c8,0xdee6311c,0x6e2dc1c9}},	//   _szyb, kkat, гони, _ayab,
   {{0x6e2d1a80,0x630509e5,0x672902a1,0x6ff300a7}},	//   _byab, _حوصل, _jkej, nəcə,
   {{0x27180087,0x6e2d0193,0x7aed141c,0x673b0350}},	//   nčna_, _cyab, dkat, _mhuj,
   {{0x6e2dc1ca,0x7aed083e,0x00000000,0x00000000}},	//   _dyab, ekat, --, --,
   {{0x6e2d0502,0x013600ca,0x61e9c1cb,0x2d8b62b1}},	//   _eyab, _גרסת_, lyel, arce_,
   {{0x7cf00222,0x7aed0f4f,0x78bc3b2a,0x672900ac}},	//   _gärn, gkat, _sarv, _nkej,
   {{0x61e93d3a,0x4a7508a1,0x2b4015c7,0xddcf00ae}},	// [f4e0] nyel, рыст, rmic_, racţ,
   {{0x4a43088f,0x7aed0172,0xb5fd0031,0x673b0079}},	//   снув, akat, _rešp, _ahuj,
   {{0x7e760088,0x7af638df,0x78bc1ee2,0x6abd0022}},	//   _keyp, phyt, _varv, _fasf,
   {{0xe61a3b9d,0x6d566976,0x6676097d,0x7aed0348}},	//   нде_, _kuya, ادار, ckat,
   {{0x78bc069d,0x442c5e11,0x6d560d2a,0x673b0113}},	//   _tarv, _syd_, _juya, _dhuj,
   {{0x7ae30012,0x2fc72048,0x6d560366,0x69c4c1cc}},	//   _într, _orng_, _muya, mvie,
   {{0x746900d6,0x7cf00212,0x6d56be8b,0xe5050076}},	//   трів_, _läro, _luya, جبني,
   {{0x6d560350,0x41b41f11,0x69c48327,0x81cd0033}},	//   _ouya, لمبر, ovie, রহন_,
   {{0x69c4c1cd,0x61e90068,0xdce40067,0x442cc1ce}},	//   nvie, gyel, _zwią, _wyd_,
   {{0x442c0665,0x7aed0a00,0x2fc70167,0x2d8b0106}},	//   _tyd_, zkat, _brng_, vrce_,
   {{0xd9d102e8,0x7cf00006,0x7aed00dd,0x6e2d0332}},	//   _सप्ट, _pärn, ykat, _syab,
   {{0x7ceb08f5,0x69c401b3,0x63ba00a5,0x6d566ccb}},	//   _türk, kvie, _istn, _buya,
   {{0x2d8bc1cf,0x6d5600e1,0x7cf00486,0x6abd57d7}},	//   urce_, _cuya, _värn, _rasf,
   {{0x69c4c1d0,0x6d56c1d1,0xe81d034c,0xeb1d0469}},	//   dvie, _duya, _बुझा_, भक्त_,
   {{0x7aedc1d2,0x66f4000f,0x6abdc1d3,0x6ff30092}},	//   tkat, _आतंक_, _pasf, yəcə,
   {{0x7cf00149,0x7cebc1d4,0x6d56815d,0xddcd044c}},	//   _härl, _müri, _fuya, _ceaţ,
   {{0x6d56c1d5,0x7aedc1d6,0x7cf00149,0x3ea906a8}},	// [f4f0] _guya, rkat, _kärl, _ibat_,
   {{0x7aedc1d7,0x6729c1d8,0x2718033b,0x673b969c}},	//   skat, _skej, včna_, _shuj,
   {{0xb8dd0ccb,0x7c2902e2,0x61fb75aa,0xcc7600ca}},	//   _आस_, ßerd, zzul, _דעתה_,
   {{0xf770054f,0xb8ec05d4,0xf9900018,0x2918037a}},	//   سام_, _शो_, تبہ_, _ejra_,
   {{0x6ff301d4,0x69c4c1d9,0x2d80014b,0x1efc0142}},	//   rəcə, cvie, _xvie_, עלדע,
   {{0x2eb2000d,0xbf021fbb,0x61fb00a7,0xe7950504}},	//   _जस्त, _लग्न_, vzul, _پاسک,
   {{0x6ed802e8,0x3ea906dd,0x6299020b,0x672902a1}},	//   यामु, _obat_, _pcwo, _tkej,
   {{0x61e9022b,0xa2e50636,0x61fb20a4,0xd1850036}},	//   tyel, роид, tzul, алий,
   {{0x61fb7a54,0x69c00072,0x63ba0324,0x00000000}},	//   uzul, _ámet, _estn, --,
   {{0x205500ae,0x3ea92f7c,0x945501c2,0x61fb374f}},	//   штир, _abat_, _zān, rzul,
   {{0x3dc913b5,0x69c437e6,0x6d563cf4,0x798d0150}},	//   _araw_, zvie, _suya, hraw,
   {{0xed5a136c,0xfe46249c,0x798dc1da,0x6d563317}},	//   ком_, инно, kraw, _puya,
   {{0x236900e9,0x7ceb0364,0x21673cf9,0x69c400fe}},	//   ćaju_, _züri, _стег, xvie,
   {{0x6ee6002b,0x317f026a,0x272e003e,0x3dc988f5}},	//   _cóbr, msuz_, rýni_, _draw_,
   {{0x8c462da1,0x317f07e7,0x6d560044,0x273c6c6c}},	//   реве, lsuz_, _wuya, líne_,
   {{0x69c40029,0xf1a91085,0x225fc1db,0x6d56c1dc}},	//   tvie, _कहान, ncuk_, _tuya,
   {{0x09063c97,0x317f07aa,0xa2b80469,0x798d057a}},	// [f500] апан, nsuz_, ्यत्, graw,
   {{0xe8f7197f,0xa2cc009d,0xdd7b006e,0x7d7b00ca}},	//   алу_, _दोन्, _שטיל, _שניו,
   {{0xd90d00d0,0x69c4c1dd,0x798d0036,0xf1af09a1}},	//   ریف_, svie, araw, _झनझन,
   {{0x46a61a5c,0x798d4500,0x7c290364,0xd7ef0037}},	//   радв, braw, ßere, بكم_,
   {{0x28762787,0x7cf02169,0xe3b8047e,0x00000000}},	//   _выбр, _lärm, _ayıp_, --,
   {{0x05140081,0xa3b2030b,0xed591515,0x7ceb0e5b}},	//   িত্র_, टबल_, íži_, _püri,
   {{0x7cf00222,0x2ca7026a,0x590700ae,0x25ad0062}},	//   _närm, _önde_, _терм_, _epel_,
   {{0x387812ab,0xf1a608a1,0x16040096,0x69c00072}},	//   _herr_, арон, _शेअर_, _ámes,
   {{0x7cf0c10d,0xb5a90037,0xa6340103,0x59c9097c}},	//   _pärl, _مالك_, _اکاؤ, रियर,
   {{0x5f940a7c,0x3878611d,0x4fc60da5,0x7ceb7aa0}},	//   биот, _jerr_, асма, _türi,
   {{0x7cf0070a,0x63ba8954,0x387800dd,0x271802dd}},	//   _värl, _ustn, _merr_, nčno_,
   {{0x7cf00149,0xd36f001c,0x38780063,0x6d582f54}},	//   _därm, _آهن_, _lerr_, _čvar,
   {{0xae0102e8,0x3dc902a1,0x00000000,0x00000000}},	//   _लेखन_, _qraw_, --, --,
   {{0x3e750023,0x7cf00486,0x61430284,0x00000000}},	//   ất_, _härj, _деча, --,
   {{0xc1b60640,0x81cd0081,0x61b6167f,0x7cf012f1}},	//   _अनुग, রহণ_, _अनुष, _kärj,
   {{0x7cf0069d,0x3ea918c4,0x798d852a,0x8e850037}},	//   _järj, _ubat_, traw, _الظه,
   {{0x4c952260,0x7e7d0d2f,0x387803a8,0x13af0033}},	// [f510] _липс, masp, _berr_, কিয়,
   {{0xd8791629,0x798d03e3,0x7e7dc1de,0x854200c6}},	//   امات_, rraw, lasp, žėja,
   {{0x25ad16f3,0xdead0022,0xe28b00d2,0x00000000}},	//   _spel_, _shaƙ, íčků_, --,
   {{0x798d0067,0x7e7d6f7b,0xa3bc023a,0x00000000}},	//   praw, nasp, ेटन_, --,
   {{0x929d0034,0xc98412c0,0x38781fd2,0x6ed8178c}},	//   siłk, _мури, _ferr_, यातु,
   {{0x43850037,0x7cf901b9,0x7e7dc1df,0x3f8301f9}},	//   ملتق, _fìre, hasp, ájuk_,
   {{0x31660085,0x5eb00033,0x9f64013c,0x13680284}},	//   _atoz_, য়াতে, ətçi_, ашњи_,
   {{0x56944f31,0x7e7dc1e0,0x387800e7,0x98b90138}},	//   _маст, jasp, _zerr_, _pusė_,
   {{0x224b0149,0xc692006e,0xd49b0012,0x38780063}},	//   äck_, _מאן_, _аре_, _yerr_,
   {{0x395902dc,0xa3d706ed,0x317f03e0,0x9f4e00b6}},	//   _muss_, ामद_, rsuz_, ěním_,
   {{0x7cf00212,0xe435071c,0x6b950357,0xd2510781}},	//   _färj, _افاد, juzg, _فنا_,
   {{0x7cf00222,0x1efa00e3,0x7e7d0bb6,0x613d0257}},	//   _värm, اعدة_, gasp, dèle,
   {{0xd256028c,0x7cf001bf,0xdce40034,0x0165231c}},	//   _השנה_, _wärm, _zwię, _укло,
   {{0xed570613,0x2d5d0065,0x1d190686,0x463a006e}},	//   сор_, _dìe_, аюсь_, טערע,
   {{0x6f95054f,0x7f850080,0xa3d711c7,0x7cf0679d}},	//   _العض, _البن, ामि_, _härk,
   {{0x3959c1e1,0x7cf000c2,0x2718033b,0x7e7dc1e2}},	//   _buss_, _kärk, včno_, casp,
   {{0x7cf00084,0x9f460103,0x7e640032,0x9c8305db}},	// [f520] _järk, szló_, _ifip, _ščem,
   {{0xa3d70f66,0x7cf062bf,0x2d825be4,0x23b7009d}},	//   ामा_, _märk, mske_, _आनंद,
   {{0x27ff03e3,0x2a7900c4,0x7c3b0022,0x387804c8}},	//   _ƙuna_, _fesb_, ƙura, _verr_,
   {{0xf7433760,0xf72900d6,0xe9a60870,0x39591399}},	//   пехо, ацій_, _ламп, _fuss_,
   {{0x941201d4,0xd90d00fb,0xa2b8167f,0x38780052}},	//   əyə_, ریہ_, ्यस्, _terr_,
   {{0x26c0434e,0x6ab6003e,0x2b5a063d,0x2d8236d1}},	//   žio_, leyf, _kupc_, iske_,
   {{0x7cf001a5,0x7e64039f,0x00000000,0x00000000}},	//   _pärj, _ofip, --, --,
   {{0x7ae65b50,0x2d82c1e3,0x7d0ec1e4,0xfbd300d7}},	//   _jokt, kske_, hibs, לתו_,
   {{0x7e7d6580,0x7ceba719,0x63b8023e,0xe4521ac9}},	//   vasp, _kürt, swvn, _فضا_,
   {{0x2d8202e6,0x7e7d0479,0x7e640032,0x3ae700aa}},	//   dske_, wasp, _afip, _lõpp_,
   {{0x33f6120c,0xdeb51736,0xe4d703ed,0xd8db00c1}},	//   _учас, обны, _دولت_, אקיר,
   {{0x7ae66c5b,0x80d61a09,0xf83700ca,0x613d020d}},	//   _nokt, बाहे, מנית_, vèle,
   {{0xa2d5017f,0x290a0a4b,0x51620032,0x7cf00dd8}},	//   भार्, _omba_, _fọọm, _kärh,
   {{0x51620129,0x2a79057c,0xc19b00ca,0x7e64039f}},	//   _gọọm, _sesb_, _עשוי, _efip,
   {{0xe7e300c7,0x3cfa0251,0x7ae6059a,0x7e7dc1e5}},	//   _মধ্য, _उतरे_, _bokt, pasp,
   {{0x290ac1e6,0x39591e95,0x2d822ad5,0x7ae61afd}},	//   _amba_, _puss_, bske_, _cokt,
   {{0x6f0f028d,0x2d8201f9,0x00000000,0x00000000}},	// [f530] micc, cske_, --, --,
   {{0x7cf00222,0x6f0fc1e7,0x6b4f0139,0x00000000}},	//   _närh, licc, _bògì, --,
   {{0xaac44694,0xc5e60081,0x96eb06c4,0x4ac400a8}},	//   _लोकक, _খেলা_, льда_, _लोकव,
   {{0x6f0f0036,0xfe7fc1e8,0x41a9007a,0x3861225b}},	//   nicc, naï_, _कहलस, schr_,
   {{0x1a9a00c1,0x7ceb5c07,0xb4c40285,0x85a70284}},	//   _דירע, _fürt, एयू_, сјед,
   {{0x92d500c7,0x80b702d5,0x6f0f0036,0x9a2900fe}},	//   _হতে_, _असें, hicc, _gươm_,
   {{0x7ae601e8,0x7cf06a47,0x00000000,0x00000000}},	//   _yokt, _särk, --, --,
   {{0x2d823229,0x7ceb0345,0x68e70031,0x23a10034}},	//   yske_, _kürs, _hojd, rój_,
   {{0x44290067,0x6f0f3bf0,0x0edd000d,0xfd620065}},	//   ła_, dicc, यानड, _dawọ,
   {{0x672b01e5,0x9f85470d,0x1fe40081,0x273c0031}},	//   logj, огод, _ফেইস, mína_,
   {{0xef1a2c6b,0x273cab6f,0x6f0f009e,0x68e70fee}},	//   имо_, lína_, ficc, _mojd,
   {{0x2d823371,0x7cf00084,0x2f5408d1,0x3f8b1523}},	//   tske_, _tärk, ятьс, čcu_,
   {{0xa2b80251,0xed5a49cc,0x2d8486c6,0x7cf00212}},	//   ्यर्, рог_, éme_, _häri,
   {{0xa0692363,0x2d82c1e9,0x80a70081,0xdbc7003e}},	//   _така_, rske_, _কোর্, töðv,
   {{0xf0b8110a,0x6f0f028d,0xc6230033,0x60c301b9}},	//   _دانش_, bicc, বেচা_, _ianm,
   {{0x2d820335,0xed5a0303,0x6f0f3c59,0x629b9dea}},	//   pske_, _кои_, cicc, nguo,
   {{0xe9da5fdd,0x60c3a3c2,0xdb0502b6,0x3ea0022b}},	// [f540] шка_, _kanm, _ophæ, _icit_,
   {{0x60c380a8,0x92d50033,0x00000000,0x00000000}},	//   _janm, _হতো_, --, --,
   {{0x60c30c56,0x7cf026af,0x656900dd,0x25bf0fa0}},	//   _manm, _näri, _ateh, _asul_,
   {{0x60c30c56,0x27e70149,0x7ceb1fbe,0x4c3b00a1}},	//   _lanm, änna_, _fürs, _כתיב,
   {{0xf5b600b1,0x60c30324,0x16041f88,0x7ceb0233}},	//   تصاد, _oanm, _शेखर_, _gürs,
   {{0xf36603fc,0x7ceb0367,0x290a0239,0xdce414f3}},	//   отин, _hürr, _umba_, _otič,
   {{0xbcfb025a,0x439405b6,0x00000000,0x00000000}},	//   mpét, чайс, --, --,
   {{0x60c3043e,0x6569003d,0x7cf00149,0x613400ee}},	//   _aanm, _fteh, _däri, màli,
   {{0xe5a6450e,0x60c3805d,0x2cb824e7,0x79840150}},	//   _физи, _banm, kerd_, nsiw,
   {{0x26c4c1ea,0x60c300f0,0x7cf007ee,0x3ea00231}},	//   _hamo_, _canm, _färi, _acit_,
   {{0x4438c1eb,0x60c3c1ec,0x26c48a5f,0xb4b60034}},	//   _ár_, _danm, _kamo_, ज़ी_,
   {{0x741300bf,0x26c6c1ed,0x2cb8029a,0x00000000}},	//   _توما, ndoo_, eerd_, --,
   {{0x60c314b1,0xdced0039,0x6280c1ee,0x25a68ffe}},	//   _fanm, _svađ, mamo, ntol_,
   {{0x6f0f9143,0x2cb856a2,0x80a1009f,0x6367020e}},	//   sicc, gerd_, _खाये, _fınd,
   {{0x26110251,0x6f0f1bc1,0x945501c2,0x00000000}},	//   _देनी_, picc, _sāk, --,
   {{0x6280c1ef,0xda0c0067,0x60c30c56,0x26c4c1f0}},	//   namo, _सेहत_, _zanm, _namo_,
   {{0x68e7c1f1,0x3eb9726c,0x798412f5,0x60c3c1f2}},	// [f550] _pojd, mest_, gsiw, _yanm,
   {{0x3eb93245,0x8b08030b,0x2d99c1f3,0x613400b3}},	//   lest_, _pořá, muse_, fàli,
   {{0x656902dc,0x6280c1f4,0x2d99007a,0xb06500c2}},	//   _steh, kamo, luse_, lkää,
   {{0x3eb94ada,0x6280c1f5,0x2d9903be,0x95d900c2}},	//   nest_, jamo, ouse_, йдет_,
   {{0x443e00fb,0xd5bb3fea,0xb0650084,0xd46922ee}},	//   _azt_, рсе_, nkää, биле_,
   {{0x9f443e0a,0x7cf00006,0xdb1e0c45,0x273c0e4b}},	//   ájú_, _päri, _aspè, rína_,
   {{0x60c3c1f6,0x3eb9007a,0x2d99c1f7,0x26c40036}},	//   _ranm, kest_, huse_, _famo_,
   {{0x3eb90292,0x8c1c0105,0x66b40084,0x7cf02a3c}},	//   jest_, יווי, _обсу, _väri,
   {{0x443e0068,0x25bf0706,0x60c3019c,0xdce41027}},	//   _ezt_, _usul_, _panm, _stič,
   {{0x6f0dc1f8,0x2d99c1f9,0xdb1e757d,0x26c40044}},	//   _amac, duse_, _espè, _zamo_,
   {{0x2cb8c1fa,0x62800fb6,0x60c3673e,0x2d993f7f}},	//   verd_, bamo, _vanm, euse_,
   {{0x7cf01d2d,0x6280065b,0x69cf0042,0x2ca10441}},	//   _järv, camo, _orce, _achd_,
   {{0x60c3c1fb,0x2d99007a,0x0d835566,0x2cb824e7}},	//   _tanm, guse_, нлян, terd_,
   {{0x6f0d070e,0xb6061054,0xa3cf0f35,0x68020139}},	//   _emac, _ukáž, शिप_, _jíjé,
   {{0xdce40c27,0xb5fd12e8,0x1d073549,0x26c6041c}},	//   _utič, _ofšo, чери_, ydoo_,
   {{0x7cf01faa,0x612f00f2,0x89662a64,0x25a60206}},	//   _närv, pøls, зкаж, ytol_,
   {{0xc33200a1,0xe8fa1a77,0x26c49bc8,0x2cb8000b}},	// [f560] תון_, бла_, _ramo_, perd_,
   {{0x499902fd,0x79840150,0x8c46c1fc,0x613400ee}},	//   ются_, rsiw, _непе, tàli,
   {{0x6280c1fd,0x69cf0218,0xbcfb2e00,0x2718033b}},	//   yamo, _erce, rpét, lčni_,
   {{0x628098b1,0xe73a0084,0x61340428,0x660201e9}},	//   xamo, щее_, ràli, tzok,
   {{0xbcfb0257,0x27180087,0x62803916,0x443e0034}},	//   mpér, nčni_, vamo, _szt_,
   {{0x7ae401ac,0x3f87007e,0x26c40a4b,0x3f8512b8}},	//   ljit, _ovnu_, _wamo_, kslu_,
   {{0x62800d9f,0x26c402e6,0x66020068,0x25a6c1fe}},	//   tamo, _tamo_, szok, stol_,
   {{0x7ae4c1ff,0x7af6013f,0x25a60234,0x6cf800b6}},	//   njit, nkyt, ptol_, ँसँग_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f0d2ab9,0x2d99007a,0x3eb900ca,0x7cf000bc}},	//   _smac, vuse_, west_, _käru,
   {{0x3eb9c200,0x6280c201,0xdb1e6320,0x6f1d0890}},	//   test_, pamo, _espé, érco,
   {{0x2d990006,0x7f44c202,0xb06500c2,0xbebb0052}},	//   tuse_, _chiq, tkää, llëz,
   {{0x3eb901cc,0x7ae403d6,0x7f44041c,0x00000000}},	//   rest_, djit, _dhiq, --,
   {{0x3eb905a7,0x2d99260d,0x91bb00ca,0x7c29042c}},	//   sest_, ruse_, _למדי, ßero,
   {{0x3eb90068,0x6e2400c9,0x2d991bc7,0x8fa30831}},	//   pest_, _exib, suse_, _заје,
   {{0x7ae400dd,0x2d9900d3,0x6f0d2533,0x803700ca}},	//   gjit, puse_, _umac, _מנוע_,
   {{0xa2a1097c,0x645a008c,0xb95500e5,0xfc300103}},	// [f570] क्ट्, _ogti, дващ, نحہ_,
   {{0x98b80138,0x8e380076,0x2ca101f7,0x00000000}},	//   _mirė_, _عسير_, _uchd_, --,
   {{0x6f1dc203,0x7e7f0052,0x6d450372,0xaa590a0e}},	//   onsc, _keqp, _ihha, _мину_,
   {{0x6f1daf1b,0x645a77fd,0x6d5f1ffb,0x69cf00e7}},	//   nnsc, _agti, _kuqa, _trce,
   {{0x6f1d1094,0x7cf01ad3,0xd138013f,0x49930260}},	//   insc, _värv, klą_, _سیار,
   {{0x6d5f311b,0x3f85c204,0xe5700037,0x7afd4abf}},	//   _muqa, yslu_, اطن_, _hlst,
   {{0x6d577eeb,0x6d5f432e,0x68e3003e,0xa2e5007b}},	//   _mixa, _luqa, öndu, дойд,
   {{0xa2a20980,0x6d57be6b,0x7cf00364,0xe29900e5}},	//   _गाण्, _lixa, _härt, цаи_,
   {{0xb14517b9,0x765bc205,0x65942a5a,0x69cd007b}},	//   мнил, _iguy, _пату, nvae,
   {{0x248c0124,0x2718033b,0x7f44c206,0x6f1d18ef}},	//   _gddm_, včni_, _shiq, ensc,
   {{0x7cf0007a,0x26110034,0x2d89024a,0x3afc00d2}},	//   _märt, _देती_, _avae_, _lípa_,
   {{0x7c290b88,0x6441c207,0x6d45c208,0x3f850088}},	//   ğerl, _izli, _ahha, rslu_,
   {{0x6d45009c,0x6d570062,0x6d5f008c,0x28e0055c}},	//   _bhha, _bixa, _cuqa, नामि,
   {{0x3e7c00ef,0x7afd8cec,0xf1bc099d,0x6f1d54a5}},	//   ật_, _alst, ्टरन, ansc,
   {{0x7f4400dc,0xa3e0058f,0x765b0361,0x6aadc209}},	//   _thiq, दमय_, _oguy, ffaf,
   {{0x765bc20a,0x6d5f9e0e,0x6d570428,0x291303a4}},	//   _nguy, _fuqa, _eixa, eixa_,
   {{0x7af61736,0x44250231,0x6d880103,0x613d00b3}},	// [f580] rkyt, _lxl_, _عمدہ_, nèlo,
   {{0x7af6b849,0x64412e78,0x7afdc20b,0x6fb10789}},	//   skyt, _ozli, _elst, _जहां,
   {{0x6ea53212,0x59ba007a,0x657b1c64,0x81e30033}},	//   _कामु, _उनकर, _awuh, ননি_,
   {{0xb95b0139,0x28ce00c3,0x00000000,0x00000000}},	//   _isìn, _होरि, --, --,
   {{0xd5b00d74,0x6b9cc20c,0x64416987,0xe4e6004d}},	//   افت_, lurg, _azli, дійн,
   {{0x29130072,0x7cf00364,0x81e30033,0x765b48d3}},	//   cixa_, _gärt, ননা_, _eguy,
   {{0x2bd10b94,0x44253f17,0xec36006e,0x18a30582}},	//   हिया, _cxl_, ואַר_, _шарм,
   {{0x7cf02a4c,0x20057694,0xa2d500c3,0xfbc00033}},	//   _kärs, dzli_, भाग्, _উপাত,
   {{0x7cf000bc,0xd1b00281,0x69c4136b,0x6b9c67f6}},	//   _järs, ایتک, रिटी, hurg,
   {{0x6b9c01e9,0x7cf002c3,0x6d5f311b,0x00000000}},	//   kurg, _märs, _ruqa, --,
   {{0x6560c20d,0xd01015ae,0x00000000,0x00000000}},	//   _humh, الج_, --, --,
   {{0x65602822,0x799676b2,0x6b9c003e,0x6f1d0364}},	//   _kumh, kryw, durg, unsc,
   {{0x65606206,0xb95b0139,0x7cf002c3,0x6f1d0364}},	//   _jumh, _asìn, _närs, rnsc,
   {{0xa2b802c6,0x7996632e,0xc1bc0285,0x65600076}},	//   ्यक्, dryw, ्टीग, _mumh,
   {{0x7c344442,0xd00f0ed4,0x6b9c812d,0x44250c20}},	//   верх, _рф_, gurg, _xxl_,
   {{0xa3cf2ebd,0xaf080037,0xcf2702fc,0x7cf002c3}},	//   शित_, _يقوم_, _ترتي, _bärs,
   {{0x6aad006d,0x6560002b,0x79960034,0x2d890350}},	// [f590] rfaf, _numh, gryw, _uvae_,
   {{0x7b67413c,0xf1c800de,0x3eb20034,0x657b0027}},	//   _отме, _mỡ_, _zbyt_, _rwuh,
   {{0x6560009c,0xf1c800de,0x6b9c020a,0x29131d55}},	//   _aumh, _lỡ_, curg, rixa_,
   {{0x7bc5c20e,0x7cf00149,0x7afd21ad,0x7d1545c2}},	//   _ishu, _färs, _ulst, lizs,
   {{0x65609816,0xe57801b3,0xf1c800fe,0x6441007f}},	//   _cumh, дзі_, _nỡ_, _szli,
   {{0xa3c3030b,0x7d15c20f,0x7cf032ee,0x395800ee}},	//   _září_, nizs, _härr, _girs_,
   {{0xe3b11b67,0x291107aa,0x7cf005f8,0x6ea50096}},	//   ارت_, _imza_, _kärr, _काढु,
   {{0x7bc51a87,0xe0bb0033,0x4425c210,0x2b59009c}},	//   _mshu, _অচেন, _vxl_, _jisc_,
   {{0x9f52030b,0xf1c800de,0x7d1500e7,0x657b050f}},	//   ází_, _cỡ_, kizs, _uwuh,
   {{0xa3cf02d5,0xf4850018,0xf1c800fe,0x60092c59}},	//   शिद_, _سائی, _dỡ_, зном_,
   {{0x799600a5,0x644101d3,0x3ea63120,0x7bc502a4}},	//   zryw, _uzli, нинг, _nshu,
   {{0x7b03007a,0x42300174,0x59df50a4,0x00000000}},	//   _jõud, ịbọk, नमार, --,
   {{0xf1c800de,0x7bc5c211,0x2005007f,0x00000000}},	//   _gỡ_, _ashu, szli_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cf00222,0x26110f78,0x1c39004d,0xec1605bc}},	//   _särs, _देसी_, дять_, رورد,
   {{0x7b03007a,0x395802a1,0x7cf068e2,0x2911078e}},	//   _nõud, _sirs_, _pärs, _amza_,
   {{0x39580aa0,0x2b59794c,0x7bc54944,0x6b9c20c7}},	// [f5a0] _pirs_, _disc_, _eshu, surg,
   {{0x7cf006fb,0x6b9c4bb6,0x02bd000c,0xe4f43212}},	//   _värs, purg, ्युन, _अवधि_,
   {{0xb9080251,0x7cf00704,0x395817b1,0x2b593cb7}},	//   _मच_, _färr, _virs_, _fisc_,
   {{0x261104a9,0xb5aa0080,0x3cde00aa,0x6d4b3e56}},	//   _देही_, كاتك_, खावे_, _ègar,
   {{0x3958c212,0xfa360103,0x6d4e27aa,0x28e00bba}},	//   _tirs_, _سرحد, omba, नादि,
   {{0x69c6c213,0x636703a3,0xf1c800de,0x98a400c6}},	//   _iske, _sına, _rỡ_, _ėmė_,
   {{0x52bd00c3,0xf1c80023,0x63670233,0xccf30eda}},	//   ्यूस, _sỡ_, _pına, רכו_,
   {{0xc7d70054,0x26110b7f,0x2bd1277c,0x3dc20479}},	//   _אולי_, _देवी_, हिता, kwkw_,
   {{0xc1b71402,0x00000000,0x00000000,0x00000000}},	//   елых_, --, --, --,
   {{0xa2d5009d,0xf1c800de,0xf99300ca,0x68eec214}},	//   _मोठ्, _vỡ_, נרת_, _jobd,
   {{0x7d15c215,0x7c3b01c2,0x00000000,0x00000000}},	//   vizs, ƙuri, --, --,
   {{0xa3bd0f53,0x6d4e52d2,0x00000000,0x00000000}},	//   इबर_, emba, --, --,
   {{0x2b59396a,0x9df8008f,0x00000000,0x00000000}},	//   _risc_, енят_, --, --,
   {{0x2b5900dc,0xef1f04a8,0x00000000,0x00000000}},	//   _sisc_, snü_, --, --,
   {{0xdb1e0b0b,0x69c63980,0x3a3f00d4,0xf8ce00bc}},	//   _espí, _aske, _šup_, _होइय,
   {{0x6d4e5f59,0x3f9e35c3,0x9b582a72,0x00000000}},	//   amba, mutu_, еист_, --,
   {{0x0f5800c1,0x7e6d0f20,0x7cf00149,0x7b0300aa}},	// [f5b0] _איהם_, _ifap, _värr, _nõue,
   {{0x7bc501bb,0x68ee00ee,0xa3e000b6,0x7b0300bc}},	//   _tshu, _cobd, दमा_, _sõud,
   {{0x3f9e02a7,0x2d8b00a5,0x69c602a7,0x7bc552cd}},	//   nutu_, lsce_, _eske, _ushu,
   {{0xa3cf5fc7,0x238c00d2,0x00000000,0x00000000}},	//   शिस_, děj_, --, --,
   {{0x3f9e696a,0x64a5457f,0x26110455,0x7cf013ce}},	//   hutu_, вала, _देशी_, _kärp,
   {{0x3f9e59e1,0x26c9005f,0xa3bd030b,0x2d990037}},	//   kutu_, žao_, इबल_, irse_,
   {{0x6282043e,0x26110ed3,0x7c290364,0x2019173c}},	//   _beoo, _देरी_, ßerh, şsiz_,
   {{0x02bd007d,0x0ed0009d,0x69c602ac,0x00000000}},	//   ्येन, _तोंड, _yske, --,
   {{0x2d8b00a5,0xa2a2022d,0x7aef037a,0x963500ae}},	//   jsce_, _गार्, _moct, _рнац,
   {{0xd12e00ab,0x3f9e0027,0x7cf012cd,0x00000000}},	//   يمي_, futu_, _närp, --,
   {{0x3f9ec216,0x2d9918f0,0x52b50037,0xddc400ae}},	//   gutu_, erse_, _لماذ, _ofiţ,
   {{0x7aef0575,0x62821570,0x5215268e,0x00000000}},	//   _noct, _geoo, _идет, --,
   {{0x78b50146,0x7cf002c3,0x00000000,0x00000000}},	//   _obzv, _bärp, --, --,
   {{0x3f9e3cd3,0xed574f03,0xdfa91f11,0xaca40129}},	//   butu_, коя_, _قطعه_, kwụk,
   {{0xed574383,0x6d4e00dd,0x2d990328,0x68ee0381}},	//   тор_, rmba, arse_, _robd,
   {{0x38c81e49,0x2fc700f9,0x097a0fe9,0x00000000}},	//   کاری_, _isng_, дёжь_, --,
   {{0x7aef09bc,0x5a63661e,0xfd120308,0xf1ca01cd}},	// [f5c0] _doct, ркуб, _نجد_, mráð_,
   {{0x2fc70113,0x6b6600d3,0x00000000,0x00000000}},	//   _ksng_, _икоа, --, --,
   {{0xc8b5013f,0x248706a3,0x00000000,0x00000000}},	//   ысты, danm_, --, --,
   {{0x02bd231e,0x00000000,0x00000000,0x00000000}},	//   ्योन, --, --, --,
   {{0x6f1d1f9f,0x68ee2c07,0x05b40037,0xb86607e8}},	//   érci, _tobd, امتح, _لازو,
   {{0x684611d9,0x3f9e0233,0xa53302b7,0x00000000}},	//   _анга, yutu_, аніч, --,
   {{0x17c7078b,0x69c400a5,0x60ca003e,0x22405c56}},	//   _игри_, lwie, _rafm, _šik_,
   {{0x6aa411f9,0x14d20096,0xf5960037,0x69c4007f}},	//   ngif, _धोरण, _للرج, owie,
   {{0x44320067,0x7c29026a,0x69c4281c,0x00000000}},	//   ły_, ğeri, nwie, --,
   {{0xa3cf05d4,0x6722013f,0x3f9e19f6,0x60ca0063}},	//   शिश_, lnoj, tutu_, _qafm,
   {{0x69c401bf,0x2d80345f,0x628200bc,0x251b021e}},	//   hwie, _awie_, _teoo, _קובא,
   {{0x3f9e073b,0x67223f9b,0x00000000,0x00000000}},	//   rutu_, nnoj, --, --,
   {{0xf19414fa,0x3f9ec217,0x6aa402b6,0x6722c218}},	//   _силь, sutu_, dgif, inoj,
   {{0x3f9ec219,0x2d800034,0xdb1e01b9,0x67225d4d}},	//   putu_, _dwie_, _aspà, hnoj,
   {{0x7ceb01bf,0x7aef0146,0x6aa402b6,0x8aa75781}},	//   _kürz, _poct, fgif, крад,
   {{0x99800034,0x905700ca,0x2cad00b6,0x6722c21a}},	//   dził_, _בסוף_, řed_, jnoj,
   {{0xdb1e0072,0x3ea9849e,0x690b007f,0x00000000}},	// [f5d0] _arpó, _icat_, dżer, --,
   {{0x3dc90270,0xdb1e015e,0x6aa4010a,0x6722250f}},	//   _isaw_, _espà, agif, enoj,
   {{0xccf20054,0x248706a3,0xfd130018,0xc1af00b6}},	//   _הכי_, vanm_, _مجھ_, _जङ्ग,
   {{0x07a41d1b,0x7bd70090,0x69c4c21b,0x00000000}},	//   раїн, _irxu, bwie, --,
   {{0xa63416dd,0xf7730018,0xa3c8009f,0x5a9a00ca}},	//   анці, _چار_, _लैब_, _אשרא,
   {{0xa3cf0966,0xf7730308,0x00000000,0x00000000}},	//   शिल_, _نار_, --, --,
   {{0x22460018,0x3ea902f7,0x28e0074c,0x00000000}},	//   _azok_, _ocat_, नारि, --,
   {{0x248714b1,0xf366001c,0x613d00b3,0x00000000}},	//   sanm_, دئوی, mèli, --,
   {{0xdced0d62,0x788801d3,0x798d22cc,0x00000000}},	//   _atač, būvē, nsaw, --,
   {{0x0cce0081,0x00000000,0x00000000,0x00000000}},	//   _রক্ত, --, --, --,
   {{0x3ce7007d,0xb4cf009d,0x69c4007f,0x00000000}},	//   ञाने_, षयी_, zwie, --,
   {{0x24851399,0x6eff0052,0xddc400e8,0x798d0113}},	//   _helm_, _dëbo, _afiš, ksaw,
   {{0xe0ce0020,0x2903c21c,0x6aa40160,0x333f00bd}},	//   _лв_, _olja_, vgif, mlux_,
   {{0x333f009e,0x67222c3c,0x3ea9033c,0x2af600aa}},	//   llux_, znoj, _ecat_, _एकहु_,
   {{0x798d00f0,0x6aa43b7a,0x3ea90383,0x3a2b00a7}},	//   esaw, tgif, _fcat_, _axcp_,
   {{0xdce4005f,0x69c44197,0x2365015c,0x2b4bc21d}},	//   _otić, twie, _mulj_, _chcc_,
   {{0x09e3455b,0x6aa40f6f,0x6f04c21e,0x7a1a0065}},	// [f5e0] ботн, rgif, _ilic, _bíbẹ,
   {{0x69c4c21f,0xcc361a37,0x60c15656,0xed6200c6}},	//   rwie, _مرجع, nelm, įžę_,
   {{0x6f04c220,0x6aa40222,0xb8cc3245,0xdb1e2733}},	//   _klic, pgif, _गा_, _espá,
   {{0x2bd102e8,0xdb9b02f8,0xbc1b00c1,0x798d023e}},	//   हिरा, _אסטר, _טויש, bsaw,
   {{0x6d5e9fe3,0x63ba0085,0x6f04024a,0x672201b6}},	//   _kipa, _sptn, _mlic, rnoj,
   {{0x60c102fd,0x6f040472,0xa7861a13,0x236500c4}},	//   jelm, _llic, _مشرو, _bulj_,
   {{0x60c1c221,0x6d5e0010,0x291a00f9,0xe3af0037}},	//   delm, _mipa, mipa_, كري_,
   {{0x6d5ec222,0x291ac223,0xaa7b0181,0xa2f41b48}},	//   _lipa, lipa_, _inýc, рпич,
   {{0xdced18ed,0x8af00092,0x171b00c1,0x7b0300aa}},	//   _stač, mməd, _נומע, _jõua,
   {{0x6d5e2706,0x60c1c224,0x8af00092,0x291a6413}},	//   _nipa, gelm, lməd, nipa_,
   {{0x6f04c225,0x2b40033b,0x7c3e5759,0xd36f0076}},	//   _blic, klic_, _nypr, _فهل_,
   {{0x291a002d,0x6d5e02a7,0x9f35004d,0xb857006e}},	//   hipa_, _aipa, ремі, טשיג_,
   {{0x60c1c226,0x7b03007a,0x291ac227,0x443e14bd}},	//   belm, _nõua, kipa_, _hyt_,
   {{0x6f04c228,0x656f0257,0x6d5ec229,0x273c0094}},	//   _elic, _éche, _cipa, mínu_,
   {{0x6d5e0655,0x6f049aad,0x798d0270,0x273c2255}},	//   _dipa, _flic, wsaw, línu_,
   {{0x7b64016a,0x443e6e6d,0x543b006e,0x798d0d2a}},	//   стре, _myt_, געלא, tsaw,
   {{0xad2703ef,0x6d5e0af0,0x443e0b81,0x6f1d0072}},	// [f5f0] _مردو, _fipa, _lyt_, ércu,
   {{0x4a54594b,0x0edd02e8,0x6fa80455,0x6d5e1098}},	//   скус, याकड, _कमां, _gipa,
   {{0x443ec22a,0xf77000e3,0xdce40106,0x6eac009f}},	//   _nyt_, كان_, _stić, _झामु,
   {{0x1b7a00c1,0x6d5e39bd,0x60c10230,0x0c74001c}},	//   _שטרע, _zipa, zelm, _پدید,
   {{0xa68402ec,0x443e53c4,0x60c16eab,0x7aed575f}},	//   слід, _ayt_, yelm, mjat,
   {{0x7aedc22b,0x443ec22c,0x290302e6,0x291a351b}},	//   ljat, _byt_, _ulja_, cipa_,
   {{0x2bd831d7,0x60c1001f,0xddca007f,0x7aed04d9}},	//   डिया, velm, _łoży, ojat,
   {{0x41b523a3,0x16160251,0xe610015a,0x857516d0}},	//   асот, _देवर_, _کشف_, _влах,
   {{0x60c161b0,0x54a7097d,0x628902ad,0xb8860031}},	//   telm, _محاف, raeo, stíž,
   {{0xa2d53245,0x6f161113,0xe7e70081,0x7aed0329}},	//   _मोर्, _smyc, পনীয, hjat,
   {{0x6d5e0530,0x60c1c22d,0x6f04c22e,0x4f26078b}},	//   _ripa, relm, _plic, идоб,
   {{0x6d5ec22f,0x7f4dc230,0x7aed8478,0x63a3c231}},	//   _sipa, _chaq, jjat, munn,
   {{0x7f4d025e,0x6d5ec232,0x63a3c233,0x7aedc234}},	//   _dhaq, _pipa, lunn, djat,
   {{0xdca60a28,0x4e9600cd,0xa0660974,0x645c0a61}},	//   јави, دشگر, _каша_, _úric,
   {{0x6d5ec235,0x63a3003e,0x673b0283,0x61fb019c}},	//   _vipa, nunn, _okuj, lyul,
   {{0x2b40c236,0x7c3e025b,0x672900dd,0x7aed1c96}},	//   ulic_, _vypr, _njej, gjat,
   {{0x61fb05fb,0x61e98936,0x7c3e00a5,0x63a381ec}},	// [f600] nyul, nxel, _wypr, hunn,
   {{0xa3d504a9,0xe9d7534f,0x63a3245b,0xc8e006ed}},	//   िटा_, шку_, kunn, नाइट,
   {{0x63a38832,0xcd290c5e,0x76490154,0xdc9b0266}},	//   junn, _حسين_, _azey, _בייל,
   {{0x7d1c8368,0xe9a652be,0x291a0995,0x63a3c237}},	//   lirs, _камп, sipa_, dunn,
   {{0x70c50251,0x62860088,0xfb3700c1,0x8af000a7}},	//   _वसूल, ðkom, _כאטש_, rməd,
   {{0x63a3c238,0x6729037a,0x443ec239,0x673bc23a}},	//   funn, _ejej, _pyt_, _ekuj,
   {{0xb4e60251,0x63a3c23b,0x76490172,0x291800b3}},	//   _बची_, gunn, _ezey, _imra_,
   {{0xb6a35598,0x672900dd,0x7b03007a,0x64480220}},	//   _мисл, _gjej, _lõun, _vzdi,
   {{0x9f590d79,0xdb070103,0x443e00f0,0x7d1cc23c}},	//   árí_, ntjá, _wyt_, kirs,
   {{0x7f4d025e,0x63a3c23d,0x7aed003d,0x443e0063}},	//   _shaq, bunn, zjat, _tyt_,
   {{0x644800cc,0x7d1cc23e,0xd8d7006e,0x40340b9e}},	//   _uzdi, dirs, בויט_, сенс,
   {{0xd04100a7,0x273c7273,0xdb230555,0x77600078}},	//   ndlə, míns_, ürüc, _jimx,
   {{0x7d1c9238,0x7e471231,0x7e64078e,0x00000000}},	//   firs, рхне, _dgip, --,
   {{0x7d1cc23f,0x00000000,0x00000000,0x00000000}},	//   girs, --, --, --,
   {{0x7aed8fc4,0x9b680859,0x7f4dc240,0x7bc701cb}},	//   tjat, ишта_, _thaq, uwju,
   {{0x2918b63b,0x5f73046b,0x2cba0154,0x6e2d0634}},	//   _amra_, _باور, _ebpd_, _txab,
   {{0x7aedc241,0x6f1d0bb7,0x7d1cc242,0x9f530034}},	// [f610] rjat, misc, birs, ńców_,
   {{0x6f1dc243,0x7d1c0328,0x7c290364,0x26110034}},	//   lisc, cirs, ßers, _देगी_,
   {{0x7aed2f2d,0x8e38001c,0x3ebe0103,0xd5430032}},	//   pjat, _مسیر_, őtte_, _lẹ́h,
   {{0xb8fe10ed,0x6f1dc0be,0xec360054,0x63a3c244}},	//   _दो_, nisc, _לאתר_, vunn,
   {{0x261104dd,0x63a303e3,0x764000f0,0x588701b3}},	//   _देखी_, wunn, _cymy, _выба,
   {{0x63a38c38,0x6f1dc0be,0xd0060bf4,0xd5e20134}},	//   tunn, hisc, _فل_, waọ,
   {{0x67290222,0xaca306c0,0x6f1da727,0xc95200ca}},	//   _tjej, _adịg, kisc, _ממך_,
   {{0x2bd804a9,0x63a36f85,0x61e91164,0x672905bd}},	//   डिता, runn, txel, _ujej,
   {{0x6f1dc245,0x7d1c0092,0x764000f0,0x7538050c}},	//   disc, yirs, _gymy, bovz,
   {{0x63a3b0a4,0x25bf1a3a,0x7d1c01f2,0x60e94f07}},	//   punn, _ipul_, xirs, умом_,
   {{0x68f508a9,0x6f1d4e37,0x7e640124,0x83ab273f}},	//   _mozd, fisc, _pgip, _штаб_,
   {{0x81c600c7,0x6f1d0bb7,0x7c380856,0x61fb00f9}},	//   _উপর_, gisc, _øvri, pyul,
   {{0x2d8404ea,0x2f5502ec,0xa3cf034d,0x7d1cc246}},	//   ème_, ютьс, शिक_, tirs,
   {{0xd37e2461,0x6f1d0037,0xa3ab0f35,0x656102a1}},	//   šćen_, aisc, कंप_, _jilh,
   {{0x65610396,0x7d1c7780,0x3f9e0335,0xd041013c}},	//   _milh, rirs, crtu_, ydlə,
   {{0x6441c247,0x6e960037,0x387f0095,0x213c00c4}},	//   _myli, _الظا, _đura_, _zkvh_,
   {{0xe9da1736,0x7d1c767b,0x68f50233,0x6fd500aa}},	// [f620] ыка_, pirs, _bozd, धिवं,
   {{0xb4e6000f,0xdb070103,0x656102a1,0x202800c4}},	//   _बचे_, rtjá, _nilh, štiš_,
   {{0x64411bfa,0xdb070088,0x65690231,0x00000000}},	//   _nyli, stjá, _aueh, --,
   {{0x7b03007a,0xdd8f00cd,0xa3ab0179,0x6561c248}},	//   _jõul, _توی_, कंन_, _ailh,
   {{0x6561c249,0xe5a30c5b,0xd04100a7,0x6441020e}},	//   _bilh, зичи, rdlə, _ayli,
   {{0x644112b1,0x68f50087,0x76400146,0x29181308}},	//   _byli, _gozd, _vymy, _umra_,
   {{0x64418537,0x07a3037e,0x7640007f,0x7760009e}},	//   _cyli, _нарн, _wymy, _timx,
   {{0x6441043a,0x79860449,0x273c002b,0x628f0072}},	//   _dyli, _kwkw, ríns_, ócop,
   {{0x65610396,0xe29f0088,0x32022347,0x9aeb006e}},	//   _filh, óða_, áky_, אַיִ,
   {{0x656f025a,0x6f1d3f27,0x00000000,0x00000000}},	//   _écha, wisc, --, --,
   {{0x6f1d3d25,0x32020074,0x61e4013f,0x248e0124}},	//   tisc, šky_, _šild, mafm_,
   {{0xb7db0089,0x656903e3,0x00000000,0x00000000}},	//   אקטי, _yueh, --, --,
   {{0x64410364,0x644d0022,0xa2b70285,0x00000000}},	//   _zyli, ƙaic, ्जर्, --,
   {{0x6f1dc0be,0xd1300076,0x248e0350,0x00000000}},	//   sisc, _تمت_, nafm_, --,
   {{0x68f51fe8,0x6f1dc24a,0xb4fb0341,0x26c600e7}},	//   _rozd, pisc, נפלי, keoo_,
   {{0xae9b0037,0xaca30139,0xbebb0381,0x00000000}},	//   _إضغط_, _idọg, fiëe, --,
   {{0xb4fa00b7,0x00000000,0x00000000,0x00000000}},	// [f630] ्साय_, --, --, --,
   {{0x2907c24b,0xb8820220,0x25a6793f,0xd3780234}},	//   óna_, _šírk, duol_, _zrće_,
   {{0xf84b2dfb,0x25bf93c7,0x68f53df1,0xdb1e0231}},	//   учай_, _spul_, _vozd, _arpõ,
   {{0x17f80037,0x8c44020a,0x00000000,0x00000000}},	//   حركة_, ăşti, --, --,
   {{0xa3ab2cb6,0x65610161,0x2bd10b94,0x6569034f}},	//   कून_, _pilh, हिका, _queh,
   {{0xdb1e02ac,0x5f1b00ac,0x73990161,0x6eff0216}},	//   _appè, ụghị_, атис_, _dëbi,
   {{0x051600e3,0x65612085,0x65690113,0x8cbb007f}},	//   تيوب_, _vilh, _wueh, श्यो,
   {{0x8c1c00c1,0x6561c24c,0x69dd0a39,0x64412347}},	//   טווי, _wilh, _krse, _vyli,
   {{0x6441053c,0x65615ec1,0x2d9e00a5,0xd49b12d3}},	//   _wyli, _tilh, ątek_, _бре_,
   {{0xc10500e3,0x161f0557,0x34940450,0xdb070212}},	//   زوجي, _मेयर_, _наур, ltjä,
   {{0xceea12d3,0xd8d8006e,0x78ba01f9,0x3eb9042c}},	//   адне_, מוזט_, _ötve, ffst_,
   {{0x69cf7f71,0x69dd8fa5,0xc7d600ca,0x25a00dab}},	//   _osce, _orse, קורי_, šile_,
   {{0xee370f1e,0x2003033b,0x62990383,0x82370286}},	//   жня_, šji_, _idwo, _ارضا,
   {{0x628b01e9,0x00000000,0x00000000,0x00000000}},	//   _hego, --, --, --,
   {{0x628b0533,0x69cf0fca,0x00000000,0x00000000}},	//   _kego, _asce, --, --,
   {{0x28ac2087,0xb4e60034,0x69dd00c4,0x1a2a1da9}},	//   _चाहि, _बच्_, _brse, ажби_,
   {{0x628b0068,0x3b07016e,0x13a600c0,0x8d760dd0}},	// [f640] _mego, цето_, _गम्भ, _بابا,
   {{0x628bc24d,0xa3e9000d,0x98a3002d,0x69dd0117}},	//   _lego, ममा_, дифе, _drse,
   {{0x69cf38c4,0x69ddc24e,0x62990034,0x00000000}},	//   _esce, _erse, _odwo, --,
   {{0x628b1190,0xb6030146,0xe73a00c2,0x09e600d3}},	//   _nego, _omáč, шее_, _домн,
   {{0x7ae6029a,0x644500aa,0x00000000,0x00000000}},	//   _inkt, ühin, --, --,
   {{0x628b8d46,0xb6030031,0x33980076,0x00000000}},	//   _aego, úšan, منتج_, --,
   {{0x261a0e46,0x628bc24f,0x0eaa0789,0xdb1e020d}},	//   _मेरी_, _bego, _कांड, _appé,
   {{0xe73737fa,0x628b0558,0xcfcf0033,0x69dd02c3}},	//   _дес_, _cego, িমান, _yrse,
   {{0x628b3b72,0x80d30033,0x61e4007e,0x248e044c}},	//   _dego, তান্, _šilb, pafm_,
   {{0xe4520281,0xd46700d3,0x30141272,0x628b041c}},	//   _قضا_, _дифе_, здор, _eego,
   {{0xa2d51da8,0x628b0154,0x00000000,0x00000000}},	//   _मोक्, _fego, --, --,
   {{0x628bc250,0x51862290,0x543b0142,0x00000000}},	//   _gego, _дука, _דעבא, --,
   {{0xe0cf00cd,0x3eb928c7,0xd49100fe,0x00000000}},	//   رزی_, rfst_, _hòa_, --,
   {{0x628b0a00,0x224b01bf,0x7ae6023b,0x387f00cb}},	//   _zego, ücke_, _ankt, _đuro_,
   {{0xcb1b0396,0x7b2c00a7,0xb60300d2,0x00000000}},	//   аќа_, rğun, _zmáč, --,
   {{0x290a0049,0x539b0089,0xb8821515,0xdd910037}},	//   _alba_, יילו, _šípk, _كوب_,
   {{0x5d840037,0x290a00d8,0x00000000,0x00000000}},	// [f650] _قليل, _blba_, --, --,
   {{0x2bcb009d,0xaa7b0031,0x60c800f9,0x69dd0a39}},	//   ाबदा, _iným, nedm, _vrse,
   {{0x6d4715f4,0xb8d360a3,0x7b0300bc,0xdb0702c3}},	//   mlja, _टा_, _jõuk, ttjä,
   {{0x69dd005c,0x6d470088,0x2be00251,0x8af0013c}},	//   _trse, llja, _पछता, lmən,
   {{0x628bc251,0x69cfc252,0xdb070212,0x257001ec}},	//   _rego, _usce, rtjä, _càl_,
   {{0x628bc253,0xdb070149,0x929d0034,0xe9df0d79}},	//   _sego, stjä, dkła, _irú_,
   {{0xe29924c0,0x4900009d,0x628b0161,0x7b03007a}},	//   бай_, _शकतो_, _pego, _nõuk,
   {{0x6aad87ad,0x16160034,0x656f00fd,0x6d470117}},	//   ngaf, _देकर_, _écho, hlja,
   {{0x6d470128,0x672b00d6,0x257000b3,0x91b00023}},	//   klja, mngj, _gàl_, _đại_,
   {{0xa3bb0678,0xbef600c3,0xa3b8001c,0x628b0372}},	//   _ناصر_, ुघ्न_, _ژانر_, _wego,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x672b64f8,0x00000000,0x00000000,0x00000000}},	//   nngj, --, --, --,
   {{0x91e50b1e,0x273b0134,0x6d470357,0x672b32a7}},	//   _холе, ụnwa_, flja, ingj,
   {{0x2d9e025b,0x657b0010,0x91f600ca,0x6d470aa0}},	//   čte_, _mtuh, _ממנו_, glja,
   {{0xe8df0019,0xe9df033c,0x00000000,0x00000000}},	//   _ngực_, _arú_, --, --,
   {{0x6b634a4e,0x63ae01c5,0xe9df6084,0x511b00bc}},	//   екса, _åbne, _brú_, _फगुआ_,
   {{0x6d472782,0x6ebc0d88,0x80ce0081,0x63a30094}},	// [f660] blja, ष्णु, ়ার্, hrnn,
   {{0xb9250134,0x7bde00c4,0x8f1c03e3,0xcdb700ca}},	//   mkpụ_, _trpu, ɗɗaɗ, _צפיה_,
   {{0x78a30088,0xe9df0032,0x36c620e6,0x929d0034}},	//   ónva, _erú_, збег, zkła,
   {{0x60c80067,0x248c02c6,0x257000ee,0x3a2d191d}},	//   zedm, _sedm_, _pàl_, _žepe_,
   {{0xa4d4004d,0x00000000,0x00000000,0x00000000}},	//   долі, --, --, --,
   {{0xb4d662c3,0x00000000,0x00000000,0x00000000}},	//   िये_, --, --, --,
   {{0xf214009f,0x60c80170,0x279500be,0x335800ae}},	//   _तेज़_, vedm, _оштр, оакэ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd5c00006,0x79960034,0x67220109,0xd52800fe}},	//   _एहिज, nsyw, mioj, _cộn,
   {{0x6722bfa2,0x6aa802d5,0xdce40880,0xd49100fe}},	//   lioj, गलुर, _otiđ, _tòa_,
   {{0x66022315,0x8f351bf9,0xe1ef0260,0x7bdc02ef}},	//   lyok, денц, نسی_, jvru,
   {{0x60c825d5,0x67220138,0x7d1e24d4,0x7bdc18f0}},	//   sedm, nioj, _amps, dvru,
   {{0xa2d5007d,0x6602c254,0x7b2c0092,0x3cfa01c8}},	//   _मोट्, nyok, rğul, _bopv_,
   {{0xeb0519af,0xed590138,0xd3780234,0x7b0300bc}},	//   रस्त_, įžo_, _zrća_, _tõuk,
   {{0x00bb00a1,0x6d470559,0xcc54008f,0x67220138}},	//   _המומ, rlja, евръ, kioj,
   {{0x6d4703ce,0x5bb8007b,0x660206b0,0x00000000}},	//   slja, ялся_, kyok, --,
   {{0x2bcb0034,0x6f0dbea6,0x63a30094,0x67224452}},	// [f670] ाबहा, _ilac, zrnn, dioj,
   {{0xb4d609f6,0x2bce0251,0x8af00092,0x63aa02ef}},	//   ियो_, _हैवा, lməl, kufn,
   {{0x6f0dc255,0xf6d5004d,0x69cd0f5a,0x66020172}},	//   _klac, діля, swae, eyok,
   {{0xe9df429a,0xd4910023,0x7bc50201,0x672201b6}},	//   _trú_, _còn_, _iphu, gioj,
   {{0xd5bb6ebc,0x497407ef,0x22460483,0x29cd14f3}},	//   ссе_, _пляс, _nyok_, _uža_,
   {{0x6f0dc256,0x1dde06ec,0x00000000,0x00000000}},	//   _llac, मितत, --, --,
   {{0x6f0d06d7,0x22461a3a,0xb0a600a4,0x660206b0}},	//   _olac, _ayok_, _खाजग, ayok,
   {{0x07090080,0x36d40d06,0x61e400c6,0x67223610}},	//   _بيري_, _поср, _šila, cioj,
   {{0x59e0086d,0x657b0350,0xdcf600d8,0x41b400d3}},	//   नियर, _utuh, _styč, нсэт,
   {{0xf1d20067,0x6f0dc257,0xa2bd0455,0x2ee96623}},	//   तिजन, _alac, _वॉर्, _anaf_,
   {{0x6f0d632b,0xbea6100f,0x1eca078b,0x7523063d}},	//   _blac, манк, олни_, minz,
   {{0x6f0d01b5,0x7523c258,0x2b4902ef,0x212c009c}},	//   _clac, linz, jlac_, andh_,
   {{0x6f0d00a5,0x213e53ca,0x7bc5019f,0xee3a097a}},	//   _dlac, both_, _aphu, інг_,
   {{0xd009002d,0x332d0167,0xcb6a8a30,0x333f8e3d}},	//   _меле_, lnex_, жаве_, loux_,
   {{0x8c431d5c,0x6f0dc259,0xdc670da5,0x00000000}},	//   вере, _flac, дард_, --,
   {{0x6f0dc25a,0x25ee009d,0x7523023f,0x333f020d}},	//   _glac, _आपली_, hinz, noux_,
   {{0xe8fa0581,0x3167c25b,0x14ae0096,0x7523600a}},	// [f680] ола_, _kinz_, _घालण, kinz,
   {{0x66020010,0x6f0d0e43,0x7c39014b,0x00000000}},	//   vyok, _zlac, ébré, --,
   {{0x7a6a0231,0x8af000a7,0xd25901d3,0x75230036}},	//   _минг_, lməm, meņu_, dinz,
   {{0xe5c6344d,0xa3e1046e,0x333f4466,0xa2bd0789}},	//   дско, दिन_, joux_, _वॉल्,
   {{0x6722013f,0x333f1829,0x8af0013c,0x00000000}},	//   rioj, doux_, nməm, --,
   {{0xd37a31d9,0x67221093,0x9f5f0094,0x75230027}},	//   очи_, sioj, ryté_, ginz,
   {{0x2246048e,0x68fcc25c,0xbebb01c0,0x66026221}},	//   _syok_, _iord, diën, syok,
   {{0x68fcc25d,0x63aa005c,0x2b401881,0xc2980291}},	//   _hord, rufn, noic_, чких_,
   {{0x68fc7547,0x75231206,0x6f0d009c,0x00000000}},	//   _kord, binz, _rlac, --,
   {{0x68fcc25e,0x6f0dc25f,0x7523c252,0xbebb0371}},	//   _jord, _slac, cinz, giën,
   {{0x68fcc260,0x6f0d6f73,0x3f98025b,0x2b490188}},	//   _mord, _plac, éru_, ylac_,
   {{0x656800dd,0x522600c9,0xe28300d3,0x6d5c01fc}},	//   _hidh, _офла, _алци, emra,
   {{0x68fc159f,0x22460124,0x8af00092,0x2f02003e}},	//   _oord, _uyok_, rməl, _nógu_,
   {{0x68fc0073,0x656821f5,0xbebb01c0,0x23c20034}},	//   _nord, _jidh, ciën, _शहाद,
   {{0x6f0dc261,0xb0650673,0x65682592,0x251b0089}},	//   _tlac, rjää, _midh, קולא,
   {{0x656801e5,0x6448be39,0x75230b32,0xdb1e014b}},	//   _lidh, _mydi, zinz, _appâ,
   {{0x68fc79e0,0x6568117b,0x64488934,0x75230a15}},	// [f690] _bord, _oidh, _lydi, yinz,
   {{0x2b490559,0x6568c262,0x25a60178,0xba540284}},	//   slac_, _nidh, drol_, твуј,
   {{0xf77039d9,0x68fc5b1b,0x6d450201,0x2b4900b3}},	//   لان_, _dord, _ikha, plac_,
   {{0x61e2c263,0x6568c264,0x25a68d67,0x00000000}},	//   _orol, _aidh, frol_, --,
   {{0x68fc9a92,0x6568c265,0x75231825,0x7e6d0009}},	//   _ford, _bidh, tinz, _mgap,
   {{0x7afd06ce,0x65681dc1,0x2d99be81,0x68fc95e7}},	//   _host, _cidh, isse_, _gord,
   {{0x7523c266,0xc61f00a5,0x61e20150,0xe2990219}},	//   rinz, _मेरठ_, _arol, пай_,
   {{0x7e6d7246,0x25a612b7,0x7afdc267,0x752335e0}},	//   _ngap, brol_, _jost, sinz,
   {{0x68fcc268,0xbebb0126,0x61e23f89,0x75230051}},	//   _yord, tiën, _crol, pinz,
   {{0x7afdc269,0x6d45022e,0x7e6dc26a,0x68fc08a8}},	//   _lost, _nkha, _agap, _xord,
   {{0x7afd043e,0xff2619cb,0xbebb1030,0x2d99c26b}},	//   _oost, емно, riën, esse_,
   {{0x7afdc26c,0x6da61b48,0x6d45c26d,0x77690167}},	//   _nost, нима, _akha, _jiex,
   {{0x65680694,0xa3ab0096,0x61e20381,0x52ab0034}},	//   _yidh, कूर_, _grol, छलीस,
   {{0x65680694,0x7afdc26e,0xd19600a1,0x8af000a7}},	//   _xidh, _aost, _טכני_, rməm,
   {{0x7afd5dd3,0x1be72872,0x2d99c26f,0x76490172}},	//   _bost, ндри_, asse_, _lyey,
   {{0x7afd7de6,0x6d450060,0x68fcc270,0x7769009e}},	//   _cost, _ekha, _sord, _niex,
   {{0x4a7500c6,0x68fc5c3b,0xdc3c031a,0x8af000a7}},	// [f6a0] тыст, _pord, _išča, lmək,
   {{0x38c80260,0x290e3e07,0x7afd00fc,0xd491020b}},	//   باری_, ófa_, _eost, _nè_,
   {{0x8cd905a5,0x7afdc271,0x7649c272,0x68fc2cec}},	//   _फोटो, _fost, _ayey, _vord,
   {{0x7afdc273,0x68fc0bcc,0xb907048a,0xa96a0451}},	//   _gost, _word, _मो_, _нима_,
   {{0x6f1d05fe,0x45d411b4,0x2bd800b6,0x65686e5d}},	//   èrci, толс, डिका, _pidh,
   {{0x7afd3239,0x25a608a8,0x9f590080,0xb4bc00aa}},	//   _zost, rrol_, árú_, ेजे_,
   {{0xf366450e,0xa3ab110d,0x25a672b7,0x3ea0022b}},	//   нтин, कूल_, srol_, _odit_,
   {{0x61e25809,0x2d990519,0x6568c274,0x64480031}},	//   _prol, ysse_, _widh, _vydi,
   {{0x65682811,0xe7371230,0x76490361,0x6448c0c8}},	//   _tidh, _чет_, _gyey, _wydi,
   {{0x61e20db1,0x3ea009a4,0x7e6d0441,0x644800f3}},	//   _vrol, _adit_, _sgap, _tydi,
   {{0x40341e6d,0x2d800063,0xb3e90037,0x00000000}},	//   тенс, _atie_, _يعمل_, --,
   {{0x61e233f1,0xbebb0126,0x6fb10aa1,0x7b0300bc}},	//   _trol, ciël, _अमरू, _jõut,
   {{0x7afdc275,0xc333028c,0x2d99c276,0x61e20cd6}},	//   _rost, _גוף_, usse_, _urol,
   {{0x7afd2ff4,0xd24f00e3,0x3ea000a1,0x20050354}},	//   _sost, _انه_, _edit_, byli_,
   {{0xd00f0b2e,0xf0930796,0x6456013c,0x2bc8290e}},	//   _сф_, _ענק_, əyic, нуто_,
   {{0xa3e10e4c,0x39580167,0x7b0300aa,0x7e6d0169}},	//   दित_, _ahrs_, _nõut, _ugap,
   {{0x7afdc277,0x9f5f0103,0xe29f003e,0x387f03e3}},	// [f6b0] _vost, sztó_, óði_, _ƙur_,
   {{0x273c0146,0xaa64545b,0x6d45019f,0x7afd0063}},	//   míny_, утск, _ukha, _wost,
   {{0x2815037f,0x7afdc278,0x56950084,0xdb0702c6}},	//   خواس, _tost, вает, lují,
   {{0x7afd6d61,0x5d841aaa,0x7bd701ee,0x00000000}},	//   _uost, _جلیل, _isxu, --,
   {{0x02bc00aa,0xdb1e0956,0xdb0702c6,0x2005007f}},	//   ्जैन, _espó, nují, zyli_,
   {{0xf99209c1,0xfaff0185,0x7c34026a,0x03a5a102}},	//   _דרך_, _hoë_, _çerç, вико,
   {{0xdce50087,0x77690063,0xdb0702c6,0x2911084e}},	//   _nihč, _tiex, hují, _ilza_,
   {{0xdb0702c6,0x00000000,0x00000000,0x00000000}},	//   kují, --, --, --,
   {{0x3dc9023e,0xbebb0db1,0x61e40037,0x26cf0034}},	//   _npaw_, riël, _áill, mego_,
   {{0x26cf4b1f,0x60092f93,0xdb07030b,0x3ea00167}},	//   lego_, дном_, dují, _sdit_,
   {{0x2d8000d3,0x7b03007a,0x3dc90270,0x61ed0138}},	//   _stie_, _jõus, _apaw_, _šald,
   {{0x26cf0067,0xe2900080,0x26dd01bf,0x8af000a7}},	//   nego_, _هذه_, ndwo_, rmək,
   {{0xe0ce236f,0xc33200a1,0x273c0146,0x00e3010d}},	//   _кв_, _דוא_, gíny_, _متغی,
   {{0xa3b50e72,0xa5a9009f,0x26cf0a61,0x6289029a}},	//   _जमा_, _घिनौ, hego_, lbeo,
   {{0x7b03007a,0xfaff084e,0xad9b0103,0x00000000}},	//   _nõus, _boë_, nyúj, --,
   {{0x3f8546d0,0x26cf00a5,0x29116636,0x62890381}},	//   mplu_, jego_, _alza_, nbeo,
   {{0x26cf819c,0x273c0094,0x29110231,0xdb0702c6}},	// [f6c0] dego_, cíny_, _blza_, cují,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd9450076,0x26cf0231,0x3f8501c8,0x00000000}},	//   ائقي, fego_, nplu_, --,
   {{0x6d4eb867,0xd7ef00e3,0xc6a32cd8,0xdb1e4682}},	//   llba, تكم_, арши, _espò,
   {{0xdb1e0067,0xe76916c4,0x31bd0835,0x6d4e444a}},	//   _wspó, رحمن_, ्बोध, olba,
   {{0x260e00aa,0xfaff0b8e,0x62890381,0x00000000}},	//   तैषी_, _zoë_, ebeo, --,
   {{0x25ee00a5,0x59e00034,0xdb0702c6,0x68ee02a1}},	//   _आपकी_, निवर, zují, _inbd,
   {{0x26cf00a5,0x61d82a6e,0x6d4e0364,0x8ca20285}},	//   cego_, емия_, hlba, कृतो,
   {{0x05660f99,0x261a00b6,0x00000000,0x00000000}},	//   _аван, _मेची_, --, --,
   {{0x70ac0096,0xdb0702c6,0xddcb00c6,0x00000000}},	//   चलेल, vují, šiūn, --,
   {{0xd0070303,0xf6510068,0xb4ae03a2,0x00000000}},	//   веќе_, _نئے_, कली_, --,
   {{0x6d4e6178,0xb226007b,0xdb0700d2,0x00000000}},	//   elba, _имел, tují, --,
   {{0x51f60504,0x00000000,0x00000000,0x00000000}},	//   _جسار, --, --, --,
   {{0x26cfc279,0x25f5009d,0x273c0094,0xdb0702c6}},	//   zego_, ्हती_, ríny_, rují,
   {{0x212b1bc4,0x26cf027f,0x57d100bc,0xdb0702c6}},	//   èche_, yego_, _सनेह, sují,
   {{0x6d4e07e4,0xdb0700b6,0x940700a7,0x26cfc27a}},	//   alba, pují, ganə_, xego_,
   {{0x61e40995,0xba550396,0xaa55001f,0x3df4007b}},	// [f6d0] _šilj, увај, уваш, _взыс,
   {{0x26cfc27b,0x2bab0251,0x3914044b,0x68ee009c}},	//   wego_, _छिपा, амур, _cnbd,
   {{0x3d080067,0x26cfc27c,0xba3b03a8,0x00000000}},	//   _सकते_, tego_, _ddïa, --,
   {{0x2bf2030b,0x98ba01d3,0x2c00030b,0x59f9008f}},	//   ीहरू_, ropā_, रहरू_, _земя_,
   {{0x26cfc27d,0x64a50566,0xdb1e003e,0xe61000b9}},	//   rego_, гала, _uppá, يشه_,
   {{0xe79500d0,0x7b03007a,0x26cfc27e,0x68ee0154}},	//   _مارک, _tõus, sego_, _gnbd,
   {{0xe78719e8,0xf8b20796,0x27f70018,0x3ebe0103}},	//   _југо, _לשם_, _جہاد_, őtti_,
   {{0xf1b70251,0x00000000,0x00000000,0x00000000}},	//   _आमदन, --, --, --,
   {{0x628941a3,0x7aef0479,0xb1452d06,0xc69200ca}},	//   rbeo, _mnct, лнил, _לאן_,
   {{0x28c6206b,0xe00e136b,0xf8c6521f,0x00000000}},	//   र्पि, ानंद_, र्पय, --,
   {{0x26d90042,0x28ab007f,0x60251689,0xe4f0074c}},	//   _ósos_, _चयनि, удна, चारि_,
   {{0x7b0a033d,0x2579022b,0xe37a006e,0x3ce6047e}},	//   _výuk, _kèl_, _טרער, _şov_,
   {{0xdb1c0052,0xe1ee9bc7,0x25790154,0xe29f01cd}},	//   strë, _уг_, _jèl_, óðu_,
   {{0x9d56046b,0x2579022b,0x00000000,0x00000000}},	//   انست, _mèl_, --, --,
   {{0xf99f14b1,0x6d4e00ec,0xdee600ae,0xfaa614e8}},	//   _avè_, rlba, _бойи, лаво,
   {{0x28c609c4,0x00000000,0x00000000,0x00000000}},	//   र्नि, --, --, --,
   {{0xdb1c8733,0x7f3b006e,0x387f00a7,0x6aab0076}},	// [f6e0] ntré, _רעפו, _şura_, ógfa,
   {{0xe9d7055b,0xfd6900ac,0x940700a7,0x61e60120}},	//   ыку_, _mkpụ, sanə_, åkli,
   {{0xa68612d3,0x66e64c8a,0x80b80033,0x00000000}},	//   глед, ложа, _অসম্, --,
   {{0xd6d9004d,0x25790c56,0xd5ba0012,0x3f77044c}},	//   кті_, _bèl_, еск_, _răul_,
   {{0x25790428,0xb4f06bbd,0x00000000,0x00000000}},	//   _cèl_, चालय_, --, --,
   {{0x25790c45,0x6ab61384,0xbf100096,0x00000000}},	//   _dèl_, lgyf, ासुन_, --,
   {{0xfd690129,0x00000000,0x00000000,0x00000000}},	//   _akpụ, --, --, --,
   {{0xdced00a7,0x6ab600f0,0x25790383,0x00000000}},	//   _otağ, ngyf, _fèl_, --,
   {{0x62340a8e,0xb1144170,0x25794ca5,0xc4ca00e5}},	//   репу, имиш, _gèl_, _плаж_,
   {{0x64560092,0x7ddb02c3,0x7c3b044c,0x61ed05db}},	//   əyin, _läså, şuri, _šalc,
   {{0xbf1002e8,0x5ede0081,0x58f700c1,0xf8c608c0}},	//   ासून_, যানে, אמיע_, र्यय,
   {{0xa3e11362,0x41e635bf,0xe8d90134,0xf8d100b6}},	//   दिर_, _مستف, mpụ_, _हस्प,
   {{0x3fc80260,0x656f2cd5,0xe29b006e,0x00000000}},	//   ردگی_, _écht, _טשאר, --,
   {{0x61db040a,0x30760859,0x00000000,0x00000000}},	//   _נקוד, _судс, --, --,
   {{0x940501d4,0x00000000,0x00000000,0x00000000}},	//   _belə_, --, --, --,
   {{0xd5d40096,0x3f9e01ab,0x00000000,0x00000000}},	//   _धनंज, mstu_, --, --,
   {{0x3f9e383d,0xbd6b00d3,0xaa7b01cd,0xbf3400d1}},	// [f6f0] lstu_, _прое_, _snýs, _دروغ,
   {{0xd25700ca,0xa3b50e1f,0xe8d90129,0x0a680eed}},	//   רשמה_, _जमल_, kpụ_, урси_,
   {{0x25795735,0x6d47147c,0x00000000,0x00000000}},	//   _sèl_, moja, --, --,
   {{0x3f9ec27f,0xd5fb0174,0x257955ed,0xbd880d7f}},	//   istu_, _ndụ, _pèl_, _جنین_,
   {{0xdb070102,0x4a9a006e,0xaa9a00ca,0x33e3013c}},	//   stjó, _בירג, _בברכ, _sıx_,
   {{0x3f9ec280,0x6d4719db,0x290f00d9,0x63a5030b}},	//   kstu_, noja, īgas_, áhno,
   {{0x999200a5,0xd7e4325f,0x36d55bc7,0x25793bcb}},	//   czył_, _літо, _ковр, _wèl_,
   {{0x2903c281,0xdc0f02c6,0x25790383,0x00000000}},	//   _hoja_, _něče, _tèl_, --,
   {{0x290303ce,0xf4d930cc,0x6d47c282,0x3f9ec283}},	//   _koja_, _имаш_, koja, estu_,
   {{0x672bc284,0xdb1c045e,0x644500aa,0x0fc51aad}},	//   ligj, rtré, ühis, айон,
   {{0x29031eff,0x6d4722bb,0xdb1cc285,0x3f9ec286}},	//   _moja_, doja, stré, gstu_,
   {{0x290300c9,0xf3b6006e,0x74c70033,0x3f8300e8}},	//   _loja_, _כּדי_, _শফিউ, īju_,
   {{0xf1d9030b,0x6d473cf4,0x4cdf0033,0x28c609c4}},	//   _भनिन, foja, মানু, र्डि,
   {{0x9fc900ae,0xed5a0284,0x8af0013c,0x9f5f023c}},	//   _агка_, тог_, hmət, rytá_,
   {{0xfc032c22,0xab2a004d,0x5ecb0033,0x8fc4001c}},	//   опро, вова_, িয়ে, _هزين,
   {{0x672b01e5,0x6a860e05,0x2d9602f3,0x2bc7110d}},	//   jigj, рлаа, _крос, _लहरा,
   {{0xdca6091c,0xcb6733d0,0x8af001d4,0x290345ca}},	// [f700] _капи, рате_, dmət, _boja_,
   {{0x236f023b,0x29030b44,0x6d470143,0x00000000}},	//   _ligj_, _coja_, coja, --,
   {{0x2903023b,0x629b0350,0xcd3600d1,0x00000000}},	//   _doja_, kauo, _مرگب, --,
   {{0xeab2003f,0x99920034,0x7c3e0090,0xfc5700ca}},	//   _بعد_, rzył_, _ixpr, _כביש_,
   {{0x25a000e3,0x6f040034,0x45d6008f,0x9992007f}},	//   éil_, _moic, рцет, szył_,
   {{0xdc1900a5,0x29030052,0x6f040fdb,0xa4d402b7}},	//   _włąc, _goja_, _loic, сокі,
   {{0xf8c61860,0x6f160149,0x28c605cd,0xc7a300b4}},	//   र्णय, _olyc, र्णि, _мирк,
   {{0x31c61af2,0x25a9011d,0x2ee003a9,0x61ed7b43}},	//   асов, šala_, _naif_, _šala,
   {{0x8af001d4,0x7d010088,0xd2572ad3,0x28c6320a}},	//   lməs, ölsk, иць_, र्थि,
   {{0x30a300d6,0x6f040503,0xdce5044c,0x6b8300cd}},	//   орюв, _aoic, _mihă, _éngg,
   {{0x6d47947d,0x6f0415d3,0x3f9ec287,0x8af000a7}},	//   voja, _boic, ustu_, nməs,
   {{0x28c6000c,0x3f9e157e,0x6f04c288,0x6d47c1da}},	//   र्ति, rstu_, _coic, woja,
   {{0x6d4705d5,0x6f0400e3,0x2ee03fc8,0x63a100d4}},	//   toja, _doic, _daif_, _zvln,
   {{0x6d470138,0x644d0022,0x00000000,0x00000000}},	//   uoja, ƙait, --, --,
   {{0x6d47c289,0x9f592c0e,0x8af001d4,0x2903c28a}},	//   roja, áró_, ymət, _roja_,
   {{0x29033204,0x200f025b,0x212c0441,0x3a7522cb}},	//   _soja_, íliš_, lidh_, слар,
   {{0x6d47c28b,0x212c009b,0x290300bc,0x00000000}},	// [f710] poja, oidh_, _poja_, --,
   {{0x6cd51e49,0x7c3e0063,0x27ea01b9,0x645a0062}},	//   _اقدا, _fxpr, _brbn_, _ozti,
   {{0x29030095,0x26df0027,0x672b1c96,0x00000000}},	//   _voja_, _pauo_, tigj, --,
   {{0x63670018,0x7d0500e7,0xb95b0139,0xa3ea0179}},	//   _tűni, _hohs, _apìt, मिन_,
   {{0x8af000a7,0x645a01c8,0x7c3b0555,0x6ebc02c6}},	//   rmət, _azti, ğuru, ष्टु,
   {{0x28c605a5,0x69dd9834,0x62820af0,0x7d0501c2}},	//   र्दि, _isse, _afoo, _johs,
   {{0x3edf0065,0x443e0072,0x212c036b,0x00000000}},	//   _agọọ_, _cxt_, didh_, --,
   {{0x5c3800a1,0x443e0072,0x8af000a7,0x98ba00c6}},	//   ירון_, _dxt_, lmər, ropą_,
   {{0x6729c28c,0x212c00e3,0x752800e7,0xdb1e0212}},	//   _imej, fidh_, _fmdz, _uppå,
   {{0x6f040037,0x2ee0c28d,0xddcd010a,0xdb074880}},	//   _soic, _saif_, _eyaŋ, lujä,
   {{0x6f04008f,0x311d023a,0x20111ed4,0xf7700018}},	//   _poic, योगः_, ázi_, _راہ_,
   {{0x6d5e00dd,0x212c006b,0x69ddbfd2,0x69cf0dd9}},	//   _shpa, aidh_, _osse, _opce,
   {{0x6f048da2,0x7d0500dc,0x332d003d,0xd0e20096}},	//   _voic, _bohs, miex_, _कोकण_,
   {{0x30790130,0x332d003d,0xd5fa0327,0x8af0013c}},	//   _גאַנ, liex_, אפשר, zləd,
   {{0x69dd2a21,0x672902dd,0x629914f9,0x673b0294}},	//   _asse, _omej, _kewo, _ojuj,
   {{0x673b1a5d,0x62990c56,0x9f483d66,0x00000000}},	//   _njuj, _jewo, _orné_, --,
   {{0x62996859,0x61fb039f,0xdb0700bc,0x00000000}},	// [f720] _mewo, nxul, dujä, --,
   {{0x673b00ac,0x320d008a,0x67290051,0xd3780234}},	//   _ajuj, iyey_, _amej, _zrću_,
   {{0x69dd480e,0xa15600a1,0xa2d80442,0x409a006e}},	//   _esse, צבעה_, _मसल्, רבעס,
   {{0x7bde02e6,0xe61a0095,0x63ae0f04,0x629954d4}},	//   _ispu, лде_, _åbni, _newo,
   {{0xa50a0ac6,0xdb1c222b,0x67290090,0x00000000}},	//   леда_, ntrí, _dmej, --,
   {{0x7ae47c86,0x69c424e5,0x6729c28e,0x62990383}},	//   ldit, mtie, _emej, _aewo,
   {{0x62995e94,0x320d008a,0x61eb00f0,0xd90d0018}},	//   _bewo, eyey_, _argl, _جیل_,
   {{0x5214036a,0x69c42a28,0x61eb05db,0x212c008c}},	//   ждит, otie, _brgl, widh_,
   {{0x64a622e4,0x80dc00c7,0x629902f1,0x3a20c28f}},	//   _газа, বাস্, _dewo, nzip_,
   {{0xf8d802b0,0x69c4c290,0x7ae48740,0xd37800c4}},	//   ड़िय, itie, hdit, _tuć_,
   {{0x32ca5577,0x212c10f0,0x332d03e5,0x69c4c291}},	//   _было_, ridh_, biex_, htie,
   {{0x62995e94,0x69c4c292,0x61e4013f,0x7ae4230b}},	//   _gewo, ktie, _šilu, jdit,
   {{0x5fda2234,0x7ae43ab5,0x7bde7083,0xf8d8009f}},	//   _बनवल, ddit, _aspu, ड़ाय,
   {{0x80dc0081,0x5f943f1d,0xa3ac009f,0x7e76c293}},	//   বাহ্, _дикт, _कटा_, _egyp,
   {{0xac182cd8,0xb7b30081,0xdb1c0328,0x69c400e8}},	//   бору_, _ঘন্ট, atrí, etie,
   {{0x69c4c294,0xd13852d4,0x15fa250d,0x28c60640}},	//   ftie, lną_, ्हार_, र्सि,
   {{0x7bde9bc8,0xd04301c2,0x6f1d0076,0x69c440b1}},	// [f730] _espu, _banɗ, mhsc, gtie,
   {{0x67293e23,0x2918009c,0xd138007f,0x7ae4c295}},	//   _smej, _clra_, nną_, adit,
   {{0x69c4525b,0x7ae40090,0xb9010abe,0x80ca0096}},	//   atie, bdit, _दस_, त्ये,
   {{0x69c4bc9a,0xd3666e50,0xbebb0381,0x7b2c013c}},	//   btie, _زه_, ciët, nşul,
   {{0xd2460e8c,0x69c43db6,0xf7700f43,0xf8a900cd}},	//   _آن_, ctie, رام_, _نگاه_,
   {{0x25a98076,0xd04301c2,0xd1380034,0x798d4944}},	//   šalo_, _ganɗ, jną_, mpaw,
   {{0xd13800a5,0x629905aa,0x672902a1,0x3ea93177}},	//   dną_, _pewo, _tmej, _odat_,
   {{0x17680dc9,0x130900d6,0xd138013f,0x6729c296}},	//   _груп_, рний_, eną_, _umej,
   {{0x65943fea,0x28c61178,0xdc050179,0xdb1c0231}},	//   _нату, र्वि, रहुड_, ltrã,
   {{0xaca40294,0x61eb0117,0x61fb62f6,0xe9df0206}},	//   twọk, _vrgl, rxul, _msú_,
   {{0x69c402a7,0x61e43ea4,0xf8b20327,0x657b007b}},	//   ztie, _šilt, ושי_, _huuh,
   {{0x798d07ac,0x657b6f7b,0x69c4c297,0xd138007f}},	//   kpaw, _kuuh, ytie, aną_,
   {{0xa3e13245,0x69c403e5,0xd138007f,0x26cd033c}},	//   दिक_, xtie, bną_, _mbeo_,
   {{0x3ea905fe,0x3f660257,0x61e90201,0x63770134}},	//   _edat_, _cœur_, mvel, _ụnya,
   {{0x61e902fd,0xeb9a01ce,0x3ea902a1,0xda870174}},	//   lvel, риб_, _fdat_, _ụlọa,
   {{0x6f1d01bf,0xa3ea046e,0x16090ff9,0x6ec109c4}},	//   chsc, मित_, वहार_, _वायु,
   {{0xfce607b8,0xf2d213b6,0x61e95b2b,0x69c4a9bf}},	// [f740] _допо, וען_, nvel, utie,
   {{0xe8f752a5,0x7ae4023b,0x61e91f6d,0xb8560284}},	//   олу_, sdit, ivel, ођењ,
   {{0x28c605a5,0x7bde005f,0x61e9b9dd,0x00000000}},	//   र्षि, _uspu, hvel, --,
   {{0x69c4c298,0xd04301c2,0x61e975ad,0x657b0188}},	//   ptie, _wanɗ, kvel, _buuh,
   {{0xbebb023b,0xe5a3002d,0xd13829aa,0x2ba800a4}},	//   shëg, дичи, yną_, गळवा,
   {{0x28c645c8,0x61e90103,0xb7da0018,0xbebb000b}},	//   र्शि, dvel, _پورا_, niër,
   {{0x61e901d0,0x00000000,0x00000000,0x00000000}},	//   evel, --, --, --,
   {{0xf1a63e04,0xe73a013d,0x65a30134,0xd1380034}},	//   орон, _теб_, _ọher, wną_,
   {{0xd1380034,0x61e96132,0x00000000,0x00000000}},	//   tną_, gvel, --, --,
   {{0x4fc600c2,0x00000000,0x00000000,0x00000000}},	//   осма, --, --, --,
   {{0x6f1d5ac1,0xbebb0a88,0xd13829aa,0xf2ac0033}},	//   thsc, diër, rną_, ক্ষণ,
   {{0xd1380034,0x3f66020d,0xd12f0281,0x9c8700d4}},	//   sną_, _sœur_, _یمن_, _ovčí,
   {{0x63b8025b,0x224b01bf,0x63750138,0xbebb01cb}},	//   luvn, ückt_, _išna, fiër,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc04f1557,0x7c220022,0x2a7000a7,0x00000000}},	//   _ці_, _ƙora, ənbə_, --,
   {{0x3ea9078e,0xdb070206,0x00000000,0x00000000}},	//   _udat_, lujú, --, --,
   {{0xbebb0313,0x29010372,0xdce70a60,0x00000000}},	// [f750] biër, tjha_, şlıg, --,
   {{0x2907003e,0x28c61f88,0x657b007b,0xbebb01cb}},	//   ðna_, र्लि, _ruuh, ciër,
   {{0x61e9c299,0x657b0302,0xbf7800fe,0x5ede0033}},	//   zvel, _suuh, _đuợc_, যারে,
   {{0x63b85d1a,0x5ead0081,0xdb070220,0x64410063}},	//   duvn, ট্রে, hujú, _rxli,
   {{0xdb070031,0xd6180190,0x7bc74b79,0xbafa00ca}},	//   kujú, يتها_, ltju, _ההרש,
   {{0x03953c7e,0x2db800a1,0xb4d500aa,0xb97a00ca}},	//   прия, קלון_, िजे_, _לנשי,
   {{0x8ccd000f,0xdb070181,0x7bc7c29a,0xdb1c7052}},	//   द्यो, dujú, ntju, ltrá,
   {{0x11d900e3,0x61e9c29b,0xd3d80037,0xc7b20266}},	//   موعة_, tvel, تبها_, _רבן_,
   {{0xdb1c455c,0x61e90381,0x00000000,0x00000000}},	//   ntrá, uvel, --, --,
   {{0x44b48329,0x7bc50415,0x00000000,0x00000000}},	//   _обус, _oqhu, --, --,
   {{0x61e98798,0x7bc501fa,0xdee63a7a,0x777c03be}},	//   svel, _nqhu, пони, _xurx,
   {{0xdb1c0146,0xdbd00146,0xba3b0f5a,0x224b042c}},	//   ktrá, užív, _geïg, ücks_,
   {{0xee3700d6,0x5ede0033,0x7bc50415,0x427a00ca}},	//   зня_, যালে, _aqhu, _האנג,
   {{0x4ace02d5,0xf1b90218,0xdb070031,0x3f77020a}},	//   ह्नव, muš_, cujú, _băut_,
   {{0xbebb0371,0xeb970b9e,0x00000000,0x00000000}},	//   riër, зис_, --, --,
   {{0xbebb0313,0xaca40139,0x00000000,0x00000000}},	//   siër, _iwọw, --, --,
   {{0x61ed02e6,0x25a908a9,0x3b07078b,0xf1b9c29c}},	// [f760] _šalj, šalj_, чето_, nuš_,
   {{0xdb1c0428,0x3ea27377,0xb4d500bc,0x00000000}},	//   strà, lakt_, िजो_, --,
   {{0x777c008c,0x6d4e0ac1,0x7e60042c,0xa84a0076}},	//   _qurx, moba, ümpf, حلام_,
   {{0xdd8f001c,0xdb070031,0x2c0900b6,0x940c013c}},	//   _جوی_, zujú, सहरू_, _gedə_,
   {{0x5fdd0971,0x50bd0179,0x7ae61e8f,0x00000000}},	//   _फैसल, ्भाष, _iakt, --,
   {{0x3ea2bf1a,0x07a60566,0x00000000,0x00000000}},	//   hakt_, _нагн, --, --,
   {{0xdb070031,0x00000000,0x00000000,0x00000000}},	//   vujú, --, --, --,
   {{0x66e308b4,0xa6b50084,0x7ae613f8,0xa686672f}},	//   _поса, _осущ, _jakt, _хлад,
   {{0xcad700f5,0x6d4ec29d,0x7ae6a8cd,0x63b80579}},	//   לוקת_, koba, _makt, suvn,
   {{0x290a0af0,0xf55a00e3,0x28cf0592,0xdced0090}},	//   _joba_, _الطب_, स्पि, _iwaħ,
   {{0x6d4e55f1,0x25a60270,0xdb070220,0x3f59c29e}},	//   doba, lsol_, rujú, séum_,
   {{0x3f8a0b4b,0x7ae616d1,0x290a5a0e,0xc7b300a1}},	//   ību_, _nakt, _loba_, עבר_,
   {{0x6d4e5a96,0xdb070220,0xdced02a1,0x290a010a}},	//   foba, pujú, _jwaħ, _ooba_,
   {{0x6d4e855f,0x6018013d,0x61e2188c,0x98ba00b6}},	//   goba, _моля_, _isol, ropě_,
   {{0x7ae64136,0x4900030b,0x3d0d0aa1,0xd24d1aaa}},	//   _bakt, रानो_, _सकीं_, _مچی_,
   {{0xe7f00efb,0x7ae600dd,0x60daa719,0x7bc7c29f}},	//   घटना_, _cakt, letm, rtju,
   {{0x7ae6c2a0,0x6d4ec2a1,0x7bc707ee,0x61e202a1}},	// [f770] _dakt, boba, stju, _jsol,
   {{0x290a1fb5,0x60da01e8,0x61ed0aa8,0x61e2198d}},	//   _coba_, netm, _šalk, _msol,
   {{0xdb1cc2a2,0xdbdc037a,0x8af000a7,0xf1b90206}},	//   strá, báñe, mlən, zuš_,
   {{0x61e25d33,0x8af0013c,0x00000000,0x00000000}},	//   _osol, llən, --, --,
   {{0x84e50396,0xa509015f,0x63650072,0x06cc0033}},	//   долж, жела_, lóng, _রোহি,
   {{0x3ea212f7,0x7ae65c32,0x8af0013c,0x00000000}},	//   zakt_, _zakt, nlən, --,
   {{0x67d4c2a3,0x61e224df,0xa3d20b1b,0x7ae60233}},	//   _пору, _asol, војч, _yakt,
   {{0x68e7c2a4,0x6d4e2ad2,0x27f80146,0x63a80167}},	//   _hajd, zoba, šený_, _dvdn,
   {{0xc245249c,0x6d4e339e,0x3ea20351,0x8af000a7}},	//   ьник, yoba, vakt_, klən,
   {{0x80bd009d,0xb6030094,0x60420134,0x68e70090}},	//   _शाळे, _vláč, _ọmal, _jajd,
   {{0x3ea24559,0x68e7c2a5,0x6d4e05db,0x61e20415}},	//   takt_, _majd, voba, _esol,
   {{0x61e202a1,0x6fbf0096,0x63a500d2,0x52159032}},	//   _fsol, लंबू, áhnu, _одет,
   {{0x6d4e3df1,0x7ae6c2a6,0x3ea20429,0x8af000a7}},	//   toba, _rakt, rakt_, flən,
   {{0x68e718f9,0x7ae63a88,0x28cf218b,0x3ea22fa2}},	//   _najd, _sakt, स्मि, sakt_,
   {{0x6d4e2eee,0x290a15f1,0x7ae600dd,0x3ea20126}},	//   roba, _roba_, _pakt, pakt_,
   {{0x6d4ec2a7,0xc05200a1,0x8f9a03c2,0xbec801d3}},	//   soba, _שזה_, _ויקי, _brīž,
   {{0x7ae6c2a8,0xc33200a1,0x68e7009e,0x6d4e024a}},	// [f780] _vakt, דון_, _bajd, poba,
   {{0x7ae603b4,0x68e7023e,0x6d4e6851,0x3ea00a47}},	//   _wakt, _cajd, qoba, _heit_,
   {{0x7ae6c2a9,0x3ce70592,0x68e702ef,0x46ea30cf}},	//   _takt, _छोटे_, _dajd, жден_,
   {{0x3a3f1912,0x7ae6c2aa,0x65a30174,0x290a083e}},	//   _župe_, _uakt, _ọhar, _woba_,
   {{0xd6e000c7,0x68e71a0d,0xa5da0e11,0x60da0092}},	//   ণালয, _fajd, تبار_, yetm,
   {{0xa3ea0d0b,0x3ea00088,0xa5070291,0x2d801497}},	//   मिल_, _leit_, деља_, _muie_,
   {{0x25a64d6e,0xdb1c052f,0x2d8001cb,0x61e2009e}},	//   ssol_, rtræ, _luie_, _ssol,
   {{0xdb1c34c9,0x8af00092,0x3ea058b5,0x6aa403bc}},	//   stræ, zlən, _neit_, naif,
   {{0xdb1c23bc,0x67220239,0x81d60033,0x60da2115}},	//   mträ, mhoj, ায়ন_, tetm,
   {{0x6aa47e48,0xdb1c09b5,0x3d0da95c,0x00000000}},	//   haif, lträ, _सकें_, --,
   {{0x2018c2ab,0x60da01e8,0x3d020455,0x39840212}},	//   ári_, retm, शाने_, _lös_,
   {{0xdb1c6986,0x7d1e1271,0x3ea001ec,0x73360037}},	//   nträ, _alps, _ceit_, _غرائ,
   {{0x61e20201,0x3ea00441,0x8af000a7,0xdb1c0364}},	//   _usol, _deit_, tlən, iträ,
   {{0x2d80084e,0x660201ff,0x00000000,0x00000000}},	//   _duie_, ixok, --, --,
   {{0x3ea02088,0x69a4121d,0xead56bef,0x8af000a7}},	//   _feit_, _चौबी, новь, rlən,
   {{0x61ed01b3,0xa3b60034,0x80ca2166,0x8af000a7}},	//   _šali, _जिन_, त्रे, slən,
   {{0x68e7c2ac,0xf1bc0033,0x6722c2ad,0xdb1c227a}},	// [f790] _pajd, _অনুভ, dhoj, dträ,
   {{0x3ea002dc,0x6f0d2628,0x8af0013c,0x80dc0033}},	//   _zeit_, _hoac, lləl, বাক্,
   {{0x656f028d,0xdb1c0364,0x6b7500d3,0x6aa40027}},	//   _èchi, fträ, _плоу, baif,
   {{0x19950fdf,0x6f0dc2ae,0x81d50033,0x38b50065}},	//   _памя, _joac, হিত_, _bùrà_,
   {{0x25a9c2af,0x2ee906ee,0x68e700dc,0x16160e46}},	//   éal_, _maaf_, _tajd, थनगर_,
   {{0x2edc07e2,0x2366025b,0x9f9f02ac,0x00000000}},	//   _बस्त, _ahoj_, _wéét_, --,
   {{0xc7c4125c,0x437500ae,0x78a50085,0x7d08042c}},	//   _исти, нуит, mahv, ödsi,
   {{0x2366006c,0x67220239,0x645f00a7,0xc2c50037}},	//   _choj_, choj, əqil, ريخي,
   {{0x28cf0d61,0xe1f1006f,0x26dd0c56,0x32190146}},	//   स्थि, اسب_, mewo_, ásy_,
   {{0x3ea002dc,0x26dd3165,0x6aa47074,0x2d8002ac}},	//   _seit_, lewo_, zaif, _ruie_,
   {{0x6375007e,0x6f0d19f0,0xdb1c0429,0x00000000}},	//   _ušno, _boac, ltrå, --,
   {{0x28cf000c,0xe1f122aa,0x2ee9026d,0x00000000}},	//   स्ति, _مست_, _caaf_, --,
   {{0x3ea023ff,0xdb1c6265,0x2d80037a,0x78a5007b}},	//   _veit_, ntrå, _quie_, kahv,
   {{0x3ea001bf,0xc0e21f46,0x2b420063,0x67220052}},	//   _weit_, _бошк, _sjkc_, zhoj,
   {{0x6aa41ee3,0x6c360037,0x3ea04ead,0x26dd06b0}},	//   taif, رفرا, _teit_, kewo_,
   {{0x2ee93584,0x628957be,0x8af00092,0xdb1c0216}},	//   _gaaf_, nceo, lməz, murë,
   {{0xe9d73e2f,0x6df300e3,0x6aa42425,0xcdaa1f11}},	// [f7a0] нкт_, _مكيا, raif, _عهده_,
   {{0x7e64505b,0xebe63f98,0x30bd0033,0xd5da007f}},	//   _izip, _зооп, _অসুস, _मैगज,
   {{0xe50300c3,0xdb1c17a5,0x67220216,0x7b3700c4}},	//   लानि_, tträ, thoj, tćut,
   {{0xe5c60ed8,0x660201e9,0x6f0d002b,0xf8b00018}},	//   еско, txok, _xoac, _چکا_,
   {{0xdb1c3224,0xceb3040a,0x8af000a7,0x6722007b}},	//   rträ, ריד_, nləm, rhoj,
   {{0x53e60157,0x2b40c2b0,0xdb1cc2b1,0x6722681c}},	//   ециа, lnic_, strä, shoj,
   {{0xd94308a4,0xbebb023b,0xdb1c0212,0x26dd0e62}},	//   _сери, dhën, pträ, bewo_,
   {{0x2b4074b9,0x8af000a7,0xdb1c0052,0x6d5c02db}},	//   nnic_, kləm, durë, hlra,
   {{0x7e640134,0x2b40a26a,0x00000000,0x00000000}},	//   _nzip, inic_, --, --,
   {{0x2b40c2b2,0x6f0d8c6f,0x00000000,0x00000000}},	//   hnic_, _soac, --, --,
   {{0x44386fb3,0x6f0d5202,0x2366006c,0x6e9500a9}},	//   _är_, _poac, _thoj_, кину,
   {{0x78a500cc,0x2b403e94,0x6d5c02db,0x00000000}},	//   zahv, jnic_, elra, --,
   {{0xe33700c1,0x657a09e7,0x67d302c6,0x61ed00d4}},	//   _אראפ_, _kith, mějš, _šalv,
   {{0x63650081,0x645a0146,0x645600a7,0x657a00bd}},	//   róne, _kyti, əyir, _jith,
   {{0x8af00092,0x657ac2b3,0x602600fd,0x7e64505b}},	//   lməy, _mith, _démé, _ezip,
   {{0x67d3000d,0x3df5661b,0xdbdc0143,0x6d5c2bc0}},	//   nějš, _азис, _cáña, alra,
   {{0x3a751469,0x7b6433fd,0x645a0138,0x8af000a7}},	// [f7b0] тлар, утре, _lyti, nməy,
   {{0x657ac2b4,0xb4df009d,0x52dd02d5,0x97a71b60}},	//   _nith, _तसे_, _मस्स, ердл,
   {{0x78a513e1,0xe8df0023,0x81d60033,0x645a676b}},	//   rahv, _ngục_, াটি_, _nyti,
   {{0xf7700dd0,0x657a4450,0x8ccd07e2,0x2b4076f5}},	//   مان_, _aith, द्रो, cnic_,
   {{0x645a0154,0x657a09f7,0x7aed00ae,0x6124022b}},	//   _ayti, _bith, mdat, _gòlg,
   {{0x7aedc2b5,0x657a00cd,0x81d60081,0xbc38001c}},	//   ldat, _cith, াটা_, _آسیا_,
   {{0x657a01b5,0x7aed12e7,0xdb1c0bc6,0x8af000a7}},	//   _dith, odat, strå, zləm,
   {{0xf99f0c56,0x657a1fdd,0x527510b8,0x28c70d75}},	//   _kwè_, _eith, купу, _लाडि,
   {{0x657a036b,0xf99f06a3,0x645a861b,0x62890755}},	//   _fith, _jwè_, _eyti, rceo,
   {{0xdb1c023b,0x9f5f0094,0x7aeda53c,0x62890076}},	//   turë, rytý_, hdat, sceo,
   {{0x7afd355f,0x28c63fac,0x69cd13e1,0x765b0167}},	//   _onst, र्टि, htae, _hyuy,
   {{0xa29500d6,0x657a0201,0x765b0167,0xfaff023b}},	//   _раді, _zith, _kyuy, _shën_,
   {{0xd00e010d,0x2b40c2b6,0xf99f05aa,0x00000000}},	//   ملی_, vnic_, _nwè_, --,
   {{0x7afd4435,0xdbdc01cd,0xe0d904a1,0x7aed0381}},	//   _anst, _báða, _цвк_, edat,
   {{0xdca330fd,0x2b40c2b7,0xfaa6083c,0xf99f83f5}},	//   раси, tnic_, каво, _awè_,
   {{0x7aed00a6,0xf99f06a3,0x3a3f0234,0x0b43ad7f}},	//   gdat, _bwè_, _župa_, ансн,
   {{0xe8ea00d3,0x2b40c2b8,0x1ce70103,0xdc3c0206}},	// [f7c0] ммад_, rnic_, رکیٹ_, _ušľa,
   {{0x7afdc2b9,0x2b40c2ba,0x394100f9,0xa9235cac}},	//   _enst, snic_, gnhs_, адул,
   {{0x657a3470,0x765b03e3,0x25adc2bb,0x2b40033b}},	//   _rith, _ayuy, _avel_, pnic_,
   {{0x28c608c0,0x657a2cff,0xeabf009c,0x645a7daf}},	//   र्जि, _sith, _clùd_, _ryti,
   {{0x77690694,0x67d3030b,0x657ac2bc,0xd70700e5}},	//   _dhex, vějš, _pith, ънце_,
   {{0xd9461896,0x5ede0033,0x1ace00b6,0x00000000}},	//   _реги, যাটে, ह्रथ, --,
   {{0xc7a345f9,0x7bce5482,0x67d300b6,0x657ac2bd}},	//   _виск, ntbu, tějš, _vith,
   {{0x657a0054,0x645a40a6,0x77690090,0x8af000a7}},	//   _with, _vyti, _ghex, tməy,
   {{0xe737037e,0x2d92010a,0xdb1c014b,0x00000000}},	//   _рет_, _ntye_, guré, --,
   {{0x8af00092,0x657a0a9f,0x7bce533d,0x00000000}},	//   rməy, _uith, ktbu, --,
   {{0x61ed6431,0x94061f11,0x2d92010a,0x7aed0034}},	//   _šalt, _جواه, _atye_, ydat,
   {{0x612406a3,0x7aed01c0,0xdbdc003e,0x777b40a0}},	//   _sòld, xdat, _ráða, _xiux,
   {{0xa3ea0557,0xa3de00a5,0x57df0e4c,0x05b80285}},	//   मिक_, दौर_, _नन्ह, उंटब,
   {{0xc27b0c6a,0xba3b0a9f,0x7aed0113,0x39ac00c3}},	//   _חרדי, _beïn, wdat, _चिड़ि,
   {{0x612400ee,0x46b4049d,0x636501f9,0xd138548b}},	//   _còle, ुलाह, lóna, mią_,
   {{0x28c6007d,0xc8c6303f,0xd1388a2d,0x69cd0084}},	//   र्घि, र्घट, lią_, ttae,
   {{0x7aed15ec,0x61ed0072,0x28a700c2,0x58d5247a}},	// [f7d0] rdat, _áalt, вшег, лоат,
   {{0x7aed3651,0x69cd01e9,0xd1381c8a,0x6f1d0381}},	//   sdat, rtae, nią_, lksc,
   {{0x7aedc2be,0x76b94170,0xba3b03ee,0x69cd68ff}},	//   pdat, елер_, _geïn, stae,
   {{0x6f1d1d7f,0x69cd0076,0x7afd0703,0xf99f0154}},	//   nksc, ptae, _unst, _twè_,
   {{0xd138013f,0x6365003e,0xaa67bc1c,0xb0c20285}},	//   kią_, jóna, _шток, _शांग,
   {{0xb4ad0096,0xd469002d,0x044512d3,0xdb07034f}},	//   कणे_, ниле_, лелн, pujó,
   {{0x8882015a,0x386601c2,0x04b4013f,0x00000000}},	//   _ایمن, ƙora_, рсія, --,
   {{0x6d55177c,0xdb1c0482,0x22400095,0x6f1d029a}},	//   hoza, turé, _žika_, jksc,
   {{0xa3e3000f,0x78b20088,0x6d55c2bf,0x3f59016d}},	//   _पैर_, _ákvö, koza, héus_,
   {{0x6009108f,0x410500c2,0x6f1d029a,0xbebb0052}},	//   еном_, узов, eksc, shël,
   {{0x29110858,0x3ea623b9,0xdb1c00fd,0x6d550103}},	//   _moza_, линг, suré, doza,
   {{0x51f50260,0xdb1cc2c0,0xba3b1cab,0x929d007f}},	//   _مستر, strú, _reïn, ykły,
   {{0x2d840257,0xd1380034,0x629b822d,0xef17007b}},	//   ême_, bią_, mbuo, умя_,
   {{0xfaff023b,0x7bce5de0,0xd1380034,0x7c3a0031}},	//   _anë_, ttbu, cią_, útro,
   {{0x629b00fe,0x00000000,0x00000000,0x00000000}},	//   obuo, --, --, --,
   {{0xa3b600a5,0xba3b0472,0x7d1c1711,0x6f1d0364}},	//   _जिस_, _veïn, skrs, cksc,
   {{0x7bce5b5a,0x80ca00b6,0x00000000,0x00000000}},	// [f7e0] stbu, त्के, --, --,
   {{0x28cf0b7f,0x8ca5007f,0xfaff0216,0x00000000}},	//   स्लि, करणो, _enë_, --,
   {{0x9b460bf4,0x00000000,0x00000000,0x00000000}},	//   _مندو, --, --, --,
   {{0x273b0294,0x00000000,0x00000000,0x00000000}},	//   ụnna_, --, --, --,
   {{0x363600e3,0x35b6413c,0xfdf40557,0x75380a39}},	//   دراس, ущес, इटिस_, tivz,
   {{0xb5fd033b,0x00000000,0x00000000,0x00000000}},	//   _izšl, --, --, --,
   {{0xd37a4000,0x186723e3,0xfaff023b,0x8cd60034}},	//   нчи_, _бари_, _ynë_, म्यो,
   {{0xd3787a1d,0x7986563a,0xdc0800d9,0xd1380034}},	//   _opće_, _kukw, dēļa, wią_,
   {{0x79860010,0x6d553121,0x6aa6009a,0xd9f60179}},	//   _jukw, yoza, _mekf, ीमित_,
   {{0x8af00092,0x7986170c,0x636542bc,0x6b8301dc}},	//   sləh, _mukw, róna, _èngg,
   {{0xd13852ce,0x6d550106,0x79863121,0x68eebfac}},	//   rią_, voza, _lukw, _mabd,
   {{0x68eec2c1,0xd138013f,0xd24f00cd,0x6d555b31}},	//   _labd, sią_, _کنه_, woza,
   {{0x628276b0,0x6f1d5530,0x79860079,0x83530103}},	//   _igoo, rksc, _nukw, _اپنا,
   {{0xceb40092,0x25ec10e9,0xdfec25af,0x00000000}},	//   _edə_, _आईनी_, _जनपद_, --,
   {{0x6d550018,0x2911393c,0xa3ea0f35,0xaca30174}},	//   roza, _roza_, मिट_, _ngụg,
   {{0x79866698,0xab6203a3,0x6d5546e1,0x00000000}},	//   _bukw, şünc, soza, --,
   {{0x2911c2c2,0xaca30174,0x798601c2,0xba3b000b}},	// [f7f0] _poza_, _agụg, _cukw, _geïl,
   {{0x68ee025e,0x2abb0af0,0x798602a4,0x3f590131}},	//   _cabd, _bàbà_, _dukw, péus_,
   {{0x29110e94,0x1a6500cd,0x7aee00c2,0x7d1a0212}},	//   _voza_, _چیزی_, öntä, ötse,
   {{0xfaff01e5,0xef1f0587,0x36d50b1b,0x628247fd}},	//   _unë_, nkü_, родр, _ngoo,
   {{0x660506d8,0x63650220,0x79862cd0,0x3f66020d}},	//   рпла, fónn, _gukw, _vœux_,
   {{0x68ee008a,0x62823634,0x7aef03a8,0x29110350}},	//   _gabd, _agoo, _hact, _uoza_,
   {{0x629b0227,0x634101d3,0x1b740504,0x5eab0033}},	//   tbuo, lēni, _خدیج, _কানে,
   {{0xdc2103e5,0x11d90037,0x60d8010a,0x78a72ceb}},	//   _aċċe, نوعة_, _abvm, _hejv,
   {{0x7aef01f7,0x63a40ca7,0x13060084,0x629b013f}},	//   _mact, ćina, рный_, rbuo,
   {{0xdb1c038c,0x69dd00dc,0x62820172,0x8574263d}},	//   strø, _mpse, _egoo, _глух,
   {{0x3eab22d4,0x80a70081,0x5f06888a,0x78a70d62}},	//   fact_, _খাদ্, азна, _mejv,
   {{0x539a00a1,0x25a0002d,0x850300aa,0xdc21003d}},	//   _ייעו, ţile_, लावट_, _eċċe,
   {{0xe3c70081,0x63650e4b,0x00000000,0x00000000}},	//   _শনিব, lóno, --, --,
   {{0x59a92337,0x78a7000d,0xdca32139,0x79864686}},	//   _चौधर, _nejv, жари, _rukw,
   {{0xbb560037,0x68ee00ae,0x798601c2,0xb8820094}},	//   لنسب, _rabd, _sukw, šíko,
   {{0x7aefc2c3,0x68ee5d10,0x63650094,0x92900032}},	//   _cact, _sabd, zónn, _iṣẹ́_,

   {{0x67f0026e,0x00000000,0x00000000,0x00000000}},	// [f800] kójá, --, --, --,
   {{0x3f87393f,0x68ee8a4b,0xba3b1030,0x090300ae}},	//   _kunu_, _qabd, _geïm, опун,
   {{0x2ba5000f,0x7aef1173,0x78a7ad31,0xc6a60360}},	//   गीदा, _fact, _dejv, арли,
   {{0x7a2c00fd,0x3f87003e,0x7bde0078,0x7986c2c4}},	//   _côté, _munu_, _ippu, _tukw,
   {{0x55060832,0x1a9b00c1,0x68ee01c2,0x7ae4c2c5}},	//   ичка, _ביכע, _tabd, meit,
   {{0x7ae4c2c6,0x63650220,0x38bc0065,0x291c2dd3}},	//   leit, fóno, _dárà_, övad_,
   {{0x66e60e45,0xb2260088,0x69c403ae,0x61eb03a8}},	//   _кова, kvæð, luie, _asgl,
   {{0xb024011b,0x7ae40aca,0xdb1c0216,0x6b8303a9}},	//   _ngườ, neit, drrë, _ènge,
   {{0x69c4c2ae,0x00000000,0x00000000,0x00000000}},	//   nuie, --, --, --,
   {{0x3f8707d1,0x7bde0ea0,0x7ae4c2c7,0xdb1c058a}},	//   _bunu_, _oppu, heit, durí,
   {{0x7ae4c2c8,0x61eb0472,0x776203be,0x25ec0251}},	//   keit, _esgl, olox, _आईडी_,
   {{0x7ae48a24,0xe29a4f07,0x61248d84,0x69c4c2c9}},	//   jeit, _рад_, _dòla, kuie,
   {{0x7bdec2ca,0x3eabc2cb,0x7ae400f0,0xc8c7049d}},	//   _appu, ract_, deit, _लालट,
   {{0x2d990d4d,0x3f870234,0x69c4044c,0x00000000}},	//   rpse_, _funu_, duie, --,
   {{0x7ae4c2cc,0x06bc00c7,0x7aef04d3,0x0b882549}},	//   feit, _ইউনি, _pact, исти_,
   {{0x7ae401e9,0x69dd00e7,0x307b0327,0x00000000}},	//   geit, _ppse, _באונ, --,
   {{0x69c40eb8,0x7bde0110,0xe0ea0139,0x636500d4}},	// [f810] guie, _eppu, _gbòò_, zóno,
   {{0x3ea900ca,0x256901ab,0xdb1c044c,0x00000000}},	//   _heat_, kúla_, gurâ, --,
   {{0x7ae4c2cd,0x6d4702e6,0x3ea900dc,0x78a702b6}},	//   beit, mnja, _keat_, _vejv,
   {{0x7ae40bfe,0x14c9009d,0x69c420ce,0x6d4730a0}},	//   ceit, _राहण, buie, lnja,
   {{0x6aad0808,0x69c400d3,0x8af000a7,0x67f00103}},	//   maaf, cuie, tləv, tójá,
   {{0x3ea90fab,0x6365c2ce,0x6aad3992,0x6d47a998}},	//   _leat_, tóno, laaf, nnja,
   {{0xd7c900cd,0x62860031,0x2d8105db,0x2903063d}},	//   _حوزه_, ľkon, _mihe_, _inja_,
   {{0x68e50084,0x6aad68f7,0x77620072,0x27fc02b6}},	//   lehd, naaf, clox, ævne_,
   {{0x65941994,0x6d4725e2,0x612401f7,0x3f87c2cf}},	//   _мату, knja, _sòla, _sunu_,
   {{0x7ae402e2,0x3f870995,0x8af00092,0x6aad32c1}},	//   zeit, _punu_, llət, haaf,
   {{0x6d470335,0x14190037,0x7ae41134,0x3ea906dc}},	//   dnja, _حياة_, yeit, _beat_,
   {{0x7ae408a8,0x2d8100c2,0x643a006e,0x6d4718f0}},	//   xeit, _aihe_, _געענ, enja,
   {{0x7ae4c2d0,0x6aad008a,0x32090511,0x2d8102a4}},	//   veit, daaf, _çay_, _bihe_,
   {{0x2d9e0074,0x409500e3,0x7ae420a0,0x61e925aa}},	//   ďte_, _الغر, weit, mwel,
   {{0x7ae47b60,0x61e9c2d1,0xab2a0058,0xdb0a0146}},	//   teit, lwel, гова_, šník,
   {{0x69c4c2d2,0x6aad0b8e,0x6d4758b2,0x3ea901b9}},	//   tuie, gaaf, anja, _geat_,
   {{0x7ae4c2d3,0x61e94e95,0x6d47005f,0x81d50033}},	// [f820] reit, nwel, bnja, হিক_,
   {{0x7ae4c2d4,0x2d81092f,0x6d470039,0x69c4c2d5}},	//   seit, _gihe_, cnja, ruie,
   {{0x7ae4c2d6,0x61e9c2d7,0x6d5e0174,0x6f04c2d8}},	//   peit, hwel, _ikpa, _knic,
   {{0x61e9c2d9,0xd3780ac3,0x6aad250c,0x290300c4}},	//   kwel, _opća_, caaf, _enja_,
   {{0x69c4184f,0x6f041077,0x2d810027,0x850306eb}},	//   quie, _mnic, _yihe_, लांट_,
   {{0x25690037,0x6f1606b0,0x00000000,0x00000000}},	//   túla_, _loyc, --, --,
   {{0x6f04c2da,0x63a4005f,0x6d5e00ac,0x33260113}},	//   _onic, ćino, _mkpa, _plox_,
   {{0x070c04dd,0x6d4708a9,0x4900030b,0x62860220}},	//   _सचिव_, znja, राको_, ľkoo,
   {{0x28cfc2db,0x442000d9,0x8af000a7,0x61e94a2a}},	//   स्कि, ņi_, lləs, gwel,
   {{0x6f049126,0x6722c2dc,0x644f0034,0x6d5e0294}},	//   _anic, lkoj, _ście, _nkpa,
   {{0x6d4703f1,0xb5fd0579,0xf1b90220,0x2d810027}},	//   vnja, _vyše, vyše_, _rihe_,
   {{0x0dcb2c13,0x6d5e00ac,0x6aad008a,0x6722055b}},	//   луги_, _akpa, xaaf, nkoj,
   {{0xe287010d,0x61e90201,0x5eab0033,0x395a219b}},	//   _اطمی, cwel, _কাদে, kops_,
   {{0x303900cd,0xdb1cc2dd,0x6722088a,0xc8c73613}},	//   اتیک_, ktró, hkoj, _लाइट,
   {{0xc2eb0081,0x67220084,0x6aad0051,0x40340dde}},	//   কারি_, kkoj, taaf, _фейс,
   {{0x6d4726dd,0x6f04009c,0x61240154,0x00000000}},	//   snja, _gnic, _kòlo, --,
   {{0x8af001d4,0x6aad74c0,0x201e0138,0xa2d0349f}},	// [f830] vlət, raaf, lyti_, _धान्,
   {{0x6d40025a,0x213e692a,0xa3e80789,0x7e6d0634}},	//   émat, nith_, यबा_, _izap,
   {{0x61e90201,0xdbe30072,0x61240154,0x201e00c6}},	//   zwel, _téña, _lòlo, nyti_,
   {{0x95990528,0x61e96d6a,0x7bc75582,0xcf9300c1}},	//   атку_, ywel, muju, לטע_,
   {{0xd5bb3566,0x7bd50634,0x7bc70e22,0x62860206}},	//   усе_, ltzu, luju, ľkol,
   {{0x201e01b3,0x03950927,0x15a800e5,0x550301e4}},	//   kyti_, ория, съци_, लाइए_,
   {{0xdb1c11c4,0x7bd502a7,0x8af001d4,0x213e2cc7}},	//   ctró, ntzu, mlər, dith_,
   {{0x201e01b3,0x8af001d4,0xb0650084,0x7d17002b}},	//   dyti_, llər, hdää, _loxs,
   {{0x7bc7c2de,0x61e924e7,0xe61300e3,0x612400ee}},	//   huju, uwel, _عشر_, _còlo,
   {{0x8af001d4,0x61e95c63,0x7bc77a06,0x6f040e37}},	//   nlər, rwel, kuju, _snic,
   {{0xa06916d9,0x61e9c2df,0x201e0138,0xa3b6009f}},	//   рана_, swel, gyti_, _जिए_,
   {{0xdb1c0e4b,0x2b490095,0x7d0500fe,0x7bc73733}},	//   kurá, jnac_, _anhs, duju,
   {{0x926700bf,0x8af001d4,0x7d1718ef,0x20d5004d}},	//   _ادام, klər, _boxs, _дійс,
   {{0x53dd000c,0xdb1cc2e0,0x672902a1,0x7bd5042c}},	//   _महाश, strü, _llej, ftzu,
   {{0x672912fb,0x8af00092,0x3079006e,0xe8df0023}},	//   _olej, dlər, _דאַנ, _ngốc_,
   {{0x2b490f01,0x6f04451e,0xab660426,0x5f760604}},	//   gnac_, _unic, івал, _باتر,
   {{0x8af00092,0xbebb0052,0xdb1cc2e1,0x612d0503}},	// [f840] flər, thëv, gurá, _cúlg,
   {{0x6729c2e2,0xd9100688,0x673b6af6,0xb4e85ed7}},	//   _alej, ریز_, _amuj, _बसे_,
   {{0x6d5c1b9e,0x6729c2e3,0x672200c2,0xdb0702b6}},	//   mora, _blej, tkoj, dsjæ,
   {{0xd6d900d6,0x2c17030b,0xadc30af0,0x6d5c0fca}},	//   йті_, नहरू_, _afẹf, lora,
   {{0x672214f1,0x6729023e,0x8af00092,0x7d170092}},	//   rkoj, _dlej, blər, _yoxs,
   {{0xdb1c0990,0x7af6013f,0x07a63031,0x6d5c1bc8}},	//   ctrò, ldyt, _магн, nora,
   {{0x67291c96,0x7e64039f,0x6d5c0062,0x29180503}},	//   _flej, _lyip, iora, _iora_,
   {{0x6d5cc2e4,0x213e00f0,0x7af6c2e5,0x3a3f0234}},	//   hora, with_, ndyt, _župi_,
   {{0x69d6c2e6,0x7bc708c5,0xaca40032,0xb06500c2}},	//   ntye, zuju, _atọw, ydää,
   {{0x6d5cc2e7,0x201e01b3,0x7af600c2,0xe9ff0023}},	//   jora, tyti_, hdyt, _liếc_,
   {{0xe51f0167,0x28cf0b7f,0x213e036b,0x7e643853}},	//   _भवति_, स्टि, rith_, _ayip,
   {{0x201e013f,0x8af001d4,0xeeab00d3,0xd528020b}},	//   ryti_, zlər, шток_, _hồn,
   {{0x7bc726f7,0x6d5c2035,0x8af00092,0x201e0138}},	//   wuju, fora, ylər, syti_,
   {{0x6d5c3f55,0x7bc725fa,0x2918c2e8,0x61e2026e}},	//   gora, tuju, _nora_, _ipol,
   {{0x8af00092,0x2b400188,0x7e64a228,0xe9ff00fe}},	//   vlər, fiic_, _eyip, _biếc_,
   {{0x7bc770e6,0x7bd50a00,0x28dd42d4,0x2918200e}},	//   ruju, rtzu, न्नि, _aora_,
   {{0x2918c2e9,0x8af001d4,0x5a35016e,0x6d5c0133}},	// [f850] _bora_, tlər, чнат, bora,
   {{0x25fe048a,0x6d5c40d3,0xc867171b,0x61e2357c}},	//   लिनी_, cora, отеи, _mpol,
   {{0x8af00253,0x6729c2ea,0x2918c2eb,0xf7700470}},	//   rlər, _plej, _dora_, چان_,
   {{0x61e2c2ec,0xd36600bf,0xf77054c8,0x8af00092}},	//   _opol, _سه_, نان_, slər,
   {{0xd246054f,0x29188042,0xfa960341,0xe5a530fd}},	//   _أن_, _fora_, _מדרש_, чили,
   {{0xd006054f,0x63657e43,0x29181257,0x7e6000aa}},	//   _كل_, móni, _gora_, ümpi,
   {{0x61e23f1f,0x63653210,0x00000000,0x00000000}},	//   _apol, lóni, --, --,
   {{0x130900d6,0x6d5c1da7,0x673b0193,0xdced02a1}},	//   сний_, zora, _umuj, _ftaħ,
   {{0x68f54cb3,0x636504d8,0x956700e5,0xdafe0231}},	//   _kazd, nóni, _дъжд, _pãºb,
   {{0x68f53239,0x2cb13f8a,0x81dc0033,0x7e640027}},	//   _jazd, jazd_, ডিং_, _ryip,
   {{0xb4e7007d,0x6d5c312e,0xd91c00ca,0x61e29159}},	//   यजी_, vora, יוזל, _epol,
   {{0x6d5cc2ed,0xbebb023b,0xd3430068,0x68f533f4}},	//   wora, dhës, _تفصی, _lazd,
   {{0x63650088,0xa15904a1,0xa2d012f2,0xa02628b4}},	//   jóni, _ладу_, _धात्, ttöö,
   {{0x63653ce8,0x61fb2395,0x28c700b6,0xdcfe0141}},	//   dóni, mvul, _लागि, _tipč,
   {{0xf09200a1,0x6d5cc2ee,0xfaa60399,0x7f5d0143}},	//   _אנו_, rora, забо, bosq,
   {{0x6d5c43cf,0x63650610,0xa02632d2,0x8af000a7}},	//   sora, fóni, stöö, tləq,
   {{0x6d5c0e64,0x61fb03ee,0x2918c2ef,0x68f5c2f0}},	// [f860] pora, nvul, _pora_, _bazd,
   {{0x26df0129,0x0e57028c,0x2918008c,0x6d5c4887}},	//   _abuo_, _משפט_, _qora_, qora,
   {{0xe9ff00de,0x2918c2f1,0xdcf7044c,0xdced0090}},	//   _tiếc_, _vora_, şcăt, _staħ,
   {{0x69d62375,0x63650072,0x7bc100e7,0x62860031}},	//   ptye, bóni, šluc, ľkok,
   {{0x29186f13,0xaad509c3,0x62860138,0x63650072}},	//   _tora_, _डॉटक, žkok, cóni,
   {{0x68f5c2f2,0x644f00a5,0x634800b6,0xf99f05aa}},	//   _gazd, _ścia, měni, _brèf_,
   {{0x61e22449,0x69c45b84,0xa3b6058f,0x00000000}},	//   _spol, lrie, _जिओ_, --,
   {{0xa3ad04a9,0xe73a013d,0x26df0294,0xdb24020d}},	//   _कबर_, _уеб_, _gbuo_, érès,
   {{0x68f508bb,0x05761363,0x61fb1570,0x5eab0033}},	//   _yazd, _فائد, gvul, _কালে,
   {{0x3a37040a,0x859b00a1,0x7d1a0149,0x69c4c2f3}},	//   פרים_, _לשמו, ötsl, irie,
   {{0x69c4c2f4,0xbebb023b,0x63650143,0x63ad015c}},	//   hrie, dhër, zóni, ćanc,
   {{0x69c49952,0xd64e0134,0xc17800c6,0x612d00da}},	//   krie, bọtụ_, smė_, _cúlb,
   {{0xc33300a1,0x61e2c2f5,0xddcf0138,0x28af00b7}},	//   _אוף_, _upol, ždži, टरमि,
   {{0x14df0b61,0xc16f02ec,0x69c4c2f6,0xbebb00dd}},	//   प्पण, _її_, drie, thës,
   {{0xd0f70089,0x69c41e29,0x60db00ca,0x38c30139}},	//   _זצוק_, erie, _הקונ, _lérà_,
   {{0x69c46b54,0x6b8608d3,0xae9b00e3,0x63652ad4}},	//   frie, _cikg, _اضغط_, tóni,
   {{0x69c4c2f7,0x239500d9,0x6b86166c,0x68f500f1}},	// [f870] grie, _māja_, _dikg, _pazd,
   {{0x636511c4,0x98b90077,0x9e67001c,0x3f8e010a}},	//   róni, ілет_, _واکن, _kufu_,
   {{0x29070390,0x68f5175b,0x69c425a8,0x78ae037a}},	//   ına_, _vazd, arie, _debv,
   {{0x636546b4,0xb9150129,0xcfae0033,0x3f8e0361}},	//   póni, _yabụ_, _কমান, _mufu_,
   {{0xa3cf02e8,0xb8d30081,0x69c427af,0x5eb20033}},	//   वून_, _টা_, crie, _ঝামে,
   {{0x85e802ec,0xf9920341,0xba3b00b3,0x25de08d4}},	//   ядів_, _ברך_, _deït, _गहरी_,
   {{0xc95200ca,0x00000000,0x00000000,0x00000000}},	//   _סמל_, --, --, --,
   {{0xf773110a,0x6124022b,0x798f07f5,0xe1f10076}},	//   _ساز_, _fòlk, _kucw, نسخ_,
   {{0x4cb300c7,0x20180084,0xdb240103,0xe4e7224a}},	//   _জানু, ärin_, érés, _ніжн,
   {{0x61fb01d0,0x3f8e010a,0x70c70096,0x00000000}},	//   rvul, _bufu_, ललेल, --,
   {{0x69c40181,0xceeabc12,0x61fb1305,0xaca40174}},	//   zrie, одне_, svul, stịk,
   {{0xe28e50b0,0x26cf172a,0xd5d10961,0x28dd030b}},	//   _ја_, nggo_, _समाज, न्ति,
   {{0xee370879,0x799d006c,0xf5480134,0xe0ce44f3}},	//   дня_, _ntsw, kụl_, _ив_,
   {{0x69c4c2f8,0xac0a43c7,0x25e5074c,0xd00e01f3}},	//   vrie, онга_, _टहनी_, _چلو_,
   {{0xeb972105,0x69c4c2f9,0x00000000,0x00000000}},	//   дис_, wrie, --, --,
   {{0x69c402f4,0x61ed013f,0xbebb023b,0x798f0172}},	//   trie, _šaly, shër, _bucw,
   {{0x79870126,0x63a40477,0xf2d200c1,0xaa4347ff}},	// [f880] _bijw, ćini, כען_, ветл,
   {{0x69c4a3aa,0x6d8b01d3,0xb5fd0094,0x00000000}},	//   rrie, _pļav, _pyšn, --,
   {{0x28dd08fa,0x5fc50179,0x628b0188,0x6299010a}},	//   न्धि, _विफल, _oggo, _ofwo,
   {{0x69c4c2fa,0x6fc5009d,0x9f5d0220,0x628b00cd}},	//   prie, _विनं, _prvé_, _nggo,
   {{0x6ed64735,0x6d4e1cab,0xba3b02ac,0x14c900a4}},	//   _भानु, onba, _deïs, _राखण,
   {{0x28dd3fdd,0x629905aa,0x6d4e11fc,0x6124022b}},	//   न्दि, _afwo, nnba, _vòlk,
   {{0x6d4e0d87,0xdb0700f3,0x290a01ee,0x00000000}},	//   inba, ssjå, _inba_, --,
   {{0xba3b1030,0x66000167,0x28cc023a,0x79871b05}},	//   _geïs, _trmk, ालवि, _zijw,
   {{0x96635222,0x63650088,0x63ad0580,0xa3ba0b2b}},	//   _акте, jónu, ćana, _अटक_,
   {{0xb5fd0579,0x628b0361,0x6d4e029a,0x6299022b}},	//   _myšl, _eggo, jnba, _efwo,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4e2e97,0xf5480134,0x42265b80,0x00000000}},	//   enba, zụl_, _одев, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb150103,0x6353020a,0x6d4e0ac9,0x00000000}},	//   mszé, măna, gnba, --,
   {{0xd30f00de,0x1bd41cf2,0x7987029a,0x212b014b}},	//   _mệnh_, коря, _rijw, êche_,
   {{0x290a0c56,0x91f20251,0xa3cf086d,0xd30f00de}},	//   _anba_, _अनाज_, वंत_, _lệnh_,
   {{0x49750dc0,0x6365b504,0x00000000,0x00000000}},	// [f890] елас, mónt, --, --,
   {{0x612400b3,0xe6a7097c,0x5fc51677,0x92ea0033}},	//   _bòli, खर्ज, _विमल, মায়_,
   {{0xe61000cd,0x612400ee,0x6aaf0231,0x00000000}},	//   یشه_, _còli, _tecf, --,
   {{0x7c2809af,0x63650076,0x2b4d01ff,0x00000000}},	//   ødre, nónt, _ñec_, --,
   {{0xd30f0028,0x7aeda15a,0xae0f04f1,0xa509460b}},	//   _bệnh_, meat, ामिन_, зела_,
   {{0x7aeda0a5,0x293500c1,0x67d511cc,0x6124101c}},	//   leat, _טאָן_, _погу, _fòli,
   {{0xf8b20089,0xf770001c,0x3b0b0113,0xc4f80037}},	//   _תשל_, _چاق_, _kncq_, بعنا_,
   {{0xdb1cc2fb,0x7aedb55b,0x644e00c4,0xae0f09a0}},	//   strö, neat, _žbic, ामान_,
   {{0xa2d004f8,0x6d4ec2fc,0x20d507bf,0x00000000}},	//   _धार्, ynba, нінс, --,
   {{0xd64e0174,0xf8af009f,0x63ba01ff,0xb6cc020e}},	//   pọrụ_, टरिय, _fvtn, _çürü,
   {{0x7aed2c6f,0xd0095eb0,0x69cd0131,0x3f899de1}},	//   keat, чене_, huae, _biau_,
   {{0xdb1c025a,0x6fc016f8,0x3f890f34,0x25ad084e}},	//   ntrô, _विरू, _ciau_, _kwel_,
   {{0x7aed0a00,0x3f89030a,0x00000000,0x00000000}},	//   deat, _diau_, --, --,
   {{0x621a0089,0xdd8f071c,0x823406cf,0x721a00ca}},	//   _מונק, صوف_, _جرما, _מונח,
   {{0x6d4e0429,0x69c259f2,0xf99f35c6,0x98ba00ae}},	//   rnba, _लिही, _atè_, hipă_,
   {{0x62860220,0x7aed2a9a,0x63650042,0x3f89c2fd}},	//   ľkov, geat, cónt, _giau_,
   {{0x6fc51e5e,0xb0b6000f,0x6286025b,0x61240428}},	// [f8a0] _विडं, _आजमग, žkov, _sòli,
   {{0xb5fd0146,0xf99f022b,0x6124015e,0x8cd70bf5}},	//   _vyšl, _dtè_, _pòli, _बायो,
   {{0xacd700c1,0x2d92c121,0x614600fd,0xf99f0154}},	//   _אויפ_, _huye_, _hélè, _etè_,
   {{0xbbe900d0,0x7bce450c,0x2d920060,0x25ad0172}},	//   _کریم_, mubu, _kuye_, _bwel_,
   {{0x7d1ec2fe,0x2d9203e3,0x00000000,0x00000000}},	//   _kops, _juye_, --, --,
   {{0x2d924458,0x66030284,0x00000000,0x00000000}},	//   _muye_, упља, --, --,
   {{0x7bcec2ff,0x25ad0090,0xf1bf00d4,0xe4a5004d}},	//   nubu, _ewel_, šál_, тріо,
   {{0x2d920154,0x7d1e3b64,0xdb1501f9,0xb7db00ca}},	//   _ouye_, _lops, tszé, _מקלי,
   {{0x32020074,0x7bce06ee,0x3f89c158,0xf8dd0be4}},	//   íky_, hubu, _riau_, न्वय,
   {{0x7bce66fd,0xc05a00c6,0x6b820134,0xd49100fe}},	//   kubu, зім_, ọghe, _hàn_,
   {{0x399608dc,0x2d9201c2,0x41c205e4,0x64a31538}},	//   _læs_, _auye_, _शिवस, _саха,
   {{0xe2920080,0xd3782e78,0xceeb0037,0xdb0704c8}},	//   _إذا_, _opći_, أردن_, ssjú,
   {{0x160300a5,0x61460257,0x3d9400ae,0xd49100fe}},	//   लियर_, _célè, лияр, _màn_,
   {{0x7d1e00ee,0x7bc7033b,0x7bdc2c18,0xc05a004d}},	//   _cops, trju, ftru, _ній_,
   {{0x81dc00c7,0x40340e2d,0x7bce81aa,0x63650072}},	//   ডিও_, _шекс, gubu, cóns,
   {{0xdb0700f3,0x7bc100c6,0xdb6800ae,0x00000000}},	//   nsjø, šluo, ерул_, --,
   {{0xf99309f4,0x98c712d3,0x58d5060b,0x6f0d19ca}},	// [f8b0] ابر_, فغان, коат, _inac,
   {{0x7bcec300,0x7aed20a3,0x6f0d00d4,0x00000000}},	//   bubu, seat, _hnac, --,
   {{0x80d80bd9,0x6d47c301,0x7bce74b5,0x6f0d2271}},	//   _माने, mija, cubu, _knac,
   {{0x2366006c,0xdcfe00ae,0x99890031,0x69cd00bc}},	//   _nkoj_, _tipă, dzať_, puae,
   {{0xf7700241,0x6f0dc302,0x00000000,0x00000000}},	//   حال_, _mnac, --, --,
   {{0xcd9800a1,0xd4695c24,0x28dd0096,0xdb150143}},	//   עדות_, миле_, न्शि, puzó,
   {{0xaca30134,0x63ad0542,0x6f0d01cb,0xdce400e8}},	//   _akịd, ćano, _onac, _etiķ,
   {{0x490502e8,0x5332001f,0x05c90287,0x6f0d0350}},	//   _होतो_, иејт, _रिपब, _nnac,
   {{0xc6920054,0x6595415c,0x44290029,0x6ea202d5}},	//   _כאן_, _разу, ņa_, _क्षु,
   {{0x6f0dc303,0x6d470113,0x00000000,0x00000000}},	//   _anac, jija, --, --,
   {{0x7d1e0ca7,0x7bdc7810,0xbea61689,0x3ea61a0c}},	//   _rops, xtru, канк, кинг,
   {{0x7d1e175b,0x0caa04f8,0x4427c304,0x6563c305}},	//   _sops, कर्म, myn_, lonh,
   {{0xb6ba00a1,0x7d1eae76,0x733a00c1,0x442788f5}},	//   וצרי, _pops, _קענס, lyn_,
   {{0x6da36ab3,0x236000e9,0x7bcec306,0x6d47743c}},	//   рира, čije_, tubu, gija,
   {{0x4427c307,0x7d1e00d3,0x612400b3,0xdc6713c7}},	//   nyn_, _vops, _pòlv, вард_,
   {{0x7bcec308,0x629bb8f9,0xef260233,0x2ca50233}},	//   rubu, ncuo, çüde_, ılda_,
   {{0x6d47c309,0xcb670a29,0xe9da02ec,0x7bcec30a}},	// [f8c0] bija, тате_, ька_, subu,
   {{0x7d1e0c27,0x44270185,0x6ab601e8,0x7bce0193}},	//   _uops, kyn_, sayf, pubu,
   {{0x8cd70034,0x2cb8020d,0xfaff0052,0xe7c90034}},	//   _बातो, mard_, _ikën_, ांगप,
   {{0x442702ad,0xe5a60a71,0xe5c63612,0x2cb8c30b}},	//   dyn_, види, вско, lard_,
   {{0xca75022a,0x4427008c,0x6124022b,0x99860037}},	//   _буры, eyn_, _kòlt, _للحو,
   {{0x2cb8481e,0x44270150,0xb9070033,0x65630231}},	//   nard_, fyn_, _মো_, gonh,
   {{0xd9436135,0x442700f0,0xd37a007e,0x612400b3}},	//   _тери, gyn_, мчи_, _mòlt,
   {{0x236d02dd,0x51f80084,0x9f5d0206,0x00000000}},	//   glej_, ению_, _prví_, --,
   {{0x25ec00a5,0x8755013d,0xda05009f,0xc0ca37fa}},	//   _आईटी_, _сърц, रियत_, муне_,
   {{0x68fcc30c,0x25a6c30d,0x6f0d35b6,0x442702ad}},	//   _jard, mpol_, _snac, byn_,
   {{0x44380501,0x68fcc30e,0x63a403ce,0x25a60270}},	//   _år_, _mard, ćins, lpol_,
   {{0x68fcb6be,0x6d47c30f,0x645a33bc,0xc24619c3}},	//   _lard, wija, _ixti, _инек,
   {{0xa2d70d77,0x62860181,0x6602c310,0xb5fd0138}},	//   _यात्, ľkos, nvok, _ryšk,
   {{0x614303bf,0x628624a1,0x2cb88ce3,0xe8cc08c0}},	//   _кеча, žkos, gard_, ालोच,
   {{0xa5cc000f,0x25690103,0xa17700ca,0xd00f0f98}},	//   _समझौ, múlt_, _שעוד_, _وله_,
   {{0x68fc4e0b,0x6d47c311,0x7f5600dd,0x6f0dc312}},	//   _aard, sija, _gjyq, _unac,
   {{0x68fcc313,0x3a750c39,0x3eb92338,0x27ea00ec}},	// [f8d0] _bard, улар, mast_, _apbn_,
   {{0x442700c2,0x3da4008f,0x66020407,0xacf50291}},	//   yyn_, _тръб, dvok, _спољ,
   {{0x68fcc314,0x6d45c315,0x67200113,0xdb150103}},	//   _dard, _imha, _bomj, lszí,
   {{0x3eb9c316,0x68fc009c,0xdbd1007a,0x44270853}},	//   nast_, _eard, _müüg, vyn_,
   {{0x4427b6a6,0x2d9c0087,0x67207b91,0xdb150103}},	//   wyn_, _čvek_, _domj, nszí,
   {{0x4427c317,0x68fc8ce3,0x7afd60c8,0x3eb900aa}},	//   tyn_, _gard, _hast, hast_,
   {{0xe29908a1,0x7afdc318,0x3eb9b699,0x7e6d010a}},	//   най_, _kast, kast_, _lyap,
   {{0x44279da5,0x3eb977bf,0xd3780dd9,0x8219001f}},	//   ryn_, jast_, _opću_, ецот_,
   {{0x3eb9c319,0x3a291a47,0x7afd1cf5,0x442701ce}},	//   dast_, nyap_, _mast, syn_,
   {{0x68fc49da,0x629b00e5,0x236d66b8,0x44270150}},	//   _xard, scuo, slej_, pyn_,
   {{0x777b023e,0x5eab0081,0x2cb8c31a,0x236d5874}},	//   _khux, _কাজে, vard_, plej_,
   {{0x6d450e5c,0x752101bf,0x3eb92fe3,0x2cb82ab4}},	//   _amha, _holz, gast_, ward_,
   {{0xc0e502b3,0xd49100de,0x2d4d02ef,0x7e6d0169}},	//   _болк, _làm_, džeb_, _cyap,
   {{0x7afd05a7,0x78b5110e,0x6ed60006,0x2d8cc31b}},	//   _aast, _nezv, _भावु, öde_,
   {{0x66020117,0x68fc7153,0x3eb900bc,0x7e6d48d3}},	//   zvok, _rard, bast_, _eyap,
   {{0x68fc9c9e,0x7afd34d2,0x765b0092,0x2cb800fd}},	//   _sard, _cast, _oxuy, sard_,
   {{0x68fcc31c,0x7afdc31d,0xa3b30f78,0x67207fc3}},	// [f8e0] _pard, _dast, जीत_, _romj,
   {{0x63ad02e6,0x68fc15fb,0x7afd095b,0x6d400052}},	//   ćanj, _qard, _east, ëmad,
   {{0x68fcc31e,0x8caa1362,0x78b5002d,0xddcd00e9}},	//   _vard, _ज्यो, _dezv, _izaš,
   {{0x25a60967,0x31650364,0x8af000a7,0x4789004d}},	//   tpol_, holz_, yləy, всім_,
   {{0x7ae42500,0x7521c31f,0xe4e60426,0x15d90018}},	//   mfit, _bolz, гійн, ندوں_,
   {{0x7ae4c320,0x25a6c321,0x7521a5a1,0x5eab0033}},	//   lfit, rpol_, _colz, _কাছে,
   {{0xc61c00c7,0x25a64abf,0x75210141,0xf36610e8}},	//   _দেখা_, spol_, _dolz, лтин,
   {{0x7afd002b,0x436700c9,0xfbac148e,0x6136020d}},	//   _xast, лајн_, टीएम, _mâle,
   {{0x64a6041e,0x3eb9c322,0xe4d65c4d,0x14d60260}},	//   _база, vast_, _متاب, _مزاح,
   {{0x200700c4,0x7e6d0027,0x75210231,0x06bc0033}},	//   _brni_, _ryap, _golz, _ইউটি,
   {{0x0493054f,0x20071419,0x3eb9487c,0xb5fd0138}},	//   _المح, _crni_, tast_, _ryši,
   {{0x6d8b0090,0x7bc1015c,0x798e0172,0x777b0216}},	//   _eżal, šluk, _libw, _xhux,
   {{0x3eb979f1,0x7afdc323,0x88cc0081,0x3b0002fa}},	//   rast_, _rast, র্যক, ddiq_,
   {{0x798e0193,0x3eb9c324,0xdd9400c6,0x7e6d024a}},	//   _nibw, sast_, сары, _vyap,
   {{0x8ca4000f,0x3eb9c325,0xd00f136e,0xdb150103}},	//   कड़ो, past_, _уф_, sszí,
   {{0x798e0350,0x7afd11bc,0x00000000,0x00000000}},	//   _aibw, _qast, --, --,
   {{0x7afd1c73,0x2b49c326,0x798e05bd,0xa9970103}},	// [f8f0] _vast, riac_, _bibw, اشرت,
   {{0x2b490181,0x7afd59af,0x6d45c327,0xf99f022b}},	//   siac_, _wast, _umha, _frèn_,
   {{0x63ad1912,0x3a2900f9,0x603300a7,0xe7960103}},	//   ćank, syap_, təmə, لانک,
   {{0x7521497d,0x7afd0037,0xa2d00096,0x00000000}},	//   _solz, _uast, _धाग्, --,
   {{0xfad607a6,0xeef800c1,0x7521c328,0x49930018}},	//   _דורך_, טמאר_, _polz, _طیار,
   {{0x69cd02e0,0xc7b706cf,0x6d557746,0x00000000}},	//   mrae, _مصرع, nnza, --,
   {{0xc2930018,0x29110113,0xc6a70859,0xa2620131}},	//   میاب, _inza_, _брзи, çôni,
   {{0x1309249c,0x798e0b58,0x777b039f,0x00000000}},	//   тний_, _zibw, _uhux, --,
   {{0x65150018,0x20070e94,0x798e05bd,0xd24e01dc}},	//   _پوائ, _srni_, _yibw, وچه_,
   {{0x23600542,0x2901c329,0x60092311,0x6609c32a}},	//   čija_, ndha_, вном_, _irek,
   {{0xa2f50e58,0xb4c309a0,0xdb070653,0x29010188}},	//   _впеч, ्ली_, nsjó, idha_,
   {{0x6609c32b,0x9f5d0220,0x6d550a53,0x2007033b}},	//   _krek, _prvá_, enza, _vrni_,
   {{0x6d8b0078,0x3f821d95,0x29114846,0x8e7600d3}},	//   _eżam, rmku_, _onza_, рунч,
   {{0x69cdb6a6,0x6609610e,0x4f955cac,0xd13824c5}},	//   drae, _mrek, _криу, chą_,
   {{0x2901c32c,0xd0161673,0x2007033b,0x8cd702d5}},	//   ddha_, _نقوش_, _urni_, _बारो,
   {{0x9f5d0146,0x6d550610,0x6609506c,0x2911c32d}},	//   _trvá_, anza, _orek, _anza_,
   {{0x7ae400dd,0x3ead0328,0x39460138,0xc8960e2c}},	// [f900] rfit, ñete_, анаг, арењ,
   {{0xf09200c1,0x78bb0257,0x3b000092,0xddcd00c4}},	//   ַנד_, _œuvr, sdiq_, _uzaš,
   {{0x6609784f,0x98aa00ae,0xdb0704c8,0x798e024a}},	//   _arek, _albă_, gsjó, _vibw,
   {{0x66e60f80,0x660923ff,0x69cda3c8,0x2911019f}},	//   рода, _brek, brae, _enza_,
   {{0x6b840934,0x22a600b6,0xb4c309b0,0x395817f9}},	//   mmig, níků_, ्लू_, _tjrs_,
   {{0x6609c32e,0x6b840188,0x03c61c66,0x00000000}},	//   _drek, lmig, асим, --,
   {{0x6d8b0090,0xdb150103,0xd499004d,0x00000000}},	//   _bżaj, lszá, урі_, --,
   {{0x66091c36,0x6b841ea5,0x6616007b,0x80d81fbb}},	//   _frek, nmig, äyks, _माहे,
   {{0x24f62457,0xe5a328ce,0x66094f65,0xdb150018}},	//   _вчер, _мити, _grek, nszá,
   {{0x6b8401bf,0x637e023b,0xf8b3006e,0x99b10033}},	//   hmig, këng, ֿשר_, _চমৎক,
   {{0xb4d20693,0x66095141,0x88cc0033,0x00000000}},	//   वली_, _zrek, র্থক, --,
   {{0x91e608c3,0x14170037,0xdb1501f9,0x6136078e}},	//   _воде, _خيمة_, kszá, _bâlc,
   {{0x51f61b49,0x9df82c4c,0x7bce0b8e,0x00000000}},	//   _خسار, анят_, erbu, --,
   {{0xa3b31e9f,0xc0460103,0x6b8400bc,0x00000000}},	//   जीव_, _پختو, emig, --,
   {{0xb17b006e,0xf99f0154,0xdb6b0450,0x6b8402ac}},	//   _שטור, _erèl_, врал_, fmig,
   {{0x69cd02a1,0x9e670018,0x6b840270,0x9ed902a0}},	//   trae, _پابن, gmig, _смит_,
   {{0x63ad08c5,0x7bce0124,0x6ce7097a,0xdb150103}},	// [f910] ćani, arbu, _кіне, gszá,
   {{0x69cd0150,0x637e023b,0x66095b92,0xf80752fc}},	//   rrae, lënd, _rrek, ичен,
   {{0x69cdc32f,0x2901c330,0xf99f00fe,0xd61800d1}},	//   srae, rdha_, _trèo_, یتها_,
   {{0x660916fc,0x7bd5c331,0x69cd29c0,0xdb07003e}},	//   _prek, muzu, prae, rsjó,
   {{0x66059032,0x64a50e48,0xaae6010d,0xdb070088}},	//   спла, бала, _اسپو, ssjó,
   {{0xb4c30179,0x637e023b,0xdb1c0610,0xd56737fa}},	//   ्ले_, hënd, buró, штеп,
   {{0x237d023e,0x637e0052,0xdb1c0072,0x7bd5c332}},	//   _phwj_, kënd, curó, nuzu,
   {{0x66093927,0x612d3e43,0xcc5800ca,0x00000000}},	//   _trek, _túlk, יסוק_, --,
   {{0x7985023e,0x130600c2,0xe1f10037,0x66092ff5}},	//   omhw, сный_, سسة_, _urek,
   {{0x23e700d6,0x7bd52e60,0x64a40284,0xf8a70442}},	//   _відв, kuzu, _мађа, गडिय,
   {{0x612d0018,0xe8df0028,0x40493b85,0x237d006c}},	//   _júli, _ngọc_, упно_, _thwj_,
   {{0x22950080,0x7bd55322,0x9989031a,0x6d8b00bd}},	//   _الإس, duzu, jzaž_, _użaj,
   {{0x528500e3,0xf99f0154,0xa3b3014e,0x00000000}},	//   _الشك, _brèm_, जीर_, --,
   {{0xdca316d9,0x7bd5c333,0x613600ae,0xa0090308}},	//   зари, fuzu, _vâlc, _مقتل_,
   {{0xd4910023,0x201800c2,0xdb1c0042,0x7bd501c8}},	//   _bài_, ärit_, xuró, guzu,
   {{0x2b9c030b,0xdb150103,0xd49100fe,0xbebb0216}},	//   _víc_, tszá, _cài_, skër,
   {{0x3b07008f,0xf99f022b,0x4ab94214,0xd49100fe}},	// [f920] щето_, _frèm_, руся_, _dài_,
   {{0xdb150068,0xb4c3000d,0x6b84c334,0x20180073}},	//   rszá, ्लो_, smig, årig_,
   {{0x6d4e60ed,0xdb150018,0xc6250033,0x239500e8}},	//   miba, sszá, _মেলা_, _kāju_,
   {{0x98b80511,0xd6d90120,0x00000000,0x00000000}},	//   ızın_, иті_, --, --,
   {{0x239501d3,0x7c2e03a8,0x2cba0090,0x291c02c3}},	//   _māju_, lybr, _kepd_, övas_,
   {{0xb4d20c3d,0x6d4ec335,0xe9a318e4,0xdb05014b}},	//   वले_, niba, _харп, _athè,
   {{0x69d6034f,0xa3b33613,0xa3181aad,0x29370142}},	//   luye, जील_, ижку_, _פאלן_,
   {{0xe44f0080,0x6d4e0b49,0x7af60088,0xe737055b}},	//   عضو_, hiba, neyt, _лес_,
   {{0x69d6c336,0x9406001c,0x7e990504,0x5f1c87bf}},	//   nuye, _گواه, یندر_, यान्_,
   {{0x6d4e26ef,0xb5fd0e4b,0x7bd505bd,0x00000000}},	//   jiba, _vyšt, yuzu, --,
   {{0x3f920a75,0x5eaa0081,0x28dd15e4,0x160302d5}},	//   _biyu_, _কয়ে, न्टि, लिअर_,
   {{0xe29a349e,0x6d4e1030,0xeeab1402,0x3f80491c}},	//   _сад_, eiba, ыток_, _chiu_,
   {{0x637e00dd,0x518601b3,0x13ad0081,0x5118333f}},	//   rënd, _лука, _গিয়, _волю_,
   {{0x7bd54fa3,0x6d4e5b64,0x394a029a,0x201809a1}},	//   tuzu, giba, _nmbs_, äris_,
   {{0x33260188,0x3f92010a,0x3f8001b9,0x7c342249}},	//   _koox_, _fiyu_, _fhiu_, перх,
   {{0x7bd54835,0xb06500c2,0x6d4e1183,0x63a893f9}},	//   ruzu, seää, aiba, _mtdn,
   {{0x6d4e74ff,0x7bd50193,0x69d6c337,0xf99f03a9}},	// [f930] biba, suzu, guye, _trèm_,
   {{0xaa7b025b,0x2be20b89,0x27050023,0x127b006e}},	//   _obýv, _पहचा, _ồn_, ראמע,
   {{0xaa950b2e,0x3f9203e3,0xd4910023,0xf99f022b}},	//   _минч, _yiyu_, _tài_, _krèk_,
   {{0x69d60201,0x2d9b023b,0xb4c300aa,0x291c02c3}},	//   buye, _kuqe_, ्ल्_, övar_,
   {{0x2cb20222,0x35e700d6,0xceb400ca,0x61e2063d}},	//   _ändå_, сцев, ליף_, _nqol,
   {{0x2c8300fd,0xa509235c,0x00000000,0x00000000}},	//   cédé_, река_, --, --,
   {{0xe3b20068,0xa3b32171,0xdb05c338,0x3ea20212}},	//   ورٹ_, जीं_, _athé, yckt_,
   {{0x290361d2,0x6d4eb281,0x2d930231,0x644f007f}},	//   _haja_, ziba, _lixe_, _ścis,
   {{0x6d4e1937,0x612d0103,0x3326041c,0x00000000}},	//   yiba, _múlv, _doox_, --,
   {{0x95570241,0x4fe911c0,0x3f800052,0x28dd0179}},	//   _اخرا, амон_, _shiu_, न्चि,
   {{0x2903c339,0x3d1d0bb5,0x3f9203a9,0x61e20372}},	//   _maja_, माने_, _piyu_, _eqol,
   {{0x7c2e0146,0x6d4ec33a,0x3f6ab580,0xb7da0266}},	//   vybr, wiba, римо_, סקרי,
   {{0xc33200a1,0x5fc50f62,0x3ead28b3,0xaa7b00b6}},	//   _קוד_, _विकल, ñeta_, _zbýv,
   {{0x290301bf,0x61fb411d,0xf99f0154,0x2cba037a}},	//   _naja_, mwul, _erèk_, _qepd_,
   {{0x69cb0081,0x6d4ec33b,0x7af60084,0x3326413a}},	//   ágen, riba, teyt, _yoox_,
   {{0xdb1c0088,0x69d6c33c,0x2d931ba8,0xf99f0383}},	//   gurð, tuye, _eixe_, _grèk_,
   {{0x2903c33d,0x2d935f7a,0x7af6003e,0xa9262312}},	// [f940] _baja_, _fixe_, reyt, одал,
   {{0x38cb14df,0x29030033,0x69d6c33e,0x2d4d0146}},	//   لامی_, _caja_, ruye, nžel_,
   {{0x69d6b3a4,0x6f041d51,0xdb1c003e,0x2bd902d5}},	//   suye, _kaic, burð, बूदा,
   {{0x69d600fd,0x941100a7,0x61400139,0x7c2301b9}},	//   puye, _üzə_, _kálù, _ànra,
   {{0x6f04b82c,0x29033912,0x442e00f0,0xd49100fe}},	//   _maic, _faja_, wyf_, _màu_,
   {{0x69c4c33f,0x442e084e,0x2d93020d,0x3cd3007f}},	//   msie, tyf_, _xixe_, _ताज़ा,
   {{0x69c4c340,0x6f160154,0xf99f03a9,0x6d8b00bd}},	//   lsie, _onyc, _arèh_, _eżaw,
   {{0x442002e6,0x442e0665,0x78bc01f4,0x31c608d1}},	//   ći_, ryf_, _herv, осов,
   {{0x316e0063,0x29033e26,0x78bcb365,0x00000000}},	//   _pkfz_, _yaja_, _kerv, --,
   {{0x2ee000e7,0x69c43f7f,0x78bc01ce,0x672200ce}},	//   _acif_, isie, _jerv, ljoj,
   {{0xc05a0565,0x78bcc341,0x6f045bf3,0xa2e60291}},	//   ріп_, _merv, _baic, _можд,
   {{0x69c4c342,0x672251f4,0x75280b14,0x93fb00ca}},	//   ksie, njoj, _hodz, _כלבי,
   {{0x76421019,0x7528c343,0x6f044157,0x10e600ba}},	//   nzoy, _kodz, _daic, _дюйм,
   {{0x69c4152e,0x23690128,0x3af50023,0x6722007b}},	//   dsie, čaje_, _ấp_, hjoj,
   {{0x29030498,0x69c452eb,0x6f0401b5,0x4fb30037}},	//   _raja_, esie, _faic, _قصير,
   {{0x2903c344,0x31a002f1,0x752856cc,0x6d5e00b3}},	//   _saja_, _kòz_, _lodz, _ejpa,
   {{0x78bcc345,0x7f4d1b7b,0x31a00154,0x753a0062}},	// [f950] _berv, _imaq, _jòz_, _oltz,
   {{0x48ab0265,0x752840e8,0x3f9c1f9e,0x26df28f7}},	//   ртам_, _nodz, _kuvu_, _scuo_,
   {{0x2903007a,0x69c44459,0x6f040a4b,0x00000000}},	//   _vaja_, asie, _yaic, --,
   {{0x2903c346,0x6722023b,0x753a01e9,0x7f4d0090}},	//   _waja_, gjoj, _altz, _jmaq,
   {{0xe4f70ed3,0x5f1c0e57,0x78bc45f8,0x64a57ed6}},	//   ंजलि_, यात्_, _ferv, пала,
   {{0x75280034,0x64a50f5f,0x7d05c347,0x80d00033}},	//   _codz, чака, _jahs, ত্ত্,
   {{0x0edb009d,0x7d05c348,0xc2e95f34,0x7f4d039f}},	//   _भांड, _mahs, معظم_, _omaq,
   {{0x31a0022b,0x799d6af0,0x79950027,0xbfa30023}},	//   _bòz_, _kusw, _hizw, _diễ,
   {{0xe4e7013a,0x6f04200e,0xda0e074c,0x4cd30081}},	//   _міжн, _raic, सियत_, দ্যু,
   {{0x75280067,0x799d908d,0x7f4d0201,0x31a005aa}},	//   _godz, _musw, _amaq, _dòz_,
   {{0x63ad0268,0x799d0172,0x6f040503,0x672902ac}},	//   ćans, _lusw, _paic, _koej,
   {{0xe3b00867,0x69c45fd8,0xd64e0174,0x26dd0294}},	//   _شرم_, ysie, bọdụ_, ngwo_,
   {{0x7d05bd1f,0x799d00d1,0x6f0440b1,0x00000000}},	//   _bahs, _nusw, _vaic, --,
   {{0xcfe900bf,0x200e00e7,0x320f0113,0x612d0076}},	//   _هفته_, _frfi_, _irgy_, _cúlt,
   {{0x799d02e2,0x7d05561b,0x6f0401b5,0x60c1780f}},	//   _ausw, _dahs, _taic, malm,
   {{0x3f67013d,0x69c4c349,0x799d6260,0x6abd0c45}},	//   _нищо_, tsie, _busw, _cesf,
   {{0x6abdc34a,0x78bcc34b,0xda6305c7,0x7995c34c}},	// [f960] _desf, _perv, евти, _bizw,
   {{0x01bd0f71,0x69c4c34d,0x3d1d009d,0x6aa4c34e}},	//   _আমাদ, rsie, माणे_, scif,
   {{0x78bc1db2,0x75280067,0x79950383,0xfaa65a5c}},	//   _verv, _rodz, _dizw, _нано,
   {{0xe61a25a7,0x8f9a0089,0x673b00d3,0x78bc01c0}},	//   йде_, ציני, _cluj, _werv,
   {{0x78bcc34f,0x752808fa,0x60c10068,0x672200c2}},	//   _terv, _podz, kalm, rjoj,
   {{0x6d5c6b3c,0x3ae80068,0x60c10078,0x629905aa}},	//   nnra, _ابھی_, jalm, _agwo,
   {{0x8af001d4,0x673b058a,0x60c10018,0xdb070212}},	//   ynəl, _fluj, dalm, rsjö,
   {{0xdce700e9,0x320f07ac,0x75280034,0x3f9c0a4b}},	//   vojč, _brgy_, _wodz, _ruvu_,
   {{0x257600cd,0x6443c350,0x60c1411d,0x3f9c049c}},	//   _فهرس, azni, falm, _suvu_,
   {{0xe1ef5e51,0x60c1c351,0x6d5c178f,0xb0342611}},	//   اسي_, galm, jnra, днош,
   {{0x64430067,0x7d0518c4,0x06e30081,0x67290167}},	//   czni, _rahs, _নোটি, _yoej,
   {{0x7d05353e,0x0ea70592,0x987b00ca,0x60c100aa}},	//   _sahs, कुंड, מריק, aalm,
   {{0x7d050124,0x6abd9682,0x2918009c,0x0e34007b}},	//   _pahs, _resf, _onra_, еняю,
   {{0xe6b92dfd,0x5ba7463e,0xa3d0030b,0x799d02a4}},	//   _उज्ज, зраз, _वटा_, _rusw,
   {{0x7e6403be,0x961d01d3,0x799d1d42,0x79950169}},	//   _exip, _izņe, _susw, _rizw,
   {{0x7d05363c,0x7995019f,0x7f4d5d6f,0x00000000}},	//   _wahs, _sizw, _umaq, --,
   {{0x433b00c1,0x7d059b87,0x78a50f05,0x3ea9041c}},	// [f970] צעמב, _tahs, tchv, _ifat_,
   {{0x673b00d3,0x67290167,0x8cd700b6,0x28e20635}},	//   _sluj, _soej, _बाटो, _पाणि,
   {{0x673b05fe,0x99e402c6,0x973500d1,0x2b4001b9}},	//   _pluj, ěňat, وکرا, bhic_,
   {{0xf770177a,0x06752b69,0x6d8b0078,0x64430094}},	//   هان_, муля, _eżat, vzni,
   {{0xc1780138,0x7bc7344e,0x55620134,0x00000000}},	//   klė_, lsju, wụọl, --,
   {{0x80d807ad,0x00000000,0x00000000,0x00000000}},	//   _मागे, --, --, --,
   {{0x60c103cf,0x28e200b7,0x672905c2,0x7bc707ee}},	//   valm, _पाति, _toej, nsju,
   {{0x7aed1d21,0x3b090063,0x7c2a0131,0x613f014b}},	//   nfat, ndaq_, _àfre, _mêle,
   {{0x26cd0087,0x7aed0150,0x64432fcc,0x45d4001f}},	//   _ideo_, ifat, szni, _потс,
   {{0xe125004d,0x3ea90052,0xdb1c0231,0x7aed0113}},	//   ємни, _afat_, lurô, hfat,
   {{0xf7700068,0xf99f0383,0xece30033,0xb4b91d96}},	//   _شاہ_, _grèv_, য়াড, चरी_,
   {{0xd24e2c6a,0x60c151a0,0x994f0491,0x612d0076}},	//   انی_, salm, yüş_, _cúlr,
   {{0x60c1c352,0x612d0076,0x00000000,0x00000000}},	//   palm, _dúlr, --, --,
   {{0x61e9c353,0x25ad02ef,0xdd9205bc,0xeb9a2877}},	//   mtel, _mtel_, ئوس_, жив_,
   {{0x7aed14fb,0xdca39bc7,0x7bc70212,0x7ff50421}},	//   ffat, таси, gsju, _آستا,
   {{0xb0dd0251,0x25adc354,0x7e760084,0x61e9c355}},	//   _माँग, _otel_, _tyyp, otel,
   {{0x61e9c356,0x7940042c,0xdb1c003e,0x092a2178}},	// [f980] ntel, _löwe, gsrá, ожай_,
   {{0x2360042d,0x994f07aa,0xe9d708d1,0x61e9c357}},	//   čiji_, rüş_, ьку_, itel,
   {{0x61e90fc4,0xad1b0341,0x9d1b0341,0xdead0d2a}},	//   htel, _וויר, _וויט, _alaƙ,
   {{0x48fa08fa,0x6d8b009e,0x00000000,0x00000000}},	//   _उसको_, _wżat, --, --,
   {{0x7bdc2c09,0xb0dd3ad1,0x80c30081,0x00000000}},	//   luru, _मांग, _শান্, --,
   {{0xf99f02f1,0x6d8b003d,0x00000000,0x00000000}},	//   _prèv_, _użat, --, --,
   {{0x7bdc03b4,0x61e9c358,0xa4380805,0xdce700e8}},	//   nuru, etel, язку_, nojā,
   {{0xbebb0052,0xa3c100c3,0x00000000,0x00000000}},	//   gjël, _्टर_, --, --,
   {{0x7bdcc359,0x05760e25,0x61e9c35a,0x2d4d02c6}},	//   huru, _قائد, gtel, užek_,
   {{0x3ea900ae,0xf99f0154,0xc17800c6,0x00000000}},	//   _sfat_, _trèv_, ulė_, --,
   {{0x61e9c35b,0x7bdc4218,0xd36f002d,0xa2d70096}},	//   atel, juru, _ач_, _याच्,
   {{0x7bdcab4a,0xdb150103,0xf99f022b,0x69d60216}},	//   duru, sszú, _krèt_, krye,
   {{0x61e9002d,0x925a0192,0x00000000,0x00000000}},	//   ctel, _بشار_, --, --,
   {{0x961d00d9,0xd0101ac9,0x7bc71e8f,0xc05a004d}},	//   _uzņe, _ملت_, tsju, _мій_,
   {{0x7bdcc35c,0xdd94013f,0x9f590068,0x8aac0174}},	//   guru, тары, író_, _ọgịg,
   {{0xd13829aa,0x7bc75481,0x69d60216,0x6ab602ac}},	//   lką_, rsju, frye, gbyf,
   {{0x7aed02fe,0x0dbb1e49,0xf99f0990,0x7bc7c35d}},	// [f990] rfat, _باعث_, _què_, ssju,
   {{0x7bdcc35e,0xd13816e0,0x7aed3292,0x98a301d3}},	//   buru, nką_, sfat, _bojā_,
   {{0x25ad0db8,0x61e9c35f,0x7bdc023f,0x7aed13f8}},	//   _stel_, ztel, curu, pfat,
   {{0x61e9c360,0x98bf008b,0x6282010a,0x3d1d00bc}},	//   ytel, ırın_, _ozoo, मावे_,
   {{0xd2460080,0x6b8dc361,0xfad600a1,0x79a47305}},	//   _إن_, mmag, _אורך_, _арсе,
   {{0x38780088,0x6b8dae18,0xf99f022b,0xb0dd0179}},	//   _fyrr_, lmag, _drèt_, _माइग,
   {{0x36d51e6e,0x64e00096,0xd138007f,0x644e00d8}},	//   _повр, _नारळ, dką_, _žbir,
   {{0x61e9c362,0x6d55429e,0x4917030b,0x02050012}},	//   ttel, hiza, नाको_, езин,
   {{0x61e90a9f,0x6d554835,0x5155534d,0x7bdc1ab9}},	//   utel, kiza, етну, zuru,
   {{0x7fd504a1,0x7bdc0511,0x70d90096,0x6d5571f9}},	//   німі, yuru, ढलेल, jiza,
   {{0x61e9c363,0xdee61a9c,0xdbd703cf,0x628206b0}},	//   stel, нони, _jääv, _ezoo,
   {{0x61e9c364,0x7bdcc365,0x9f48052f,0xc7d600ca}},	//   ptel, vuru, _opnå_, עורי_,
   {{0xee373f90,0x6d55c366,0x7bdc0294,0x6464020a}},	//   еня_, fiza, wuru, ătiţ,
   {{0x7bdca1ae,0x6d55c367,0xd13824c5,0x6b8d0381}},	//   turu, giza, cką_, emag,
   {{0x6b8d003e,0x629c00b6,0xf99f0154,0x00000000}},	//   fmag, ěrov, _orès_, --,
   {{0x28e202e8,0x7bdc11b8,0xab2737e8,0x63a1190c}},	//   _पाहि, ruru, носа_, _muln,
   {{0x2d9629b7,0xe9da0108,0x6d55a0fd,0xdca62636}},	// [f9a0] _прос, яка_, biza, _папи,
   {{0x7bdc3a0d,0x6d552436,0xf4050023,0x186a00e5}},	//   puru, ciza, _đãng_, пази_,
   {{0x313600c1,0x3d1d0096,0x6b8dc368,0x00000000}},	//   ענעם_, मारे_, bmag, --,
   {{0xf99f06a3,0x78bb09ac,0x6b8d0231,0x02be00b6}},	//   _prèt_, _đuve, cmag, _एजेन,
   {{0x6a9b00a1,0x2d9a05bd,0x63a1020d,0x3bf000a3}},	//   _משכנ, _kipe_, _auln, _चहुँ_,
   {{0x63a1009c,0xf99f0154,0x2d9a7680,0xbebb0216}},	//   _buln, _erès_, _jipe_, gjëj,
   {{0x7696074e,0x63a10113,0x290a010a,0x2d9a05db}},	//   _büyü, _culn, _iaba_, _mipe_,
   {{0x290ac369,0xf99f5ca6,0x2d9a0559,0x6d556eb8}},	//   _haba_, _grès_, _lipe_, ziza,
   {{0x0566251e,0xd25000cd,0x6d553c74,0xf7434a09}},	//   _зван, شند_, yiza, _сето,
   {{0x290a00cd,0x6602646a,0xd1380138,0x2d9a6680}},	//   _jaba_, mwok, uką_, _nipe_,
   {{0xd13840f0,0x2013002b,0x63a111bc,0x290ac36a}},	//   rką_, _áxil_, _guln, _maba_,
   {{0x290ac36b,0xd13816e0,0x2d9a0065,0xdb1c00a2}},	//   _laba_, ską_, _aipe_, nsrä,
   {{0x6b4300aa,0x82332729,0x00000000,0x00000000}},	//   _jõge, _مروا, --, --,
   {{0x236001ac,0x290a4db0,0x2d9a06f8,0x2c0d0096}},	//   čiju_, _naba_, _cipe_, हिलं_,
   {{0x291f0019,0x00000000,0x00000000,0x00000000}},	//   _đua_, --, --, --,
   {{0x6d55c36c,0x6b8d02b1,0x8e1500d3,0x290a7803}},	//   siza, umag, _адиц, _aaba_,
   {{0x290a80c4,0x6b8dc36d,0xdb1c0149,0x49753340}},	// [f9b0] _baba_, rmag, dsrä, влас,
   {{0x3eb902dc,0x602a00a7,0xdbd7007b,0x290ac36e}},	//   lbst_, həmm, _pääv, _caba_,
   {{0xb909c36f,0x3f896e0c,0xf99f5dd1,0x290ac370}},	//   _या_, _khau_, _près_, _daba_,
   {{0xcb3500e5,0x613f014b,0x7c2a1c26,0x36d50095}},	//   _ремъ, _mêla, _àfra, тодр,
   {{0xa5093a7a,0x5b14013d,0x290a002b,0x9a840265}},	//   дела_, _смят, _faba_, _бурл,
   {{0x290a0a75,0x3f89023e,0xf99f0154,0xaae10bd9}},	//   _gaba_, _lhau_, _frèr_, _फाँक,
   {{0xf99f04ea,0x3ce9417a,0x3206019c,0x27f40206}},	//   _très_, _जाने_, _asoy_, čaná_,
   {{0xe2995f56,0x3f890028,0x236902dd,0x9f5d0181}},	//   май_, _nhau_, čajo_, _prvý_,
   {{0x339200e3,0x13060084,0x290ac371,0xa92600e8}},	//   جليز, тный_, _yaba_, bežā,
   {{0x63a100aa,0xdb1c0120,0x00000000,0x00000000}},	//   _tuln, msrå, --, --,
   {{0xef861ad5,0x3f89009c,0x3f6a0284,0x854400ae}},	//   клоп, _bhau_, дино_, _сэте,
   {{0xbebb00dd,0x2d9a08dd,0x3f89c372,0x6da600ae}},	//   njëh, _sipe_, _chau_, кима,
   {{0x3f8901bb,0x28e209c4,0xdb1c17d2,0x910500d3}},	//   _dhau_, _पालि, nsrå, _апле,
   {{0x3afc00fe,0x00000000,0x00000000,0x00000000}},	//   _ập_, --, --, --,
   {{0x290ac373,0x00000000,0x00000000,0x00000000}},	//   _raba_, --, --, --,
   {{0x290ac374,0xf8b90023,0x60c37fa5,0xdb1c0572}},	//   _saba_, _đũa_, _henm, ksrå,
   {{0x2d9ac375,0xc332028c,0x60c31cab,0x9e6600d6}},	// [f9c0] _tipe_, בון_, _kenm, _швид,
   {{0x3ce90da9,0x290a0188,0xdb1c6265,0x637e0052}},	//   _जाये_, _qaba_, dsrå, gënj,
   {{0x60c302f1,0x290a007a,0x8c460cc6,0xdb1c0c19}},	//   _menm, _vaba_, _рене, tsrä,
   {{0x60c313fb,0x290aae6c,0xf99f03a9,0x6b4300aa}},	//   _lenm, _waba_, _isèn_, _põge,
   {{0x290a29e5,0x7ae400f9,0x7bda1656,0x3ce900b7}},	//   _taba_, mgit, štud, _जामे_,
   {{0x7ae4007a,0xcdb700a1,0x66022253,0x4616010d}},	//   lgit, דפסה_, rwok, _یوزر,
   {{0xdcee05db,0x00000000,0x00000000,0x00000000}},	//   jobč, --, --, --,
   {{0xd5b200cd,0x7ae42bd4,0x68e14e8d,0xdcee0e9e}},	//   _نفر_, ngit, _öldr, dobč,
   {{0x35a61456,0xe5a6638e,0x25a60113,0x799c05bd}},	//   _разг, _ризи, qqol_, _kirw,
   {{0x3ea00257,0x799c01c2,0xc05a0565,0x60c3033c}},	//   _agit_, _jirw, дім_, _cenm,
   {{0x60c3c376,0x3f890197,0x41d42674,0x26c4031b}},	//   _denm, _phau_, _दिवस, _kemo_,
   {{0x60c30cad,0x3f89023e,0x20070085,0x26c4c377}},	//   _eenm, _qhau_, _dsni_, _jemo_,
   {{0x3eb90364,0x60c305aa,0x7ae44ba8,0x7762464f}},	//   rbst_, _fenm, dgit, inox,
   {{0xc6930089,0x26c4b080,0x799cc378,0x60c3093e}},	//   יאר_, _lemo_, _nirw, _genm,
   {{0x3f896f3b,0x2d4d1100,0x9f6b261f,0x60c80324}},	//   _thau_, džet_, _ориз_, madm,
   {{0xeab30080,0x26c46a75,0x05d20789,0x7ae48847}},	//   شعر_, _nemo_, _सिंब, ggit,
   {{0x799c2771,0x61e0c379,0x60c30233,0x3dc000eb}},	// [f9d0] _birw, numl, _yenm, _gwiw_,
   {{0x58b80080,0x60c82791,0x3ad300de,0x6f0d0350}},	//   نامج_, nadm, ệp_, _haac,
   {{0x26c40483,0x61e003e0,0x637e023b,0x36b00134}},	//   _bemo_, huml, rënj, _ịnọk,
   {{0x26c404a3,0x236602e6,0xdb1cc37a,0x61e00d33}},	//   _cemo_, _njoj_, tsrå, kuml,
   {{0x6f0dc37b,0x61e051b5,0x799c00eb,0x80c30033}},	//   _maac, juml, _firw, _শাস্,
   {{0x6b9d0eac,0x6f0dc37c,0x236600c4,0x799c010a}},	//   _hisg, _laac, _ajoj_, _girw,
   {{0x60c30c56,0x29010095,0xe4e400d6,0x60c8037a}},	//   _renm, meha_, річн, dadm,
   {{0x442902e6,0x60c30383,0x2901a47b,0x6b9d02a1}},	//   ća_, _senm, leha_, _jisg,
   {{0x6b9d34d5,0x69cd00f0,0x60c3c37d,0xdb150103}},	//   _misg, nsae, _penm, lszó,
   {{0x814500cd,0x66097a3e,0x290147aa,0x26c4c37e}},	//   اندن, _isek, neha_, _zemo_,
   {{0x68e50a1b,0x6b6500c6,0x6f0d7803,0xb5fd00c6}},	//   ighd, jėgo, _baac, _ryšy,
   {{0xe1f100bf,0x29cf00d9,0x8af000a7,0x60c303e3}},	//   _هست_, kļa_, nnət, _wenm,
   {{0x60c327de,0x60c800b3,0x6f0d0188,0x8e560c10}},	//   _tenm, badm, _daac, утні,
   {{0x29010268,0x6da31510,0xe81605cd,0x6b9d033f}},	//   jeha_, сира, णिमा_, _aisg,
   {{0x8c4321fd,0x2007015c,0x09cc0096,0x7ae400f9}},	//   бере, _usni_, ाळ्य, tgit,
   {{0x3ea000f9,0x6b9d0036,0x6609019f,0x799c19a2}},	//   _ugit_, _cisg, _osek, _sirw,
   {{0xc33203c2,0x6609012d,0x6b9d88f5,0x7f44063d}},	// [f9e0] זון_, _nsek, _disg, _iliq,
   {{0x26c40036,0x7ae4c37f,0xcd0602f3,0x00000000}},	//   _semo_, sgit, _спой, --,
   {{0x3ce93abb,0x66099a38,0x6b9d0131,0x7ae40120}},	//   _जाते_, _asek, _fisg, pgit,
   {{0x6aad028d,0xdbd200bc,0x799c0381,0x61e01577}},	//   ccaf, _müüv, _wirw, yuml,
   {{0x26c40087,0x7bce0973,0x81a90033,0x29010381}},	//   _vemo_, lsbu, গীত_, beha_,
   {{0x18a32a6a,0x27e100dc,0x7bdcc380,0x245803a0}},	//   _гарм, buhn_, orru, каль_,
   {{0x26c402dd,0x7bce10ef,0xec3600c1,0x6609a228}},	//   _temo_, nsbu, טאַר_, _esek,
   {{0x395a535f,0x5334085f,0x61e0a034,0xb042020b}},	//   lips_, реит, tuml, _ngưở,
   {{0x6f0d0694,0x25a46362,0x602a00a7,0x60c81394}},	//   _raac, _uuml_, məmi, tadm,
   {{0x61e08368,0x7f44c381,0x6f0d4ed8,0x7bce3155}},	//   ruml, _aliq, _saac, ksbu,
   {{0x7bce1cae,0x637e00dd,0xd8db006e,0xf5930037}},	//   jsbu, hëni, עקטר, _اللج,
   {{0x7f44c382,0x7bce0407,0x395a3d0f,0x6f0d0188}},	//   _cliq, dsbu, hips_, _qaac,
   {{0x2d4d0542,0x6b9dc383,0x7bce02ac,0x3ce9007a}},	//   džer_, _risg, esbu, _जादे_,
   {{0x3d0f0034,0x6f0d0239,0xdb150103,0x7f44019f}},	//   ायें_, _waac, sszü, _eliq,
   {{0x602a0092,0xbc950396,0x7bce2a0d,0x645c02ef}},	//   kəmi, равј, gsbu, _žrij,
   {{0x6d47682d,0x2901024a,0x00000000,0x00000000}},	//   shja, weha_, --, --,
   {{0xa3e40569,0xb955008f,0x29010167,0x6b9d250f}},	// [f9f0] भूत_, аващ, teha_, _visg,
   {{0xdb150103,0x395a044c,0x660902ac,0x69cd738f}},	//   tszó, gips_, _rsek, rsae,
   {{0x6d4501d4,0xa3a9048a,0x2901c384,0x6d5700bd}},	//   _ilha, _गंध_, reha_, _imxa,
   {{0x66090062,0xa6155bc6,0x6b9d0013,0x3f420af0}},	//   _psek, имеч, _uisg, _lóun_,
   {{0x3d0a02e8,0x29018112,0xf62501b6,0xe4c525d7}},	//   ायचे_, peha_, рдло, айли,
   {{0xdfc608ba,0x66090087,0x8cba0521,0x290f01d3}},	//   _وي_, _vsek, ्रयो, ēgas_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6609566a,0x613f0131,0x2b4900fe,0x947400d1}},	//   _tsek, _pêlo, nhac_, حدها,
   {{0x6d450396,0xaca30065,0xb1451fbf,0x3f420139}},	//   _olha, _ajọd, инил, _bóun_,
   {{0xe9ff00de,0x3d0f007f,0x00000000,0x00000000}},	//   _giấc_, ायों_, --, --,
   {{0xa069188d,0x046740b2,0xb4d10096,0x7f4400b3}},	//   тана_, _стам, वणी_, _pliq,
   {{0x6d450d2a,0x6d570188,0x2ba9034c,0x2f56400f}},	//   _alha, _amxa, _कढ़ा, ртос,
   {{0x6d45023e,0x93940018,0xada60138,0x6da6038f}},	//   _blha, _اجلا, рагл, рига,
   {{0x823400bf,0xc0e25550,0x2d9e1664,0x7bce141d}},	//   _درما, _дошк, öte_, tsbu,
   {{0xb7b000c7,0x30790130,0x207900c1,0xdea200cd}},	//   _চট্ট, _באַנ, _באַא, _ویدی,
   {{0x6d45c385,0x224d01ff,0xbb430161,0x7f44063d}},	//   _elha, ozek_, оеск, _uliq,
   {{0xeb973457,0x3b072de0,0x395a032e,0x09e65e39}},	// [fa00] рит_, шето_, tips_, розн,
   {{0x7bce01af,0x1aee0081,0x777b0372,0x637e0216}},	//   psbu, _চোখে_, _akux, rëni,
   {{0xc796013f,0x395ac386,0x602a00a7,0x59da0285}},	//   арды, rips_, təmi, यूजर,
   {{0x6d5cc387,0x28e2269c,0x09e60084,0x38ac0139}},	//   lira, _पाकि, _комн, _bòró_,
   {{0xd64e0294,0x613f084e,0xf1d400b6,0x00000000}},	//   mọkụ_, _pêll, _दिइन, --,
   {{0x2b4000e7,0x777b0415,0xa96a107a,0x00000000}},	//   lkic_, _ekux, _рига_, --,
   {{0x0fe000c7,0xb7da0113,0x224d01ff,0x4aaa2172}},	//   _বন্ধ, _جوزا_, ezek_, _कलाव,
   {{0x6d5cc388,0x320a0034,0x38ac0065,0x2b400a39}},	//   hira, łbym_, _fòró_, nkic_,
   {{0x6d5cc389,0xd5a4001c,0x2166008d,0xdb0502c3}},	//   kira, _طلای, итог, _uthå,
   {{0x6d5c8926,0x09f700ca,0x657a4807,0x00000000}},	//   jira, סמים_, _ukth, --,
   {{0x940600bf,0x1306013d,0xb4c2049d,0x2d4d0a39}},	//   _خواه, _взем, ंरी_, džep_,
   {{0x6d5c137f,0xd49100de,0xc2e90076,0x2b4005db}},	//   eira, _này_, _معهم_, jkic_,
   {{0x224d00a5,0x6d45022e,0x443c0031,0xee871402}},	//   czek_, _plha, lyv_, рыно,
   {{0x657d0910,0x6d5c1dd0,0x73fa0033,0x00000000}},	//   _ësht, gira, ্মীয়_, --,
   {{0x443c0018,0xb0b700ca,0x5f9500d3,0x00000000}},	//   nyv_, _דפוס_, _ликт, --,
   {{0x4fb30fba,0xb09b0089,0x7e6d0a00,0xe51d1bc3}},	//   _بصور, _ביור, _txap, _योनि_,
   {{0x6d5cc38a,0x443c037a,0x63a8b655,0x8d8728b0}},	// [fa10] bira, hyv_, _ludn, _вунд,
   {{0x2369011d,0xb4c20285,0x63a80b8e,0x00000000}},	//   čaji_, ्णो_, _oudn, --,
   {{0x2d8308a9,0x69c0023b,0x46b40294,0x63a80c6f}},	//   mlje_, _çmen, _ịtọ_, _nudn,
   {{0xd3660604,0x2d833b16,0xe79600d1,0x00000000}},	//   _ره_, llje_, مانک, --,
   {{0xa9971ac9,0x201a05db,0x2d8300f3,0x00000000}},	//   _نشست, _špil_, olje_, --,
   {{0xb4d1009d,0xd4693084,0x3a360327,0x24e90120}},	//   वणे_, лиле_, _הרשם_, умки_,
   {{0xbebb023b,0x58d400d3,0x3f82008c,0x612d01f9}},	//   njës, _фост, ylku_, _túlz,
   {{0x130900d3,0x224d0634,0x777b0201,0x29113170}},	//   уний_, tzek_, _ukux, _haza_,
   {{0x6d5cb4d8,0x291143ad,0x7f5d00b3,0xdb0e014b}},	//   yira, _kaza_, disq, édéf,
   {{0x661b5c6e,0x77b302a1,0x2911024a,0x6d5cc38b}},	//   _iruk, _eħxe, _jaza_, xira,
   {{0x224d1feb,0x2911c38c,0x93270018,0xf99f022b}},	//   szek_, _maza_, _پران, _asèk_,
   {{0x6d5cc38d,0x3ea401df,0x69dd0096,0x00000000}},	//   wira, ømt_, _पिढी, --,
   {{0xf1a733ed,0xe28e4a54,0x237400e3,0xade300c3}},	//   _трен, _ха_, _بالح, कूलन_,
   {{0x7c3c01df,0x2911c38e,0x661b7a54,0x2d8305db}},	//   tyrr, _naza_, _mruk, glje_,
   {{0x6d5cc38f,0x8c431116,0xbebb00dd,0x92e90081}},	//   rira, пере, gjës, য়ী_,
   {{0xaec62cf1,0xce5a001c,0x6b8f009c,0x6d5c3f43}},	//   _убил, _مشخص_, _chcg, sira,
   {{0x29110619,0x2d8300cb,0x612d0018,0xe8fa4a30}},	// [fa20] _baza_, blje_, _súly, лла_,
   {{0xeeeb0019,0x291104d8,0x4a430396,0x6d5cc390}},	//   ượng_, _caza_, чнув, qira,
   {{0x3ead28d9,0x291101c2,0x661bc0e2,0x9b460286}},	//   žete_, _daza_, _aruk, _هندو,
   {{0x661b50f7,0x6f0608a9,0xab2a007e,0x929d007f}},	//   _bruk, nekc, _сома_, zeła,
   {{0x6b840222,0x991602ec,0x63a8050d,0x3d1d0096}},	//   mlig, _льві, _sudn, माचे_,
   {{0x29113cd3,0x28e20455,0xbebb0052,0x443c0c89}},	//   _gaza_, _पाटि, njër, tyv_,
   {{0x68e3c391,0x661bb01c,0x6b8409a1,0xd37a21fd}},	//   ónde, _eruk, olig, лчи_,
   {{0x6b8409ce,0x661b038b,0xb9250294,0x35a6065c}},	//   nlig, _fruk, kepụ_, _гааг,
   {{0x3ce900aa,0xcb1300ca,0x291197e7,0x6d80007b}},	//   _जाले_, ללה_, _yaza_, löau,
   {{0x3a370054,0x63a80018,0x6b84c392,0xf8ba0179}},	//   צרים_, _tudn, hlig, ेरिय,
   {{0x2d8300e9,0x6b84b1a4,0xe97b00c1,0x7f5dc393}},	//   vlje_, klig, רניש, tisq,
   {{0x6b845f23,0x8f47598f,0x398f0364,0x923b02c6}},	//   jlig, сход, müse_, ířát,
   {{0x7f5d04d4,0x6b8416f4,0x2d8309ac,0x00000000}},	//   risq, dlig, tlje_, --,
   {{0x63a200e3,0x6b650138,0x21674cc3,0xbebb0052}},	//   _hion, mėgi, _личи_, gjër,
   {{0x63a20010,0x853b040a,0x29118e0b,0x6fb4029e}},	//   _kion, נגלי, _raza_, _بمبا,
   {{0x6b8416f4,0x63a20051,0x2d830880,0xbab94ead}},	//   glig, _jion, slje_, ргах_,
   {{0x63a2c394,0x291100ae,0x660412b9,0x201c0234}},	// [fa30] _mion, _paza_, çikl, _hrvi_,
   {{0x3947a212,0x63a207bc,0x6b8471da,0xdcee044c}},	//   óns_, _lion, alig, robă,
   {{0x6b8468fc,0x4c954abb,0xe7870c10,0x645e0031}},	//   blig, _финс, будо, úpil,
   {{0x501b00ca,0x62820134,0x63a2b14b,0x7d07c395}},	//   טובו, _oyoo, _nion, lejs,
   {{0xbf4702b4,0x62820197,0x29110314,0xd6295a67}},	//   únṣe_, _nyoo, _taza_, роле_,
   {{0x81b700c7,0x7d070f1c,0xf2b30eeb,0x63a20350}},	//   _ছিল_, nejs, ीर्घ, _aion,
   {{0xf8ae0688,0x6282c396,0xc7c4002d,0x00000000}},	//   _شکل_, _ayoo, _нсти, --,
   {{0x63a20099,0x661b4650,0xc2452c22,0xf1d40034}},	//   _cion, _truk, жник, _दिखन,
   {{0x63a2c397,0x661b023f,0x7d07033b,0xda1c007f}},	//   _dion, _uruk, kejs, नियत_,
   {{0x92e90f71,0x26cfc398,0x628b02dd,0x63a202a1}},	//   য়ে_, lago_, _vzgo, _eion,
   {{0x5f06215f,0x63a20a1b,0x6b845675,0x7d077b2f}},	//   озна, _fion, ylig, dejs,
   {{0x26cfbfbd,0x7c2a0428,0x63a2b8f9,0x201c05db}},	//   nago_, _àfri, _gion, _drvi_,
   {{0x6b840bab,0x80ba074c,0x23780103,0x62820172}},	//   vlig, _श्वे, _írja_, _gyoo,
   {{0x236902e6,0x7afd54fe,0x26cfc140,0x7d0702b6}},	//   čaju_, _abst, hago_, gejs,
   {{0x6b84c399,0x26cf47af,0xdca3260f,0xf99f0154}},	//   tlig, kago_, дари, _frèz_,
   {{0x63a201fa,0xeeeb00de,0x26cf38a4,0xb33c02a1}},	//   _xion, ưỡng_, jago_, _ruħk,
   {{0x6b8416f4,0x26cf5570,0x62820197,0x00000000}},	// [fa40] rlig, dago_, _xyoo, --,
   {{0x7afd00f9,0xf99f0154,0x090300ba,0x00000000}},	//   _ebst, _krèy_, мпун, --,
   {{0xb9020067,0xcc8a00bf,0x6b84c39a,0xc6a6107a}},	//   _नए_, _خنده_, plig, орли,
   {{0x34b40dba,0xe61a0f99,0x06860d0f,0x6b840188}},	//   ुर्द, иде_, оген, qlig,
   {{0x63a288e4,0x929d007f,0x2b47044c,0x00000000}},	//   _rion, wełn, _înca_, --,
   {{0x6d4ec39b,0xf99f0154,0x26cf0172,0x00000000}},	//   nhba, _orèy_, aago_, --,
   {{0xf7460f7e,0x26cfc39c,0xd57507bf,0x186720c0}},	//   _дево, bago_, чуць, _дари_,
   {{0x7d07278c,0x26cfc39d,0x70e22172,0x662502c6}},	//   zejs, cago_, पल्ल, átký,
   {{0x63a2068d,0x05660ffa,0x6d4e1470,0x416a0291}},	//   _vion, _дван, khba, ијом_,
   {{0x929d00a5,0x321d02ad,0xd13a0dfb,0x6282024a}},	//   pełn, _drwy_, рхи_, _vyoo,
   {{0xe81d0775,0x63a2ad78,0x6d4e00e3,0x7d07c39e}},	//   फिया_, _tion, dhba, vejs,
   {{0x80ba06e4,0x201c0117,0xd24600ae,0x63a20350}},	//   _श्रे, _vrvi_, _мэли, _uion,
   {{0x3326071a,0x079b0341,0xdb1c5756,0x7d079a37}},	//   _inox_, יסטל, mprè, tejs,
   {{0x26cf0634,0x656a0076,0xdcf702a1,0x00000000}},	//   zago_, nnfh, _mixħ, --,
   {{0x7d07390f,0x26cf23c8,0x93bc00ae,0xf99f022b}},	//   rejs, yago_, _drăg, _trèz_,
   {{0x671900a3,0x26cf01c8,0x00000000,0x00000000}},	//   _नोंक_, xago_, --, --,
   {{0xaf4b0688,0x26cf771f,0x7d070034,0x3ea9630c}},	// [fa50] _مشکل_, vago_, pejs, _igat_,
   {{0x6d4e02e2,0xcd0000a5,0x929d007f,0x00000000}},	//   chba, ęści_, zeło, --,
   {{0x26cf5977,0xb8d30455,0x00000000,0x00000000}},	//   tago_, _ऑल_, --, --,
   {{0xaca30134,0x4758004d,0x00000000,0x00000000}},	//   _chụd, орія_, --, --,
   {{0x26cf1a11,0x98aa0034,0x59e20aa6,0x00000000}},	//   rago_, _sobą_, _पियर, --,
   {{0x7aed2ba2,0xd0a20af0,0x2ea80f77,0xa5092636}},	//   lgat, _gẹgẹ, _गल्त, сека_,
   {{0x26cfc39f,0x2b4b061d,0x64a20284,0x1b0e0033}},	//   pago_, _klcc_, наша, হারে_,
   {{0x7aed3d3a,0x3f99007e,0x3ea9c3a0,0xf2d101f3}},	//   ngat, jmsu_, _ngat_, رآب_,
   {{0x020200ae,0x93bc044c,0xc2e80076,0x00000000}},	//   езын, _arăd, زعيم_, --,
   {{0x3ea90080,0x2eb60f62,0xe3b31f11,0x9f46020d}},	//   _agat_, ूर्त, _قرص_, mulé_,
   {{0xf3f000e3,0x48fd06e4,0x00000000,0x00000000}},	//   _لأن_, र्यो_, --, --,
   {{0x321d02ad,0x3f6a05d8,0x23fa00ca,0x2d810201}},	//   _trwy_, симо_, _לפעמ, _akhe_,
   {{0x9f462e6d,0x7aed44df,0x25a5a728,0x23b105f1}},	//   nulé_, dgat, _kill_, _háj_,
   {{0x7aedc3a1,0x61e9aaba,0xb2260088,0x7bda013f}},	//   egat, muel, stæð, štum,
   {{0xa0661c03,0x93bc00d3,0x3eadc3a2,0xb95b0139}},	//   _наша_, _grăd, žeta_, _ewìk,
   {{0x25a504f9,0x23b16cf4,0x7aedc3a3,0x8b953ea8}},	//   _lill_, _máj_, ggat, друч,
   {{0x6b6500c6,0x00000000,0x00000000,0x00000000}},	// [fa60] jėgu, --, --, --,
   {{0x7aed01e9,0x9f46001c,0xef1801d3,0xe9d707bf}},	//   agat, dulé_, ēļu_, яку_,
   {{0x61e9c3a4,0xdb240018,0xd0a20139,0x6d3b00d7}},	//   huel, _ہوگی, _gẹdẹ, _התינ,
   {{0x61e9c3a5,0x25a51ab6,0x44224582,0xdb1c0113}},	//   kuel, _aill_, _čk_, kpré,
   {{0xd6cf012b,0x61e9034f,0xceb3040a,0x25a500ca}},	//   اقه_, juel, גיד_, _bill_,
   {{0x25a50527,0x61e9407b,0x4536018a,0x00000000}},	//   _cill_, duel, яхет, --,
   {{0xb4ac0251,0xa84a0037,0x53341bc1,0x00000000}},	//   _गली_, _الأم_, дейт, --,
   {{0xe3af00bf,0x25ad863d,0x98a31aad,0x9f4603a9}},	//   درو_, _fuel_, _чисе, bulé_,
   {{0x6d5e9720,0xdb1c36e7,0x69d6c3a6,0x9f46020d}},	//   _ompa, rprè, nsye, culé_,
   {{0x25fb04a9,0x7aed0018,0xdb1c5c16,0x6d5e00dc}},	//   ोबरी_, zgat, sprè, _nmpa,
   {{0xc05a01b6,0x764203e3,0xadc40032,0x3dc90154}},	//   сіп_, lyoy, _iyẹw, _swaw_,
   {{0x6d5e0b27,0x69d66d64,0x6f1676ca,0x753a01e9}},	//   _ampa, ksye, _cayc, _hotz,
   {{0x61e914e2,0x76421114,0x753a10ef,0xd3370327}},	//   cuel, nyoy, _kotz, _מראה_,
   {{0x753a0a00,0x7aed009c,0x93bc020a,0x7bd55c07}},	//   _jotz, wgat, _trăd, tszu,
   {{0x01335d50,0x1dd90789,0x753a01c8,0x317e01e9}},	//   _سعود, _भटकत, _motz, motz_,
   {{0x7aed00d3,0x3ea91281,0x3ce9007a,0x753a01e9}},	//   ugat, _ugat_, _जाके_, _lotz,
   {{0x7aed6f4e,0x7bd50018,0x7f4d8237,0xad27046b}},	// [fa70] rgat, sszu, _ilaq, _فردو,
   {{0x7aedc3a7,0x48ab1480,0xa41c009f,0x25ad00f9}},	//   sgat, стам_, पटाप_, _ruel_,
   {{0xf7700281,0x69d605aa,0x00000000,0x00000000}},	//   گال_, asye, --, --,
   {{0xf7730b05,0xf1dd00a5,0xadc40032,0xf99f0113}},	//   راض_, _मिलन, _ayẹw, _asèt_,
   {{0x25ad8cd8,0x61e9c3a8,0x76420270,0x7f4d02a1}},	//   _quel_, xuel, gyoy, _mlaq,
   {{0x61e90890,0x9f460072,0x6d476c91,0xc984004d}},	//   vuel, rulé_, nkja, _зуси,
   {{0x25a5509d,0xe9ff0019,0x753a4fcc,0x93bc078e}},	//   _vill_, _khắc_, _dotz, _arăb,
   {{0x25a58718,0xb22530fd,0x7528b459,0x7f4d0090}},	//   _will_, дмил, _endz, _nlaq,
   {{0x25a51368,0x6d47c3a9,0xf77009e5,0x67290027}},	//   _till_, kkja, _صاف_, _inej,
   {{0xdb1c911d,0x48f2030b,0x753a0634,0x320d676c}},	//   rpré, ुभयो_, _gotz, rwey_,
   {{0xdee61a77,0xdb1c0990,0x65630396,0x6729009e}},	//   мони, spré, minh, _knej,
   {{0x6563c3aa,0x6d5e0808,0xe9ff00de,0xe8050034}},	//   linh, _smpa, _nhắc_, _रहना_,
   {{0x61e96d52,0x236d17b5,0xa2940426,0x7d1723f4}},	//   quel, mnej_, _заці, _baxs,
   {{0x236d2ac2,0x6563c3ab,0x2480026a,0xe1f900c6}},	//   lnej_, ninh, şime_, mtų_,
   {{0x6da308c3,0x628f0039,0xe1f90138,0x6729c3ac}},	//   тира, škoć, ltų_, _onej,
   {{0xe9ff0028,0x6563c3ad,0x236dc3ae,0x76420d2a}},	//   _chắc_, hinh, nnej_, yyoy,
   {{0xe1f901b3,0x6563c3af,0x6d5e02e7,0xed5a17aa}},	// [fa80] ntų_, kinh, _tmpa, _мои_,
   {{0x6d5e1084,0x69d6027f,0x65630161,0x6443b688}},	//   _umpa, rsye, jinh, kyni,
   {{0x65630396,0x673b02f1,0x672902a1,0x753a0acb}},	//   dinh, _bouj, _bnej, _rotz,
   {{0xe1f901b3,0x644352d4,0x236d3f8a,0xb95b0139}},	//   ktų_, dyni, jnej_, _atìd,
   {{0x236d6e9f,0x7d17013c,0x6563a7a9,0x77620634}},	//   dnej_, _yaxs, finh, riox,
   {{0x65638ff4,0x64430150,0x8e570266,0x344a2c37}},	//   ginh, fyni, וינג_, жчин_,
   {{0x8af000a7,0x29181497,0x00000000,0x00000000}},	//   biət, _iara_, --, --,
   {{0x27f7000d,0x52140870,0xd0410092,0x8af000a7}},	//   žení_, едит, qalə, ciət,
   {{0x2918c3b0,0x6d470102,0x65637bae,0x26c6c3b1}},	//   _kara_, ykja, binh, mboo_,
   {{0x29185dd4,0x6563001f,0x270e0378,0x93bc00ae}},	//   _jara_, cinh, _ससुर_, _crăc,
   {{0x2918c3b2,0x236dc3b3,0x7f4dc3b4,0xc05700d6}},	//   _mara_, bnej_, _plaq, дія_,
   {{0x2918c3b5,0x122a00c2,0x236d56ff,0x38b50065}},	//   _lara_, _моей_, cnej_, _kúró_,
   {{0x291800ae,0xcd00007f,0x00000000,0x00000000}},	//   _oara_, ęśni_, --, --,
   {{0x291858dc,0x77600072,0x8ca00285,0x00000000}},	//   _nara_, _lmmx, _गृहो, --,
   {{0x5ba71e6d,0x6d4738e1,0x6b510d00,0xf99f0113}},	//   драз, rkja, _låge, _osèr_,
   {{0x65634d3b,0x29180139,0x6d472456,0x3cfb00aa}},	//   zinh, _aara_, skja, _लउके_,
   {{0x29183a99,0x64430034,0xd91b007b,0x00000000}},	// [fa90] _bara_, zyni, жье_, --,
   {{0x29182a2b,0x6563c3b6,0x661d0088,0x236d1c5c}},	//   _cara_, xinh, _áski, znej_,
   {{0x2918c3b7,0x6563001f,0xe9ff0019,0x248903e3}},	//   _dara_, vinh, _thắc_, ƙami_,
   {{0x05e00b94,0xe1f90138,0x2918009c,0x644300c6}},	//   _निशब, ytų_, _eara_, vyni,
   {{0x2918c3b8,0x65630396,0x236d0181,0x64430150}},	//   _fara_, tinh, vnej_, wyni,
   {{0x2918c3b9,0x6443c3ba,0xfbd012eb,0x236d0034}},	//   _gara_, tyni, _حتی_, wnej_,
   {{0x673bc3bb,0x6563c3bc,0x236d3239,0xd88300bf}},	//   _touj, rinh, tnej_, _شهری,
   {{0x29182d4d,0x65630a3a,0x38b533c3,0x6443c3bd}},	//   _zara_, sinh, _fúró_, ryni,
   {{0x236d1b3e,0x2918c3be,0x6563001f,0x64435d74}},	//   rnej_, _yara_, pinh, syni,
   {{0xdb0600dd,0xe1f9013f,0x236d3f8a,0x00000000}},	//   _pikë, rtų_, snej_, --,
   {{0xe1f901b3,0x236d2907,0x1ee800d1,0x00000000}},	//   stų_, pnej_, وودی_, --,
   {{0xe1f90138,0xd49830c0,0x00000000,0x00000000}},	//   ptų_, _цру_, --, --,
   {{0x3ea40149,0x25bf0090,0x00000000,0x00000000}},	//   ämt_, _jtul_, --, --,
   {{0x98aa030b,0xdb050018,0x61fbc3bf,0x2cac00f3}},	//   _době_, _ruhá, mtul, ødd_,
   {{0x29189710,0x61fbc3c0,0xeb9a4c8a,0xab2a8e4a}},	//   _rara_, ltul, зив_, пова_,
   {{0xdbd6007a,0x61fbc3c1,0xa3c20285,0x2be1c3c2}},	//   _rääg, otul, ्ठत_, _फिरा,
   {{0x2918c3c3,0x61fb4218,0x3f8252d7,0x6f040193}},	// [faa0] _para_, ntul, moku_, _ibic,
   {{0x5e5700c1,0x3f82c3c4,0x29180092,0xb95b0065}},	//   _נייע_, loku_, _qara_, _atìb,
   {{0x2918c3c5,0x25bf01c2,0x6e24033b,0xdb060094}},	//   _vara_, _atul_, _hrib, _liké,
   {{0x291804f9,0x3ae80068,0x61fb23ad,0x25bf1d49}},	//   _wara_, _کبھی_, ktul, _btul_,
   {{0x8af000a7,0xa3a902d5,0x6f041c35,0x00000000}},	//   rhəd, _गंज_, _mbic, --,
   {{0x59b51362,0x69c4c3c6,0x3f8220bb,0x6b511842}},	//   _अंतर, mpie, hoku_, _våge,
   {{0xf8a713ae,0x66e673f4,0xdcfc007e,0xdb06022b}},	//   _कृपय, _пова, jorč, _pikè,
   {{0x31c62776,0xe80524cf,0x6b514fbc,0x69c4c3c7}},	//   нсов, _रहता_, _tåge, opie,
   {{0x61fb2b72,0x69c4c3c8,0x6e2400b3,0xcfd10032}},	//   gtul, npie, _nrib, _ijẹẹ,
   {{0x2ee06df6,0x6f0427f8,0x09f700a1,0xdb060113}},	//   _adif_, _abic, עמים_, _diké,
   {{0xb4cc13ae,0xf65f0102,0x6e240193,0x61fbbab0}},	//   लरी_, _þær_, _arib, atul,
   {{0x3ead038c,0x98aa00b6,0x3f8201dc,0x21f900cd}},	//   øet_, _sobě_, goku_, bèh_,
   {{0x614605af,0x61fb00d3,0x6e24209a,0x69c40034}},	//   _педа, ctul, _crib, jpie,
   {{0x021700f5,0xc6930341,0x2d8500fd,0xf99f05aa}},	//   _נחום_, טאר_, ôle_, _apèn_,
   {{0xef1f03a3,0x6e24083e,0x3f82c3c9,0x69c48ac5}},	//   nlük_, _erib, boku_, epie,
   {{0xa3e81176,0xfaff0052,0x59b50e4c,0x3f823600}},	//   _बिन_, _ajër_, _अंदर, coku_,
   {{0x3da713b0,0x6e24c3ca,0x6b740236,0x98aa02c6}},	// [fab0] _проб, _grib, улту, _tobě_,
   {{0x6f0f2567,0x6f1dc3cb,0xa3c200c3,0xc6090033}},	//   lecc, ldsc, ्ठा_, লিমা_,
   {{0xfe7001f3,0x2d833616,0x69c40451,0xa3b00034}},	//   _ندی_, moje_, apie, _टूल_,
   {{0x6458c3cc,0x2d8317cc,0xdc3600c1,0x6f0f5ae9}},	//   dzvi, loje_, _סארט_, necc,
   {{0x6b8d0795,0x64580220,0xd7740192,0x6f1d0acb}},	//   mlag, ezvi, دالع, idsc,
   {{0x2d83c3cd,0x6b8d0b87,0x00000000,0x00000000}},	//   noje_, llag, --, --,
   {{0xe89400ce,0x6b8d01ff,0x437500d3,0x00000000}},	//   _барь, olag, куит, --,
   {{0x6b8dc3ce,0x61fbc3cf,0x6f1d0126,0x6f0f05fe}},	//   nlag, ttul, jdsc, jecc,
   {{0x2d83c3d0,0x11d600e3,0x6f0f0036,0x29cf5442}},	//   koje_, نوية_, decc, nża_,
   {{0x2d8301b3,0x61fbc3d1,0x6b8d02e2,0xd6846e54}},	//   joje_, rtul, hlag, _сусп,
   {{0x69c40067,0xf8b2028c,0x6b8d2ca7,0x2d83c3d2}},	//   zpie, ישי_, klag, doje_,
   {{0x6b8d5520,0x61fb00d3,0x7d0eb8ef,0x7d0501b9}},	//   jlag, ptul, webs, _abhs,
   {{0x780d000c,0x6b8dc3d3,0xee370243,0x2d83c3d4}},	//   सबुक_, dlag, вня_, foje_,
   {{0x0cb000c7,0x4d150879,0x2d8362fd,0xd13800a5}},	//   কর্ত, льст, goje_, cją_,
   {{0x69ddc3d5,0x6b8d1489,0xdbcc002b,0x61e90a04}},	//   _avse, flag, _póñe, lrel,
   {{0x6f04c3d6,0x6609c3d7,0x6b8dc3d8,0x6e24154c}},	//   _ubic, _opek, glag, _trib,
   {{0xf2d20130,0xef1f01e8,0x6e241a11,0x2d834160}},	// [fac0] יען_, zlük_, _urib, boje_,
   {{0x63abc3d9,0x08c35ccc,0x69c429d0,0x271e0174}},	//   _lign, ибун, rpie, _ịn_,
   {{0x69c4c3da,0x07a6487f,0x66099b90,0x628b5d5f}},	//   spie, важн, _apek, _lygo,
   {{0x0bb70054,0x66e64cb0,0x6b8dc3db,0x61e92c94}},	//   _שלכם_, тода, clag, krel,
   {{0x6b840257,0x61e9015c,0x628e0034,0x99460206}},	//   moig, jrel, ębok, môž_,
   {{0xa8061b4d,0x44250161,0x61e9044c,0x63ab4a76}},	//   _изгл, _brl_, drel, _aign,
   {{0x660920c1,0x63ab0380,0x6f0f1ea5,0x86ea0037}},	//   _epek, _bign, yecc, _يعرف_,
   {{0x6f0f08a8,0x63ab26ae,0x61e9c3dc,0xb6c80018}},	//   xecc, _cign, frel, _سارے_,
   {{0x6f0fc3dd,0xf743001f,0x9605001c,0xb3550504}},	//   vecc, _тето, _مبلم, دینا_,
   {{0x63ab23ff,0x6b8d0087,0x4a9b006e,0x2d830052}},	//   _eign, zlag, ויפג, xoje_,
   {{0x6f0f2567,0x2d837d92,0x61e90b1c,0x63abc3de}},	//   tecc, voje_, arel, _fign,
   {{0x6b840257,0xf99f02f1,0x2d5400aa,0x7bdc8cbf}},	//   joig, _apèl_, _näeb_, dsru,
   {{0x6f0f0e4d,0x2d83c3df,0x61e90233,0x6b8d0727}},	//   recc, toje_, crel, vlag,
   {{0xe9ff00ef,0x644501bf,0xac190396,0x0cbf0c3c}},	//   _nhạc_, ähig, ногу_, ्रेम,
   {{0x2d8373c9,0x6b8d1a88,0x7bdc1d21,0x6f0f7627}},	//   roje_, tlag, gsru, pecc,
   {{0x2d83c3e0,0x6b8d03a9,0x00000000,0x00000000}},	//   soje_, ulag, --, --,
   {{0x497513b0,0x6b8d1a02,0x2d830b17,0xdb120037}},	// [fad0] глас, rlag, poje_, ágái,
   {{0x6b8d35b6,0x29cf3b3a,0x29190e25,0xef1f0511}},	//   slag, rża_, عقاد_, ldü_,
   {{0x6c3509f4,0x6b8d0d90,0x61e945ca,0xa8a71a1b}},	//   _صفحا, plag, zrel, трак,
   {{0x7bc7c3e1,0x61e96265,0xc2e80081,0x7c2a0088}},	//   mpju, yrel, ক্তি_, _áfra,
   {{0x4425c3e2,0x62fa0081,0x63ab01cd,0x6b510429}},	//   _srl_, ্যায়_, _rign, _gåga,
   {{0x63ab32b8,0x75d20037,0x61e9c3e3,0x628bc3e4}},	//   _sign, حيوا, vrel, _rygo,
   {{0x97a7004b,0x63ab209a,0xdcfc01d3,0xad9b0143}},	//   _арал, _pign, norā, ctúe,
   {{0x61e90303,0xb8821cf3,0x3f89023e,0x93bc00de}},	//   trel, číta, _nkau_, _trăn,
   {{0x63abc3e5,0x28a704f8,0x6609c3e6,0xe50000aa}},	//   _vign, _कृति, _upek, ल्हि_,
   {{0x61e9c3e7,0x3f89005c,0x44250a4b,0x63ab3045}},	//   rrel, _akau_, _trl_, _wign,
   {{0x63ab0bb6,0x628b00a5,0x4ad30096,0x6b840350}},	//   _tign, _wygo, तराव, yoig,
   {{0x69c1134c,0x61e9c3e8,0x628b00a5,0xd04800a7}},	//   _člen, prel, _tygo, nadə,
   {{0xcdf60895,0x79850169,0x00000000,0x00000000}},	//   ычны, kohw, --, --,
   {{0x3f890063,0x7bdcc3e9,0xd048013c,0x00000000}},	//   _ekau_, tsru, hadə, --,
   {{0x6b51057e,0x3b0a7203,0x00000000,0x00000000}},	//   _såga, нево_, --, --,
   {{0x13d1030b,0x7bdc8b7b,0x6b512452,0x00000000}},	//   _सबैभ, rsru, _påga, --,
   {{0x0eaa02ec,0x7bdc0e37,0x00000000,0x00000000}},	// [fae0] _який_, ssru, --, --,
   {{0x6b512708,0x18a60fe3,0xe6cc0d61,0xbd020094}},	//   _våga, газм, ार्ज, _šéfo,
   {{0xd04801d4,0x46ea0e06,0x3cfb00a1,0x8c463283}},	//   fadə, еден_, _אלינ, _сене,
   {{0x27e70308,0x291c031a,0xaab8201e,0xcc3b006e}},	//   ánna_, žva_, _अलिक, _נעכט,
   {{0x163427a5,0xe9ff0023,0xd9100281,0x79850169}},	//   реля, _thạc_, _ویر_, bohw,
   {{0x7af60138,0x9f430094,0xef1f173c,0x00000000}},	//   lgyt, čké_, zdü_, --,
   {{0x4ab805d4,0x6d4e0db1,0x97b5001f,0xb7960284}},	//   _अलाव, ikba, _всуш, _браћ,
   {{0x7d1e1c73,0xb6a67ade,0x63a0023e,0x00000000}},	//   _laps, _библ, ummn, --,
   {{0x316a0114,0x39b2022b,0x25ac00f2,0x6d4e3b69}},	//   ешно_, _fņse_, _tidl_, kkba,
   {{0x7d1e000d,0x6d4e0ab2,0x845a1f5d,0x69fb006e}},	//   _naps, jkba, _прет_, עליק,
   {{0xb4c205d4,0x893700c1,0xdb1c0220,0x4906049d}},	//   ूरी_, אריע_, zprá, स्यो_,
   {{0x60c40b88,0x3cfa00ee,0x6d4e1183,0x7d1e02ac}},	//   _şimd, _acpv_, ekba, _aaps,
   {{0xe29200e3,0x246e01d4,0xef1f07aa,0x5ce700d6}},	//   _اذا_, _həm_, rdü_, люва,
   {{0x74ca0bf5,0x7c870c59,0xe805007a,0xd048013c}},	//   _स्मृ, губе, _रहला_, zadə,
   {{0x07040386,0x06f60285,0x00000000,0x00000000}},	//   रभाव_, ीभाव_, --, --,
   {{0x60dac3ea,0xae221179,0x00000000,0x00000000}},	//   latm, मिशन_, --, --,
   {{0x5a35016e,0x5f74001c,0xce6813a4,0x23660350}},	// [faf0] шнат, _داور, _брэд_, _mmoj_,
   {{0xdd920018,0x2907c3eb,0x799c030a,0x60dac3ec}},	//   _ووٹ_, ýna_, _chrw, natm,
   {{0x8ccb2c5f,0xdb1c0244,0x6aa60081,0x4815007e}},	//   _त्यो, sprá, গুলো, рмес,
   {{0x644a0034,0x7bc50201,0x7d1e02c6,0x00000000}},	//   dyfi, _ithu, _zaps, --,
   {{0x06d70033,0x7d1e0233,0x00000000,0x00000000}},	//   _হাদি, _yaps, --, --,
   {{0xa5091824,0x60da005c,0xe5a53732,0x00000000}},	//   тека_, jatm, шили, --,
   {{0x60da03e0,0x93bc044c,0x36d50138,0x00000000}},	//   datm, _frăm, _вобр, --,
   {{0x394305db,0xc2e80033,0x93bc044c,0x7bc5063d}},	//   _hojs_, ক্সি_, _grăm, _mthu,
   {{0x6d4e057a,0x00000000,0x00000000,0x00000000}},	//   ykba, --, --, --,
   {{0xe6100dd0,0x29131f72,0x661bc3ed,0xa3b0009f}},	//   _عشق_, nexa_, _isuk, _टूक_,
   {{0x6b511424,0x764b00f0,0x7bc5006c,0xb4c103a2}},	//   _någo, lygy, _nthu, ंडी_,
   {{0x3f6a0feb,0x00000000,0x00000000,0x00000000}},	//   тимо_, --, --, --,
   {{0x7bc5c3ee,0x43840080,0x7d1e3e99,0x2b4205db}},	//   _athu, _النق, _paps, _rokc_,
   {{0xa0a59da3,0x661b0239,0x3943c3ef,0xc5d70033}},	//   _калд, _msuk, _nojs_, _সমাপ,
   {{0xdca6121c,0xdfd100e3,0x7bc50503,0x6b5102b6}},	//   рави, _بيع_, _cthu, _vågn,
   {{0x3a2d00e7,0x207a006e,0x7d1e0023,0xc4d1097c}},	//   _šepa_, _באצא, _waps, हरुख,
   {{0xe8fa43f1,0xc332028c,0x4aaa0e05,0x442000de}},	// [fb00] кла_, חון_, ткан_, ̉i_,
   {{0x7c2a002b,0x38cb0281,0xe8c700ae,0x00000000}},	//   _áfro, نامی_, игул_, --,
   {{0x661bc3f0,0xad9b0031,0x00000000,0x00000000}},	//   _asuk, stúc, --, --,
   {{0xe5c6376f,0x661b061d,0xe73900f0,0x6c7b0327}},	//   аско, _bsuk, _siŵr_, _יריד,
   {{0x66762ce3,0x799c00f0,0xb4c10b2b,0x661b01f9}},	//   جدار, _thrw, ंडू_, _csuk,
   {{0xb4c200c3,0xe5e50037,0x69c600c2,0x6e3b0364}},	//   ूरे_, إثني, _itke, äubi,
   {{0xa967020f,0xad9b0143,0x60da45d9,0x37e31894}},	//   _тира_, ntúa, vatm, _морг,
   {{0x644ac3f1,0xdb1c0537,0x00000000,0x00000000}},	//   ryfi, spræ, --, --,
   {{0x644a5d17,0x60da5fd5,0xd1300037,0x6b580065}},	//   syfi, tatm, كمة_, _kígb,
   {{0x6602ab11,0x67200239,0x71740037,0x62990034}},	//   mtok, _hamj, إهدا, _dzwo,
   {{0x6602c3f2,0x60da47c1,0x73360018,0x629905aa}},	//   ltok, ratm, _پرائ, _ezwo,
   {{0x6722c3f3,0x66020239,0x60dac3f4,0x490617ad}},	//   ndoj, otok, satm, स्तो_,
   {{0x60da5067,0x6602c3f5,0x661b0063,0x7a0a01d3}},	//   patm, ntok, _xsuk, nētā,
   {{0x6b580d79,0x61e2039f,0xd24f00d1,0x672000c4}},	//   _nígb, _ivol, _تنه_, _lamj,
   {{0x06d70081,0x6b510212,0x7b6700c2,0x39430218}},	//   _হাসি, _fågl, атае, _rojs_,
   {{0x6720c3f6,0xc2e80081,0x61e20031,0x290ac3f7}},	//   _namj, ক্রি_, _kvol, _abba_,
   {{0x65680113,0x2913002b,0x00000000,0x00000000}},	// [fb10] _omdh, texa_, --, --,
   {{0x98c73fe2,0x60d800e7,0x93bc020a,0xe9ff00fe}},	//   рсал, _jevm, _vrăj, _nhấc_,
   {{0x29130933,0x7bc57727,0x7d15026a,0x660205cc}},	//   rexa_, _uthu, mezs, etok,
   {{0x61e20ca7,0x291303be,0x6d45078e,0x290a1a92}},	//   _ovol, sexa_, _hoha, _ebba_,
   {{0x6d450006,0x7afd0124,0x67200aa0,0x61e202a1}},	//   _koha, _icst, _damj, _nvol,
   {{0x6d45b6a8,0xb4c13516,0x2abd0139,0x5dda006e}},	//   _joha, ंडे_, _fábó_, אַקס,
   {{0x6d45996e,0x0445c3f8,0x61e2c3f9,0x00000000}},	//   _moha, сейн, _avol, --,
   {{0xe299307f,0x661b6b5d,0x67200022,0x2d540329}},	//   лай_, _tsuk, _gamj, _näen_,
   {{0x26ddc3fa,0x316c06e1,0x661b0201,0x48fe030b}},	//   mawo_, fidz_, _usuk, _लामो_,
   {{0x67200292,0x6d45c3fb,0xaca30065,0x26dd45e9}},	//   _zamj, _noha, _amọd, lawo_,
   {{0x04950080,0x7f440072,0xdb0f023b,0xcea90327}},	//   _الاح, _poiq, _cicë, _ני_,
   {{0x2f5670a4,0x8c490092,0x09cd0081,0x26dd54f6}},	//   стос, _maşı, _লিনা, nawo_,
   {{0x6d451af5,0xa3b0000f,0x7521c3fc,0x877a00c1}},	//   _boha, _टूट_, _kalz, רארי,
   {{0x6d45c3fd,0xada62db3,0x4427ad72,0xd49100fe}},	//   _coha, сагл, ovn_, _kỳ_,
   {{0x61e20074,0x224d0018,0x752101e8,0x6d45c3fe}},	//   _zvol, lyek_, _malz, _doha,
   {{0x236d00a5,0xdb0d0364,0x6e470216,0x26dd06b0}},	//   niej_, rmaß, ërbë, jawo_,
   {{0xeb97261d,0x224d0018,0x26dd0201,0xbb430291}},	// [fb20] сит_, nyek_, dawo_, четк,
   {{0xa3e802d5,0x8c4908bb,0xb4e6049d,0xad9b0072}},	//   _बिल_, _başı, _भये_, ptúa,
   {{0x236d0067,0x6d5c10f0,0x672000dd,0x1bec5d3b}},	//   kiej_, mhra, _pamj, _जटिल_,
   {{0x8c4901d4,0x6602a1ab,0x6d450220,0x2d8a404b}},	//   _daşı, ttok, _zoha, lobe_,
   {{0x6d454222,0xca750077,0xdb1c1489,0x6722c3ff}},	//   _yoha, _дуры, rprä, rdoj,
   {{0x75212034,0xdb1c01bf,0x7a0a00d9,0x6602c400}},	//   _calz, sprä, rētā, rtok,
   {{0xf863125c,0xf366117a,0x61e2c401,0x06d70081}},	//   _евро, йтин, _svol, _হারি,
   {{0x60d807aa,0x2b40050d,0x236d0034,0x2d8a0027}},	//   _sevm, njic_, giej_, hobe_,
   {{0x752102a1,0x224d0018,0x2d8a12ed,0xdb0f03a9}},	//   _falz, gyek_, kobe_, _dicè,
   {{0x8c490702,0x4647007e,0x00000000,0x00000000}},	//   _yaşı, _узун_, --, --,
   {{0xaab8048a,0x2d8ac402,0x6d456bd7,0x60d80565}},	//   _अलंक, dobe_, _roha, _vevm,
   {{0x442c38bf,0x224d0510,0x236d0034,0x2fc70167}},	//   _ird_, byek_, ciej_, _dtng_,
   {{0x6e2200d9,0x442c0085,0x8af00092,0x63ba0891}},	//   _šobr, _hrd_, rhəl, _hutn,
   {{0x6d5c0267,0xb4e6000d,0x26dd0361,0x63bac403}},	//   ghra, _भयो_, zawo_, _kutn,
   {{0x93bc00ae,0x6d4521ab,0x4fc60ed7,0x63ba01f9}},	//   _brăi, _voha, _усла, _jutn,
   {{0x63ba0995,0x442c0e78,0xc17800c6,0x6d4500d1}},	//   _mutn, _mrd_, lnė_, _woha,
   {{0x6d5c10f0,0x3f8b00cc,0x8b0400b6,0x6d454d0a}},	// [fb30] bhra, mocu_, ířat, _toha,
   {{0x6d5c05d3,0x236d0067,0x442c3813,0x6e2d839d}},	//   chra, ziej_, _ord_, _irab,
   {{0x63ba0363,0x6e2d0dab,0x26ddc404,0x6e220072}},	//   _nutn, _hrab, tawo_, _áobr,
   {{0x7521042c,0x2a6001fa,0x93bc044c,0x00000000}},	//   _salz, bzib_, _grăi, --,
   {{0x442cc405,0x26dd0517,0x63ba00e7,0x6f0d63dc}},	//   _ard_, rawo_, _autn, _mbac,
   {{0x67d5562b,0x8c4901e8,0x442ca03c,0x63ba019c}},	//   _могу, _taşı, _brd_, _butn,
   {{0x58d41312,0x6b58c33d,0xdb1c0ec9,0x75210036}},	//   _хост, _híga, språ, _valz,
   {{0x225f02a7,0x6d5c0146,0xc1780138,0xdff202d5}},	//   tzuk_, zhra, enė_, _अमजद_,
   {{0x24890067,0x3dc901fa,0xa3e5009f,0x60c40092}},	//   łam_, _ntaw_, _भटक_, _şima,
   {{0x6f0d1a0f,0x6009074b,0x442c0216,0x44270988}},	//   _abac, аном_, _frd_, pvn_,
   {{0x236d00a5,0x442c0611,0x6e2d202c,0xd00971b0}},	//   piej_, _grd_, _arab, шене_,
   {{0x6e2dc406,0x5ea80081,0x9eaa249b,0x99540031}},	//   _brab, _ক্ষে, ивна_, mäť_,
   {{0x6d5c0e5c,0x200a01e8,0x25b201e8,0x2d8ac407}},	//   thra, çbir_, _ünlü_, tobe_,
   {{0x6e2dc408,0x2fc70167,0x6f0d5cd6,0xad9b182b}},	//   _drab, _ttng_, _ebac, stún,
   {{0x6e2d03f3,0x8b26001f,0x6d5cc409,0x00000000}},	//   _erab, одве, rhra, --,
   {{0x6e2d01af,0x6f0d0294,0x2d8a4230,0x399400ce}},	//   _frab, _gbac, sobe_, mäsi_,
   {{0x5ea80081,0x39460138,0x2480026a,0x261900c3}},	// [fb40] _ক্রে, онаг, ğimi_, _मैली_,
   {{0x6f0d0a39,0x2480026a,0x6b585bef,0xfaff0216}},	//   _zbac, şimi_, _díga, _ecë_,
   {{0x93bc00d3,0x443c0072,0xa6ca0d5b,0x20053ed0}},	//   _trăi, xxv_, لوال_, ntli_,
   {{0x6b580558,0xab2a1a0c,0xad9b0076,0x00000000}},	//   _fíga, _тома_, htúl, --,
   {{0x442c0b14,0xe53401b3,0x88840260,0x63ba0580}},	//   _srd_, зель, _کیان, _sutn,
   {{0x442cc40a,0x6b96c40b,0x03c6c40c,0x399412f1}},	//   _prd_, llyg, осим, käsi_,
   {{0x399400c2,0x2005007e,0x398fc40d,0x00000000}},	//   jäsi_, jtli_, rüst_, --,
   {{0x4906030b,0xdb170042,0x442cc40e,0x375600d1}},	//   स्रो_, _puxé, _vrd_, _بپرس,
   {{0xdb0400fd,0xdd0e013c,0x00000000,0x00000000}},	//   rmiè, xışd, --, --,
   {{0x3a3700a1,0x442cc40f,0x6f0d0036,0x2489020e}},	//   קרים_, _trd_, _sbac, şama_,
   {{0x5f9500d3,0x41b40421,0x6e2dbf5f,0xb8bb006e}},	//   зинт, _کمتر, _srab, יזיש,
   {{0x6e2d0510,0xc178013f,0xdb0f0037,0xdb08001c}},	//   _prab, snė_, _ticé, _èlèk,
   {{0xdb060084,0x637e01d3,0x628e042c,0x6e2d009e}},	//   _mikä, cīna, ßbod, _qrab,
   {{0x6ad3000f,0xc5f3028c,0xdd0e00a7,0x224b17a5}},	//   तर्र, ודש_, rışd, äcke_,
   {{0x63a2c410,0x6b58c411,0x5c047a20,0xdb6b168c}},	//   _khon, _síga, мята, арал_,
   {{0x6f0d03ce,0xa3dc06ae,0x5ed50081,0x6b960537}},	//   _ubac, तीय_, _থাকে, glyg,
   {{0x63a2c412,0x6e2d02a4,0x00000000,0x00000000}},	// [fb50] _mhon, _urab, --, --,
   {{0xceb400ca,0xe739030a,0x893800d3,0x00000000}},	//   _קיץ_, _chŵn_, опус_, --,
   {{0x63a20150,0xdce700d9,0xd7fb0d62,0x6b9600f0}},	//   _ohon, cijā, руз_, blyg,
   {{0x99540031,0x69cd1ddf,0x00000000,0x00000000}},	//   väť_, ppae, --, --,
   {{0xbc6800cd,0x5f000789,0xeb3a00c1,0x6b8d0062}},	//   _همین_, ष्ट्_, _הערש, moag,
   {{0x6b8d5f53,0x200500d4,0x63a2c413,0x00000000}},	//   loag, ytli_, _ahon, --,
   {{0x63a2009b,0x00000000,0x00000000,0x00000000}},	//   _bhon, --, --, --,
   {{0x63a2c414,0xc2454fe3,0x85b9282a,0x6b8d0062}},	//   _chon, зник, _глас_, noag,
   {{0x63a20e79,0xe1f100e3,0xddc600a5,0x95c88e4a}},	//   _dhon, رسة_, zykł, _духа_,
   {{0xc69200c1,0x63a23cc2,0x0ef402d5,0x399400c2}},	//   _טאן_, _ehon, अल्स_, täsi_,
   {{0x63a20037,0xad9b0428,0x6b8d0634,0x6b960077}},	//   _fhon, rtúl, koag, ylyg,
   {{0x7c2a08ec,0x6b8d0167,0x200580ae,0x6d5501cb}},	//   _áfri, joag, rtli_, ekza,
   {{0xc6090081,0x2005030b,0x539a00ca,0x899f0139}},	//   লিকা_, stli_, _פינו, _díẹ̀,
   {{0x63a2c415,0xc10400e3,0x9f43035d,0xe1640037}},	//   _zhon, _يوني, čká_, _يدوي,
   {{0x913a00a1,0x63a90138,0xc61881ec,0x6b9601b6}},	//   _לעסק, omen, _धन्य_, tlyg,
   {{0xbb43372d,0x63a9c416,0xdce701d3,0xdb1c0120}},	//   неск, nmen, rijā, nprø,
   {{0x63a9c417,0x80de0081,0xb18300b6,0xdfa50adb}},	// [fb60] imen, _মাত্, šťuj, _تحوي,
   {{0xdca6133d,0x63a9c418,0x8ccb02d5,0x0d83539a}},	//   _напи, hmen, तुदो, _плын,
   {{0x63a9c419,0xf99f0065,0x6b8d01c8,0x00000000}},	//   kmen, _apès_, boag, --,
   {{0x63a94729,0x2d98539e,0x1fbd0033,0xd5ba04d9}},	//   jmen, llre_, _আবাস, бск_,
   {{0x63a23da9,0x63a9018a,0xba760fba,0xdb1c01df}},	//   _rhon, dmen, _راحت, dprø,
   {{0x63a9c41a,0x63a2b383,0xd5b900f3,0x00000000}},	//   emen, _shon, ісі_, --,
   {{0x63a2c41b,0x2937006e,0x63a902ac,0x00000000}},	//   _phon, _צאלן_, fmen, --,
   {{0x80de00c7,0x987b00c1,0x291a25d1,0x6b511e95}},	//   _মাধ্, _האלט, lepa_, _pågi,
   {{0xa3dc05d4,0x93bc00d3,0x05666484,0xb17d0206}},	//   _तौर_, _arăt, _еван, vrťr,
   {{0x63a9c41c,0x394a4d02,0x291a0513,0x46131454}},	//   amen, _jobs_, nepa_, _سومر,
   {{0x80de0081,0xf2db0081,0x63a21bc8,0x1aa9142e}},	//   _মাদ্, _ধারণ, _thon, _कण्ठ,
   {{0x389b00c1,0x62820197,0x63a96569,0x643b006e}},	//   מיינ, _txoo, cmen, _לעבנ,
   {{0xa3c200a5,0x7d030222,0x91a600fe,0x3ea00503}},	//   _एंड_, _önsk, _trò_, _czit_,
   {{0x614308a4,0x291a0ea3,0x00000000,0x00000000}},	//   _печа, jepa_, --, --,
   {{0x6d550126,0xab95004d,0x93bc020a,0x00000000}},	//   rkza, диві, _grăt, --,
   {{0x6b58002b,0x69be00aa,0x307b00ca,0x00000000}},	//   _dígo, _वंशी, _לאונ, --,
   {{0xa3dc009d,0x6b8d01e9,0x291a037a,0x394a972e}},	// [fb70] तीत_, roag, fepa_, _bobs_,
   {{0xa8a71c66,0xaca30174,0x6b5800b3,0x01be0033}},	//   прек, _akụd, _fígo, _ইবাদ,
   {{0xf9900177,0xaf200081,0xa3e806eb,0x63a9c41d}},	//   ابق_, ধারণ_, _बिग_, ymen,
   {{0x99800580,0xe7fe00a3,0x00000000,0x00000000}},	//   rviš_, _उमरा_, --, --,
   {{0x5a34036c,0x9a840231,0x63a9c41e,0x00000000}},	//   _знят, _зурл, vmen, --,
   {{0xdb1708a8,0xe618004d,0x291a044c,0x00000000}},	//   _muxí, яді_, cepa_, --,
   {{0x63a9c41f,0xa3d7007a,0x59c302d5,0x3f8300c4}},	//   tmen, ़ीं_, _वंडर, čkuj_,
   {{0x63a9c420,0x00000000,0x00000000,0x00000000}},	//   umen, --, --, --,
   {{0x2b4b00dc,0xdb1c00f2,0x00000000,0x00000000}},	//   _mocc_, rprø, --, --,
   {{0xd5b10781,0xdb1c00f2,0x00000000,0x00000000}},	//   _شفا_, sprø, --, --,
   {{0x63a97211,0xdb170161,0x2455006f,0xdbf200b6}},	//   pmen, _auxí, _تناس, třít,
   {{0x83670177,0xdb170072,0x32551828,0x25bf6be4}},	//   _عدال, _buxí, _овер, _kuul_,
   {{0x25bf62a1,0xb6060995,0x93bc078e,0x00000000}},	//   _juul_, _gušć, _frăs, --,
   {{0xdb0f03be,0x61fba52f,0x93bc00ae,0x25bf00bc}},	//   _dicí, muul, _grăs, _muul_,
   {{0xdbf202c6,0xdb0f0503,0x394ac421,0x00000000}},	//   přít, _eicí, _robs_, --,
   {{0xf0920054,0xe9da0e4a,0x212700de,0xdb170072}},	//   _שנה_, жка_, _hanh_, _fuxí,
   {{0x0d860036,0x13d60081,0x61fb0517,0x6f041d09}},	// [fb80] _олин, সওয়, nuul, _icic,
   {{0x6e24c422,0x660612f1,0xdb1e0052,0x22420d67}},	//   _isib, _äkki, _kupë, äkki_,
   {{0x7d1ca52a,0x212700de,0xb8f60006,0xb95b0139}},	//   mers, _manh_, _सभ_, _buìb,
   {{0x61fb189e,0xa3c11fbb,0x212700de,0x75e30134}},	//   kuul, ंदन_, _lanh_, _ọzar,
   {{0x291a0174,0x7ae4c423,0x21270023,0x66e37030}},	//   pepa_, mait, _oanh_, точа,
   {{0x7ae4c424,0x61fb9cb6,0x25bf21d2,0x2ee0017a}},	//   lait, duul, _duul_, _leif_,
   {{0xc10e00de,0x13942a6e,0x7d1c6a49,0x00000000}},	//   _bỗng_, никю, iers, --,
   {{0x7ae4b533,0x18a30e05,0xb6060234,0x61fb0517}},	//   nait, _расм, _pušć, fuul,
   {{0x25bf0188,0x21271c42,0x6e2483d4,0x51866070}},	//   _guul_, _banh_, _nsib, дуна,
   {{0x7ae48118,0x21270019,0x224b0149,0x3994042c}},	//   hait, _canh_, äcka_, mäss_,
   {{0x7ae4c425,0x21270028,0xb2260102,0x6e245714}},	//   kait, _danh_, fræð, _asib,
   {{0x7528ac77,0x2ee000e7,0x6d5ec426,0x7ae400c2}},	//   _hadz, _ceif_, _alpa, jait,
   {{0x7ae4c427,0x7d1cc428,0xad9b0076,0x93bc020a}},	//   dait, fers, ltúi, _trăs,
   {{0x212700fe,0x6f04033c,0x00000000,0x00000000}},	//   _ganh_, _ecic, --, --,
   {{0x7ae4a91d,0x6e24c429,0xad9b0037,0xeb9304f4}},	//   fait, _esib, ntúi, نظر_,
   {{0x7ae40f9d,0x00000000,0x00000000,0x00000000}},	//   gait, --, --, --,
   {{0x753ac42a,0x9f460146,0xad9b0076,0x00000000}},	// [fb90] _ontz, nulý_, htúi, --,
   {{0x752805c5,0x6f1d0f19,0x7d1c5924,0x21270028}},	//   _nadz, lesc, cers, _xanh_,
   {{0x6ec305d4,0x9cd600a1,0x7ae4c42b,0x2d91161f}},	//   रखपु, _אותה_, bait, moze_,
   {{0x6f1dc42c,0x7c250c27,0x753a02a7,0x7ae40076}},	//   nesc, _ishr, _antz, cait,
   {{0x8f9c00a1,0xc10e00fe,0x3ce100bc,0xa3dc09a0}},	//   קידי, _rỗng_, _kehv_, तीस_,
   {{0x64a52cf0,0x2d91be60,0x3dfc00ca,0x6f1d19f0}},	//   нала, noze_, קלוד, hesc,
   {{0x68e5c42d,0x21270023,0x6f1dc42e,0x00000000}},	//   mahd, _ranh_, kesc, --,
   {{0x753ac42f,0x61fb0c15,0x68e5b38b,0x2d91023f}},	//   _entz, tuul, lahd, hoze_,
   {{0x2d910b92,0x7528061d,0xdb1e03a9,0x6f1d0d63}},	//   koze_, _fadz, _dupè, desc,
   {{0x29013996,0x6f042555,0x2ee0052a,0x67290167}},	//   ngha_, _scic, _seif_, _haej,
   {{0x61fb7a18,0x6f1d037a,0x67290113,0x7ae4024a}},	//   suul, fesc, _kaej, yait,
   {{0x6d890038,0x6f1d0bb7,0x67295d65,0x7d1cc430}},	//   hľad, gesc, _jaej, wers,
   {{0x80de00c7,0x7ae40895,0x7d1c2bae,0x3f9e0029}},	//   _মার্, vait, ters, ētu_,
   {{0x61e9c431,0x7ae4c432,0xd1380034,0x7d1c1597}},	//   msel, wait, gląd_, uers,
   {{0x7ae4c424,0x61e9c433,0x6f1d3f15,0x69cf00d9}},	//   tait, lsel, besc, _atce,
   {{0x28d20789,0x6e24b174,0x6f1d7649,0x00000000}},	//   दुनि, _tsib, cesc, --,
   {{0x61e9c434,0x7ae4c435,0xf2d20105,0x6e241937}},	// [fba0] nsel, rait, טען_, _usib,
   {{0x7ae4c436,0x61e9234b,0x673b03a9,0x629900fe}},	//   sait, isel, _anuj, _mywo,
   {{0x7528c437,0x62990150,0x38cb001c,0x69dd02a1}},	//   _radz, _lywo, سالی_, _ewse,
   {{0xaa462d7b,0x61e9c438,0x752894e9,0x068618a2}},	//   _земл, ksel, _sadz, нген,
   {{0x4425c439,0x61e94b6d,0x752800e8,0x00000000}},	//   _asl_, jsel, _padz, --,
   {{0x61e92864,0x95c30037,0x6f1dc43a,0xdb1e101c}},	//   dsel, ديوه, zesc, _supè,
   {{0x98a30451,0xbf200096,0x6b5102c3,0x18a30d76}},	//   _бире, _बसून_, _tågt, _барм,
   {{0x44257f07,0x23a10103,0x61e92387,0x629917a7}},	//   _dsl_, tója_, fsel, _bywo,
   {{0x36672f93,0x61e924d4,0x6f1d55f6,0xd13000e3}},	//   _зато_, gsel, vesc, لمة_,
   {{0x04180033,0xbebb0052,0x50661009,0x753a0634}},	//   থিবী_, ndëv, етма, _untz,
   {{0x741303ef,0xa3dc0cce,0x61e9a43a,0xe50532d1}},	//   _مولا, तीश_, asel, _राति_,
   {{0xb28600d3,0x6299030a,0x61e9c43b,0x9f4601f9}},	//   _пылк, _fywo, bsel, duló_,
   {{0x6f1d33d0,0x2d916136,0xa3dc00b7,0x00000000}},	//   resc, toze_, तीर_, --,
   {{0x6b51070a,0x6f1d002d,0xac19084c,0x7c3809ac}},	//   _någr, sesc, могу_, _švra,
   {{0x6f1d0cc0,0xac9529b7,0x4c95038a,0x68e5007b}},	//   pesc, тавш, тивс, vahd,
   {{0xdb17002b,0x409b00ca,0xddd002c6,0x309b0327}},	//   _buxá, _מבוס, řeši, _משומ,
   {{0x2d9106a3,0x238501d3,0x00000000,0x00000000}},	// [fbb0] poze_, nēja_, --, --,
   {{0xfbd00068,0x9998002d,0xbebb084e,0x00000000}},	//   شتہ_, екут_, geëe, --,
   {{0x2d54007a,0xdb1c0103,0xd7fb00ae,0x9f46037a}},	//   _päev_, gpró, яуа_, culó_,
   {{0x572700e3,0x61e9273a,0x45d52e0f,0x06751982}},	//   عراق, ysel, водс, куля,
   {{0x442532e8,0x68e5007b,0x00000000,0x00000000}},	//   _ssl_, pahd, --, --,
   {{0x4a5a004f,0x2b490039,0x44256787,0x61e9319a}},	//   _חדשו, ljac_, _psl_, vsel,
   {{0xa3dc0454,0xdb1e0257,0x6498013d,0xd7f80831}},	//   तील_, _supé, нтър_, _пут_,
   {{0x61e9ab99,0x2b4904a3,0x0395008f,0x9f5f007b}},	//   tsel, njac_, ърля, nttä_,
   {{0xdb0600dd,0xe78405cb,0x9f4d0220,0x61e9065c}},	//   _shkë, _суро, budú_, usel,
   {{0x046700d3,0x00000000,0x00000000,0x00000000}},	//   _птем, --, --, --,
   {{0x442500d3,0x61e94bb4,0xe53600c1,0x62990034}},	//   _usl_, ssel, _שטעט_, _wywo,
   {{0x61e97c53,0x78ba0155,0x69c00036,0x3f8400bc}},	//   psel, _útve, _èmeg, õmu_,
   {{0xc7b200c1,0xdb1c01bf,0x2b490b18,0x238500e8}},	//   יבט_, rprü, djac_, cēja_,
   {{0xdb1c01bf,0x2a69c43c,0x2d5400c2,0xf1ba00fe}},	//   sprü, dzab_, _näet_, _giơ_,
   {{0xeb9a2e01,0x69cb2e56,0xe9df0139,0xfce309e0}},	//   див_, ígen, _awú_, росо,
   {{0x332dc43d,0x00000000,0x00000000,0x00000000}},	//   ndex_, --, --, --,
   {{0xeb970b37,0x6b516cab,0x320d0188,0xdd8a1143}},	// [fbc0] тит_, _pågr, ntey_, _обид_,
   {{0x3d11110f,0xa3c11b79,0xe8f70581,0x00000000}},	//   द्दे_, ंदा_, клу_, --,
   {{0xe9df0139,0x238501d3,0x6b580231,0x9cd70a41}},	//   _ewú_, zēja_, _lígi, _שוטה_,
   {{0xe813009f,0x65616727,0x6e360430,0xe1f900c6}},	//   _ठहरा_, _allh, _kryb, krų_,
   {{0x332d008a,0x660f0212,0x5f0508d4,0x3f82008c}},	//   ddex_, _äckl, _वास्_, inku_,
   {{0x238501d3,0x6b832c68,0x637e00e8,0x69d603a9}},	//   vēja_, _íngr, mīni, mpye,
   {{0x8af000a7,0xd7060a51,0x386d03e3,0xa3dc1c05}},	//   hkəm, _изви, _ƙere_, तीं_,
   {{0x040d0028,0x2d5400aa,0x2480020a,0x238500e8}},	//   _hướn, _käes_, ăim_, tēja_,
   {{0x249200a5,0x6d5c003e,0x60cd07e7,0x320d0188}},	//   łym_, kkra, _şama, gtey_,
   {{0xd5ae00fb,0x6d5c0fee,0x238500d9,0x6f1600b6}},	//   _بہت_, jkra, rēja_, _abyc,
   {{0x39570054,0x9f5f0084,0x93460ebf,0x250b0018}},	//   דשים_, yttä_, _инже, _ترقی_,
   {{0x320d0188,0x28a71e18,0x6d5cc43e,0x238500e8}},	//   btey_, केटि, ekra, pēja_,
   {{0x6458013f,0x8d77001c,0x6e3600eb,0x6d5c1d4a}},	//   lyvi, ناسا, _cryb, fkra,
   {{0xd12f00e3,0x6fca332a,0x040d00de,0x3f82388f}},	//   _ومن_, _संपू, _nướn, anku_,
   {{0x30a3008f,0xc04f00d6,0x07130aa6,0x2ca502c3}},	//   _кръв, _ті_, ण्डव_, åld_,
   {{0xe0b700c1,0x70b700d7,0x00000000,0x00000000}},	//   _בלוט_, _בהוד_, --, --,
   {{0x6e364675,0x69d600f9,0x3915251c,0x5f740a85}},	// [fbd0] _gryb, gpye, лмар, _خاور,
   {{0x6d5c0c19,0x7bc10103,0x645832f8,0x00000000}},	//   ckra, ílus, kyvi, --,
   {{0x2d830039,0x1aef0081,0xc7f50291,0x4e940281}},	//   mnje_, ঙ্গে_, узећ, _مشیر,
   {{0x29076a1b,0xfaff023b,0xf4080081,0x2bb40096}},	//   żna_, _emër_, লবার_, ंगणा,
   {{0xd2461be8,0xb90900c7,0xa3e533d9,0x7bc5c43f}},	//   _ان_, _যা_, बीन_, _huhu,
   {{0x7bc51ee3,0x6b58c440,0x24092de9,0xbf2000b6}},	//   _kuhu, _rígi, енки_, _बस्न_,
   {{0x7bc54586,0x26c9002b,0x3f82007f,0x645883d6}},	//   _juhu, ñaos_, ynku_, gyvi,
   {{0xbebb01e5,0x320d02e5,0x7bc54829,0x15f5250d}},	//   ndës, ttey_, _muhu, ुंदर_,
   {{0x7bc564ea,0xd9e30e5e,0x82352c9a,0x2bb40096}},	//   _luhu, गठित_, اربا, ंगता,
   {{0x2d8304a3,0x320d008a,0x7fd50565,0xdb0f016d}},	//   jnje_, rtey_, лімі, _ficç,
   {{0xdee60cfc,0xc4d200a1,0x7bc548e6,0x6d5c0b97}},	//   лони, _הגב_, _nuhu, vkra,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f60003e,0x7bc50231,0x5f0500a4,0x00000000}},	//   _þrír_, _auhu, _वार्_, --,
   {{0x7bc5c441,0x3179006e,0x661b0361,0x8af000a7}},	//   _buhu, _ראַד, _mpuk, rkəm,
   {{0x6d5cc442,0xd00e0246,0x06e300c3,0x00000000}},	//   rkra, _فلو_, खराव_, --,
   {{0x7bc5c443,0xa09a006e,0x040d00de,0x8cd40469}},	//   _duhu, _איצט, _sướn, _ब्रो,
   {{0xa3ab099d,0x6d5c3564,0x2d830117,0x61fb093e}},	// [fbe0] _गठन_, pkra, bnje_, nrul,
   {{0x61fb00dc,0x69d600f9,0x6d5a00aa,0x645d00a7}},	//   irul, rpye, ötad, _əsir,
   {{0x7bc5023f,0x2d9a00ac,0x040d0023,0x07a61141}},	//   _guhu, _ikpe_, _vướn, гажн,
   {{0x61fb00dc,0x238500d9,0xbb464774,0x3a3f14f3}},	//   krul, dējo_, _семк, _šupe_,
   {{0xe50505d4,0x040d0019,0x7bc5057c,0x88e80033}},	//   _राशि_, _tướn, _zuhu, _পাঠক,
   {{0xad9bc444,0x6458013f,0x7bc50188,0x9f5f0052}},	//   ltúr, tyvi, _yuhu, tutë_,
   {{0xbebb01e5,0x98a300d9,0xa92801d3,0x6b841350}},	//   ndër, _tajā_, režģ, onig,
   {{0x69c64a2d,0xf363013f,0x2d830ca7,0xad9b0181}},	//   _kuke, йтын, znje_, ntúr,
   {{0xa686387c,0x7ae6b3da,0x8b570089,0x6b84c445}},	//   _слад, _mekt, טיקס_, inig,
   {{0xd13000d0,0xb42609b4,0x69c60512,0x3014bc1c}},	//   آمد_, _معصو, _muke, адор,
   {{0x69c64633,0xad9b6cf4,0xddd00a9e,0x660200c2}},	//   _luke, ktúr, _češl, luok,
   {{0xa3c13abb,0x7bc5c446,0x7ae6c447,0x61fb85d8}},	//   ंदर_, _ruhu, _nekt, brul,
   {{0x9f5f025b,0x69c6c448,0x61fb020a,0x6b840d18}},	//   nuté_, _nuke, crul, dnig,
   {{0x7bc5198c,0xa90300a5,0xc6930089,0x6b58002b}},	//   _puhu, _लाइफ_, מאר_, _mígu,
   {{0x69c602a7,0x2d8328fc,0x7ae65bcb,0x6b580072}},	//   _auke, rnje_, _bekt, _lígu,
   {{0x2d8300cc,0x69c6c449,0x2d9a0129,0x29180623}},	//   snje_, _buke, _ekpe_, _abra_,
   {{0x49752e9e,0x6722c44a,0x2d83108b,0x66021ad1}},	// [fbf0] алас, deoj, pnje_, juok,
   {{0x69c6550c,0x7bc5c44b,0x6b840188,0x3ea90063}},	//   _duke, _tuhu, anig, _izat_,
   {{0x61e206b0,0x69c60062,0x290f007f,0x6b960154}},	//   _lwol, _euke, ęga_, boyg,
   {{0x96355ecf,0x7ae60381,0xc7b40037,0x61e2c44c}},	//   инец, _gekt, مصنع, _owol,
   {{0xa5094a4e,0x69c60193,0x25be022b,0x3f89c44d}},	//   вела_, _guke, _bitl_, _mjau_,
   {{0xa3c10789,0x61fb681e,0x238501d3,0x00000000}},	//   ंदल_, vrul, tējo_, --,
   {{0x67d40084,0xfd620134,0x7ae6519c,0x61e2c44e}},	//   _госу, _agwọ, _yekt, _awol,
   {{0x78ba4346,0xe29908a1,0x986a0491,0x27fc0220}},	//   _útva, кай_, lığa_, ávne_,
   {{0xe6670c1d,0x69c0020d,0x1634534b,0x6b580032}},	//   _ство, _émet, _летя, _gígu,
   {{0xdb0a0220,0x50b5124e,0x61fb9363,0x238500e8}},	//   ľnéh, исну, rrul, pējo_,
   {{0xa0a51c16,0x68e73d42,0xdb0a0146,0x9f863a83}},	//   ранд, _mejd, žnéh, игод,
   {{0x7523c44f,0x68e7a4d8,0x2d9a016d,0x68300103}},	//   lenz, _lejd, _skpe_, lódá,
   {{0x61e25b31,0x91e519d4,0x61450396,0x442700f0}},	//   _gwol, _толе, _вела, lwn_,
   {{0x68e70363,0x7523c450,0x3ea90706,0x69c605bd}},	//   _nejd, nenz, _dzat_, _ruke,
   {{0xad9b0088,0x69c6c451,0x61e2c452,0x3ea9007e}},	//   ttúr, _suke, _zwol, _ezat_,
   {{0x7523c453,0x38ac0d79,0x69c6c454,0x6b84c455}},	//   henz, _lórí_, _puke, unig,

   {{0x6b84c456,0xdb1d3435,0x7ae6c457,0x752329f4}},	// [fc00] rnig, _misè, _vekt, kenz,
   {{0x2fc711eb,0x7ae60979,0xdb1d00bf,0x75239357}},	//   _kung_, _wekt, _lisè, jenz,
   {{0x2d98c458,0x75235a3d,0x6b580fb6,0x8c460a71}},	//   more_, denz, _sígu, _тене,
   {{0x2fc700bf,0x69c60084,0x6602013f,0x2d980a5f}},	//   _mung_, _tuke, tuok, lore_,
   {{0x38ac0065,0x2fc700d7,0x163421b6,0x00000000}},	//   _bórí_, _lung_, селя, --,
   {{0x75233565,0x66021736,0x291800f9,0x2d98ab0f}},	//   genz, ruok, _ubra_, nore_,
   {{0x2fc700a6,0xf8aa0f78,0xa6ca0b21,0xdb1d022b}},	//   _nung_, _करिय, _алба_, _bisè,
   {{0xe3af04f4,0x9f5f00fd,0xaac60034,0x7f8800a7}},	//   وري_, puté_, वशिक, dıqo,
   {{0x75230e7a,0x2d98c459,0x25be0580,0xdb1d1c45}},	//   benz, kore_, _titl_, _disè,
   {{0xf8aa53ee,0x2fc72a69,0x2d98c45a,0xe50607e8}},	//   _कराय, _bung_, jore_, _خبري,
   {{0x2fc70028,0x2d988eda,0x656a033f,0x3ea00154}},	//   _cung_, dore_, mhfh, _ayit_,
   {{0x2fc70028,0x61e206b0,0xdb1d014b,0x00000000}},	//   _dung_, _twol, _gisè, --,
   {{0x2d980054,0x2fc70167,0x7c2200cc,0x98a7031a}},	//   fore_, _eung_, _ćora, _čiča_,
   {{0x2d98092f,0x2366023e,0x7f8800a7,0xa1575e41}},	//   gore_, _hloj_, lıql, _вашу_,
   {{0x2fc703a9,0x442c0063,0x92e80033,0x6c54017b}},	//   _gung_, _jsd_, বলী_, окру,
   {{0x7523ba32,0x68e7c45b,0x3a390027,0x3ea901c8}},	//   zenz, _sejd, _prsp_, _tzat_,
   {{0x98a300a5,0x78eb7f94,0x75235e0a,0xcf78001c}},	// [fc10] _mają_, вьев_, yenz, _خصوص_,
   {{0xb4e5007d,0x2d98c45c,0x6e2d460c,0x2fc70256}},	//   _भजे_, core_, _isab, _yung_,
   {{0x75230f2f,0xd8791e53,0x2fc70019,0x7f9d020d}},	//   venz, دمات_, _xung_, séqu,
   {{0xf77006f6,0x3f9903ce,0x7523c45d,0x7bd701e9}},	//   وان_, nosu_, wenz, _itxu,
   {{0x75238c32,0x7aed6e59,0x442c5c3b,0x9a840131}},	//   tenz, maat, _asd_, _дурл,
   {{0x7aed3251,0x6e2d0a4b,0x2ee900d7,0x00000000}},	//   laat, _msab, _leaf_, --,
   {{0x7523c45e,0x442c037b,0xdb1d6b40,0x6f0dc45f}},	//   renz, _csd_, _aisé, _ocac,
   {{0x7aed4f0f,0x752370fa,0x2d981136,0x2fc7c460}},	//   naat, senz, zore_, _rung_,
   {{0x7523c461,0x6e2d6708,0xaab717ad,0x98a3007f}},	//   penz, _nsab, अधिक, _dają_,
   {{0x0fd92787,0x2fc78797,0x7aed2ef2,0xdb1d01dc}},	//   льмы_, _pung_, haat, _disé,
   {{0x6e2d5c19,0x7bd70197,0x331900d6,0x442c6240}},	//   _asab, _ntxu, _біля_, _gsd_,
   {{0x3204045b,0x2fc700de,0x6f0d010a,0x6b5800b3}},	//   bumy_, _vung_, _ccac, _lígr,
   {{0x2d98c462,0xd00e1ac9,0x7aedc463,0x7bd70634}},	//   tore_, ولی_, daat, _atxu,
   {{0x61d60054,0x2fc715fd,0x5fcf0096,0x6f0d0415}},	//   _הוסף_, _tung_, _संपल, _ecac,
   {{0x2d98c464,0x645c007a,0x7aedc465,0x6e2d4944}},	//   rore_, _ürit, faat, _esab,
   {{0x2d98c466,0x2005c467,0x256b1484,0x7aed1e08}},	//   sore_, muli_, _følg_, gaat,
   {{0x20052e74,0x7f440036,0xdb1e0076,0xed5a0036}},	// [fc20] luli_, _iniq, _cupá, _боп_,
   {{0x41df02d5,0xfe37006e,0xad9b0042,0x2e370142}},	//   पीएस, _פריי_, trúe, _פריש_,
   {{0xb17a07a6,0x200503ce,0x7aed0694,0x7d57006e}},	//   נטער, nuli_, baat, _הייד_,
   {{0x7aed93bf,0x442c0284,0x7bdcc468,0x6e2d00f9}},	//   caat, _rsd_, mpru, _ysab,
   {{0x68f809b4,0x2005a9df,0xdcf500d9,0xa3e5121d}},	//   _نکاح_, huli_, lizā, बीस_,
   {{0x442cc469,0x78ba0018,0xbbe9001c,0x02e016f8}},	//   _psd_, _útvo, _حریم_, नर्न,
   {{0x888409b4,0xdcf500d9,0x23660197,0xe50e1101}},	//   _بیان, nizā, _ploj_, _साठि_,
   {{0xd3260a8d,0x51f80084,0xcc3b006e,0xb90c0134}},	//   ськи, анию_, רעקט, yahụ_,
   {{0x637e013f,0x4254001c,0x7f88013c,0xda7b0142}},	//   gūna, زندر, rıql, ָניר,
   {{0xa3a80104,0x6f0d00e5,0x3d1a0d75,0x2005017e}},	//   _खीर_, _scac, म्मे_, fuli_,
   {{0x20056c81,0x6e2d0283,0x442c852b,0x99800138}},	//   guli_, _ssab, _usd_, lvių_,
   {{0xd0410092,0xad9b0031,0x7bdc00d4,0xd5be00e8}},	//   nclə, krúc, dpru, žāda_,
   {{0x7aedc46a,0x88c00081,0x225a09f4,0xdcfc00c6}},	//   vaat, েরিক, _حجاب_, norė,
   {{0x20050283,0x7aed848b,0xb90c0174,0x7f44039f}},	//   buli_, waat, rahụ_, _eniq,
   {{0x2005c46b,0xd0b20092,0x317b00ca,0xa3dc0096}},	//   culi_, yğəm, _תרומ, तीच_,
   {{0x317ec46c,0x6e2d0044,0xbe9a0134,0x3d1a1cff}},	//   litz_, _tsab, ọhụr, म्बे_,
   {{0x6e2d728e,0x99550dcc,0x9f5f0579,0x7bdc0381}},	// [fc30] _usab, окац, nutí_, apru,
   {{0x7aed03cf,0xb8820579,0x317e4700,0xd05800a7}},	//   saat, čína, nitz_, _sevə,
   {{0x6d4502f4,0x7aed2197,0x00000000,0x00000000}},	//   _inha, paat, --, --,
   {{0x7aed0188,0x657a36e4,0x317e0634,0x27fc0031}},	//   qaat, _amth, hitz_, ávna_,
   {{0x2005c46d,0xf8ae010d,0x99890031,0x00000000}},	//   zuli_, _یکم_, evať_, --,
   {{0x998900a5,0x637e0138,0x23d5562f,0xdfc663dc}},	//   stał_, vūna, оцир, _يي_,
   {{0x657a009c,0x6d577e11,0x317e01ff,0x00000000}},	//   _dmth, _moxa, ditz_, --,
   {{0x6fcf245a,0xe1f92e81,0x657a0201,0x6568003e}},	//   _संबं, аги_, _emth, _eldh,
   {{0x6d45a448,0x7769002b,0x20055f6a,0xdc3c02c6}},	//   _onha, _ilex, wuli_, váče,
   {{0x2005a1e3,0x7f5600a7,0xbebb0313,0x637e00c6}},	//   tuli_, _soyq, reël, rūna,
   {{0xcea9193b,0xdb0400e3,0x2bbe023a,0xdc3c00b6}},	//   _סי_, rmiú, ्दमा, táče,
   {{0x60dc06d7,0x6d4523a8,0x25f00f65,0x7ad90096}},	//   ırma, _anha, ुंची_, _फ्लॅ,
   {{0xd10900bf,0x317e215b,0x2005ba54,0xa3e52235}},	//   _نقشه_, bitz_, suli_, बीर_,
   {{0xafe51440,0x256b01df,0x2005799f,0x6d5750d5}},	//   _докл, _føle_, puli_, _coxa,
   {{0xdb060103,0x6da30f0c,0x2cac0727,0xdb0a02c6}},	//   _mikö, фира, ådd_, žníh,
   {{0xe80d02e8,0x7f442198,0x6d45863d,0xd9100504}},	//   ांना_, _uniq, _enha, کیس_,
   {{0x7bdcbf3f,0xfaa3c46e,0x225f300f,0xe9d70879}},	// [fc40] spru, дато, nyuk_, жку_,
   {{0x7bdc0078,0x291c0031,0x2cad00b6,0x6d570062}},	//   ppru, ýva_, ředa_, _goxa,
   {{0x1c1e007a,0xad9b0076,0xd70a00d3,0x00000000}},	//   _पहिल_, srúc, инже_, --,
   {{0x236dc46f,0x998000c6,0xdcfc00c6,0x00000000}},	//   jhej_, tvių_, torė, --,
   {{0xd0410092,0x236d023b,0x9b8a0018,0x7d1e0113}},	//   rclə, dhej_, _منگل_, _kbps,
   {{0x77690cf8,0x6d890206,0x224d01ff,0x00000000}},	//   _elex, eľaj, dxek_, --,
   {{0x317e89c6,0xdcf500d3,0x77694a62,0x224d0634}},	//   vitz_, liză, _flex, exek_,
   {{0x3958025a,0xdb0600c2,0x938a19e8,0x7c220234}},	//   _hors_, _eikö, јска_, _ćorl,
   {{0x914a5961,0x3958c470,0xdcf5020a,0x674500d2}},	//   ачна_, _kors_, niză, šují,
   {{0x55032082,0x657a0060,0x395802ac,0x00000000}},	//   _опуб, _umth, _jors_, --,
   {{0x3958c471,0x6d578273,0x3a220063,0x6aa70caf}},	//   _mors_, _roxa, _lpkp_, _खर्र,
   {{0x3958025a,0x443e38bf,0x236d2907,0xdea401c2}},	//   _lors_, _irt_, chej_, _haiƙ,
   {{0x443e3c92,0x3ead01c5,0x224b0212,0x6d57002b}},	//   _hrt_, ået_, äckt_, _poxa,
   {{0x7d1b005f,0x395801b3,0x443e85db,0xdb0417f9}},	//   đuso, _nors_, _krt_, lliè,
   {{0xdea401c2,0x660236e2,0xe88b0206,0x5bc50efb}},	//   _maiƙ, hrok, _ťažš, वदेव,
   {{0x443e9c5b,0xe8e000de,0x3a220085,0x238500e8}},	//   _mrt_, _đền_, _bpkp_, tēji_,
   {{0x3958c472,0x4fb40867,0x443ec473,0x60cd028e}},	// [fc50] _bors_, _تصور, _lrt_, _şami,
   {{0x443ec474,0xad9b0102,0xc4c40068,0x3958292e}},	//   _ort_, brúa, _لے_, _cors_,
   {{0x3958c475,0x636e0139,0x443e0227,0x00000000}},	//   _dors_, _gùng, _nrt_, --,
   {{0xe80c05a7,0x6602bb45,0x00000000,0x00000000}},	//   _हमरा_, frok, --, --,
   {{0x662700e3,0x8af001d4,0x8d7400cd,0x39587377}},	//   تراك, rkət, _رایا, _fors_,
   {{0xe578004d,0x39581892,0x1be80285,0x00000000}},	//   озі_, _gors_, टीवल_, --,
   {{0xdb1d0072,0x00000000,0x00000000,0x00000000}},	//   _lisí, --, --, --,
   {{0x6602c476,0x99890034,0x3f8b007e,0x37040284}},	//   brok, stań_, jncu_, _очув,
   {{0x443e05be,0x0ca83212,0x00000000,0x00000000}},	//   _ert_, _गर्म, --, --,
   {{0x8af00092,0x60091055,0x2b59014b,0x236d0216}},	//   nkər, бном_, _losc_, shej_,
   {{0xb4e77a0a,0x225f17b6,0x443e01cb,0xdb1d0076}},	//   परी_, syuk_, _grt_, _aisí,
   {{0x88d10081,0x224b02c3,0x527500d3,0x2a601a4a}},	//   িরিক, äcks_, _нулу, yyib_,
   {{0xe28e1067,0x443e0103,0x636e0032,0x3ea4003e}},	//   _ча_, _zrt_, _dùnd, æmt_,
   {{0xe80c05d4,0xd256040a,0xad9b003e,0x3ce6007f}},	//   _हमला_, _משנה_, trúa, करें_,
   {{0x2b5905fe,0xdb1d00e3,0x8c4300d3,0x660217a0}},	//   _bosc_, _eisí, нере, zrok,
   {{0x3958c477,0x2b590037,0x5aca0396,0xaffa00c1}},	//   _sors_, _cosc_, слам_, _פּוי,
   {{0x3f82c478,0xe8fa1787,0x9b460018,0x3958c479}},	// [fc60] miku_, йла_, _ہندو, _pors_,
   {{0x9f5f0094,0xa3cb0285,0x238500e8,0xdcf5020a}},	//   vrté_, लदा_, mēju_, riză,
   {{0x2b592f7c,0xc7260c79,0xdca6120a,0x7e600364}},	//   _fosc_, здей, _хани, ämpf,
   {{0x66026461,0xe5c60831,0x39580313,0x95ca3a46}},	//   trok, пско, _wors_, бука_,
   {{0xe5340084,0x39582dfc,0x9f5f0146,0xa3c102d5}},	//   дель, _tors_, nutá_, ूदन_,
   {{0x6602c47a,0x7bc601af,0x2bb41179,0x00000000}},	//   rrok, _hiku, ंगका, --,
   {{0x66e6559f,0x7bc6c47b,0x6ba7001f,0x3f823734}},	//   _нова, _kiku, _órgã, kiku_,
   {{0x6602c47c,0xe76a1574,0x443ec47d,0x07a30528}},	//   prok, _احسن_, _vrt_, _засн,
   {{0xa6aa1e56,0x7ae4c47e,0x784e0103,0x00000000}},	//   _طارق_, ibit, _fővá, --,
   {{0x7bc6c47f,0x443e7965,0x26c00138,0x238500e8}},	//   _liku, _trt_, žios_, dēju_,
   {{0x3f82c480,0x9ad30134,0x0ec802d5,0x6e240138}},	//   fiku_, _kịta, रखंड, _apib,
   {{0xdb040257,0x69da030b,0x7bc660b6,0xde8f0294}},	//   blié, _čten, _niku, kịta_,
   {{0x63a2c481,0x61461e2f,0x62343407,0x7ae423e2}},	//   _ikon, _неда, _целу, dbit,
   {{0x7bc60084,0xdb1d45f8,0x5bc505d6,0xdcfc0141}},	//   _aiku, _visí, वद्व, birč,
   {{0xaeec00c7,0x7bc601e2,0x7f594d70,0x2ca5052f}},	//   _কারণ_, _biku, _макс_, æld_,
   {{0xdb1d0074,0x7ae4118e,0x7bc60479,0x238500e8}},	//   _tisí, gbit, _ciku, bēju_,
   {{0x2aab364c,0x63a2068d,0x89d900e3,0x238500e8}},	// [fc70] ство_, _mkon, زوار_, cēju_,
   {{0xd138013f,0x6f1d04aa,0x7ae4c482,0x9ce700d3}},	//   ndą_, lfsc, abit, _эцил,
   {{0x2d8341e3,0x7bc6c483,0x7bc3028d,0xb9c40037}},	//   mije_, _fiku, _ènuo, رقمي,
   {{0x7bc68055,0xd366001c,0x63a24864,0xcb0b00c2}},	//   _giku, _شه_, _nkon, _уход_,
   {{0x6b8d009c,0x80c50a43,0x00000000,0x00000000}},	//   mnag, লুপ্, --, --,
   {{0x64a56924,0x63a24c9c,0xb92500e3,0x69ddc484}},	//   мала, _akon, _تفسي, _itse,
   {{0x26d20b88,0x7c22015c,0x7640010a,0x2fdc0381}},	//   ıyor_, _ćork, _ermy, _ntvg_,
   {{0x6b8dc485,0xc2450408,0x2d83c486,0x61c80fdd}},	//   nnag, дник, hije_, रदूष,
   {{0x2d830193,0x69c7c487,0x69cf0268,0x6b8d54ca}},	//   kije_, _kije, _juce, inag,
   {{0x2d83858e,0x3f820085,0x7aef34d2,0x69cfc488}},	//   jije_, wiku_, _lect, _muce,
   {{0x2d8308a9,0x69c70292,0x69cf0996,0x6d5a00aa}},	//   dije_, _mije, _luce, ötam,
   {{0x69c7029b,0x69dd007a,0xdb0f0072,0x69cf0072}},	//   _lije, _otse, _micó, _ouce,
   {{0x69dd0d7d,0x7bc6749e,0x63a970d6,0xbf180139}},	//   _ntse, _riku, mlen, _aṣís,
   {{0x2d83c489,0x69c7c0f0,0x7bc6c48a,0x44250084}},	//   gije_, _nije, _siku, _kpl_,
   {{0x3f824695,0xdca30870,0x69dd22c9,0x7bc67f41}},	//   piku_, вари, _atse, _piku,
   {{0x63a9b971,0x69cf34ef,0x6b8dc48b,0x672b00dd}},	//   nlen, _buce, gnag, jegj,
   {{0x2d839be1,0x69c70fa3,0x7ae43246,0x7bc6c48c}},	// [fc80] bije_, _bije, rbit, _viku,
   {{0x69c7029b,0x63a970d1,0x69cf4d21,0x7ae48a18}},	//   _cije, hlen, _duce, sbit,
   {{0x69c7c48d,0x63a9c48e,0xb8f60775,0x7aef03a8}},	//   _dije, klen, _हल_, _fect,
   {{0xdb1d001f,0xadeb397e,0x69cf028d,0x63a920a2}},	//   _visã, जीवन_, _fuce, jlen,
   {{0x2bd20d88,0x64412414,0x63a9c48f,0x4425c490}},	//   _दूता, _arli, dlen, _apl_,
   {{0x63a2c491,0x6b8499bf,0x64410234,0x2bbe0285}},	//   _skon, liig, _brli, ्दवा,
   {{0x63a923b4,0x200502ef,0x672bc492,0x00000000}},	//   flen, jrli_, begj, --,
   {{0xdb0d0303,0x63bbc493,0x6d5a007a,0x63a9c494}},	//   rmaç, gmun, ötaj, glen,
   {{0x644117c6,0x4425773b,0x2005028d,0x6eaa0096}},	//   _erli, _epl_, erli_, _घरगु,
   {{0x7bde0039,0xbe140033,0x6b84008c,0x00000000}},	//   _otpu, িবাদ_, hiig, --,
   {{0x2d8300e9,0x63a9c495,0x64410335,0xd1380138}},	//   vije_, blen, _grli, rdą_,
   {{0x63a262d7,0x224908a9,0x63a911e0,0x6f1d042c}},	//   _ukon, _šake_, clen, ufsc,
   {{0x2d8300cb,0x20050451,0x7aef34d2,0xc04600d1}},	//   tije_, arli_, _rect, سخگو,
   {{0x7aef6f73,0x601700ac,0x009400ae,0x6e3d0537}},	//   _sect, ụmah, _пилэ, rvsb,
   {{0x69c7029b,0xe5710130,0x44250124,0x394d02ef}},	//   _rije, אַן_, _xpl_, _đes_,
   {{0x2d8308a9,0x69c7c496,0x200cc497,0x69cf20ed}},	//   sije_, _sije, mudi_, _puce,
   {{0x9ccb00d3,0x200c003d,0xdb1d0206,0x00000000}},	// [fc90] _мына_, ludi_, _cisá, --,
   {{0x63bbc498,0x63a9c499,0x69cf037a,0x9f5f0037}},	//   zmun, zlen, _vuce, irtí_,
   {{0x69c7029b,0x200c00e9,0x2fc90197,0x63a9bbd5}},	//   _vije, nudi_, _kiag_, ylen,
   {{0xf8df06e4,0x28df022d,0x7afd01c5,0x2fc9023e}},	//   _प्रय, _प्रि, _udst, _jiag_,
   {{0x69c7029b,0x200c53ab,0xf7730260,0x69dd13f8}},	//   _tije, hudi_, _یار_, _utse,
   {{0x660b0305,0x2fc9c49a,0x212c023b,0x4425c49b}},	//   rugk, _liag_, jedh_, _ppl_,
   {{0x63a9c49c,0x4369495f,0x03a561f5,0x63bb1fc6}},	//   tlen, зайн_, нико, tmun,
   {{0x644100cc,0x2fc9006c,0x4255171b,0xdb1e0072}},	//   _vrli, _niag_, етот, _supú,
   {{0x63a9c49d,0x3ea901dc,0x00000000,0x00000000}},	//   rlen, _nyat_, --, --,
   {{0x63bbc49e,0x6b810134,0x80da2397,0x78a2020a}},	//   smun, ịgha, पुले, şove,
   {{0x3ea910dd,0x63bbc49f,0x2fc90270,0x200c6dff}},	//   _ayat_, pmun, _biag_, gudi_,
   {{0x3c3900d2,0x00000000,0x00000000,0x00000000}},	//   zývá_, --, --, --,
   {{0x2fc9c4a0,0x6d890b14,0x00000000,0x00000000}},	//   _diag_, džab, --, --,
   {{0x2005033b,0x332d026d,0xfe7f00b3,0x00000000}},	//   prli_, leex_, taïr_, --,
   {{0x6ea00c16,0xc4d200ca,0x3f6a0291,0xe1f900c6}},	//   _गुरु, רגל_, _нико_, lsų_,
   {{0x92c300c7,0xe9da0805,0x645c00ee,0xfe7f00ee}},	//   ্রী_, зка_, _àrie, raïr_,
   {{0x6b84007a,0xe1f90138,0x00000000,0x00000000}},	// [fca0] riig, nsų_, --, --,
   {{0x850e417a,0x2fc901fa,0xdff33d34,0x26cd0062}},	//   _साइट_, _ziag_, _आबाद_, _ageo_,
   {{0x2fc901fa,0x63a02ad2,0x65ad0031,0x636e0441}},	//   _yiag_, yomn, rúhl, _lùna,
   {{0x09e62ba6,0x68e308bb,0xd6c400cd,0x65ad0220}},	//   _помн, ında, نمای, súhl,
   {{0x6d5ec4a1,0x1634571b,0x7af6c4a2,0xe80c074c}},	//   _kopa, теля, mayt, _हमका_,
   {{0x26cd0036,0x5bbe0129,0x7af6841c,0xceb300ca}},	//   _egeo_, _ọchị_, layt, איד_,
   {{0x6d5e9fb8,0x69d600dd,0x63a0c4a3,0x5334008f}},	//   _mopa, lqye, tomn, вейт,
   {{0x31c845c8,0xd37717b9,0x7af60abd,0x63750076}},	//   रद्ध, ечь_, nayt, _lánf,
   {{0xc2981116,0xdb040072,0x00000000,0x00000000}},	//   ьких_, nmiñ, --, --,
   {{0x200cc4a4,0x63a00220,0x6d5e6204,0x02e013cc}},	//   tudi_, somn, _nopa, _ग्रह_,
   {{0x63a0247d,0xb4cc2f4f,0x69d6023b,0x00000000}},	//   pomn, रखी_, hqye, --,
   {{0x200c86c1,0x4ea73566,0x753a0062,0xee3f0094}},	//   rudi_, ерга, _hatz, tvý_,
   {{0x753a01bf,0x200c804c,0x518632a2,0x98b101d3}},	//   _katz, sudi_, _пука, _mazā_,
   {{0x238c00b6,0x753a0062,0x00000000,0x00000000}},	//   ději_, _jatz, --, --,
   {{0x850e048a,0x1fa7014d,0x3d12048a,0x2fc901bb}},	//   _साईट_, _приг, _तारे_, _tiag_,
   {{0x9b581a77,0x7af60270,0x753a0634,0x00000000}},	//   нист_, gayt, _latz, --,
   {{0x4ea70109,0x7f4d009e,0x3a9800ae,0xbebb02ac}},	// [fcb0] _ярка, _inaq, ектэ_, geët,
   {{0x93bc00ae,0x7cd900c2,0x753a303d,0x00000000}},	//   _spăl, _юмор_, _natz, --,
   {{0x7f4d0216,0xa02100bc,0x79850169,0x00000000}},	//   _knaq, _ööta, rihw, --,
   {{0xdddd00a5,0x6d5e4243,0x638700cd,0x7f4d009e}},	//   mysł, _zopa, _mènè, _jnaq,
   {{0x753a03f3,0x6d5e037a,0x26c202c6,0x7f4d009e}},	//   _batz, _yopa, _úkol_, _mnaq,
   {{0xa2c40976,0x636e0441,0x6eaa294e,0x00000000}},	//   ाइन्, _rùna, _घरघु, --,
   {{0x753a18c9,0x69aa09c3,0x638703a9,0xd4e4004d}},	//   _datz, _जीटी, _nènè, уючи,
   {{0x753a0062,0x78b50117,0x7f4d02a1,0x00000000}},	//   _eatz, _izzv, _nnaq, --,
   {{0xa5350d06,0x45d500d6,0x3d1200c3,0x753a5768}},	//   _инач, _розс, _ताले_, _fatz,
   {{0x673b01bb,0x7f4d0143,0x753a0634,0xe1f90138}},	//   _hauj, _anaq, _gatz, rsų_,
   {{0xdee617e9,0x92c30081,0x6d5ec4a5,0x7f5f0090}},	//   кони, ্রে_, _ropa, _boqq,
   {{0x6d5e98ce,0x2d91008f,0x753ac4a6,0x673b01ff}},	//   _sopa, enze_, _zatz, _jauj,
   {{0x9f5f0084,0x673b4d0a,0x00000000,0x00000000}},	//   yttö_, _mauj, --, --,
   {{0xdb1d0d64,0x673b4c19,0x61fbc4a7,0x602501b3}},	//   _lisä, _lauj, msul, _адка,
   {{0xdca61055,0x68f7008a,0xdb0f009c,0xa3e500b6}},	//   тави, daxd, _bhcà, बीच_,
   {{0x673b08a1,0x98a7030b,0x2d9153b2,0xab270582}},	//   _nauj, žně_, anze_, коса_,
   {{0x6d5ec4a8,0x81e50033,0xdb04002b,0x00000000}},	// [fcc0] _topa, _ফিড_, umiñ, --,
   {{0x7af600f9,0xbef2009d,0xbc661012,0x63750143}},	//   sayt, _अजुन_, _авок, _hánd,
   {{0x61fb0092,0x673b0364,0x63750139,0x661b0372}},	//   hsul, _bauj, _gáng, _aquk,
   {{0x6a86569d,0x61fbc4a9,0x753a0364,0xb68a0504}},	//   _алма, ksul, _satz, وپال_,
   {{0x9f59c4aa,0x63753859,0x68f7008c,0x753ac4ab}},	//   éré_, _mánd, baxd, _patz,
   {{0xb4cc009d,0x6e29026a,0xe5e50037,0x636e01b9}},	//   रखे_, çebi, اثني, _cùnn,
   {{0xbef2009d,0xe9df0019,0x29180740,0xf7830090}},	//   _अजून_, _trúc_, _icra_, _baħħ_,
   {{0x442003e5,0xdcee0220,0x60cd026a,0x673bc286}},	//   ċi_, jobľ, _şamp, _gauj,
   {{0x171b0130,0x61fb1336,0x75820470,0xdddd0034}},	//   _קומע, gsul, _پیغم, zysł,
   {{0x673b1cf3,0x717400e3,0x638703a9,0x00000000}},	//   _zauj, اهدا, _pènè, --,
   {{0x6375c4ac,0x7bda0143,0x61fb0172,0x257001b9}},	//   _bánd, ítul, asul, _gàla_,
   {{0x637524c7,0xbebb084e,0xbb1b044c,0x00000000}},	//   _cánd, deër, _amîn, --,
   {{0x5f940dde,0x63757176,0x7642c4ad,0x29180036}},	//   рият, _dánd, nvoy, _ocra_,
   {{0x61e2c4ae,0x61ed07aa,0x7e600212,0x63870154}},	//   _itol, _çala, ämpa, _tènè,
   {{0x7f5f00a7,0x08f10081,0x224600c4,0xbebb084e}},	//   _toqq, _চালু_, _hrok_, geër,
   {{0x63750042,0x7f4d00ee,0x22461670,0x2918c4af}},	//   _gánd, _unaq, _krok_, _acra_,
   {{0xdb04003e,0x2918037a,0x201ec4b0,0x00000000}},	// [fcd0] rmið, _bcra_, ltti_, --,
   {{0xdb1d0d64,0xd7e702ec,0x201e116a,0xe9df002b}},	//   _sisä, відо, otti_, _crúa_,
   {{0x201e0084,0x68f776ef,0xa9c4084c,0x48ab0077}},	//   ntti_, raxd, рстк, фтам_,
   {{0x201e02fd,0x61e288ab,0xd6db00d6,0x77600113}},	//   itti_, _otol, єте_, _comx,
   {{0xf7700177,0x63b902ad,0x98b100d3,0x61e2c4b1}},	//   غام_, _rhwn, _bază_, _ntol,
   {{0xe9df05e6,0xa979006e,0xf1ba020b,0x00000000}},	//   _grúa_, _טאָכ, _nhơ_, --,
   {{0xdb040018,0x61e2c4b2,0x22461195,0x3d1b034c}},	//   lliá, _atol, _arok_, _बाने_,
   {{0x61fb6f20,0x22465b5a,0x490b00b6,0x77b80042}},	//   tsul, _brok_, ालको_, tíxe,
   {{0x68f50068,0xe7841778,0x201e30cf,0x61fb0b62}},	//   _kezd, _туро, etti_, usul,
   {{0x61fbc4b3,0x68f5c4b4,0x6375c4b5,0x9f5f0094}},	//   rsul, _jezd, _sánd, vrtá_,
   {{0x61e20294,0x61fb2f1c,0xbfc6008f,0xa0694d95}},	//   _etol, ssul, лбок, хана_,
   {{0xeeeb00ef,0x20180472,0xd24e09b4,0x2a690124}},	//   ường_, ària_, آنی_, kyab_,
   {{0x5fcf13ae,0x65614ab2,0x201e142f,0x637e00c6}},	//   _संकल, _kolh, atti_, gūnu,
   {{0x5bbe0835,0x236d00d4,0x00000000,0x00000000}},	//   ्द्व, lkej_, --, --,
   {{0xab2a1d7b,0x6561001f,0xd01100e3,0x63751ba6}},	//   нова_, _molh, _الع_, _tánd,
   {{0xf0920054,0x29030018,0xfaa6020f,0x33267ae7}},	//   _לנו_, _adja_, габо, _xbox_,
   {{0xf2d20132,0x68f513bd,0xeb9700d3,0x3a2b03a8}},	// [fce0] מען_, _bezd, уит_, _cpcp_,
   {{0x1e5700d7,0x7760039f,0x00000000,0x00000000}},	//   _עשיר_, _somx, --, --,
   {{0x9d1b00c1,0x7760023e,0x98b1044c,0xbddb210f}},	//   _אויט, _pomx, _rază_, nvèn,
   {{0x2d8a66e8,0xe9df0143,0x6375033c,0x2a69022b}},	//   libe_, _irún_, _lánb, byab_,
   {{0x65610b27,0x6f040063,0xdb07002b,0x98b1020a}},	//   _bolh, _mdic, _émái, _pază_,
   {{0x6561001f,0x66040220,0xad9b0037,0x201e8821}},	//   _colh, šiko, trúi, ytti_,
   {{0x3a20c4b6,0xd90d04c6,0xb4260018,0x00000000}},	//   ltip_, _زین_, اعتو, --,
   {{0x69cec4b7,0x22460167,0xfaff023b,0x6f0466d5}},	//   _hibe, _prok_, _ulët_, _ndic,
   {{0x69cec4b8,0x65610396,0xc1740dde,0x3a202d96}},	//   _kibe, _folh, илищ, ntip_,
   {{0x6f04c4b9,0x2ee0005c,0xdb1e0146,0xe8e00023}},	//   _adic, _afif_, _kupó, _đớn_,
   {{0x69cec4ba,0x05770037,0xddc40172,0x2570009c}},	//   _mibe, _حملة_, _eriŋ, _hàlo_,
   {{0x236d0181,0x201ec4a9,0x9989564a,0x442c0087}},	//   ckej_, rtti_, ktaş_, _ipd_,
   {{0x11543d7c,0x61e20018,0xf1ba0019,0x64480146}},	//   _вклю, _utol, _thơ_, _hrdi,
   {{0x6f0404d3,0x442c1a47,0x68e902ef,0xe9df6d26}},	//   _edic, _kpd_, _đedo, _brún_,
   {{0x80db00ca,0x00000000,0x00000000,0x00000000}},	//   _אחוז, --, --, --,
   {{0x501b00ca,0x00000000,0x00000000,0x00000000}},	//   _נוחו, --, --, --,
   {{0x69ce2fe9,0x8d871f5d,0x3f8b7ada,0x3d9500d6}},	// [fcf0] _bibe, _бунд, micu_, _випр,
   {{0x2d8a11ce,0x3f8b02e6,0x64480d63,0x6e2d1ef8}},	//   cibe_, licu_, _ordi, _ipab,
   {{0x69ce10e3,0xdb1e0487,0x6561016d,0xb8fd0179}},	//   _dibe, _cupó, _rolh, _डल_,
   {{0x3f8b45ca,0x636e0af0,0x656120ab,0x69ce225b}},	//   nicu_, _bùnm, _solh, _eibe,
   {{0x69ce1d91,0xe8010251,0xb9200134,0x6375c4bb}},	//   _fibe, _लटका_, ntrị_, _lánc,
   {{0x69ce5a3e,0x7aedc4bc,0x2cad00b6,0x644300e7}},	//   _gibe, lbat, ředu_, tvni,
   {{0x65611507,0x3f8b00cb,0xf99f0383,0x7bcf05bd}},	//   _volh, kicu_, _avèg_, _kicu,
   {{0x442c6c87,0x3f8b02e6,0x7aed0a00,0x64430968}},	//   _dpd_, jicu_, nbat, rvni,
   {{0x3f8b1419,0x64480a00,0x7bcf8685,0x7bd71106}},	//   dicu_, _erdi, _micu, _luxu,
   {{0x7aed0167,0x236d0181,0x7bcfc4bd,0x2b400117}},	//   hbat, skej_, _licu, zdic_,
   {{0x6e2d3ad9,0x8af001d4,0x63750890,0x3f8b00cc}},	//   _apab, rkəz, _cánc, ficu_,
   {{0x764914b1,0x7bcfc4be,0x3f8b04e9,0xe80d02d5}},	//   _krey, _nicu, gicu_, _हिना_,
   {{0x6d8903ce,0x200cc4bf,0xee3724c0,0x7aed291d}},	//   ržan, ardi_, аня_, dbat,
   {{0x61e9a9e1,0xeeeb0028,0x427a0327,0x63a40f1c}},	//   mpel, ưởng_, _באנג, čine,
   {{0x2d8ac4c0,0x69ce4772,0x6b66013d,0x6729423b}},	//   ribe_, _ribe, аква, _obej,
   {{0x6f04ac77,0x69ce4051,0x7aedc4c1,0x3f8b0335}},	//   _udic, _sibe, gbat, cicu_,
   {{0x7bcf39a0,0xdb1e08a8,0x69cec4c2,0xe9d716e6}},	// [fd00] _dicu, _supó, _pibe, икт_,
   {{0x7aed1f9a,0x6729c4c3,0x61ed003d,0x8d770281}},	//   abat, _abej, _ħall, _ناپا,
   {{0x7aed1114,0x59d80251,0x3d1b0251,0x64580042}},	//   bbat, _भंवर, _बाते_, xxvi,
   {{0x76490102,0x70d21f88,0x7bcf0193,0x61e90063}},	//   _brey, _सल्ल, _gicu, kpel,
   {{0x69cec4c4,0x28b80455,0x7649034f,0x442c1aee}},	//   _tibe, _अरवि, _crey, _spd_,
   {{0x442c91c4,0x76491d4a,0x3f8b0106,0x7bd700a7}},	//   _ppd_, _drey, zicu_, _yuxu,
   {{0x9cd700a1,0x6d8900e7,0x61e920ae,0x76493634}},	//   בוצה_, džal, epel, _erey,
   {{0x7649003e,0x200c0335,0x98b80090,0x67290032}},	//   _frey, vrdi_, _gorġ_, _gbej,
   {{0x76490d8e,0x637504d8,0x7e600149,0x0ea50592}},	//   _grey, _sánc, ämpl, _गुंड,
   {{0x7aed00d3,0x64480087,0x200c033b,0x15ba10e0}},	//   zbat, _trdi, trdi_, _рыбы_,
   {{0x6448c4c5,0x04db021e,0x403454b5,0x6e2d4492}},	//   _urdi, _סקאל, щенс, _spab,
   {{0x7e7d042c,0x672902a1,0x00000000,0x00000000}},	//   tzsp, _xbej, --, --,
   {{0xa1160979,0x3f8b02e6,0x7bcfb35e,0x7bd70188}},	//   _نوشت, ricu_, _ricu, _suxu,
   {{0x7bcf0465,0x3f8b14f3,0xac190e20,0x63750103}},	//   _sicu, sicu_, логу_, _tánc,
   {{0x7bcf2bd6,0x7aed0381,0xb9200294,0x00000000}},	//   _picu, tbat, strị_, --,
   {{0x7aed02fa,0xdb1e6949,0x6d5ac4c6,0x00000000}},	//   ubat, _supò, ötar, --,
   {{0x7bd7025e,0x7aedc4c7,0x7bcf97a9,0x4aa70179}},	// [fd10] _wuxu, rbat, _vicu, _कुशव,
   {{0x63750088,0x7aed6cd6,0x69da02c6,0x7bcfc4c8}},	//   _mána, sbat, _čtet, _wicu,
   {{0xd246110a,0x63755f58,0xab5b8159,0x7bcf044c}},	//   _کن_, _lána, _diür, _ticu,
   {{0x6e4400cd,0x7649c4c9,0xdc36006e,0x07080037}},	//   _انیم, _prey, _פארט_, ليمي_,
   {{0x63750088,0x6b8dc4ca,0xd6d90034,0xa509120a}},	//   _nána, miag, _cała_, гела_,
   {{0xa80503be,0x2a3a006e,0x77b80072,0x60170174}},	//   _coñé, _געשמ, ríxa, ụmih,
   {{0x69c525c0,0x28c30557,0x00000000,0x00000000}},	//   mmhe, वेशि, --, --,
   {{0x6b8dc4cb,0x9ad30294,0x7649c4cc,0x6729c4cd}},	//   niag, _aịza, _trey, _ubej,
   {{0x63750037,0x81df0033,0x61e905c2,0x6d17007f}},	//   _cána, ধীন_, upel, _तांग_,
   {{0x6b8d03f3,0x61e9c4ce,0x320dc4cf,0x515500ae}},	//   hiag, rpel, rrey_, стиу,
   {{0xa0a5434e,0x6d8900cc,0x69c5c4d0,0x6b8d01e9}},	//   санд, ržal, imhe, kiag,
   {{0x61e9533f,0x320d009c,0x6375c4d1,0x257905aa}},	//   ppel, prey_, _fána, _dèle_,
   {{0xaaa7009d,0x63a90313,0x6375037a,0x00000000}},	//   _कुलक, moen, _gána, --,
   {{0x63a90cc4,0x3d1200c3,0x61e693bd,0xfce38c7f}},	//   loen, ़लें_, íkle, зоро,
   {{0xdd8f2761,0x6b8dab7f,0x69c503dc,0xc0c80284}},	//   روف_, fiag, dmhe, _куће_,
   {{0x6b8dc4d2,0x63a931d4,0xef1a00c2,0xda03007a}},	//   giag, noen, _сми_, _लिखत_,
   {{0x3de20081,0x9f5f0146,0x00000000,0x00000000}},	// [fd20] _বিকল, nutý_, --, --,
   {{0x63a90126,0xd9100470,0x9cf6002d,0xe8f7400f}},	//   hoen, بیس_, _учиш, йлу_,
   {{0x63a939e4,0xa3b70789,0x6b8d08fc,0x387f03e3}},	//   koen, छता_, biag, _ƙura_,
   {{0x7c3e02e6,0x69c50305,0x3f890063,0x9f5f023c}},	//   _ispr, amhe, _xmau_, kutý_,
   {{0x63a90a9f,0xa805002b,0x2003033b,0x6d89007e}},	//   doen, _poñé, šjih_, džaj,
   {{0xf8dc0775,0x637c00cd,0x7c3e022b,0x3ea080de}},	//   _बलिय, _kéng, _kspr, _mxit_,
   {{0xe3af0421,0x637c03a9,0xf7461165,0x00000000}},	//   کرو_, _jéng, _лево, --,
   {{0x637c01dc,0x63a90a00,0x68fe0124,0xf40f0037}},	//   _méng, goen, lapd, رؤى_,
   {{0x25be061d,0x637c03a9,0x3ea00216,0xaaae0285}},	//   _thtl_, _léng, _nxit_, _झुमक,
   {{0xe80d02e8,0x7c3e069a,0x256b01df,0x291a66e5}},	//   ांचा_, _ospr, _sølv_, ngpa_,
   {{0xa3df000f,0x63a9032e,0x649a0636,0x2fc003ea}},	//   _धूप_, boen, _стар_, _bhig_,
   {{0x443e3477,0x63a9c4d3,0x289b0341,0x68fe0eac}},	//   _ist_, coen, ריטא, hapd,
   {{0x4aa70d39,0x6b8d168c,0x66024ead,0x2fc0008c}},	//   _कुंव, viag, nsok, _dhig_,
   {{0x2366023e,0x637c0113,0x614315a6,0x443eb294}},	//   _hooj_, _béng, _неча, _kst_,
   {{0x236601fa,0x443ec4d4,0x637c0113,0x9fe60f98}},	//   _kooj_, _jst_, _céng, _استه,
   {{0x23660357,0x00000000,0x00000000,0x00000000}},	//   _jooj_, --, --, --,
   {{0x7c3e8c5f,0x6b8dc4d5,0x236601fa,0xeab30037}},	// [fd30] _espr, riag, _mooj_, سعر_,
   {{0x2366022e,0x63a9c4d6,0x443e2e9c,0x6b8da8bd}},	//   _looj_, zoen, _ost_, siag,
   {{0x69c50080,0xdb0d0037,0x63a90051,0xf7700421}},	//   rmhe, llaí, yoen, کال_,
   {{0xdb0d00e3,0x637c03a9,0x501b2252,0x63a90062}},	//   olaí, _jénd, רואו, xoen,
   {{0x637c2f20,0x62800141,0x00000000,0x00000000}},	//   _ménd, jzmo, --, --,
   {{0xd5af0018,0x3f9903e3,0xd4690012,0x00000000}},	//   رہا_, hnsu_, ииле_, --,
   {{0xdcf500d9,0x984800ae,0x2bbf1e05,0x00000000}},	//   lizē, _лята_, ्षपा, --,
   {{0x2366023e,0x9f5f0076,0x00000000,0x00000000}},	//   _cooj_, artú_, --, --,
   {{0x443e1729,0x63a94926,0xe29942c7,0xdcf500d9}},	//   _est_, roen, рап_, nizē,
   {{0x63a9bfd3,0x5fdd0285,0x00000000,0x00000000}},	//   soen, _नंदल, --, --,
   {{0x25a00080,0x7dc00103,0x63a9c4d7,0x39432222}},	//   éile_, nöse, poen, _majs_,
   {{0xd6d90034,0x637c01dc,0x1eca078b,0x527500d3}},	//   _mało_, _cénd, илни_, _мулу,
   {{0x637c03a9,0xdb0d0076,0x256b00f2,0x67f00139}},	//   _dénd, glaí, _følt_, _kòjò,
   {{0x9f4600e3,0x236601fa,0x29cd007e,0x637c00d1}},	//   mplí_, _zooj_, _džak_, _péng,
   {{0x3d1b1085,0x8c437ce1,0x2fc06b75,0x23660197}},	//   _बारे_, мере, _thig_, _yooj_,
   {{0xdb0400e3,0x637c03a9,0x0aea01b6,0xe8e000fe}},	//   lliú, _génd, рдай_, _đốn_,
   {{0xe8fa2820,0xc332028c,0xdb0d0037,0x98b800ae}},	// [fd40] ила_, וון_, claí, _oară_,
   {{0x61e400e3,0x9f5f0487,0xad9b0076,0x637cc4d8}},	//   _éile, butó_, lsún, _téng,
   {{0xb17a00c1,0xdb040037,0x6d89050d,0x63750094}},	//   סטער, iliú, džah, _náno,
   {{0xd37800e9,0x68fe6e08,0x39430124,0xe51c2065}},	//   _kuće_, sapd, _eajs_, _नाहि_,
   {{0xe5c62348,0x23660197,0x7f44037a,0xddcd24a1}},	//   оско, _rooj_, _maiq, _braň,
   {{0x1dbc099d,0x443e2fa2,0x63750224,0x53e61bc1}},	//   ोगित, _pst_, _báno, оциа,
   {{0x475a2dfb,0x66027a33,0xd37a0aeb,0x236601fa}},	//   _края_, ssok, ичи_, _pooj_,
   {{0x68fcc4d9,0x7ae447a5,0x93bc002d,0x637503be}},	//   _herd, ncit, _apăr, _dáno,
   {{0xa5f70396,0x637c0072,0x2e24003e,0x62340012}},	//   _меѓу_, _rénd, jöf_, чепу,
   {{0x7ae400ec,0x443e0231,0x637c0072,0x28af023a}},	//   hcit, _tst_, _sénd, _जुडि,
   {{0x23660197,0x443ec4da,0xd8db006e,0x637c0328}},	//   _tooj_, _ust_, יקיר, _pénd,
   {{0x65680052,0x68fc915f,0x637c00fc,0xddcd00d8}},	//   _hodh, _lerd, _béne, _zraň,
   {{0x6568c4db,0x637c0328,0x68fc1868,0x46ca00b6}},	//   _kodh, _vénd, _oerd, िधिह,
   {{0x68fc026a,0x656801dc,0xdb0d0037,0xd37800c4}},	//   _nerd, _jodh, rlaí, _duće_,
   {{0x6568c4dc,0x39432a3e,0x637c65ea,0x00000000}},	//   _modh, _rajs_, _ténd, --,
   {{0x65687a93,0xdb0d01cd,0xdcf501d3,0x9f5f034f}},	//   _lodh, gmað, tizē, rutó_,
   {{0x68fcc4dd,0x637c2e40,0x49752863,0x29d500e3}},	// [fd50] _berd, _géne, плас, سياس,
   {{0x68fc5c8e,0xdcf500d9,0xf84b00d3,0x6568a1d7}},	//   _cerd, rizē, ичей_, _nodh,
   {{0x2d91c4de,0x68fc8940,0x4735120c,0x6d5725f5}},	//   mize_, _derd, знес, _inxa,
   {{0x68fc04ee,0x6f1dc4df,0x7ae49143,0x657a85af}},	//   _eerd, ngsc, ccit, _alth,
   {{0x6d453e73,0x65684699,0x7afd0029,0x637c0933}},	//   _kaha, _bodh, _iest, _xéne,
   {{0x68fcc4e0,0x2d919c3e,0x6d47c4e1,0x7afd2eb8}},	//   _gerd, nize_, ndja, _hest,
   {{0x29010694,0x6d450e69,0x7afd8c1b,0x69dd3813}},	//   maha_, _maha, _kest, _huse,
   {{0x6d45c4e2,0x7afdc4e3,0x2901c4e4,0x69dd52b4}},	//   _laha, _jest, laha_, _kuse,
   {{0x68fc07d1,0x9ad30294,0x69dd2ceb,0x2d91768f}},	//   _yerd, _dịga, _juse, kize_,
   {{0x6d45c4e5,0x61e60074,0x656800cd,0x29019306}},	//   _naha, íkla, _godh, naha_,
   {{0x69d55457,0x69ddc4e6,0xcea9006e,0xfbdb2171}},	//   _mize, _luse, _עי_, _मूलम,
   {{0x69d54a82,0x7afdc4e7,0x6441c4e8,0x6d5700b3}},	//   _lize, _nest, _isli, _anxa,
   {{0x2d9106a3,0x29019d87,0x69ddc4e9,0xe8b80176}},	//   fize_, kaha_, _nuse, _अर्च,
   {{0x6d453665,0x2d91023f,0x69d565f3,0x637cc4ea}},	//   _caha, gize_, _nize, _véne,
   {{0x7afdc4eb,0x2901025e,0x6d45c4ec,0x307900c1}},	//   _best, daha_, _daha, _לאַנ,
   {{0x7afd2449,0x6d57414c,0x69dd81ea,0xbea600d6}},	//   _cest, _enxa, _buse, _найк,
   {{0x7afdc4ed,0x7ae42f48,0x6d45c4ee,0x2d84025a}},	// [fd60] _dest, rcit, _faha, èmes_,
   {{0x7afd3b30,0x7ae4c4ef,0xdb0d003e,0x6d45c4f0}},	//   _eest, scit, smað, _gaha,
   {{0x7afd34d2,0x69d5c4f1,0x656803a9,0x443c006c}},	//   _fest, _dize, _rodh, xwv_,
   {{0x68fc12c1,0x6d45c4f2,0x68e50049,0x69dd5058}},	//   _werd, _zaha, achd, _fuse,
   {{0x6d45c4f3,0x68fc10f3,0x69d511f6,0x6441c4f4}},	//   _yaha, _terd, _fize, _asli,
   {{0x7afdc4f5,0x69d51235,0x6d45003d,0x200713c6}},	//   _zest, _gize, _xaha, _ovni_,
   {{0x777b1c07,0x7bdea615,0x798e02a4,0x65680052}},	//   _flux, _jupu, _imbw, _vodh,
   {{0x7afd22e7,0x63a40660,0xf7432dc5,0x8c1b0089}},	//   _xest, čino, _песо, צופי,
   {{0x7bde0533,0x2007c4f6,0x69dd008a,0x6568033f}},	//   _lupu, _avni_, _xuse, _todh,
   {{0xad9b0080,0x04460636,0x44270113,0x7bde00f9}},	//   gsúl, _незн, btn_, _oupu,
   {{0x2d91c4f7,0x636e009c,0x7bde743c,0x00000000}},	//   vize_, _bùnt, _nupu, --,
   {{0x6d45c4f8,0x929d00a5,0x29011bbd,0x2d918af6}},	//   _saha, wałe, zaha_, wize_,
   {{0x2901c4f9,0x6e3d0ab2,0x2d91c4fa,0x0ec70455}},	//   yaha_, uwsb, tize_, रेंड,
   {{0x69ddc4fb,0x7bdec4fc,0x2901008a,0x3d1709c3}},	//   _ruse, _bupu, xaha_, तलें_,
   {{0x2d91c4fd,0x6d47c234,0x7afd1173,0x69dd5241}},	//   rize_, rdja, _pest, _suse,
   {{0x2d91be37,0x69ddbd98,0x7bde45b0,0x1fa4013f}},	//   size_, _puse, _dupu, _прыг,
   {{0x7afdc4fe,0x6d45c4ff,0x63752897,0x2901c500}},	// [fd70] _vest, _taha, _bánj, taha_,
   {{0x7afd2071,0x395854ca,0x6d45b0f8,0x00000000}},	//   _west, _cnrs_, _uaha, --,
   {{0x2901c501,0xb4bb0d0d,0x69d5c502,0x7bde03a9}},	//   raha_, _घरे_, _vize, _gupu,
   {{0x69dd1f60,0x78b5025b,0x569500c2,0xe6950037}},	//   _tuse, _vyzv, мает, ولاد,
   {{0x69d50103,0x29010270,0x8b0802c6,0x6f0d0350}},	//   _tize, paha_, stří, _mdac,
   {{0x2901b586,0x00000000,0x00000000,0x00000000}},	//   qaha_, --, --, --,
   {{0x98b816d7,0xe5040076,0x00000000,0x00000000}},	//   _parą_, ربوي, --, --,
   {{0x2b4973d3,0xe3b102a3,0x7705001c,0x6f0d05bd}},	//   ndac_, خرت_, _آژان, _ndac,
   {{0x3a29005a,0x0eac0034,0xd346001c,0xa5f8007b}},	//   ntap_, _टुंड, بینه_, _нету_,
   {{0x60096eb1,0x4427061d,0x6f0d0027,0xfaff0313}},	//   оном_, ptn_, _adac, _leë_,
   {{0x644103c6,0x8fa60448,0x66040218,0xfbbf0c38}},	//   _usli, дане, šikt, ्षाम,
   {{0x22492f54,0x543400d1,0x00000000,0x00000000}},	//   _šaku_, _سرمر, --, --,
   {{0x7bde4d62,0xe28e43f1,0xfaff0313,0x00000000}},	//   _supu, _ра_, _voël_, --,
   {{0x7bde1ca0,0x01c80018,0xd1310a09,0x00000000}},	//   _pupu, _فونٹ_, _شمع_, --,
   {{0x6ec200c3,0x2aeb0294,0x2b4901c2,0x224d6b9e}},	//   रेजु, _ụkọ_, fdac_, lvek_,
   {{0x05dd000f,0xd37802e6,0x66090d12,0x637c0113}},	//   मदाब, _kuća_, _ovek, _kéna,
   {{0x27ed0095,0xaec60110,0xef19007f,0x6fe802c6}},	// [fd80] _čena_, _юбил, óże_, _věce,
   {{0x63756f08,0x637cc503,0x7bde2b76,0xf9c7097a}},	//   _bánk, _ména, _tupu, дгук_,
   {{0x637c0113,0xcb6a5334,0x9b4613c3,0x00000000}},	//   _léna, _дане_, _قندو, --,
   {{0x9ad30174,0x290704c8,0x00000000,0x00000000}},	//   _dịba, ónar_, --, --,
   {{0x6d8902e6,0x66093360,0xeb3b00ca,0x9f6501f9}},	//   ržav, _cvek, _ועכש, áték_,
   {{0x798e4829,0x00000000,0x00000000,0x00000000}},	//   _umbw, --, --, --,
   {{0x63750065,0x00000000,0x00000000,0x00000000}},	//   _kánh, --, --, --,
   {{0xd37802ef,0x5b7b00c1,0x7af60b6a,0x637c014b}},	//   _buća_, ַריא, nbyt, _béna,
   {{0xc29800a9,0x6f0d01ec,0x00000000,0x00000000}},	//   яких_, _rdac, --, --,
   {{0x636e009c,0xd37800c4,0x661d0727,0x78a27084}},	//   _cùnr, _duća_, _åska, şovu,
   {{0x660900cc,0x04db00ca,0xa0a61aad,0x80c90ff9}},	//   _zvek, _וקבל, ьшил, हेले,
   {{0x201115bf,0xf99f022b,0x77b800ee,0x00000000}},	//   ázia_, _avèl_, fíxi, --,
   {{0xdb0d0990,0x7af600d4,0x63a20169,0x6234002d}},	//   llaç, dbyt, _ijon, _челу,
   {{0x63adc504,0xfaff084e,0x00000000,0x00000000}},	//   čane, _seë_, --, --,
   {{0x1fa7142f,0x6d8900e7,0x5f95002d,0xdb6b00ae}},	//   _ориг, džat, _пикт, орал_,
   {{0x6f0d9bc3,0x63a20167,0x63750143,0x7af65575}},	//   _udac, _jjon, _ránk, gbyt,
   {{0x63750206,0x63a2c505,0x00000000,0x00000000}},	// [fd90] _sánk, _mjon, --, --,
   {{0xc178013f,0x2eaa00c1,0x7dc00212,0x3a291aa7}},	//   nkė_, _משפּ, lösn, rtap_,
   {{0x63a402e6,0x3a292d6d,0x660901ce,0xc1780138}},	//   činj, stap_, _svek, ikė_,
   {{0x8c1a0130,0x63a20d6a,0x3a290248,0x00000000}},	//   _צורי, _njon, ptap_, --,
   {{0xaaa72171,0x659557a4,0x00000000,0x00000000}},	//   _कुचक, наду, --, --,
   {{0x7bcdc506,0xdb0d0161,0x63a200c2,0x9f5f0e43}},	//   lmau, flaç, _ajon, vrtý_,
   {{0x69c7181f,0x637c06aa,0x63a2023b,0x23d52ff8}},	//   _ihje, _séna, _bjon, нцир,
   {{0x130902ec,0xc2450058,0x66090149,0x637c00fd}},	//   чний_, еник, _tvek, _péna,
   {{0x461500b1,0x26090635,0x63a20154,0x25790113}},	//   _سوار, _सिटी_, _djon, _hèlm_,
   {{0x63a20f20,0x91b40023,0x7af602c6,0x80650927}},	//   _ejon, _đẹp_, zbyt, евож,
   {{0x2d8301e5,0x63756a3e,0x00000000,0x00000000}},	//   dhje_, _láni, --, --,
   {{0x92bd0081,0xa3c20b7f,0xf1b92017,0x63a20052}},	//   _আলী_, ूषण_, duše_, _gjon,
   {{0x69c702fd,0xf99f0154,0x63bb5228,0x539a0eda}},	//   _ohje, _avèm_, mlun, _צינו,
   {{0x63bb96a0,0x7bc601e5,0x3f8200dd,0x66d601e8}},	//   llun, _shku, shku_, _hükü,
   {{0xdca3a49c,0x6d89013f,0xfd690294,0x7af647db}},	//   гари, ežas, _hapụ, tbyt,
   {{0x63755944,0xbb43115e,0x63bb9397,0x00000000}},	//   _báni, леск, nlun, --,
   {{0xfce65cac,0x63bb02e2,0x63750072,0x6ea80018}},	// [fda0] _попо, ilun, _cáni, _زندہ_,
   {{0x63bb5a68,0xfd690134,0xe9df00b3,0x2d83c507}},	//   hlun, _mapụ, _arús_, chje_,
   {{0x69c700dd,0x6d890995,0x63bb09a8,0xad1b006e}},	//   _dhje, ržat, klun, _צוטר,
   {{0xdd200490,0x66e603a0,0x46a61402,0x68fb00c4}},	//   _बाँध_, хода, наев, _đude,
   {{0x63bbc508,0xfbbf0403,0x2bbf2b6e,0x00000000}},	//   dlun, ्षरम, ्षरा, --,
   {{0x63a2c509,0x63750139,0x63bbc50a,0x9f5f0231}},	//   _sjon, _kánw, elun, istá_,
   {{0xc8b50077,0x63a20e94,0x63bbc50b,0x63750094}},	//   _асты, _pjon, flun, _záni,
   {{0x32663126,0x63bb1088,0x929d0034,0x394ac50c}},	//   етов, glun, wała, _habs_,
   {{0x6f0613bd,0xe1ef03ed,0xdb0d0161,0xdb040103}},	//   dakc, یسی_, slaç, llió,
   {{0xfd690134,0xdb0d15c9,0x82330037,0x76420361}},	//   _dapụ, plaç, اريا, mwoy,
   {{0x63bb5a45,0x387f0d2a,0x26c4080e,0x98b80034}},	//   blun, _ƙuri_, _hzmo_, _parę_,
   {{0x6722c50d,0x389b0341,0xf1b9b6aa,0x3f8001ec}},	//   ngoj, ליינ, vuše_, _cliu_,
   {{0x2d8300dd,0x6b84008a,0x59b0009d,0x6d896a6a}},	//   thje_, dhig, जकार, džar,
   {{0x224600d1,0x764201c2,0x7ec900e8,0x6b84009c}},	//   _isok_, iwoy, _rūpī, ehig,
   {{0x61e202fd,0x645c10d9,0x41c3177a,0x66d60367}},	//   _huol, _árid, _حقوق, _yükü,
   {{0x61e2c50e,0x2d8300dd,0x213e4e57,0x201e1f34}},	//   _kuol, shje_, leth_, muti_,
   {{0x201e2340,0x9ad30134,0x4fd800a1,0x7bcdc50f}},	// [fdb0] luti_, _bịaa, _אוהב_, rmau,
   {{0x3d1b0006,0x25a00076,0xf1b914f3,0x7bcdc42e}},	//   _बाटे_, éill_, puše_, smau,
   {{0x4ac5007d,0x39a43db3,0xac99001c,0x63bb0178}},	//   लेजव, уштв, _آنجا_, ylun,
   {{0x6b84c510,0x98140076,0x61ed13a9,0x00000000}},	//   chig, ابلا, _éalg, --,
   {{0x69c700dd,0x61e2022c,0x201e3e57,0x2fc9009c}},	//   _thje, _nuol, huti_, _mhag_,
   {{0x201e06ee,0xe4e702ec,0x7d071def,0xd37800c4}},	//   kuti_, хідн, najs, _bućo_,
   {{0x224633b4,0xa4930470,0x63bb97ab,0xad9b0076}},	//   _asok_, دیات, tlun, gsúi,
   {{0x201e162d,0x9f5f0146,0x637c0257,0x22460167}},	//   duti_, ystá_, _déno, _bsok_,
   {{0x63bbc511,0x29cd08c5,0x2903a757,0x2d810161}},	//   rlun, _užas_, _keja_, _olhe_,
   {{0x63bbc512,0x201e4835,0x3a3900dc,0x637cc513}},	//   slun, futi_, _mpsp_, _féno,
   {{0x7d07025b,0xf99f14b1,0x201e153f,0xa0a50e1d}},	//   dajs, _avèk_, guti_, танд,
   {{0x213e02ad,0x2292001c,0x29034640,0x00000000}},	//   aeth_, الیس, _leja_, --,
   {{0x213ec514,0x333f00fd,0x7d070052,0x201e00c6}},	//   beth_, meux_, fajs, auti_,
   {{0x201ec515,0x333f00fd,0x2903c516,0xc0e200c2}},	//   buti_, leux_, _neja_, _кошк,
   {{0x5c15333f,0x201ec517,0xab2a10f5,0x1c3914fa}},	//   льту, cuti_, мова_, нять_,
   {{0x26df0051,0x333f00fd,0xbebb023b,0x236f0113}},	//   _nguo_, neux_, rfër, _jogj_,
   {{0xe9da371f,0xbb431d5c,0x48e62f11,0x2903c518}},	// [fdc0] дка_, шетк, возв, _beja_,
   {{0x6b84c519,0x8c960426,0x63a40213,0x7d5600c1}},	//   shig, _армі, čini, _ייִד_,
   {{0x2903c51a,0x2d980625,0x6d5e1d59,0x92bd0081}},	//   _deja_, mire_, _inpa, _আলো_,
   {{0x8a0619ff,0x2d98c51b,0x6d4e2084,0x637c0257}},	//   _изме, lire_, ldba, _réno,
   {{0x25fd09d0,0x6722c51c,0x2903023b,0x6f04c51d}},	//   रीली_, rgoj, _feja_, _meic,
   {{0x2d98c51e,0x6f04c51f,0x63750102,0x61e2008f}},	//   nire_, _leic, _mánu, _ruol,
   {{0xdb0403be,0x61e22f2e,0x7c2ec520,0x43940636}},	//   lliñ, _suol, ntbr, лакс,
   {{0x61e202fd,0x2d98c521,0x201ec522,0xe3af00ab}},	//   _puol, hire_, vuti_, يري_,
   {{0x69dc600a,0x2d98c523,0x2fc90150,0x55e6004d}},	//   _kire, kire_, _rhag_, _розб,
   {{0x61e2013d,0x69dc0694,0xa5450e25,0xd1300192}},	//   _vuol, _jire, _مضمو, حمد_,
   {{0x213e332d,0xd91b0341,0x534601b6,0xf99300a1}},	//   reth_, וויל, _ахла, שרת_,
   {{0x6d5e17a5,0x61e20084,0x69dcc524,0x6d4e112f}},	//   _anpa, _tuol, _lire, edba,
   {{0x2d98c525,0x69dc91a7,0x6f040091,0x7d070087}},	//   fire_, _oire, _deic, tajs,
   {{0x69dcc526,0x2d9809b7,0x217600d3,0x236f0216}},	//   _nire, gire_, _шуер, _zogj_,
   {{0x290301e5,0x6f04c527,0x40340265,0x7d07c528}},	//   _reja_, _feic, _сейс, rajs,
   {{0x290300c9,0x69dc4cb6,0x6d5ec529,0x2d986b40}},	//   _seja_, _aire, _enpa, aire_,
   {{0x69dcc52a,0x2d985ca0,0xf1b98315,0x290378ef}},	// [fdd0] _bire, bire_, luša_, _peja_,
   {{0x69dc7cdd,0x2d98c52b,0x2bc30789,0x6f0402e2}},	//   _cire, cire_, _वीरा, _zeic,
   {{0x290300c9,0xe7190080,0x4815bf0a,0x333f00fd}},	//   _veja_, فيات_, умес, yeux_,
   {{0x4aae007d,0xf7705e51,0x3f998dfa,0x69dc0a02}},	//   _झुकव, يان_, nisu_, _eire,
   {{0x7bddc52c,0x333f0257,0x2903c52d,0x637c0072}},	//   _iisu, veux_, _teja_, _vénl,
   {{0x64a5083c,0xf1b90ca7,0x69dcc52e,0x7aed2ab6}},	//   лала, kuša_, _gire, lcat,
   {{0x7bddc52f,0x7aed0036,0x387f03e3,0x333f04d1}},	//   _kisu, ocat, _ƙuru_, teux_,
   {{0x69dc8d58,0x7aedc530,0x2d98c531,0x2a6d00a5}},	//   _zire, ncat, zire_, _żeby_,
   {{0x7bddc532,0x2d989610,0x333f025a,0x6f0496c0}},	//   _misu, yire_, reux_, _reic,
   {{0x7bdd62e7,0x6f0457e5,0x3b09321d,0x7649427d}},	//   _lisu, _seic, haaq_, _isey,
   {{0x93f50870,0x2d98c533,0x7f4d008a,0x6f04a2eb}},	//   _спец, vire_, _baaq, _peic,
   {{0x2d98c534,0x7bdd7db5,0x63750610,0x324523bb}},	//   wire_, _nisu, _cánt, _منصف,
   {{0x6f04c535,0x7aedc536,0x26060789,0x877a00c1}},	//   _veic, dcat, सीपी_, גארי,
   {{0x6f0401bf,0x9f5f00c2,0x7c2eb867,0x00000000}},	//   _weic, estä_, ttbr, --,
   {{0x2d98c537,0x6f04c538,0x7bdd0ab9,0x69dcc539}},	//   rire_, _teic, _bisu, _rire,
   {{0x2d981aa3,0x764961d1,0x00000000,0x00000000}},	//   sire_, _osey, --, --,
   {{0x69dc4e48,0x7bdd26f7,0x320dc53a,0x49ca14f8}},	// [fde0] _pire, _disu, nsey_, елан_,
   {{0x6d5e0238,0x7aed00e1,0xed462436,0xdb040072}},	//   _unpa, acat, _сноп, rliñ,
   {{0x7649c53b,0x7f4d0188,0x7bdd3261,0xb17a006e}},	//   _asey, _yaaq, _fisu, עטער,
   {{0x7aed013d,0xdc9b0105,0x0686007e,0x7bdd11b9}},	//   ccat, _טייל, лген, _gisu,
   {{0xd5ba0895,0x69dc32b4,0x63758f3d,0x4a76002d}},	//   нск_, _tire, _láns, _сынт,
   {{0x69dc0441,0x7bdd479d,0x9f5f1842,0x98c0020e}},	//   _uire, _zisu, mstå_, şsın_,
   {{0xf9832f17,0x7649c53c,0xf99f022b,0xa2d62f74}},	//   _угро, _esey, _avèw_, मेन्,
   {{0x52142249,0x08770130,0xf1b908c5,0x00000000}},	//   адит, _געלט_, vuša_, --,
   {{0x63753e0a,0xbb3b00c1,0x7791010d,0x442e6dc9}},	//   _ránt, געפי, _بینا, stf_,
   {{0x442c037a,0xf1b900c4,0xc33901f9,0x00000000}},	//   _tqd_, tuša_, áírá, --,
   {{0xc057116d,0x9f5f0084,0x7aed9627,0x40340915}},	//   гія_, ystä_, ycat, шенс,
   {{0xe81c05d4,0xf1b90335,0x7dc00212,0x63750146}},	//   _पटना_, ruša_, lösh, _dáns,
   {{0x7bdd0465,0x957c00a5,0x3f990335,0x5f94008f}},	//   _risu, _ciąg, risu_, сият,
   {{0x091a0f71,0x7bddc53d,0x5bbf0285,0x7f4d008c}},	//   ন্তু_, _sisu, ्ष्व, _waaq,
   {{0x7bddc53e,0x7aed00b3,0x41bb0eda,0x00000000}},	//   _pisu, tcat, _רצוע, --,
   {{0x9ad30134,0x101307e8,0x6e2d009e,0x00000000}},	//   _fịla, _ابود, _tqab, --,
   {{0x7aedc53f,0x7bddc540,0xbda7006f,0x3b090188}},	// [fdf0] rcat, _visu, _محدو, raaq_,
   {{0x7aed2ab6,0xdb040088,0x7bddc541,0x3b090188}},	//   scat, slið, _wisu, saaq_,
   {{0x7bdd37f6,0x7aed00e7,0x00000000,0x00000000}},	//   _tisu, pcat, --, --,
   {{0x3b09008c,0x320d0188,0x290e6084,0x205700ca}},	//   qaaq_, ysey_, ófar_, טיבל_,
   {{0xd24652c6,0xd138007f,0x00000000,0x00000000}},	//   _بن_, ciąg_, --, --,
   {{0x27150019,0x35f8001c,0x441500b4,0xd0062ba0}},	//   ền_, ارند_, афит, _ول_,
   {{0x6498008f,0x00000000,0x00000000,0x00000000}},	//   лтър_, --, --, --,
   {{0x63ad0206,0x091a0081,0x7dc02e7e,0x00000000}},	//   čano, ন্দু_, tösk, --,
   {{0x99800220,0xfaff084e,0x161c00aa,0x417501f3}},	//   stiť_, _hoës_, _नियर_, لادس,
   {{0x63750074,0x217528f1,0x7dc00e2e,0x320d48cc}},	//   _páns, руир, rösk, rsey_,
   {{0xd7a9009d,0xde8f0174,0xe7a91677,0x00000000}},	//   _कदाच, sịla_, _कदाप, --,
   {{0x2018497e,0x62352917,0x16020096,0xa3cc0354}},	//   ária_, _веду, रीवर_, _शीप_,
   {{0x39840149,0x59c5148e,0x24a700e8,0x00000000}},	//   _lösa_, वतार, šumā_, --,
   {{0xe2c800d6,0x8cb108d4,0xe1f900c6,0x00000000}},	//   _слід_, _आँखो, mpų_, --,
   {{0x6da31510,0x1d071e61,0x412600d6,0xeb9a6aed}},	//   цира, реси_, _тощо_, вив_,
   {{0x2bbf0252,0x6fb30037,0xdca3004d,0x00000000}},	//   ्षगा, _وموا, іати, --,
   {{0x6da600d6,0xa3c8009d,0x090637f0,0x1d1a007b}},	// [fe00] _випа, ोगत_, ипан, _июнь_,
   {{0x9f5f09ce,0xe8f7108f,0x9e7b00ca,0x00000000}},	//   rstå_, илу_, _סניפ, --,
   {{0xad1b021e,0xa6e600d3,0xd11600ca,0x00000000}},	//   _בויר, ажел, שקעה_, --,
   {{0x2617007d,0x7c3e03e5,0x9f5f1f60,0x2579001c}},	//   _निशी_, _ippr, pstå_, _mèlu_,
   {{0xf1b901d3,0x25790065,0x00000000,0x00000000}},	//   jušo_, _lèlu_, --, --,
   {{0x5e5700c1,0x7b3e0034,0x61e40037,0x8e570266}},	//   יינע_, _dłuż, _éili, יינג_,
   {{0x98a3123a,0x18a32f0c,0x25a90076,0xe4b801b3}},	//   _дире, _дарм, éala_, ылкі_,
   {{0xd37800e9,0xea000028,0xfaff057a,0x236d0216}},	//   _kući_, _luật_, _hoër_, gjej_,
   {{0x68e900d3,0x0566273f,0x637c03a9,0xe3af046b}},	//   _şedi, _кван, _jéni, برو_,
   {{0x7c3e00d6,0xd37800c4,0x637c20ed,0x649a0231}},	//   _oppr, _mući_, _méni, _итер_,
   {{0x53df0285,0x637c1d23,0x00000000,0x00000000}},	//   _पंचश, _léni, --, --,
   {{0xf1b908a9,0x63a403f1,0x645ac542,0x443e80c4}},	//   vrše_, čins, _irti, _ipt_,
   {{0x7c3e120f,0x6f1600f0,0x3ead0052,0x00000000}},	//   _appr, _ddyc, çet_, --,
   {{0xe7e7007d,0x443e0063,0x6f160034,0x2d850034}},	//   _ओढला_, _kpt_, _edyc, óle_,
   {{0x25b90037,0x3cec0094,0x00000000,0x00000000}},	//   _ísle_, _živý_, --, --,
   {{0xdb0400fd,0xdb230230,0x201e0995,0x637c3a20}},	//   nniè, _örül, mrti_, _béni,
   {{0x637c002b,0x00000000,0x00000000,0x00000000}},	// [fe10] _céni, --, --, --,
   {{0x645a334c,0x637c0979,0x2907c543,0xd7fb0e06}},	//   _orti, _déni, úna_, вуд_,
   {{0x6f1602ad,0x7b3e00a5,0xa3c80ccb,0x7e7d02ac}},	//   _ydyc, _służ, ोगा_, lysp,
   {{0x30d900c1,0x637cb4fe,0x60d900c1,0x69ce01c8}},	//   אַנע, _féni, אַנג, _ehbe,
   {{0x98a70390,0xf7700e5a,0xbb3a00c1,0x637c0257}},	//   ını_, بال_, _גערי, _géni,
   {{0xd90f1e49,0x99850080,0x2b3f0134,0x63ad0206}},	//   _آیا_, _السو, _ịgụọ_, čanm,
   {{0x645a0fa3,0xaadb0d77,0xad380266,0x637c014b}},	//   _crti, _मृतक, ינגס_, _zéni,
   {{0x443e005a,0x645a02c6,0xe787294a,0xf3490aca}},	//   _dpt_, _drti, _туго, упил_,
   {{0x645a063f,0x645c003e,0xd24e00e3,0xe7eb0fef}},	//   _erti, _árin, فني_, _जूता_,
   {{0x05740192,0x237f7ce7,0x443e00de,0x77910281}},	//   _والد, skuj_, _fpt_, _بیچا,
   {{0xc35500e5,0x395100e8,0x00000000,0x00000000}},	//   _гълъ, _mazs_, --, --,
   {{0x765b0381,0x083a006e,0x6fe800d2,0x00000000}},	//   _kruy, נערל, _měch, --,
   {{0x9ad30129,0x201e5c3b,0xf38c006e,0x673b4ed7}},	//   _dịka, arti_, _בראָ, _mbuj,
   {{0x61fb06e1,0xea000023,0xd2560327,0xa3e6269c}},	//   mpul, _quật_, _לשנה_, _यूँ_,
   {{0x7ff50fba,0x673b0517,0x637c394f,0xddc4026a}},	//   _استا, _obuj, _séni, _eriş,
   {{0x637c416f,0x7bcf01b9,0xd3780a39,0x7e7d225b}},	//   _péni, _chcu, _pući_, bysp,
   {{0x61fb3da1,0x2eff0072,0x5f76262f,0x5aca00c6}},	// [fe20] npul, ñufe_, _ناکر, улам_,
   {{0x673bc544,0x186a0291,0xd3780995,0x637c014b}},	//   _abuj, лази_, _vući_, _véni,
   {{0x63ad011d,0x7c3e0cec,0x6ff300ae,0x2bc302d5}},	//   čanj, _uppr, _făce, _वीका,
   {{0xdc3b00c1,0xcb6a18be,0x443e002b,0x7d0e58c6}},	//   _געטר, _саме_, _rpt_, labs,
   {{0x443e063f,0x941201d4,0xa4f80018,0x3f824c04}},	//   _spt_, əcək_, لکار_, ikku_,
   {{0x860700e3,0x2d9a0063,0x645a0141,0x7d0e2633}},	//   حقوق_, _jmpe_, _prti, nabs,
   {{0x6e2600f9,0x765bc545,0x7e7d007f,0x4394061b}},	//   hukb, _eruy, zysp, жайс,
   {{0x645a6ca6,0x799e0051,0xadfa0469,0x937800d3}},	//   _vrti, lipw, ्ठान_, рбит_,
   {{0xdb0404ea,0x7d0ec546,0x290a0063,0x61fb4a19}},	//   rniè, kabs, _keba_, gpul,
   {{0x20180303,0x21662249,0x3014255a,0x443e005c}},	//   ário_, стиг, одор, _tpt_,
   {{0xdb0f0018,0xc32a00e3,0x645a8045,0x7bc40138}},	//   ődés, _مكان_, _urti, kliu,
   {{0x290ac547,0x2d9ac548,0x3a20019c,0x799e00f9}},	//   _leba_, _ampe_, krip_, hipw,
   {{0x291831f2,0x3d0500b6,0x6ff3044c,0x998905db}},	//   _odra_, वरले_, _răce, htaš_,
   {{0x3a2059c6,0x291c0018,0xc6930341,0x3ce500f3}},	//   drip_, óval_, לאר_, ølv_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xec3400d6,0x2d9a010a,0x29182886,0x7bc41974}},	//   янсь, _empe_, _adra_, gliu,
   {{0x290a00cb,0x3a200a9f,0x6f0f693c,0x3f8901c2}},	// [fe30] _beba_, grip_, macc, _ilau_,
   {{0x3f89006c,0x6f0fc549,0x290ac54a,0x25be010a}},	//   _hlau_, lacc, _ceba_, _nktl_,
   {{0x290a4c4c,0x7bc400c6,0x26060c22,0x6ff3020a}},	//   _deba_, bliu, सीसी_, _tăce,
   {{0xd37800e9,0x6d47c54b,0x5fc9045f,0x6d5501c0}},	//   _kuću_, leja, रतिल, ldza,
   {{0xf7702204,0x36690058,0x61fbae11,0xa5090cb0}},	//   عام_, рало_, xpul, аела_,
   {{0x6d55c54c,0xce3800a1,0x9f4800dd,0x6fe8030b}},	//   ndza, צאות_, _punë_, _těch,
   {{0xb4e50065,0x25fd074c,0x6d5500e8,0x290101dc}},	//   _afàì, रीजी_, idza, mbha_,
   {{0x765b00ef,0x69c54d8f,0x7dc015b4,0x673b0193}},	//   _truy, llhe, löst, _ubuj,
   {{0x6d4723a6,0x6f0f38c4,0x645820c0,0xe667097a}},	//   keja, dacc, avvi, _утво,
   {{0x6d47005c,0x61fbc54d,0x2d8301c0,0x6d550a39}},	//   jeja, rpul, jkje_, jdza,
   {{0x6f0fc54e,0x3f89ad9a,0xd138007f,0x6b8d01f9}},	//   facc, _blau_, wiąc_, khag,
   {{0x4427c54f,0x6f0f9138,0x3f8905fe,0x6d5540e8}},	//   mun_, gacc, _clau_, edza,
   {{0x63bbc550,0x3f89023e,0x63a98c08,0x25fd0096}},	//   moun, _dlau_, mnen, रीची_,
   {{0x6d471cec,0x63a9c551,0x63bbc552,0x637c020d}},	//   geja, lnen, loun, _dénu,
   {{0x44271732,0xfce32da1,0x6e266a14,0x3b000092}},	//   nun_, доро, sukb, tbiq_,
   {{0x63a9c553,0x6f0f2742,0x6b8d3814,0xbea62c4c}},	//   nnen, cacc, ghag, _майк,
   {{0x44277dd5,0x6d47c554,0x61ebc555,0x7bc4c556}},	// [fe40] hun_, beja, _jugl, rliu,
   {{0x4427c557,0x61e3026e,0x64410629,0x63a90364}},	//   kun_, _jinl, _opli, hnen,
   {{0x61eb0465,0x61e3c558,0x6441022e,0x63bb022b}},	//   _lugl, _minl, _npli, koun,
   {{0xe73a1675,0x6b8dc559,0x44273698,0x63a95793}},	//   ред_, chag, dun_, jnen,
   {{0x63bb0fb6,0x63a90220,0x290a0220,0x637c03a9}},	//   doun, dnen, _teba_, _mént,
   {{0xa2da349d,0x4427c55a,0x8c4301e8,0xdb1d1584}},	//   _पृष्, fun_, ışve, _aksè,
   {{0x61eb0102,0x44271bd3,0x69b90efb,0x63bbc55b}},	//   _augl, gun_, ्तरी, foun,
   {{0x63a9c55c,0x63bb04d4,0x2fc001fa,0x1c1d009f}},	//   gnen, goun, _nkig_, _फिसल_,
   {{0xfbd300a1,0x6f0f58e3,0xb6a300d6,0x316a1510}},	//   ותה_, vacc, _житл, ашно_,
   {{0xba9b0089,0x63a9010a,0x61eb056e,0x6f0f0d2a}},	//   יספי, anen, _dugl, wacc,
   {{0x4427c55d,0x6f0fc55e,0x61e308bb,0x6b844e0b}},	//   cun_, tacc, _dinl, kkig,
   {{0x63bba4e1,0x61eb5ec1,0x61e325ea,0x91e6372d}},	//   coun, _fugl, _einl, _доде,
   {{0xa2d628fb,0x6d47c55f,0xb7db00a1,0x23660357}},	//   मेश्, teja, יקטי, _inoj_,
   {{0x63a04f72,0x6f0fac87,0x3cdc09a1,0x26c40036}},	//   limn, sacc, _गृहे_, _mymo_,
   {{0x672b5d1f,0x6d473b1a,0xfe6e0688,0x2d83c560}},	//   yggj, reja, نگی_, rkje_,
   {{0x6d47890d,0x63a01cb4,0xb4f806ed,0x6b84019c}},	//   seja, nimn, ुरुप_, gkig,
   {{0x442754fd,0x6ce70426,0x6d4737e5,0x61e311bc}},	// [fe50] zun_, _міне, peja, _yinl,
   {{0x44270dc2,0x63a91912,0x6b8dc561,0x67f303e5}},	//   yun_, znen, shag, _aħja,
   {{0x63bbc562,0x7dc00f3a,0x2366005f,0x63a9166e}},	//   youn, röst, _onoj_, ynen,
   {{0x4427bc7c,0x637c0072,0x6b842104,0x20020580}},	//   vun_, _méns, ckig, ćkih_,
   {{0xaaf6193b,0x4427957d,0x63a9c563,0x63bb03be}},	//   _מזרח_, wun_, vnen, voun,
   {{0x4427c564,0x6f0d5df1,0x61ebc565,0x62800138}},	//   tun_, _leac, _rugl, dymo,
   {{0x61e30af0,0x61ebc566,0xfd500294,0x3a290da3}},	//   _rinl, _sugl, _achụ, luap_,
   {{0x4427c567,0x6f0d0049,0x644102dd,0x61eb008f}},	//   run_, _neac, _vpli, _pugl,
   {{0x26cd03ce,0xe2990231,0x13060084,0x61e301df}},	//   _uzeo_, сап_, чный_, _pinl,
   {{0x442764ea,0x63a90220,0x6b8401e9,0x61eb015c}},	//   pun_, snen, zkig, _vugl,
   {{0x61e3c568,0x637c0018,0x7dc00018,0x6f0dc569}},	//   _vinl, _pént, zöss, _beac,
   {{0x6609c56a,0x6f0d0037,0x61e3030a,0x7dc000c2}},	//   _kwek, _ceac, _winl, yöss,
   {{0x6f0d1519,0xee371c17,0x1e8322de,0x20320103}},	//   _deac, пня_, елям, وفیس,
   {{0x660963c1,0xf1b901d3,0x201101f9,0x00000000}},	//   _mwek, kuši_, ázis_, --,
   {{0xaffe00ef,0xf1b90029,0x6f0d02bc,0x637c03be}},	//   _trướ, juši_, _feac, _tént,
   {{0xeb971a18,0x6f0dc56b,0x6616013f,0x33f11f97}},	//   пис_, _geac, šyki, _máx_,
   {{0x660900ac,0x6b9d0090,0x6b84c56c,0x00000000}},	// [fe60] _nwek, _dmsg, rkig, --,
   {{0x63a0c56d,0x6b840486,0x7dc03e99,0x998011dc}},	//   zimn, skig, röss, stiž_,
   {{0x98a30e1b,0x660928c0,0x7d7b00ca,0xf1b900e8}},	//   нифе, _awek, _הניו, guši_,
   {{0xdb240260,0x66090517,0x00000000,0x00000000}},	//   _توحی, _bwek, --, --,
   {{0x83fc00c4,0xdb0d01ab,0xb6e3061b,0xad9b037a}},	//   _mrđe, mlað, нюшк, spúe,
   {{0xdb0d0088,0x236605db,0x186a1143,0xb9b600d1}},	//   llað, _snoj_, _лаги_, _رمزع,
   {{0x6609c56e,0x9f590052,0xf99f022b,0x00000000}},	//   _ewek, ërë_, _mwèl_, --,
   {{0x201802ef,0x6609022b,0xa7a700ae,0x7af6c56f}},	//   šrik_, _fwek, _екса_, ncyt,
   {{0x6f0dc570,0xbebb00dd,0x63a0c571,0x660906b0}},	//   _reac, ngët, rimn, _gwek,
   {{0x6f0d4450,0xb603000d,0x63a025f5,0x54f0009f}},	//   _seac, ášen, simn, _चलिए_,
   {{0x6568c572,0x6ff300ae,0x82330470,0x6f0d09ff}},	//   _indh, _păca, وریا, _peac,
   {{0xfaff023b,0x657a0503,0x637c0072,0xdef80077}},	//   _anën_, _hoth, _véns, зыр_,
   {{0x657a00bf,0x54f00557,0x59be0b42,0x6f0d020a}},	//   _koth, _चलाए_, ्तार, _veac,
   {{0x657a010a,0x661d0537,0xd12f00d1,0x00000000}},	//   _joth, _æske, _ممه_, --,
   {{0x6f0d5d5b,0x21570867,0x657a4f4e,0x2b4901ff}},	//   _teac, _رجوع_, _moth, teac_,
   {{0x657a41f5,0x8bc400f6,0xe08508ba,0xf1b901d3}},	//   _loth, есуд, _تجهي, vuši_,
   {{0x2b4903e9,0xadb53c12,0x656801dc,0x00000000}},	// [fe70] reac_, _обиш, _ondh, --,
   {{0x657ac573,0x3a290063,0x61ef0072,0xf1b900e8}},	//   _noth, ruap_, ícli, tuši_,
   {{0xdb0d0088,0x3a2902e7,0x4735879f,0x2cfb00b6}},	//   blað, suap_, днес, ्रील_,
   {{0x656800cd,0xb9040490,0x66090c45,0xf1b90877}},	//   _andh, _पृ_, _pwek, ruši_,
   {{0xe61801ce,0xa3c0022d,0xcd34010d,0xf1b9010f}},	//   зді_, ंकन_, _غریب, suši_,
   {{0x657a10f0,0x33f103be,0xceb4006e,0x98b800c6}},	//   _coth, _páx_, עיס_, _narė_,
   {{0x6d57025e,0x5fbd007d,0x657ac574,0x6a830032}},	//   _maxa, ईवाल, _doth, _fífú,
   {{0xe1f95a64,0x27fc0220,0x6d577e10,0x6568001c}},	//   оги_, ívne_, _laxa, _endh,
   {{0x6d570a43,0x66090051,0x657a033f,0x00000000}},	//   _oaxa, _uwek, _foth, --,
   {{0x6d57008a,0x297a006e,0x00000000,0x00000000}},	//   _naxa, ַטרא, --, --,
   {{0xff26007b,0x29380142,0xbef900a4,0x00000000}},	//   ммно, לאזן_, ंडून_, --,
   {{0x63750042,0x6b8300ae,0x00000000,0x00000000}},	//   _lánz, _îngh, --, --,
   {{0x6d576ac9,0xceb401d4,0xa3b806fa,0xf99f022b}},	//   _baxa, _edən_, _عامر_, _pwèl_,
   {{0xf0b800cd,0x2d9e06a3,0x6d5713a9,0x00000000}},	//   _کاهش_, òte_, _caxa, --,
   {{0xef1f008e,0x2913008a,0xdb0d003e,0xdca6007b}},	//   mkün_, daxa_, tlað, фави,
   {{0x7e620072,0x00000000,0x00000000,0x00000000}},	//   _áopo, --, --, --,
   {{0xc3320054,0x291301ff,0xed5a5e3d,0x81c20033}},	// [fe80] כון_, faxa_, _доп_, ্দর_,
   {{0x26170782,0xe9d70a18,0x7769c575,0x29135adb}},	//   _निजी_, дку_, _anex, gaxa_,
   {{0x657ac576,0x2d0a009d,0x6fe80113,0x00000000}},	//   _roth, वरील_, cècè, --,
   {{0x657ac577,0xd83e033b,0x59be00b6,0x00000000}},	//   _soth, ščob_, ्तहर, --,
   {{0x657a760f,0xeb9700ae,0xcb130266,0x6d57c578}},	//   _poth, _ция_, _שלש_, _yaxa,
   {{0x2913037a,0x77690381,0xa3e6007f,0x657a0415}},	//   caxa_, _enex, _यूज_, _qoth,
   {{0xb17600de,0xc7a60ac6,0xd6d90034,0xf1b900e7}},	//   _nhượ, _живк, _mały_, nušu_,
   {{0x63755944,0x7c37026a,0xb5fd166d,0x39581cab}},	//   _kány, _çarş, _srše, _hars_,
   {{0x657a0472,0x99890220,0x914a49f4,0x9f4800ee}},	//   _toth, stať_, очна_, _cuní_,
   {{0x6602c579,0x656800cd,0x442a002b,0x9f5f014b}},	//   mpok, _undh, _ªb_, mpté_,
   {{0xb5fd0580,0x63750018,0x39584e82,0x20184573}},	//   _vrše, _lány, _mars_, éri_,
   {{0x59d0000f,0x39580501,0x6d570694,0x6e951ca3}},	//   _तीसर, _lars_, _saxa, еиму,
   {{0x395800f9,0x6d5703be,0x6d4008c5,0x660201e9}},	//   _oars_, _paxa, đman, npok,
   {{0xea0000ef,0x39581281,0xd6d900a5,0x5f010033}},	//   _xuất_, _nars_, _cały_, ্লেখ_,
   {{0xb5fd00e7,0x00000000,0x00000000,0x00000000}},	//   _kršc, --, --, --,
   {{0x6d57697e,0x69d40b61,0x798e0178,0x39583f6d}},	//   _waxa, _बीबी, _albw, _aars_,
   {{0x6d57c57a,0x3958172e,0x777bc57b,0xbebb0216}},	// [fe90] _taxa, _bars_, _roux, rgës,
   {{0xc4c40434,0x660206c2,0x395800ca,0x22460085}},	//   _نے_, dpok, _cars_, _mpok_,
   {{0x7d15564a,0x395851fb,0x29130188,0x00000000}},	//   mazs, _dars_, raxa_, --,
   {{0xea000019,0x8af00092,0x39580158,0x00000000}},	//   _suất_, ndəl, _ears_, --,
   {{0x776900de,0x3958c57c,0x660212f5,0x2b590076}},	//   _vnex, _fars_, gpok, _iasc_,
   {{0x3958c57d,0x6fd60031,0xea000023,0x61ed0231}},	//   _gars_, máce, _quất_, _éali,
   {{0xf99200ca,0x291101c8,0x6ff3020a,0x6fd600d2}},	//   _גרם_, _ieza_, _răco, láce,
   {{0x58d41cfb,0x291105bd,0x2b590231,0x776900d7}},	//   _рост, _heza_, _jasc_, _unex,
   {{0xb5c900fb,0x2911c57e,0x2b59c57f,0x8af000a7}},	//   _فورم_, _keza_, _masc_, ddəl,
   {{0xf99200c1,0x2911211b,0x2cfb121d,0xb17600de}},	//   ָרט_, _jeza_, ्रोल_, _phượ,
   {{0x2cfb05d4,0x2911b410,0x2246c580,0x28a502d5}},	//   ्रैल_, _meza_, _epok_, _गेमि,
   {{0x2b5900e3,0x63ad2188,0xf8b200c1,0xf1b900c4}},	//   _nasc_, čans, רשט_, vušu_,
   {{0xe28ec581,0x8db6004d,0x5ec80033,0x00000000}},	//   _са_, есві, রেনে, --,
   {{0xef1f0068,0x2911092f,0x637531a2,0x44270cad}},	//   lkül_, _neza_, _rány, orn_,
   {{0x20546bef,0x8fa601a0,0x8c4308d1,0xf3f10174}},	//   _атыр, _паке, лере, _jụ_,
   {{0x4427152f,0x2b590428,0xffd601b3,0x661b0372}},	//   irn_, _casc_, _яўля, _ovuk,
   {{0xa3c0007d,0x2911c582,0x395805ef,0x4427103a}},	// [fea0] ंकत_, _beza_, _pars_, hrn_,
   {{0x2911026a,0x7e64039f,0xf1b91db9,0x00000000}},	//   _ceza_, _irip, pušu_, --,
   {{0x39585ff5,0x6d4ec583,0x661bc584,0x29119e34}},	//   _vars_, meba, _avuk, _deza_,
   {{0x6d5c1e81,0x7e646e5d,0x39584302,0x2907003e}},	//   ldra, _krip, _wars_, ðnar_,
   {{0xe5c619ff,0x7bc6bb58,0xb8f600c7,0x3d05009d}},	//   нско, _ikku, _হল_, वरचे_,
   {{0xf3f10134,0x6d4ebc4d,0x7e64ab11,0x2911406e}},	//   _bụ_, neba, _mrip, _geza_,
   {{0x68460084,0x53e608d8,0x7c2ec585,0x6d5cc586}},	//   _янва, нциа, nubr, idra,
   {{0x6d4ec587,0xddcd00d3,0xf99f00d1,0x29111136}},	//   heba, _oraş, _awèh_, _zeza_,
   {{0x44277f0b,0xb5fd0d62,0x6d5c2e7c,0x00000000}},	//   arn_, _vršc, kdra, --,
   {{0x6d4e1fce,0xd1302ce3,0x3a370327,0x98a7007f}},	//   jeba, جمد_, ערים_, żną_,
   {{0x7bc60102,0xddcd07d1,0x661b01d9,0x6d5c2222}},	//   _okku, _araş, _zvuk, ddra,
   {{0xddcd00d3,0x7e640479,0x67100179,0x6d5c3dac}},	//   _braş, _brip, ारिक_, edra,
   {{0x63a22a78,0x443cc588,0x442e5b9b,0xb5fd00c4}},	//   _imon, ltv_, luf_, _krša,
   {{0x63a2006c,0x7bc6c589,0x6d5c49fd,0x7f44039f}},	//   _hmon, _akku, gdra, _ebiq,
   {{0x3ce5070a,0xb5fd1419,0x7e6413e1,0x67200dd9}},	//   älv_, _mrša, _erip, _odmj,
   {{0xa3c00d0b,0xa3c204dd,0x5ba449b7,0x291161d1}},	//   ंकि_, ृति_, груз, _seza_,
   {{0x2911c58a,0x63a20090,0x2b59020b,0xddcd044c}},	// [feb0] _peza_, _mmon, _vasc_, _graş,
   {{0x442e5925,0x63a20124,0x7bc60283,0xdd0400ae}},	//   kuf_, _lmon, _ekku, ărăr,
   {{0x63a23e5d,0x291102e6,0x6d450060,0xa3c00179}},	//   _omon, _veza_, _ibha, ंका_,
   {{0x69de00b3,0xf3f10174,0x29114100,0x27fc0031}},	//   ampe, _rụ_, _weza_, ívna_,
   {{0x7bcd7417,0x6e3d0ac1,0x3b090063,0xb5fd00c4}},	//   mlau, ntsb, mbaq_, _brša,
   {{0x64a51dc6,0x83fc1100,0x63a22ac3,0x201c028d}},	//   кала, _srđa, _amon, _ovvi_,
   {{0x7bc60088,0x58d41231,0x6d450415,0x69c74b96}},	//   _ykku, _борт, _mbha, _ikje,
   {{0xc245290e,0x7bcd8d64,0x4427c58b,0xf3f10023}},	//   вник, nlau, rrn_, _vụ_,
   {{0x6d45bf0c,0x6d5cc58c,0x248900d9,0x6d4ec58d}},	//   _obha, ydra, ņam_, yeba,
   {{0x63a2c58e,0x7bcd2305,0x6d4e0634,0x76490139}},	//   _emon, hlau, xeba, _ipey,
   {{0x7bcdc58f,0x443c8fd9,0xe0cf0081,0x61ea22cc}},	//   klau, ctv_, রশ্ন, _difl,
   {{0x7e64c590,0x6d45c2b4,0x8fa608cb,0x39840149}},	//   _prip, _abha, таме, _höst_,
   {{0x6d5c5cf1,0x277600c1,0x6d450113,0x7bcdc591}},	//   tdra, דערש_, _bbha, dlau,
   {{0x7afdc592,0x63a2c593,0xf1b900e7,0x61eac594}},	//   _afst, _zmon, krši_, _gifl,
   {{0x6d4ec595,0x6d5c112f,0x6e3d2ba3,0x711a0089}},	//   reba, rdra, atsb, _חוצפ,
   {{0x7bcdc596,0x2005c597,0x398400a2,0x7e640d71}},	//   glau, mpli_, _löst_, _trip,
   {{0x6f0922e7,0x6a8318b6,0x6d5c9c82,0x3a290967}},	// [fec0] ñece, алта, pdra, grap_,
   {{0x4c866ceb,0x443c020b,0x7afd003e,0x7bcd022a}},	//   _алов, ytv_, _efst, alau,
   {{0x8af00092,0x200506a3,0x7bcd5530,0x38cb0018}},	//   ndək, npli_, blau, وامی_,
   {{0xe7d000c7,0x7bcd15d3,0x7bc601c2,0x3a290027}},	//   িদ্য, clau, _ukku, brap_,
   {{0x442e06e1,0x63a20090,0xbad501b6,0xa3c0007f}},	//   wuf_, _rmon, _біры, ंकस_,
   {{0xdb0d025a,0x63a200e5,0x442e0188,0x644800c4}},	//   nnaî, _smon, tuf_, _ppdi,
   {{0xb5fd077e,0x61ea9b79,0x7f860231,0xdb040231}},	//   _vrša, _rifl, _hóqu, gniç,
   {{0x442e85e7,0xa3cc0096,0x7bc4020a,0x61ea05aa}},	//   ruf_, _शीख_, noiu, _sifl,
   {{0x442e2a17,0x443c01ab,0xd2510018,0x66e300ae}},	//   suf_, stv_, منٹ_, _вота,
   {{0x69c302dd,0x443cc598,0xceb40092,0xb5fd00c4}},	//   čneg, ptv_, _edək_, _kršn,
   {{0x442e005c,0xb4250dd0,0x00000000,0x00000000}},	//   quf_, _معنو, --, --,
   {{0x331a037f,0x838300c2,0x69d42231,0x63a2019f}},	//   _آزاد_, _выше, _बीसी, _umon,
   {{0x61ea4ea2,0xdd910037,0x00000000,0x00000000}},	//   _tifl, موح_, --, --,
   {{0x6e3d0407,0x398402c3,0x40341824,0x00000000}},	//   rtsb, _möss_, _бекс, --,
   {{0x7bcdc599,0x3a292b18,0xebc70284,0x6aab00a4}},	//   tlau, wrap_, вљан, चप्र,
   {{0xf1b904a3,0x69c702ec,0x3a29c59a,0xe502349d}},	//   vrši_, _skje, trap_, रुति_,
   {{0x7bcdb4fc,0x7d024455,0x6d4100bc,0x040c0033}},	// [fed0] rlau, _şose, õlas, সূচী_,
   {{0x7bcd79a1,0x6d4509c7,0x5d552b81,0x00000000}},	//   slau, _ubha, _скот, --,
   {{0xa2c9033a,0x39840212,0x6fd60031,0x7bcd3f43}},	//   _हुन्, _röst_, láca, plau,
   {{0x7e6221b8,0x56952a6e,0x2d8101bf,0xb8eb009f}},	//   _šopi, лает, _hohe_, _लड_,
   {{0x2d819b7a,0x8af0013c,0x00000000,0x00000000}},	//   _kohe_, zdək, --, --,
   {{0x69c700f3,0xc9870095,0x00000000,0x00000000}},	//   _ukje, _руми, --, --,
   {{0x03a53f37,0x2d810063,0x628601df,0x69c50052}},	//   лико, _mohe_, økon, mohe,
   {{0x69c500dd,0x2fc90197,0xdb040131,0x00000000}},	//   lohe, _nkag_, rniç, --,
   {{0xab5b0174,0x6fd6037a,0x00000000,0x00000000}},	//   _akük, jáca, --, --,
   {{0x69c500dd,0x27ed00de,0x60090084,0xdd3c00c6}},	//   nohe, _hien_, нном_, _sąži,
   {{0x27ed04f9,0x26cd0167,0x6b8d354c,0x058467a5}},	//   _kien_, _hyeo_, kkag, _тутм,
   {{0x27ed003d,0x69c587ab,0x8af000a7,0x6b8d01cb}},	//   _jien_, hohe, rdək, jkag,
   {{0x63a9c59b,0xa3c00e72,0x61450ad3,0x69c5c59c}},	//   mien, ंकर_, _бела, kohe,
   {{0x27edc59d,0x69c500dd,0x20050090,0x628952c0}},	//   _lien_, johe, ppli_, myeo,
   {{0x6b9602ad,0x41cf0f35,0xa066008f,0x69c50052}},	//   thyg, _सीएस, _баща_, dohe,
   {{0x09be2cb6,0x6b8d1ba1,0x7f86037a,0x27edc59e}},	//   ्त्य, gkag, _póqu, _nien_,
   {{0x399601c5,0x628905e3,0x629bc59f,0x7db61673}},	// [fee0] _læse_, nyeo, nzuo, _مصدا,
   {{0x63a967e1,0x7a470029,0x69c5023b,0x27ed9309}},	//   hien, dītā, gohe, _aien_,
   {{0x27edc5a0,0x63a9c5a1,0x6f1622d4,0x6bd606f6}},	//   _bien_, kien, _keyc, _متحر,
   {{0x63a9c5a2,0x6d5e3adc,0x4b56013d,0x27edc5a3}},	//   jien, _hapa, _съот, _cien_,
   {{0x6d5ec5a4,0x63a91864,0x27edad8a,0x9cb300cd}},	//   _kapa, dien, _dien_, _نمیت,
   {{0x8e5700f5,0x69c543a2,0x6b8300d3,0x63a90db1}},	//   טינג_, cohe, _îngr, eien,
   {{0x69dc02dc,0x6d5ec5a5,0x63a9456c,0x27ed0381}},	//   _ihre, _mapa, fien, _fien_,
   {{0x27edc5a6,0x6d5ec5a7,0xee3f0094,0xbddb00ee}},	//   _gien_, _lapa, ytý_, otèc,
   {{0x171b006e,0x7a4700e8,0x5186596a,0x8383007b}},	//   _רומע, cītā, гуна, сыще,
   {{0x6d5ec5a8,0x291a0484,0x27edc5a9,0x63a95b53}},	//   _napa, napa_, _zien_, aien,
   {{0xe04a00d1,0x69dc00eb,0x00000000,0x00000000}},	//   رشده_, _mhre, --, --,
   {{0x645ac5aa,0x63a9b0b7,0x69c500dd,0x6d5e90e3}},	//   _isti, cien, zohe, _aapa,
   {{0x6d5e1084,0x62890da7,0x69dc6e36,0x4ea720e6}},	//   _bapa, cyeo, _ohre, урна,
   {{0xf99f0c56,0xf237040a,0x69c50052,0x69dc00f0}},	//   _jwèt_, _ערוץ_, xohe, _nhre,
   {{0x6d5e0493,0x6fd6025b,0x291ac5ab,0xfbd3177a}},	//   _dapa, mácn, dapa_, متر_,
   {{0x9b5859bc,0x6d61007e,0x7c280076,0x2d8101dc}},	//   лист_, _žvać, ádra, _wohe_,
   {{0x27ed04ea,0x69c501e5,0x69dc0099,0x6b8d3da1}},	// [fef0] _rien_, tohe, _bhre, rkag,
   {{0x7f5f01d4,0x645ac5ac,0x27ed040c,0x69dc7fe9}},	//   _haqq, _osti, _sien_, _chre,
   {{0x69c57b7b,0x69dc0a02,0x629b0451,0x201ec5ad}},	//   rohe, _dhre, zzuo, nsti_,
   {{0x69c500dd,0x7a4700d9,0x201e86d0,0x63a903be}},	//   sohe, tītā, isti_, xien,
   {{0x63a9c5ae,0x6d5e0b88,0x27edc5af,0x69dc0a1b}},	//   vien, _yapa, _vien_, _fhre,
   {{0x201e1ee8,0x63a90067,0x69dc0a02,0x27edc5b0}},	//   ksti_, wien, _ghre, _wien_,
   {{0x27ed362d,0x63a99f3b,0x7a4700d9,0xdb0d0037}},	//   _tien_, tien, sītā, hnaí,
   {{0x7f5f009e,0x637c0018,0x61fd0094,0x27ed029a}},	//   _naqq, _kény, íslo, _uien_,
   {{0x201e2132,0xe2991969,0xf99f05aa,0xa5f90b21}},	//   esti_, тап_, _fwèt_, _резу_,
   {{0x63a9c5b1,0xd49b0831,0xf1cf0034,0x00000000}},	//   sien, _пре_, _सीखन, --,
   {{0x637c0018,0x7f5f7568,0x201ec5b2,0x2be600a4}},	//   _lény, _baqq, gsti_, _कळलं_,
   {{0x6d5ec5b3,0xdee6450e,0x800a0018,0xe47a006e}},	//   _sapa, иони, کریہ_, _ברעכ,
   {{0x291ac5b4,0x2d9800e3,0x201e0084,0x6f0905e6}},	//   yapa_, thre_, asti_, ñeca,
   {{0xc0e507f3,0xf2d203c2,0xf1b90995,0x6d5e00a7}},	//   _колк, _ועד_, gršt_, _qapa,
   {{0x6d5e02fd,0xfce65bc5,0x291a02ef,0x99890146}},	//   _vapa, рово, vapa_, mpaň_,
   {{0x6d5e0010,0x291a0010,0x8024001c,0xb5fd74a5}},	//   _wapa, wapa_, _اروم, _pršl,
   {{0x6d5ec5b5,0x291a3cb8,0x637c0068,0x2907008b}},	// [ff00] _tapa, tapa_, _pénz, ınan_,
   {{0x9d46091c,0x186a84d5,0xa2dd046e,0xdb040076}},	//   _теод, кази_, _परन्, nniú,
   {{0x291a03b4,0x48d40033,0x765b0027,0x673b05db}},	//   rapa_, ়শ্র, _asuy, _bcuj,
   {{0x637c0018,0x291a113a,0xf7460dfb,0x8c1b00ca}},	//   _fény, sapa_, редо, _בוטי,
   {{0x69dc68da,0x7f42037a,0xf99f0154,0xb5fd05db}},	//   _thre, _ñoqu, _pwèt_, _uršl,
   {{0x23ba00d9,0x201ec5b6,0x69dc09ab,0xceb300ca}},	//   dīja_, ysti_, _uhre, חיד_,
   {{0xe73a00ae,0x00000000,0x00000000,0x00000000}},	//   _иев_, --, --, --,
   {{0x7d1c4b35,0x29180f52,0x201e8a42,0x00000000}},	//   hars, _hera_, vsti_, --,
   {{0x3a20c5b7,0x2918c5b8,0x1dc63ffc,0x179b0341}},	//   nsip_, _kera_, लकात, _סימב,
   {{0x64a62cbd,0x7f5f25c3,0x7d1cc5b9,0x3a2000a6}},	//   _каза, _saqq, jars, isip_,
   {{0x2918c5ba,0x645a4379,0xf4870018,0x201ec5bb}},	//   _mera_, _usti, _پالی, usti_,
   {{0x201e9dea,0x2918c5bc,0x7f5f11bc,0x00000000}},	//   rsti_, _lera_, _qaqq, --,
   {{0x7d1cc5bd,0x6d8b0092,0x23ba01d3,0x7642c5be}},	//   fars, _müav, cīja_, ntoy,
   {{0x291819e0,0x91e32ac0,0xdb040037,0x32064a19}},	//   _nera_, _доче, cniú, _itoy_,
   {{0xb05700e3,0x5f770f36,0x7f5fadcd,0xe6d300b6}},	//   _نشيط_, _ناظر, _taqq, _तर्ज,
   {{0x5bb80084,0xa2dd099d,0x386d00b6,0x853c0138}},	//   ался_, _परम्, _čer_, _smėl,
   {{0xa9072ce3,0x6f1d5761,0x291817c6,0x2b8e02c6}},	// [ff10] لبان, masc, _bera_, _mých_,
   {{0x6f1dc5bf,0xd138013f,0xfaff0052,0x27f82042}},	//   lasc, ngą_, _anët_, _burn_,
   {{0x6d55c5c0,0x6ff3002d,0xfbd00018,0x7760039f}},	//   meza, _făcu, ستہ_, _bamx,
   {{0x637c0018,0x6d551a87,0x6f1d038f,0xf5680018}},	//   _tény, leza, nasc, یمنٹ_,
   {{0x29181a72,0x6f1d00ae,0x442e029a,0xf7700308}},	//   _fera_, iasc, erf_, ظام_,
   {{0x2918a2a6,0x6d55c5c1,0x7dd200f2,0xfaff0216}},	//   _gera_, neza, væsk, _enët_,
   {{0x88e50f71,0xf8e50f71,0xb8950080,0xe8df0028}},	//   _প্রক, _প্রথ, _الأع, _trực_,
   {{0x61b10557,0x7d1c3b8f,0x23ba00d9,0x6f1d30cb}},	//   ीक्ष, zars, tīja_, jasc,
   {{0x7d1cb6d4,0x6f1d05fe,0x6d555f1d,0x957c00a5}},	//   yars, dasc, keza, _piąt,
   {{0x29010d9f,0x6fd608a8,0x7d1cc5c2,0x48de030b}},	//   ncha_, táco, xars, केको_,
   {{0x6f1dc252,0x23ba01d3,0x2b170285,0x69ba0635}},	//   fasc, sīja_, तराँ_, ्वती,
   {{0x7d1cc5c3,0xd4983e28,0x6561c5c4,0x6441013c}},	//   wars, _тру_, _halh, _iqli,
   {{0x290191ce,0x656100b6,0x61fb11bc,0x6e2902c6}},	//   kcha_, _kalh, qqul, šebn,
   {{0x6d554524,0xdcfe8dfa,0x237f033b,0xd0a80504}},	//   geza, _topč, ljuj_, اطین_,
   {{0xab2a2264,0x65617463,0xe0d10241,0x6f1d6500}},	//   лова_, _malh, _عزت_, basc,
   {{0x2918c5c5,0x7d1c18e8,0xa3c92a09,0xfbdf00de}},	//   _sera_, sars, ोति_, _chê_,
   {{0xa92628bb,0x2918c5c6,0x6d5587ee,0x6443033b}},	// [ff20] йдал, _pera_, beza, htni,
   {{0x7d1c01ee,0x6443c5c7,0xf2d20130,0x6fdd03be}},	//   qars, ktni, לען_, réce,
   {{0x291823ff,0x6443c5c8,0x237f00dc,0xa2c90861}},	//   _vera_, jtni, kjuj_, _हुस्,
   {{0x29015fef,0x2918b910,0x76420257,0xbddb6910}},	//   acha_, _wera_, ttoy, ntèn,
   {{0x65613d82,0x64434c15,0x2918c5c9,0xd1380138}},	//   _balh, etni, _tera_, ygą_,
   {{0xb9960080,0x64430bab,0x29010090,0x65610131}},	//   _السب, ftni, ccha_, _calh,
   {{0x6561c5ca,0x6443052f,0x3206037a,0x6f1d03e3}},	//   _dalh, gtni, _stoy_, yasc,
   {{0x6d55294f,0xf743386f,0xbebb0052,0x00000000}},	//   zeza, _несо, rgëz, --,
   {{0x6561001f,0x27e600a1,0x6b86166c,0x6d5560e8}},	//   _falh, mmon_, _mokg, yeza,
   {{0x6f04c5cb,0x64430087,0x6561016d,0x61ed028d}},	//   _afic, btni, _galh, _èall,
   {{0x6d551c54,0xb9150174,0x2b8e0220,0x6f1d5eb1}},	//   veza, _agbụ_, _tých_, tasc,
   {{0x6d5551d2,0x8af000a7,0x46dc4038,0x6b86039f}},	//   weza, ndəs, _बराह, _nokg,
   {{0x6f1d5ec4,0x41e600d6,0xeabf0032,0x32060270}},	//   rasc, _ліка, _adùn_, _utoy_,
   {{0x27e6c5cc,0xd0100cc8,0xf99f47d6,0xa2dd05d6}},	//   hmon_, _قلت_, _atèn_, _परत्,
   {{0xfbdf0019,0x6f1d51b3,0x6d47003e,0x2b4b022b}},	//   _phê_, pasc, rfja, _pbcc_,
   {{0x27e6007e,0x6d551c7b,0x6ab40096,0x00000000}},	//   jmon_, seza, ंपूर, --,
   {{0x6d550610,0x75280034,0x2901c5cd,0x8af000a7}},	// [ff30] peza, _oddz, tcha_, ddəs,
   {{0x6443c5ce,0x7e6db073,0xf99f0154,0x27e6acbf}},	//   ytni, _irap, _etèn_, emon_,
   {{0x2901386a,0x1bf200c3,0xfbdf0023,0x7e6dc5cf}},	//   rcha_, _आंचल_, _thê_, _hrap,
   {{0x29016ce8,0x9be40426,0xb5fd0117,0x7f4d0090}},	//   scha_, _ніяк, _uršk, _jbaq,
   {{0xbb3a00c1,0x65610161,0xb5fd0660,0xeb3a00c1}},	//   _דערי, _palh, _krši, _דערש,
   {{0x6443c18c,0x99800031,0x24090d9b,0x00000000}},	//   ttni, triť_, анки_, --,
   {{0xb5fd080e,0x6561419f,0x81c30033,0x7399468c}},	//   _mrši, _valh, ্ষম_, итис_,
   {{0x656138ad,0x316901c2,0x24414205,0x02050c59}},	//   _walh, _ɗazu_, róm_, озин,
   {{0x0cd60386,0x6561c5d0,0xb5fd00c4,0x7e6d03a9}},	//   _धर्म, _talh, _orši, _nrap,
   {{0x66094368,0x6d8b0092,0x7f4d019f,0x0595015a}},	//   _itek, _müas, _abaq, _بارگ,
   {{0x8af001d4,0x6e24badb,0xa2c900b6,0xadf3007f}},	//   ndər, _svib, _हुर्, _इंजन_,
   {{0x7e6d0808,0x35af0251,0xa2aa009d,0x442500e7}},	//   _brap, _झगड़, _जेव्, _ivl_,
   {{0x7e6d21d8,0xbddb7673,0xa2d002d5,0x672902a1}},	//   _crap, rtèn, _डुप्, _mdej,
   {{0x7e6dc5d1,0xbddb0472,0xa0690396,0xac0a1b04}},	//   _drap, stèn, _вака_, инга_,
   {{0x67290f90,0xa3de0096,0x7e6dc5d2,0xab1a007b}},	//   _odej, _दीड_, _erap, ицах_,
   {{0x7e6d1bc4,0x66096205,0x67290052,0x6f0460e8}},	//   _frap, _otek, _ndej, _ufic,
   {{0x442500d9,0xeb974000,0x7e6d4eda,0x660902a4}},	// [ff40] _lvl_, цит_, _grap, _ntek,
   {{0x67290065,0x3f82005f,0xbddb64b4,0x7d000065}},	//   _adej, ljku_, ntèl, _dàró,
   {{0x44251df6,0x66097300,0x6729009e,0x00000000}},	//   _nvl_, _atek, _bdej, --,
   {{0x6fd600d4,0x3f8214f3,0x6fca00c3,0x00000000}},	//   dáck, njku_, रविं, --,
   {{0x672902a1,0x16a709b9,0x442513ea,0xa4f80504}},	//   _ddej, овци_, _avl_, مکار_,
   {{0x27e60178,0xa2aa0966,0x69ce0634,0x00000000}},	//   smon_, _जेष्, _ukbe, --,
   {{0x6609c5d3,0x672900bd,0x6fdd014b,0x00000000}},	//   _etek, _fdej, héca, --,
   {{0x248002e6,0x050a0033,0xe7370613,0x136a23b8}},	//   ćim_, রণের_, _мес_, ршки_,
   {{0xd25000bf,0xef1f08bb,0xc17a004d,0xf99f0383}},	//   رند_, kkür_, аїн_, _otèl_,
   {{0x7e6d4e75,0x67290354,0x6fd60094,0xd5a400d1}},	//   _rrap, _zdej, lách, _علای,
   {{0x9f520383,0xc3070033,0x00000000,0x00000000}},	//   _kiyè_, োলজি_, --, --,
   {{0x7e6dc5d4,0xd36f00e3,0x9f5206a3,0xcfa70120}},	//   _prap, _لهم_, _jiyè_, ішни,
   {{0x35df000f,0x80ca034d,0xb5fd138c,0x518627d4}},	//   _पीड़, _सुरे, _prši, _мука,
   {{0x0dcb0636,0x7e6d48a3,0x8af0013c,0x00000000}},	//   руми_, _vrap, ydər, --,
   {{0xfbab246d,0x5f9500c2,0x9b080294,0x2bd901f3}},	//   атай_, _никт, _ọhịa_, مارک_,
   {{0x81c30081,0x7f4d063d,0x00000000,0x00000000}},	//   ্ষণ_, _ubaq, --, --,
   {{0x8d8737f2,0x3a32057a,0x5a3500e5,0x7e6d0027}},	// [ff50] _дунд, gryp_, янат, _urap,
   {{0xa2dd0efb,0x35df000f,0x89370037,0x2b49020a}},	//   _परस्, _पीढ़, تعرا, sfac_,
   {{0xa3ca6100,0x2b9c0220,0x9f52022b,0x2a6900aa}},	//   लका_, _síce_, _biyè_, svab_,
   {{0x6fd60146,0xb8f3007a,0xcd340018,0xf77315ae}},	//   váck, _हँ_, _ٹریب, باط_,
   {{0xddc47b57,0xa5094cc3,0x4b7a0327,0xdb0d0131}},	//   _hriš, бела_, _הארו, enaç,
   {{0x2b9c033a,0xce3800a1,0x05a8004d,0x7bcd2d31}},	//   _více_, קאות_, овій_, loau,
   {{0xdb0d016d,0x9f520032,0x69ba1e05,0xe8242a84}},	//   gnaç, _fiyè_, ्वरी, _офто,
   {{0x7bcd0131,0x7dd277d4,0x67291f54,0x6fd600d4}},	//   noau, læst, _udej, ráck,
   {{0x66091c35,0x3e7200fe,0x00000000,0x00000000}},	//   _utek, _môtô_, --, --,
   {{0x6fd619a3,0xdb160018,0x10a559bc,0xddc405db}},	//   máci, rnyé, зион, _oriš,
   {{0x6fd60181,0x98780880,0xfbbd02c6,0x00000000}},	//   láci, ršća_, ्काम, --,
   {{0x6ee10294,0x9f520113,0x644b0031,0x09b84f99}},	//   _ịban, _kiyé_, ľnič, _आद्य,
   {{0x6fd66cf4,0x644b0aa0,0x63bb1ab9,0x7bcd037a}},	//   náci, žnič, mnun, doau,
   {{0x1d071af2,0x661d01cd,0x00000000,0x00000000}},	//   зери_, _æsku, --, --,
   {{0x6ab4136b,0x00000000,0x00000000,0x00000000}},	//   ंप्र, --, --, --,
   {{0x6fd6c5d5,0x501a00a1,0xef1a0231,0x60dc7f09}},	//   káci, _פופו, _уми_, ürme,
   {{0x63bb1c0c,0x7dd20537,0xdcfe078e,0x69ba00b7}},	// [ff60] inun, fæst, _copă, ्वली,
   {{0x63bb02e2,0x6fd60220,0xddc40ebd,0x291c4777}},	//   hnun, dáci, _friš, úva_,
   {{0x9f520065,0xacfb00ca,0x63bb061a,0x7bc1014b}},	//   _aiyé_, _להיכ, knun, éluc,
   {{0x63bb03e5,0x7d1e01e8,0xe73a6e7c,0x6fd6016d}},	//   jnun, _heps, сед_, fáci,
   {{0x6fd6c5d6,0x63bb5ea6,0x28ac17ad,0x7d1e12ef}},	//   gáci, dnun, _टेरि, _keps,
   {{0xe5a33119,0x2fc00284,0x7dd2052f,0x67fa00b6}},	//   ничи, _ljig_, mæss, _půjd,
   {{0x63bb0e8a,0x81c300c7,0x09e33006,0x6fd600d4}},	//   fnun, ্ষা_, _чорн, pách,
   {{0x58bb00a1,0x48e1009d,0x7d1e872e,0x6b840cea}},	//   _המלצ, _करतो_, _leps, njig,
   {{0xdcfc00d9,0x6fd60161,0x877b006e,0x7d1e02ac}},	//   nkrē, cáci, _פאמי, _oeps,
   {{0x63bbc5d7,0x7d1e057d,0x00000000,0x00000000}},	//   anun, _neps, --, --,
   {{0xd25009b4,0xf8be0557,0x68050138,0x9f35097a}},	//   رنگ_, ्थिय, _kėda, мені,
   {{0x67220051,0x2d8c071b,0x6b8401c2,0x00000000}},	//   naoj, öden_, jjig, --,
   {{0xbddb025a,0x7d1e039f,0x00000000,0x00000000}},	//   stèm, _beps, --, --,
   {{0xddc412bf,0x7d1e0dcb,0x6aa400e7,0xf8be06e4}},	//   _priš, _ceps, dzif, ्थाय,
   {{0x6fd6c5d5,0x28ac314f,0x7bcd8cce,0x00000000}},	//   záci, _टेलि, toau, --,
   {{0xaca30134,0xb5fd0a9e,0x69c3103b,0xddc40106}},	//   _haịd, _kršt, čnem, _vriš,
   {{0x6fdd0257,0xfb340077,0x7bcd11fe,0x6fd60206}},	// [ff70] léco, энтэ, roau, xáci,
   {{0x127b00c1,0x6fd619a3,0x213e00a1,0xad9b0072}},	//   זאמע, váci, ngth_, rpús,
   {{0x4af90f94,0xc70a0294,0x23cc0d61,0x63bb9819}},	//   _меню_, _ịrịb, ावाद, ynun,
   {{0x6fd66cf4,0x27e4009c,0x9f5200d1,0xe7380120}},	//   táci, _chmn_, _piyé_, зеї_,
   {{0xb8d40553,0x59bf0285,0x00000000,0x00000000}},	//   _जे_, ्वदर, --, --,
   {{0x6fd6c5d5,0x395a34d2,0x00000000,0x00000000}},	//   ráci, ceps_, --, --,
   {{0x66e30065,0xa3e937a8,0x63bb0e67,0x00000000}},	//   _bìkí, одка_, tnun, --,
   {{0x6fdd020d,0x6fd64df5,0x00000000,0x00000000}},	//   déco, páci, --, --,
   {{0x63bbc5d8,0x6fdd1f84,0xb5fd0ebd,0x45d500ae}},	//   rnun, técn, _pršu, _жоас,
   {{0x38713693,0x35b400d3,0x59bf00b6,0x661b849c}},	//   _krzr_, _збур, ्विर, _iwuk,
   {{0x75233f68,0x6aa40036,0xa3de06eb,0xe81100a4}},	//   manz, zzif, _दीव_, डीचा_,
   {{0x7d1e01e5,0x2614000f,0x7523c5d9,0x661b0294}},	//   _seps, नीकी_, lanz, _kwuk,
   {{0x61450747,0x59bf1388,0x69c30631,0xa3ca39d4}},	//   _жела, ्वार, čnej, लकर_,
   {{0x7523c5da,0x61fd0074,0xe9ff00ef,0xfce629a4}},	//   nanz, íslu, _hoặc_, дого,
   {{0x8c430235,0x45220033,0x9f5d02f1,0x7d1e2012}},	//   кере, _নামক_, _ouvè_, _veps,
   {{0xee3a453b,0x752302a4,0x09c65d3b,0x44271f40}},	//   _дни_, hanz, वव्य, isn_,
   {{0x75230bbd,0x6d4f003e,0x00000000,0x00000000}},	// [ff80] kanz, únað, --, --,
   {{0x7e64c5db,0x752377d6,0x99890357,0x8e37006e}},	//   _isip, janz, traš_, _קניא_,
   {{0x7766013d,0x7523c5dc,0x395a1d91,0x661b4102}},	//   дълж, danz, reps_, _awuk,
   {{0x7c3cc5dd,0x661b0027,0x00000000,0x00000000}},	//   murr, _bwuk, --, --,
   {{0x6f090933,0x7523c5de,0xe5c6022f,0x7c3c01e9}},	//   ñeci, fanz, мско, lurr,
   {{0x75232771,0x2b4043a2,0x61c700c3,0x2d980103}},	//   ganz, lgic_, रकोष, nkre_,
   {{0x3e85074a,0xd943120a,0x6d5cc5df,0x84e81c05}},	//   _këtë_, _шери, iera, टेंट_,
   {{0x16190251,0x2b4000e7,0xb5fd0218,0x75230350}},	//   _नौकर_, ngic_, _pršt, aanz,
   {{0x6d5c6ccf,0x7523271c,0x7c3c3a0d,0xfd650023}},	//   kera, banz, hurr, _chuồ,
   {{0x75232034,0x7c3c02a7,0x30146c35,0x3cef00a4}},	//   canz, kurr, ндор, _आणले_,
   {{0x130a0084,0x7e64c5e0,0x80d60081,0x657a019f}},	//   _дней_, _asip, ডেন্, _inth,
   {{0x6568996e,0x7c3cc13f,0x660052cd,0x6d4e0b8e}},	//   _hadh, durr, _kumk, efba,
   {{0x6d5cc5e1,0x6568c5e2,0x16dc0cf6,0x02e20179}},	//   fera, _kadh, _बरोब, _परिभ,
   {{0x316702dc,0x660000ad,0x6d5cc5e3,0x70190018}},	//   _ganz_, _mumk, gera, _کروڑ_,
   {{0x65686108,0x0cd400d6,0x7e640201,0xfbd31f11}},	//   _madh, ворю, _esip, نتر_,
   {{0x75230051,0x6568c5e4,0x6720bbe0,0x200e02a1}},	//   zanz, _ladh, _nemj, _itfi_,
   {{0x6d5cc5e5,0x657a5268,0x443c01fa,0x75230435}},	// [ff90] bera, _onth, huv_, yanz,
   {{0x6d5c070a,0xf7700e8c,0x443c5981,0x6568c5e6}},	//   cera, یان_, kuv_, _nadh,
   {{0xb907550b,0x7523c5e7,0x4735139c,0x6e3d0475}},	//   _पर_, vanz, енес, lusb,
   {{0x752302a4,0x61f820ab,0x657a436f,0x442700e7}},	//   wanz, _livl, _anth, vsn_,
   {{0x752346b6,0x6568c5e8,0x6e3d633e,0xa5095d16}},	//   tanz, _badh, nusb, пела_,
   {{0x3edf0294,0x6568c5e9,0x660001c2,0x6fd60328}},	//   _arịọ_, _cadh, _dumk, láct,
   {{0x7523c5ea,0x6d45068d,0xa5c50065,0x656803a9}},	//   ranz, _mcha, _akóì, _dadh,
   {{0x61c706e4,0x6d5cc5eb,0x22150012,0x75230ab1}},	//   रक्ष, zera, нфор, sanz,
   {{0x6568c5ec,0x7c3cc5ed,0x7523acdc,0x7f5d00b3}},	//   _fadh, zurr, panz, desq,
   {{0x6d45c5ee,0x6568c5e8,0x6d5c37b8,0xdd31013c}},	//   _ncha, _gadh, xera, _rəşa,
   {{0x61f800e9,0x6d5cc5ef,0xd00e110a,0x7afd0124}},	//   _divl, vera, یلی_, _ogst,
   {{0x6d45c5f0,0x6d5cc5f1,0x34940120,0x65680113}},	//   _acha, wera, _шахр, _zadh,
   {{0x6fd64c20,0x6e3dc5f2,0x7c3c01c2,0x3167042c}},	//   dáct, gusb, wurr, _tanz_,
   {{0x6145638e,0x75210103,0x65680188,0x7afd4806}},	//   _чека, _jelz, _xadh, _agst,
   {{0x6d5cc5f3,0xc4d200c1,0x7f5d2722,0x6d4538bf}},	//   rera, ָגן_, besq, _dcha,
   {{0x6d5cc5f4,0x6d45c5f5,0xd00e00e3,0x69d501bf}},	//   sera, _echa, _الي_, _akze,
   {{0xfaa33c91,0xdb0f0103,0x7e64339e,0x2b404065}},	// [ffa0] гато, ájár, _usip, rgic_,
   {{0xe9d7c5f6,0x7c3cc5f7,0x6720b535,0x752100b6}},	//   еку_, purr, _semj, _nelz,
   {{0x6568c5f8,0x644a48fc,0x77690381,0x00000000}},	//   _radh, xtfi, _baex, --,
   {{0xd6d900a5,0x69d5c5f9,0x65681f11,0xa3de0006}},	//   _był_, _ekze, _sadh, _दीं_,
   {{0x656800bf,0x69d500e7,0x777b0113,0xb7d70286}},	//   _padh, _fkze, _dnux, روها_,
   {{0xceb300c1,0x644a6f0a,0x6568388f,0x046623f9}},	//   ניג_, ttfi, _qadh, етим,
   {{0x6fd60018,0xb0cf009f,0x65683b69,0x3a2b0141}},	//   nács, _सुलग, _vadh, _zvcp_,
   {{0x6568c5fa,0x443cc5fb,0x4908030b,0xff5f020d}},	//   _wadh, ruv_, ाँको_, noît_,
   {{0x644a4559,0x6568c5fc,0x61f80095,0x798e0027}},	//   stfi, _tadh, _pivl, _kobw,
   {{0xe4d600e3,0x200e0167,0x6fd601f9,0x00000000}},	//   _كتاب, _ptfi_, kács, --,
   {{0x8937006e,0xc95300ca,0x91a6007f,0xdb0d0231}},	//   ערטע_, אמת_, टोगै, rnaú,
   {{0x6d45510f,0x6e3dc5fd,0x00000000,0x00000000}},	//   _scha, tusb, --, --,
   {{0x7f5d412d,0x212505db,0x00000000,0x00000000}},	//   resq, balh_, --, --,
   {{0x99800138,0x127b00c1,0x31341107,0x81de0033}},	//   irių_, _מאדע, _рекр, _দূর_,
   {{0xe0d40130,0x0133010d,0x6fd6037a,0xc17800c6}},	//   _בײַ_, _صعود, táct, smės_,
   {{0x3a29037a,0x9f5500ae,0x00000000,0x00000000}},	//   tsap_, _рвич, --, --,
   {{0x6fd60fb6,0x6d45c5fe,0x99890220,0x798e010a}},	// [ffb0] ráct, _tcha, hrať_, _bobw,
   {{0x6d45c5ff,0xa3e70e50,0x442c258e,0x61ed0036}},	//   _ucha, _मीन_, _ovd_, _èalt,
   {{0xbb1b025a,0x3a29c600,0x2ca700f2,0xa9c40120}},	//   _boît, ssap_, _ånd_, устк,
   {{0xdb0700c2,0x75210090,0x3b1e020b,0x00000000}},	//   ämät, _selz, _đtqg_, --,
   {{0x442c0727,0x99890206,0x752102db,0x23ba00e8}},	//   _avd_, erať_, _pelz, nīju_,
   {{0x442c0381,0x6e2d0027,0x00000000,0x00000000}},	//   _bvd_, _mvab, --, --,
   {{0xd466049f,0x65920291,0x752101cb,0x917b020b}},	//   вище_, рају, _velz, _lễ_,
   {{0x58d455f7,0x77d700e3,0x752101c0,0x442c7ae7}},	//   _сост, _أغسط, _welz, _dvd_,
   {{0x35f50977,0xdcfe1d88,0x422200c2,0xd2f6001c}},	//   _апар, _uopć, адыв, نکها_,
   {{0x6fdd04ea,0xe4a703fc,0x6f0d002d,0x99890181}},	//   léch, _прео, _afac, brať_,
   {{0x8fa60465,0x442c0381,0x00000000,0x00000000}},	//   ване, _gvd_, --, --,
   {{0x2125005c,0x200500a7,0x4f962fad,0xb4cd6bbd}},	//   salh_, rqli_, троу, रथी_,
   {{0xe28e1d1b,0x59d10ff9,0xfe790109,0x00000000}},	//   _та_, तकार, нёры_, --,
   {{0x6f0dc248,0x917b00fe,0x00000000,0x00000000}},	//   _efac, _dễ_, --, --,
   {{0x224dc601,0x6f0d00f0,0x798e0027,0x442c0113}},	//   ltek_, _ffac, _robw, _xvd_,
   {{0x25e805d4,0x224d02fe,0x6fd60018,0x236d023b}},	//   _चीनी_, otek_, rács, ndej_,
   {{0x224d0018,0xff5f014b,0x6fdd014b,0x00000000}},	// [ffc0] ntek_, roît_, déch, --,
   {{0x224d8377,0x957c007f,0x8d5600ae,0x00000000}},	//   itek_, _wiąz, _ртич, --,
   {{0x98b101e8,0xdca60ac6,0x6e2d0141,0x00000000}},	//   _bazı_, _рани, _zvab, --,
   {{0x224dc602,0x2d8a00c4,0x7e763f43,0x00000000}},	//   ktek_, ljbe_, _kryp, --,
   {{0x224dc603,0x442c0149,0xe5340a2d,0x4733036c}},	//   jtek_, _svd_, гель, рніс,
   {{0x35b6008f,0xd6930291,0x56930307,0x442c0a84}},	//   ъщес, ришћ, рашт, _pvd_,
   {{0xa3be074c,0x67e309a1,0x00000000,0x00000000}},	//   ँचल_, sõja, --, --,
   {{0x68e3c604,0x442c01c0,0x236d023e,0x98b10233}},	//   ünde, _vvd_, gdej_, _gazı_,
   {{0x05660114,0x6f0d1d66,0x00000000,0x00000000}},	//   _иван, _rfac, --, --,
   {{0xa3e731f4,0x6f0d3ab5,0xbddb210f,0x00000000}},	//   _मीठ_, _sfac, ntèt, --,
   {{0x98b103a3,0x493b00ca,0x6e2dc605,0x44387d11}},	//   _yazı_, וגיו, _svab, _ír_,
   {{0x23ba00e8,0x00000000,0x00000000,0x00000000}},	//   tīju_, --, --, --,
   {{0x28d9000f,0x539b028c,0x00000000,0x00000000}},	//   _बुनि, _קידו, --, --,
   {{0xbbbd007d,0x7bc62a6c,0x7e766f0c,0x63a20372}},	//   ्क्क, _ajku, _dryp, _hlon,
   {{0x1df800c2,0x23ba00e8,0xdb040381,0x00000000}},	//   теры_, sīju_, chië, --,
   {{0x63a20113,0xddcd020a,0x00000000,0x00000000}},	//   _jlon, _braţ, --, --,
   {{0x98b10491,0x63a218c7,0x6fdd037a,0x7e764c15}},	// [ffd0] _razı_, _mlon, véch, _gryp,
   {{0x645a7571,0x6fdd97b2,0x63a24967,0x236d12b1}},	//   _opti, déci, _llon, zdej_,
   {{0x224d1fd1,0x38c90281,0x7bc8020d,0x6fdd014b}},	//   ztek_, رائی_, éduc, téch,
   {{0x224dc606,0xddcd00ae,0xe7d10033,0xc053006e}},	//   ytek_, _fraţ, িষ্য, יזע_,
   {{0xf7700dd0,0x26c90396,0x6fdda8a0,0x659562b6}},	//   تال_, çao_, réch, ладу,
   {{0x63a2c607,0x69cb0103,0xbf1f0096,0x59a700e2}},	//   _alon, éged, परुन_, _गतिर,
   {{0x26d2026a,0x00000000,0x00000000,0x00000000}},	//   üyor_, --, --, --,
   {{0x248902e6,0x04560080,0x224d0018,0x6fdd2a56}},	//   ćam_, الية_, ttek_, béci,
   {{0xe1f90d9b,0x63a202a1,0x236dc608,0x61ea0076}},	//   нги_, _dlon, rdej_, _bhfl,
   {{0x63a22b43,0x224dc609,0xd49b00d3,0x6468007b}},	//   _elon, rtek_, _оре_, äsiä,
   {{0x224dc60a,0xbf1f0096,0x00000000,0x00000000}},	//   stek_, परून_, --, --,
   {{0x224d0103,0x63a262b1,0x201101d3,0x6d57013c}},	//   ptek_, _glon, īzi_, _abxa,
   {{0x2bc708c0,0x69c70361,0x00000000,0x00000000}},	//   रचना, _ojje, --, --,
   {{0xde031357,0x8c460161,0xa3e700aa,0x765b0027}},	//   спри, леге, _मीत_, _mpuy,
   {{0xdca30d9b,0x00000000,0x00000000,0x00000000}},	//   бари, --, --, --,
   {{0x399634da,0x69c7010a,0xf412021e,0x6d8b013c}},	//   _læst_, _ajje, מפל_, _müay,
   {{0x4e1d00a5,0x6e29015c,0x00000000,0x00000000}},	// [ffe0] बीआई_, šebr, --, --,
   {{0x8d6621b4,0x3996003e,0x680c00a7,0x4d6602f3}},	//   _свое, _næst_, _ağda, _сков,
   {{0x765b2621,0xf99f0428,0x3f920233,0x28f900ae}},	//   _apuy, _atès_, _koyu_, вэцэ_,
   {{0x69c7c60b,0x7c2e0596,0xddcd8076,0x46a64778}},	//   _ejje, msbr, _iraš, лаев,
   {{0x6d410155,0x9f8b00bc,0x52e200bc,0x00000000}},	//   ólag, _tööl_, _परेस, --,
   {{0x7bc401b3,0xddcd3616,0x6fdd0921,0xbddb020d}},	//   lniu, _kraš, réci, ltèr,
   {{0x7794010d,0x2b9c020b,0x00000000,0x00000000}},	//   _پیشا, _níck_, --, --,
   {{0x6fdd001f,0xa3e700aa,0x7791001c,0x684300ae}},	//   péci, _मीद_, _ویلا, _ынса,
   {{0xf126663a,0x399601cd,0x63a2c60c,0x55e600ae}},	//   льно, _fæst_, _vlon, _боаб,
   {{0x865b0341,0xddcd0106,0x399602b6,0x76420233}},	//   _אדמי, _oraš, _gæst_, muoy,
   {{0x3f9207aa,0x63a2005c,0x7c2e2c18,0x7bc42fe0}},	//   _boyu_, _tlon, jsbr, kniu,
   {{0x7c2e01c5,0xdb0d0161,0xdfd5004c,0x289b021e}},	//   dsbr, miaç, ромы, גיטא,
   {{0xdb0d00c9,0x22164487,0x9f920088,0xef1f0103}},	//   liaç, _сфер, ráð_, ljük_,
   {{0x6286007b,0xa6d10033,0x6fc80342,0x00000000}},	//   äkou, ়েকট, rıca, --,
   {{0x2b9c0028,0x7c2e1088,0x11db00a1,0x442e022b}},	//   _kích_, gsbr, _רחוב, nsf_,
   {{0xddcd031a,0x7bc44a3b,0x6fc80233,0x09bf0b76}},	//   _draš, gniu, pıca, ्व्य,
   {{0x7762c60d,0x52e2009f,0x5edc007f,0x645c00bc}},	// [fff0] deox, _परोस, _गुप्_, _ärif,
   {{0xa2c5030b,0x5f5d0129,0x2b9c00fe,0x7d1800d4}},	//   ापत्, _ọnụọ, _lích_, časí,
   {{0xddcd28fc,0x765b0167,0x3157006e,0xbddb00ee}},	//   _graš, _spuy, ריבן_, stès,
   {{0x2d930933,0xbddb0257,0xdb0d7148,0x7b673ae7}},	//   _hoxe_, ctèr, diaç, _стое,
   {{0x36691061,0xddcd05db,0x752a0381,0x00000000}},	//   тало_, _zraš, fafz, --,
   {{0x6d477cd9,0x2d9301e9,0xbebb0052,0xd6180037}},	//   ngja, _joxe_, mbëd, اتنا_,
   {{0x6fdd06fc,0xcd9800a1,0x2b9c00de,0x69d70042}},	//   lécu, רדות_, _bích_, moxe,
   {{0x6b8d460d,0x69d7002b,0x42550c59,0xf8b200d7}},	//   njag, loxe, атот, _ושל_,
   {{0x69c5856c,0x6aad0a53,0x9f840233,0x6d5500b3}},	//   onhe, nzaf, lıç_, kfza,
   {{0x69c58c05,0x672b2261,0x6b8dc60e,0x00000000}},	//   nnhe, lagj, hjag, --,
   {{0xdb0d001f,0x27ed0019,0x65633e97,0x6e3d525b}},	//   ciaç, _khen_, menh, ersb,
   {{0x69c50364,0x72d5141a,0x672bc60f,0xdb04014b}},	//   hnhe, _коеф, nagj, phié,
   {{0x6443c610,0x539a00a1,0x2d93c611,0x63a9003e}},	//   luni, _שינו, _boxe_, mhen,
   {{0xddcdbc62,0x7c2e74e6,0x65636dc9,0x6d476f92}},	//   _praš, tsbr, nenh, ggja,
   {{0xab2a2dd5,0x1c3914fa,0x64435768,0x69c50063}},	//   кова_, лять_, nuni, dnhe,
   {{0x63a9c612,0x63bbc613,0x69c5286f,0x2b9c0023}},	//   nhen, niun, enhe, _xích_,

  };
  // table_hash = 8a13-6340, unused_entries = 17771 (6.78%)

static const uint32 kQuadChrome0122_2SizeOne = 50708;  // One-langprob count
static const uint32 kQuadChrome0122_2IndSize = 50708;  // Largest subscript
extern const uint32 kQuadChromeIndSize = kQuadChrome0122_2IndSize; // Source-agnostic named constant
static const uint32 kQuadChrome0122_2Ind[kQuadChrome0122_2IndSize] = {
  // [0000]
  0x00000000, 0x00000000, 0x08040709, 0x06000c13,   // -- --  bg.ru.uk_444 sv.de.un_650
  0x080c03a7, 0x1a6b1cee, 0x0000131c, 0x04523508,   // nl.sv.no_532 id.ceb.tl_422  et.un.un_800 zu.ha.fi_443
  0x236e05ec, 0x00006b0a, 0x2d162908, 0x03003f08,   // fr.hmn.ca_644 ceb.un.un_500  sl.hr.sk_443 af.nl.un_430
  0x1c090daf, 0x00000d1c, 0x281e1c05, 0x13000914,   // ne.hi.mr_655 ne.un.un_800  id.ms.sw_333 hi.bh.un_660
  // [0010]
  0x00002815, 0x21520ea4, 0x0000111c, 0x0000271c,   // sw.un.un_700 is.ha.jw_433  ro.un.un_800 gd.un.un_800
  0x02212013, 0x21190a02, 0x06030ca4, 0x1f2864af,   // sq.jw.da_665 pt.gl.jw_222  sv.nl.de_433 lg.sw.cy_655
  0x00001215, 0x00002b15, 0x25131a07, 0x64005219,   // hu.un.un_700 vi.un.un_700  tl.et.eu_432 ha.lg.un_750
  0x0000210f, 0x11000721, 0x11001f18, 0x00000a0f,   // fa.un.un_600 it.ro.un_860  cy.ro.un_740 pt.un.un_600
  // [0020]
  0x00000724, 0x0000021c, 0x00005206, 0x00002b0a,   // bg.un.un_900 da.un.un_800  ha.un.un_400 vi.un.un_500
  0x11356805, 0x211611ee, 0x281852a0, 0x00005501,   // ig.zu.ro_333 ro.hr.jw_422  ha.ga.sw_322 rw.un.un_200
  0x00002b1c, 0x00000f1c, 0x64075204, 0x00001903,   // vi.un.un_800 lv.un.un_800  ha.it.lg_332 gl.un.un_300
  0x0309060c, 0x00001115, 0x040810ee, 0x3b2028a4,   // de.pl.nl_543 ro.un.un_700  be.uk.ru_422 sw.sq.so_433
  // [0030]
  0x16092d5a, 0x00002d0a, 0x00004a0a, 0x00000b0f,   // sk.pl.hr_553 sk.un.un_500  yo.un.un_500 bn.un.un_600
  0x0000090f, 0x21001e05, 0x00000701, 0x0000180f,   // pl.un.un_600 ms.jw.un_330  it.un.un_200 ar.un.un_600
  0x00002d1c, 0x3216170e, 0x1e001a04, 0x18002723,   // sk.un.un_800 sr.hr.bs_555  tl.ms.un_320 gd.ga.un_880
  0x0312355a, 0x00002a15, 0x00000e0f, 0x211812af,   // zu.hu.nl_553 mt.un.un_700  is.un.un_600 ur.ar.fa_655
  // [0040]
  0x1c131e0c, 0x1b2825ee, 0x00001906, 0x64351aad,   // ms.et.id_543 eu.sw.tr_422  gl.un.un_400 tl.zu.lg_643
  0x0000520f, 0x25196ba0, 0x08030208, 0x532b1f0c,   // ha.un.un_600 ceb.gl.eu_322  da.nl.no_443 cy.vi.ht_543
  0x1f0c06a0, 0x00002724, 0x1b321704, 0x00001006,   // de.sv.cy_322 gd.un.un_900  sr.bs.tr_332 be.un.un_400
  0x0400110c, 0x0000080f, 0x2a1220a7, 0x00000124,   // ro.ru.un_530 no.un.un_600  sq.hu.mt_532 en.un.un_900
  // [0050]
  0x0e210804, 0x0000280f, 0x0000200a, 0x06030cad,   // no.jw.is_332 sw.un.un_600  sq.un.un_500 sv.nl.de_643
  0x0000011c, 0x18002729, 0x35060a0c, 0x3b3117a0,   // en.un.un_800 gd.ga.un_960  pt.de.zu_543 sr.az.so_322
  0x070a17a4, 0x3513045a, 0x1e001c14, 0x2d092507,   // sr.mk.bg_433 fi.et.zu_553  id.ms.un_660 eu.pl.sk_432
  0x1e001c02, 0x6b1011ec, 0x52352808, 0x3217160e,   // id.ms.un_220 ro.lt.ceb_644  sw.zu.ha_443 hr.sr.bs_555
  // [0060]
  0x0000351c, 0x32291007, 0x00002503, 0x00001e01,   // zu.un.un_800 lt.sl.bs_432  eu.un.un_300 ms.un.un_200
  0x042125ee, 0x00004a06, 0x21002802, 0x0000091c,   // eu.jw.fi_422 yo.un.un_400  sw.jw.un_220 pl.un.un_800
  0x0000121c, 0x4a006e08, 0x18273b12, 0x27001822,   // hu.un.un_800 hmn.yo.un_430  so.gd.ga_654 ga.gd.un_870
  0x00006e15, 0x00005215, 0x0000240f, 0x181221af,   // hmn.un.un_700 ha.un.un_700  yi.un.un_600 fa.ur.ar_655
  // [0070]
  0x17080408, 0x11253508, 0x00001901, 0x0c08020d,   // ru.uk.sr_443 zu.eu.ro_443  gl.un.un_200 da.no.sv_554
  0x2d000d1b, 0x0f006e0c, 0x0000180a, 0x00001001,   // cs.sk.un_770 hmn.lv.un_530  ga.un.un_500 be.un.un_200
  0x00002a0f, 0x00005506, 0x00001315, 0x0000040a,   // mt.un.un_600 rw.un.un_400  bh.un.un_700 fi.un.un_500
  0x2a2818a0, 0x1c001305, 0x00001701, 0x0000090a,   // ga.sw.mt_322 bh.mr.un_330  sr.un.un_200 pl.un.un_500
  // [0080]
  0x0000181c, 0x00000b15, 0x0a04175a, 0x080225ee,   // ar.un.un_800 bn.un.un_700  sr.ru.mk_553 eu.da.no_422
  0x00000415, 0x00001c03, 0x0410110c, 0x0000290f,   // ru.un.un_700 id.un.un_300  ro.be.ru_543 sl.un.un_600
  0x00000e15, 0x0100240d, 0x00003b15, 0x31001b13,   // is.un.un_700 yi.iw.un_540  so.un.un_700 tr.az.un_650
  0x00003b0a, 0x0704080d, 0x1b00311a, 0x0000070f,   // so.un.un_500 uk.ru.bg_554  az.tr.un_760 bg.un.un_600
  // [0090]
  0x00002a01, 0x1800271a, 0x00003115, 0x2a003b02,   // mt.un.un_200 gd.ga.un_760  az.un.un_700 so.mt.un_220
  0x2d000d09, 0x00001703, 0x00001c0f, 0x04081705,   // cs.sk.un_440 sr.un.un_300  mr.un.un_600 sr.uk.ru_333
  0x64006e07, 0x2700181b, 0x17003204, 0x27001814,   // hmn.lg.un_420 ga.gd.un_770  bs.sr.un_320 ga.gd.un_660
  0x00002701, 0x00001c15, 0x00002a0a, 0x13000909,   // gd.un.un_200 mr.un.un_700  mt.un.un_500 hi.bh.un_440
  // [00a0]
  0x10070408, 0x00000115, 0x06000c0d, 0x09001304,   // ru.bg.be_443 iw.un.un_700  sv.de.un_540 bh.hi.un_320
  0x00001c0a, 0x00000915, 0x00001a15, 0x0000310f,   // mr.un.un_500 pl.un.un_700  tl.un.un_700 az.un.un_600
  0x091c0d0c, 0x04000813, 0x0000130f, 0x21001819,   // ne.mr.hi_543 uk.ru.un_650  et.un.un_600 ar.fa.un_750
  0x0000681c, 0x1b003105, 0x0000110a, 0x130d09af,   // ig.un.un_800 az.tr.un_330  ro.un.un_500 hi.ne.bh_655
  // [00b0]
  0x10041ca0, 0x121821af, 0x18531902, 0x00002301,   // id.fi.lt_322 fa.ar.ur_655  gl.ht.ga_222 ca.un.un_200
  0x070a170d, 0x10080c0c, 0x00000d0f, 0x00001303,   // sr.mk.bg_554 sv.no.lt_543  ne.un.un_600 et.un.un_300
  0x0a1707a9, 0x1800210e, 0x0800040e, 0x08020eaf,   // bg.sr.mk_544 fa.ar.un_550  ru.uk.un_550 is.da.no_655
  0x0000130a, 0x00002a06, 0x04081707, 0x0000211c,   // et.un.un_500 mt.un.un_400  sr.uk.ru_432 fa.un.un_800
  // [00c0]
  0x13090dec, 0x00002415, 0x0000040f, 0x13000905,   // ne.hi.bh_644 yi.un.un_700  ru.un.un_600 hi.bh.un_330
  0x00001601, 0x070a10ee, 0x0000100a, 0x00000b1c,   // hr.un.un_200 be.mk.bg_422  lt.un.un_500 bn.un.un_800
  0x17040aec, 0x00000a1c, 0x0000010f, 0x321716a4,   // mk.ru.sr_644 mk.un.un_800  iw.un.un_600 hr.sr.bs_433
  0x17163205, 0x00002115, 0x00000406, 0x17080aa9,   // bs.hr.sr_333 fa.un.un_700  ru.un.un_400 mk.uk.sr_544
  // [00d0]
  0x2100121a, 0x0000210a, 0x00000d06, 0x0000110f,   // ur.fa.un_760 fa.un.un_500  cs.un.un_400 ro.un.un_600
  0x2d000d05, 0x17040813, 0x00000815, 0x0000010a,   // cs.sk.un_330 uk.ru.sr_665  uk.un.un_700 iw.un.un_500
  0x2d000d02, 0x00000f15, 0x00001806, 0x52000104,   // cs.sk.un_220 lv.un.un_700  ga.un.un_400 en.ha.un_320
  0x00001e03, 0x00002015, 0x00002b0f, 0x0d001302,   // ms.un.un_300 sq.un.un_700  vi.un.un_600 bh.ne.un_220
  // [00e0]
  0x18006b04, 0x19000b04, 0x09000d09, 0x00001815,   // ceb.ga.un_320 es.gl.un_320  ne.hi.un_440 ar.un.un_700
  0x0f00100d, 0x0000070a, 0x6b061fa0, 0x00003201,   // lt.lv.un_540 bg.un.un_500  cy.de.ceb_322 bs.un.un_200
  0x00000f0a, 0x32161714, 0x0e001212, 0x00001f06,   // lv.un.un_500 sr.hr.bs_666  hu.is.un_640 cy.un.un_400
  0x00001c06, 0x18002102, 0x00002303, 0x00002b24,   // id.un.un_400 jw.ga.un_220  ca.un.un_300 vi.un.un_900
  // [00f0]
  0x00001f0f, 0x09002904, 0x08000209, 0x00000806,   // cy.un.un_600 sl.pl.un_320  da.no.un_440 no.un.un_400
  0x05001b08, 0x01002413, 0x0a001713, 0x10000822,   // tr.fr.un_430 yi.iw.un_650  sr.mk.un_650 uk.be.un_870
  0x0a0407ec, 0x00001a01, 0x1c320da0, 0x00001224,   // bg.ru.mk_644 tl.un.un_200  cs.bs.id_322 ur.un.un_900
  0x00000501, 0x0000050a, 0x00002b06, 0x1c556804,   // fr.un.un_200 fr.un.un_500  vi.un.un_400 ig.rw.id_332
  // [0100]
  0x12002118, 0x1c130960, 0x00000e1c, 0x0000120f,   // fa.ur.un_740 hi.bh.mr_664  is.un.un_800 ur.un.un_600
  0x091c13a4, 0x01002419, 0x32171609, 0x1b1f1a04,   // bh.mr.hi_433 yi.iw.un_750  hr.sr.bs_444 tl.cy.tr_332
  0x100407a7, 0x0400100d, 0x00006401, 0x18002702,   // bg.ru.be_532 be.ru.un_540  lg.un.un_200 gd.ga.un_220
  0x0c046407, 0x2100120e, 0x0a0411af, 0x0f002904,   // lg.fi.sv_432 ur.fa.un_550  ro.ru.mk_655 sl.lv.un_320
  // [0110]
  0x0700040e, 0x64685555, 0x35001a04, 0x00002101,   // ru.bg.un_550 rw.ig.lg_442  tl.zu.un_320 jw.un.un_200
  0x170a0708, 0x55686407, 0x0e000604, 0x00002906,   // bg.mk.sr_443 lg.ig.rw_432  de.is.un_320 sl.un.un_400
  0x05311ba4, 0x1f2d09a9, 0x2a186b0c, 0x00002b2d,   // tr.az.fr_433 pl.sk.cy_544  ceb.ga.mt_543 vi.un.un_A00
  0x0706310c, 0x16002908, 0x20005304, 0x64680412,   // az.de.it_543 sl.hr.un_430  ht.sq.un_320 fi.ig.lg_654
  // [0120]
  0x0000080a, 0x68004a22, 0x0d01030c, 0x1c000b02,   // no.un.un_500 yo.ig.un_870  nl.en.cs_543 es.id.un_220
  0x00006b06, 0x12000c04, 0x0000030f, 0x08110407,   // ceb.un.un_400 sv.hu.un_320  nl.un.un_600 fi.ro.no_432
  0x16002904, 0x00006815, 0x0c080e0d, 0x1800211a,   // sl.hr.un_320 ig.un.un_700  is.no.sv_554 fa.ar.un_760
  0x2d040da7, 0x64005509, 0x0c052a05, 0x03005507,   // cs.fi.sk_532 rw.lg.un_440  mt.fr.sv_333 rw.nl.un_420
  // [0130]
  0x0000241c, 0x00000a03, 0x0000242d, 0x00000103,   // yi.un.un_800 pt.un.un_300  yi.un.un_A00 en.un.un_300
  0x0000680a, 0x4a005202, 0x4a006822, 0x4a3f030c,   // ig.un.un_500 ha.yo.un_220  ig.yo.un_870 nl.af.yo_543
  0x0000100f, 0x00004a03, 0x08001022, 0x010306a0,   // lt.un.un_600 yo.un.un_300  be.uk.un_870 de.nl.en_322
  0x0000310a, 0x00000715, 0x20283507, 0x00001015,   // az.un.un_500 bg.un.un_700  zu.sw.sq_432 lt.un.un_700
  // [0140]
  0x023f035a, 0x00002903, 0x0000240a, 0x19000b02,   // nl.af.da_553 sl.un.un_300  yi.un.un_500 es.gl.un_220
  0x10000f0c, 0x190b0aa4, 0x2d000d0e, 0x0d002904,   // lv.lt.un_530 pt.es.gl_433  cs.sk.un_550 sl.cs.un_320
  0x05001004, 0x00000c0f, 0x3f003b02, 0x00000503,   // lt.fr.un_320 sv.un.un_600  so.af.un_220 fr.un.un_300
  0x13040ea0, 0x07080408, 0x0d1c0955, 0x0c00200d,   // is.fi.et_322 ru.uk.bg_443  hi.mr.ne_442 sq.sv.un_540
  // [0150]
  0x00001f15, 0x556b2807, 0x1000110d, 0x06001809,   // cy.un.un_700 sw.ceb.rw_432  ro.be.un_540 ga.de.un_440
  0x00005301, 0x12000e0d, 0x04001711, 0x04000723,   // ht.un.un_200 is.hu.un_540  sr.ru.un_630 bg.ru.un_880
  0x00000106, 0x12002120, 0x12002113, 0x0300280c,   // en.un.un_400 fa.ur.un_850  fa.ur.un_650 sw.nl.un_530
  0x17163202, 0x4a6b6804, 0x00002306, 0x04070a0c,   // bs.hr.sr_222 ig.ceb.yo_332  ca.un.un_400 mk.bg.ru_543
  // [0160]
  0x08000c13, 0x00000a0a, 0x1e1c1fee, 0x08040a0c,   // sv.no.un_650 pt.un.un_500  cy.id.ms_422 mk.ru.uk_543
  0x0c060e07, 0x0a190b04, 0x12006408, 0x00001c01,   // is.de.sv_432 es.gl.pt_332  lg.hu.un_430 id.un.un_200
  0x3f0e05a0, 0x00005503, 0x0000112d, 0x112a010b,   // fr.is.af_322 rw.un.un_300  ro.un.un_A00 en.mt.ro_542
  0x17000a19, 0x00000a06, 0x07000a1a, 0x190b0502,   // mk.sr.un_750 pt.un.un_400  mk.bg.un_760 fr.es.gl_222
  // [0170]
  0x02000808, 0x11002804, 0x00006403, 0x0e080cad,   // no.da.un_430 sw.ro.un_320  lg.un.un_300 sv.no.is_643
  0x00006806, 0x64002805, 0x0d1c095a, 0x21001221,   // ig.un.un_400 sw.lg.un_330  hi.mr.ne_553 ur.fa.un_860
  0x00001f0a, 0x0d000905, 0x0c08020e, 0x040a1704,   // cy.un.un_500 hi.ne.un_330  da.no.sv_555 sr.mk.ru_332
  0x25205207, 0x311e1c04, 0x641e2807, 0x091c1312,   // ha.sq.eu_432 id.ms.az_332  sw.ms.lg_432 bh.mr.hi_654
  // [0180]
  0x01000802, 0x00002d15, 0x18001212, 0x1700110d,   // no.en.un_220 sk.un.un_700  ur.ar.un_640 ro.sr.un_540
  0x0c060404, 0x00003f15, 0x0b230507, 0x1c0913ac,   // fi.de.sv_332 af.un.un_700  fr.ca.es_432 bh.hi.mr_632
  0x00003b0f, 0x083b01a0, 0x08001009, 0x1c0913af,   // so.un.un_600 en.so.no_322  be.uk.un_440 bh.hi.mr_655
  0x033f13ad, 0x3b000c0d, 0x041005a4, 0x27001f05,   // et.af.nl_643 sv.so.un_540  fr.lt.fi_433 cy.gd.un_330
  // [0190]
  0x21001812, 0x19005507, 0x21121812, 0x00005515,   // ar.fa.un_640 rw.gl.un_420  ar.ur.fa_654 rw.un.un_700
  0x21001c08, 0x6400352a, 0x64006b0c, 0x00006e1c,   // id.jw.un_430 zu.lg.un_970  ceb.lg.un_530 hmn.un.un_800
  0x64005514, 0x1b1f27a4, 0x13003b12, 0x6400351a,   // rw.lg.un_660 gd.cy.tr_433  so.et.un_640 zu.lg.un_760
  0x00006b0f, 0x352018a4, 0x033f01a4, 0x0000350f,   // ceb.un.un_600 ga.sq.zu_433  en.af.nl_433 zu.un.un_600
  // [01a0]
  0x040a0705, 0x20271fa0, 0x03003f1a, 0x1f3f27a4,   // bg.mk.ru_333 cy.gd.sq_322  af.nl.un_760 gd.af.cy_433
  0x286435a9, 0x13000412, 0x55006422, 0x122b200c,   // zu.lg.sw_544 fi.et.un_640  lg.rw.un_870 sq.vi.hu_543
  0x0c003504, 0x10000835, 0x03003f2b, 0x00000e03,   // zu.sv.un_320 uk.be.un_A90  af.nl.un_980 is.un.un_300
  0x321617a9, 0x3b006e07, 0x20002807, 0x00006b03,   // sr.hr.bs_544 hmn.so.un_420  sw.sq.un_420 ceb.un.un_300
  // [01b0]
  0x3f0325a7, 0x202304ee, 0x35006408, 0x0000101c,   // eu.nl.af_532 fi.ca.sq_422  lg.zu.un_430 lt.un.un_800
  0x0e0608a4, 0x00002715, 0x00001003, 0x09001f12,   // no.de.is_433 gd.un.un_700  be.un.un_300 cy.pl.un_640
  0x03043f0c, 0x00002703, 0x04002314, 0x00006e24,   // af.fi.nl_543 gd.un.un_300  ca.fi.un_660 hmn.un.un_900
  0x040613a0, 0x131255ee, 0x3f080208, 0x0000060f,   // et.de.fi_322 rw.hu.et_422  da.no.af_443 de.un.un_600
  // [01c0]
  0x0000030a, 0x200304ee, 0x00005201, 0x1800210d,   // nl.un.un_500 fi.nl.sq_422  ha.un.un_200 fa.ar.un_540
  0x1304200c, 0x00000215, 0x3100550d, 0x643f0307,   // sq.fi.et_543 da.un.un_700  rw.az.un_540 nl.af.lg_432
  0x00002506, 0x07000a1b, 0x201904ee, 0x00000303,   // eu.un.un_400 mk.bg.un_770  fi.gl.sq_422 nl.un.un_300
  0x1300010d, 0x00000e0a, 0x00000803, 0x530523a7,   // en.et.un_540 is.un.un_500  no.un.un_300 ca.fr.ht_532
  // [01d0]
  0x03003f05, 0x2d100dad, 0x1a002a07, 0x00000f0f,   // af.nl.un_330 cs.lt.sk_643  mt.tl.un_420 lv.un.un_600
  0x0000311c, 0x010c060c, 0x1f1218ee, 0x0600210c,   // az.un.un_800 de.sv.en_543  ga.hu.cy_422 jw.de.un_530
  0x0b133ba4, 0x162d0d08, 0x311b550c, 0x0723190c,   // so.et.es_433 cs.sk.hr_443  rw.tr.az_543 gl.ca.it_543
  0x00002106, 0x2a1716eb, 0x3f190b09, 0x0800020e,   // jw.un.un_400 hr.sr.mt_662  es.gl.af_444 da.no.un_550
  // [01e0]
  0x1f350107, 0x351a27ad, 0x6400551a, 0x3b1955a0,   // en.zu.cy_432 gd.tl.zu_643  rw.lg.un_760 rw.gl.so_322
  0x0d0913a0, 0x0000201c, 0x1100050d, 0x27003508,   // bh.hi.ne_322 sq.un.un_800  fr.ro.un_540 zu.gd.un_430
  0x00001b15, 0x0000250f, 0x080220ee, 0x081b3fa0,   // tr.un.un_700 eu.un.un_600  sq.da.no_422 af.tr.no_322
  0x00002706, 0x1a0435ac, 0x00003b01, 0x08100413,   // gd.un.un_400 zu.fi.tl_632  so.un.un_200 ru.be.uk_665
  // [01f0]
  0x213501a4, 0x18210107, 0x31001907, 0x2100120c,   // en.zu.jw_433 en.jw.ga_432  gl.az.un_420 ur.fa.un_530
  0x033f0608, 0x18271faf, 0x13030404, 0x0000270a,   // de.af.nl_443 cy.gd.ga_655  fi.nl.et_332 gd.un.un_500
  0x130704a7, 0x0000120a, 0x00006e0a, 0x27210107,   // fi.it.et_532 hu.un.un_500  hmn.un.un_500 en.jw.gd_432
  0x03002004, 0x072004a6, 0x2100350d, 0x00002501,   // sq.nl.un_320 fi.sq.it_521  zu.jw.un_540 eu.un.un_200
  // [0200]
  0x0b0723a4, 0x00003515, 0x070a17ad, 0x20313b07,   // ca.it.es_433 zu.un.un_700  sr.mk.bg_643 so.az.sq_432
  0x10001112, 0x170411ec, 0x00002d06, 0x17080414,   // ro.be.un_640 ro.ru.sr_644  sk.un.un_400 ru.uk.sr_666
  0x04000809, 0x1801270c, 0x00001106, 0x00002b03,   // uk.ru.un_440 gd.en.ga_543  ro.un.un_400 vi.un.un_300
  0x27183508, 0x00000506, 0x31001b0d, 0x0700110c,   // zu.ga.gd_443 fr.un.un_400  tr.az.un_540 ro.bg.un_530
  // [0210]
  0x05210107, 0x29002d13, 0x00000c0a, 0x00000d03,   // en.jw.fr_432 sk.sl.un_650  sv.un.un_500 ne.un.un_300
  0x21181205, 0x0a001719, 0x00002006, 0x0a08040c,   // ur.ar.fa_333 sr.mk.un_750  sq.un.un_400 ru.uk.mk_543
  0x17001602, 0x080410a0, 0x1000080e, 0x171008a0,   // hr.sr.un_220 be.ru.uk_322  uk.be.un_550 uk.be.sr_322
  0x08041705, 0x17000d0d, 0x01002408, 0x06002305,   // sr.ru.uk_333 cs.sr.un_540  yi.iw.un_430 ca.de.un_330
  // [0220]
  0x00002d0f, 0x070417a0, 0x00000c15, 0x3f2b03a0,   // sk.un.un_600 sr.ru.bg_322  sv.un.un_700 nl.vi.af_322
  0x12002d0d, 0x521203ac, 0x10000411, 0x00002b01,   // sk.hu.un_540 nl.hu.ha_632  ru.be.un_630 vi.un.un_200
  0x0308020c, 0x07001120, 0x04001005, 0x00005303,   // da.no.nl_543 ro.bg.un_850  be.ru.un_330 ht.un.un_300
  0x04001019, 0x1c0d0914, 0x00006e0f, 0x04001708,   // be.ru.un_750 hi.ne.mr_666  hmn.un.un_600 sr.ru.un_430
  // [0230]
  0x1b001213, 0x00000a01, 0x211e1caf, 0x00001b0a,   // hu.tr.un_650 pt.un.un_200  id.ms.jw_655 tr.un.un_500
  0x00001603, 0x17000704, 0x070a17a9, 0x0a170712,   // hr.un.un_300 bg.sr.un_320  sr.mk.bg_544 bg.sr.mk_654
  0x01001c04, 0x0000280a, 0x0d000902, 0x0000200f,   // id.en.un_320 sw.un.un_500  hi.ne.un_220 sq.un.un_600
  0x2d000d08, 0x0c082009, 0x00006e06, 0x0000551c,   // cs.sk.un_430 sq.no.sv_444  hmn.un.un_400 rw.un.un_800
  // [0240]
  0x6b043f05, 0x18211212, 0x3f3b04a4, 0x04000812,   // af.fi.ceb_333 ur.fa.ar_654  fi.so.af_433 uk.ru.un_640
  0x0d002d13, 0x04070aec, 0x21181208, 0x04001a19,   // sk.cs.un_650 mk.bg.ru_644  ur.ar.fa_443 tl.fi.un_750
  0x53001a05, 0x6b0403ee, 0x00002803, 0x13003b1b,   // tl.ht.un_330 nl.fi.ceb_422  sw.un.un_300 so.et.un_770
  0x6b3f04ad, 0x042b13ee, 0x1c3b13a0, 0x3f00010d,   // fi.af.ceb_643 et.vi.fi_422  et.so.id_322 en.af.un_540
  // [0250]
  0x13033ba4, 0x1300090e, 0x130d0960, 0x00003124,   // so.nl.et_433 hi.bh.un_550  hi.ne.bh_664 az.un.un_900
  0x3b3f0312, 0x3b002808, 0x00001a1c, 0x0000050f,   // nl.af.so_654 sw.so.un_430  tl.un.un_800 fr.un.un_600
  0x016b3bad, 0x64133fa4, 0x00000515, 0x2d000d14,   // so.ceb.en_643 af.et.lg_433  fr.un.un_700 cs.sk.un_660
  0x0000312d, 0x0a0717ee, 0x00003b24, 0x2d0d3baf,   // az.un.un_A00 sr.bg.mk_422  so.un.un_900 so.cs.sk_655
  // [0260]
  0x21001213, 0x1e4a1c60, 0x3f684a12, 0x163f0355,   // ur.fa.un_650 id.yo.ms_664  yo.ig.af_654 nl.af.hr_442
  0x2800272a, 0x08041005, 0x0100240c, 0x1f001822,   // gd.sw.un_970 be.ru.uk_333  yi.iw.un_530 ga.cy.un_870
  0x3200160e, 0x036e640e, 0x00001b0f, 0x23000304,   // hr.bs.un_550 lg.hmn.nl_555  tr.un.un_600 nl.ca.un_320
  0x643b1ca4, 0x00003b06, 0x00004a15, 0x3b002b05,   // id.so.lg_433 so.un.un_400  yo.un.un_700 vi.so.un_330
  // [0270]
  0x00001a03, 0x0f001007, 0x3f000321, 0x1e1c31af,   // tl.un.un_300 lt.lv.un_420  nl.af.un_860 az.id.ms_655
  0x11040813, 0x04070a11, 0x683f0408, 0x04001713,   // uk.ru.ro_665 mk.bg.ru_653  fi.af.ig_443 sr.ru.un_650
  0x043b1aac, 0x522b3b05, 0x32080c0e, 0x0d1c0910,   // tl.so.fi_632 so.vi.ha_333  sv.no.bs_555 hi.mr.ne_642
  0x043b6b07, 0x1e001804, 0x01002304, 0x1a006b05,   // ceb.so.fi_432 ga.ms.un_320  ca.en.un_320 ceb.tl.un_330
  // [0280]
  0x01270407, 0x2100120d, 0x00003137, 0x0000641c,   // fi.gd.en_432 ur.fa.un_540  az.un.un_B00 lg.un.un_800
  0x0000170f, 0x1c000902, 0x1800210c, 0x1c090d09,   // sr.un.un_600 hi.mr.un_220  fa.ar.un_530 ne.hi.mr_444
  0x3b0313a4, 0x24000111, 0x00002d01, 0x1b033faf,   // et.nl.so_433 iw.yi.un_630  sk.un.un_200 af.nl.tr_655
  0x2400011a, 0x00000703, 0x1b00310c, 0x093b2da7,   // iw.yi.un_760 it.un.un_300  az.tr.un_530 sk.so.pl_532
  // [0290]
  0x17001002, 0x00001715, 0x3200161b, 0x0a071707,   // be.sr.un_220 sr.un.un_700  hr.bs.un_770 sr.bg.mk_432
  0x0000680f, 0x532835ee, 0x09001c07, 0x213b2813,   // ig.un.un_600 zu.sw.ht_422  mr.hi.un_420 sw.so.jw_665
  0x35000c08, 0x03121607, 0x00000306, 0x32001623,   // sv.zu.un_430 hr.hu.nl_432  nl.un.un_400 hr.bs.un_880
  0x12032011, 0x131c2109, 0x211812ec, 0x32001304,   // sq.nl.hu_653 jw.id.et_444  ur.ar.fa_644 et.bs.un_320
  // [02a0]
  0x07000a02, 0x00002a03, 0x09033fad, 0x18001209,   // mk.bg.un_220 mt.un.un_300  af.nl.pl_643 ur.ar.un_440
  0x0000550f, 0x20001b12, 0x52004a0c, 0x0000251c,   // rw.un.un_600 tr.sq.un_640  yo.ha.un_530 eu.un.un_800
  0x19000a12, 0x16293507, 0x08041711, 0x041310a7,   // pt.gl.un_640 zu.sl.hr_432  sr.ru.uk_653 lt.et.fi_532
  0x00003f01, 0x00001f1c, 0x3f001c04, 0x0700171b,   // af.un.un_200 cy.un.un_800  id.af.un_320 sr.bg.un_770
  // [02b0]
  0x13000919, 0x13006b04, 0x02005207, 0x0a000714,   // hi.bh.un_750 ceb.et.un_320  ha.da.un_420 bg.mk.un_660
  0x00004a2d, 0x290d53af, 0x0000020a, 0x08001012,   // yo.un.un_A00 ht.cs.sl_655  da.un.un_500 be.uk.un_640
  0x522b06ee, 0x0c00021a, 0x182a0c0c, 0x29211304,   // de.vi.ha_422 da.sv.un_760  sv.mt.ga_543 et.jw.sl_332
  0x18002714, 0x27001833, 0x10000512, 0x11120704,   // gd.ga.un_660 ga.gd.un_A70  fr.lt.un_640 it.hu.ro_332
  // [02c0]
  0x203b21ec, 0x080a1712, 0x0c002005, 0x00000c06,   // jw.so.sq_644 sr.mk.uk_654  sq.sv.un_330 sv.un.un_400
  0x4a002513, 0x1b000c02, 0x00000d0a, 0x4a0a07a7,   // eu.yo.un_650 sv.tr.un_220  cs.un.un_500 it.pt.yo_532
  0x17002d04, 0x00006b15, 0x121729a4, 0x09001f04,   // sk.sr.un_320 ceb.un.un_700  sl.sr.hu_433 cy.pl.un_320
  0x13180607, 0x05002304, 0x3f000212, 0x041707a7,   // de.ga.et_432 ca.fr.un_320  da.af.un_640 bg.sr.ru_532
  // [02d0]
  0x1800350e, 0x18211207, 0x2b280608, 0x0c121fa9,   // zu.ga.un_550 ur.fa.ar_432  de.sw.vi_443 cy.hu.sv_544
  0x1f523b0b, 0x1c000905, 0x00000624, 0x03063f12,   // so.ha.cy_542 hi.mr.un_330  de.un.un_900 af.de.nl_654
  0x080a07a4, 0x05131eee, 0x20170307, 0x00000603,   // bg.mk.uk_433 ms.et.fr_422  nl.sr.sq_432 de.un.un_300
  0x0000061c, 0x00002915, 0x0708100e, 0x29001609,   // de.un.un_800 sl.un.un_700  be.uk.bg_555 hr.sl.un_440
  // [02e0]
  0x00001f24, 0x17000a05, 0x00000615, 0x04001012,   // cy.un.un_900 mk.sr.un_330  de.un.un_700 lt.fi.un_640
  0x133b1f12, 0x6e6b6804, 0x32171614, 0x1e001c05,   // cy.so.et_654 ig.ceb.hmn_332  hr.sr.bs_666 id.ms.un_330
  0x00001c1c, 0x182035ee, 0x32001723, 0x01001e08,   // mr.un.un_800 zu.sq.ga_422  sr.bs.un_880 ms.en.un_430
  0x0000081c, 0x1c1309ad, 0x29000f21, 0x00003203,   // uk.un.un_800 hi.bh.mr_643  lv.sl.un_860 bs.un.un_300
  // [02f0]
  0x13000d04, 0x0000530f, 0x07272ba7, 0x07080404,   // ne.bh.un_320 ht.un.un_600  vi.gd.it_532 ru.uk.bg_332
  0x0600010d, 0x11000604, 0x315535a7, 0x32001607,   // en.de.un_540 de.ro.un_320  zu.rw.az_532 hr.bs.un_420
  0x24000120, 0x08023fee, 0x1c001e04, 0x1600290d,   // iw.yi.un_850 af.da.no_422  ms.id.un_320 sl.hr.un_540
  0x122118ec, 0x0000041c, 0x0c080213, 0x0a1704ec,   // ar.fa.ur_644 fi.un.un_800  da.no.sv_665 ru.sr.mk_644
  // [0300]
  0x3f080cee, 0x12000e09, 0x1300040d, 0x00000a24,   // sv.no.af_422 is.hu.un_440  fi.et.un_540 mk.un.un_900
  0x021808a4, 0x03003f14, 0x060818a0, 0x0000170a,   // no.ga.da_433 af.nl.un_660  ga.no.de_322 sr.un.un_500
  0x12001812, 0x3f002304, 0x00001f03, 0x00000d15,   // ar.ur.un_640 ca.af.un_320  cy.un.un_300 ne.un.un_700
  0x0e00040c, 0x03000208, 0x0b132355, 0x23000619,   // fi.is.un_530 da.nl.un_430  ca.et.es_442 de.ca.un_750
  // [0310]
  0x21005318, 0x12000413, 0x27002104, 0x00003f0a,   // ht.jw.un_740 fi.hu.un_650  jw.gd.un_320 af.un.un_500
  0x00000b06, 0x08170a08, 0x3f002902, 0x1707040d,   // es.un.un_400 mk.sr.uk_443  sl.af.un_220 ru.bg.sr_554
  0x070a1714, 0x6b001f12, 0x321617a0, 0x02003204,   // sr.mk.bg_666 cy.ceb.un_640  sr.hr.bs_322 bs.da.un_320
  0x1e182707, 0x170229a0, 0x10170aa0, 0x11000612,   // gd.ga.ms_432 sl.da.sr_322  mk.sr.be_322 de.ro.un_640
  // [0320]
  0x04645509, 0x07130407, 0x17005302, 0x2a0c0207,   // rw.lg.fi_444 fi.et.it_432  ht.sr.un_220 da.sv.mt_432
  0x00000c01, 0x00000f01, 0x04071712, 0x24000112,   // sv.un.un_200 lv.un.un_200  sr.bg.ru_654 iw.yi.un_640
  0x19000b05, 0x0400130d, 0x3500041b, 0x100f04a0,   // es.gl.un_330 et.fi.un_540  fi.zu.un_770 fi.lv.lt_322
  0x13000413, 0x0400170e, 0x08020ca4, 0x04005305,   // fi.et.un_650 sr.ru.un_550  sv.da.no_433 ht.fi.un_330
  // [0330]
  0x0e000f07, 0x0c000f08, 0x00001e0a, 0x13046404,   // lv.is.un_420 lv.sv.un_430  ms.un.un_500 lg.fi.et_332
  0x31086b02, 0x32161709, 0x09001308, 0x3f0308a0,   // ceb.no.az_222 sr.hr.bs_444  bh.hi.un_430 no.nl.af_322
  0x17002307, 0x12040ca0, 0x00000d24, 0x0000290a,   // ca.sr.un_420 sv.fi.hu_322  cs.un.un_900 sl.un.un_500
  0x00001801, 0x2d000d12, 0x3f0c0855, 0x27001812,   // ga.un.un_200 cs.sk.un_640  no.sv.af_442 ga.gd.un_640
  // [0340]
  0x01236b04, 0x01002412, 0x31001b0c, 0x2d000d21,   // ceb.ca.en_332 yi.iw.un_640  tr.az.un_530 cs.sk.un_860
  0x32001604, 0x31001b09, 0x0f0b10ac, 0x351a55ac,   // hr.bs.un_320 tr.az.un_440  lt.es.lv_632 rw.tl.zu_632
  0x17000c07, 0x12000507, 0x170413ec, 0x0f003f04,   // sv.sr.un_420 fr.hu.un_420  et.fi.sr_644 af.lv.un_320
  0x0900130c, 0x0d091caf, 0x280c21a0, 0x00000b03,   // bh.hi.un_530 mr.hi.ne_655  jw.sv.sw_322 es.un.un_300
  // [0350]
  0x00002801, 0x0e0c08ad, 0x2100050d, 0x1f2101a0,   // sw.un.un_200 no.sv.is_643  fr.jw.un_540 en.jw.cy_322
  0x09000d0c, 0x03002108, 0x0a285507, 0x32001602,   // ne.hi.un_530 jw.nl.un_430  rw.sw.pt_432 hr.bs.un_220
  0x10000804, 0x01641211, 0x3f1364a9, 0x203229ad,   // uk.be.un_320 hu.lg.en_653  lg.et.af_544 sl.bs.sq_643
  0x2d000d18, 0x0d002d12, 0x64003f1a, 0x0708040e,   // cs.sk.un_740 sk.cs.un_640  af.lg.un_760 ru.uk.bg_555
  // [0360]
  0x17000a04, 0x0000640a, 0x531a1ca0, 0x2d000d19,   // mk.sr.un_320 lg.un.un_500  id.tl.ht_322 cs.sk.un_750
  0x0000060a, 0x00000601, 0x1b645508, 0x31001b12,   // de.un.un_500 de.un.un_200  rw.lg.tr_443 tr.az.un_640
  0x2d000d20, 0x1e005309, 0x0400070e, 0x18002704,   // cs.sk.un_850 ht.ms.un_440  bg.ru.un_550 gd.ga.un_320
  0x10000812, 0x3f002108, 0x53080209, 0x0a0711ee,   // uk.be.un_640 jw.af.un_430  da.no.ht_444 ro.bg.mk_422
  // [0370]
  0x080c6e04, 0x3f00030d, 0x00003506, 0x28002a04,   // hmn.sv.no_332 nl.af.un_540  zu.un.un_400 mt.sw.un_320
  0x1c0d0902, 0x01000609, 0x350713a7, 0x01230708,   // hi.ne.mr_222 de.en.un_440  et.it.zu_532 it.ca.en_443
  0x09001312, 0x07040804, 0x00000b01, 0x1f002904,   // bh.hi.un_640 uk.ru.bg_332  es.un.un_200 sl.cy.un_320
  0x07001212, 0x17001605, 0x04001702, 0x12002122,   // hu.it.un_640 hr.sr.un_330  sr.ru.un_220 fa.ur.un_870
  // [0380]
  0x07005302, 0x00000301, 0x2a131ea0, 0x0000530a,   // ht.it.un_220 nl.un.un_200  ms.et.mt_322 ht.un.un_500
  0x28005513, 0x1b000202, 0x1c0d0909, 0x281e2a07,   // rw.sw.un_650 da.tr.un_220  hi.ne.mr_444 mt.ms.sw_432
  0x050708a0, 0x02070860, 0x08000a0d, 0x08000c1b,   // no.it.fr_322 no.it.da_664  mk.uk.un_540 sv.no.un_770
  0x08000214, 0x322d0d04, 0x07000e04, 0x0a000704,   // da.no.un_660 cs.sk.bs_332  is.it.un_320 bg.mk.un_320
  // [0390]
  0x31001b23, 0x21181212, 0x07080407, 0x35002302,   // tr.az.un_880 ur.ar.fa_654  ru.uk.bg_432 ca.zu.un_220
  0x04170808, 0x040a080d, 0x00000a15, 0x121821ec,   // uk.sr.ru_443 uk.mk.ru_554  mk.un.un_700 fa.ar.ur_644
  0x0a1008a4, 0x04170a04, 0x52213b0c, 0x11170408,   // uk.be.mk_433 mk.sr.ru_332  so.jw.ha_543 ru.sr.ro_443
  0x213b1e04, 0x13090d0c, 0x55005205, 0x00003501,   // ms.so.jw_332 ne.hi.bh_543  ha.rw.un_330 zu.un.un_200
  // [03a0]
  0x04081004, 0x100a070c, 0x13091caf, 0x31001b1a,   // be.uk.ru_332 bg.mk.be_543  mr.hi.bh_655 tr.az.un_760
  0x23001902, 0x55003505, 0x17100a02, 0x10000405,   // gl.ca.un_220 zu.rw.un_330  mk.be.sr_222 fi.lt.un_330
  0x00001f01, 0x00002103, 0x0d002a19, 0x16003207,   // cy.un.un_200 jw.un.un_300  mt.cs.un_750 bs.hr.un_420
  0x062a0411, 0x11006b13, 0x06001102, 0x322a16ec,   // fi.mt.de_653 ceb.ro.un_650  ro.de.un_220 hr.mt.bs_644
  // [03b0]
  0x17080a05, 0x030c0ea0, 0x0f21130c, 0x0d0913ee,   // mk.uk.sr_333 is.sv.nl_322  et.jw.lv_543 bh.hi.ne_422
  0x1e001c23, 0x090711ee, 0x0f0127a0, 0x311b2d07,   // id.ms.un_880 ro.it.pl_422  gd.en.lv_322 sk.tr.az_432
  0x3f000619, 0x6b000c05, 0x04112108, 0x1f001c07,   // de.af.un_750 sv.ceb.un_330  jw.ro.fi_443 id.cy.un_420
  0x1f002808, 0x06000c04, 0x0000190a, 0x17000a07,   // sw.cy.un_430 sv.de.un_320  gl.un.un_500 mk.sr.un_420
  // [03c0]
  0x21000b08, 0x13002920, 0x24000118, 0x01001f02,   // es.jw.un_430 sl.et.un_850  iw.yi.un_740 cy.en.un_220
  0x28002b13, 0x211812a4, 0x17321660, 0x1329110c,   // vi.sw.un_650 ur.ar.fa_433  hr.bs.sr_664 ro.sl.et_543
  0x170a0404, 0x3200210d, 0x550652a4, 0x6b001a22,   // ru.mk.sr_332 jw.bs.un_540  ha.de.rw_433 tl.ceb.un_870
  0x19000b20, 0x040e25ad, 0x17163214, 0x04001314,   // es.gl.un_850 eu.is.fi_643  bs.hr.sr_666 et.fi.un_660
  // [03d0]
  0x0e132aa4, 0x210e0811, 0x29001212, 0x27001802,   // mt.et.is_433 no.is.jw_653  hu.sl.un_640 ga.gd.un_220
  0x52122aa4, 0x2d3f0404, 0x16321708, 0x521c1e0b,   // mt.hu.ha_433 fi.af.sk_332  sr.bs.hr_443 ms.id.ha_542
  0x2700060d, 0x0a0708a4, 0x0f321704, 0x0a100405,   // de.gd.un_540 uk.bg.mk_433  sr.bs.lv_332 ru.be.mk_333
  0x2700180e, 0x08002019, 0x1a033fa4, 0x09000f08,   // ga.gd.un_550 sq.no.un_750  af.nl.tl_433 lv.pl.un_430
  // [03e0]
  0x1b00310e, 0x28003513, 0x2a00121a, 0x00005203,   // az.tr.un_550 zu.sw.un_650  hu.mt.un_760 ha.un.un_300
  0x170f290c, 0x00002a1c, 0x351e28a4, 0x32160914,   // sl.lv.sr_543 mt.un.un_800  sw.ms.zu_433 pl.hr.bs_666
  0x0f0413ad, 0x11182712, 0x1800270d, 0x25001902,   // et.fi.lv_643 gd.ga.ro_654  gd.ga.un_540 gl.eu.un_220
  0x1c211e0c, 0x12002121, 0x3f000314, 0x182112ad,   // ms.jw.id_543 fa.ur.un_860  nl.af.un_660 ur.fa.ar_643
  // [03f0]
  0x21130405, 0x17002908, 0x071104a4, 0x00002524,   // fi.et.jw_333 sl.sr.un_430  ru.ro.bg_433 eu.un.un_900
  0x08021fa9, 0x01080208, 0x2325190b, 0x131e1c14,   // cy.da.no_544 da.no.en_443  gl.eu.ca_542 id.ms.et_666
  0x071008ec, 0x32162aee, 0x28006808, 0x040810ad,   // uk.be.bg_644 mt.hr.bs_422  ig.sw.un_430 be.uk.ru_643
  0x0a0717a4, 0x0e08025a, 0x080c1fee, 0x041b0e07,   // sr.bg.mk_433 da.no.is_553  cy.sv.no_422 is.tr.fi_432

  // [0400]
  0x02000819, 0x00001206, 0x2a002922, 0x0d001c12,   // no.da.un_750 hu.un.un_400  sl.mt.un_870 mr.ne.un_640
  0x03042509, 0x35002905, 0x16000805, 0x0c080204,   // eu.fi.nl_444 sl.zu.un_330  no.hr.un_330 da.no.sv_332
  0x0804170c, 0x0d130955, 0x24000119, 0x2d0d1b12,   // sr.ru.uk_543 hi.bh.ne_442  iw.yi.un_750 tr.cs.sk_654
  0x00003f24, 0x2500011a, 0x1c000312, 0x08020ca9,   // af.un.un_900 en.eu.un_760  nl.id.un_640 sv.da.no_544
  // [0410]
  0x29000c0b, 0x18211204, 0x1b001c04, 0x0600011a,   // sv.sl.un_520 ur.fa.ar_332  id.tr.un_320 en.de.un_760
  0x1a1b03a0, 0x0000350a, 0x2d103207, 0x202a030c,   // nl.tr.tl_322 zu.un.un_500  bs.lt.sk_432 nl.mt.sq_543
  0x06033faf, 0x09001f09, 0x25001314, 0x08000e0c,   // af.nl.de_655 cy.pl.un_440  et.eu.un_660 is.no.un_530
  0x00003b03, 0x3f001b19, 0x07101107, 0x070a1002,   // so.un.un_300 tr.af.un_750  ro.be.bg_432 be.mk.bg_222
  // [0420]
  0x2723050c, 0x12002112, 0x3b001821, 0x0700041a,   // fr.ca.gd_543 fa.ur.un_640  ga.so.un_860 ru.bg.un_760
  0x071711ee, 0x5355280d, 0x08001014, 0x160c2907,   // ro.sr.bg_422 sw.rw.ht_554  be.uk.un_660 sl.sv.hr_432
  0x0000230a, 0x0c080205, 0x28551faf, 0x211e1cad,   // ca.un.un_500 da.no.sv_333  cy.rw.sw_655 id.ms.jw_643
  0x00000606, 0x32161705, 0x321e0304, 0x52001c02,   // de.un.un_400 sr.hr.bs_333  nl.ms.bs_332 id.ha.un_220
  // [0430]
  0x08000208, 0x20321705, 0x3b00190d, 0x29001602,   // da.no.un_430 sr.bs.sq_333  gl.so.un_540 hr.sl.un_220
  0x00001237, 0x64005513, 0x102d0d13, 0x122d0d05,   // ur.un.un_B00 rw.lg.un_650  cs.sk.lt_665 cs.sk.hu_333
  0x090d1cac, 0x4a020d07, 0x0c001f19, 0x131f070c,   // mr.ne.hi_632 cs.da.yo_432  cy.sv.un_750 it.cy.et_543
  0x10002913, 0x643b31a0, 0x3f00031a, 0x09002a0c,   // sl.lt.un_650 az.so.lg_322  nl.af.un_760 mt.pl.un_530
  // [0440]
  0x2000550d, 0x0000270f, 0x1c0913a0, 0x4a0d55ad,   // rw.sq.un_540 gd.un.un_600  bh.hi.mr_322 rw.cs.yo_643
  0x0b20550c, 0x216b2aad, 0x25121b11, 0x2d120da4,   // rw.sq.es_543 mt.ceb.jw_643  tr.hu.eu_653 cs.hu.sk_433
  0x10000712, 0x21001c02, 0x352d1705, 0x08040aa0,   // bg.be.un_640 id.jw.un_220  sr.sk.zu_333 mk.ru.uk_322
  0x00001103, 0x1a006b0b, 0x080407ec, 0x20105504,   // ro.un.un_300 ceb.tl.un_520  bg.ru.uk_644 rw.lt.sq_332
  // [0450]
  0x00000401, 0x00000706, 0x1218210c, 0x2855640c,   // ru.un.un_200 it.un.un_400  fa.ar.ur_543 lg.rw.sw_543
  0x00001c24, 0x1c00090e, 0x28080ead, 0x100804af,   // mr.un.un_900 hi.mr.un_550  is.no.sw_643 ru.uk.be_655
  0x270e0813, 0x0704170c, 0x06100e04, 0x09002d12,   // no.is.gd_665 sr.ru.bg_543  is.lt.de_332 sk.pl.un_640
  0x20004a08, 0x00006803, 0x122d0d0d, 0x09000d13,   // yo.sq.un_430 ig.un.un_300  cs.sk.hu_554 ne.hi.un_650
  // [0460]
  0x190a1f05, 0x180104a7, 0x03006402, 0x55642802,   // cy.pt.gl_333 fi.en.ga_532  lg.nl.un_220 sw.lg.rw_222
  0x05255313, 0x0000071c, 0x125553a7, 0x040708a4,   // ht.eu.fr_665 bg.un.un_800  ht.rw.hu_532 uk.bg.ru_433
  0x12520412, 0x1c090da9, 0x55001c08, 0x181221ec,   // fi.ha.hu_654 ne.hi.mr_544  id.rw.un_430 fa.ur.ar_644
  0x2d0d2911, 0x4a001913, 0x0d000908, 0x3f006408,   // sl.cs.sk_653 gl.yo.un_650  hi.ne.un_430 lg.af.un_430
  // [0470]
  0x21001212, 0x6e2a05ee, 0x00002315, 0x091c0da7,   // ur.fa.un_640 fr.mt.hmn_422  ca.un.un_700 ne.mr.hi_532
  0x1a002d04, 0x12006b05, 0x07000a14, 0x1716320c,   // sk.tl.un_320 ceb.hu.un_330  mk.bg.un_660 bs.hr.sr_543
  0x04070a0d, 0x21001c04, 0x046435a0, 0x3b001905,   // mk.bg.ru_554 id.jw.un_320  zu.lg.fi_322 gl.so.un_330
  0x09001f05, 0x290c0812, 0x00001b06, 0x100f0608,   // cy.pl.un_330 no.sv.sl_654  tr.un.un_400 de.lv.lt_443
  // [0480]
  0x1732165a, 0x27100111, 0x0e000508, 0x1c002102,   // hr.bs.sr_553 en.lt.gd_653  fr.is.un_430 jw.id.un_220
  0x1e1c2114, 0x35551a13, 0x13000c0d, 0x19000b07,   // jw.id.ms_666 tl.rw.zu_665  sv.et.un_540 es.gl.un_420
  0x6b641a0c, 0x1c001604, 0x1c09130e, 0x23002702,   // tl.lg.ceb_543 hr.id.un_320  bh.hi.mr_555 gd.ca.un_220
  0x356b1aa9, 0x13033faf, 0x211e1c08, 0x2118120d,   // tl.ceb.zu_544 af.nl.et_655  id.ms.jw_443 ur.ar.fa_554
  // [0490]
  0x0d09130e, 0x1b003113, 0x04281908, 0x1a1e1c14,   // bh.hi.ne_555 az.tr.un_650  gl.sw.fi_443 id.ms.tl_666
  0x551a64a9, 0x04284a07, 0x211e1c13, 0x08040aee,   // lg.tl.rw_544 yo.sw.fi_432  id.ms.jw_665 mk.ru.uk_422
  0x1e1c21a9, 0x210c080c, 0x281a35a0, 0x21002714,   // jw.id.ms_544 no.sv.jw_543  zu.tl.sw_322 gd.jw.un_660
  0x32001707, 0x0d091305, 0x52001e08, 0x040708ec,   // sr.bs.un_420 bh.hi.ne_333  ms.ha.un_430 uk.bg.ru_644
  // [04a0]
  0x132a075a, 0x0800100e, 0x3b551a09, 0x1716320e,   // it.mt.et_553 be.uk.un_550  tl.rw.so_444 bs.hr.sr_555
  0x21000f04, 0x55003204, 0x1b006b04, 0x02003f0e,   // lv.jw.un_320 bs.rw.un_320  ceb.tr.un_320 af.da.un_550
  0x1b003109, 0x1c001309, 0x06000305, 0x23052d07,   // az.tr.un_440 bh.mr.un_440  nl.de.un_330 sk.fr.ca_432
  0x06006e07, 0x2d0d2905, 0x236e0508, 0x271f0107,   // hmn.de.un_420 sl.cs.sk_333  fr.hmn.ca_443 en.cy.gd_432
  // [04b0]
  0x100806a0, 0x230105ad, 0x12255508, 0x071117a4,   // de.no.lt_322 fr.en.ca_643  rw.eu.hu_443 sr.ro.bg_433
  0x0f0806a6, 0x35645508, 0x4a002a21, 0x1e1c52ee,   // de.no.lv_521 rw.lg.zu_443  mt.yo.un_860 ha.id.ms_422
  0x3b1935ee, 0x1c1a1ea0, 0x53001819, 0x55316809,   // zu.gl.so_422 ms.tl.id_322  ga.ht.un_750 ig.az.rw_444
  0x21090d04, 0x35641ca4, 0x352825ad, 0x19002707,   // cs.pl.jw_332 id.lg.zu_433  eu.sw.zu_643 gd.gl.un_420
  // [04c0]
  0x556b640d, 0x2300050c, 0x080621a0, 0x23190b02,   // lg.ceb.rw_554 fr.ca.un_530  jw.de.no_322 es.gl.ca_222
  0x55311ca4, 0x230a0513, 0x21001218, 0x2300051a,   // id.az.rw_433 fr.pt.ca_665  ur.fa.un_740 fr.ca.un_760
  0x00000e06, 0x0a07170c, 0x191a6b11, 0x01272902,   // is.un.un_400 sr.bg.mk_543  ceb.tl.gl_653 sl.gd.en_222
  0x06000207, 0x041c2112, 0x31353baf, 0x04200804,   // da.de.un_420 jw.id.fi_654  so.zu.az_655 no.sq.fi_332
  // [04d0]
  0x06086e07, 0x55000507, 0x0a081713, 0x190b23af,   // hmn.no.de_432 fr.rw.un_420  sr.uk.mk_665 ca.es.gl_655
  0x05001904, 0x68050607, 0x00001b03, 0x091c0d0b,   // gl.fr.un_320 de.fr.ig_432  tr.un.un_300 ne.mr.hi_542
  0x19000b0e, 0x0400100c, 0x1c5521a4, 0x1b00090c,   // es.gl.un_550 lt.fi.un_530  jw.rw.id_433 pl.tr.un_530
  0x0c3f0305, 0x0d091314, 0x00006e03, 0x1c001311,   // nl.af.sv_333 bh.hi.ne_666  hmn.un.un_300 bh.mr.un_630
  // [04e0]
  0x552305ac, 0x3f00290b, 0x03003f0e, 0x03000807,   // fr.ca.rw_632 sl.af.un_520  af.nl.un_550 no.nl.un_420
  0x2305010c, 0x236e0607, 0x07170aa9, 0x283b1f0d,   // en.fr.ca_543 de.hmn.ca_432  mk.sr.bg_544 cy.so.sw_554
  0x06000a08, 0x32001605, 0x0000051c, 0x171632af,   // pt.de.un_430 hr.bs.un_330  fr.un.un_800 bs.hr.sr_655
  0x081f0608, 0x05001113, 0x3f00031b, 0x6e06280c,   // de.cy.no_443 ro.fr.un_650  nl.af.un_770 sw.de.hmn_543
  // [04f0]
  0x552305ad, 0x1c0913a4, 0x13001108, 0x2100280c,   // fr.ca.rw_643 bh.hi.mr_433  ro.et.un_430 sw.jw.un_530
  0x122118af, 0x0a001723, 0x080c02a4, 0x286e2b07,   // ar.fa.ur_655 sr.mk.un_880  da.sv.no_433 vi.hmn.sw_432
  0x09000d08, 0x00002a24, 0x32002907, 0x3b00520c,   // ne.hi.un_430 mt.un.un_900  sl.bs.un_420 ha.so.un_530
  0x1e005508, 0x17040807, 0x02002707, 0x35005504,   // rw.ms.un_430 uk.ru.sr_432  gd.da.un_420 rw.zu.un_320
  // [0500]
  0x3f1206ad, 0x0c080214, 0x35006414, 0x00001803,   // de.hu.af_643 da.no.sv_666  lg.zu.un_660 ga.un.un_300
  0x21001209, 0x0000031c, 0x1c006b07, 0x0b04050c,   // ur.fa.un_440 nl.un.un_800  ceb.id.un_420 fr.fi.es_543
  0x040a1705, 0x09003b04, 0x1e1c04a9, 0x351c210e,   // sr.mk.ru_333 so.pl.un_320  fi.id.ms_544 jw.id.zu_555
  0x2d002905, 0x171632ee, 0x04002713, 0x3500550d,   // sl.sk.un_330 bs.hr.sr_422  gd.fi.un_650 rw.zu.un_540
  // [0510]
  0x21001c0d, 0x31001b14, 0x64005508, 0x53002102,   // id.jw.un_540 tr.az.un_660  rw.lg.un_430 jw.ht.un_220
  0x27001823, 0x23080208, 0x314a3507, 0x00006415,   // ga.gd.un_880 da.no.ca_443  zu.yo.az_432 lg.un.un_700
  0x043f3109, 0x05000804, 0x190b04ad, 0x0a041108,   // az.af.fi_444 no.fr.un_320  fi.es.gl_643 ro.ru.mk_443
  0x01033f60, 0x1b003120, 0x55006819, 0x2b6b01a9,   // af.nl.en_664 az.tr.un_850  ig.rw.un_750 en.ceb.vi_544
  // [0520]
  0x181b2007, 0x0d1c09ec, 0x1f2912af, 0x120407a0,   // sq.tr.ga_432 hi.mr.ne_644  hu.sl.cy_655 it.fi.hu_322
  0x0c005302, 0x35006819, 0x6b3b1c07, 0x1800270e,   // ht.sv.un_220 ig.zu.un_750  id.so.ceb_432 gd.ga.un_550
  0x17081008, 0x0701270c, 0x18002808, 0x064a3505,   // be.uk.sr_443 gd.en.it_543  sw.ga.un_430 zu.yo.de_333
  0x0d001c13, 0x05004a04, 0x2a000808, 0x0000020f,   // mr.ne.un_650 yo.fr.un_320  no.mt.un_430 da.un.un_600
  // [0530]
  0x2000070c, 0x2b006e07, 0x0602070c, 0x1e1c21a0,   // it.sq.un_530 hmn.vi.un_420  it.da.de_543 jw.id.ms_322
  0x551153ee, 0x35000a12, 0x050b10a0, 0x00000206,   // ht.ro.rw_422 pt.zu.un_640  lt.es.fr_322 da.un.un_400
  0x1b3b310c, 0x06001e04, 0x312518a4, 0x101a0c12,   // az.so.tr_543 ms.de.un_320  ga.eu.az_433 sv.tl.lt_654
  0x09001f13, 0x1b04315a, 0x01000704, 0x17321655,   // cy.pl.un_650 az.fi.tr_553  it.en.un_320 hr.bs.sr_442
  // [0540]
  0x52002904, 0x32162509, 0x321617a4, 0x64351a07,   // sl.ha.un_320 eu.hr.bs_444  sr.hr.bs_433 tl.zu.lg_432
  0x0b13040c, 0x120b040c, 0x2b4a0714, 0x071708ec,   // fi.et.es_543 fi.es.hu_543  it.yo.vi_666 uk.sr.bg_644
  0x2905200c, 0x6400551b, 0x20002a0c, 0x6b020811,   // sq.fr.sl_543 rw.lg.un_770  mt.sq.un_530 no.da.ceb_653
  0x3b003104, 0x2500070d, 0x05002305, 0x00001824,   // az.so.un_320 it.eu.un_540  ca.fr.un_330 ar.un.un_900
  // [0550]
  0x02211c0c, 0x55351b0e, 0x190853ee, 0x0d1c1311,   // id.jw.da_543 tr.zu.rw_555  ht.no.gl_422 bh.mr.ne_653
  0x1e1c6409, 0x1b00310d, 0x3b001021, 0x0d000909,   // lg.id.ms_444 az.tr.un_540  lt.so.un_860 hi.ne.un_440
  0x19000a09, 0x321716a0, 0x1e006404, 0x04001013,   // pt.gl.un_440 hr.sr.bs_322  lg.ms.un_320 be.ru.un_650
  0x09000d07, 0x1b252aa4, 0x1c090d60, 0x19110bee,   // ne.hi.un_420 mt.eu.tr_433  ne.hi.mr_664 es.ro.gl_422
  // [0560]
  0x1b1e1c02, 0x0b0a0cee, 0x070a1709, 0x3200080c,   // id.ms.tr_222 sv.pt.es_422  sr.mk.bg_444 no.bs.un_530
  0x1c005207, 0x00000801, 0x170408a0, 0x3f000708,   // ha.id.un_420 uk.un.un_200  uk.ru.sr_322 it.af.un_430
  0x1221180c, 0x091c0dec, 0x13071212, 0x0e000812,   // ar.fa.ur_543 ne.mr.hi_644  hu.it.et_654 no.is.un_640
  0x2b001c07, 0x12002a07, 0x08000e12, 0x31121b07,   // id.vi.un_420 mt.hu.un_420  is.no.un_640 tr.hu.az_432
  // [0570]
  0x2d080204, 0x0e000608, 0x0c000808, 0x28182702,   // da.no.sk_332 de.is.un_430  no.sv.un_430 gd.ga.sw_222
  0x0b521e07, 0x190b23a0, 0x0c0e02ee, 0x35522a05,   // ms.ha.es_432 ca.es.gl_322  da.is.sv_422 mt.ha.zu_333
  0x0c00081a, 0x2d000d13, 0x00003f0f, 0x252718ee,   // no.sv.un_760 cs.sk.un_650  af.un.un_600 ga.gd.eu_422
  0x25001e04, 0x0d00210d, 0x08020c0c, 0x55643504,   // ms.eu.un_320 jw.cs.un_540  sv.da.no_543 zu.lg.rw_332
  // [0580]
  0x171632a0, 0x04081708, 0x04170aa0, 0x05000204,   // bs.hr.sr_322 sr.uk.ru_443  mk.sr.ru_322 da.fr.un_320
  0x645535a4, 0x10002508, 0x044a2502, 0x31001b19,   // zu.rw.lg_433 eu.lt.un_430  eu.yo.fi_222 tr.az.un_750
  0x641825a7, 0x20001c05, 0x19000b0c, 0x531a6b07,   // eu.ga.lg_532 id.sq.un_330  es.gl.un_530 ceb.tl.ht_432
  0x042b1009, 0x53006b04, 0x0c000f04, 0x00001301,   // lt.vi.fi_444 ceb.ht.un_320  lv.sv.un_320 et.un.un_200
  // [0590]
  0x2500521a, 0x53292da4, 0x09001c13, 0x2b0405a7,   // ha.eu.un_760 sk.sl.ht_433  mr.hi.un_650 fr.fi.vi_532
  0x1000530c, 0x355564af, 0x0c000e04, 0x256413a0,   // ht.lt.un_530 lg.rw.zu_655  is.sv.un_320 et.lg.eu_322
  0x1f001e13, 0x285329a0, 0x0c000805, 0x08001021,   // ms.cy.un_650 sl.ht.sw_322  no.sv.un_330 be.uk.un_860
  0x110d1211, 0x35286404, 0x051f0111, 0x21002504,   // hu.cs.ro_653 lg.sw.zu_332  en.cy.fr_653 eu.jw.un_320
  // [05a0]
  0x642868ee, 0x1e55280c, 0x181e2504, 0x08000223,   // ig.sw.lg_422 sw.rw.ms_543  eu.ms.ga_332 da.no.un_880
  0x09001c09, 0x091c0daf, 0x25005208, 0x00001324,   // mr.hi.un_440 ne.mr.hi_655  ha.eu.un_430 bh.un.un_900
  0x6b042511, 0x18120e5a, 0x00005306, 0x551035a0,   // eu.fi.ceb_653 is.hu.ga_553  ht.un.un_400 zu.lt.rw_322
  0x210c1f0c, 0x2527180c, 0x1b001904, 0x100408a4,   // cy.sv.jw_543 ga.gd.eu_543  gl.tr.un_320 uk.ru.be_433
  // [05b0]
  0x190d0b0c, 0x1300270c, 0x0f080604, 0x051f010c,   // es.cs.gl_543 gd.et.un_530  de.no.lv_332 en.cy.fr_543
  0x0b002304, 0x060e0f0c, 0x08041007, 0x083f06a0,   // ca.es.un_320 lv.is.de_543  be.ru.uk_432 de.af.no_322
  0x10070aa0, 0x19200b12, 0x0f000919, 0x0f0c0804,   // mk.bg.be_322 es.sq.gl_654  pl.lv.un_750 no.sv.lv_332
  0x21001208, 0x0000550a, 0x0c000e1a, 0x06000202,   // ur.fa.un_430 rw.un.un_500  is.sv.un_760 da.de.un_220
  // [05c0]
  0x25121807, 0x092555a7, 0x03003f02, 0x1c111ea7,   // ga.hu.eu_432 rw.eu.pl_532  af.nl.un_220 ms.ro.id_532
  0x0c060807, 0x16092907, 0x0e020fa9, 0x08070a05,   // no.de.sv_432 sl.pl.hr_432  lv.da.is_544 mk.bg.uk_333
  0x532520a4, 0x03063fa4, 0x09350ea0, 0x170a0704,   // sq.eu.ht_433 af.de.nl_433  is.zu.pl_322 bg.mk.sr_332
  0x04002d08, 0x09001c08, 0x09000307, 0x170811ee,   // sk.fi.un_430 mr.hi.un_430  nl.pl.un_420 ro.uk.sr_422
  // [05d0]
  0x06050111, 0x21001202, 0x29000d07, 0x27001f0d,   // en.fr.de_653 ur.fa.un_220  cs.sl.un_420 cy.gd.un_540
  0x1300091b, 0x0f001021, 0x00000d01, 0x1f05010c,   // hi.bh.un_770 lt.lv.un_860  ne.un.un_200 en.fr.cy_543
  0x170407a4, 0x110504ee, 0x0a071702, 0x00002901,   // bg.ru.sr_433 fi.fr.ro_422  sr.bg.mk_222 sl.un.un_200
  0x2b001c12, 0x55001f07, 0x1b063f5a, 0x126435a0,   // id.vi.un_640 cy.rw.un_420  af.de.tr_553 zu.lg.hu_322
  // [05e0]
  0x3b005202, 0x080407a4, 0x213b1f08, 0x2b001c0c,   // ha.so.un_220 bg.ru.uk_433  cy.so.jw_443 id.vi.un_530
  0x0d091c07, 0x0c080e0c, 0x19000b08, 0x35080214,   // mr.hi.ne_432 is.no.sv_543  es.gl.un_430 da.no.zu_666
  0x08000c0d, 0x093235ee, 0x31003507, 0x3b0955af,   // sv.no.un_540 zu.bs.pl_422  zu.az.un_420 rw.pl.so_655
  0x641b35a0, 0x17040707, 0x3b001f05, 0x21000504,   // zu.tr.lg_322 bg.ru.sr_432  cy.so.un_330 fr.jw.un_320
  // [05f0]
  0x52553507, 0x122d0d04, 0x281129af, 0x55683505,   // zu.rw.ha_432 cs.sk.hu_332  sl.ro.sw_655 zu.ig.rw_333
  0x352a31ee, 0x122a0405, 0x68201113, 0x3b002119,   // az.mt.zu_422 fi.mt.hu_333  ro.sq.ig_665 jw.so.un_750
  0x0c00040e, 0x095525a4, 0x1c000d18, 0x35006405,   // fi.sv.un_550 eu.rw.pl_433  ne.mr.un_740 lg.zu.un_330
  0x106e06a4, 0x2811550c, 0x0000230f, 0x1f002702,   // de.hmn.lt_433 rw.ro.sw_543  ca.un.un_600 gd.cy.un_220
  // [0600]
  0x642835a7, 0x35006b04, 0x12182112, 0x321611a0,   // zu.sw.lg_532 ceb.zu.un_320  fa.ar.ur_654 ro.hr.bs_322
  0x18002113, 0x08000705, 0x0a001108, 0x2a00180d,   // fa.ar.un_650 it.no.un_330  ro.mk.un_430 ga.mt.un_540
  0x13122aa4, 0x17000a09, 0x2d1f2708, 0x0700110d,   // mt.hu.et_433 mk.sr.un_440  gd.cy.sk_443 ro.bg.un_540
  0x35000b08, 0x231e1c0c, 0x0e1a6b08, 0x1c002108,   // es.zu.un_430 id.ms.ca_543  ceb.tl.is_443 jw.id.un_430
  // [0610]
  0x19000b09, 0x53002707, 0x1f00270d, 0x17070407,   // es.gl.un_440 gd.ht.un_420  gd.cy.un_540 ru.bg.sr_432
  0x352d0d13, 0x3b5552a7, 0x03005212, 0x3217120e,   // cs.sk.zu_665 ha.rw.so_532  ha.nl.un_640 hu.sr.bs_555
  0x2d000d1a, 0x095511ee, 0x12000e04, 0x08041004,   // cs.sk.un_760 ro.rw.pl_422  is.hu.un_320 be.ru.uk_332
  0x2a002304, 0x00001e06, 0x27312da0, 0x64002813,   // ca.mt.un_320 ms.un.un_400  sk.az.gd_322 sw.lg.un_650
  // [0620]
  0x1a00350e, 0x012d0d0e, 0x17551155, 0x190b0a04,   // zu.tl.un_550 cs.sk.en_555  ro.rw.sr_442 pt.es.gl_332
  0x070411af, 0x11645513, 0x060c07a0, 0x033f2707,   // ro.ru.bg_655 rw.lg.ro_665  it.sv.de_322 gd.af.nl_432
  0x1100550e, 0x3f000307, 0x0a040708, 0x0e04060c,   // rw.ro.un_550 nl.af.un_420  bg.ru.mk_443 de.fi.is_543
  0x080411af, 0x1b003204, 0x0e041e07, 0x033f1f0c,   // ro.ru.uk_655 bs.tr.un_320  ms.fi.is_432 cy.af.nl_543
  // [0630]
  0x04000e04, 0x2d002913, 0x05000104, 0x28643504,   // is.fi.un_320 sl.sk.un_650  en.fr.un_320 zu.lg.sw_332
  0x0000250a, 0x1c0d09a4, 0x17070aa4, 0x04000e02,   // eu.un.un_500 hi.ne.mr_433  mk.bg.sr_433 is.fi.un_220
  0x1707045a, 0x05000b02, 0x0d001c04, 0x201211a0,   // ru.bg.sr_553 es.fr.un_220  mr.ne.un_320 ro.hu.sq_322
  0x1c000d13, 0x00003503, 0x0d1c13ee, 0x1e001c0e,   // ne.mr.un_650 zu.un.un_300  bh.mr.ne_422 id.ms.un_550
  // [0640]
  0x09000d19, 0x6b000213, 0x0a0811a0, 0x6b003b04,   // ne.hi.un_750 da.ceb.un_650  ro.uk.mk_322 so.ceb.un_320
  0x0e020c14, 0x0b0a210c, 0x6e003f08, 0x10170a08,   // sv.da.is_666 jw.pt.es_543  af.hmn.un_430 mk.sr.be_443
  0x12682a08, 0x00004a24, 0x251b1e0c, 0x0000272d,   // mt.ig.hu_443 yo.un.un_900  ms.tr.eu_543 gd.un.un_A00
  0x0a170812, 0x3120010c, 0x6e1f1913, 0x07170a14,   // uk.sr.mk_654 en.sq.az_543  gl.cy.hmn_665 mk.sr.bg_666
  // [0650]
  0x060c0807, 0x0c00022c, 0x52000804, 0x00000e01,   // no.sv.de_432 da.sv.un_990  no.ha.un_320 is.un.un_200
  0x1200050c, 0x1e211caf, 0x060e08a9, 0x1f0511ad,   // fr.hu.un_530 id.jw.ms_655  no.is.de_544 ro.fr.cy_643
  0x06130807, 0x0c001912, 0x0c082307, 0x190b0a05,   // no.et.de_432 gl.sv.un_640  ca.no.sv_432 pt.es.gl_333
  0x04001004, 0x280c550c, 0x1c6b55ad, 0x06006e12,   // be.ru.un_320 rw.sv.sw_543  rw.ceb.id_643 hmn.de.un_640
  // [0660]
  0x16002907, 0x230a19a0, 0x01296bee, 0x55521e0c,   // sl.hr.un_420 gl.pt.ca_322  ceb.sl.en_422 ms.ha.rw_543
  0x0f002302, 0x00003f1c, 0x3216290e, 0x0e020c13,   // ca.lv.un_220 af.un.un_800  sl.hr.bs_555 sv.da.is_665
  0x03000504, 0x12001902, 0x00000201, 0x3b003108,   // fr.nl.un_320 gl.hu.un_220  da.un.un_200 az.so.un_430
  0x6b276e0c, 0x1e1c1fa9, 0x2d0d1909, 0x190523a4,   // hmn.gd.ceb_543 cy.id.ms_544  gl.cs.sk_444 ca.fr.gl_433
  // [0670]
  0x55251c0c, 0x323120a9, 0x0b5223a0, 0x04001313,   // id.eu.rw_543 sq.az.bs_544  ca.ha.es_322 et.fi.un_650
  0x1200180e, 0x3b1c1eee, 0x21131ca6, 0x1200050d,   // ar.ur.un_550 ms.id.so_422  id.et.jw_521 fr.hu.un_540
  0x21181213, 0x033f050c, 0x53132a07, 0x09061fa6,   // ur.ar.fa_665 fr.af.nl_543  mt.et.ht_432 cy.de.pl_521
  0x07100413, 0x00003524, 0x1b1e1c05, 0x0410080c,   // ru.be.bg_665 zu.un.un_900  id.ms.tr_333 uk.be.ru_543
  // [0680]
  0x31006b02, 0x10250404, 0x00000e24, 0x10006b04,   // ceb.az.un_220 fi.eu.lt_332  is.un.un_900 ceb.lt.un_320
  0x1b00060d, 0x0e5235ad, 0x08000413, 0x131b31b3,   // de.tr.un_540 zu.ha.is_643  ru.uk.un_650 az.tr.et_743
  0x1200211b, 0x070a04ee, 0x19000d13, 0x2800180d,   // fa.ur.un_770 ru.mk.bg_422  cs.gl.un_650 ga.sw.un_540
  0x642028a0, 0x0000281c, 0x322d0d08, 0x09000707,   // sw.sq.lg_322 sw.un.un_800  cs.sk.bs_443 it.pl.un_420
  // [0690]
  0x28001302, 0x01000607, 0x1b310608, 0x13001c09,   // et.sw.un_220 de.en.un_420  de.az.tr_443 mr.bh.un_440
  0x00003b1c, 0x2d0d0c09, 0x13000607, 0x2b2718a0,   // so.un.un_800 sv.cs.sk_444  de.et.un_420 ga.gd.vi_322
  0x10070812, 0x07000411, 0x29092da4, 0x3f3b0313,   // uk.bg.be_654 ru.bg.un_630  sk.pl.sl_433 nl.so.af_665
  0x080a17ad, 0x13000422, 0x091c2104, 0x32000d0d,   // sr.mk.uk_643 fi.et.un_870  jw.id.pl_332 cs.bs.un_540
  // [06a0]
  0x28001a13, 0x06003113, 0x11000707, 0x00005315,   // tl.sw.un_650 az.de.un_650  it.ro.un_420 ht.un.un_700
  0x0d320ba0, 0x0a006402, 0x19052107, 0x08021b0c,   // es.bs.cs_322 lg.pt.un_220  jw.fr.gl_432 tr.da.no_543
  0x00001a0a, 0x17272307, 0x2100050c, 0x0207080c,   // tl.un.un_500 ca.gd.sr_432  fr.jw.un_530 no.it.da_543
  0x21292004, 0x18000504, 0x13000d09, 0x0311085a,   // sq.sl.jw_332 fr.ga.un_320  ne.bh.un_440 no.ro.nl_553
  // [06b0]
  0x00006406, 0x0120680c, 0x0a080408, 0x6800080d,   // lg.un.un_400 ig.sq.en_543  ru.uk.mk_443 no.ig.un_540
  0x11350702, 0x160802a4, 0x0703080c, 0x0a53680c,   // it.zu.ro_222 da.no.hr_433  no.nl.it_543 ig.ht.pt_543
  0x1600290b, 0x6408020d, 0x20002908, 0x68005523,   // sl.hr.un_520 da.no.lg_554  sl.sq.un_430 rw.ig.un_880
  0x32000d04, 0x21005202, 0x0207110c, 0x1f1729ee,   // cs.bs.un_320 ha.jw.un_220  ro.it.da_543 sl.sr.cy_422
  // [06c0]
  0x00006824, 0x060e3f55, 0x092d0d60, 0x53063f02,   // ig.un.un_900 af.is.de_442  cs.sk.pl_664 af.de.ht_222
  0x08041008, 0x01000c04, 0x29005313, 0x68000813,   // be.ru.uk_443 sv.en.un_320  ht.sl.un_650 no.ig.un_650
  0x19001102, 0x08020714, 0x3f001e0d, 0x12190b08,   // ro.gl.un_220 it.da.no_666  ms.af.un_540 es.gl.hu_443
  0x290668a9, 0x080c0e07, 0x2d0d01a4, 0x1800120c,   // ig.de.sl_544 is.sv.no_432  en.cs.sk_433 ur.ar.un_530
  // [06d0]
  0x1c002a07, 0x080255ec, 0x68002519, 0x190d0aee,   // mt.id.un_420 rw.da.no_644  eu.ig.un_750 pt.cs.gl_422
  0x0607080c, 0x07080a08, 0x075368a9, 0x1b003123,   // no.it.de_543 mk.uk.bg_443  ig.ht.it_544 az.tr.un_880
  0x10040855, 0x19050b07, 0x08001f07, 0x1c001e34,   // uk.ru.be_442 es.fr.gl_432  cy.no.un_420 ms.id.un_A80
  0x06000111, 0x21001c1a, 0x2b27010c, 0x281610ee,   // en.de.un_630 id.jw.un_760  en.gd.vi_543 lt.hr.sw_422
  // [06e0]
  0x5228550c, 0x211c1e0c, 0x2b641ca4, 0x32005502,   // rw.sw.ha_543 ms.id.jw_543  id.lg.vi_433 rw.bs.un_220
  0x09000d0d, 0x06000113, 0x172d29a0, 0x1007040c,   // cs.pl.un_540 en.de.un_650  sl.sk.sr_322 ru.bg.be_543
  0x0f100807, 0x2d0d09a4, 0x08001712, 0x1c00090c,   // no.lt.lv_432 pl.cs.sk_433  sr.uk.un_640 hi.mr.un_530
  0x13090da9, 0x0d00090e, 0x1e001c1b, 0x521603a0,   // ne.hi.bh_544 hi.ne.un_550  id.ms.un_770 nl.hr.ha_322
  // [06f0]
  0x4a001212, 0x110604a7, 0x3f0b01ad, 0x112009ee,   // hu.yo.un_640 fi.de.ro_532  en.es.af_643 pl.sq.ro_422
  0x050d2107, 0x06000107, 0x12182113, 0x2d090d07,   // jw.cs.fr_432 en.de.un_420  fa.ar.ur_665 cs.pl.sk_432
  0x20000702, 0x12190b13, 0x18001213, 0x0c00131b,   // it.sq.un_220 es.gl.hu_665  ur.ar.un_650 et.sv.un_770
  0x05001908, 0x2b1801a6, 0x1600290e, 0x0a04110c,   // gl.fr.un_430 en.ga.vi_521  sl.hr.un_550 ro.ru.mk_543
  // [0700]
  0x122005a4, 0x1a080a12, 0x31001b22, 0x06000108,   // fr.sq.hu_433 pt.no.tl_654  tr.az.un_870 en.de.un_430
  0x06000c12, 0x131f35ee, 0x1e1c21a4, 0x11000104,   // sv.de.un_640 zu.cy.et_422  jw.id.ms_433 en.ro.un_320
  0x1b0608a0, 0x06080208, 0x00000c1c, 0x25001804,   // no.de.tr_322 da.no.de_443  sv.un.un_800 ga.eu.un_320
  0x251f0504, 0x202135ec, 0x18003504, 0x21042bee,   // fr.cy.eu_332 zu.jw.sq_644  zu.ga.un_320 vi.fi.jw_422
  // [0710]
  0x1e001c0c, 0x250418ad, 0x35046b04, 0x4a52350c,   // id.ms.un_530 ga.fi.eu_643  ceb.fi.zu_332 zu.ha.yo_543
  0x09001c0d, 0x292d03ec, 0x2b0e2104, 0x04060c67,   // mr.hi.un_540 nl.sk.sl_644  jw.is.vi_332 sv.de.fi_775
  0x3f00061b, 0x32000108, 0x2b000a04, 0x04060c0c,   // de.af.un_770 en.bs.un_430  pt.vi.un_320 sv.de.fi_543
  0x1800120d, 0x31001b0e, 0x030c08ee, 0x08200cad,   // ur.ar.un_540 tr.az.un_550  no.sv.nl_422 sv.sq.no_643
  // [0720]
  0x182b0aa0, 0x53000604, 0x1b2906a4, 0x04130c55,   // pt.vi.ga_322 de.ht.un_320  de.sl.tr_433 sv.et.fi_442
  0x013b2d07, 0x1900050e, 0x55356404, 0x0c00080c,   // sk.so.en_432 fr.gl.un_550  lg.zu.rw_332 no.sv.un_530
  0x1a044a12, 0x18190b09, 0x13060c0c, 0x1b645504,   // yo.fi.tl_654 es.gl.ga_444  sv.de.et_543 rw.lg.tr_332
  0x2b006e2a, 0x0d1c1355, 0x0e520804, 0x21001c13,   // hmn.vi.un_970 bh.mr.ne_442  no.ha.is_332 id.jw.un_650
  // [0730]
  0x2d0d12a4, 0x0a1711ec, 0x3f02040c, 0x100f0407,   // hu.cs.sk_433 ro.sr.mk_644  fi.da.af_543 fi.lv.lt_432
  0x08002b13, 0x1a006404, 0x2b0a6807, 0x6800552a,   // vi.no.un_650 lg.tl.un_320  ig.pt.vi_432 rw.ig.un_970
  0x68040aee, 0x27002b34, 0x0c0802ac, 0x0f002507,   // pt.fi.ig_422 vi.gd.un_A80  da.no.sv_632 eu.lv.un_420
  0x1a0a350c, 0x6b190a11, 0x2a00531b, 0x27182107,   // zu.pt.tl_543 pt.gl.ceb_653  ht.mt.un_770 jw.ga.gd_432
  // [0740]
  0x1b003119, 0x190b18ee, 0x016b0604, 0x0408170e,   // az.tr.un_750 ga.es.gl_422  de.ceb.en_332 sr.uk.ru_555
  0x1308180c, 0x0e0a0107, 0x0802050e, 0x0400071b,   // ga.no.et_543 en.pt.is_432  fr.da.no_555 bg.ru.un_770
  0x17161a0c, 0x2100280d, 0x00002024, 0x040817af,   // tl.hr.sr_543 sw.jw.un_540  sq.un.un_900 sr.uk.ru_655
  0x09001307, 0x0b230107, 0x00001b24, 0x026408af,   // bh.hi.un_420 en.ca.es_432  tr.un.un_900 no.lg.da_655
  // [0750]
  0x6b120e05, 0x0d13090d, 0x0a0407a4, 0x2000640c,   // is.hu.ceb_333 hi.bh.ne_554  bg.ru.mk_433 lg.sq.un_530
  0x06002013, 0x18000708, 0x1c10210c, 0x0f001b05,   // sq.de.un_650 it.ga.un_430  jw.lt.id_543 tr.lv.un_330
  0x20002d1a, 0x1c211eaf, 0x01006e02, 0x080213a0,   // sk.sq.un_760 ms.jw.id_655  hmn.en.un_220 et.da.no_322
  0x12003f04, 0x1268640c, 0x2d6413a4, 0x17070a07,   // af.hu.un_320 lg.ig.hu_543  et.lg.sk_433 mk.bg.sr_432
  // [0760]
  0x11003b08, 0x1000041b, 0x2b3b1704, 0x212d0d55,   // so.ro.un_430 ru.be.un_770  sr.so.vi_332 cs.sk.jw_442
  0x1f002504, 0x2d13100c, 0x2300190d, 0x2d1064a4,   // eu.cy.un_320 lt.et.sk_543  gl.ca.un_540 lg.lt.sk_433
  0x6e212b05, 0x04000a13, 0x1b20180c, 0x28060b04,   // vi.jw.hmn_333 mk.ru.un_650  ga.sq.tr_543 es.de.sw_332
  0x1c005204, 0x1f000309, 0x06121bad, 0x011a6ba0,   // ha.id.un_320 nl.cy.un_440  tr.hu.de_643 ceb.tl.en_322
  // [0770]
  0x3b3119a9, 0x1710080b, 0x13001a04, 0x200f29a4,   // gl.az.so_544 uk.be.sr_542  tl.et.un_320 sl.lv.sq_433
  0x2d001014, 0x0d0913af, 0x01200da6, 0x2d0d1bee,   // lt.sk.un_660 bh.hi.ne_655  cs.sq.en_521 tr.cs.sk_422
  0x1f2519a9, 0x07001a09, 0x2000080d, 0x131b2008,   // gl.eu.cy_544 tl.it.un_440  no.sq.un_540 sq.tr.et_443
  0x02000a19, 0x091c0d09, 0x321617ee, 0x12000a0c,   // pt.da.un_750 ne.mr.hi_444  sr.hr.bs_422 pt.hu.un_530
  // [0780]
  0x1c000104, 0x1821120c, 0x0d00091b, 0x29321605,   // en.id.un_320 ur.fa.ar_543  hi.ne.un_770 hr.bs.sl_333
  0x1a003b19, 0x680f0107, 0x29321704, 0x2900170c,   // so.tl.un_750 en.lv.ig_432  sr.bs.sl_332 sr.sl.un_530
  0x0523010c, 0x1c000909, 0x1a080ea0, 0x170a0712,   // en.ca.fr_543 hi.mr.un_440  is.no.tl_322 bg.mk.sr_654
  0x06110107, 0x200d2dac, 0x00001101, 0x09000614,   // en.ro.de_432 sk.cs.sq_632  ro.un.un_200 de.pl.un_660
  // [0790]
  0x296b1a08, 0x0a100708, 0x10001111, 0x020e1305,   // tl.ceb.sl_443 bg.be.mk_443  ro.be.un_630 et.is.da_333
  0x25050704, 0x08000e04, 0x24000113, 0x2d001914,   // it.fr.eu_332 is.no.un_320  iw.yi.un_650 gl.sk.un_660
  0x04006b05, 0x05190b0e, 0x28011802, 0x05000e22,   // ceb.fi.un_330 es.gl.fr_555  ga.en.sw_222 is.fr.un_870
  0x170a0707, 0x3b0409a6, 0x6b6410ee, 0x0800200e,   // bg.mk.sr_432 pl.fi.so_521  lt.lg.ceb_422 sq.no.un_550
  // [07a0]
  0x21292da0, 0x1a000c04, 0x182027a4, 0x190b2dee,   // sk.sl.jw_322 sv.tl.un_320  gd.sq.ga_433 sk.es.gl_422
  0x02001a07, 0x2a006b07, 0x00002424, 0x120f5211,   // tl.da.un_420 ceb.mt.un_420  yi.un.un_900 ha.lv.hu_653
  0x29000909, 0x07080e0b, 0x1b003114, 0x32230e07,   // pl.sl.un_440 is.no.it_542  az.tr.un_660 is.ca.bs_432
  0x00001a06, 0x1c000d0d, 0x2a6b1aaf, 0x1f05530b,   // tl.un.un_400 ne.mr.un_540  tl.ceb.mt_655 ht.fr.cy_542
  // [07b0]
  0x0e000c0e, 0x350f1005, 0x0d091c5a, 0x070a170e,   // sv.is.un_550 lt.lv.zu_333  mr.hi.ne_553 sr.mk.bg_555
  0x3b006e08, 0x292d1204, 0x12001105, 0x27002005,   // hmn.so.un_430 hu.sk.sl_332  ro.hu.un_330 sq.gd.un_330
  0x0a0408af, 0x20100fa6, 0x0a001119, 0x3b1e1304,   // uk.ru.mk_655 lv.lt.sq_521  ro.mk.un_750 et.ms.so_332
  0x18002708, 0x0f160da0, 0x011f120c, 0x0800100d,   // gd.ga.un_430 cs.hr.lv_322  hu.cy.en_543 be.uk.un_540
  // [07c0]
  0x17002904, 0x05002107, 0x5268200b, 0x00002137,   // sl.sr.un_320 jw.fr.un_420  sq.ig.ha_542 fa.un.un_B00
  0x29080202, 0x19000508, 0x08101107, 0x0a1711af,   // da.no.sl_222 fr.gl.un_430  ro.be.uk_432 ro.sr.mk_655
  0x0a00171b, 0x03001607, 0x170a10a4, 0x04071007,   // sr.mk.un_770 hr.nl.un_420  be.mk.sr_433 be.bg.ru_432
  0x09110d07, 0x03291208, 0x040a0702, 0x0a102507,   // cs.ro.pl_432 hu.sl.nl_443  bg.mk.ru_222 eu.lt.pt_432
  // [07d0]
  0x17080204, 0x1b00311b, 0x030208ec, 0x1f080e04,   // da.no.sr_332 az.tr.un_770  no.da.nl_644 is.no.cy_332
  0x1800050c, 0x09001302, 0x0c1b0e05, 0x1300020e,   // fr.ga.un_530 bh.hi.un_220  is.tr.sv_333 da.et.un_550
  0x31351bee, 0x0000122d, 0x1f0853ee, 0x2b00270c,   // tr.zu.az_422 ur.un.un_A00  ht.no.cy_422 gd.vi.un_530
  0x041c1e12, 0x29110f07, 0x072a11af, 0x0a070412,   // ms.id.fi_654 lv.ro.sl_432  ro.mt.it_655 ru.bg.mk_654
  // [07e0]
  0x10001f07, 0x10001e05, 0x0d000914, 0x04000718,   // cy.lt.un_420 ms.lt.un_330  hi.ne.un_660 bg.ru.un_740
  0x3f002704, 0x1c0913a7, 0x063f0304, 0x1b003112,   // gd.af.un_320 bh.hi.mr_532  nl.af.de_332 az.tr.un_640
  0x18001208, 0x3f0e06a4, 0x23050107, 0x081017ee,   // ur.ar.un_430 de.is.af_433  en.fr.ca_432 sr.be.uk_422
  0x04170a08, 0x17000a1a, 0x00000c03, 0x0704100c,   // mk.sr.ru_443 mk.sr.un_760  sv.un.un_300 be.ru.bg_543
  // [07f0]
  0x0807040e, 0x01203fa0, 0x110417a4, 0x07000a23,   // ru.bg.uk_555 af.sq.en_322  sr.ru.ro_433 mk.bg.un_880
  0x11040713, 0x64003504, 0x080717a9, 0x212701ee,   // bg.ru.ro_665 zu.lg.un_320  sr.bg.uk_544 en.gd.jw_422
  0x05002012, 0x13080ca0, 0x2a00072a, 0x2000051a,   // sq.fr.un_640 sv.no.et_322  it.mt.un_970 fr.sq.un_760
  0x131b0ca0, 0x1b001319, 0x28002018, 0x09001213,   // sv.tr.et_322 et.tr.un_750  sq.sw.un_740 hu.pl.un_650

  // [0800]
  0x08022aee, 0x1a0c290d, 0x2100050e, 0x35005222,   // mt.da.no_422 sl.sv.tl_554  fr.jw.un_550 ha.zu.un_870
  0x27001e07, 0x040810a4, 0x08212008, 0x0f1c1fa4,   // ms.gd.un_420 be.uk.ru_433  sq.jw.no_443 cy.id.lv_433
  0x1e001c09, 0x2300251a, 0x07113512, 0x0f000519,   // id.ms.un_440 eu.ca.un_760  zu.ro.it_654 fr.lv.un_750
  0x53003f0c, 0x356b68ad, 0x00001606, 0x09000d02,   // af.ht.un_530 ig.ceb.zu_643  hr.un.un_400 ne.hi.un_220
  // [0810]
  0x04351f0b, 0x10283512, 0x1e282a04, 0x32002007,   // cy.zu.fi_542 zu.sw.lt_654  mt.sw.ms_332 sq.bs.un_420
  0x21001222, 0x550410ad, 0x12006407, 0x10682108,   // ur.fa.un_870 lt.fi.rw_643  lg.hu.un_420 jw.ig.lt_443
  0x10040805, 0x2a681fad, 0x03202d07, 0x520a1fa9,   // uk.ru.be_333 cy.ig.mt_643  sk.sq.nl_432 cy.pt.ha_544
  0x01026ba0, 0x3b000808, 0x6827180d, 0x0c00121a,   // ceb.da.en_322 no.so.un_430  ga.gd.ig_554 hu.sv.un_760
  // [0820]
  0x28352004, 0x1c002109, 0x31121ca0, 0x31001912,   // sq.zu.sw_332 jw.id.un_440  id.hu.az_322 gl.az.un_640
  0x4a286409, 0x112d0d0d, 0x23071104, 0x06002507,   // lg.sw.yo_444 cs.sk.ro_554  ro.it.ca_332 eu.de.un_420
  0x121b31ad, 0x1004080d, 0x011e2107, 0x06006b08,   // az.tr.hu_643 uk.ru.be_554  jw.ms.en_432 ceb.de.un_430
  0x12001818, 0x28002014, 0x3b6b1a07, 0x2d190b07,   // ar.ur.un_740 sq.sw.un_660  tl.ceb.so_432 es.gl.sk_432
  // [0830]
  0x12004a04, 0x0000171c, 0x07000a13, 0x2d000305,   // yo.hu.un_320 sr.un.un_800  mk.bg.un_650 nl.sk.un_330
  0x04101260, 0x13000d14, 0x08001007, 0x04001321,   // hu.lt.fi_664 ne.bh.un_660  be.uk.un_420 et.fi.un_860
  0x104a0408, 0x10071208, 0x1f0705ec, 0x0f090da4,   // fi.yo.lt_443 hu.it.lt_443  fr.it.cy_644 cs.pl.lv_433
  0x04081007, 0x112d0d12, 0x0000640f, 0x32052302,   // be.uk.ru_432 cs.sk.ro_654  lg.un.un_600 ca.fr.bs_222
  // [0840]
  0x2b000d04, 0x19231807, 0x1f001a04, 0x25230b02,   // cs.vi.un_320 ga.ca.gl_432  tl.cy.un_320 es.ca.eu_222
  0x12002d09, 0x01002907, 0x07080402, 0x31001b08,   // sk.hu.un_440 sl.en.un_420  ru.uk.bg_222 tr.az.un_430
  0x040a17a4, 0x01003f04, 0x1c00091b, 0x120519a6,   // sr.mk.ru_433 af.en.un_320  hi.mr.un_770 gl.fr.hu_521
  0x10000814, 0x04000c0b, 0x00003f03, 0x321716af,   // uk.be.un_660 sv.fi.un_520  af.un.un_300 hr.sr.bs_655
  // [0850]
  0x0b000a02, 0x0d00090d, 0x13090d0e, 0x0c000412,   // pt.es.un_220 hi.ne.un_540  ne.hi.bh_555 fi.sv.un_640
  0x321723a0, 0x2a3555a9, 0x02000813, 0x0000682d,   // ca.sr.bs_322 rw.zu.mt_544  no.da.un_650 ig.un.un_A00
  0x20001904, 0x0a001714, 0x040710ee, 0x0f3f3507,   // gl.sq.un_320 sr.mk.un_660  be.bg.ru_422 zu.af.lv_432
  0x1b2a31ad, 0x080c0212, 0x03060cee, 0x07000a09,   // az.mt.tr_643 da.sv.no_654  sv.de.nl_422 mk.bg.un_440
  // [0860]
  0x642006a0, 0x1c0d090c, 0x2a000721, 0x35006422,   // de.sq.lg_322 hi.ne.mr_543  it.mt.un_860 lg.zu.un_870
  0x2a0f0714, 0x0e001308, 0x0a001c04, 0x182112a9,   // it.lv.mt_666 et.is.un_430  id.pt.un_320 ur.fa.ar_544
  0x04000612, 0x64001b20, 0x0a11170c, 0x6b005509,   // de.fi.un_640 tr.lg.un_850  sr.ro.mk_543 rw.ceb.un_440
  0x2d060402, 0x09001c14, 0x3552640c, 0x04033f5a,   // fi.de.sk_222 mr.hi.un_660  lg.ha.zu_543 af.nl.fi_553
  // [0870]
  0x08070408, 0x2d000d23, 0x252d5305, 0x3f0304a4,   // ru.bg.uk_443 cs.sk.un_880  ht.sk.eu_333 fi.nl.af_433
  0x06040c07, 0x2800550d, 0x25280907, 0x00000f06,   // sv.fi.de_432 rw.sw.un_540  pl.sw.eu_432 lv.un.un_400
  0x3b000414, 0x10080412, 0x0e0d2d12, 0x043b2555,   // fi.so.un_660 ru.uk.be_654  sk.cs.is_654 eu.so.fi_442
  0x13091ca9, 0x29210909, 0x283b03ee, 0x3f253bad,   // mr.hi.bh_544 pl.jw.sl_444  nl.so.sw_422 so.eu.af_643
  // [0880]
  0x17321604, 0x070a11a0, 0x2d0d2baf, 0x281c3107,   // hr.bs.sr_332 ro.mk.bg_322  vi.cs.sk_655 az.id.sw_432
  0x080a170b, 0x092a280c, 0x25643b11, 0x21521207,   // sr.mk.uk_542 sw.mt.pl_543  so.lg.eu_653 hu.ha.jw_432
  0x3b001109, 0x04005205, 0x20000409, 0x1b002819,   // ro.so.un_440 ha.fi.un_330  fi.sq.un_440 sw.tr.un_750
  0x081004af, 0x1c0d13a0, 0x3f643b11, 0x08000a13,   // ru.be.uk_655 bh.ne.mr_322  so.lg.af_653 mk.uk.un_650
  // [0890]
  0x19000b12, 0x092d0d09, 0x0c216ba6, 0x03041304,   // es.gl.un_640 cs.sk.pl_444  ceb.jw.sv_521 et.fi.nl_332
  0x2528520c, 0x04001021, 0x3f130408, 0x2d000d22,   // ha.sw.eu_543 be.ru.un_860  fi.et.af_443 cs.sk.un_870
  0x0c002d12, 0x211e1c02, 0x3f000108, 0x310e35a0,   // sk.sv.un_640 id.ms.jw_222  en.af.un_430 zu.is.az_322
  0x292a5512, 0x09100d08, 0x18002718, 0x55002823,   // rw.mt.sl_654 cs.lt.pl_443  gd.ga.un_740 sw.rw.un_880
  // [08a0]
  0x0b231908, 0x00001024, 0x284a2105, 0x13000423,   // gl.ca.es_443 lt.un.un_900  jw.yo.sw_333 fi.et.un_880
  0x0a040709, 0x64552807, 0x250604ee, 0x1e521ca4,   // bg.ru.mk_444 sw.rw.lg_432  fi.de.eu_422 id.ha.ms_433
  0x0000190f, 0x17163209, 0x01001304, 0x523f1c04,   // gl.un.un_600 bs.hr.sr_444  et.en.un_320 id.af.ha_332
  0x042d0d08, 0x12045304, 0x04522013, 0x2d005207,   // cs.sk.fi_443 ht.fi.hu_332  sq.ha.fi_665 ha.sk.un_420
  // [08b0]
  0x072519a0, 0x040c1c04, 0x0c001f04, 0x03233b13,   // gl.eu.it_322 id.sv.fi_332  cy.sv.un_320 so.ca.nl_665
  0x0a170808, 0x1c5512a4, 0x2d0d09ee, 0x0b0a290c,   // uk.sr.mk_443 hu.rw.id_433  pl.cs.sk_422 sl.pt.es_543
  0x0a171109, 0x25000705, 0x21001813, 0x31001b1b,   // ro.sr.mk_444 it.eu.un_330  ar.fa.un_650 tr.az.un_770
  0x06006b04, 0x0d2d2912, 0x3b1b1aa9, 0x1600350c,   // ceb.de.un_320 sl.sk.cs_654  tl.tr.so_544 zu.hr.un_530
  // [08c0]
  0x1c090d0c, 0x52353b0c, 0x3528550c, 0x170a0713,   // ne.hi.mr_543 so.zu.ha_543  rw.sw.zu_543 bg.mk.sr_665
  0x11001e04, 0x321716a9, 0x042d0d13, 0x2b20110c,   // ms.ro.un_320 hr.sr.bs_544  cs.sk.fi_665 ro.sq.vi_543
  0x063f03a4, 0x536835ec, 0x0e08020d, 0x080407ad,   // nl.af.de_433 zu.ig.ht_644  da.no.is_554 bg.ru.uk_643
  0x55002809, 0x131035a0, 0x680464a9, 0x20003513,   // sw.rw.un_440 zu.lt.et_322  lg.fi.ig_544 zu.sq.un_650
  // [08d0]
  0x29005308, 0x0400081a, 0x09350ea9, 0x00001e0f,   // ht.sl.un_430 uk.ru.un_760  is.zu.pl_544 ms.un.un_600
  0x13000912, 0x556453a7, 0x282b6b02, 0x25000623,   // hi.bh.un_640 ht.lg.rw_532  ceb.vi.sw_222 de.eu.un_880
  0x04000714, 0x0a1711a4, 0x2b00010c, 0x061e1ca9,   // bg.ru.un_660 ro.sr.mk_433  en.vi.un_530 id.ms.de_544
  0x00000224, 0x35004a04, 0x2309290c, 0x0e643b04,   // da.un.un_900 yo.zu.un_320  sl.pl.ca_543 so.lg.is_332
  // [08e0]
  0x06003b08, 0x2d003508, 0x1b352104, 0x01001b04,   // so.de.un_430 zu.sk.un_430  jw.zu.tr_332 tr.en.un_320
  0x091c210c, 0x07170805, 0x1f000914, 0x0d1c0911,   // jw.id.pl_543 uk.sr.bg_333  pl.cy.un_660 hi.mr.ne_653
  0x1f002a07, 0x28553560, 0x0a041712, 0x285268a4,   // mt.cy.un_420 zu.rw.sw_664  sr.ru.mk_654 ig.ha.sw_433
  0x0b0a190e, 0x20351104, 0x04640f04, 0x55282aa0,   // gl.pt.es_555 ro.zu.sq_332  lv.lg.fi_332 mt.sw.rw_322
  // [08f0]
  0x35285508, 0x4a5228a0, 0x04110aa4, 0x1b006409,   // rw.sw.zu_443 sw.ha.yo_322  mk.ro.ru_433 lg.tr.un_440
  0x684a55ec, 0x31001b2b, 0x190b0aa6, 0x161a2d12,   // rw.yo.ig_644 tr.az.un_980  pt.es.gl_521 sk.tl.hr_654
  0x1b3101a4, 0x17070a04, 0x09000d1a, 0x01000d0d,   // en.az.tr_433 mk.bg.sr_332  ne.hi.un_760 cs.en.un_540
  0x07002504, 0x31001b2c, 0x2b040707, 0x1b5225a7,   // eu.it.un_320 tr.az.un_990  it.fi.vi_432 eu.ha.tr_532
  // [0900]
  0x25001a04, 0x294a255a, 0x1b000804, 0x041310af,   // tl.eu.un_320 eu.yo.sl_553  no.tr.un_320 lt.et.fi_655
  0x0d000112, 0x17000802, 0x0e0f2a08, 0x0c1b310c,   // en.cs.un_640 uk.sr.un_220  mt.lv.is_443 az.tr.sv_543
  0x1b0208a4, 0x25101a0c, 0x1e1c1a05, 0x252313ac,   // no.da.tr_433 tl.lt.eu_543  tl.id.ms_333 et.ca.eu_632
  0x1307530b, 0x64285560, 0x11311bad, 0x0a071705,   // ht.it.et_542 rw.sw.lg_664  tr.az.ro_643 sr.bg.mk_333
  // [0910]
  0x0000202d, 0x251b4a5a, 0x0c1a6b0c, 0x1e1c520c,   // sq.un.un_A00 yo.tr.eu_553  ceb.tl.sv_543 ha.id.ms_543
  0x1e1c6405, 0x0a040707, 0x11136ba4, 0x27350d11,   // lg.id.ms_333 bg.ru.mk_432  ceb.et.ro_433 cs.zu.gd_653
  0x211e1c05, 0x31000b1b, 0x1b000104, 0x172902a7,   // id.ms.jw_333 es.az.un_770  en.tr.un_320 da.sl.sr_532
  0x07171155, 0x353b0dad, 0x1e1c2aa9, 0x3f0306a4,   // ro.sr.bg_442 cs.so.zu_643  mt.id.ms_544 de.nl.af_433
  // [0920]
  0x2a2d6404, 0x05001905, 0x3f032507, 0x09002d0d,   // lg.sk.mt_332 gl.fr.un_330  eu.nl.af_432 sk.pl.un_540
  0x0c00061a, 0x52121807, 0x6b0a01a4, 0x0400070d,   // de.sv.un_760 ga.hu.ha_432  en.pt.ceb_433 bg.ru.un_540
  0x2902040c, 0x201107a9, 0x27000e21, 0x3b4a6411,   // fi.da.sl_543 it.ro.sq_544  is.gd.un_860 lg.yo.so_653
  0x05000112, 0x293216ec, 0x316b1baf, 0x00005524,   // en.fr.un_640 hr.bs.sl_644  tr.ceb.az_655 rw.un.un_900
  // [0930]
  0x052301af, 0x1e1c6b0c, 0x271a1807, 0x00001915,   // en.ca.fr_655 ceb.id.ms_543  ga.tl.gd_432 gl.un.un_700
  0x03003f1b, 0x0c311b07, 0x162d1209, 0x25285508,   // af.nl.un_770 tr.az.sv_432  hu.sk.hr_444 rw.sw.eu_443
  0x04000819, 0x0200081a, 0x25311b0d, 0x2a002d1a,   // uk.ru.un_750 no.da.un_760  tr.az.eu_554 sk.mt.un_760
  0x25311b13, 0x32251b13, 0x0c080202, 0x1a011bad,   // tr.az.eu_665 tr.eu.bs_665  da.no.sv_222 tr.en.tl_643
  // [0940]
  0x09101fad, 0x17002d08, 0x130d1cac, 0x25005312,   // cy.lt.pl_643 sk.sr.un_430  mr.ne.bh_632 ht.eu.un_640
  0x555201a0, 0x0d001909, 0x21011b08, 0x211e1ca4,   // en.ha.rw_322 gl.cs.un_440  tr.en.jw_443 id.ms.jw_433
  0x131a10a7, 0x28640507, 0x18190a04, 0x100f2804,   // lt.tl.et_532 fr.lg.sw_432  pt.gl.ga_332 sw.lv.lt_332
  0x0b001b0d, 0x23000705, 0x2500170d, 0x170d0f08,   // tr.es.un_540 it.ca.un_330  sr.eu.un_540 lv.cs.sr_443
  // [0950]
  0x07170aa4, 0x25190b55, 0x050601ec, 0x6b3b1aee,   // mk.sr.bg_433 es.gl.eu_442  en.de.fr_644 tl.so.ceb_422
  0x16002d08, 0x18002807, 0x19000a02, 0x0c000e02,   // sk.hr.un_430 sw.ga.un_420  pt.gl.un_220 is.sv.un_220
  0x211c1108, 0x1b000a04, 0x190a05a6, 0x6b180107,   // ro.id.jw_443 pt.tr.un_320  fr.pt.gl_521 en.ga.ceb_432
  0x270118a7, 0x1800050d, 0x05190bad, 0x190405a0,   // ga.en.gd_532 fr.ga.un_540  es.gl.fr_643 fr.fi.gl_322
  // [0960]
  0x2500190c, 0x0d001c0d, 0x2b0c2dee, 0x04001022,   // gl.eu.un_530 mr.ne.un_540  sk.sv.vi_422 be.ru.un_870
  0x17002d0d, 0x0d001c07, 0x1c000d12, 0x1c002105,   // sk.sr.un_540 mr.ne.un_420  ne.mr.un_640 jw.id.un_330
  0x0c002904, 0x3f066ba0, 0x1218210b, 0x2b002d0c,   // sl.sv.un_320 ceb.de.af_322  fa.ar.ur_542 sk.vi.un_530
  0x111a4aa0, 0x29172da4, 0x1b00110e, 0x2a001c02,   // yo.tl.ro_322 sk.sr.sl_433  ro.tr.un_550 id.mt.un_220
  // [0970]
  0x0c080604, 0x0d130913, 0x1b003b0c, 0x08020ca0,   // de.no.sv_332 hi.bh.ne_665  so.tr.un_530 sv.da.no_322
  0x0a040702, 0x04070804, 0x09000d14, 0x07001109,   // bg.ru.mk_222 uk.bg.ru_332  ne.hi.un_660 ro.it.un_440
  0x0800041b, 0x00002124, 0x10000813, 0x13040cad,   // ru.uk.un_770 fa.un.un_900  uk.be.un_650 sv.fi.et_643
  0x0d1c090c, 0x12211813, 0x07113b02, 0x1b005214,   // hi.mr.ne_543 ar.fa.ur_665  so.ro.it_222 ha.tr.un_660
  // [0980]
  0x09001c12, 0x18002109, 0x07000d08, 0x07171104,   // mr.hi.un_640 fa.ar.un_440  cs.it.un_430 ro.sr.bg_332
  0x0f171055, 0x11230760, 0x0f1001a0, 0x32000707,   // lt.sr.lv_442 it.ca.ro_664  en.lt.lv_322 it.bs.un_420
  0x18002b07, 0x52003204, 0x10080404, 0x203153ee,   // vi.ga.un_420 bs.ha.un_320  ru.uk.be_332 ht.az.sq_422
  0x53002108, 0x23004a07, 0x1100070e, 0x041710a4,   // jw.ht.un_430 yo.ca.un_420  bg.ro.un_550 be.sr.ru_433
  // [0990]
  0x0000231c, 0x211e1c55, 0x0b0c0812, 0x27006e08,   // ca.un.un_800 id.ms.jw_442  no.sv.es_654 hmn.gd.un_430
  0x1c006e07, 0x32171605, 0x11190b04, 0x1b311ca0,   // hmn.id.un_420 hr.sr.bs_333  es.gl.ro_332 id.az.tr_322
  0x64004a02, 0x1b07310c, 0x1a006e12, 0x0b033fa4,   // yo.lg.un_220 az.it.tr_543  hmn.tl.un_640 af.nl.es_433
  0x20002304, 0x13090daf, 0x32162aa9, 0x11000705,   // ca.sq.un_320 ne.hi.bh_655  mt.hr.bs_544 it.ro.un_330
  // [09a0]
  0x090d1c0c, 0x00001306, 0x0a0717ad, 0x0c003f02,   // mr.ne.hi_543 et.un.un_400  sr.bg.mk_643 af.sv.un_220
  0x1e001c04, 0x64123104, 0x162d29a4, 0x3f311b0e,   // id.ms.un_320 az.hu.lg_332  sl.sk.hr_433 tr.az.af_555
  0x0e000c08, 0x12054a07, 0x03005204, 0x0400060d,   // sv.is.un_430 yo.fr.hu_432  ha.nl.un_320 de.fi.un_540
  0x32161702, 0x08000e0d, 0x04061308, 0x0200080c,   // sr.hr.bs_222 is.no.un_540  et.de.fi_443 no.da.un_530
  // [09b0]
  0x1c130955, 0x03180612, 0x1b005312, 0x19000b13,   // hi.bh.mr_442 de.ga.nl_654  ht.tr.un_640 es.gl.un_650
  0x21001214, 0x06000c0c, 0x313f1f07, 0x6400550c,   // ur.fa.un_660 sv.de.un_530  cy.af.az_432 rw.lg.un_530
  0x0a080702, 0x170a07af, 0x17001013, 0x063f0ca0,   // bg.uk.mk_222 bg.mk.sr_655  lt.sr.un_650 sv.af.de_322
  0x110501a4, 0x0b002104, 0x3f000c05, 0x52003121,   // en.fr.ro_433 jw.es.un_320  sv.af.un_330 az.ha.un_860
  // [09c0]
  0x28000405, 0x24000121, 0x53002302, 0x1c091305,   // fi.sw.un_330 iw.yi.un_860  ca.ht.un_220 bh.hi.mr_333
  0x1c0d090e, 0x061f010b, 0x55256409, 0x27003514,   // hi.ne.mr_555 en.cy.de_542  lg.eu.rw_444 zu.gd.un_660
  0x130f64a0, 0x6b3b52ee, 0x09001c20, 0x063f2512,   // lg.lv.et_322 ha.so.ceb_422  mr.hi.un_850 eu.af.de_654
  0x1f00351b, 0x112305a4, 0x08020c14, 0x552d0d13,   // zu.cy.un_770 fr.ca.ro_433  sv.da.no_666 cs.sk.rw_665
  // [09d0]
  0x09001319, 0x123f3baf, 0x1b001f13, 0x0a190b55,   // bh.hi.un_750 so.af.hu_655  cy.tr.un_650 es.gl.pt_442
  0x3f002109, 0x1f002108, 0x20000407, 0x28002502,   // jw.af.un_440 jw.cy.un_430  fi.sq.un_420 eu.sw.un_220
  0x25005507, 0x06000419, 0x2300030c, 0x213b1c02,   // rw.eu.un_420 fi.de.un_750  nl.ca.un_530 id.so.jw_222
  0x13000609, 0x13090d11, 0x312a0704, 0x04000c0e,   // de.et.un_440 ne.hi.bh_653  it.mt.az_332 sv.fi.un_550
  // [09e0]
  0x0a080405, 0x230113ee, 0x182a01a6, 0x3f033baf,   // ru.uk.mk_333 et.en.ca_422  en.mt.ga_521 so.nl.af_655
  0x171008a4, 0x21001219, 0x20013fa0, 0x2100351a,   // uk.be.sr_433 ur.fa.un_750  af.en.sq_322 zu.jw.un_760
  0x06643507, 0x19000b1a, 0x110a10ad, 0x21001f1a,   // zu.lg.de_432 es.gl.un_760  lt.pt.ro_643 cy.jw.un_760
  0x063f0307, 0x3f0306a9, 0x03003519, 0x16001208,   // nl.af.de_432 de.nl.af_544  zu.nl.un_750 hu.hr.un_430
  // [09f0]
  0x52002104, 0x32125505, 0x080a0708, 0x20003b05,   // jw.ha.un_320 rw.hu.bs_333  bg.mk.uk_443 so.sq.un_330
  0x18122160, 0x3f004a04, 0x09130d12, 0x18002719,   // fa.ur.ar_664 yo.af.un_320  ne.bh.hi_654 gd.ga.un_750
  0x18203b08, 0x122118ac, 0x11002508, 0x25001120,   // so.sq.ga_443 ar.fa.ur_632  eu.ro.un_430 ro.eu.un_850
  0x04000c21, 0x0b0d2d0c, 0x07040813, 0x182701a4,   // sv.fi.un_860 sk.cs.es_543  uk.ru.bg_665 en.gd.ga_433
  // [0a00]
  0x00002515, 0x070804af, 0x18002713, 0x3f060eee,   // eu.un.un_700 ru.uk.bg_655  gd.ga.un_650 is.de.af_422
  0x120c08a0, 0x11002502, 0x25190b02, 0x02003f0c,   // no.sv.hu_322 eu.ro.un_220  es.gl.eu_222 af.da.un_530
  0x090d1c14, 0x18122111, 0x35001c04, 0x25111c12,   // mr.ne.hi_666 fa.ur.ar_653  id.zu.un_320 id.ro.eu_654
  0x0604050c, 0x19120a07, 0x040a1702, 0x11252008,   // fr.fi.de_543 pt.hu.gl_432  sr.mk.ru_222 sq.eu.ro_443
  // [0a10]
  0x25001114, 0x170a1107, 0x040206a9, 0x29001702,   // ro.eu.un_660 ro.mk.sr_432  de.da.fi_544 sr.sl.un_220
  0x08322aa9, 0x00006424, 0x533f0304, 0x5504280c,   // mt.bs.no_544 lg.un.un_900  nl.af.ht_332 sw.fi.rw_543
  0x04100813, 0x21000407, 0x64216b08, 0x2700181a,   // uk.be.ru_665 fi.jw.un_420  ceb.jw.lg_443 ga.gd.un_760
  0x6b002809, 0x321e1c55, 0x25001113, 0x020c0804,   // sw.ceb.un_440 id.ms.bs_442  ro.eu.un_650 no.sv.da_332
  // [0a20]
  0x2a1801a0, 0x1800272a, 0x041711ee, 0x07003b04,   // en.ga.mt_322 gd.ga.un_970  ro.sr.ru_422 so.it.un_320
  0x522032a0, 0x1e211c04, 0x190d2da6, 0x040a1713,   // bs.sq.ha_322 id.jw.ms_332  sk.cs.gl_521 sr.mk.ru_665
  0x0a001722, 0x00001124, 0x3564550d, 0x211c5204,   // sr.mk.un_870 ro.un.un_900  rw.lg.zu_554 ha.id.jw_332
  0x06033f04, 0x040810ec, 0x52002d1a, 0x25001121,   // af.nl.de_332 be.uk.ru_644  sk.ha.un_760 ro.eu.un_860
  // [0a30]
  0x091c0d13, 0x1a0a280d, 0x32002d07, 0x552853a4,   // ne.mr.hi_665 sw.pt.tl_554  sk.bs.un_420 ht.sw.rw_433
  0x25001112, 0x0d091c08, 0x530b1112, 0x6b55640d,   // ro.eu.un_640 mr.hi.ne_443  ro.es.ht_654 lg.rw.ceb_554
  0x13090d13, 0x32001702, 0x04000a08, 0x3235090c,   // ne.hi.bh_665 sr.bs.un_220  mk.ru.un_430 pl.zu.bs_543
  0x53110b07, 0x35002807, 0x552164a9, 0x033f28a4,   // es.ro.ht_432 sw.zu.un_420  lg.jw.rw_544 sw.af.nl_433
  // [0a40]
  0x21005204, 0x0100240b, 0x3253550c, 0x00000b0a,   // ha.jw.un_320 yi.iw.un_520  rw.ht.bs_543 bn.un.un_500
  0x5521350c, 0x08270607, 0x192301a4, 0x06080e07,   // zu.jw.rw_543 de.gd.no_432  en.ca.gl_433 is.no.de_432
  0x201e1c07, 0x4a682807, 0x0b001c02, 0x00002806,   // id.ms.sq_432 sw.ig.yo_432  id.es.un_220 sw.un.un_400
  0x52000d13, 0x5300551a, 0x13210fa4, 0x1c001f05,   // cs.ha.un_650 rw.ht.un_760  lv.jw.et_433 cy.id.un_330
  // [0a50]
  0x13001c04, 0x170a0705, 0x0a17070e, 0x12000702,   // id.et.un_320 bg.mk.sr_333  bg.sr.mk_555 it.hu.un_220
  0x07040aa0, 0x28001e08, 0x32000408, 0x0b4a55ec,   // mk.ru.bg_322 ms.sw.un_430  fi.bs.un_430 rw.yo.es_644
  0x3500280d, 0x32000b04, 0x4a000a0d, 0x08000512,   // sw.zu.un_540 es.bs.un_320  pt.yo.un_540 fr.no.un_640
  0x6b18270d, 0x09002005, 0x68521ea0, 0x07000108,   // gd.ga.ceb_554 sq.pl.un_330  ms.ha.ig_322 en.it.un_430
  // [0a60]
  0x00001b01, 0x190b0a02, 0x27001821, 0x52280b07,   // tr.un.un_200 pt.es.gl_222  ga.gd.un_860 es.sw.ha_432
  0x0a041105, 0x0c1204ad, 0x13001814, 0x080704ad,   // ro.ru.mk_333 fi.hu.sv_643  ga.et.un_660 ru.bg.uk_643
  0x112953a0, 0x1a006b04, 0x0c00061b, 0x55002811,   // ht.sl.ro_322 ceb.tl.un_320  de.sv.un_770 sw.rw.un_630
  0x27001819, 0x550b530c, 0x532d3bee, 0x530b11ec,   // ga.gd.un_750 ht.es.rw_543  so.sk.ht_422 ro.es.ht_644
  // [0a70]
  0x532921ee, 0x04071104, 0x3200280c, 0x210c03ee,   // jw.sl.ht_422 ro.bg.ru_332  sw.bs.un_530 nl.sv.jw_422
  0x2d290d0e, 0x00005224, 0x2723180c, 0x122a20a9,   // cs.sl.sk_555 ha.un.un_900  ga.ca.gd_543 sq.mt.hu_544
  0x1c130902, 0x2d0d0caf, 0x1c033f07, 0x2a0d0908,   // hi.bh.mr_222 sv.cs.sk_655  af.nl.id_432 pl.cs.mt_443
  0x04070a04, 0x18190b05, 0x213b13ad, 0x2d000d0c,   // mk.bg.ru_332 es.gl.ga_333  et.so.jw_643 cs.sk.un_530
  // [0a80]
  0x04071709, 0x08040607, 0x0b000a0e, 0x3f002105,   // sr.bg.ru_444 de.fi.no_432  pt.es.un_550 jw.af.un_330
  0x00000f03, 0x1200210c, 0x3b006e0c, 0x2d290d07,   // lv.un.un_300 fa.ur.un_530  hmn.so.un_530 cs.sl.sk_432
  0x03003f0c, 0x20002812, 0x08001309, 0x1000292a,   // af.nl.un_530 sw.sq.un_640  et.no.un_440 sl.lt.un_970
  0x27101812, 0x00000824, 0x08041104, 0x2800211a,   // ga.lt.gd_654 no.un.un_900  ro.ru.uk_332 jw.sw.un_760
  // [0a90]
  0x2d0d1905, 0x2718010c, 0x04211f05, 0x4a001812,   // gl.cs.sk_333 en.ga.gd_543  cy.jw.fi_333 ga.yo.un_640
  0x271813ee, 0x07040aa9, 0x09005504, 0x0e0412ee,   // et.ga.gd_422 mk.ru.bg_544  rw.pl.un_320 hu.fi.is_422
  0x0c001121, 0x0a041704, 0x1f002704, 0x211c1fa0,   // ro.sv.un_860 sr.ru.mk_332  gd.cy.un_320 cy.id.jw_322
  0x1c1f21ad, 0x133f6ba0, 0x32171608, 0x03003f13,   // jw.cy.id_643 ceb.af.et_322  hr.sr.bs_443 af.nl.un_650
  // [0aa0]
  0x171629a0, 0x09001311, 0x536410a7, 0x6e003b0d,   // sl.hr.sr_322 bh.hi.un_630  lt.lg.ht_532 so.hmn.un_540
  0x06005314, 0x1b536408, 0x090d13ad, 0x08022105,   // ht.de.un_660 lg.ht.tr_443  bh.ne.hi_643 jw.da.no_333
  0x10001702, 0x21002804, 0x19003f0c, 0x0c0806a0,   // sr.be.un_220 sw.jw.un_320  af.gl.un_530 de.no.sv_322
  0x17001f07, 0x08070413, 0x311e29ac, 0x04111705,   // cy.sr.un_420 ru.bg.uk_665  sl.ms.az_632 sr.ro.ru_333
  // [0ab0]
  0x112301a4, 0x64005521, 0x00000315, 0x10000414,   // en.ca.ro_433 rw.lg.un_860  nl.un.un_700 ru.be.un_660
  0x13000a02, 0x181e1c09, 0x55646ba4, 0x1b3f3107,   // pt.et.un_220 id.ms.ga_444  ceb.lg.rw_433 az.af.tr_432
  0x13080202, 0x55006408, 0x1c211eee, 0x1f005202,   // da.no.et_222 lg.rw.un_430  ms.jw.id_422 ha.cy.un_220
  0x53641ea0, 0x00003106, 0x130d0914, 0x03003f07,   // ms.lg.ht_322 az.un.un_400  hi.ne.bh_666 af.nl.un_420
  // [0ac0]
  0x2b00050c, 0x00000203, 0x640501af, 0x32001608,   // fr.vi.un_530 da.un.un_300  en.fr.lg_655 hr.bs.un_430
  0x2a032807, 0x12005312, 0x0a0717af, 0x3b0601ee,   // sw.nl.mt_432 ht.hu.un_640  sr.bg.mk_655 en.de.so_422
  0x351253a0, 0x08000205, 0x0700040c, 0x06000308,   // ht.hu.zu_322 da.no.un_330  ru.bg.un_530 nl.de.un_430
  0x091c0d55, 0x1c214a11, 0x010d2d0c, 0x0800171a,   // ne.mr.hi_442 yo.jw.id_653  sk.cs.en_543 sr.uk.un_760
  // [0ad0]
  0x2a07520c, 0x32171002, 0x1b281308, 0x0000102d,   // ha.it.mt_543 lt.sr.bs_222  et.sw.tr_443 be.un.un_A00
  0x0f000804, 0x551f2809, 0x0f0e06a7, 0x0b214a0c,   // no.lv.un_320 sw.cy.rw_444  de.is.lv_532 yo.jw.es_543
  0x0a001004, 0x2128350c, 0x20682907, 0x21001814,   // be.mk.un_320 zu.sw.jw_543  sl.ig.sq_432 ar.fa.un_660
  0x1800212a, 0x4a00202a, 0x21002819, 0x641b35a4,   // fa.ar.un_970 sq.yo.un_970  sw.jw.un_750 zu.tr.lg_433
  // [0ae0]
  0x0a002b02, 0x64281b55, 0x1b521c07, 0x10000412,   // vi.pt.un_220 tr.sw.lg_442  id.ha.tr_432 ru.be.un_640
  0x4a00551a, 0x55001b05, 0x0e1b2a12, 0x0e1f2a5a,   // rw.yo.un_760 tr.rw.un_330  mt.tr.is_654 mt.cy.is_553
  0x13006819, 0x31071baf, 0x4a2504a4, 0x0a071708,   // ig.et.un_750 tr.it.az_655  fi.eu.yo_433 sr.bg.mk_443
  0x17070a0d, 0x311f3507, 0x0e2a0d07, 0x0c08030b,   // mk.bg.sr_554 zu.cy.az_432  cs.mt.is_432 nl.no.sv_542
  // [0af0]
  0x00004a0f, 0x090d1cec, 0x2a351f12, 0x23190b0d,   // yo.un.un_600 mr.ne.hi_644  cy.zu.mt_654 es.gl.ca_554
  0x0f2a1305, 0x350453a4, 0x1b0e1f07, 0x3b1b060d,   // et.mt.lv_333 ht.fi.zu_433  cy.is.tr_432 de.tr.so_554
  0x3b1b3202, 0x0e001814, 0x2d0d210c, 0x53552804,   // bs.tr.so_222 ga.is.un_660  jw.cs.sk_543 sw.rw.ht_332
  0x1a286455, 0x2a001108, 0x25005202, 0x2d04680c,   // lg.sw.tl_442 ro.mt.un_430  ha.eu.un_220 ig.fi.sk_543
  // [0b00]
  0x31051104, 0x251f0107, 0x0652350c, 0x21281c0c,   // ro.fr.az_332 en.cy.eu_432  zu.ha.de_543 id.sw.jw_543
  0x2d6435a4, 0x1200181a, 0x2a006e07, 0x6400680d,   // zu.lg.sk_433 ar.ur.un_760  hmn.mt.un_420 ig.lg.un_540
  0x3b1e1c04, 0x352821a0, 0x04001705, 0x190b0a14,   // id.ms.so_332 jw.sw.zu_322  sr.ru.un_330 pt.es.gl_666
  0x11080705, 0x321b3155, 0x2568060c, 0x1b090d07,   // bg.uk.ro_333 az.tr.bs_442  de.ig.eu_543 cs.pl.tr_432
  // [0b10]
  0x11001602, 0x0a0711af, 0x31001b07, 0x3b1025a4,   // hr.ro.un_220 ro.bg.mk_655  tr.az.un_420 eu.lt.so_433
  0x00003206, 0x201e2104, 0x2d0d520c, 0x2d0d1005,   // bs.un.un_400 jw.ms.sq_332  ha.cs.sk_543 lt.cs.sk_333
  0x16321704, 0x1c211ea9, 0x356455af, 0x17000a14,   // sr.bs.hr_332 ms.jw.id_544  rw.lg.zu_655 mk.sr.un_660
  0x050711ee, 0x1b112aaf, 0x08070a04, 0x0a006404,   // ro.it.fr_422 mt.ro.tr_655  mk.bg.uk_332 lg.pt.un_320
  // [0b20]
  0x0e004a0e, 0x07000a04, 0x081707a4, 0x55642504,   // yo.is.un_550 mk.bg.un_320  bg.sr.uk_433 eu.lg.rw_332
  0x64000302, 0x00000f2d, 0x0708110c, 0x0000291c,   // nl.lg.un_220 lv.un.un_A00  ro.uk.bg_543 sl.un.un_800
  0x233555ee, 0x52133ba0, 0x6435550e, 0x09001c0c,   // rw.zu.ca_422 so.et.ha_322  rw.zu.lg_555 mr.hi.un_530
  0x0a170409, 0x200f1308, 0x0a071107, 0x1000040e,   // ru.sr.mk_444 et.lv.sq_443  ro.bg.mk_432 ru.be.un_550
  // [0b30]
  0x1100010d, 0x040a07a0, 0x55643508, 0x55002813,   // en.ro.un_540 bg.mk.ru_322  zu.lg.rw_443 sw.rw.un_650
  0x0a1017a0, 0x27111302, 0x17000a0d, 0x07041108,   // sr.be.mk_322 et.ro.gd_222  mk.sr.un_540 ro.ru.bg_443
  0x16102908, 0x052d0d04, 0x1c090d0b, 0x07001108,   // sl.lt.hr_443 cs.sk.fr_332  ne.hi.mr_542 ro.it.un_430
  0x32173ba0, 0x21001829, 0x11002104, 0x1c091307,   // so.sr.bs_322 ar.fa.un_960  jw.ro.un_320 bh.hi.mr_432
  // [0b40]
  0x0a0704a9, 0x01230b05, 0x1c0d0907, 0x35215505,   // ru.bg.mk_544 es.ca.en_333  hi.ne.mr_432 rw.jw.zu_333
  0x11000b05, 0x12001802, 0x13006b19, 0x4a133b55,   // es.ro.un_330 ga.hu.un_220  ceb.et.un_750 so.et.yo_442
  0x122813ec, 0x3b006b2b, 0x2500130d, 0x00000f24,   // et.sw.hu_644 ceb.so.un_980  et.eu.un_540 lv.un.un_900
  0x1117080c, 0x35000819, 0x11000518, 0x3b6b6412,   // uk.sr.ro_543 no.zu.un_750  fr.ro.un_740 lg.ceb.so_654
  // [0b50]
  0x1a6e200c, 0x08001c05, 0x64033f04, 0x1c081e08,   // sq.hmn.tl_543 id.no.un_330  af.nl.lg_332 ms.no.id_443
  0x033f3b12, 0x3f03080c, 0x270e0812, 0x070a0808,   // so.af.nl_654 no.nl.af_543  no.is.gd_654 uk.mk.bg_443
  0x64005504, 0x130e1b55, 0x3500080d, 0x64003b18,   // rw.lg.un_320 tr.is.et_442  no.zu.un_540 so.lg.un_740
  0x0e030604, 0x0e005304, 0x033f06af, 0x1300092a,   // de.nl.is_332 ht.is.un_320  de.af.nl_655 hi.bh.un_970
  // [0b60]
  0x2d000308, 0x0d000923, 0x033f25a4, 0x640306a4,   // nl.sk.un_430 hi.ne.un_880  eu.af.nl_433 de.nl.lg_433
  0x033f06ee, 0x023f080c, 0x12000e0e, 0x0c080307,   // de.af.nl_422 no.af.da_543  is.hu.un_550 nl.no.sv_432
  0x2d000504, 0x20283ba0, 0x0c000804, 0x03286404,   // fr.sk.un_320 so.sw.sq_322  no.sv.un_320 lg.sw.nl_332
  0x3b006422, 0x2d0d01af, 0x03643ba4, 0x0706010c,   // lg.so.un_870 en.cs.sk_655  so.lg.nl_433 en.de.it_543
  // [0b70]
  0x11070a09, 0x041364a0, 0x3f130c02, 0x040a0713,   // mk.bg.ro_444 lg.et.fi_322  sv.et.af_222 bg.mk.ru_665
  0x64136b07, 0x20280111, 0x0d091ca4, 0x3f060304,   // ceb.et.lg_432 en.sw.sq_653  mr.hi.ne_433 nl.de.af_332
  0x092a06a7, 0x1c00131b, 0x0408070d, 0x08001714,   // de.mt.pl_532 bh.mr.un_770  bg.uk.ru_554 sr.uk.un_660
  0x06033fa4, 0x4a00250d, 0x23002508, 0x13000908,   // af.nl.de_433 eu.yo.un_540  eu.ca.un_430 hi.bh.un_430
  // [0b80]
  0x06355502, 0x02000807, 0x2d0d010c, 0x1f002505,   // rw.zu.de_222 no.da.un_420  en.cs.sk_543 eu.cy.un_330
  0x060c0804, 0x0c000809, 0x0d1309ad, 0x05000108,   // no.sv.de_332 no.sv.un_440  hi.bh.ne_643 en.fr.un_430
  0x00001b1c, 0x1300091a, 0x2d0d01ec, 0x1e1c12ee,   // tr.un.un_800 hi.bh.un_760  en.cs.sk_644 hu.id.ms_422
  0x21002807, 0x18080213, 0x3f000302, 0x23002519,   // sw.jw.un_420 da.no.ga_665  nl.af.un_220 eu.ca.un_750
  // [0b90]
  0x13060c02, 0x0400110d, 0x64005522, 0x32641b05,   // sv.de.et_222 ro.ru.un_540  rw.lg.un_870 tr.lg.bs_333
  0x1c001302, 0x1c0913a9, 0x321935a4, 0x08020c09,   // bh.mr.un_220 bh.hi.mr_544  zu.gl.bs_433 sv.da.no_444
  0x323b2d07, 0x07041708, 0x08026eac, 0x17311107,   // sk.so.bs_432 sr.ru.bg_443  hmn.da.no_632 ro.az.sr_432
  0x10001704, 0x1b100aaf, 0x080407a0, 0x1812210d,   // sr.lt.un_320 pt.lt.tr_655  bg.ru.uk_322 fa.ur.ar_554
  // [0ba0]
  0x19000a1b, 0x06000e08, 0x356455ad, 0x100a170d,   // pt.gl.un_770 is.de.un_430  rw.lg.zu_643 sr.mk.be_554
  0x04170a05, 0x07001208, 0x19230b07, 0x686455a4,   // mk.sr.ru_333 hu.it.un_430  es.ca.gl_432 rw.lg.ig_433
  0x060e2807, 0x07080a12, 0x11003202, 0x08020caf,   // sw.is.de_432 mk.uk.bg_654  bs.ro.un_220 sv.da.no_655
  0x09001902, 0x3f030c04, 0x1805535e, 0x6b213b04,   // gl.pl.un_220 sv.nl.af_332  ht.fr.ga_652 so.jw.ceb_332
  // [0bb0]
  0x20000104, 0x06003b12, 0x2a00060e, 0x2100230c,   // en.sq.un_320 so.de.un_640  de.mt.un_550 ca.jw.un_530
  0x0a170804, 0x13091c60, 0x00001a0f, 0x0300061a,   // uk.sr.mk_332 mr.hi.bh_664  tl.un.un_600 de.nl.un_760
  0x02080e5a, 0x08000421, 0x1c000d02, 0x02000112,   // is.no.da_553 ru.uk.un_860  ne.mr.un_220 en.da.un_640
  0x2900091a, 0x64005505, 0x06001f22, 0x0f2a53a0,   // pl.sl.un_760 rw.lg.un_330  cy.de.un_870 ht.mt.lv_322
  // [0bc0]
  0x3b1364a0, 0x0d181209, 0x3b000c13, 0x05070aa0,   // lg.et.so_322 hu.ga.cs_444  sv.so.un_650 pt.it.fr_322
  0x253528a7, 0x0e0c1107, 0x08020c0e, 0x0e2931a0,   // sw.zu.eu_532 ro.sv.is_432  sv.da.no_555 az.sl.is_322
  0x0c270ea9, 0x0500231b, 0x1e1c20a4, 0x0e00251a,   // is.gd.sv_544 ca.fr.un_770  sq.id.ms_433 eu.is.un_760
  0x0300011a, 0x2700060c, 0x06005514, 0x53002d04,   // en.nl.un_760 de.gd.un_530  rw.de.un_660 sk.ht.un_320
  // [0bd0]
  0x07171107, 0x19062709, 0x11002507, 0x03001304,   // ro.sr.bg_432 gd.de.gl_444  eu.ro.un_420 et.nl.un_320
  0x18211214, 0x041008af, 0x532d0dad, 0x0c070e08,   // ur.fa.ar_666 uk.be.ru_655  cs.sk.ht_643 is.it.sv_443
  0x06080e08, 0x0d001308, 0x271808a0, 0x05012a07,   // is.no.de_443 bh.ne.un_430  no.ga.gd_322 mt.en.fr_432
  0x2d3f0d11, 0x532d0dec, 0x0e1306a4, 0x09202d0c,   // cs.af.sk_653 cs.sk.ht_644  de.et.is_433 sk.sq.pl_543
  // [0be0]
  0x53002d13, 0x532d0d0c, 0x081f18a0, 0x522d53a4,   // sk.ht.un_650 cs.sk.ht_543  ga.cy.no_322 ht.sk.ha_433
  0x1c090dec, 0x0d000904, 0x02050807, 0x0e080609,   // ne.hi.mr_644 hi.ne.un_320  no.fr.da_432 de.no.is_444
  0x3b09110c, 0x13043ba4, 0x2d0d3fa9, 0x2d290909,   // ro.pl.so_543 so.fi.et_433  af.cs.sk_544 pl.sl.sk_444
  0x190a2d14, 0x0c081308, 0x19270104, 0x1000521a,   // sk.pt.gl_666 et.no.sv_443  en.gd.gl_332 ha.lt.un_760
  // [0bf0]
  0x3b006408, 0x043552a4, 0x3b00641a, 0x0e290855,   // lg.so.un_430 ha.zu.fi_433  lg.so.un_760 no.sl.is_442
  0x1800120e, 0x1c0d0905, 0x3b00640c, 0x32092da4,   // ur.ar.un_550 hi.ne.mr_333  lg.so.un_530 sk.pl.bs_433
  0x0a001908, 0x171635a0, 0x1c0e25a6, 0x2d3f3bec,   // gl.pt.un_430 zu.hr.sr_322  eu.is.id_521 so.af.sk_644
  0x4a3b640d, 0x250b19ec, 0x19000a14, 0x091710ad,   // lg.so.yo_554 gl.es.eu_644  pt.gl.un_660 lt.sr.pl_643

  // [0c00]
  0x16292d0c, 0x0d002d22, 0x530405a7, 0x190a5309,   // sk.sl.hr_543 sk.cs.un_870  fr.fi.ht_532 ht.pt.gl_444
  0x53200aa4, 0x06005308, 0x17111007, 0x06110555,   // pt.sq.ht_433 ht.de.un_430  lt.ro.sr_432 fr.ro.de_442
  0x08000213, 0x0e000807, 0x12000e19, 0x32002d08,   // da.no.un_650 no.is.un_420  is.hu.un_750 sk.bs.un_430
  0x683b11ee, 0x04070a13, 0x3f030808, 0x2d530da0,   // ro.so.ig_422 mk.bg.ru_665  no.nl.af_443 cs.ht.sk_322
  // [0c10]
  0x1000081a, 0x07010b08, 0x051b53ec, 0x1c0913ad,   // uk.be.un_760 es.en.it_443  ht.tr.fr_644 bh.hi.mr_643
  0x1103050b, 0x130464ad, 0x1c090d14, 0x1c130905,   // fr.nl.ro_542 lg.fi.et_643  ne.hi.mr_666 hi.bh.mr_333
  0x13643ba9, 0x06000c07, 0x64003b21, 0x0b1918a9,   // so.lg.et_544 sv.de.un_420  so.lg.un_860 ga.gl.es_544
  0x201b3109, 0x171008a9, 0x13046413, 0x6e311ba9,   // az.tr.sq_444 uk.be.sr_544  lg.fi.et_665 tr.az.hmn_544
  // [0c20]
  0x05000604, 0x20236e12, 0x1c000907, 0x3b001a04,   // de.fr.un_320 hmn.ca.sq_654  hi.mr.un_420 tl.so.un_320
  0x091f6b04, 0x061b3ba6, 0x233509a7, 0x16321760,   // ceb.cy.pl_332 so.tr.de_521  pl.zu.ca_532 sr.bs.hr_664
  0x0a071105, 0x201b1c0c, 0x201025a4, 0x07041004,   // ro.bg.mk_333 id.tr.sq_543  eu.lt.sq_433 lt.fi.it_332
  0x162d09a4, 0x0a171007, 0x0c020812, 0x31002007,   // pl.sk.hr_433 be.sr.mk_432  no.da.sv_654 sq.az.un_420
  // [0c30]
  0x02000520, 0x03110511, 0x030205af, 0x081711a7,   // fr.da.un_850 fr.ro.nl_653  fr.da.nl_655 ro.sr.uk_532
  0x11000519, 0x1100050b, 0x0810070b, 0x17000a0e,   // fr.ro.un_750 fr.ro.un_520  bg.be.uk_542 mk.sr.un_550
  0x091c0dad, 0x170a1113, 0x6b551aa4, 0x4a005305,   // ne.mr.hi_643 ro.mk.sr_665  tl.rw.ceb_433 ht.yo.un_330
  0x090d1cad, 0x1c001323, 0x0000532d, 0x04001704,   // mr.ne.hi_643 bh.mr.un_880  ht.un.un_A00 sr.ru.un_320
  // [0c40]
  0x64000104, 0x0d002505, 0x12553507, 0x17000423,   // en.lg.un_320 eu.cs.un_330  zu.rw.hu_432 ru.sr.un_880
  0x1c09120c, 0x53002104, 0x0c110713, 0x35001c07,   // hu.pl.id_543 jw.ht.un_320  it.ro.sv_665 id.zu.un_420
  0x071108a0, 0x1c1035a0, 0x0410080e, 0x09001f2a,   // no.ro.it_322 zu.lt.id_322  uk.be.ru_555 cy.pl.un_970
  0x3b18550c, 0x25521b09, 0x1b0c555a, 0x21551c12,   // rw.ga.so_543 tr.ha.eu_444  rw.sv.tr_553 id.rw.jw_654
  // [0c50]
  0x2864550c, 0x3b21030c, 0x0c4a1105, 0x0c001305,   // rw.lg.sw_543 nl.jw.so_543  ro.yo.sv_333 et.sv.un_330
  0x1c0d09ee, 0x3b28210d, 0x0000531c, 0x2d2305ad,   // hi.ne.mr_422 jw.sw.so_554  ht.un.un_800 fr.ca.sk_643
  0x070a1708, 0x0a00070e, 0x23520705, 0x08001112,   // sr.mk.bg_443 bg.mk.un_550  it.ha.ca_333 ro.uk.un_640
  0x32002909, 0x68003b22, 0x122118ad, 0x10000409,   // sl.bs.un_440 so.ig.un_870  ar.fa.ur_643 ru.be.un_440
  // [0c60]
  0x09531212, 0x11035508, 0x286468ad, 0x10070a04,   // hu.ht.pl_654 rw.nl.ro_443  ig.lg.sw_643 mk.bg.be_332
  0x17071112, 0x1f1101a7, 0x523f3baf, 0x21002021,   // ro.it.sr_654 en.ro.cy_532  so.af.ha_655 sq.jw.un_860
  0x105232a0, 0x3500641b, 0x01002421, 0x521f2509,   // bs.ha.lt_322 lg.zu.un_770  yi.iw.un_860 eu.cy.ha_444
  0x35212304, 0x552052a0, 0x1a5213ec, 0x2d0d09a9,   // ca.jw.zu_332 ha.sq.rw_322  et.ha.tl_644 pl.cs.sk_544
  // [0c70]
  0x190b21a0, 0x6b1e1ca9, 0x523b55af, 0x121b2804,   // jw.es.gl_322 id.ms.ceb_544  rw.so.ha_655 sw.tr.hu_332
  0x3f062da0, 0x203525ad, 0x0c001112, 0x110c070c,   // sk.de.af_322 eu.zu.sq_643  ro.sv.un_640 it.sv.ro_543
  0x643b680c, 0x07000413, 0x35003112, 0x321a6b0c,   // ig.so.lg_543 fi.it.un_650  az.zu.un_640 ceb.tl.bs_543
  0x2d293ba4, 0x3f112dee, 0x32162905, 0x05030809,   // so.sl.sk_433 sk.ro.af_422  sl.hr.bs_333 no.nl.fr_444
  // [0c80]
  0x011105a4, 0x5232170c, 0x2a072509, 0x070c110c,   // fr.ro.en_433 sr.bs.ha_543  eu.it.mt_444 ro.sv.it_543
  0x2d001804, 0x033553ac, 0x53000804, 0x3b2152a4,   // ga.sk.un_320 ht.zu.nl_632  no.ht.un_320 ha.jw.so_433
  0x2a313b0c, 0x08000207, 0x1308020d, 0x063f0305,   // so.az.mt_543 da.no.un_420  da.no.et_554 nl.af.de_333
  0x0d130960, 0x063b01a0, 0x0b00280c, 0x1e033f55,   // hi.bh.ne_664 en.so.de_322  sw.es.un_530 af.nl.ms_442
  // [0c90]
  0x12000d0d, 0x09005204, 0x3f0608af, 0x05201160,   // cs.hu.un_540 ha.pl.un_320  no.de.af_655 ro.sq.fr_664
  0x130e04a7, 0x09003513, 0x0c0208ec, 0x08020aa4,   // fi.is.et_532 zu.pl.un_650  no.da.sv_644 pt.da.no_433
  0x16100da7, 0x21251ca0, 0x10080a02, 0x080c02af,   // cs.lt.hr_532 id.eu.jw_322  mk.uk.be_222 da.sv.no_655
  0x13000d05, 0x6b35280d, 0x286b4a0b, 0x1c3b1eac,   // ne.bh.un_330 sw.zu.ceb_554  yo.ceb.sw_542 ms.so.id_632
  // [0ca0]
  0x21002708, 0x1e1c200c, 0x2d0d68af, 0x53001104,   // gd.jw.un_430 sq.id.ms_543  ig.cs.sk_655 ro.ht.un_320
  0x20002705, 0x12641109, 0x64355204, 0x171632a9,   // gd.sq.un_330 ro.lg.hu_444  ha.zu.lg_332 bs.hr.sr_544
  0x0c082904, 0x55002109, 0x310904a4, 0x1e000223,   // sl.no.sv_332 jw.rw.un_440  fi.pl.az_433 da.ms.un_880
  0x03063f0e, 0x3f000313, 0x02002104, 0x1c0913ee,   // af.de.nl_555 nl.af.un_650  jw.da.un_320 bh.hi.mr_422
  // [0cb0]
  0x07000a08, 0x17040702, 0x2d2b0c02, 0x102b1707,   // mk.bg.un_430 bg.ru.sr_222  sv.vi.sk_222 sr.vi.lt_432
  0x060c0808, 0x231f1902, 0x190b0a08, 0x1e003f05,   // no.sv.de_443 gl.cy.ca_222  pt.es.gl_443 af.ms.un_330
  0x17000a2b, 0x0f00030d, 0x0a000713, 0x1a004a22,   // mk.sr.un_980 nl.lv.un_540  bg.mk.un_650 yo.tl.un_870
  0x0e13040c, 0x04080e04, 0x1000110e, 0x06003514,   // fi.et.is_543 is.no.fi_332  ro.be.un_550 zu.de.un_660
  // [0cc0]
  0x07001107, 0x07170aec, 0x18002707, 0x0a0810a0,   // ro.bg.un_420 mk.sr.bg_644  gd.ga.un_420 be.uk.mk_322
  0x28001305, 0x080a17a9, 0x0a0717a0, 0x07170aa7,   // et.sw.un_330 sr.mk.uk_544  sr.bg.mk_322 mk.sr.bg_532
  0x12001813, 0x32161707, 0x070206ee, 0x1c09130c,   // ar.ur.un_650 sr.hr.bs_432  de.da.it_422 bh.hi.mr_543
  0x2a000209, 0x080c09a4, 0x13000913, 0x021106a0,   // da.mt.un_440 pl.sv.no_433  hi.bh.un_650 de.ro.da_322
  // [0cd0]
  0x1e211c12, 0x081004ad, 0x211218ad, 0x0b0a52a4,   // id.jw.ms_654 ru.be.uk_643  ar.ur.fa_643 ha.pt.es_433
  0x1325090b, 0x13000d19, 0x25000108, 0x17070a14,   // pl.eu.et_542 ne.bh.un_750  en.eu.un_430 mk.bg.sr_666
  0x13250707, 0x1f002707, 0x0b001912, 0x230725a4,   // it.eu.et_432 gd.cy.un_420  gl.es.un_640 eu.it.ca_433
  0x3f112d0c, 0x0a3f0304, 0x09250807, 0x09002d35,   // sk.ro.af_543 nl.af.pt_332  no.eu.pl_432 sk.pl.un_A90
  // [0ce0]
  0x080725a6, 0x09000e12, 0x27000508, 0x0e000c0c,   // eu.it.no_521 is.pl.un_640  fr.gd.un_430 sv.is.un_530
  0x0f09010b, 0x080a1708, 0x1e1c2505, 0x080e0c0c,   // en.pl.lv_542 sr.mk.uk_443  eu.id.ms_333 sv.is.no_543
  0x680f3f11, 0x04001a08, 0x2a006407, 0x3f0b2d0c,   // af.lv.ig_653 tl.fi.un_430  lg.mt.un_420 sk.es.af_543
  0x0e000c14, 0x0d102904, 0x20004a04, 0x3f050da4,   // sv.is.un_660 sl.lt.cs_332  yo.sq.un_320 cs.fr.af_433
  // [0cf0]
  0x17002913, 0x521e0ca0, 0x2d072511, 0x03113faf,   // sl.sr.un_650 sv.ms.ha_322  eu.it.sk_653 af.ro.nl_655
  0x2d6809ad, 0x080417a4, 0x13001c19, 0x09002d2b,   // pl.ig.sk_643 sr.ru.uk_433  mr.bh.un_750 sk.pl.un_980
  0x25001908, 0x0b000708, 0x3f1a6b07, 0x1e1c2514,   // gl.eu.un_430 it.es.un_430  ceb.tl.af_432 eu.id.ms_666
  0x0a17110c, 0x07006404, 0x09070da4, 0x091e25a4,   // ro.sr.mk_543 lg.it.un_320  cs.it.pl_433 eu.ms.pl_433
  // [0d00]
  0x0c080207, 0x052d01a4, 0x070a17ec, 0x0600092b,   // da.no.sv_432 en.sk.fr_433  sr.mk.bg_644 pl.de.un_980
  0x0d1c1312, 0x2d11030d, 0x041707a4, 0x060501a0,   // bh.mr.ne_654 nl.ro.sk_554  bg.sr.ru_433 en.fr.de_322
  0x2d093f12, 0x3f090d07, 0x53002807, 0x13000923,   // af.pl.sk_654 cs.pl.af_432  sw.ht.un_420 hi.bh.un_880
  0x13251904, 0x1c001319, 0x080c0ea9, 0x040a0805,   // gl.eu.et_332 bh.mr.un_750  is.sv.no_544 uk.mk.ru_333
  // [0d10]
  0x05120a04, 0x6b1c1e0c, 0x29001704, 0x122a64ee,   // pt.hu.fr_332 ms.id.ceb_543  sr.sl.un_320 lg.mt.hu_422
  0x1b1a4a13, 0x285564a0, 0x35001a07, 0x211e1c0d,   // yo.tl.tr_665 lg.rw.sw_322  tl.zu.un_420 id.ms.jw_554
  0x1a000104, 0x1e002102, 0x1c090d02, 0x00000924,   // en.tl.un_320 jw.ms.un_220  ne.hi.mr_222 hi.un.un_900
  0x1f004a02, 0x0a07110d, 0x29000f13, 0x6b001a0d,   // yo.cy.un_220 ro.bg.mk_554  lv.sl.un_650 tl.ceb.un_540
  // [0d20]
  0x6425130c, 0x06002a04, 0x1a0e6405, 0x033f1f55,   // et.eu.lg_543 mt.de.un_320  lg.is.tl_333 cy.af.nl_442
  0x1a1b0504, 0x311b1fa9, 0x2b3b52a0, 0x3100520d,   // fr.tr.tl_332 cy.tr.az_544  ha.so.vi_322 ha.az.un_540
  0x3b2001a4, 0x13001c14, 0x0000520a, 0x3b0419a0,   // en.sq.so_433 mr.bh.un_660  ha.un.un_500 gl.fi.so_322
  0x1a1e1c08, 0x0c0208a7, 0x1f1e1c60, 0x0e001319,   // id.ms.tl_443 no.da.sv_532  id.ms.cy_664 et.is.un_750
  // [0d30]
  0x1b005204, 0x1c080c05, 0x06001f0d, 0x35000f08,   // ha.tr.un_320 sv.no.id_333  cy.de.un_540 lv.zu.un_430
  0x0c00190d, 0x076412ad, 0x063113ee, 0x1f00550d,   // gl.sv.un_540 hu.lg.it_643  et.az.de_422 rw.cy.un_540
  0x0c001904, 0x0d091311, 0x080c5304, 0x4a3f1aa7,   // gl.sv.un_320 bh.hi.ne_653  ht.sv.no_332 tl.af.yo_532
  0x0e000a09, 0x6b001a1a, 0x020c08af, 0x27522504,   // pt.is.un_440 tl.ceb.un_760  no.sv.da_655 eu.ha.gd_332
  // [0d40]
  0x0c000823, 0x1e0f1ca0, 0x2b4a1fa7, 0x1c130907,   // no.sv.un_880 id.lv.ms_322  cy.yo.vi_532 hi.bh.mr_432
  0x131701a4, 0x04000811, 0x092d0d55, 0x07000422,   // en.sr.et_433 uk.ru.un_630  cs.sk.pl_442 ru.bg.un_870
  0x011f6b02, 0x0a1f1955, 0x18001304, 0x080201a0,   // ceb.cy.en_222 gl.cy.pt_442  et.ga.un_320 en.da.no_322
  0x1e211cec, 0x01000304, 0x091218a7, 0x1000110b,   // id.jw.ms_644 nl.en.un_320  ga.hu.pl_532 ro.be.un_520
  // [0d50]
  0x06033f13, 0x0a2a0107, 0x27002807, 0x2a3f3b04,   // af.nl.de_665 en.mt.pt_432  sw.gd.un_420 so.af.mt_332
  0x18000104, 0x1c033f11, 0x050c01a0, 0x170a0702,   // en.ga.un_320 af.nl.id_653  en.sv.fr_322 bg.mk.sr_222
  0x0c006b07, 0x182112a4, 0x190b0aee, 0x00001201,   // ceb.sv.un_420 ur.fa.ar_433  pt.es.gl_422 ur.un.un_200
  0x130301a0, 0x171629a9, 0x0a00071a, 0x53003119,   // en.nl.et_322 sl.hr.sr_544  bg.mk.un_760 az.ht.un_750
  // [0d60]
  0x09061f07, 0x091c0da9, 0x00001706, 0x07000104,   // cy.de.pl_432 ne.mr.hi_544  sr.un.un_400 en.it.un_320
  0x00000424, 0x6800030e, 0x040708a0, 0x04001305,   // fi.un.un_900 nl.ig.un_550  uk.bg.ru_322 et.fi.un_330
  0x35002007, 0x0a10170c, 0x20003504, 0x0c081302,   // sq.zu.un_420 sr.be.mk_543  zu.sq.un_320 et.no.sv_222
  0x06000502, 0x11002d0c, 0x2b001e02, 0x0417100c,   // fr.de.un_220 sk.ro.un_530  ms.vi.un_220 be.sr.ru_543
  // [0d70]
  0x1c291ead, 0x23000107, 0x0410085a, 0x0b1223ec,   // ms.sl.id_643 en.ca.un_420  uk.be.ru_553 ca.hu.es_644
  0x18211211, 0x1c001307, 0x07000402, 0x09000d0e,   // ur.fa.ar_653 bh.mr.un_420  ru.bg.un_220 ne.hi.un_550
  0x0c080211, 0x00004a1c, 0x1c000d07, 0x09001f0c,   // da.no.sv_653 yo.un.un_800  ne.mr.un_420 cy.pl.un_530
  0x0f00100c, 0x00006e2d, 0x1c000d09, 0x1200210d,   // lt.lv.un_530 hmn.un.un_A00  ne.mr.un_440 fa.ur.un_540
  // [0d80]
  0x1300041b, 0x080704ee, 0x21131cee, 0x21001205,   // fi.et.un_770 ru.bg.uk_422  id.et.jw_422 ur.fa.un_330
  0x101704a9, 0x080a07a0, 0x070a1704, 0x03000604,   // ru.sr.be_544 bg.mk.uk_322  sr.mk.bg_332 de.nl.un_320
  0x091c0d12, 0x11000422, 0x031304a7, 0x0f314aa4,   // ne.mr.hi_654 ru.ro.un_870  fi.et.nl_532 yo.az.lv_433
  0x524a1fa9, 0x07000304, 0x3f000e05, 0x0f130e04,   // cy.yo.ha_544 nl.it.un_320  is.af.un_330 is.et.lv_332
  // [0d90]
  0x0e080ca4, 0x2d0d1305, 0x230b050e, 0x0d1c13af,   // sv.no.is_433 et.cs.sk_333  fr.es.ca_555 bh.mr.ne_655
  0x16000d04, 0x16000d08, 0x3b2a0fec, 0x080a0704,   // cs.hr.un_320 cs.hr.un_430  lv.mt.so_644 bg.mk.uk_332
  0x0e001f1b, 0x100a0813, 0x03183fee, 0x08070405,   // cy.is.un_770 uk.mk.be_665  af.ga.nl_422 ru.bg.uk_333
  0x11003b1a, 0x1b041207, 0x1e1c3baf, 0x190a0b14,   // so.ro.un_760 hu.fi.tr_432  so.id.ms_655 es.pt.gl_666
  // [0da0]
  0x03001313, 0x12082104, 0x20101304, 0x211e1c04,   // et.nl.un_650 jw.no.hu_332  et.lt.sq_332 id.ms.jw_332
  0x25230112, 0x0a00170e, 0x1a12680e, 0x2b001c04,   // en.ca.eu_654 sr.mk.un_550  ig.hu.tl_555 id.vi.un_320
  0x0e002808, 0x0900131a, 0x0b000713, 0x17000d04,   // sw.is.un_430 bh.hi.un_760  it.es.un_650 cs.sr.un_320
  0x03281355, 0x3b001f0d, 0x18002711, 0x1100681b,   // et.sw.nl_442 cy.so.un_540  gd.ga.un_630 ig.ro.un_770
  // [0db0]
  0x1b00530d, 0x3f00030e, 0x040810a0, 0x21001114,   // ht.tr.un_540 nl.af.un_550  be.uk.ru_322 ro.jw.un_660
  0x23000a04, 0x03113f0c, 0x271718ec, 0x03071808,   // pt.ca.un_320 af.ro.nl_543  ga.sr.gd_644 ga.it.nl_443
  0x03003f22, 0x050320ee, 0x0d001307, 0x033f05a4,   // af.nl.un_870 sq.nl.fr_422  bh.ne.un_420 fr.af.nl_433
  0x03000608, 0x0f0912ad, 0x2000280d, 0x021b0e05,   // de.nl.un_430 hu.pl.lv_643  sw.sq.un_540 is.tr.da_333
  // [0dc0]
  0x04171008, 0x1e002818, 0x52001c04, 0x040711ec,   // be.sr.ru_443 sw.ms.un_740  id.ha.un_320 ro.bg.ru_644
  0x131c090c, 0x55202813, 0x0800120c, 0x06002302,   // hi.mr.bh_543 sw.sq.rw_665  hu.no.un_530 ca.de.un_220
  0x213f2804, 0x070811a4, 0x1c132755, 0x0f001904,   // sw.af.jw_332 ro.uk.bg_433  gd.et.id_442 gl.lv.un_320
  0x080a1107, 0x6b100755, 0x2118120c, 0x1a00211b,   // ro.mk.uk_432 it.lt.ceb_442  ur.ar.fa_543 jw.tl.un_770
  // [0dd0]
  0x18122112, 0x09005512, 0x0e001f13, 0x0b0a23a9,   // fa.ur.ar_654 rw.pl.un_640  cy.is.un_650 ca.pt.es_544
  0x52001f11, 0x55006808, 0x18000e04, 0x2a00550d,   // cy.ha.un_630 ig.rw.un_430  is.ga.un_320 rw.mt.un_540
  0x00000403, 0x32001609, 0x2a000702, 0x02002805,   // ru.un.un_300 hr.bs.un_440  it.mt.un_220 sw.da.un_330
  0x1e211ca0, 0x110827ad, 0x040807ad, 0x0d001c20,   // id.jw.ms_322 gd.no.ro_643  bg.uk.ru_643 mr.ne.un_850
  // [0de0]
  0x27041f0b, 0x12002123, 0x1b2153a0, 0x25000b08,   // cy.fi.gd_542 fa.ur.un_880  ht.jw.tr_322 es.eu.un_430
  0x1300122b, 0x1c001f1a, 0x28081f04, 0x13001c0e,   // hu.et.un_980 cy.id.un_760  cy.no.sw_332 id.et.un_550
  0x3f1f13ee, 0x0c000204, 0x1b003122, 0x23000419,   // et.cy.af_422 da.sv.un_320  az.tr.un_870 fi.ca.un_750
  0x0a002818, 0x1c0d1305, 0x070a0812, 0x023f0e02,   // sw.pt.un_740 bh.ne.mr_333  uk.mk.bg_654 is.af.da_222
  // [0df0]
  0x55063f02, 0x06351aa0, 0x051f0408, 0x0500070c,   // af.de.rw_222 tl.zu.de_322  fi.cy.fr_443 it.fr.un_530
  0x11000505, 0x3f002808, 0x2a04020c, 0x13000305,   // fr.ro.un_330 sw.af.un_430  da.fi.mt_543 nl.et.un_330
  0x21001f0c, 0x12082055, 0x1f6b010c, 0x04000808,   // cy.jw.un_530 sq.no.hu_442  en.ceb.cy_543 no.fi.un_430
  0x0700010d, 0x0c086ba0, 0x08060c07, 0x081f0e08,   // en.it.un_540 ceb.no.sv_322  sv.de.no_432 is.cy.no_443
  // [0e00]
  0x211218ac, 0x12071ba4, 0x35682a07, 0x06002002,   // ar.ur.fa_632 tr.it.hu_433  mt.ig.zu_432 sq.de.un_220
  0x0507010c, 0x17000a02, 0x17070a0c, 0x04091fa9,   // en.it.fr_543 mk.sr.un_220  mk.bg.sr_543 cy.pl.fi_544
  0x0a000709, 0x020e1f04, 0x08110707, 0x0e0752ee,   // it.pt.un_440 cy.is.da_332  it.ro.no_432 ha.it.is_422
  0x06031b08, 0x53100908, 0x08110a07, 0x1f002313,   // tr.nl.de_443 pl.lt.ht_443  mk.ro.uk_432 ca.cy.un_650
  // [0e10]
  0x121b3112, 0x18122114, 0x2a096807, 0x07050107,   // az.tr.hu_654 fa.ur.ar_666  ig.pl.mt_432 en.fr.it_432
  0x0800230e, 0x086828a4, 0x1f010604, 0x040601a4,   // ca.no.un_550 sw.ig.no_433  de.en.cy_332 en.de.fi_433
  0x17040709, 0x09001c05, 0x070604ad, 0x110a1709,   // bg.ru.sr_444 mr.hi.un_330  fi.de.it_643 sr.mk.ro_444
  0x052352ac, 0x04000804, 0x2d0d3f05, 0x0d1c1304,   // ha.ca.fr_632 no.fi.un_320  af.cs.sk_333 bh.mr.ne_332
  // [0e20]
  0x04081704, 0x08070a07, 0x04001304, 0x0711040c,   // sr.uk.ru_332 mk.bg.uk_432  et.fi.un_320 ru.ro.bg_543
  0x06002a0d, 0x211812ad, 0x1b003102, 0x1200210e,   // mt.de.un_540 ur.ar.fa_643  az.tr.un_220 fa.ur.un_550
  0x0d1c0908, 0x10080460, 0x3b002704, 0x1e002702,   // hi.mr.ne_443 ru.uk.be_664  gd.so.un_320 gd.ms.un_220
  0x0a001712, 0x0a0817a0, 0x12000e08, 0x0a0408a0,   // sr.mk.un_640 sr.uk.mk_322  is.hu.un_430 uk.ru.mk_322
  // [0e30]
  0x0e00101b, 0x102d0d05, 0x08022005, 0x07001828,   // lt.is.un_770 cs.sk.lt_333  sq.da.no_333 ar.bg.un_950
  0x3b684aa4, 0x1c00042a, 0x1f001904, 0x08000c04,   // yo.ig.so_433 fi.id.un_970  gl.cy.un_320 sv.no.un_320
  0x0400071a, 0x092104ad, 0x07000a0d, 0x232d0d04,   // bg.ru.un_760 fi.jw.pl_643  mk.bg.un_540 cs.sk.ca_332
  0x081704ad, 0x12000908, 0x08000c0e, 0x080704a9,   // ru.sr.uk_643 pl.hu.un_430  sv.no.un_550 ru.bg.uk_544
  // [0e40]
  0x2b1f2704, 0x0a684a08, 0x08534aa6, 0x0d002d08,   // gd.cy.vi_332 yo.ig.pt_443  yo.ht.no_521 sk.cs.un_430
  0x1f003f21, 0x08071705, 0x0d000911, 0x1800212b,   // af.cy.un_860 sr.bg.uk_333  hi.ne.un_630 fa.ar.un_980
  0x10170a04, 0x030906a0, 0x10040708, 0x0d002d07,   // mk.sr.be_332 de.pl.nl_322  bg.ru.be_443 sk.cs.un_420
  0x1300090c, 0x23190b09, 0x2d082908, 0x07040aee,   // hi.bh.un_530 es.gl.ca_444  sl.no.sk_443 mk.ru.bg_422
  // [0e50]
  0x1c0913ec, 0x2d000d11, 0x1c090d5a, 0x1b000c07,   // bh.hi.mr_644 cs.sk.un_630  ne.hi.mr_553 sv.tr.un_420
  0x1800201a, 0x6b1a6812, 0x1929230c, 0x090d1ca0,   // sq.ga.un_760 ig.tl.ceb_654  ca.sl.gl_543 mr.ne.hi_322
  0x0a040713, 0x070f68a4, 0x18122113, 0x06001308,   // bg.ru.mk_665 ig.lv.it_433  fa.ur.ar_665 et.de.un_430
  0x1f271813, 0x3f000a05, 0x090d1312, 0x131c0908,   // ga.gd.cy_665 pt.af.un_330  bh.ne.hi_654 hi.mr.bh_443
  // [0e60]
  0x1a003f02, 0x6b0a1f08, 0x4a00680d, 0x31001b11,   // af.tl.un_220 cy.pt.ceb_443  ig.yo.un_540 tr.az.un_630
  0x211c1ea4, 0x17080704, 0x05070112, 0x12000e05,   // ms.id.jw_433 bg.uk.sr_332  en.it.fr_654 is.hu.un_330
  0x03000805, 0x28001e04, 0x0e1918a0, 0x2311100c,   // no.nl.un_330 ms.sw.un_320  ga.gl.is_322 lt.ro.ca_543
  0x0500011a, 0x231119a4, 0x0f001318, 0x2d1009a9,   // en.fr.un_760 gl.ro.ca_433  et.lv.un_740 pl.lt.sk_544
  // [0e70]
  0x2800682a, 0x08042712, 0x1c091314, 0x271304ad,   // ig.sw.un_970 gd.fi.no_654  bh.hi.mr_666 fi.et.gd_643
  0x0c000609, 0x0807120c, 0x1e1c6ea0, 0x270e0655,   // de.sv.un_440 hu.it.no_543  hmn.id.ms_322 de.is.gd_442
  0x06000808, 0x21182712, 0x0000352d, 0x096b35a0,   // no.de.un_430 gd.ga.jw_654  zu.un.un_A00 zu.ceb.pl_322
  0x05680107, 0x27202114, 0x11000d08, 0x010c18ee,   // en.ig.fr_432 jw.sq.gd_666  cs.ro.un_430 ga.sv.en_422
  // [0e80]
  0x21041809, 0x4a202dee, 0x1168270c, 0x101123ac,   // ga.fi.jw_444 sk.sq.yo_422  gd.ig.ro_543 ca.ro.lt_632
  0x64325508, 0x023b070c, 0x0c19230c, 0x04190a55,   // rw.bs.lg_443 it.so.da_543  ca.gl.sv_543 pt.gl.fi_442
  0x1e191108, 0x11092da9, 0x06000e1a, 0x23002704,   // ro.gl.ms_443 sk.pl.ro_544  is.de.un_760 gd.ca.un_320
  0x1200212a, 0x160712a7, 0x3b006b05, 0x1a6b0705,   // fa.ur.un_970 hu.it.hr_532  ceb.so.un_330 it.ceb.tl_333
  // [0e90]
  0x132801a0, 0x04006402, 0x182721af, 0x350f10af,   // en.sw.et_322 lg.fi.un_220  jw.gd.ga_655 lt.lv.zu_655
  0x32001705, 0x061e1c08, 0x08170a02, 0x203b28ad,   // sr.bs.un_330 id.ms.de_443  mk.sr.uk_222 sw.so.sq_643
  0x551a20a4, 0x2d111005, 0x31002023, 0x010535a0,   // sq.tl.rw_433 lt.ro.sk_333  sq.az.un_880 zu.fr.en_322
  0x19002319, 0x35312055, 0x2d002904, 0x0c02080c,   // ca.gl.un_750 sq.az.zu_442  sl.sk.un_320 no.da.sv_543
  // [0ea0]
  0x08000719, 0x10231108, 0x20005514, 0x32001614,   // bg.uk.un_750 ro.ca.lt_443  rw.sq.un_660 hr.bs.un_660
  0x53006407, 0x20351812, 0x1168230c, 0x1b1853a0,   // lg.ht.un_420 ga.zu.sq_654  ca.ig.ro_543 ht.ga.tr_322
  0x32166ba0, 0x20000d04, 0x2b001a04, 0x351e10a0,   // ceb.hr.bs_322 cs.sq.un_320  tl.vi.un_320 lt.ms.zu_322
  0x1a006b08, 0x2010110d, 0x0a011a07, 0x17000408,   // ceb.tl.un_430 ro.lt.sq_554  tl.en.pt_432 fi.sr.un_430
  // [0eb0]
  0x3555520d, 0x232d100c, 0x25001e0d, 0x06033fa0,   // ha.rw.zu_554 lt.sk.ca_543  ms.eu.un_540 af.nl.de_322
  0x1b05350c, 0x023f08a4, 0x1b132007, 0x102d110e,   // zu.fr.tr_543 no.af.da_433  sq.et.tr_432 ro.sk.lt_555
  0x19000b21, 0x6b551a08, 0x2b1a6ba0, 0x03012aee,   // es.gl.un_860 tl.rw.ceb_443  ceb.tl.vi_322 mt.en.nl_422
  0x02000404, 0x29001604, 0x1c2952a4, 0x17040705,   // fi.da.un_320 hr.sl.un_320  ha.sl.id_433 bg.ru.sr_333
  // [0ec0]
  0x3f552a55, 0x28352014, 0x3531640c, 0x090d1307,   // mt.rw.af_442 sq.zu.sw_666  lg.az.zu_543 bh.ne.hi_432
  0x09003504, 0x200b1313, 0x01060c04, 0x05010605,   // zu.pl.un_320 et.es.sq_665  sv.de.en_332 de.en.fr_333
  0x292d0d14, 0x0c000813, 0x1f003513, 0x09003f02,   // cs.sk.sl_666 no.sv.un_650  zu.cy.un_650 af.pl.un_220
  0x110710ad, 0x290d02a0, 0x1c002107, 0x0913040d,   // be.bg.ro_643 da.cs.sl_322  jw.id.un_420 fi.et.pl_554
  // [0ed0]
  0x2a033fa0, 0x07080409, 0x101e1c05, 0x09001313,   // af.nl.mt_322 ru.uk.bg_444  id.ms.lt_333 bh.hi.un_650
  0x0800040c, 0x0d091c0b, 0x0411170d, 0x08001002,   // ru.uk.un_530 mr.hi.ne_542  sr.ro.ru_554 be.uk.un_220
  0x0717040c, 0x2d0d090e, 0x2400010c, 0x162d0d09,   // ru.sr.bg_543 pl.cs.sk_555  iw.yi.un_530 cs.sk.hr_444
  0x521e25a9, 0x1e1c350c, 0x35003b09, 0x09130d11,   // eu.ms.ha_544 zu.id.ms_543  so.zu.un_440 ne.bh.hi_653
  // [0ee0]
  0x0d091307, 0x0e000c13, 0x12000c08, 0x040e0ca7,   // bh.hi.ne_432 sv.is.un_650  sv.hu.un_430 sv.is.fi_532
  0x551e1c05, 0x170711af, 0x071004ec, 0x28005505,   // id.ms.rw_333 ro.bg.sr_655  ru.be.bg_644 rw.sw.un_330
  0x09003f07, 0x1e101c12, 0x070411a0, 0x0d001304,   // af.pl.un_420 id.lt.ms_654  ro.ru.bg_322 bh.ne.un_320
  0x080a0709, 0x07170804, 0x1a645504, 0x06001b13,   // bg.mk.uk_444 uk.sr.bg_332  rw.lg.tl_332 tr.de.un_650
  // [0ef0]
  0x3b000702, 0x17040a02, 0x68003522, 0x2d1b0d55,   // it.so.un_220 mk.ru.sr_222  zu.ig.un_870 cs.tr.sk_442
  0x1f002512, 0x35536812, 0x0c321ca0, 0x100a17a4,   // eu.cy.un_640 ig.ht.zu_654  id.bs.sv_322 sr.mk.be_433
  0x1c0d1307, 0x35001f04, 0x551e1c0c, 0x1c000d08,   // bh.ne.mr_432 cy.zu.un_320  id.ms.rw_543 ne.mr.un_430
  0x55351c08, 0x13001c08, 0x531e1c04, 0x172d0d55,   // id.zu.rw_443 mr.bh.un_430  id.ms.ht_332 cs.sk.sr_442
  // [0f00]
  0x08070414, 0x080205ee, 0x130d1c0d, 0x21001220,   // ru.bg.uk_666 fr.da.no_422  mr.ne.bh_554 ur.fa.un_850
  0x08000212, 0x08020c05, 0x04001308, 0x19000b22,   // da.no.un_640 sv.da.no_333  et.fi.un_430 es.gl.un_870
  0x07080a05, 0x21005302, 0x08000a12, 0x27005505,   // mk.uk.bg_333 ht.jw.un_220  mk.uk.un_640 rw.gd.un_330
  0x0a1707ad, 0x0407115a, 0x2d005304, 0x0e0c0612,   // bg.sr.mk_643 ro.bg.ru_553  ht.sk.un_320 de.sv.is_654
  // [0f10]
  0x11000302, 0x17070a11, 0x131c1a04, 0x0f321705,   // nl.ro.un_220 mk.bg.sr_653  tl.id.et_332 sr.bs.lv_333
  0x0200080b, 0x110b5507, 0x100a1708, 0x1b000c04,   // no.da.un_520 rw.es.ro_432  sr.mk.be_443 sv.tr.un_320
  0x04001307, 0x050111ee, 0x080704ec, 0x31005508,   // et.fi.un_420 ro.en.fr_422  ru.bg.uk_644 rw.az.un_430
  0x292d0d04, 0x11204aa0, 0x0800101a, 0x101e1c04,   // cs.sk.sl_332 yo.sq.ro_322  be.uk.un_760 id.ms.lt_332
  // [0f20]
  0x00004a01, 0x0a00110d, 0x061e1c04, 0x64006b04,   // yo.un.un_200 ro.mk.un_540  id.ms.de_332 ceb.lg.un_320
  0x3200010c, 0x2b000508, 0x280f1105, 0x55001602,   // en.bs.un_530 fr.vi.un_430  ro.lv.sw_333 hr.rw.un_220
  0x1b003121, 0x21252a04, 0x21006b07, 0x0c002105,   // az.tr.un_860 mt.eu.jw_332  ceb.jw.un_420 jw.sv.un_330
  0x100711a7, 0x02000612, 0x04081008, 0x07002a14,   // ro.bg.be_532 de.da.un_640  be.uk.ru_443 mt.it.un_660
  // [0f30]
  0x170a1108, 0x12190a0c, 0x040a07a4, 0x6b4a1a07,   // ro.mk.sr_443 pt.gl.hu_543  bg.mk.ru_433 tl.yo.ceb_432
  0x10000702, 0x1c000912, 0x1821120d, 0x3f072013,   // bg.be.un_220 hi.mr.un_640  ur.fa.ar_554 sq.it.af_665
  0x0d091c05, 0x3217160c, 0x06000c0e, 0x280f31a4,   // mr.hi.ne_333 hr.sr.bs_543  sv.de.un_550 az.lv.sw_433
  0x0c08025a, 0x553b1a0e, 0x11041760, 0x2d0d0aec,   // da.no.sv_553 tl.so.rw_555  sr.ru.ro_664 pt.cs.sk_644
  // [0f40]
  0x530d065a, 0x52060eee, 0x13091c12, 0x182112af,   // de.cs.ht_553 is.de.ha_422  mr.hi.bh_654 ur.fa.ar_655
  0x0c0e29ad, 0x13043104, 0x080e0408, 0x290f0c09,   // sl.is.sv_643 az.fi.et_332  fi.is.no_443 sv.lv.sl_444
  0x0a1704a9, 0x17292808, 0x080c09a7, 0x3f032909,   // ru.sr.mk_544 sw.sl.sr_443  pl.sv.no_532 sl.nl.af_444
  0x25006404, 0x080c1fa0, 0x0635080c, 0x216b1aad,   // lg.eu.un_320 cy.sv.no_322  no.zu.de_543 tl.ceb.jw_643
  // [0f50]
  0x07040a0d, 0x033f6407, 0x0e002007, 0x0d0913ec,   // mk.ru.bg_554 lg.af.nl_432  sq.is.un_420 bh.hi.ne_644
  0x17100811, 0x29211313, 0x3f0208a9, 0x17100aa0,   // uk.be.sr_653 et.jw.sl_665  no.da.af_544 mk.be.sr_322
  0x16000312, 0x01060ca6, 0x00003f06, 0x2d132912,   // nl.hr.un_640 sv.de.en_521  af.un.un_400 sl.et.sk_654
  0x21526bad, 0x061c2104, 0x100817a4, 0x07001013,   // ceb.ha.jw_643 jw.id.de_332  sr.uk.be_433 be.bg.un_650
  // [0f60]
  0x013b5311, 0x0a001907, 0x1c0d0913, 0x0c000812,   // ht.so.en_653 gl.pt.un_420  hi.ne.mr_665 no.sv.un_640
  0x09006b08, 0x1c000911, 0x09000d2b, 0x06310fa4,   // ceb.pl.un_430 hi.mr.un_630  ne.hi.un_980 lv.az.de_433
  0x3b3f1304, 0x033b01a0, 0x0a07100c, 0x0800100c,   // et.af.so_332 en.so.nl_322  be.bg.mk_543 be.uk.un_530
  0x292d25ec, 0x19000e09, 0x01005312, 0x08023f05,   // eu.sk.sl_644 is.gl.un_440  ht.en.un_640 af.da.no_333
  // [0f70]
  0x050a19a0, 0x00000b24, 0x16292d07, 0x131c0913,   // gl.pt.fr_322 bn.un.un_900  sk.sl.hr_432 hi.mr.bh_665
  0x033b3f0b, 0x10645304, 0x040a17a7, 0x09000d11,   // af.so.nl_542 ht.lg.lt_332  sr.mk.ru_532 ne.hi.un_630
  0x1c1309ec, 0x530208af, 0x03063f0c, 0x100f25a7,   // hi.bh.mr_644 no.da.ht_655  af.de.nl_543 eu.lv.lt_532
  0x1a250e08, 0x120a2304, 0x17040aaf, 0x6b281a07,   // is.eu.tl_443 ca.pt.hu_332  mk.ru.sr_655 tl.sw.ceb_432
  // [0f80]
  0x080410a4, 0x12001305, 0x0d091c14, 0x13001a08,   // be.ru.uk_433 et.hu.un_330  mr.hi.ne_666 tl.et.un_430
  0x070a11ee, 0x1f0453ee, 0x0a071160, 0x3b003f19,   // ro.mk.bg_422 ht.fi.cy_422  ro.bg.mk_664 af.so.un_750
  0x011f5355, 0x01033fa0, 0x23190704, 0x211e1c0c,   // ht.cy.en_442 af.nl.en_322  it.gl.ca_332 id.ms.jw_543
  0x286b100c, 0x04001119, 0x53001c04, 0x1c000d05,   // lt.ceb.sw_543 ro.ru.un_750  id.ht.un_320 ne.mr.un_330
  // [0f90]
  0x29090da9, 0x170810a7, 0x352b4aa0, 0x28006820,   // cs.pl.sl_544 be.uk.sr_532  yo.vi.zu_322 ig.sw.un_850
  0x07080413, 0x08171008, 0x090d13a6, 0x08070a02,   // ru.uk.bg_665 be.sr.uk_443  et.cs.pl_521 mk.bg.uk_222
  0x2100180d, 0x070a11a4, 0x07002a19, 0x1f194aa4,   // ar.fa.un_540 ro.mk.bg_433  mt.it.un_750 yo.gl.cy_433
  0x283552a0, 0x10522555, 0x120b25ee, 0x4a0e2dad,   // ha.zu.sw_322 eu.ha.lt_442  eu.es.hu_422 sk.is.yo_643
  // [0fa0]
  0x1a006b13, 0x041b3bad, 0x0b124aaf, 0x17321608,   // ceb.tl.un_650 so.tr.fi_643  yo.hu.es_655 hr.bs.sr_443
  0x0b4a120c, 0x0a00071b, 0x19120b07, 0x186b01a7,   // hu.yo.es_543 bg.mk.un_770  es.hu.gl_432 en.ceb.ga_532
  0x3b356405, 0x18005304, 0x120b4aec, 0x2700182b,   // lg.zu.so_333 ht.ga.un_320  yo.es.hu_644 ga.gd.un_980
  0x0b001221, 0x17311fad, 0x27003b04, 0x202a07a4,   // hu.es.un_860 cy.az.sr_643  so.gd.un_320 it.mt.sq_433
  // [0fb0]
  0x17001007, 0x12230b08, 0x29002007, 0x1c2164a7,   // be.sr.un_420 es.ca.hu_443  sq.sl.un_420 lg.jw.id_532
  0x3216095a, 0x080c3ba4, 0x19000b14, 0x2100181b,   // pl.hr.bs_553 so.sv.no_433  es.gl.un_660 ar.fa.un_770
  0x6b081302, 0x2d0d21a0, 0x121821ad, 0x1c1304ee,   // et.no.ceb_222 jw.cs.sk_322  fa.ar.ur_643 fi.et.id_422
  0x08020cec, 0x32005504, 0x08040707, 0x02080c0c,   // sv.da.no_644 rw.bs.un_320  bg.ru.uk_432 sv.no.da_543
  // [0fc0]
  0x53000308, 0x1a683b0c, 0x12190bac, 0x32043baf,   // nl.ht.un_430 so.ig.tl_543  es.gl.hu_632 so.fi.bs_655
  0x1300041a, 0x12000d13, 0x080f040c, 0x4a002102,   // fi.et.un_760 cs.hu.un_650  fi.lv.no_543 jw.yo.un_220
  0x4a230b05, 0x09000113, 0x190b01a0, 0x120b2313,   // es.ca.yo_333 en.pl.un_650  en.es.gl_322 ca.es.hu_665
  0x12003b19, 0x4a120b09, 0x55001b0c, 0x12000302,   // so.hu.un_750 es.hu.yo_444  tr.rw.un_530 nl.hu.un_220
  // [0fd0]
  0x522164a4, 0x68000104, 0x112b01a4, 0x066e0107,   // lg.jw.ha_433 en.ig.un_320  en.vi.ro_433 en.hmn.de_432
  0x095505a7, 0x04071004, 0x11000413, 0x0b00010d,   // fr.rw.pl_532 be.bg.ru_332  ru.ro.un_650 en.es.un_540
  0x170407ee, 0x19122d0c, 0x13000104, 0x05001804,   // bg.ru.sr_422 sk.hu.gl_543  en.et.un_320 ga.fr.un_320
  0x00003b2d, 0x0d1c0912, 0x3f2506ad, 0x0400101b,   // so.un.un_A00 hi.mr.ne_654  de.eu.af_643 be.ru.un_770
  // [0fe0]
  0x01006e07, 0x03190a04, 0x1f000912, 0x04000a02,   // hmn.en.un_420 pt.gl.nl_332  pl.cy.un_640 mk.ru.un_220
  0x2300010d, 0x0a2755a0, 0x07100aa9, 0x1a1f01a4,   // en.ca.un_540 rw.gd.pt_322  mk.be.bg_544 en.cy.tl_433
  0x0c00060c, 0x04001008, 0x2300120c, 0x07081707,   // de.sv.un_530 be.ru.un_430  hu.ca.un_530 sr.uk.bg_432
  0x0700170d, 0x060c35a4, 0x29002d08, 0x0900130d,   // sr.bg.un_540 zu.sv.de_433  sk.sl.un_430 bh.hi.un_540
  // [0ff0]
  0x18530404, 0x1000110c, 0x52006812, 0x27003f02,   // fi.ht.ga_332 ro.be.un_530  ig.ha.un_640 af.gd.un_220
  0x3b00550c, 0x080710a0, 0x1e1c3bee, 0x0708040c,   // rw.so.un_530 be.bg.uk_322  so.id.ms_422 ru.uk.bg_543
  0x10000422, 0x1c001304, 0x08101705, 0x1b001205,   // ru.be.un_870 et.id.un_320  sr.be.uk_333 hu.tr.un_330
  0x311b1212, 0x311b13a7, 0x0804115a, 0x0c003502,   // hu.tr.az_654 et.tr.az_532  ro.ru.uk_553 zu.sv.un_220

  // [1000]
  0x00000d2d, 0x31001b20, 0x181f35ec, 0x2b003512,   // ne.un.un_A00 tr.az.un_850  zu.cy.ga_644 zu.vi.un_640
  0x132703a0, 0x35283ba4, 0x091c1308, 0x2b003519,   // nl.gd.et_322 so.sw.zu_433  bh.mr.hi_443 zu.vi.un_750
  0x32002912, 0x17000a13, 0x11001902, 0x1e001c07,   // sl.bs.un_640 mk.sr.un_650  gl.ro.un_220 id.ms.un_420
  0x040817a0, 0x3f002104, 0x2a001319, 0x08041002,   // sr.uk.ru_322 jw.af.un_320  et.mt.un_750 be.ru.uk_222
  // [1010]
  0x32171660, 0x0a0407af, 0x070a11a7, 0x033f53a4,   // hr.sr.bs_664 bg.ru.mk_655  ro.mk.bg_532 ht.af.nl_433
  0x1b123112, 0x0a00180c, 0x12001b1a, 0x172d2908,   // az.hu.tr_654 ga.pt.un_530  tr.hu.un_760 sl.sk.sr_443
  0x010528ad, 0x28006b04, 0x3100121a, 0x0a001705,   // sw.fr.en_643 ceb.sw.un_320  hu.az.un_760 sr.mk.un_330
  0x23005307, 0x121b2d0c, 0x28003504, 0x1b1629a4,   // ht.ca.un_420 sk.tr.hu_543  zu.sw.un_320 sl.hr.tr_433
  // [1020]
  0x033f23a9, 0x1e00180d, 0x53000504, 0x0400120e,   // ca.af.nl_544 ga.ms.un_540  fr.ht.un_320 hu.fi.un_550
  0x1c13090d, 0x250f0707, 0x0c3f0312, 0x29321708,   // hi.bh.mr_554 it.lv.eu_432  nl.af.sv_654 sr.bs.sl_443
  0x2d005313, 0x043b3507, 0x182b27a7, 0x0e3b130d,   // ht.sk.un_650 zu.so.fi_432  gd.vi.ga_532 et.so.is_554
  0x05110aa0, 0x0d091302, 0x09005308, 0x55283b04,   // pt.ro.fr_322 bh.hi.ne_222  ht.pl.un_430 so.sw.rw_332
  // [1030]
  0x3f000309, 0x07001113, 0x27190b02, 0x0a001812,   // nl.af.un_440 ro.bg.un_650  es.gl.gd_222 ga.pt.un_640
  0x110203ee, 0x20553b07, 0x10071707, 0x17110a04,   // nl.da.ro_422 so.rw.sq_432  sr.bg.be_432 mk.ro.sr_332
  0x3b551307, 0x09001c0b, 0x062d0d04, 0x2d0d29ee,   // et.rw.so_432 mr.hi.un_520  cs.sk.de_332 sl.cs.sk_422
  0x296e0da0, 0x10040a09, 0x20553b12, 0x03090708,   // cs.hmn.sl_322 mk.ru.be_444  so.rw.sq_654 it.pl.nl_443
  // [1040]
  0x2a000719, 0x120b19ee, 0x35000204, 0x1100070d,   // it.mt.un_750 gl.es.hu_422  da.zu.un_320 it.ro.un_540
  0x03003f0d, 0x1206020c, 0x035207a0, 0x1a6b3ba0,   // af.nl.un_540 da.de.hu_543  it.ha.nl_322 so.ceb.tl_322
  0x040811a0, 0x1a002804, 0x4a00120e, 0x163217ad,   // ro.uk.ru_322 sw.tl.un_320  hu.yo.un_550 sr.bs.hr_643
  0x170711a6, 0x21004a04, 0x04001f09, 0x03000d07,   // ro.bg.sr_521 yo.jw.un_320  cy.fi.un_440 cs.nl.un_420
  // [1050]
  0x0e000219, 0x520d1a0d, 0x100a07a0, 0x1f002013,   // da.is.un_750 tl.cs.ha_554  bg.mk.be_322 sq.cy.un_650
  0x2d000d0d, 0x04001709, 0x16001007, 0x040811a4,   // cs.sk.un_540 sr.ru.un_440  lt.hr.un_420 ro.uk.ru_433
  0x0a1b2304, 0x0a070107, 0x040105ee, 0x17081005,   // ca.tr.pt_332 en.it.pt_432  fr.en.fi_422 be.uk.sr_333
  0x1710110d, 0x2d12080c, 0x04170a12, 0x110825ee,   // ro.be.sr_554 no.hu.sk_543  mk.sr.ru_654 eu.no.ro_422
  // [1060]
  0x1200101b, 0x0a041707, 0x08000a1a, 0x3f0301a0,   // lt.hu.un_770 sr.ru.mk_432  mk.uk.un_760 en.nl.af_322
  0x01001f07, 0x052311a4, 0x20001f04, 0x17001119,   // cy.en.un_420 ro.ca.fr_433  cy.sq.un_320 ro.sr.un_750
  0x041008ec, 0x092512ec, 0x3b00121a, 0x170811a0,   // uk.be.ru_644 hu.eu.pl_644  hu.so.un_760 ro.uk.sr_322
  0x01091fee, 0x1a000411, 0x2b001f04, 0x112718ad,   // cy.pl.en_422 fi.tl.un_630  cy.vi.un_320 ga.gd.ro_643
  // [1070]
  0x1f000c13, 0x00006e37, 0x2a0708a4, 0x13000904,   // sv.cy.un_650 hmn.un.un_B00  no.it.mt_433 hi.bh.un_320
  0x1100521a, 0x25000804, 0x101308a0, 0x2d090da7,   // ha.ro.un_760 no.eu.un_320  no.et.lt_322 cs.pl.sk_532
  0x05110807, 0x11006e22, 0x04000a04, 0x02000604,   // no.ro.fr_432 hmn.ro.un_870  mk.ru.un_320 de.da.un_320
  0x27006e18, 0x051827a9, 0x08110414, 0x05182711,   // hmn.gd.un_740 gd.ga.fr_544  ru.ro.uk_666 gd.ga.fr_653
  // [1080]
  0x083f6e07, 0x00006b01, 0x06002102, 0x0527180d,   // hmn.af.no_432 ceb.un.un_200  jw.de.un_220 ga.gd.fr_554
  0x1e1c21af, 0x13000922, 0x033f23a4, 0x081704a4,   // jw.id.ms_655 hi.bh.un_870  ca.af.nl_433 ru.sr.uk_433
  0x0c000e08, 0x1f000c19, 0x321629ec, 0x16002913,   // is.sv.un_430 sv.cy.un_750  sl.hr.bs_644 sl.hr.un_650
  0x0e080202, 0x0a000d07, 0x0800020b, 0x040817ec,   // da.no.is_222 cs.pt.un_420  da.no.un_520 sr.uk.ru_644
  // [1090]
  0x3f0306ee, 0x1300092c, 0x0e3f1a07, 0x28001013,   // de.nl.af_422 hi.bh.un_990  tl.af.is_432 lt.sw.un_650
  0x19002304, 0x4a2025a7, 0x0c126ba0, 0x19000a0c,   // ca.gl.un_320 eu.sq.yo_532  ceb.hu.sv_322 pt.gl.un_530
  0x00006b24, 0x64100f0c, 0x20003519, 0x092d0d08,   // ceb.un.un_900 lv.lt.lg_543  zu.sq.un_750 cs.sk.pl_443
  0x2825350c, 0x1200180c, 0x28352113, 0x06033fa7,   // zu.eu.sw_543 ga.hu.un_530  jw.zu.sw_665 af.nl.de_532
  // [10a0]
  0x230a1ea0, 0x08280e07, 0x070f1ea0, 0x1c351e11,   // ms.pt.ca_322 is.sw.no_432  ms.lv.it_322 ms.zu.id_653
  0x09002a08, 0x06000804, 0x070a0405, 0x230b2107,   // mt.pl.un_430 no.de.un_320  ru.mk.bg_333 jw.es.ca_432
  0x2d0d12af, 0x061e0e07, 0x0c024aad, 0x170708a4,   // hu.cs.sk_655 is.ms.de_432  yo.da.sv_643 uk.bg.sr_433
  0x0e082a12, 0x03023f08, 0x11200212, 0x00000524,   // mt.no.is_654 af.da.nl_443  da.sq.ro_654 fr.un.un_900
  // [10b0]
  0x29002a04, 0x553564a0, 0x0800201a, 0x1e351c07,   // mt.sl.un_320 lg.zu.rw_322  sq.no.un_760 id.zu.ms_432
  0x093b0da4, 0x0a3f03a4, 0x3f060a09, 0x03040608,   // cs.so.pl_433 nl.af.pt_433  pt.de.af_444 de.fi.nl_443
  0x0a000712, 0x1e1c0fa0, 0x04000613, 0x040807a9,   // bg.mk.un_640 lv.id.ms_322  de.fi.un_650 bg.uk.ru_544
  0x04132012, 0x35286407, 0x53020b05, 0x32006419,   // sq.et.fi_654 lg.sw.zu_432  es.da.ht_333 lg.bs.un_750
  // [10c0]
  0x293208a4, 0x20080c08, 0x033f270c, 0x102012a7,   // no.bs.sl_433 sv.no.sq_443  gd.af.nl_543 hu.sq.lt_532
  0x3f040308, 0x08033faf, 0x0308200c, 0x1f190bad,   // nl.fi.af_443 af.nl.no_655  sq.no.nl_543 es.gl.cy_643
  0x06286405, 0x20000b19, 0x1e1c64a0, 0x2a001704,   // lg.sw.de_333 es.sq.un_750  lg.id.ms_322 sr.mt.un_320
  0x2d0d3b14, 0x1106190d, 0x016e0cad, 0x0d000919,   // so.cs.sk_666 gl.de.ro_554  sv.hmn.en_643 hi.ne.un_750
  // [10d0]
  0x08002a0c, 0x18000521, 0x0900010d, 0x291e1c05,   // mt.no.un_530 fr.ga.un_860  en.pl.un_540 id.ms.sl_333
  0x123525a4, 0x53003f05, 0x0b2307ad, 0x0e0c3f04,   // eu.zu.hu_433 af.ht.un_330  it.ca.es_643 af.sv.is_332
  0x1900230d, 0x0b0a1905, 0x29200908, 0x092010ac,   // ca.gl.un_540 gl.pt.es_333  pl.sq.sl_443 lt.sq.pl_632
  0x5300021a, 0x211e1c60, 0x07001114, 0x35006412,   // da.ht.un_760 id.ms.jw_664  ro.it.un_660 lg.zu.un_640
  // [10e0]
  0x1000040d, 0x172d0d08, 0x08002919, 0x211c1e11,   // fi.lt.un_540 cs.sk.sr_443  sl.no.un_750 ms.id.jw_653
  0x2700180d, 0x032008a0, 0x2b001119, 0x18273fa4,   // ga.gd.un_540 no.sq.nl_322  ro.vi.un_750 af.gd.ga_433
  0x170a11ee, 0x1c001308, 0x043509a4, 0x28100f05,   // ro.mk.sr_422 bh.mr.un_430  pl.zu.fi_433 lv.lt.sw_333
  0x03063f09, 0x13000921, 0x08200309, 0x06003f08,   // af.de.nl_444 hi.bh.un_860  nl.sq.no_444 af.de.un_430
  // [10f0]
  0x18002722, 0x2920030c, 0x1b1168a7, 0x1c001e22,   // gd.ga.un_870 nl.sq.sl_543  ig.ro.tr_532 ms.id.un_870
  0x06000a04, 0x08171005, 0x28001104, 0x17070408,   // pt.de.un_320 be.sr.uk_333  ro.sw.un_320 ru.bg.sr_443
  0x1f006b04, 0x29000919, 0x11070509, 0x08070a09,   // ceb.cy.un_320 pl.sl.un_750  fr.it.ro_444 mk.bg.uk_444
  0x3555310c, 0x551805a4, 0x4a005308, 0x01000c13,   // az.rw.zu_543 fr.ga.rw_433  ht.yo.un_430 sv.en.un_650
  // [1100]
  0x1632170d, 0x1c00130c, 0x07000a05, 0x2800550c,   // sr.bs.hr_554 bh.mr.un_530  mk.bg.un_330 rw.sw.un_530
  0x0a111708, 0x0c002b0b, 0x2d0d01a9, 0x08170aa4,   // sr.ro.mk_443 vi.sv.un_520  en.cs.sk_544 mk.sr.uk_433
  0x1221180e, 0x1e1c4a09, 0x1200211a, 0x232b1b04,   // ar.fa.ur_555 yo.id.ms_444  fa.ur.un_760 tr.vi.ca_332
  0x0800170e, 0x130d090c, 0x292d0d05, 0x1c000914,   // sr.uk.un_550 hi.ne.bh_543  cs.sk.sl_333 hi.mr.un_660
  // [1110]
  0x08070aa0, 0x0a170705, 0x08110704, 0x09000c0d,   // mk.bg.uk_322 bg.sr.mk_333  bg.ro.uk_332 sv.pl.un_540
  0x0000521c, 0x1c1309a9, 0x04000821, 0x0d001c09,   // ha.un.un_800 hi.bh.mr_544  uk.ru.un_860 mr.ne.un_440
  0x0d2d01a7, 0x04001014, 0x213b53ad, 0x1b3152ad,   // en.sk.cs_532 be.ru.un_660  ht.so.jw_643 ha.az.tr_643
  0x0e001214, 0x06001b09, 0x1e0c1cee, 0x354a520b,   // hu.is.un_660 tr.de.un_440  id.sv.ms_422 ha.yo.zu_542
  // [1120]
  0x0e0604a6, 0x17070a13, 0x53005219, 0x21201e09,   // fi.de.is_521 mk.bg.sr_665  ha.ht.un_750 ms.sq.jw_444
  0x1c211e04, 0x0d122d0c, 0x2a0501a0, 0x0a07040b,   // ms.jw.id_332 sk.hu.cs_543  en.fr.mt_322 ru.bg.mk_542
  0x063f2a04, 0x0600120c, 0x010318ee, 0x3f082a07,   // mt.af.de_332 hu.de.un_530  ga.nl.en_422 mt.no.af_432
  0x0c001c07, 0x29033f0c, 0x01215302, 0x3f000305,   // id.sv.un_420 af.nl.sl_543  ht.jw.en_222 nl.af.un_330
  // [1130]
  0x25685507, 0x06216ea0, 0x08132aa0, 0x091c1313,   // rw.ig.eu_432 hmn.jw.de_322  mt.et.no_322 bh.mr.hi_665
  0x1200280b, 0x0c022a04, 0x17002007, 0x0e002d08,   // sw.hu.un_520 mt.da.sv_332  sq.sr.un_420 sk.is.un_430
  0x190a1aa9, 0x08001c04, 0x211e1c09, 0x29006422,   // tl.pt.gl_544 id.no.un_320  id.ms.jw_444 lg.sl.un_870
  0x16321713, 0x10001b2a, 0x0407105a, 0x08110408,   // sr.bs.hr_665 tr.lt.un_970  be.bg.ru_553 ru.ro.uk_443
  // [1140]
  0x04091013, 0x08070404, 0x1c072102, 0x04000a0c,   // lt.pl.fi_665 ru.bg.uk_332  jw.it.id_222 mk.ru.un_530
  0x0e002804, 0x06353ba4, 0x08041702, 0x040710a4,   // sw.is.un_320 so.zu.de_433  sr.ru.uk_222 be.bg.ru_433
  0x1c3168a7, 0x0b000723, 0x216b0660, 0x10000609,   // ig.az.id_532 it.es.un_880  de.ceb.jw_664 de.lt.un_440
  0x18002121, 0x13091c14, 0x053f0d0c, 0x25080c08,   // fa.ar.un_860 mr.hi.bh_666  cs.af.fr_543 sv.no.eu_443
  // [1150]
  0x190a18ee, 0x1b1e1ca9, 0x1c1309af, 0x20091ba0,   // ga.pt.gl_422 id.ms.tr_544  hi.bh.mr_655 tr.pl.sq_322
  0x23001b05, 0x29190b5a, 0x4a1219ec, 0x201b11a0,   // tr.ca.un_330 es.gl.sl_553  gl.hu.yo_644 ro.tr.sq_322
  0x03063fa9, 0x2b172102, 0x0a070809, 0x13000d12,   // af.de.nl_544 jw.sr.vi_222  uk.bg.mk_444 ne.bh.un_640
  0x0f132004, 0x35001107, 0x070a1007, 0x17001b04,   // sq.et.lv_332 ro.zu.un_420  be.mk.bg_432 tr.sr.un_320
  // [1160]
  0x1b1e1c0d, 0x09001321, 0x2923190c, 0x072311ee,   // id.ms.tr_554 bh.hi.un_860  gl.ca.sl_543 ro.ca.it_422
  0x2300250d, 0x071704a4, 0x0704080e, 0x070a0409,   // eu.ca.un_540 ru.sr.bg_433  uk.ru.bg_555 ru.mk.bg_444
  0x03002102, 0x1c106404, 0x04000707, 0x2d021112,   // jw.nl.un_220 lg.lt.id_332  bg.ru.un_420 ro.da.sk_654
  0x113209a0, 0x0800101b, 0x0d0913ad, 0x202d11a0,   // pl.bs.ro_322 be.uk.un_770  bh.hi.ne_643 ro.sk.sq_322
  // [1170]
  0x18002120, 0x231901a0, 0x32001b07, 0x11000108,   // fa.ar.un_850 en.gl.ca_322  tr.bs.un_420 en.ro.un_430
  0x112801ee, 0x00002003, 0x1c130904, 0x2d000d04,   // en.sw.ro_422 sq.un.un_300  hi.bh.mr_332 cs.sk.un_320
  0x090d1c0d, 0x1c00090d, 0x080704af, 0x18002721,   // mr.ne.hi_554 hi.mr.un_540  ru.bg.uk_655 gd.ga.un_860
  0x080a1704, 0x270b6e04, 0x211e1c5a, 0x0a170405,   // sr.mk.uk_332 hmn.es.gd_332  id.ms.jw_553 ru.sr.mk_333
  // [1180]
  0x0c040ba7, 0x070403af, 0x21000905, 0x3f000308,   // es.fi.sv_532 nl.fi.it_655  pl.jw.un_330 nl.af.un_430
  0x1e533b0c, 0x35002514, 0x25190bee, 0x060a04ad,   // so.ht.ms_543 eu.zu.un_660  es.gl.eu_422 fi.pt.de_643
  0x010a07ee, 0x12000419, 0x102d0f14, 0x356b6404,   // it.pt.en_422 fi.hu.un_750  lv.sk.lt_666 lg.ceb.zu_332
  0x011105a0, 0x640a2aa4, 0x6b001a05, 0x02000307,   // fr.ro.en_322 mt.pt.lg_433  tl.ceb.un_330 nl.da.un_420
  // [1190]
  0x6b000104, 0x040a110c, 0x08006b07, 0x21001a07,   // en.ceb.un_320 ro.mk.ru_543  ceb.no.un_420 tl.jw.un_420
  0x1f21640c, 0x1a002104, 0x1c110107, 0x171632a4,   // lg.jw.cy_543 jw.tl.un_320  en.ro.id_432 bs.hr.sr_433
  0x08100409, 0x1b130414, 0x0900040c, 0x201101a4,   // ru.be.uk_444 fi.et.tr_666  fi.pl.un_530 en.ro.sq_433
  0x1a6b21ec, 0x2d000908, 0x12001808, 0x0f000704,   // jw.ceb.tl_644 pl.sk.un_430  ga.hu.un_430 it.lv.un_320
  // [11a0]
  0x0a040804, 0x04081060, 0x1200212b, 0x1a000b04,   // uk.ru.mk_332 be.uk.ru_664  fa.ur.un_980 es.tl.un_320
  0x531b6b05, 0x110231ee, 0x3b001e08, 0x35073207,   // ceb.tr.ht_333 az.da.ro_422  ms.so.un_430 bs.it.zu_432
  0x0a210907, 0x53094a08, 0x0600041a, 0x3f040e14,   // pl.jw.pt_432 yo.pl.ht_443  fi.de.un_760 is.fi.af_666
  0x12356408, 0x4a640713, 0x05000e04, 0x2a00020d,   // lg.zu.hu_443 it.lg.yo_665  is.fr.un_320 da.mt.un_540
  // [11b0]
  0x1704080b, 0x6b211a0c, 0x4a002305, 0x12001009,   // uk.ru.sr_542 tl.jw.ceb_543  ca.yo.un_330 lt.hu.un_440
  0x07170aad, 0x1c090d04, 0x11080408, 0x170a0760,   // mk.sr.bg_643 ne.hi.mr_332  ru.uk.ro_443 bg.mk.sr_664
  0x1a5552ee, 0x00006b1c, 0x10040704, 0x0d1309a7,   // ha.rw.tl_422 ceb.un.un_800  bg.ru.be_332 hi.bh.ne_532
  0x00003101, 0x1c211a04, 0x0c000d08, 0x231101a4,   // az.un.un_200 tl.jw.id_332  cs.sv.un_430 en.ro.ca_433
  // [11c0]
  0x07001002, 0x32291609, 0x040f10af, 0x1f5301a4,   // be.bg.un_220 hr.sl.bs_444  lt.lv.fi_655 en.ht.cy_433
  0x19000b23, 0x06000307, 0x1c090dad, 0x091c0d05,   // es.gl.un_880 nl.de.un_420  ne.hi.mr_643 ne.mr.hi_333
  0x18001307, 0x25193b07, 0x3b00190c, 0x0a11010c,   // et.ga.un_420 so.gl.eu_432  gl.so.un_530 en.ro.pt_543
  0x0a0417a0, 0x060c040c, 0x19000b1b, 0x10000408,   // sr.ru.mk_322 fi.sv.de_543  es.gl.un_770 ru.be.un_430
  // [11d0]
  0x06000c09, 0x19000b2c, 0x3525680e, 0x08022a02,   // sv.de.un_440 es.gl.un_990  ig.eu.zu_555 mt.da.no_222
  0x03002313, 0x32000d07, 0x0a23075a, 0x090d1c11,   // ca.nl.un_650 cs.bs.un_420  it.ca.pt_553 mr.ne.hi_653
  0x2d3f0d0d, 0x07170a13, 0x120d03a4, 0x07040a02,   // cs.af.sk_554 mk.sr.bg_665  nl.cs.hu_433 mk.ru.bg_222
  0x0d002902, 0x203503a7, 0x081017ad, 0x0d3135ad,   // sl.cs.un_220 nl.zu.sq_532  sr.be.uk_643 zu.az.cs_643
  // [11e0]
  0x27000507, 0x0a001c02, 0x03062508, 0x282b1bee,   // fr.gd.un_420 id.pt.un_220  eu.de.nl_443 tr.vi.sw_422
  0x21011302, 0x2b006b2a, 0x06030a09, 0x17080a07,   // et.en.jw_222 ceb.vi.un_970  pt.nl.de_444 mk.uk.sr_432
  0x170a0407, 0x12000a04, 0x113f12ee, 0x1a006b36,   // ru.mk.sr_432 pt.hu.un_320  hu.af.ro_422 ceb.tl.un_AA0
  0x061b0312, 0x10042011, 0x16042907, 0x0a070ba0,   // nl.tr.de_654 sq.fi.lt_653  sl.fi.hr_432 es.it.pt_322
  // [11f0]
  0x35002513, 0x04003204, 0x1e2b1ca0, 0x0d162d07,   // eu.zu.un_650 bs.fi.un_320  id.vi.ms_322 sk.hr.cs_432
  0x110a070c, 0x0d351ba4, 0x0a001222, 0x17080a04,   // bg.mk.ro_543 tr.zu.cs_433  hu.pt.un_870 mk.uk.sr_332
  0x04070aee, 0x03003513, 0x21000c07, 0x080a1007,   // mk.bg.ru_422 zu.nl.un_650  sv.jw.un_420 be.mk.uk_432
  0x08000607, 0x0d040c0c, 0x0f000608, 0x07000513,   // de.no.un_420 sv.fi.cs_543  de.lv.un_430 fr.it.un_650
  // [1200]
  0x27033fac, 0x23032b0c, 0x0d040604, 0x090d13ee,   // af.nl.gd_632 vi.nl.ca_543  de.fi.cs_332 bh.ne.hi_422
  0x06171605, 0x6e211207, 0x00002d03, 0x2b001a09,   // hr.sr.de_333 hu.jw.hmn_432  sk.un.un_300 tl.vi.un_440
  0x0f002919, 0x2a0d20ad, 0x07170aa0, 0x211128a0,   // sl.lv.un_750 sq.cs.mt_643  mk.sr.bg_322 sw.ro.jw_322
  0x07040814, 0x19250b07, 0x06001a02, 0x070501a4,   // uk.ru.bg_666 es.eu.gl_432  tl.de.un_220 en.fr.it_433
  // [1210]
  0x06001b12, 0x10040813, 0x3b000712, 0x01171602,   // tr.de.un_640 uk.ru.be_665  it.so.un_640 hr.sr.en_222
  0x2a001705, 0x03003f18, 0x2a00180c, 0x27003f04,   // sr.mt.un_330 af.nl.un_740  ga.mt.un_530 af.gd.un_320
  0x210c1708, 0x11080405, 0x0710040d, 0x070901a7,   // sr.sv.jw_443 ru.uk.ro_333  ru.be.bg_554 en.pl.it_532
  0x07170a08, 0x0d091309, 0x6b2a01a4, 0x10060fad,   // mk.sr.bg_443 bh.hi.ne_444  en.mt.ceb_433 lv.de.lt_643
  // [1220]
  0x100a17af, 0x202d290c, 0x292d0d5a, 0x100f0713,   // sr.mk.be_655 sl.sk.sq_543  cs.sk.sl_553 it.lv.lt_665
  0x18000108, 0x532a2107, 0x2d000302, 0x11040860,   // en.ga.un_430 jw.mt.ht_432  nl.sk.un_220 uk.ru.ro_664
  0x120f2907, 0x04081712, 0x172a10a4, 0x0d080204,   // sl.lv.hu_432 sr.uk.ru_654  lt.mt.sr_433 da.no.cs_332
  0x2d0d1fee, 0x2a000f1a, 0x04033f55, 0x3f000318,   // cy.cs.sk_422 lv.mt.un_760  af.nl.fi_442 nl.af.un_740
  // [1230]
  0x0a000707, 0x1008040d, 0x64002a1a, 0x32002a09,   // bg.mk.un_420 ru.uk.be_554  mt.lg.un_760 mt.bs.un_440
  0x1803270d, 0x251b3112, 0x10090f12, 0x3f000311,   // gd.nl.ga_554 az.tr.eu_654  lv.pl.lt_654 nl.af.un_630
  0x21252804, 0x032718a7, 0x0a071709, 0x291128a4,   // sw.eu.jw_332 ga.gd.nl_532  sr.bg.mk_444 sw.ro.sl_433
  0x0f292a60, 0x032718af, 0x032513a4, 0x0d092d55,   // mt.sl.lv_664 ga.gd.nl_655  et.eu.nl_433 sk.pl.cs_442
  // [1240]
  0x250c08af, 0x1f00641b, 0x04002802, 0x25001221,   // no.sv.eu_655 lg.cy.un_770  sw.fi.un_220 hu.eu.un_860
  0x0d130911, 0x6b081aec, 0x080425a0, 0x0b193ba7,   // hi.bh.ne_653 tl.no.ceb_644  eu.fi.no_322 so.gl.es_532
  0x0807100c, 0x04100808, 0x292a0f13, 0x1253250c,   // be.bg.uk_543 uk.be.ru_443  lv.mt.sl_665 eu.ht.hu_543
  0x070a04a4, 0x0b0a19a0, 0x04081709, 0x0400291a,   // ru.mk.bg_433 gl.pt.es_322  sr.uk.ru_444 sl.fi.un_760
  // [1250]
  0x23001109, 0x19052012, 0x290e2aa9, 0x13292a09,   // ro.ca.un_440 sq.fr.gl_654  mt.is.sl_544 mt.sl.et_444
  0x18033f12, 0x291b315a, 0x290f2a12, 0x17002508,   // af.nl.ga_654 az.tr.sl_553  mt.lv.sl_654 eu.sr.un_430
  0x190a23a9, 0x0c09100c, 0x04130ca9, 0x033f28af,   // ca.pt.gl_544 lt.pl.sv_543  sv.et.fi_544 sw.af.nl_655
  0x0a0717a9, 0x101e1c08, 0x02310804, 0x17000a12,   // sr.bg.mk_544 id.ms.lt_443  no.az.da_332 mk.sr.un_640
  // [1260]
  0x2900250c, 0x04000a22, 0x17080407, 0x101c1105,   // eu.sl.un_530 mk.ru.un_870  ru.uk.sr_432 ro.id.lt_333
  0x10130404, 0x2a53010c, 0x35321602, 0x07180407,   // fi.et.lt_332 en.ht.mt_543  hr.bs.zu_222 fi.ga.it_432
  0x1e001c2c, 0x1c005319, 0x19350ba7, 0x0300211b,   // id.ms.un_990 ht.id.un_750  es.zu.gl_532 jw.nl.un_770
  0x04131ba4, 0x0d171307, 0x3b005208, 0x6b000913,   // tr.et.fi_433 et.sr.cs_432  ha.so.un_430 pl.ceb.un_650
  // [1270]
  0x130504a0, 0x17002907, 0x17080404, 0x0306250d,   // fi.fr.et_322 sl.sr.un_420  ru.uk.sr_332 eu.de.nl_554
  0x13681b09, 0x05000a04, 0x201b350b, 0x23190ba0,   // tr.ig.et_444 pt.fr.un_320  zu.tr.sq_542 es.gl.ca_322
  0x07000412, 0x0a0701ee, 0x1b003f21, 0x07641b08,   // ru.bg.un_640 en.it.pt_422  af.tr.un_860 tr.lg.it_443
  0x03120f12, 0x6e6b010c, 0x1c521e08, 0x4a111255,   // lv.hu.nl_654 en.ceb.hmn_543  ms.ha.id_443 hu.ro.yo_442
  // [1280]
  0x3f031b0e, 0x6b001a13, 0x123b13ad, 0x062827ad,   // tr.nl.af_555 tl.ceb.un_650  et.so.hu_643 gd.sw.de_643
  0x211b1307, 0x06001f23, 0x01253f08, 0x64552511,   // et.tr.jw_432 cy.de.un_880  af.eu.en_443 eu.rw.lg_653
  0x1f230509, 0x641b5508, 0x0a3b19ee, 0x050601a4,   // fr.ca.cy_444 rw.tr.lg_443  gl.so.pt_422 en.de.fr_433
  0x06001c04, 0x0600272b, 0x211b1cee, 0x122d0d14,   // id.de.un_320 gd.de.un_980  id.tr.jw_422 cs.sk.hu_666
  // [1290]
  0x10213507, 0x06271804, 0x0e000d14, 0x020c06a7,   // zu.jw.lt_432 ga.gd.de_332  cs.is.un_660 de.sv.da_532
  0x0f002702, 0x170903a4, 0x1b004a19, 0x642006af,   // gd.lv.un_220 nl.pl.sr_433  yo.tr.un_750 de.sq.lg_655
  0x04132507, 0x07201b0b, 0x5220040c, 0x1300550d,   // eu.et.fi_432 tr.sq.it_542  fi.sq.ha_543 rw.et.un_540
  0x040711ee, 0x10000f13, 0x17000a08, 0x050723a4,   // ro.bg.ru_422 lv.lt.un_650  mk.sr.un_430 ca.it.fr_433
  // [12a0]
  0x0900110c, 0x683f030c, 0x1b520409, 0x3f000620,   // ro.pl.un_530 nl.af.ig_543  fi.ha.tr_444 de.af.un_850
  0x102b1107, 0x0a00060d, 0x1b530907, 0x520e0409,   // ro.vi.lt_432 de.pt.un_540  pl.ht.tr_432 fi.is.ha_444
  0x1b004a1b, 0x64211ca7, 0x35002914, 0x080c06a4,   // yo.tr.un_770 id.jw.lg_532  sl.zu.un_660 de.sv.no_433
  0x130435a4, 0x211c68af, 0x19040705, 0x55071b0c,   // zu.fi.et_433 ig.id.jw_655  it.fi.gl_333 tr.it.rw_543
  // [12b0]
  0x1c000204, 0x092d0d05, 0x0b231911, 0x550f1ba4,   // da.id.un_320 cs.sk.pl_333  gl.ca.es_653 tr.lv.rw_433
  0x2b002821, 0x233b010c, 0x120428ee, 0x1c002113,   // sw.vi.un_860 en.so.ca_543  sw.fi.hu_422 jw.id.un_650
  0x10000f0e, 0x3100200c, 0x01006b07, 0x270c010c,   // lv.lt.un_550 sq.az.un_530  ceb.en.un_420 en.sv.gd_543
  0x3b181308, 0x52282b0b, 0x0d0506ad, 0x17292d12,   // et.ga.so_443 vi.sw.ha_542  de.fr.cs_643 sk.sl.sr_654
  // [12c0]
  0x11000a0e, 0x0300062b, 0x2b280a60, 0x12002504,   // pt.ro.un_550 de.nl.un_980  pt.sw.vi_664 eu.hu.un_320
  0x020618ec, 0x2d0d090c, 0x3b00230d, 0x0c002a07,   // ga.de.da_644 pl.cs.sk_543  ca.so.un_540 mt.sv.un_420
  0x061f5255, 0x23000808, 0x20006804, 0x0c0a3f02,   // ha.cy.de_442 no.ca.un_430  ig.sq.un_320 af.pt.sv_222
  0x64002505, 0x04000c07, 0x1b0401a4, 0x2331520c,   // eu.lg.un_330 sv.fi.un_420  en.fi.tr_433 ha.az.ca_543
  // [12d0]
  0x13200414, 0x040710a0, 0x0c002104, 0x07170a0d,   // fi.sq.et_666 be.bg.ru_322  jw.sv.un_320 mk.sr.bg_554
  0x3b2a31a9, 0x25096b07, 0x0811040c, 0x52283bee,   // az.mt.so_544 ceb.pl.eu_432  ru.ro.uk_543 so.sw.ha_422
  0x1e282912, 0x32162902, 0x0a002b29, 0x29001b0d,   // sl.sw.ms_654 sl.hr.bs_222  vi.pt.un_960 tr.sl.un_540
  0x08000204, 0x17041009, 0x0b0a1fec, 0x0a002b18,   // da.no.un_320 be.ru.sr_444  cy.pt.es_644 vi.pt.un_740
  // [12e0]
  0x2b001a2a, 0x255535ad, 0x10090ca0, 0x31002008,   // tl.vi.un_970 zu.rw.eu_643  sv.pl.lt_322 sq.az.un_430
  0x09080c0d, 0x131c09ac, 0x35005507, 0x07041107,   // sv.no.pl_554 hi.mr.bh_632  rw.zu.un_420 ro.ru.bg_432
  0x0f001704, 0x170a11ec, 0x3f040304, 0x12002119,   // sr.lv.un_320 ro.mk.sr_644  nl.fi.af_332 fa.ur.un_750
  0x21321704, 0x6400350d, 0x12133104, 0x0c001004,   // sr.bs.jw_332 zu.lg.un_540  az.et.hu_332 lt.sv.un_320
  // [12f0]
  0x0d002b07, 0x1300040c, 0x1c090da0, 0x0e00181a,   // vi.cs.un_420 fi.et.un_530  ne.hi.mr_322 ga.is.un_760
  0x131c0907, 0x6b001a09, 0x186b1a08, 0x20000305,   // hi.mr.bh_432 tl.ceb.un_440  tl.ceb.ga_443 nl.sq.un_330
  0x17040802, 0x1a216bad, 0x0f002504, 0x2d0d0914,   // uk.ru.sr_222 ceb.jw.tl_643  eu.lv.un_320 pl.cs.sk_666
  0x010d0907, 0x1b0f0ea0, 0x3b250e0c, 0x1a006b0e,   // pl.cs.en_432 is.lv.tr_322  is.eu.so_543 ceb.tl.un_550
  // [1300]
  0x04070a09, 0x1f002719, 0x10030fee, 0x0c200fa4,   // mk.bg.ru_444 gd.cy.un_750  lv.nl.lt_422 lv.sq.sv_433
  0x520c1f0c, 0x08001304, 0x01060502, 0x08021f02,   // cy.sv.ha_543 et.no.un_320  fr.de.en_222 cy.da.no_222
  0x28005202, 0x253b2708, 0x0600080d, 0x1e2d0d0c,   // ha.sw.un_220 gd.so.eu_443  no.de.un_540 cs.sk.ms_543
  0x0f111205, 0x2d0d02a9, 0x35001a02, 0x0c086411,   // hu.ro.lv_333 da.cs.sk_544  tl.zu.un_220 lg.no.sv_653
  // [1310]
  0x27181a04, 0x07033f09, 0x04070a05, 0x17290fa4,   // tl.ga.gd_332 af.nl.it_444  mk.bg.ru_333 lv.sl.sr_433
  0x1f001905, 0x030b28ad, 0x1e083ba0, 0x13090dad,   // gl.cy.un_330 sw.es.nl_643  so.no.ms_322 ne.hi.bh_643
  0x31005307, 0x021b5307, 0x27351a04, 0x1008170c,   // ht.az.un_420 ht.tr.da_432  tl.zu.gd_332 sr.uk.be_543
  0x55002012, 0x17001b0c, 0x1b020807, 0x270e1f07,   // sq.rw.un_640 tr.sr.un_530  no.da.tr_432 cy.is.gd_432
  // [1320]
  0x2d3b6b0c, 0x3b003113, 0x0c08020c, 0x6b0d2dee,   // ceb.so.sk_543 az.so.un_650  da.no.sv_543 sk.cs.ceb_422
  0x09000313, 0x2d0d310e, 0x531b310c, 0x1b0f190d,   // nl.pl.un_650 az.cs.sk_555  az.tr.ht_543 gl.lv.tr_554
  0x6b551a13, 0x0b0a070b, 0x063f08a0, 0x1b004a14,   // tl.rw.ceb_665 it.pt.es_542  no.af.de_322 yo.tr.un_660
  0x1c2125a0, 0x0b0a1914, 0x102a4aa9, 0x21043f07,   // eu.jw.id_322 gl.pt.es_666  yo.mt.lt_544 af.fi.jw_432
  // [1330]
  0x080302ad, 0x6b001a19, 0x531b2302, 0x03000b04,   // da.nl.no_643 tl.ceb.un_750  ca.tr.ht_222 es.nl.un_320
  0x3b3135a4, 0x0e00521b, 0x1a006b2b, 0x3b0802a4,   // zu.az.so_433 ha.is.un_770  ceb.tl.un_980 da.no.so_433
  0x2a556b11, 0x0a0411ee, 0x0c3b6b0d, 0x071711a4,   // ceb.rw.mt_653 ro.ru.mk_422  ceb.so.sv_554 ro.sr.bg_433
  0x1e1c0e14, 0x04070aa9, 0x06001f12, 0x02131f60,   // is.id.ms_666 mk.bg.ru_544  cy.de.un_640 cy.et.da_664
  // [1340]
  0x6b292a04, 0x1c002004, 0x01004a05, 0x312d0d13,   // mt.sl.ceb_332 sq.id.un_320  yo.en.un_330 cs.sk.az_665
  0x13090d14, 0x213b4aee, 0x0a000718, 0x1f2d0d13,   // ne.hi.bh_666 yo.so.jw_422  bg.mk.un_740 cs.sk.cy_665
  0x00000b2d, 0x1c00130e, 0x1e1c2102, 0x2d3531a0,   // bn.un.un_A00 bh.mr.un_550  jw.id.ms_222 az.zu.sk_322
  0x292d0d13, 0x130c0807, 0x0f052304, 0x2a006b0d,   // cs.sk.sl_665 no.sv.et_432  ca.fr.lv_332 ceb.mt.un_540
  // [1350]
  0x3b00130d, 0x2a072312, 0x0a1711a0, 0x0300130c,   // et.so.un_540 ca.it.mt_654  ro.sr.mk_322 et.nl.un_530
  0x55126ba7, 0x21002704, 0x06080cee, 0x08041108,   // ceb.hu.rw_532 gd.jw.un_320  sv.no.de_422 ro.ru.uk_443
  0x1c0d09a7, 0x1e006b04, 0x201f0e0c, 0x321629a7,   // hi.ne.mr_532 ceb.ms.un_320  is.cy.sq_543 sl.hr.bs_532
  0x11000a05, 0x08000a14, 0x352832a0, 0x0d002d19,   // pt.ro.un_330 mk.uk.un_660  bs.sw.zu_322 sk.cs.un_750
  // [1360]
  0x0a110704, 0x07171008, 0x1c130914, 0x18001219,   // bg.ro.mk_332 be.sr.bg_443  hi.bh.mr_666 ur.ar.un_750
  0x1b321702, 0x17270e04, 0x283b1ea0, 0x6b1a6ea9,   // sr.bs.tr_222 is.gd.sr_332  ms.so.sw_322 hmn.tl.ceb_544
  0x00000c2d, 0x07040a09, 0x08031307, 0x09001c0e,   // sv.un.un_A00 mk.ru.bg_444  et.nl.no_432 mr.hi.un_550
  0x080417af, 0x6e000808, 0x08040a02, 0x6e6b1a0d,   // sr.ru.uk_655 no.hmn.un_430  mk.ru.uk_222 tl.ceb.hmn_554
  // [1370]
  0x1f000802, 0x19000a2c, 0x17001112, 0x121f10a0,   // no.cy.un_220 pt.gl.un_990  ro.sr.un_640 lt.cy.hu_322
  0x21001811, 0x27190a0d, 0x09001c19, 0x1f102007,   // ar.fa.un_630 pt.gl.gd_554  mr.hi.un_750 sq.lt.cy_432
  0x026b01ac, 0x19000a23, 0x3b286ead, 0x18190a05,   // en.ceb.da_632 pt.gl.un_880  hmn.sw.so_643 pt.gl.ga_333
  0x110208a7, 0x101711a0, 0x016e1ca0, 0x19000a0e,   // no.da.ro_532 ro.sr.be_322  id.hmn.en_322 pt.gl.un_550
  // [1380]
  0x08022b02, 0x1f190a13, 0x09290a08, 0x6e000314,   // vi.da.no_222 pt.gl.cy_665  pt.sl.pl_443 nl.hmn.un_660
  0x12001f0c, 0x12060d0c, 0x321617ec, 0x120e0a0b,   // cy.hu.un_530 cs.de.hu_543  sr.hr.bs_644 pt.is.hu_542
  0x091c0d11, 0x2d0d35af, 0x1106230b, 0x6e200d0c,   // ne.mr.hi_653 zu.cs.sk_655  ca.de.ro_542 cs.sq.hmn_543
  0x2d002908, 0x0d12290d, 0x27190a60, 0x27003b02,   // sl.sk.un_430 sl.hu.cs_554  pt.gl.gd_664 so.gd.un_220
  // [1390]
  0x0a001913, 0x060a0da9, 0x6e193bad, 0x063f02a4,   // gl.pt.un_650 cs.pt.de_544  so.gl.hmn_643 da.af.de_433
  0x20000802, 0x1a006b35, 0x13210aad, 0x6e005308,   // no.sq.un_220 ceb.tl.un_A90  pt.jw.et_643 ht.hmn.un_430
  0x1f3f1a60, 0x01000604, 0x0a230d08, 0x112d0d07,   // tl.af.cy_664 de.en.un_320  cs.ca.pt_443 cs.sk.ro_432
  0x170a110c, 0x1f0820a6, 0x080a0712, 0x10190a5a,   // ro.mk.sr_543 sq.no.cy_521  bg.mk.uk_654 pt.gl.lt_553
  // [13a0]
  0x312d0dee, 0x0b006402, 0x08000407, 0x64190a5a,   // cs.sk.az_422 lg.es.un_220  ru.uk.un_420 pt.gl.lg_553
  0x04001002, 0x0a000804, 0x020e0c60, 0x08100a05,   // be.ru.un_220 no.pt.un_320  sv.is.da_664 mk.be.uk_333
  0x04171007, 0x19000a05, 0x0a0d2307, 0x0a290daf,   // be.sr.ru_432 pt.gl.un_330  ca.cs.pt_432 cs.sl.pt_655
  0x0c160d07, 0x17290da4, 0x1c0d09af, 0x23000602,   // cs.hr.sv_432 cs.sl.sr_433  hi.ne.mr_655 de.ca.un_220
  // [13b0]
  0x040a0709, 0x20001705, 0x11070805, 0x29060da4,   // bg.mk.ru_444 sr.sq.un_330  uk.bg.ro_333 cs.de.sl_433
  0x00001c2d, 0x00001a24, 0x01002418, 0x3f2528ad,   // mr.un.un_A00 tl.un.un_900  yi.iw.un_740 sw.eu.af_643
  0x09131cad, 0x02000812, 0x06005302, 0x250564ec,   // mr.bh.hi_643 no.da.un_640  ht.de.un_220 lg.fr.eu_644
  0x2d0d5209, 0x2d0d0fa4, 0x292d0d02, 0x4a3564ad,   // ha.cs.sk_444 lv.cs.sk_433  cs.sk.sl_222 lg.zu.yo_643
  // [13c0]
  0x170a0755, 0x16290908, 0x3500640e, 0x21181204,   // bg.mk.sr_442 pl.sl.hr_443  lg.zu.un_550 ur.ar.fa_332
  0x103b07a0, 0x0c000604, 0x0b000504, 0x170a07a0,   // it.so.lt_322 de.sv.un_320  fr.es.un_320 bg.mk.sr_322
  0x0200080d, 0x08170aa0, 0x283b0404, 0x0a0411a4,   // no.da.un_540 mk.sr.uk_322  fi.so.sw_332 ro.ru.mk_433
  0x1c1309a4, 0x0c0802a7, 0x1300040e, 0x160d2dee,   // hi.bh.mr_433 da.no.sv_532  fi.et.un_550 sk.cs.hr_422
  // [13d0]
  0x53006402, 0x08020e02, 0x09006411, 0x68001308,   // lg.ht.un_220 is.da.no_222  lg.pl.un_630 et.ig.un_430
  0x08101702, 0x04001a02, 0x321204a0, 0x1e1c3b05,   // sr.be.uk_222 tl.fi.un_220  fi.hu.bs_322 so.id.ms_333
  0x68004a12, 0x3b006b0c, 0x0e000c0d, 0x1c001313,   // yo.ig.un_640 ceb.so.un_530  sv.is.un_540 bh.mr.un_650
  0x04071105, 0x0800170c, 0x2b001702, 0x11001714,   // ro.bg.ru_333 sr.uk.un_530  sr.vi.un_220 sr.ro.un_660
  // [13e0]
  0x1a005304, 0x04001312, 0x3b000108, 0x04001323,   // ht.tl.un_320 et.fi.un_640  en.so.un_430 et.fi.un_880
  0x04033fad, 0x08201fee, 0x0b033fa0, 0x25001f04,   // af.nl.fi_643 cy.sq.no_422  af.nl.es_322 cy.eu.un_320
  0x171629a4, 0x3b13040c, 0x08000202, 0x11002809,   // sl.hr.sr_433 fi.et.so_543  da.no.un_220 sw.ro.un_440
  0x4a001122, 0x3f3b01ad, 0x1a131104, 0x35210907,   // ro.yo.un_870 en.so.af_643  ro.et.tl_332 pl.jw.zu_432
  // [13f0]
  0x041a0e0c, 0x4a2529a0, 0x1b203bad, 0x016b09ad,   // is.tl.fi_543 sl.eu.yo_322  so.sq.tr_643 pl.ceb.en_643
  0x3f00032b, 0x07100804, 0x190b07ee, 0x350a110c,   // nl.af.un_980 uk.be.bg_332  it.es.gl_422 ro.pt.zu_543
  0x0c000814, 0x55000919, 0x0c2512a7, 0x12005304,   // no.sv.un_660 pl.rw.un_750  hu.eu.sv_532 ht.hu.un_320
  0x0408100c, 0x35001113, 0x2d000304, 0x10000914,   // be.uk.ru_543 ro.zu.un_650  nl.sk.un_320 pl.lt.un_660

  // [1400]
  0x6b2a1255, 0x0d2d105a, 0x04001009, 0x11080409,   // hu.mt.ceb_442 lt.sk.cs_553  be.ru.un_440 ru.uk.ro_444
  0x09006402, 0x2d000d07, 0x29001f05, 0x040a11a4,   // lg.pl.un_220 cs.sk.un_420  cy.sl.un_330 ro.mk.ru_433
  0x090306ad, 0x131f0c08, 0x2d0d0912, 0x2b3f0112,   // de.nl.pl_643 sv.cy.et_443  pl.cs.sk_654 en.af.vi_654
  0x0d291107, 0x64005312, 0x250411a4, 0x132d290c,   // ro.sl.cs_432 ht.lg.un_640  ro.fi.eu_433 sl.sk.et_543
  // [1410]
  0x0e000207, 0x0c2d0d13, 0x0a000702, 0x0c131a02,   // da.is.un_420 cs.sk.sv_665  bg.mk.un_220 tl.et.sv_222
  0x12002912, 0x12002508, 0x0d0a23a0, 0x681202ad,   // sl.hu.un_640 eu.hu.un_430  ca.pt.cs_322 da.hu.ig_643
  0x130c02a0, 0x321617af, 0x0a070805, 0x040810a9,   // da.sv.et_322 sr.hr.bs_655  uk.bg.mk_333 be.uk.ru_544
  0x0c000907, 0x0c3f08ee, 0x1f002002, 0x0d00290c,   // pl.sv.un_420 no.af.sv_422  sq.cy.un_220 sl.cs.un_530
  // [1420]
  0x2d0d290c, 0x25000c04, 0x2d120c12, 0x01002104,   // sl.cs.sk_543 sv.eu.un_320  sv.hu.sk_654 jw.en.un_320
  0x00000c24, 0x050c2104, 0x2d12640c, 0x1b002912,   // sv.un.un_900 jw.sv.fr_332  lg.hu.sk_543 sl.tr.un_640
  0x05005304, 0x110c1607, 0x1f003b19, 0x06003112,   // ht.fr.un_320 hr.sv.ro_432  so.cy.un_750 az.de.un_640
  0x16122907, 0x01002b04, 0x09000d04, 0x07000409,   // sl.hu.hr_432 vi.en.un_320  ne.hi.un_320 ru.bg.un_440
  // [1430]
  0x25002713, 0x182325a4, 0x090d1c08, 0x10081704,   // gd.eu.un_650 eu.ca.ga_433  mr.ne.hi_443 sr.uk.be_332
  0x0725180c, 0x21002505, 0x02232907, 0x2d290907,   // ga.eu.it_543 eu.jw.un_330  sl.ca.da_432 pl.sl.sk_432
  0x042508a0, 0x08111707, 0x3b280304, 0x182725af,   // no.eu.fi_322 sr.ro.uk_432  nl.sw.so_332 eu.gd.ga_655
  0x28680411, 0x09001305, 0x3f07040c, 0x27251812,   // fi.ig.sw_653 bh.hi.un_330  fi.it.af_543 ga.eu.gd_654
  // [1440]
  0x04080708, 0x07001005, 0x3b686e08, 0x20002702,   // bg.uk.ru_443 be.bg.un_330  hmn.ig.so_443 gd.sq.un_220
  0x28046814, 0x250627a4, 0x18001114, 0x040328a0,   // ig.fi.sw_666 gd.de.eu_433  ro.ga.un_660 sw.nl.fi_322
  0x03683b07, 0x1a316ba0, 0x216b01a0, 0x09350807,   // so.ig.nl_432 ceb.az.tl_322  en.ceb.jw_322 no.zu.pl_432
  0x04004a0d, 0x01035202, 0x2a1207a0, 0x090407ee,   // yo.fi.un_540 ha.nl.en_222  it.hu.mt_322 it.fi.pl_422
  // [1450]
  0x25681804, 0x3b003f21, 0x313f035a, 0x21530412,   // ga.ig.eu_332 af.so.un_860  nl.af.az_553 fi.ht.jw_654
  0x211812a7, 0x350e01a4, 0x0a170709, 0x204a0802,   // ur.ar.fa_532 en.is.zu_433  bg.sr.mk_444 no.yo.sq_222
  0x21001704, 0x3f3b1104, 0x55310507, 0x07080204,   // sr.jw.un_320 ro.so.af_332  fr.az.rw_432 da.no.it_332
  0x23000504, 0x1827250c, 0x03020e05, 0x0113250c,   // fr.ca.un_320 eu.gd.ga_543  is.da.nl_333 eu.et.en_543
  // [1460]
  0x271801ad, 0x110328a6, 0x1c090d05, 0x01003b19,   // en.ga.gd_643 sw.nl.ro_521  ne.hi.mr_333 so.en.un_750
  0x112107a0, 0x2527010b, 0x115335a0, 0x21001802,   // it.jw.ro_322 en.gd.eu_542  zu.ht.ro_322 ar.fa.un_220
  0x02030607, 0x0a001704, 0x1a3f68a7, 0x3f133b09,   // de.nl.da_432 sr.mk.un_320  ig.af.tl_532 so.et.af_444
  0x17081002, 0x27000b08, 0x190b2313, 0x060b04a4,   // be.uk.sr_222 es.gd.un_430  ca.es.gl_665 fi.es.de_433
  // [1470]
  0x3b001e02, 0x04076807, 0x100417a7, 0x520e3512,   // ms.so.un_220 ig.it.fi_432  sr.ru.be_532 zu.is.ha_654
  0x12006402, 0x08290c08, 0x08000419, 0x0b002a07,   // lg.hu.un_220 sv.sl.no_443  ru.uk.un_750 mt.es.un_420
  0x64001218, 0x2a1107ee, 0x071131a0, 0x03016b07,   // hu.lg.un_740 it.ro.mt_422  az.ro.it_322 ceb.en.nl_432
  0x04001007, 0x08120407, 0x3f2801a4, 0x0d1c1308,   // be.ru.un_420 fi.hu.no_432  en.sw.af_433 bh.mr.ne_443
  // [1480]
  0x040a1005, 0x0e0704a0, 0x1812210b, 0x080235ee,   // be.mk.ru_333 fi.it.is_322  fa.ur.ar_542 zu.da.no_422
  0x0800021b, 0x53003505, 0x070817a0, 0x12211811,   // da.no.un_770 zu.ht.un_330  sr.uk.bg_322 ar.fa.ur_653
  0x091c130d, 0x0c000607, 0x53524a07, 0x020306ad,   // bh.mr.hi_554 de.sv.un_420  yo.ha.ht_432 de.nl.da_643
  0x3f0b6b02, 0x036b06ee, 0x1c091302, 0x4a03680e,   // ceb.es.af_222 de.ceb.nl_422  bh.hi.mr_222 ig.nl.yo_555
  // [1490]
  0x191f0b0c, 0x170a11ad, 0x0d1c09a4, 0x09131c11,   // es.cy.gl_543 ro.mk.sr_643  hi.mr.ne_433 mr.bh.hi_653
  0x4a006804, 0x281c1ea4, 0x2a000214, 0x0a001104,   // ig.yo.un_320 ms.id.sw_433  da.mt.un_660 ro.mk.un_320
  0x03004a08, 0x28215204, 0x68015307, 0x091c130c,   // yo.nl.un_430 ha.jw.sw_332  ht.en.ig_432 bh.mr.hi_543
  0x6400550e, 0x1c1b1e08, 0x08000911, 0x52286eee,   // rw.lg.un_550 ms.tr.id_443  pl.no.un_630 hmn.sw.ha_422
  // [14a0]
  0x213b1b0e, 0x191f2308, 0x4a006814, 0x29172d0c,   // tr.so.jw_555 ca.cy.gl_443  ig.yo.un_660 sk.sr.sl_543
  0x041708a0, 0x1e1c01a4, 0x1b0e25ad, 0x1a003b07,   // uk.sr.ru_322 en.id.ms_433  eu.is.tr_643 so.tl.un_420
  0x17003504, 0x1a006e1a, 0x3b00101b, 0x1227070d,   // zu.sr.un_320 hmn.tl.un_760  lt.so.un_770 it.gd.hu_554
  0x2b076b07, 0x640c08a0, 0x0400082c, 0x52130fa4,   // ceb.it.vi_432 no.sv.lg_322  uk.ru.un_990 lv.et.ha_433
  // [14b0]
  0x2a00040e, 0x00005324, 0x3b00530e, 0x190a0baf,   // fi.mt.un_550 ht.un.un_900  ht.so.un_550 es.pt.gl_655
  0x3b641f0d, 0x13190b0c, 0x0f2a3b08, 0x09531f04,   // cy.lg.so_554 es.gl.et_543  so.mt.lv_443 cy.ht.pl_332
  0x050a0107, 0x6e1f1a12, 0x1f1807ec, 0x093b1fad,   // en.pt.fr_432 tl.cy.hmn_654  it.ga.cy_644 cy.so.pl_643
  0x13003204, 0x3f001f04, 0x0c3510a4, 0x3b211a0c,   // bs.et.un_320 cy.af.un_320  lt.zu.sv_433 tl.jw.so_543
  // [14c0]
  0x0c003202, 0x06000e07, 0x250523a0, 0x07052a07,   // bs.sv.un_220 is.de.un_420  ca.fr.eu_322 mt.fr.it_432
  0x1e1c2107, 0x1b1231ec, 0x02001307, 0x061b31af,   // jw.id.ms_432 az.hu.tr_644  et.da.un_420 az.tr.de_655
  0x17090d07, 0x0e4a19a9, 0x311b3b13, 0x1b002102,   // cs.pl.sr_432 gl.yo.is_544  so.tr.az_665 jw.tr.un_220
  0x040a075a, 0x2d2a0d0c, 0x12311ba4, 0x12002902,   // bg.mk.ru_553 cs.mt.sk_543  tr.az.hu_433 sl.hu.un_220
  // [14d0]
  0x01005304, 0x6b681204, 0x04000d0d, 0x2d000c0c,   // ht.en.un_320 hu.ig.ceb_332  cs.fi.un_540 sv.sk.un_530
  0x310f1ba9, 0x0a00172a, 0x1c1e12ad, 0x2a1f6eec,   // tr.lv.az_544 sr.mk.un_970  hu.ms.id_643 hmn.cy.mt_644
  0x3b002a12, 0x02003f02, 0x170410a4, 0x0d001c14,   // mt.so.un_640 af.da.un_220  be.ru.sr_433 mr.ne.un_660
  0x04000c19, 0x1e1c0ea4, 0x0a100707, 0x21001223,   // sv.fi.un_750 is.id.ms_433  bg.be.mk_432 ur.fa.un_880
  // [14e0]
  0x070a1760, 0x1b0b1207, 0x19000b19, 0x13080208,   // sr.mk.bg_664 hu.es.tr_432  es.gl.un_750 da.no.et_443
  0x110a0714, 0x0d130908, 0x11001e02, 0x0a1708ee,   // bg.mk.ro_666 hi.bh.ne_443  ms.ro.un_220 uk.sr.mk_422
  0x170810a0, 0x2000100e, 0x2112180d, 0x1b123105,   // be.uk.sr_322 lt.sq.un_550  ar.ur.fa_554 az.hu.tr_333
  0x20100404, 0x1b123104, 0x231e1b05, 0x08021fa4,   // fi.lt.sq_332 az.hu.tr_332  tr.ms.ca_333 cy.da.no_433
  // [14f0]
  0x20000412, 0x041020ad, 0x17000712, 0x32171602,   // fi.sq.un_640 sq.lt.fi_643  bg.sr.un_640 hr.sr.bs_222
  0x21121814, 0x20321b0e, 0x04000f0d, 0x211c1eec,   // ar.ur.fa_666 tr.bs.sq_555  lv.fi.un_540 ms.id.jw_644
  0x07041104, 0x2b005305, 0x0800041a, 0x04000708,   // ro.ru.bg_332 ht.vi.un_330  ru.uk.un_760 bg.ru.un_430
  0x090d13ac, 0x1c203ba7, 0x213f0304, 0x4a001819,   // bh.ne.hi_632 so.sq.id_532  nl.af.jw_332 ga.yo.un_750
  // [1500]
  0x32002902, 0x1b005322, 0x04101707, 0x52003b04,   // sl.bs.un_220 ht.tr.un_870  sr.be.ru_432 so.ha.un_320
  0x130c04a0, 0x533b280b, 0x106b1aa4, 0x03003f12,   // fi.sv.et_322 sw.so.ht_542  tl.ceb.lt_433 af.nl.un_640
  0x0a0408a6, 0x030f0911, 0x32171613, 0x0f002b0c,   // uk.ru.mk_521 pl.lv.nl_653  hr.sr.bs_665 vi.lv.un_530
  0x2a00200c, 0x0f000923, 0x1b006419, 0x200f10a4,   // sq.mt.un_530 pl.lv.un_880  lg.tr.un_750 lt.lv.sq_433
  // [1510]
  0x17070a12, 0x09000f1a, 0x043119ee, 0x10643ba9,   // mk.bg.sr_654 lv.pl.un_760  gl.az.fi_422 so.lg.lt_544
  0x0f000914, 0x0d002d0c, 0x1218210e, 0x1f001308,   // pl.lv.un_660 sk.cs.un_530  fa.ar.ur_555 et.cy.un_430
  0x09002d05, 0x1800271b, 0x520131ee, 0x2d090fee,   // sk.pl.un_330 gd.ga.un_770  az.en.ha_422 lv.pl.sk_422
  0x3b202805, 0x18002712, 0x0f002d1a, 0x3100101a,   // sw.sq.so_333 gd.ga.un_640  sk.lv.un_760 lt.az.un_760
  // [1520]
  0x2d2511ee, 0x11040814, 0x6b255307, 0x16003204,   // ro.eu.sk_422 uk.ru.ro_666  ht.eu.ceb_432 bs.hr.un_320
  0x31001902, 0x0717110c, 0x071710ad, 0x0a00050d,   // gl.az.un_220 ro.sr.bg_543  be.sr.bg_643 fr.pt.un_540
  0x0000320a, 0x31000a09, 0x1a006b22, 0x1b3b0ea7,   // bs.un.un_500 pt.az.un_440  ceb.tl.un_870 is.so.tr_532
  0x0d0913a4, 0x0e000c07, 0x09002d0c, 0x27001813,   // bh.hi.ne_433 sv.is.un_420  sk.pl.un_530 ga.gd.un_650
  // [1530]
  0x04060c0d, 0x04000c0d, 0x212301a0, 0x042a0708,   // sv.de.fi_554 sv.fi.un_540  en.ca.jw_322 it.mt.fi_443
  0x12000205, 0x0b002d08, 0x1000080d, 0x04000608,   // da.hu.un_330 sk.es.un_430  uk.be.un_540 de.fi.un_430
  0x08100407, 0x1a000302, 0x29321602, 0x2112180e,   // ru.be.uk_432 nl.tl.un_220  hr.bs.sl_222 ar.ur.fa_555
  0x1200090c, 0x170a07a9, 0x1a28520c, 0x55006b05,   // pl.hu.un_530 bg.mk.sr_544  ha.sw.tl_543 ceb.rw.un_330
  // [1540]
  0x6b1e1a0d, 0x00002437, 0x0435520b, 0x07170a02,   // tl.ms.ceb_554 yi.un.un_B00  ha.zu.fi_542 mk.sr.bg_222
  0x1f003b05, 0x52282104, 0x10040860, 0x1b535504,   // so.cy.un_330 jw.sw.ha_332  uk.ru.be_664 rw.ht.tr_332
  0x0900290c, 0x556406ec, 0x080c1214, 0x12110505,   // sl.pl.un_530 de.lg.rw_644  hu.sv.no_666 fr.ro.hu_333
  0x53000104, 0x20003b1b, 0x28002909, 0x5228255a,   // en.ht.un_320 so.sq.un_770  sl.sw.un_440 eu.sw.ha_553
  // [1550]
  0x0c000b02, 0x18002b02, 0x0e005209, 0x17080aa0,   // es.sv.un_220 vi.ga.un_220  ha.is.un_440 mk.uk.sr_322
  0x271e1c0d, 0x0925120e, 0x0e000104, 0x0800102b,   // id.ms.gd_554 hu.eu.pl_555  en.is.un_320 be.uk.un_980
  0x2100520e, 0x645507a9, 0x06080e0c, 0x35000a04,   // ha.jw.un_550 it.rw.lg_544  is.no.de_543 pt.zu.un_320
  0x20295307, 0x682852a4, 0x28005207, 0x28524a12,   // ht.sl.sq_432 ha.sw.ig_433  ha.sw.un_420 yo.ha.sw_654
  // [1560]
  0x1b043ba4, 0x05004a07, 0x2952350d, 0x293552ee,   // so.fi.tr_433 yo.fr.un_420  zu.ha.sl_554 ha.zu.sl_422
  0x1f080204, 0x01640f07, 0x09211aee, 0x1c002704,   // da.no.cy_332 lv.lg.en_432  tl.jw.pl_422 gd.id.un_320
  0x18273512, 0x0a131908, 0x06002519, 0x53192304,   // zu.gd.ga_654 gl.et.pt_443  eu.de.un_750 ca.gl.ht_332
  0x201f0e05, 0x1000350c, 0x530428ad, 0x2a033ba9,   // is.cy.sq_333 zu.lt.un_530  sw.fi.ht_643 so.nl.mt_544
  // [1570]
  0x03003f09, 0x211b1c08, 0x53003f21, 0x042916a0,   // af.nl.un_440 id.tr.jw_443  af.ht.un_860 hr.sl.fi_322
  0x18001214, 0x3f3b03a4, 0x06640811, 0x31001b05,   // ur.ar.un_660 nl.so.af_433  no.lg.de_653 tr.az.un_330
  0x06120eaf, 0x4a2b1c08, 0x06000112, 0x32163bee,   // is.hu.de_655 id.vi.yo_443  en.de.un_640 so.hr.bs_422
  0x3f0306af, 0x0c09100e, 0x0f000e19, 0x1b0f2955,   // de.nl.af_655 lt.pl.sv_555  is.lv.un_750 sl.lv.tr_442
  // [1580]
  0x1b1f0612, 0x1a215309, 0x062d0d5a, 0x2000211a,   // de.cy.tr_654 ht.jw.tl_444  cs.sk.de_553 jw.sq.un_760
  0x5300210c, 0x0f2d0e05, 0x16095304, 0x230b010c,   // jw.ht.un_530 is.sk.lv_333  ht.pl.hr_332 en.es.ca_543
  0x170408a9, 0x04110704, 0x06005307, 0x5209640c,   // uk.ru.sr_544 bg.ro.ru_332  ht.de.un_420 lg.pl.ha_543
  0x53000909, 0x0a040760, 0x010507a0, 0x35002819,   // pl.ht.un_440 bg.ru.mk_664  it.fr.en_322 sw.zu.un_750
  // [1590]
  0x0618520c, 0x1b000912, 0x13000d1a, 0x6e285512,   // ha.ga.de_543 pl.tr.un_640  ne.bh.un_760 rw.sw.hmn_654
  0x5500060d, 0x05045307, 0x323555a4, 0x3f00060c,   // de.rw.un_540 ht.fi.fr_432  rw.zu.bs_433 de.af.un_530
  0x083f040c, 0x1f002a1a, 0x041711a0, 0x1a6b25a4,   // fi.af.no_543 mt.cy.un_760  ro.sr.ru_322 eu.ceb.tl_433
  0x35005514, 0x1e211c0c, 0x6b1b5308, 0x03003f19,   // rw.zu.un_660 id.jw.ms_543  ht.tr.ceb_443 af.nl.un_750
  // [15a0]
  0x190b4a14, 0x31091bec, 0x0a003f05, 0x17083504,   // yo.es.gl_666 tr.pl.az_644  af.pt.un_330 zu.no.sr_332
  0x0e002507, 0x17001312, 0x170410ee, 0x0a0704af,   // eu.is.un_420 et.sr.un_640  be.ru.sr_422 ru.bg.mk_655
  0x0c001218, 0x0a071713, 0x11060ca0, 0x23075555,   // hu.sv.un_740 sr.bg.mk_665  sv.de.ro_322 rw.it.ca_442
  0x522d0d02, 0x07001805, 0x2112180c, 0x1218215a,   // cs.sk.ha_222 ga.it.un_330  ar.ur.fa_543 fa.ar.ur_553
  // [15b0]
  0x31002a09, 0x2d001902, 0x35552812, 0x04110a13,   // mt.az.un_440 gl.sk.un_220  sw.rw.zu_654 mk.ro.ru_665
  0x0c0604ec, 0x2d4a0e05, 0x08020d0c, 0x2d120d12,   // fi.de.sv_644 is.yo.sk_333  cs.da.no_543 cs.hu.sk_654
  0x4a00180c, 0x3f000322, 0x2d070d04, 0x27000e0c,   // ga.yo.un_530 nl.af.un_870  cs.it.sk_332 is.gd.un_530
  0x070501a0, 0x04000c13, 0x2d0d0aee, 0x122d0d09,   // en.fr.it_322 sv.fi.un_650  pt.cs.sk_422 cs.sk.hu_444
  // [15c0]
  0x2d0d6eee, 0x190a23ee, 0x07000812, 0x0417110c,   // hmn.cs.sk_422 ca.pt.gl_422  uk.bg.un_640 ro.sr.ru_543
  0x0a1f23af, 0x6b235508, 0x551a21a4, 0x23001104,   // ca.cy.pt_655 rw.ca.ceb_443  jw.tl.rw_433 ro.ca.un_320
  0x07001a11, 0x0500230c, 0x070a0407, 0x0e001a08,   // tl.it.un_630 ca.fr.un_530  ru.mk.bg_432 tl.is.un_430
  0x061f20ee, 0x04000c04, 0x55001a22, 0x04130cee,   // sq.cy.de_422 sv.fi.un_320  tl.rw.un_870 sv.et.fi_422
  // [15d0]
  0x190a230c, 0x29001014, 0x1e1c55a9, 0x11002304,   // ca.pt.gl_543 lt.sl.un_660  rw.id.ms_544 ca.ro.un_320
  0x071e1c02, 0x2d000c0d, 0x0a101702, 0x2d290da4,   // id.ms.it_222 sv.sk.un_540  sr.be.mk_222 cs.sl.sk_433
  0x25002702, 0x20230a0b, 0x4a1f07a0, 0x08170405,   // gd.eu.un_220 pt.ca.sq_542  it.cy.yo_322 ru.sr.uk_333
  0x11190a13, 0x2a060708, 0x00001724, 0x10040a02,   // pt.gl.ro_665 it.de.mt_443  sr.un.un_900 mk.ru.be_222
  // [15e0]
  0x1b201309, 0x520955af, 0x1b351309, 0x0e07640d,   // et.sq.tr_444 rw.pl.ha_655  et.zu.tr_444 lg.it.is_554
  0x1c090d11, 0x0a1710ee, 0x06040c0c, 0x2500110c,   // ne.hi.mr_653 be.sr.mk_422  sv.fi.de_543 ro.eu.un_530
  0x17351355, 0x080a1104, 0x05532b0c, 0x172d0dad,   // et.zu.sr_442 ro.mk.uk_332  vi.ht.fr_543 cs.sk.sr_643
  0x07000d04, 0x23000a14, 0x526b1aa4, 0x04081105,   // cs.it.un_320 pt.ca.un_660  tl.ceb.ha_433 ro.uk.ru_333
  // [15f0]
  0x11030709, 0x32002308, 0x0d002d18, 0x080213ec,   // it.nl.ro_444 ca.bs.un_430  sk.cs.un_740 et.da.no_644
  0x32002908, 0x1f11230c, 0x110a23ec, 0x213555a6,   // sl.bs.un_430 ca.ro.cy_543  ca.pt.ro_644 rw.zu.jw_521
  0x1821125a, 0x3b1f0ca4, 0x110a23a4, 0x3b003119,   // ur.fa.ar_553 sv.cy.so_433  ca.pt.ro_433 az.so.un_750
  0x312d0d14, 0x0c002b07, 0x2d0d290e, 0x0f350908,   // cs.sk.az_666 vi.sv.un_420  sl.cs.sk_555 pl.zu.lv_443
  // [1600]
  0x21000c04, 0x1b6420ec, 0x0a1704a4, 0x0a101707,   // sv.jw.un_320 sq.lg.tr_644  ru.sr.mk_433 sr.be.mk_432
  0x0f1025a4, 0x10070807, 0x1c281ea0, 0x351301a0,   // eu.lt.lv_433 uk.bg.be_432  ms.sw.id_322 en.et.zu_322
  0x21021c07, 0x2b274a0c, 0x25211011, 0x04001108,   // id.da.jw_432 yo.gd.vi_543  lt.jw.eu_653 ro.ru.un_430
  0x0c000612, 0x52116ba7, 0x06020ca4, 0x04100712,   // de.sv.un_640 ceb.ro.ha_532  sv.da.de_433 bg.be.ru_654
  // [1610]
  0x2b004a14, 0x6b101aa0, 0x07000414, 0x211e1cee,   // yo.vi.un_660 tl.lt.ceb_322  ru.bg.un_660 id.ms.jw_422
  0x351a5505, 0x6b100c07, 0x523b1ea4, 0x04004a0e,   // rw.tl.zu_333 sv.lt.ceb_432  ms.so.ha_433 yo.fi.un_550
  0x07170dee, 0x64285255, 0x11002819, 0x030720ee,   // cs.sr.it_422 ha.sw.lg_442  sw.ro.un_750 sq.it.nl_422
  0x0d005221, 0x2b00270e, 0x4a002b21, 0x32002d04,   // ha.cs.un_860 gd.vi.un_550  vi.yo.un_860 sk.bs.un_320
  // [1620]
  0x05075505, 0x55003514, 0x07004a07, 0x106455ec,   // rw.it.fr_333 zu.rw.un_660  yo.it.un_420 rw.lg.lt_644
  0x5303060c, 0x052801a4, 0x52090dac, 0x20283b11,   // de.nl.ht_543 en.sw.fr_433  cs.pl.ha_632 so.sw.sq_653
  0x0a080407, 0x21121811, 0x06010d02, 0x17070a55,   // ru.uk.mk_432 ar.ur.fa_653  cs.en.de_222 mk.bg.sr_442
  0x171011a4, 0x07002a0e, 0x6b12350d, 0x11350704,   // ro.be.sr_433 mt.it.un_550  zu.hu.ceb_554 it.zu.ro_332
  // [1630]
  0x27002a12, 0x552812a4, 0x35005519, 0x101c3bad,   // mt.gd.un_640 hu.sw.rw_433  rw.zu.un_750 so.id.lt_643
  0x3f312008, 0x6411200c, 0x1a6b530c, 0x07004a0c,   // sq.az.af_443 sq.ro.lg_543  ht.ceb.tl_543 yo.it.un_530
  0x351255ad, 0x55002821, 0x35106407, 0x322d1760,   // rw.hu.zu_643 sw.rw.un_860  lg.lt.zu_432 sr.sk.bs_664
  0x29160da4, 0x10000413, 0x0900550c, 0x072a11a4,   // cs.hr.sl_433 fi.lt.un_650  rw.pl.un_530 ro.mt.it_433
  // [1640]
  0x103568ee, 0x1a000d04, 0x193f53a0, 0x092d0d14,   // ig.zu.lt_422 cs.tl.un_320  ht.af.gl_322 cs.sk.pl_666
  0x27281808, 0x020752a4, 0x17070dee, 0x190b01a4,   // ga.sw.gd_443 ha.it.da_433  cs.it.sr_422 en.es.gl_433
  0x05060107, 0x0e000a08, 0x681806ee, 0x6e2028a6,   // en.de.fr_432 pt.is.un_430  de.ga.ig_422 sw.sq.hmn_521
  0x2a110704, 0x07000819, 0x55283560, 0x55642805,   // it.ro.mt_332 uk.bg.un_750  zu.sw.rw_664 sw.lg.rw_333
  // [1650]
  0x21001f04, 0x55646808, 0x64285513, 0x3f120305,   // cy.jw.un_320 ig.lg.rw_443  rw.sw.lg_665 nl.hu.af_333
  0x0c1c3f07, 0x53231c04, 0x29002d09, 0x1a55230c,   // af.id.sv_432 id.ca.ht_332  sk.sl.un_440 ca.rw.tl_543
  0x5500351b, 0x2a55075a, 0x102328a0, 0x53002d08,   // zu.rw.un_770 it.rw.mt_553  sw.ca.lt_322 sk.ht.un_430
  0x08110e07, 0x1708070e, 0x3f0612ee, 0x1b001122,   // is.ro.no_432 bg.uk.sr_555  hu.de.af_422 ro.tr.un_870
  // [1660]
  0x0d292d04, 0x03083fa9, 0x02003502, 0x0c310602,   // sk.sl.cs_332 af.no.nl_544  zu.da.un_220 de.az.sv_222
  0x060c0412, 0x066b0107, 0x5500010c, 0x112301a9,   // fi.sv.de_654 en.ceb.de_432  en.rw.un_530 en.ca.ro_544
  0x080e1f11, 0x17001111, 0x0a110707, 0x35001b08,   // cy.is.no_653 ro.sr.un_630  bg.ro.mk_432 tr.zu.un_430
  0x35003f02, 0x16002905, 0x09003b05, 0x0700040d,   // af.zu.un_220 sl.hr.un_330  so.pl.un_330 ru.bg.un_540
  // [1670]
  0x2d0d09af, 0x0d092d12, 0x092d0d0e, 0x21181209,   // pl.cs.sk_655 sk.pl.cs_654  cs.sk.pl_555 ur.ar.fa_444
  0x010629a0, 0x041708af, 0x08070a0c, 0x1c090da4,   // sl.de.en_322 uk.sr.ru_655  mk.bg.uk_543 ne.hi.mr_433
  0x1c090dee, 0x0c00530d, 0x2d0d1007, 0x110407af,   // ne.hi.mr_422 ht.sv.un_540  lt.cs.sk_432 bg.ru.ro_655
  0x0c3b080c, 0x0c3b130c, 0x23190b04, 0x0d1c090d,   // no.so.sv_543 et.so.sv_543  es.gl.ca_332 hi.mr.ne_554
  // [1680]
  0x06000c14, 0x070408af, 0x03083f05, 0x0c000613,   // sv.de.un_660 uk.ru.bg_655  af.no.nl_333 de.sv.un_650
  0x0d2d4aad, 0x07010507, 0x0c030aa0, 0x1c0d09ec,   // yo.sk.cs_643 fr.en.it_432  pt.nl.sv_322 hi.ne.mr_644
  0x190a03ee, 0x070410a0, 0x06001211, 0x64003f08,   // nl.pt.gl_422 be.ru.bg_322  hu.de.un_630 af.lg.un_430
  0x0a000708, 0x066b01a4, 0x1312040d, 0x11013fa0,   // bg.mk.un_430 en.ceb.de_433  fi.hu.et_554 af.en.ro_322
  // [1690]
  0x0f172912, 0x0f002704, 0x02270304, 0x17070a05,   // sl.sr.lv_654 gd.lv.un_320  nl.gd.da_332 mk.bg.sr_333
  0x071104af, 0x23000508, 0x09060d14, 0x29100904,   // ru.ro.bg_655 fr.ca.un_430  cs.de.pl_666 pl.lt.sl_332
  0x291827ee, 0x20311eee, 0x101b0fa0, 0x181123a0,   // gd.ga.sl_422 ms.az.sq_422  lv.tr.lt_322 ca.ro.ga_322
  0x08000c09, 0x1b002519, 0x23001704, 0x08070407,   // sv.no.un_440 eu.tr.un_750  sr.ca.un_320 ru.bg.uk_432
  // [16a0]
  0x2725080c, 0x10001705, 0x0000160f, 0x0900070c,   // no.eu.gd_543 sr.lt.un_330  hr.un.un_600 it.pl.un_530
  0x0e0d0aa9, 0x0e0c1c07, 0x10002009, 0x0a4a18a9,   // pt.cs.is_544 id.sv.is_432  sq.lt.un_440 ga.yo.pt_544
  0x06271813, 0x3b001312, 0x162d0d04, 0x4a0e18ec,   // ga.gd.de_665 et.so.un_640  cs.sk.hr_332 ga.is.yo_644
  0x102d0d08, 0x1b001111, 0x64004a07, 0x03083fee,   // cs.sk.lt_443 ro.tr.un_630  yo.lg.un_420 af.no.nl_422
  // [16b0]
  0x040b20a7, 0x3b030607, 0x170a1109, 0x18002b21,   // sq.es.fi_532 de.nl.so_432  ro.mk.sr_444 vi.ga.un_860
  0x3f000319, 0x2d184a5a, 0x07020812, 0x1c000d1b,   // nl.af.un_750 yo.ga.sk_553  no.da.it_654 ne.mr.un_770
  0x4a180ead, 0x2a0501ec, 0x1b002513, 0x4a001822,   // is.ga.yo_643 en.fr.mt_644  eu.tr.un_650 ga.yo.un_870
  0x2b0c10ee, 0x0a0704a4, 0x170a040d, 0x0e1125ad,   // lt.sv.vi_422 ru.bg.mk_433  ru.mk.sr_554 eu.ro.is_643
  // [16c0]
  0x0400100b, 0x08250e0c, 0x1f00250c, 0x0900100c,   // be.ru.un_520 is.eu.no_543  eu.cy.un_530 lt.pl.un_530
  0x1200181b, 0x4a000e1b, 0x180d4a13, 0x0c00040d,   // ga.hu.un_770 is.yo.un_770  yo.cs.ga_665 fi.sv.un_540
  0x00002324, 0x0d2d090d, 0x2b0e0a08, 0x060810a4,   // ca.un.un_900 pl.sk.cs_554  pt.is.vi_443 lt.no.de_433
  0x0000182d, 0x03023513, 0x20000302, 0x08003f02,   // ga.un.un_A00 zu.da.nl_665  nl.sq.un_220 af.no.un_220
  // [16d0]
  0x0a1711a9, 0x0f001022, 0x1b105507, 0x2000030d,   // ro.sr.mk_544 lt.lv.un_870  rw.lt.tr_432 nl.sq.un_540
  0x2d0d10af, 0x53000502, 0x252d0d0d, 0x0900100d,   // lt.cs.sk_655 fr.ht.un_220  cs.sk.eu_554 lt.pl.un_540
  0x17000a11, 0x17070aa9, 0x5500640d, 0x21556411,   // mk.sr.un_630 mk.bg.sr_544  lg.rw.un_540 lg.rw.jw_653
  0x55281008, 0x10000819, 0x04100704, 0x09001021,   // lt.sw.rw_443 uk.be.un_750  bg.be.ru_332 lt.pl.un_860
  // [16e0]
  0x0900101a, 0x2500641b, 0x09000d05, 0x01006b05,   // lt.pl.un_760 lg.eu.un_770  ne.hi.un_330 ceb.en.un_330
  0x0f1710ad, 0x5535520c, 0x080417a0, 0x05001902,   // lt.sr.lv_643 ha.zu.rw_543  sr.ru.uk_322 gl.fr.un_220
  0x09003507, 0x120c0213, 0x1f000104, 0x01533fa7,   // zu.pl.un_420 da.sv.hu_665  en.cy.un_320 af.ht.en_532
  0x04090b55, 0x55352804, 0x0e282a05, 0x030f3fa4,   // es.pl.fi_442 sw.zu.rw_332  mt.sw.is_333 af.lv.nl_433
  // [16f0]
  0x1a211ca0, 0x0600091b, 0x090f035a, 0x3f030ca4,   // id.jw.tl_322 pl.de.un_770  nl.lv.pl_553 sv.nl.af_433
  0x0c0208af, 0x0c3f2a02, 0x2a641fad, 0x06030ca0,   // no.da.sv_655 mt.af.sv_222  cy.lg.mt_643 sv.nl.de_322
  0x091c0d0d, 0x0c00040c, 0x0400111a, 0x10001607,   // ne.mr.hi_554 fi.sv.un_530  ro.ru.un_760 hr.lt.un_420
  0x10002d08, 0x55093f12, 0x1a3f0407, 0x1f6428ad,   // sk.lt.un_430 af.pl.rw_654  fi.af.tl_432 sw.lg.cy_643
  // [1700]
  0x10645308, 0x2a060713, 0x5300101a, 0x17100411,   // ht.lg.lt_443 it.de.mt_665  lt.ht.un_760 ru.be.sr_653
  0x2d102a07, 0x07000c02, 0x0900201a, 0x3f000908,   // mt.lt.sk_432 sv.it.un_220  sq.pl.un_760 pl.af.un_430
  0x07000f11, 0x4a005319, 0x091c21a4, 0x040f2d11,   // lv.it.un_630 ht.yo.un_750  jw.id.pl_433 sk.lv.fi_653
  0x55006419, 0x09000622, 0x3b00212a, 0x09211a12,   // lg.rw.un_750 de.pl.un_870  jw.so.un_970 tl.jw.pl_654
  // [1710]
  0x1b002a07, 0x3200170e, 0x18033fad, 0x1f2a0e0e,   // mt.tr.un_420 sr.bs.un_550  af.nl.ga_643 is.mt.cy_555
  0x5512640c, 0x3f0327a4, 0x281a52ee, 0x0c080705,   // lg.hu.rw_543 gd.nl.af_433  ha.tl.sw_422 it.no.sv_333
  0x2d004a0e, 0x08171104, 0x05640707, 0x04070a07,   // yo.sk.un_550 ro.sr.uk_332  it.lg.fr_432 mk.bg.ru_432
  0x0a00040c, 0x21001c07, 0x21000907, 0x05005204,   // ru.mk.un_530 id.jw.un_420  pl.jw.un_420 ha.fr.un_320
  // [1720]
  0x0a040704, 0x05000118, 0x070a10a0, 0x0000012d,   // bg.ru.mk_332 en.fr.un_740  be.mk.bg_322 en.un.un_A00
  0x08002904, 0x4a00182b, 0x16002902, 0x1c100405,   // sl.no.un_320 ga.yo.un_980  sl.hr.un_220 fi.lt.id_333
  0x080411ee, 0x0000052d, 0x0000212d, 0x232b4aaf,   // ro.ru.uk_422 fr.un.un_A00  fa.un.un_A00 yo.vi.ca_655
  0x520435ee, 0x4a211ca9, 0x060501a7, 0x18004a2a,   // zu.fi.ha_422 id.jw.yo_544  en.fr.de_532 yo.ga.un_970
  // [1730]
  0x0c0203a0, 0x1c21130c, 0x1b311ea0, 0x09002a02,   // nl.da.sv_322 et.jw.id_543  ms.az.tr_322 mt.pl.un_220
  0x1b682807, 0x0d1b29a0, 0x0400101a, 0x11121b07,   // sw.ig.tr_432 sl.tr.cs_322  be.ru.un_760 tr.hu.ro_432
  0x12032a04, 0x18004a21, 0x04000c0c, 0x4a0e1812,   // mt.nl.hu_332 yo.ga.un_860  sv.fi.un_530 ga.is.yo_654
  0x1b003108, 0x0f2701a0, 0x12001004, 0x0d4a230d,   // az.tr.un_430 en.gd.lv_322  lt.hu.un_320 ca.yo.cs_554
  // [1740]
  0x554a28a4, 0x55000b04, 0x030602ee, 0x0300060c,   // sw.yo.rw_433 es.rw.un_320  da.de.nl_422 de.nl.un_530
  0x06000d0b, 0x281c2108, 0x13001f21, 0x17163211,   // cs.de.un_520 jw.id.sw_443  cy.et.un_860 bs.hr.sr_653
  0x1f001304, 0x09532007, 0x28002022, 0x016b11a4,   // et.cy.un_320 sq.ht.pl_432  sq.sw.un_870 ro.ceb.en_433
  0x1b00680b, 0x29000d13, 0x08000405, 0x1b060dee,   // ig.tr.un_520 cs.sl.un_650  ru.uk.un_330 cs.de.tr_422
  // [1750]
  0x53290d07, 0x170a07ad, 0x100721a4, 0x6418010c,   // cs.sl.ht_432 bg.mk.sr_643  jw.it.lt_433 en.ga.lg_543
  0x110601a4, 0x21091004, 0x170a0714, 0x0d0913a9,   // en.de.ro_433 lt.pl.jw_332  bg.mk.sr_666 bh.hi.ne_544
  0x0a0807a9, 0x0c000113, 0x2821640c, 0x32001714,   // bg.uk.mk_544 en.sv.un_650  lg.jw.sw_543 sr.bs.un_660
  0x02000c09, 0x230129a9, 0x120e0c08, 0x200904ee,   // sv.da.un_440 sl.en.ca_544  sv.is.hu_443 fi.pl.sq_422
  // [1760]
  0x01000d04, 0x23016b04, 0x12060c05, 0x07190b09,   // cs.en.un_320 ceb.en.ca_332  sv.de.hu_333 es.gl.it_444
  0x35076408, 0x09001f0d, 0x030208ee, 0x070b0a14,   // lg.it.zu_443 cy.pl.un_540  no.da.nl_422 pt.es.it_666
  0x3b073511, 0x1600250c, 0x09002909, 0x11071709,   // zu.it.so_653 eu.hr.un_530  sl.pl.un_440 sr.bg.ro_444
  0x680b520c, 0x230825a0, 0x04000a0d, 0x205512ee,   // ha.es.ig_543 eu.no.ca_322  mk.ru.un_540 hu.rw.sq_422
  // [1770]
  0x29000d1a, 0x293510a4, 0x1b3555a4, 0x0a040712,   // cs.sl.un_760 lt.zu.sl_433  rw.zu.tr_433 bg.ru.mk_654
  0x2d684a11, 0x68002813, 0x191064ad, 0x2400010d,   // yo.ig.sk_653 sw.ig.un_650  lg.lt.gl_643 iw.yi.un_540
  0x07041105, 0x1b315504, 0x18002119, 0x102135a6,   // ro.ru.bg_333 rw.az.tr_332  fa.ar.un_750 zu.jw.lt_521
  0x64125509, 0x181a6b12, 0x02001f04, 0x04132808,   // rw.hu.lg_444 ceb.tl.ga_654  cy.da.un_320 sw.et.fi_443
  // [1780]
  0x6800252a, 0x0c1220a6, 0x1000070c, 0x1c00210e,   // eu.ig.un_970 sq.hu.sv_521  bg.be.un_530 jw.id.un_550
  0x0d13095a, 0x071704a0, 0x2d0d03a4, 0x070410a4,   // hi.bh.ne_553 ru.sr.bg_322  nl.cs.sk_433 be.ru.bg_433
  0x120c0608, 0x19000a04, 0x060c1255, 0x12006404,   // de.sv.hu_443 pt.gl.un_320  hu.sv.de_442 lg.hu.un_320
  0x0d001c0c, 0x1c0d0955, 0x031925a0, 0x03006e07,   // mr.ne.un_530 hi.ne.mr_442  eu.gl.nl_322 hmn.nl.un_420
  // [1790]
  0x12182111, 0x274a20a7, 0x0d1c1307, 0x1629680c,   // fa.ar.ur_653 sq.yo.gd_532  bh.mr.ne_432 ig.sl.hr_543
  0x0a00200e, 0x2a0e1008, 0x27002519, 0x0a001e02,   // sq.pt.un_550 lt.is.mt_443  eu.gd.un_750 ms.pt.un_220
  0x06006812, 0x2d0d09ec, 0x28005514, 0x126b1aa0,   // ig.de.un_640 pl.cs.sk_644  rw.sw.un_660 tl.ceb.hu_322
  0x041320a9, 0x16000407, 0x23190ba9, 0x0e3216ad,   // sq.et.fi_544 fi.hr.un_420  es.gl.ca_544 hr.bs.is_643
  // [17a0]
  0x0f002907, 0x21001808, 0x2b3f01a0, 0x2d3b09a7,   // sl.lv.un_420 ga.jw.un_430  en.af.vi_322 pl.so.sk_532
  0x0d092d5a, 0x06000c08, 0x04171107, 0x1f003f0d,   // sk.pl.cs_553 sv.de.un_430  ro.sr.ru_432 af.cy.un_540
  0x040708ad, 0x0a006e04, 0x070a0412, 0x070417ee,   // uk.bg.ru_643 hmn.pt.un_320  ru.mk.bg_654 sr.ru.bg_422
  0x10041755, 0x09000d12, 0x3b3f6ea0, 0x13006e09,   // sr.fi.lt_442 cs.pl.un_640  hmn.af.so_322 hmn.et.un_440
  // [17b0]
  0x20123f04, 0x10000f12, 0x1f1b3b07, 0x13201b07,   // af.hu.sq_332 lv.lt.un_640  so.tr.cy_432 tr.sq.et_432
  0x08003f05, 0x09002d13, 0x1c001e0c, 0x110113a4,   // af.no.un_330 sk.pl.un_650  ms.id.un_530 et.en.ro_433
  0x28000414, 0x0400110e, 0x0c001f12, 0x31000104,   // fi.sw.un_660 ro.ru.un_550  cy.sv.un_640 en.az.un_320
  0x19273ba0, 0x3b311b12, 0x08120e0c, 0x1811320c,   // so.gd.gl_322 tr.az.so_654  is.hu.no_543 bs.ro.ga_543
  // [17c0]
  0x12003b04, 0x29122a55, 0x06000a19, 0x08190a55,   // so.hu.un_320 mt.hu.sl_442  pt.de.un_750 pt.gl.no_442
  0x1f006b08, 0x10170a02, 0x25000808, 0x25001222,   // ceb.cy.un_430 mk.sr.be_222  no.eu.un_430 hu.eu.un_870
  0x190a010c, 0x3f000104, 0x11202308, 0x18001911,   // en.pt.gl_543 en.af.un_320  ca.sq.ro_443 gl.ga.un_630
  0x20001012, 0x0b6b1a0d, 0x23002014, 0x31001104,   // lt.sq.un_640 tl.ceb.es_554  sq.ca.un_660 ro.az.un_320
  // [17d0]
  0x2d001004, 0x03000619, 0x0c080208, 0x0d131c11,   // lt.sk.un_320 de.nl.un_750  da.no.sv_443 mr.bh.ne_653
  0x18000607, 0x18000b05, 0x073f03a4, 0x120c2a11,   // de.ga.un_420 es.ga.un_330  nl.af.it_433 mt.sv.hu_653
  0x162501a4, 0x03122a07, 0x4a0252a0, 0x1c285207,   // en.eu.hr_433 mt.hu.nl_432  ha.da.yo_322 ha.sw.id_432
  0x18190b02, 0x531811ee, 0x070a110c, 0x040708a7,   // es.gl.ga_222 ro.ga.ht_422  ro.mk.bg_543 uk.bg.ru_532
  // [17e0]
  0x68005519, 0x3f001e02, 0x28050aee, 0x07000814,   // rw.ig.un_750 ms.af.un_220  pt.fr.sw_422 uk.bg.un_660
  0x0e001309, 0x1c00130d, 0x10253b0b, 0x350e280e,   // et.is.un_440 bh.mr.un_540  so.eu.lt_542 sw.is.zu_555
  0x1e3b2807, 0x070a170c, 0x1805270c, 0x2d001904,   // sw.so.ms_432 sr.mk.bg_543  gd.fr.ga_543 gl.sk.un_320
  0x18270513, 0x093b130c, 0x07294a04, 0x522705a9,   // fr.gd.ga_665 et.so.pl_543  yo.sl.it_332 fr.gd.ha_544
  // [17f0]
  0x643b0e05, 0x160f1004, 0x2827180b, 0x10003b07,   // is.so.lg_333 lt.lv.hr_332  ga.gd.sw_542 so.lt.un_420
  0x2a003b0d, 0x24000122, 0x1a2125a0, 0x0f0901a4,   // so.mt.un_540 iw.yi.un_870  eu.jw.tl_322 en.pl.lv_433
  0x123f0309, 0x53000507, 0x180527ad, 0x1e001c36,   // nl.af.hu_444 fr.ht.un_420  gd.fr.ga_643 id.ms.un_AA0
  0x0500010d, 0x1e1c0fa4, 0x0c2b1ca7, 0x1c091309,   // en.fr.un_540 lv.id.ms_433  id.vi.sv_532 bh.hi.mr_444

  // [1800]
  0x0a001109, 0x55352807, 0x1e1c310c, 0x04081713,   // ro.pt.un_440 sw.zu.rw_432  az.id.ms_543 sr.uk.ru_665
  0x23001605, 0x1b3b1f13, 0x2327180c, 0x07001119,   // hr.ca.un_330 cy.so.tr_665  ga.gd.ca_543 ro.bg.un_750
  0x1b532d07, 0x0300050d, 0x1f00050b, 0x070a17a0,   // sk.ht.tr_432 fr.nl.un_540  fr.cy.un_520 sr.mk.bg_322
  0x09020c07, 0x64005204, 0x05001823, 0x23055302,   // sv.da.pl_432 ha.lg.un_320  ga.fr.un_880 ht.fr.ca_222
  // [1810]
  0x1e1c050c, 0x120427a4, 0x1a316ea4, 0x29001708,   // fr.id.ms_543 gd.fi.hu_433  hmn.az.tl_433 sr.sl.un_430
  0x271801ee, 0x312b0aa0, 0x12080207, 0x12352004,   // en.ga.gd_422 pt.vi.az_322  da.no.hu_432 sq.zu.hu_332
  0x036b0908, 0x28001c04, 0x02000818, 0x16001e04,   // pl.ceb.nl_443 id.sw.un_320  no.da.un_740 ms.hr.un_320
  0x2a311e08, 0x4a005204, 0x35006808, 0x0800020d,   // ms.az.mt_443 ha.yo.un_320  ig.zu.un_430 da.no.un_540
  // [1820]
  0x10003202, 0x01002704, 0x090f10a4, 0x12001819,   // bs.lt.un_220 gd.en.un_320  lt.lv.pl_433 ar.ur.un_750
  0x080a17a4, 0x11005507, 0x1e1c2702, 0x0d00091a,   // sr.mk.uk_433 rw.ro.un_420  gd.id.ms_222 hi.ne.un_760
  0x04001707, 0x2a000504, 0x093f030c, 0x2d001808,   // sr.ru.un_420 fr.mt.un_320  nl.af.pl_543 ga.sk.un_430
  0x09001008, 0x0200230c, 0x041707a0, 0x1f002a08,   // lt.pl.un_430 ca.da.un_530  bg.sr.ru_322 mt.cy.un_430
  // [1830]
  0x10170808, 0x1b1e1c04, 0x20000604, 0x03063508,   // uk.sr.be_443 id.ms.tr_332  de.sq.un_320 zu.de.nl_443
  0x10000707, 0x1f1a6ba4, 0x19110bec, 0x3b002109,   // bg.be.un_420 ceb.tl.cy_433  es.ro.gl_644 jw.so.un_440
  0x0f2d0912, 0x041711a4, 0x12002019, 0x07002a04,   // pl.sk.lv_654 ro.sr.ru_433  sq.hu.un_750 mt.it.un_320
  0x02120455, 0x520e10ee, 0x030c08a0, 0x10000108,   // fi.hu.da_442 lt.is.ha_422  no.sv.nl_322 en.lt.un_430
  // [1840]
  0x3518270c, 0x08006e08, 0x0c080209, 0x090d13a9,   // gd.ga.zu_543 hmn.no.un_430  da.no.sv_444 bh.ne.hi_544
  0x27005302, 0x04001018, 0x520e01a4, 0x350152ee,   // ht.gd.un_220 be.ru.un_740  en.is.ha_433 ha.en.zu_422
  0x21002304, 0x1f003f04, 0x09080213, 0x1f002705,   // ca.jw.un_320 af.cy.un_320  da.no.pl_665 gd.cy.un_330
  0x0b0a1802, 0x07081104, 0x0c002a09, 0x23190ba4,   // ga.pt.es_222 ro.uk.bg_332  mt.sv.un_440 es.gl.ca_433
  // [1850]
  0x182112ec, 0x2b012aee, 0x0b0a18ec, 0x25030608,   // ur.fa.ar_644 mt.en.vi_422  ga.pt.es_644 de.nl.eu_443
  0x281b1ea0, 0x1000040c, 0x03090d12, 0x1800211b,   // ms.tr.sw_322 ru.be.un_530  cs.pl.nl_654 fa.ar.un_770
  0x061209ad, 0x18190ba7, 0x1f003f0e, 0x120c0807,   // pl.hu.de_643 es.gl.ga_532  af.cy.un_550 no.sv.hu_432
  0x0a070408, 0x4a0d2d12, 0x52003b05, 0x28001105,   // ru.bg.mk_443 sk.cs.yo_654  so.ha.un_330 ro.sw.un_330
  // [1860]
  0x1c000d1a, 0x04100f12, 0x1104100c, 0x0a190ba7,   // ne.mr.un_760 lv.lt.fi_654  be.ru.ro_543 es.gl.pt_532
  0x0f1001a4, 0x09000619, 0x1f190b0e, 0x2d0d10ec,   // en.lt.lv_433 de.pl.un_750  es.gl.cy_555 lt.cs.sk_644
  0x03001f04, 0x10213b04, 0x130c0804, 0x12000c0d,   // cy.nl.un_320 so.jw.lt_332  no.sv.et_332 sv.hu.un_540
  0x211b5302, 0x080a170c, 0x0a001814, 0x080410a7,   // ht.tr.jw_222 sr.mk.uk_543  ga.pt.un_660 be.ru.uk_532
  // [1870]
  0x11002b11, 0x321b2007, 0x0b00180e, 0x20532513,   // vi.ro.un_630 sq.tr.bs_432  ga.es.un_550 eu.ht.sq_665
  0x18190ba0, 0x2b182812, 0x18000a0e, 0x2b271811,   // es.gl.ga_322 sw.ga.vi_654  pt.ga.un_550 ga.gd.vi_653
  0x09130d07, 0x1800170c, 0x03010aa0, 0x07010602,   // ne.bh.hi_432 sr.ga.un_530  pt.en.nl_322 de.en.it_222
  0x17080409, 0x1e000e04, 0x2b001907, 0x2a001819,   // ru.uk.sr_444 is.ms.un_320  gl.vi.un_420 ga.mt.un_750
  // [1880]
  0x0a000722, 0x01001802, 0x020c0813, 0x09006412,   // bg.mk.un_870 ga.en.un_220  no.sv.da_665 lg.pl.un_640
  0x27001836, 0x06005513, 0x0c1308a0, 0x6b680bee,   // ga.gd.un_AA0 rw.de.un_650  no.et.sv_322 es.ig.ceb_422
  0x08043f05, 0x6b191fa7, 0x11101805, 0x10070aec,   // af.fi.no_333 cy.gl.ceb_532  ga.lt.ro_333 mk.bg.be_644
  0x050701a4, 0x04070aa4, 0x1f311e12, 0x533b3102,   // en.it.fr_433 mk.bg.ru_433  ms.az.cy_654 az.so.ht_222
  // [1890]
  0x1800010d, 0x31283b07, 0x0f001f07, 0x28133b55,   // en.ga.un_540 so.sw.az_432  cy.lv.un_420 so.et.sw_442
  0x04000702, 0x3f130308, 0x170407a9, 0x13033fa4,   // it.fi.un_220 nl.et.af_443  bg.ru.sr_544 af.nl.et_433
  0x12002919, 0x022d0e12, 0x04033b04, 0x0c00091a,   // sl.hu.un_750 is.sk.da_654  so.nl.fi_332 pl.sv.un_760
  0x3b033f55, 0x050a2802, 0x04133b07, 0x4a113f0c,   // af.nl.so_442 sw.pt.fr_222  so.et.fi_432 af.ro.yo_543
  // [18a0]
  0x131f2704, 0x082a0107, 0x070810a0, 0x68023b08,   // gd.cy.et_332 en.mt.no_432  be.uk.bg_322 so.da.ig_443
  0x0a041305, 0x3f2b1cee, 0x17001304, 0x033f3baf,   // et.fi.pt_333 id.vi.af_422  et.sr.un_320 so.af.nl_655
  0x2a126407, 0x12001821, 0x0e126407, 0x190a0505,   // lg.hu.mt_432 ar.ur.un_860  lg.hu.is_432 fr.pt.gl_333
  0x2a212805, 0x122a6407, 0x05002307, 0x0c0501a4,   // sw.jw.mt_333 lg.mt.hu_432  ca.fr.un_420 en.fr.sv_433
  // [18b0]
  0x2a1b5208, 0x35645512, 0x530d2d11, 0x52122aa7,   // ha.tr.mt_443 rw.lg.zu_654  sk.cs.ht_653 mt.hu.ha_532
  0x3216290c, 0x4a001321, 0x170a10ee, 0x0f55645a,   // sl.hr.bs_543 et.yo.un_860  be.mk.sr_422 lg.rw.lv_553
  0x04033f09, 0x0a171112, 0x2a000708, 0x190f0bec,   // af.nl.fi_444 ro.sr.mk_654  it.mt.un_430 es.lv.gl_644
  0x12002a04, 0x036813a4, 0x17000819, 0x3f033b08,   // mt.hu.un_320 et.ig.nl_433  uk.sr.un_750 so.nl.af_443
  // [18c0]
  0x64522a60, 0x04133bec, 0x015528a0, 0x55642d07,   // mt.ha.lg_664 so.et.fi_644  sw.rw.en_322 sk.lg.rw_432
  0x00001e15, 0x2d0d1702, 0x07080405, 0x28002104,   // ms.un.un_700 sr.cs.sk_222  ru.uk.bg_333 jw.sw.un_320
  0x0b190a0d, 0x0300250c, 0x3b64520b, 0x12006414,   // pt.gl.es_554 eu.nl.un_530  ha.lg.so_542 lg.hu.un_660
  0x322d0d55, 0x16212807, 0x183f1fad, 0x17005207,   // cs.sk.bs_442 sw.jw.hr_432  cy.af.ga_643 ha.sr.un_420
  // [18d0]
  0x041c2804, 0x042835ee, 0x0e1f27ad, 0x12002a0c,   // sw.id.fi_332 zu.sw.fi_422  gd.cy.is_643 mt.hu.un_530
  0x17070a02, 0x64082aad, 0x28001705, 0x2a210eee,   // mk.bg.sr_222 mt.no.lg_643  sr.sw.un_330 is.jw.mt_422
  0x19230bec, 0x07522aa4, 0x321655a0, 0x06521211,   // es.ca.gl_644 mt.ha.it_433  rw.hr.bs_322 hu.ha.de_653
  0x352301ee, 0x2d170d14, 0x190b6b05, 0x19131b04,   // en.ca.zu_422 cs.sr.sk_666  ceb.es.gl_333 tr.et.gl_332
  // [18e0]
  0x35556408, 0x6b685305, 0x55136408, 0x25001219,   // lg.rw.zu_443 ht.ig.ceb_333  lg.et.rw_443 hu.eu.un_750
  0x0a07110c, 0x2800030e, 0x0e3f0804, 0x0f285255,   // ro.bg.mk_543 nl.sw.un_550  no.af.is_332 ha.sw.lv_442
  0x29005208, 0x1a6b0c0c, 0x2d321602, 0x20132807,   // ha.sl.un_430 sv.ceb.tl_543  hr.bs.sk_222 sw.et.sq_432
  0x08000718, 0x0d002d1a, 0x071017ee, 0x06000304,   // bg.uk.un_740 sk.cs.un_760  sr.be.bg_422 nl.de.un_320
  // [18f0]
  0x03003f04, 0x1c2128a4, 0x292d1007, 0x291610ee,   // af.nl.un_320 sw.jw.id_433  lt.sk.sl_432 lt.hr.sl_422
  0x0a171160, 0x321721ee, 0x07005202, 0x0d352804,   // ro.sr.mk_664 jw.sr.bs_422  ha.it.un_220 sw.zu.cs_332
  0x0500110d, 0x2d290d0c, 0x07000813, 0x0964350c,   // ro.fr.un_540 cs.sl.sk_543  uk.bg.un_650 zu.lg.pl_543
  0x55211207, 0x64002802, 0x64005502, 0x0d091ca9,   // hu.jw.rw_432 sw.lg.un_220  rw.lg.un_220 mr.hi.ne_544
  // [1900]
  0x55006409, 0x040817a7, 0x16000204, 0x322518ee,   // lg.rw.un_440 sr.uk.ru_532  da.hr.un_320 ga.eu.bs_422
  0x322d0da4, 0x092a040c, 0x071011ee, 0x07170a12,   // cs.sk.bs_433 fi.mt.pl_543  ro.be.bg_422 mk.sr.bg_654
  0x0f080c55, 0x18002705, 0x3f042aa4, 0x1b1e3111,   // sv.no.lv_442 gd.ga.un_330  mt.fi.af_433 az.ms.tr_653
  0x27006402, 0x126b1a02, 0x1800280e, 0x06000c19,   // lg.gd.un_220 tl.ceb.hu_222  sw.ga.un_550 sv.de.un_750
  // [1910]
  0x53001a14, 0x080a0711, 0x321716ee, 0x2a005504,   // tl.ht.un_660 bg.mk.uk_653  hr.sr.bs_422 rw.mt.un_320
  0x2a3b64a4, 0x2118125a, 0x1b002008, 0x20001b04,   // lg.so.mt_433 ur.ar.fa_553  sq.tr.un_430 tr.sq.un_320
  0x0c00081b, 0x0f530408, 0x12003f07, 0x17080a09,   // no.sv.un_770 fi.ht.lv_443  af.hu.un_420 mk.uk.sr_444
  0x02000835, 0x32002904, 0x53001f02, 0x0800122c,   // no.da.un_A90 sl.bs.un_320  cy.ht.un_220 hu.no.un_990
  // [1920]
  0x25181b0c, 0x07190107, 0x0f2a1012, 0x3f0603a6,   // tr.ga.eu_543 en.gl.it_432  lt.mt.lv_654 nl.de.af_521
  0x282d0dac, 0x1e000607, 0x1c130909, 0x32001e07,   // cs.sk.sw_632 de.ms.un_420  hi.bh.mr_444 ms.bs.un_420
  0x1f3b08ec, 0x17001e02, 0x32001708, 0x4a1f1007,   // no.so.cy_644 ms.sr.un_220  sr.bs.un_430 lt.cy.yo_432
  0x1f050107, 0x051901a4, 0x28171307, 0x0a07170e,   // en.fr.cy_432 en.gl.fr_433  et.sr.sw_432 sr.bg.mk_555
  // [1930]
  0x20001b09, 0x10182aad, 0x033f0c5a, 0x06001f21,   // tr.sq.un_440 mt.ga.lt_643  sv.af.nl_553 cy.de.un_860
  0x3f0e08af, 0x52005502, 0x063f0314, 0x35005513,   // no.is.af_655 rw.ha.un_220  nl.af.de_666 rw.zu.un_650
  0x6e001f14, 0x235301a0, 0x0e001813, 0x0100241a,   // cy.hmn.un_660 en.ht.ca_322  ga.is.un_650 yi.iw.un_760
  0x09005304, 0x0400170d, 0x552035a0, 0x1a1310a0,   // ht.pl.un_320 sr.ru.un_540  zu.sq.rw_322 lt.et.tl_322
  // [1940]
  0x07170408, 0x170a070b, 0x07041704, 0x2164550c,   // ru.sr.bg_443 bg.mk.sr_542  sr.ru.bg_332 rw.lg.jw_543
  0x1764520c, 0x060c135a, 0x0a190b5a, 0x0c000404,   // ha.lg.sr_543 et.sv.de_553  es.gl.pt_553 fi.sv.un_320
  0x2b00060d, 0x351a6b0b, 0x3b001308, 0x35286409,   // de.vi.un_540 ceb.tl.zu_542  et.so.un_430 lg.sw.zu_444
  0x17000413, 0x25315204, 0x08060204, 0x0d1c135a,   // ru.sr.un_650 ha.az.eu_332  da.de.no_332 bh.mr.ne_553
  // [1950]
  0x20000612, 0x081a6b0b, 0x17005502, 0x3b001313,   // de.sq.un_640 ceb.tl.no_542  rw.sr.un_220 et.so.un_650
  0x101f27ee, 0x3b000c0e, 0x35645504, 0x53000c05,   // gd.cy.lt_422 sv.so.un_550  rw.lg.zu_332 sv.ht.un_330
  0x1b256b05, 0x0b2101a0, 0x4a120e08, 0x1b2a5508,   // ceb.eu.tr_333 en.jw.es_322  is.hu.yo_443 rw.mt.tr_443
  0x3f003b05, 0x06255507, 0x0d000f05, 0x21005519,   // so.af.un_330 rw.eu.de_432  lv.cs.un_330 rw.jw.un_750
  // [1960]
  0x2b3108a0, 0x07100b08, 0x101a5307, 0x29080ca9,   // no.az.vi_322 es.lt.it_443  ht.tl.lt_432 sv.no.sl_544
  0x23001604, 0x050c2aa4, 0x1a070aa4, 0x17163210,   // hr.ca.un_320 mt.sv.fr_433  pt.it.tl_433 bs.hr.sr_642
  0x556b1c0b, 0x08100aa4, 0x551e1c5a, 0x6b2a07ee,   // id.ceb.rw_542 mk.be.uk_433  id.ms.rw_553 it.mt.ceb_422
  0x0f060107, 0x6410550c, 0x641a6b05, 0x01023ba0,   // en.de.lv_432 rw.lt.lg_543  ceb.tl.lg_333 so.da.en_322
  // [1970]
  0x3b1029ee, 0x29133b12, 0x051109a4, 0x3f133b07,   // sl.lt.so_422 so.et.sl_654  pl.ro.fr_433 so.et.af_432
  0x07001008, 0x093b1307, 0x102829a4, 0x070417a7,   // lt.it.un_430 et.so.pl_432  sl.sw.lt_433 sr.ru.bg_532
  0x290b07a7, 0x170a10a6, 0x17000809, 0x040a11a0,   // it.es.sl_532 be.mk.sr_521  uk.sr.un_440 ro.mk.ru_322
  0x040c06a7, 0x080235a0, 0x100f1705, 0x1017080c,   // de.sv.fi_532 zu.da.no_322  sr.lv.lt_333 uk.sr.be_543
  // [1980]
  0x1c000d11, 0x130d09a9, 0x1008040e, 0x0d00180d,   // ne.mr.un_630 hi.ne.bh_544  ru.uk.be_555 ga.cs.un_540
  0x19003b0c, 0x0b072907, 0x353f03ee, 0x1f3b550b,   // so.gl.un_530 sl.it.es_432  nl.af.zu_422 rw.so.cy_542
  0x2910070c, 0x07291aa7, 0x17101107, 0x10000404,   // it.lt.sl_543 tl.sl.it_532  ro.be.sr_432 ru.be.un_320
  0x0400131b, 0x35002808, 0x1a6435ee, 0x28001a04,   // et.fi.un_770 sw.zu.un_430  zu.lg.tl_422 tl.sw.un_320
  // [1990]
  0x1e1c3509, 0x06002a14, 0x1e4a6402, 0x2800060c,   // zu.id.ms_444 mt.de.un_660  lg.yo.ms_222 de.sw.un_530
  0x08170a05, 0x04001121, 0x1f272da4, 0x1a3f01a7,   // mk.sr.uk_333 ro.ru.un_860  sk.gd.cy_433 en.af.tl_532
  0x0e042a08, 0x292d0d60, 0x122a070c, 0x4a00680c,   // mt.fi.is_443 cs.sk.sl_664  it.mt.hu_543 ig.yo.un_530
  0x29002d22, 0x13080c08, 0x64001219, 0x2a041208,   // sk.sl.un_870 sv.no.et_443  hu.lg.un_750 hu.fi.mt_443
  // [19a0]
  0x10080411, 0x05001a04, 0x55006404, 0x12002d13,   // ru.uk.be_653 tl.fr.un_320  lg.rw.un_320 sk.hu.un_650
  0x0c0813a9, 0x10040707, 0x07000808, 0x03073fa0,   // et.no.sv_544 bg.ru.be_432  no.it.un_430 af.it.nl_322
  0x12001b08, 0x11070aaf, 0x0c2a20a4, 0x13002011,   // tr.hu.un_430 mk.bg.ro_655  sq.mt.sv_433 sq.et.un_630
  0x070305a0, 0x2d002909, 0x55281ca4, 0x1c090d08,   // fr.nl.it_322 sl.sk.un_440  id.sw.rw_433 ne.hi.mr_443
  // [19b0]
  0x2b001f07, 0x25000622, 0x3f002507, 0x28000608,   // cy.vi.un_420 de.eu.un_870  eu.af.un_420 de.sw.un_430
  0x04170813, 0x6b1a5214, 0x1b00060e, 0x1b1a6ba4,   // uk.sr.ru_665 ha.tl.ceb_666  de.tr.un_550 ceb.tl.tr_433
  0x0c033f55, 0x052a01a0, 0x3f2a0707, 0x1f112302,   // af.nl.sv_442 en.mt.fr_322  it.mt.af_432 ca.ro.cy_222
  0x2835640e, 0x3f080ca4, 0x2d00291a, 0x05000802,   // lg.zu.sw_555 sv.no.af_433  sl.sk.un_760 no.fr.un_220
  // [19c0]
  0x321b06ee, 0x110813a0, 0x03023f02, 0x0a001112,   // de.tr.bs_422 et.no.ro_322  af.da.nl_222 ro.mk.un_640
  0x0e3f4a0c, 0x3b005322, 0x06006814, 0x060a23a4,   // yo.af.is_543 ht.so.un_870  ig.de.un_660 ca.pt.de_433
  0x0c2a0408, 0x0c0e13a0, 0x09000104, 0x04080a07,   // fi.mt.sv_443 et.is.sv_322  en.pl.un_320 mk.uk.ru_432
  0x52310c07, 0x321116a0, 0x06080c05, 0x3f042a0c,   // sv.az.ha_432 hr.ro.bs_322  sv.no.de_333 mt.fi.af_543
  // [19d0]
  0x1600290c, 0x1213040d, 0x0b680611, 0x0e080608,   // sl.hr.un_530 fi.et.hu_554  de.ig.es_653 de.no.is_443
  0x0a170704, 0x520625ee, 0x0427180c, 0x52002512,   // bg.sr.mk_332 eu.de.ha_422  ga.gd.fi_543 eu.ha.un_640
  0x17020807, 0x2a0f2813, 0x0600040d, 0x10000f0d,   // no.da.sr_432 sw.lv.mt_665  fi.de.un_540 lv.lt.un_540
  0x3b0807a9, 0x55080213, 0x4a2718a4, 0x52002a1a,   // it.no.so_544 da.no.rw_665  ga.gd.yo_433 mt.ha.un_760
  // [19e0]
  0x07001014, 0x162d0607, 0x6b081005, 0x040313a9,   // be.bg.un_660 de.sk.hr_432  lt.no.ceb_333 et.nl.fi_544
  0x31005204, 0x12001f05, 0x3f001a02, 0x060d3f0c,   // ha.az.un_320 cy.hu.un_330  tl.af.un_220 af.cs.de_543
  0x0a00171a, 0x1e181c0c, 0x52000507, 0x193f1f0c,   // sr.mk.un_760 id.ga.ms_543  fr.ha.un_420 cy.af.gl_543
  0x29121604, 0x4a16310c, 0x321607a4, 0x3b120107,   // hr.hu.sl_332 az.hr.yo_543  it.hr.bs_433 en.hu.so_432
  // [19f0]
  0x11000a02, 0x232d01ee, 0x553564af, 0x1b292d07,   // pt.ro.un_220 en.sk.ca_422  lg.zu.rw_655 sk.sl.tr_432
  0x12114aa4, 0x27251155, 0x25003105, 0x051255ad,   // yo.ro.hu_433 ro.eu.gd_442  az.eu.un_330 rw.hu.fr_643
  0x25005207, 0x23122905, 0x556435a7, 0x08033f07,   // ha.eu.un_420 sl.hu.ca_333  zu.lg.rw_532 af.nl.no_432
  0x3b0e04ad, 0x1900350d, 0x0e130608, 0x0a04170c,   // fi.is.so_643 zu.gl.un_540  de.et.is_443 sr.ru.mk_543
  // [1a00]
  0x0e002a1a, 0x55001114, 0x080206a4, 0x2552550c,   // mt.is.un_760 ro.rw.un_660  de.da.no_433 rw.ha.eu_543
  0x060c08a4, 0x55643512, 0x130701a0, 0x1b312008,   // no.sv.de_433 zu.lg.rw_654  en.it.et_322 sq.az.tr_443
  0x02000822, 0x1c000d0e, 0x2535550c, 0x122d19ee,   // no.da.un_870 ne.mr.un_550  rw.zu.eu_543 gl.sk.hu_422
  0x040717a0, 0x20003202, 0x08100704, 0x6435550c,   // sr.bg.ru_322 bs.sq.un_220  bg.be.uk_332 rw.zu.lg_543
  // [1a10]
  0x642555ee, 0x55002508, 0x07001f13, 0x211218af,   // rw.eu.lg_422 eu.rw.un_430  cy.it.un_650 ar.ur.fa_655
  0x04071113, 0x1108170c, 0x081b03a0, 0x08170704,   // ro.bg.ru_665 sr.uk.ro_543  nl.tr.no_322 bg.sr.uk_332
  0x0a081708, 0x0a0807a4, 0x521e1fad, 0x100407a0,   // sr.uk.mk_443 bg.uk.mk_433  cy.ms.ha_643 bg.ru.be_322
  0x1f1e1c12, 0x530c23ee, 0x2a002813, 0x4a182dad,   // id.ms.cy_654 ca.sv.ht_422  sw.mt.un_650 sk.ga.yo_643
  // [1a20]
  0x130f0602, 0x04170702, 0x06101fa9, 0x231301a0,   // de.lv.et_222 bg.sr.ru_222  cy.lt.de_544 en.et.ca_322
  0x550c08a0, 0x2a006813, 0x06281fad, 0x211c1ea9,   // no.sv.rw_322 ig.mt.un_650  cy.sw.de_643 ms.id.jw_544
  0x10005208, 0x0717080c, 0x10004a05, 0x08070a0d,   // ha.lt.un_430 uk.sr.bg_543  yo.lt.un_330 mk.bg.uk_554
  0x1e1c10af, 0x6b2d0d05, 0x00001f2d, 0x201b3112,   // lt.id.ms_655 cs.sk.ceb_333  cy.un.un_A00 az.tr.sq_654
  // [1a30]
  0x0000320f, 0x1b162908, 0x356420a4, 0x06001f1a,   // bs.un.un_600 sl.hr.tr_443  sq.lg.zu_433 cy.de.un_760
  0x3229170b, 0x311a280c, 0x17000d08, 0x211812a9,   // sr.sl.bs_542 sw.tl.az_543  cs.sr.un_430 ur.ar.fa_544
  0x1a001f1b, 0x033f02a7, 0x1c002104, 0x5200280d,   // cy.tl.un_770 da.af.nl_532  jw.id.un_320 sw.ha.un_540
  0x251011ee, 0x190e1211, 0x1f5220a9, 0x101a130c,   // ro.lt.eu_422 hu.is.gl_653  sq.ha.cy_544 et.tl.lt_543
  // [1a40]
  0x68004a14, 0x211e1f12, 0x52101fa4, 0x29351307,   // yo.ig.un_660 cy.ms.jw_654  cy.lt.ha_433 et.zu.sl_432
  0x1b1c21ee, 0x551a6b12, 0x6b000204, 0x1c001e12,   // jw.id.tr_422 ceb.tl.rw_654  da.ceb.un_320 ms.id.un_640
  0x5535680c, 0x1e1c1f0c, 0x00003103, 0x0d033fa4,   // ig.zu.rw_543 cy.id.ms_543  az.un.un_300 af.nl.cs_433
  0x10251fa7, 0x4a136407, 0x03043f07, 0x3f2821a0,   // cy.eu.lt_532 lg.et.yo_432  af.fi.nl_432 jw.sw.af_322
  // [1a50]
  0x0e4a52ac, 0x070411a6, 0x07170412, 0x04071107,   // ha.yo.is_632 ro.ru.bg_521  ru.sr.bg_654 ro.bg.ru_432
  0x0a170805, 0x18000713, 0x013b0ca0, 0x070a1712,   // uk.sr.mk_333 it.ga.un_650  sv.so.en_322 sr.mk.bg_654
  0x1328350c, 0x04003f08, 0x6b2855a0, 0x13000108,   // zu.sw.et_543 af.fi.un_430  rw.sw.ceb_322 en.et.un_430
  0x0700100d, 0x16321707, 0x10521aad, 0x640813a4,   // be.bg.un_540 sr.bs.hr_432  tl.ha.lt_643 et.no.lg_433
  // [1a60]
  0x06002a0c, 0x10002d0c, 0x2300210c, 0x1e006b05,   // mt.de.un_530 sk.lt.un_530  jw.ca.un_530 ceb.ms.un_330
  0x1a003512, 0x02001f02, 0x09000f07, 0x0a070808,   // zu.tl.un_640 cy.da.un_220  lv.pl.un_420 uk.bg.mk_443
  0x3f031f0e, 0x35005202, 0x0c060209, 0x11000304,   // cy.nl.af_555 ha.zu.un_220  da.de.sv_444 nl.ro.un_320
  0x03060804, 0x07170aaf, 0x3b001f08, 0x1f00030b,   // no.de.nl_332 mk.sr.bg_655  cy.so.un_430 nl.cy.un_520
  // [1a70]
  0x18000b08, 0x1e1c64a9, 0x230a05ec, 0x1c641eaf,   // es.ga.un_430 lg.id.ms_544  fr.pt.ca_644 ms.lg.id_655
  0x1e1c640c, 0x35123b05, 0x64551c07, 0x0a0711a4,   // lg.id.ms_543 so.hu.zu_333  id.rw.lg_432 ro.bg.mk_433
  0x1e1c55a0, 0x091e1c08, 0x13000304, 0x4a00211a,   // rw.id.ms_322 id.ms.pl_443  nl.et.un_320 jw.yo.un_760
  0x211a55a4, 0x0c0f02a0, 0x0000282d, 0x012a6ea0,   // rw.tl.jw_433 da.lv.sv_322  sw.un.un_A00 hmn.mt.en_322
  // [1a80]
  0x64005523, 0x1a556b08, 0x170a04ad, 0x06040312,   // rw.lg.un_880 ceb.rw.tl_443  ru.mk.sr_643 nl.fi.de_654
  0x553568a9, 0x0c0308a0, 0x0b00250c, 0x3500280c,   // ig.zu.rw_544 no.nl.sv_322  eu.es.un_530 sw.zu.un_530
  0x0e080c04, 0x082502a0, 0x08001308, 0x3564550c,   // sv.no.is_332 da.eu.no_322  et.no.un_430 rw.lg.zu_543
  0x08092a07, 0x05003f07, 0x1e1c55a4, 0x08062aa0,   // mt.pl.no_432 af.fr.un_420  rw.id.ms_433 mt.de.no_322
  // [1a90]
  0x1255640c, 0x070a01a4, 0x0e000c04, 0x5509680d,   // lg.rw.hu_543 en.pt.it_433  sv.is.un_320 ig.pl.rw_554
  0x1c090d13, 0x1c551e0c, 0x07130455, 0x041b310d,   // ne.hi.mr_665 ms.rw.id_543  fi.et.it_442 az.tr.fi_554
  0x16321711, 0x1e1c55ec, 0x531b3160, 0x1e641c0c,   // sr.bs.hr_653 rw.id.ms_644  az.tr.ht_664 id.lg.ms_543
  0x17071105, 0x23001e13, 0x02041304, 0x07041702,   // ro.bg.sr_333 ms.ca.un_650  et.fi.da_332 sr.ru.bg_222
  // [1aa0]
  0x55006b11, 0x31130655, 0x1c5221a0, 0x55000104,   // ceb.rw.un_630 de.et.az_442  jw.ha.id_322 en.rw.un_320
  0x1f001221, 0x066b1a07, 0x106b030b, 0x0e000802,   // hu.cy.un_860 tl.ceb.de_432  nl.ceb.lt_542 no.is.un_220
  0x19211fa4, 0x641004a4, 0x12002111, 0x06003f07,   // cy.jw.gl_433 fi.lt.lg_433  fa.ur.un_630 af.de.un_420
  0x3f0c0802, 0x0400080d, 0x31001f07, 0x1f3b3f12,   // no.sv.af_222 uk.ru.un_540  cy.az.un_420 af.so.cy_654
  // [1ab0]
  0x101b0907, 0x0d1c0907, 0x100a0709, 0x0c3f0307,   // pl.tr.lt_432 hi.mr.ne_432  bg.mk.be_444 nl.af.sv_432
  0x0c1b3108, 0x53005214, 0x1800270c, 0x013153ee,   // az.tr.sv_443 ha.ht.un_660  gd.ga.un_530 ht.az.en_422
  0x351f55a4, 0x28311b07, 0x1a126bec, 0x05533b05,   // rw.cy.zu_433 tr.az.sw_432  ceb.hu.tl_644 so.ht.fr_333
  0x04130c05, 0x12002a05, 0x13002904, 0x1c00130b,   // sv.et.fi_333 mt.hu.un_330  sl.et.un_320 bh.mr.un_520
  // [1ac0]
  0x550535ee, 0x3b00130b, 0x55531fa7, 0x2700180c,   // zu.fr.rw_422 et.so.un_520  cy.ht.rw_532 ga.gd.un_530
  0x5200130c, 0x2900130d, 0x060a1ba4, 0x17070804,   // et.ha.un_530 et.sl.un_540  tr.pt.de_433 uk.bg.sr_332
  0x0a00070c, 0x12002114, 0x0d292d55, 0x100a08a4,   // bg.mk.un_530 fa.ur.un_660  sk.sl.cs_442 uk.mk.be_433
  0x13002502, 0x0b001f02, 0x2704180c, 0x08001008,   // eu.et.un_220 cy.es.un_220  ga.fi.gd_543 be.uk.un_430
  // [1ad0]
  0x09061f0d, 0x0400100e, 0x08000411, 0x0c001319,   // cy.de.pl_554 be.ru.un_550  ru.uk.un_630 et.sv.un_750
  0x040c130b, 0x110817a4, 0x120d09a9, 0x20311b0d,   // et.sv.fi_542 sr.uk.ro_433  pl.cs.hu_544 tr.az.sq_554
  0x07001104, 0x0a2d0d0e, 0x110a07a4, 0x041107ec,   // ro.it.un_320 cs.sk.pt_555  bg.mk.ro_433 bg.ro.ru_644
  0x111e1c0d, 0x0c2301a4, 0x0a230611, 0x0900200e,   // id.ms.ro_554 en.ca.sv_433  de.ca.pt_653 sq.pl.un_550
  // [1ae0]
  0x0d2d0907, 0x320917a4, 0x00001137, 0x010653a0,   // pl.sk.cs_432 sr.pl.bs_433  ro.un.un_B00 ht.de.en_322
  0x09290da4, 0x05001c02, 0x1c0d09ad, 0x352011a4,   // cs.sl.pl_433 id.fr.un_220  hi.ne.mr_643 ro.sq.zu_433
  0x03520607, 0x283f1aa4, 0x5201050d, 0x254a11a7,   // de.ha.nl_432 tl.af.sw_433  fr.en.ha_554 ro.yo.eu_532
  0x0c0552a0, 0x280a520c, 0x0100060c, 0x2d0d11a4,   // ha.fr.sv_322 ha.pt.sw_543  de.en.un_530 ro.cs.sk_433
  // [1af0]
  0x022a070c, 0x293f0355, 0x08070aa4, 0x6b2707ad,   // it.mt.da_543 nl.af.sl_442  mk.bg.uk_433 it.gd.ceb_643
  0x32290da6, 0x092d0d12, 0x213f1c07, 0x033f0ca0,   // cs.sl.bs_521 cs.sk.pl_654  id.af.jw_432 sv.af.nl_322
  0x10040809, 0x1132165a, 0x3f192707, 0x2a00230c,   // uk.ru.be_444 hr.bs.ro_553  gd.gl.af_432 ca.mt.un_530
  0x0a292d07, 0x1b001804, 0x01113507, 0x353f0313,   // sk.sl.pt_432 ga.tr.un_320  zu.ro.en_432 nl.af.zu_665
  // [1b00]
  0x11072da4, 0x0700521b, 0x1e001f2a, 0x06002502,   // sk.it.ro_433 ha.it.un_770  cy.ms.un_970 eu.de.un_220
  0x170704af, 0x35000307, 0x08023fa4, 0x0e0c120c,   // ru.bg.sr_655 nl.zu.un_420  af.da.no_433 hu.sv.is_543
  0x25182713, 0x03002707, 0x3f030612, 0x290d1baf,   // gd.ga.eu_665 gd.nl.un_420  de.nl.af_654 tr.cs.sl_655
  0x01052aa4, 0x01000907, 0x11002b02, 0x09251108,   // mt.fr.en_433 pl.en.un_420  vi.ro.un_220 ro.eu.pl_443
  // [1b10]
  0x0a170713, 0x1c13090e, 0x09002a0e, 0x11002d04,   // bg.sr.mk_665 hi.bh.mr_555  mt.pl.un_550 sk.ro.un_320
  0x1105010c, 0x050602a0, 0x3f1f0907, 0x0d05010c,   // en.fr.ro_543 da.de.fr_322  pl.cy.af_432 en.fr.cs_543
  0x0e231e04, 0x07001823, 0x033f0f0c, 0x535231a7,   // ms.ca.is_332 ga.it.un_880  lv.af.nl_543 az.ha.ht_532
  0x0b00110b, 0x175311ee, 0x2d006e0e, 0x060c03a0,   // ro.es.un_520 ro.ht.sr_422  hmn.sk.un_550 nl.sv.de_322
  // [1b20]
  0x1b356412, 0x12002102, 0x3b252702, 0x4a311b11,   // lg.zu.tr_654 jw.hu.un_220  gd.eu.so_222 tr.az.yo_653
  0x3500281a, 0x5535210c, 0x3500190e, 0x1900230c,   // sw.zu.un_760 jw.zu.rw_543  gl.zu.un_550 ca.gl.un_530
  0x214a1aad, 0x10070a0e, 0x1c216404, 0x3b002a04,   // tl.yo.jw_643 mk.bg.be_555  lg.jw.id_332 mt.so.un_320
  0x02006809, 0x11000414, 0x28000807, 0x061b03ad,   // ig.da.un_440 ru.ro.un_660  no.sw.un_420 nl.tr.de_643
  // [1b30]
  0x2d0d29af, 0x17110704, 0x292d0d08, 0x10002d12,   // sl.cs.sk_655 bg.ro.sr_332  cs.sk.sl_443 sk.lt.un_640
  0x1c2b0307, 0x06132aa6, 0x09003204, 0x06002509,   // nl.vi.id_432 mt.et.de_521  bs.pl.un_320 eu.de.un_440
  0x0b000704, 0x0d321608, 0x0f020807, 0x08006b0e,   // it.es.un_320 hr.bs.cs_443  no.da.lv_432 ceb.no.un_550
  0x321709ec, 0x1007110c, 0x09002d19, 0x04001908,   // pl.sr.bs_644 ro.bg.be_543  sk.pl.un_750 gl.fi.un_430
  // [1b40]
  0x040a2108, 0x2a003b13, 0x07001709, 0x32171309,   // jw.pt.fi_443 so.mt.un_650  sr.bg.un_440 et.sr.bs_444
  0x0a0e1255, 0x28351c07, 0x321608a0, 0x250d2a07,   // hu.is.pt_442 id.zu.sw_432  no.hr.bs_322 mt.cs.eu_432
  0x0a07040c, 0x1821120e, 0x52082aa0, 0x04101704,   // ru.bg.mk_543 ur.fa.ar_555  mt.no.ha_322 sr.be.ru_332
  0x0f2852a0, 0x17070aaf, 0x27050a07, 0x1000170e,   // ha.sw.lv_322 mk.bg.sr_655  pt.fr.gd_432 sr.be.un_550
  // [1b50]
  0x09005302, 0x10002108, 0x10090f0c, 0x28121b05,   // ht.pl.un_220 jw.lt.un_430  lv.pl.lt_543 tr.hu.sw_333
  0x100f32a0, 0x07130411, 0x12532504, 0x32000708,   // bs.lv.lt_322 fi.et.it_653  eu.ht.hu_332 it.bs.un_430
  0x20321607, 0x05005308, 0x1b005304, 0x08040ea7,   // hr.bs.sq_432 ht.fr.un_430  ht.tr.un_320 is.fi.no_532
  0x25192305, 0x041327a0, 0x292d1604, 0x210435ec,   // ca.gl.eu_333 gd.et.fi_322  hr.sk.sl_332 zu.fi.jw_644
  // [1b60]
  0x0400080e, 0x52642a07, 0x0f2d0d04, 0x3b005204,   // uk.ru.un_550 mt.lg.ha_432  cs.sk.lv_332 ha.so.un_320
  0x6b251ca0, 0x09130407, 0x210631a0, 0x2100122b,   // id.eu.ceb_322 fi.et.pl_432  az.de.jw_322 ur.fa.un_980
  0x1f27010c, 0x13040514, 0x2d0d1605, 0x0800010d,   // en.gd.cy_543 fr.fi.et_666  hr.cs.sk_333 en.no.un_540
  0x1e4a6812, 0x090d2d11, 0x35551e0c, 0x040e08a0,   // ig.yo.ms_654 sk.cs.pl_653  ms.rw.zu_543 no.is.fi_322
  // [1b70]
  0x170704ad, 0x18002111, 0x0c130ea9, 0x10640d07,   // ru.bg.sr_643 fa.ar.un_630  is.et.sv_544 cs.lg.lt_432
  0x100f1e07, 0x2d0d2aee, 0x090d2d0b, 0x0a041705,   // ms.lv.lt_432 mt.cs.sk_422  sk.cs.pl_542 sr.ru.mk_333
  0x040901a4, 0x0d091c11, 0x081104a4, 0x3b002a02,   // en.pl.fi_433 mr.hi.ne_653  ru.ro.uk_433 mt.so.un_220
  0x211e1cac, 0x06130f04, 0x0e06180c, 0x0e1f1209,   // id.ms.jw_632 lv.et.de_332  ga.de.is_543 hu.cy.is_444
  // [1b80]
  0x04000c08, 0x3f120205, 0x0a071104, 0x01002422,   // sv.fi.un_430 da.hu.af_333  ro.bg.mk_332 yi.iw.un_870
  0x0e101b08, 0x01281fee, 0x2b004a23, 0x0c000e07,   // tr.lt.is_443 cy.sw.en_422  yo.vi.un_880 is.sv.un_420
  0x07682107, 0x3f3b1fa4, 0x4a2b2713, 0x3b190b55,   // jw.ig.it_432 cy.so.af_433  gd.vi.yo_665 es.gl.so_442
  0x271f29a4, 0x12000c13, 0x02001302, 0x11231f0c,   // sl.cy.gd_433 sv.hu.un_650  et.da.un_220 cy.ca.ro_543
  // [1b90]
  0x0a190104, 0x27002b21, 0x091c0d0e, 0x2b002714,   // en.gl.pt_332 vi.gd.un_860  ne.mr.hi_555 gd.vi.un_660
  0x55250e0c, 0x64002814, 0x08000b07, 0x060355a9,   // is.eu.rw_543 sw.lg.un_660  es.no.un_420 rw.nl.de_544
  0x353f080c, 0x35006402, 0x3b64130c, 0x350655a4,   // no.af.zu_543 lg.zu.un_220  et.lg.so_543 rw.de.zu_433
  0x19170a05, 0x081710a0, 0x0a000104, 0x0c000408,   // pt.sr.gl_333 be.sr.uk_322  en.pt.un_320 fi.sv.un_430
  // [1ba0]
  0x1a6455a4, 0x1a006b1a, 0x2b004a1b, 0x02001904,   // rw.lg.tl_433 ceb.tl.un_760  yo.vi.un_770 gl.da.un_320
  0x6428550d, 0x170a0807, 0x0b001904, 0x1000080c,   // rw.sw.lg_554 uk.mk.sr_432  gl.es.un_320 uk.be.un_530
  0x23001909, 0x32001104, 0x4a002b14, 0x051901ad,   // gl.ca.un_440 ro.bs.un_320  vi.yo.un_660 en.gl.fr_643
  0x10020f05, 0x28251f0d, 0x092855ad, 0x19091fa4,   // lv.da.lt_333 cy.eu.sw_554  rw.sw.pl_643 cy.pl.gl_433
  // [1bb0]
  0x290723a0, 0x03001212, 0x09000304, 0x12000921,   // ca.it.sl_322 hu.nl.un_640  nl.pl.un_320 pl.hu.un_860
  0x036455a4, 0x190b1fa4, 0x3f00551a, 0x170f3502,   // rw.lg.nl_433 cy.es.gl_433  rw.af.un_760 zu.lv.sr_222
  0x070408a4, 0x2d000e0c, 0x1f190b0c, 0x056b1104,   // uk.ru.bg_433 is.sk.un_530  es.gl.cy_543 ro.ceb.fr_332
  0x09001802, 0x28005507, 0x070a0102, 0x033f0aa6,   // ga.pl.un_220 rw.sw.un_420  en.pt.it_222 pt.af.nl_521
  // [1bc0]
  0x0400531a, 0x0400070c, 0x3f5301a0, 0x0d000912,   // ht.fi.un_760 bg.ru.un_530  en.ht.af_322 hi.ne.un_640
  0x0500531a, 0x213f35a0, 0x0a0553ad, 0x35001319,   // ht.fr.un_760 zu.af.jw_322  ht.fr.pt_643 et.zu.un_750
  0x20000108, 0x5300052b, 0x04060c04, 0x173f0502,   // en.sq.un_430 fr.ht.un_980  sv.de.fi_332 fr.af.sr_222
  0x25001f0c, 0x53000202, 0x1000070b, 0x05005322,   // cy.eu.un_530 da.ht.un_220  bg.be.un_520 ht.fr.un_870
  // [1bd0]
  0x29002108, 0x17000805, 0x090d1c05, 0x4a000104,   // jw.sl.un_430 uk.sr.un_330  mr.ne.hi_333 en.yo.un_320
  0x0f3217a4, 0x080c2aa4, 0x211c1e12, 0x020c3fee,   // sr.bs.lv_433 mt.sv.no_433  ms.id.jw_654 af.sv.da_422
  0x0a110708, 0x166b10ad, 0x11121f04, 0x0d530514,   // bg.ro.mk_443 lt.ceb.hr_643  cy.hu.ro_332 fr.ht.cs_666
  0x1b1e1aee, 0x53000523, 0x25004a07, 0x1c00210d,   // tl.ms.tr_422 fr.ht.un_880  yo.eu.un_420 jw.id.un_540
  // [1be0]
  0x0508025a, 0x6b553505, 0x0a0411a0, 0x32000f08,   // da.no.fr_553 zu.rw.ceb_333  ro.ru.mk_322 lv.bs.un_430
  0x1600060c, 0x3f006b08, 0x1f033f0d, 0x07001007,   // de.hr.un_530 ceb.af.un_430  af.nl.cy_554 lt.it.un_420
  0x21181211, 0x2d1f0ba0, 0x200e06a7, 0x32172102,   // ur.ar.fa_653 es.cy.sk_322  de.is.sq_532 jw.sr.bs_222
  0x0704080c, 0x131c09af, 0x091f0e07, 0x016b0da0,   // uk.ru.bg_543 hi.mr.bh_655  is.cy.pl_432 cs.ceb.en_322
  // [1bf0]
  0x0c003f08, 0x0e000b02, 0x2a32165a, 0x0704050c,   // af.sv.un_430 es.is.un_220  hr.bs.mt_553 fr.fi.it_543
  0x21531ca0, 0x1a6b01a0, 0x10002d0d, 0x0a001808,   // id.ht.jw_322 en.ceb.tl_322  sk.lt.un_540 ga.pt.un_430
  0x20070460, 0x080711a4, 0x020c0812, 0x0f0d0304,   // fi.it.sq_664 ro.bg.uk_433  no.sv.da_654 nl.cs.lv_332
  0x0f291b0b, 0x1b081307, 0x04080760, 0x040613a4,   // tr.sl.lv_542 et.no.tr_432  bg.uk.ru_664 et.de.fi_433

  // [1c00]
  0x07040812, 0x16133fa0, 0x3f006e04, 0x081710a4,   // uk.ru.bg_654 af.et.hr_322  hmn.af.un_320 be.sr.uk_433
  0x1a000804, 0x1c13090c, 0x1700112a, 0x11190a04,   // no.tl.un_320 hi.bh.mr_543  ro.sr.un_970 pt.gl.ro_332
  0x081309af, 0x25080e07, 0x1c090d12, 0x4a000604,   // pl.et.no_655 is.no.eu_432  ne.hi.mr_654 de.yo.un_320
  0x08060e0d, 0x080c0260, 0x07080aa4, 0x170a1004,   // is.de.no_554 da.sv.no_664  mk.uk.bg_433 be.mk.sr_332
  // [1c10]
  0x09050407, 0x18000419, 0x0d001c0b, 0x081704a7,   // fi.fr.pl_432 fi.ga.un_750  mr.ne.un_520 ru.sr.uk_532
  0x05000413, 0x04003508, 0x04000a05, 0x1100081a,   // fi.fr.un_650 zu.fi.un_430  mk.ru.un_330 uk.ro.un_760
  0x0f001b12, 0x0518040b, 0x0e08010c, 0x170411ee,   // tr.lv.un_640 fi.ga.fr_542  en.no.is_543 ro.ru.sr_422
  0x313b1bee, 0x0c083f04, 0x05000412, 0x03061307,   // tr.so.az_422 af.no.sv_332  fi.fr.un_640 et.de.nl_432
  // [1c20]
  0x1c0d13ec, 0x07170a0e, 0x031306a4, 0x040e1307,   // bh.ne.mr_644 mk.sr.bg_555  de.et.nl_433 et.is.fi_432
  0x04002807, 0x115308a9, 0x05002704, 0x23004a08,   // sw.fi.un_420 no.ht.ro_544  gd.fr.un_320 yo.ca.un_430
  0x03001f12, 0x06000823, 0x041110a4, 0x270f06a0,   // cy.nl.un_640 no.de.un_880  be.ro.ru_433 de.lv.gd_322
  0x0c010eee, 0x21002b0c, 0x321b0e0b, 0x3f0c0fa0,   // is.en.sv_422 vi.jw.un_530  is.tr.bs_542 lv.sv.af_322
  // [1c30]
  0x170411ad, 0x6e00090b, 0x0804100c, 0x28130455,   // ro.ru.sr_643 pl.hmn.un_520  be.ru.uk_543 fi.et.sw_442
  0x21002b09, 0x55002808, 0x2a000e0c, 0x00000937,   // vi.jw.un_440 sw.rw.un_430  is.mt.un_530 hi.un.un_B00
  0x55001004, 0x1f001320, 0x55281012, 0x130d1cad,   // lt.rw.un_320 et.cy.un_850  lt.sw.rw_654 mr.ne.bh_643
  0x07000822, 0x1e002105, 0x0800110d, 0x3b2a1f07,   // uk.bg.un_870 jw.ms.un_330  ro.uk.un_540 cy.mt.so_432
  // [1c40]
  0x190b2309, 0x102a0e0d, 0x53002b0d, 0x17162d05,   // ca.es.gl_444 is.mt.lt_554  vi.ht.un_540 sk.hr.sr_333
  0x1b003514, 0x21005308, 0x0a001720, 0x170a070d,   // zu.tr.un_660 ht.jw.un_430  sr.mk.un_850 bg.mk.sr_554
  0x3f003507, 0x04000604, 0x18003514, 0x023f0304,   // zu.af.un_420 de.fi.un_320  zu.ga.un_660 nl.af.da_332
  0x07040a05, 0x2818270c, 0x161b2d04, 0x09291b55,   // mk.ru.bg_333 gd.ga.sw_543  sk.tr.hr_332 tr.sl.pl_442
  // [1c50]
  0x04170aa6, 0x016b3507, 0x213f0311, 0x18006404,   // mk.sr.ru_521 zu.ceb.en_432  nl.af.jw_653 lg.ga.un_320
  0x1700290d, 0x1f292d55, 0x0d292d07, 0x0f001604,   // sl.sr.un_540 sk.sl.cy_442  sk.sl.cs_432 hr.lv.un_320
  0x041708a9, 0x290c02a0, 0x3110110c, 0x09001905,   // uk.sr.ru_544 da.sv.sl_322  ro.lt.az_543 gl.pl.un_330
  0x0d2d0912, 0x27001808, 0x1e2d1c0c, 0x2d0d17a0,   // pl.sk.cs_654 ga.gd.un_430  id.sk.ms_543 sr.cs.sk_322
  // [1c60]
  0x180e1fa7, 0x0600040b, 0x03000c07, 0x2d1b29a4,   // cy.is.ga_532 fi.de.un_520  sv.nl.un_420 sl.tr.sk_433
  0x55003508, 0x0d0913a7, 0x0a17070c, 0x29201308,   // zu.rw.un_430 bh.hi.ne_532  bg.sr.mk_543 et.sq.sl_443
  0x29120312, 0x2d1129a7, 0x530a1108, 0x1b002d04,   // nl.hu.sl_654 sl.ro.sk_532  ro.pt.ht_443 sk.tr.un_320
  0x20002a13, 0x0e120ca9, 0x01001f05, 0x03002019,   // mt.sq.un_650 sv.hu.is_544  cy.en.un_330 sq.nl.un_750
  // [1c70]
  0x32290404, 0x09001607, 0x1f533fa0, 0x1300042b,   // fi.sl.bs_332 hr.pl.un_420  af.ht.cy_322 fi.et.un_980
  0x292d0d55, 0x051a3555, 0x10041712, 0x23000a23,   // cs.sk.sl_442 zu.tl.fr_442  sr.ru.be_654 pt.ca.un_880
  0x09011f04, 0x23050b07, 0x2b001e08, 0x64003508,   // cy.en.pl_332 es.fr.ca_432  ms.vi.un_430 zu.lg.un_430
  0x180c06ad, 0x3f0603af, 0x0e000612, 0x09002907,   // de.sv.ga_643 nl.de.af_655  de.is.un_640 sl.pl.un_420
  // [1c80]
  0x130306ad, 0x033f0613, 0x0c000822, 0x090d1caf,   // de.nl.et_643 de.af.nl_665  no.sv.un_870 mr.ne.hi_655
  0x3100530e, 0x6b3f0212, 0x29000313, 0x1b002a0c,   // ht.az.un_550 da.af.ceb_654  nl.sl.un_650 mt.tr.un_530
  0x3f0625a0, 0x0c0217a4, 0x10000913, 0x13643b07,   // eu.de.af_322 sr.da.sv_433  pl.lt.un_650 so.lg.et_432
  0x210b075a, 0x19000108, 0x21000105, 0x53000713,   // it.es.jw_553 en.gl.un_430  en.jw.un_330 it.ht.un_650
  // [1c90]
  0x20002b14, 0x04071111, 0x0a281104, 0x2113350c,   // vi.sq.un_660 ro.bg.ru_653  ro.sw.pt_332 zu.et.jw_543
  0x040a08a9, 0x3b191004, 0x2a002008, 0x01080205,   // uk.mk.ru_544 lt.gl.so_332  sq.mt.un_430 da.no.en_333
  0x0a110f0c, 0x0a1107a4, 0x07001904, 0x0804105a,   // lv.ro.pt_543 bg.ro.mk_433  gl.it.un_320 be.ru.uk_553
  0x3f0c06ee, 0x0e001904, 0x06021ea9, 0x08030555,   // de.sv.af_422 gl.is.un_320  ms.da.de_544 fr.nl.no_442
  // [1ca0]
  0x21001a08, 0x091253ee, 0x080212af, 0x071704ec,   // tl.jw.un_430 ht.hu.pl_422  hu.da.no_655 ru.sr.bg_644
  0x080203ee, 0x04081702, 0x03001207, 0x10001707,   // nl.da.no_422 sr.uk.ru_222  hu.nl.un_420 sr.lt.un_420
  0x0c001007, 0x08041055, 0x041707ad, 0x3f000304,   // lt.sv.un_420 be.ru.uk_442  bg.sr.ru_643 nl.af.un_320
  0x18005504, 0x01001f19, 0x32001712, 0x10000808,   // rw.ga.un_320 cy.en.un_750  sr.bs.un_640 no.lt.un_430
  // [1cb0]
  0x53002107, 0x04001112, 0x2a000704, 0x0d002802,   // jw.ht.un_420 ro.fi.un_640  it.mt.un_320 sw.cs.un_220
  0x29321608, 0x1c006804, 0x111b1211, 0x10000e04,   // hr.bs.sl_443 ig.id.un_320  hu.tr.ro_653 is.lt.un_320
  0x0100110c, 0x3f002008, 0x0d1935a0, 0x08071704,   // ro.en.un_530 sq.af.un_430  zu.gl.cs_322 sr.bg.uk_332
  0x16292da4, 0x04001105, 0x68553513, 0x130411ec,   // sk.sl.hr_433 ro.fi.un_330  zu.rw.ig_665 ro.fi.et_644
  // [1cc0]
  0x28000104, 0x2a000a07, 0x11000404, 0x0a001102,   // en.sw.un_320 pt.mt.un_420  fi.ro.un_320 ro.pt.un_220
  0x06000d13, 0x643523ec, 0x1220130c, 0x68006422,   // cs.de.un_650 ca.zu.lg_644  et.sq.hu_543 lg.ig.un_870
  0x18002108, 0x20002d04, 0x130b0c05, 0x1a3564a9,   // fa.ar.un_430 sk.sq.un_320  sv.es.et_333 lg.zu.tl_544
  0x0b0c13af, 0x68003514, 0x64001608, 0x0a0c1e04,   // et.sv.es_655 zu.ig.un_660  hr.lg.un_430 ms.sv.pt_332
  // [1cd0]
  0x0a0908a0, 0x55002804, 0x02000e13, 0x19130ca7,   // no.pl.pt_322 sw.rw.un_320  is.da.un_650 sv.et.gl_532
  0x13000d0c, 0x55642855, 0x6b251b11, 0x21645504,   // ne.bh.un_530 sw.lg.rw_442  tr.eu.ceb_653 rw.lg.jw_332
  0x21006412, 0x16000a05, 0x08040a07, 0x10041704,   // lg.jw.un_640 pt.hr.un_330  mk.ru.uk_432 sr.ru.be_332
  0x1a2d0a07, 0x1a28355a, 0x53102907, 0x1c002b05,   // pt.sk.tl_432 zu.sw.tl_553  sl.lt.ht_432 vi.id.un_330
  // [1ce0]
  0x64552107, 0x0c190ba6, 0x190b07a0, 0x321613a4,   // jw.rw.lg_432 es.gl.sv_521  it.es.gl_322 et.hr.bs_433
  0x2d001704, 0x17005204, 0x08006412, 0x05524aee,   // sr.sk.un_320 ha.sr.un_320  lg.no.un_640 yo.ha.fr_422
  0x0704100d, 0x0c3b2002, 0x0c041305, 0x21000b02,   // be.ru.bg_554 sq.so.sv_222  et.fi.sv_333 es.jw.un_220
  0x3f001318, 0x21001807, 0x0b01110c, 0x0a0417af,   // et.af.un_740 ar.fa.un_420  ro.en.es_543 sr.ru.mk_655
  // [1cf0]
  0x190a01a0, 0x06000809, 0x08040708, 0x0d002d21,   // en.pt.gl_322 no.de.un_440  bg.ru.uk_443 sk.cs.un_860
  0x2b3f21a0, 0x17000108, 0x4a21100c, 0x074a10a7,   // jw.af.vi_322 en.sr.un_430  lt.jw.yo_543 lt.yo.it_532
  0x645568ac, 0x19002113, 0x032552a0, 0x10080408,   // ig.rw.lg_632 jw.gl.un_650  ha.eu.nl_322 ru.uk.be_443
  0x060e0c60, 0x521e1c07, 0x17041108, 0x1c000904,   // sv.is.de_664 id.ms.ha_432  ro.ru.sr_443 hi.mr.un_320
  // [1d00]
  0x0d000412, 0x29002a0b, 0x06001108, 0x20001308,   // fi.cs.un_640 mt.sl.un_520  ro.de.un_430 et.sq.un_430
  0x12020ca4, 0x3f006b07, 0x3f001c02, 0x18006e07,   // sv.da.hu_433 ceb.af.un_420  id.af.un_220 hmn.ga.un_420
  0x170804a0, 0x01001804, 0x0e0506a6, 0x0a1704ad,   // ru.uk.sr_322 ga.en.un_320  de.fr.is_521 ru.sr.mk_643
  0x0c002504, 0x3b002104, 0x0c000220, 0x1c311ea9,   // eu.sv.un_320 jw.so.un_320  da.sv.un_850 ms.az.id_544
  // [1d10]
  0x0e000c1a, 0x6b001a1b, 0x11070a14, 0x27001c04,   // sv.is.un_760 tl.ceb.un_770  mk.bg.ro_666 id.gd.un_320
  0x292003ee, 0x08000e13, 0x032923ad, 0x133f0312,   // nl.sq.sl_422 is.no.un_650  ca.sl.nl_643 nl.af.et_654
  0x0a111705, 0x03003f23, 0x01521eee, 0x0000082d,   // sr.ro.mk_333 af.nl.un_880  ms.ha.en_422 uk.un.un_A00
  0x0a041709, 0x3f00130e, 0x12001a02, 0x03000911,   // sr.ru.mk_444 et.af.un_550  tl.hu.un_220 pl.nl.un_630
  // [1d20]
  0x13000a07, 0x08020cee, 0x0c070107, 0x0e000504,   // pt.et.un_420 sv.da.no_422  en.it.sv_432 fr.is.un_320
  0x253b050c, 0x2d090da0, 0x130a08a0, 0x033f08ad,   // fr.so.eu_543 cs.pl.sk_322  no.pt.et_322 no.af.nl_643
  0x21121813, 0x0a002807, 0x6b2928a9, 0x19000b11,   // ar.ur.fa_665 sw.pt.un_420  sw.sl.ceb_544 es.gl.un_630
  0x5200350d, 0x0400131a, 0x17000a22, 0x070417a9,   // zu.ha.un_540 et.fi.un_760  mk.sr.un_870 sr.ru.bg_544
  // [1d30]
  0x6800641a, 0x03283fa7, 0x23190b05, 0x556b1a12,   // lg.ig.un_760 af.sw.nl_532  es.gl.ca_333 tl.ceb.rw_654
  0x6b5520a4, 0x52000304, 0x033f1308, 0x11001604,   // sq.rw.ceb_433 nl.ha.un_320  et.af.nl_443 hr.ro.un_320
  0x174a1ca0, 0x12002711, 0x061132a4, 0x06122514,   // id.yo.sr_322 gd.hu.un_630  bs.ro.de_433 eu.hu.de_666
  0x21282da7, 0x29030604, 0x55351c02, 0x07040aa4,   // sk.sw.jw_532 de.nl.sl_332  id.zu.rw_222 mk.ru.bg_433
  // [1d40]
  0x644a1b04, 0x04281807, 0x28001c02, 0x2b001604,   // tr.yo.lg_332 ga.sw.fi_432  id.sw.un_220 hr.vi.un_320
  0x06000f19, 0x102835a0, 0x0e080208, 0x311255ec,   // lv.de.un_750 zu.sw.lt_322  da.no.is_443 rw.hu.az_644
  0x09001c1b, 0x1c001e07, 0x3f000e07, 0x0400130c,   // mr.hi.un_770 ms.id.un_420  is.af.un_420 et.fi.un_530
  0x130409a4, 0x080a1711, 0x3f000e13, 0x092d0d02,   // pl.fi.et_433 sr.mk.uk_653  is.af.un_650 cs.sk.pl_222
  // [1d50]
  0x2b001704, 0x2a005204, 0x13000204, 0x18002b12,   // sr.vi.un_320 ha.mt.un_320  da.et.un_320 vi.ga.un_640
  0x04170a0c, 0x19002504, 0x352028ee, 0x07001004,   // mk.sr.ru_543 eu.gl.un_320  sw.sq.zu_422 be.bg.un_320
  0x17000a20, 0x253f0304, 0x1c2025a7, 0x3f032707,   // mk.sr.un_850 nl.af.eu_332  eu.sq.id_532 gd.nl.af_432
  0x040717a4, 0x043b0e07, 0x10552104, 0x0f090613,   // sr.bg.ru_433 is.so.fi_432  jw.rw.lt_332 de.pl.lv_665
  // [1d60]
  0x64003522, 0x04006405, 0x170a070c, 0x2d0d2909,   // zu.lg.un_870 lg.fi.un_330  bg.mk.sr_543 sl.cs.sk_444
  0x07040a0c, 0x040102a0, 0x28001808, 0x171629ee,   // mk.ru.bg_543 da.en.fi_322  ga.sw.un_430 sl.hr.sr_422
  0x040a11ee, 0x09001c11, 0x13182707, 0x20122a0c,   // ro.mk.ru_422 mr.hi.un_630  gd.ga.et_432 mt.hu.sq_543
  0x0b00120c, 0x680801a4, 0x04071705, 0x170708a0,   // hu.es.un_530 en.no.ig_433  sr.bg.ru_333 uk.bg.sr_322
  // [1d70]
  0x3500281b, 0x6b3f0307, 0x090d130c, 0x1100132a,   // sw.zu.un_770 nl.af.ceb_432  bh.ne.hi_543 et.ro.un_970
  0x091f350c, 0x0600350e, 0x2a2835ad, 0x0400250e,   // zu.cy.pl_543 zu.de.un_550  zu.sw.mt_643 eu.fi.un_550
  0x3f003514, 0x3f000604, 0x3f35060d, 0x170a0709,   // zu.af.un_660 de.af.un_320  de.zu.af_554 bg.mk.sr_444
  0x64352aaf, 0x13090da4, 0x0600130c, 0x03000602,   // mt.zu.lg_655 ne.hi.bh_433  et.de.un_530 de.nl.un_220
  // [1d80]
  0x2d0d2902, 0x35645555, 0x12001007, 0x27000609,   // sl.cs.sk_222 rw.lg.zu_442  lt.hu.un_420 de.gd.un_440
  0x64041305, 0x0f000d08, 0x2a3f0805, 0x13000604,   // et.fi.lg_333 cs.lv.un_430  no.af.mt_333 de.et.un_320
  0x3200161a, 0x0e2d0d02, 0x070a04a7, 0x2a350655,   // hr.bs.un_760 cs.sk.is_222  ru.mk.bg_532 de.zu.mt_442
  0x120c1ea4, 0x1b006804, 0x090306a7, 0x20030807,   // ms.sv.hu_433 ig.tr.un_320  de.nl.pl_532 no.nl.sq_432
  // [1d90]
  0x0e001908, 0x01000804, 0x06080f04, 0x10120911,   // gl.is.un_430 no.en.un_320  lv.no.de_332 pl.hu.lt_653
  0x13000414, 0x17003207, 0x091c0da4, 0x0b180102,   // fi.et.un_660 bs.sr.un_420  ne.mr.hi_433 en.ga.es_222
  0x130c2aa7, 0x1b4a640b, 0x3101050c, 0x16071105,   // mt.sv.et_532 lg.yo.tr_542  fr.en.az_543 ro.it.hr_333
  0x0c093fa0, 0x08120208, 0x354a6805, 0x190b23ee,   // af.pl.sv_322 da.hu.no_443  ig.yo.zu_333 ca.es.gl_422
  // [1da0]
  0x1f0c3fa0, 0x2a002d07, 0x052301ee, 0x17080aa4,   // af.sv.cy_322 sk.mt.un_420  en.ca.fr_422 mk.uk.sr_433
  0x292d0907, 0x02093202, 0x23000702, 0x32000908,   // pl.sk.sl_432 bs.pl.da_222  it.ca.un_220 pl.bs.un_430
  0x0d091c0e, 0x0a00070d, 0x27351aa0, 0x284a0a12,   // mr.hi.ne_555 bg.mk.un_540  tl.zu.gd_322 pt.yo.sw_654
  0x311b5511, 0x0c1827a7, 0x091c0d04, 0x09005214,   // rw.tr.az_653 gd.ga.sv_532  ne.mr.hi_332 ha.pl.un_660
  // [1db0]
  0x011827a4, 0x356409ac, 0x3f000323, 0x531e1704,   // gd.ga.en_433 pl.lg.zu_632  nl.af.un_880 sr.ms.ht_332
  0x35000913, 0x3f000335, 0x12002009, 0x030b3f5a,   // pl.zu.un_650 nl.af.un_A90  sq.hu.un_440 af.es.nl_553
  0x03132904, 0x0f001602, 0x6452090c, 0x52000918,   // sl.et.nl_332 hr.lv.un_220  pl.ha.lg_543 pl.ha.un_740
  0x29002004, 0x3b000104, 0x230507a4, 0x2d356404,   // sq.sl.un_320 en.so.un_320  it.fr.ca_433 lg.zu.sk_332
  // [1dc0]
  0x6b1a1b0c, 0x3b00270e, 0x055301a4, 0x645528a4,   // tr.tl.ceb_543 gd.so.un_550  en.ht.fr_433 sw.rw.lg_433
  0x0900640e, 0x6b000b04, 0x0708100c, 0x2b00050d,   // lg.pl.un_550 es.ceb.un_320  be.uk.bg_543 fr.vi.un_540
  0x310c28a4, 0x02002714, 0x1a52350c, 0x080c1f0c,   // sw.sv.az_433 gd.da.un_660  zu.ha.tl_543 cy.sv.no_543
  0x08170455, 0x350428a0, 0x1a553b11, 0x04005223,   // ru.sr.uk_442 sw.fi.zu_322  so.rw.tl_653 ha.fi.un_880
  // [1dd0]
  0x2500550d, 0x2b001c05, 0x133f0607, 0x1b1c52ad,   // rw.eu.un_540 id.vi.un_330  de.af.et_432 ha.id.tr_643
  0x11001f0e, 0x09005213, 0x2852090b, 0x53641211,   // cy.ro.un_550 ha.pl.un_650  pl.ha.sw_542 hu.lg.ht_653
  0x1e3b0ca0, 0x4a006421, 0x6e641a12, 0x09521ca4,   // sv.so.ms_322 lg.yo.un_860  tl.lg.hmn_654 id.ha.pl_433
  0x28553512, 0x216b550c, 0x0a041708, 0x130408a0,   // zu.rw.sw_654 rw.ceb.jw_543  sr.ru.mk_443 no.fi.et_322
  // [1de0]
  0x110a1313, 0x0b001907, 0x0c00021b, 0x1f04205a,   // et.pt.ro_665 gl.es.un_420  da.sv.un_770 sq.fi.cy_553
  0x08000e0e, 0x1a001f07, 0x13552108, 0x0b00190d,   // is.no.un_550 cy.tl.un_420  jw.rw.et_443 gl.es.un_540
  0x0c000523, 0x200b07a4, 0x032b01a4, 0x016b3f08,   // fr.sv.un_880 it.es.sq_433  en.vi.nl_433 af.ceb.en_443
  0x18211260, 0x1f055305, 0x040a11a6, 0x29002d14,   // ur.fa.ar_664 ht.fr.cy_333  ro.mk.ru_521 sk.sl.un_660
  // [1df0]
  0x0c000e13, 0x100721a0, 0x04003b12, 0x3b640413,   // is.sv.un_650 jw.it.lt_322  so.fi.un_640 fi.lg.so_665
  0x1b000c12, 0x0f201155, 0x2b001c02, 0x0d171ead,   // sv.tr.un_640 ro.sq.lv_442  id.vi.un_220 ms.sr.cs_643
  0x0e00640d, 0x04643ba7, 0x190b25a9, 0x21641a02,   // lg.is.un_540 so.lg.fi_532  eu.es.gl_544 tl.lg.jw_222
  0x10000f19, 0x352855a0, 0x0413255a, 0x08130eee,   // lv.lt.un_750 rw.sw.zu_322  eu.et.fi_553 is.et.no_422
  // [1e00]
  0x07001112, 0x1b096ea0, 0x043b680b, 0x06002704,   // ro.bg.un_640 hmn.pl.tr_322  ig.so.fi_542 gd.de.un_320
  0x0d001c02, 0x091c0d08, 0x03001008, 0x64041311,   // mr.ne.un_220 ne.mr.hi_443  lt.nl.un_430 et.fi.lg_653
  0x043b640c, 0x64133b0c, 0x0b1219ee, 0x133b640c,   // lg.so.fi_543 so.et.lg_543  gl.hu.es_422 lg.so.et_543
  0x0e002502, 0x0c02080b, 0x110a1712, 0x116418ad,   // eu.is.un_220 no.da.sv_542  sr.mk.ro_654 ga.lg.ro_643
  // [1e10]
  0x552964a0, 0x07040a04, 0x28002507, 0x0a070414,   // lg.sl.rw_322 mk.ru.bg_332  eu.sw.un_420 ru.bg.mk_666
  0x2d001214, 0x2d000d0b, 0x1a1e1c04, 0x202925a7,   // hu.sk.un_660 cs.sk.un_520  id.ms.tl_332 eu.sl.sq_532
  0x0d1c0904, 0x070a2513, 0x4a00251a, 0x0b2107ee,   // hi.mr.ne_332 eu.pt.it_665  eu.yo.un_760 it.jw.es_422
  0x2700250e, 0x646e250c, 0x6b1a2508, 0x08110760,   // eu.gd.un_550 eu.hmn.lg_543  eu.tl.ceb_443 bg.ro.uk_664
  // [1e20]
  0x04081009, 0x31002105, 0x11050ea4, 0x040807ee,   // be.uk.ru_444 jw.az.un_330  is.fr.ro_433 bg.uk.ru_422
  0x356828a4, 0x28046e07, 0x32172aa4, 0x0b35130c,   // sw.ig.zu_433 hmn.fi.sw_432  mt.sr.bs_433 et.zu.es_543
  0x1e1c20af, 0x0f000808, 0x1b005321, 0x1e18110c,   // sq.id.ms_655 no.lv.un_430  ht.tr.un_860 ro.ga.ms_543
  0x175535a0, 0x04002102, 0x0f00080c, 0x041017a4,   // zu.rw.sr_322 jw.fi.un_220  no.lv.un_530 sr.be.ru_433
  // [1e30]
  0x10000b05, 0x17002a04, 0x190b21ee, 0x0a171107,   // es.lt.un_330 mt.sr.un_320  jw.es.gl_422 ro.sr.mk_432
  0x1c215307, 0x6432280c, 0x08005302, 0x6b1a5312,   // ht.jw.id_432 sw.bs.lg_543  ht.no.un_220 ht.tl.ceb_654
  0x1f001b0c, 0x29002705, 0x322d0d0d, 0x23001908,   // tr.cy.un_530 gd.sl.un_330  cs.sk.bs_554 gl.ca.un_430
  0x182311ee, 0x350e2a0d, 0x13010ead, 0x07002708,   // ro.ca.ga_422 mt.is.zu_554  is.en.et_643 gd.it.un_430
  // [1e40]
  0x1b000604, 0x0409250d, 0x2a001c04, 0x25352855,   // de.tr.un_320 eu.pl.fi_554  id.mt.un_320 sw.zu.eu_442
  0x23180eaf, 0x0c1102a0, 0x08001702, 0x3100522b,   // is.ga.ca_655 da.ro.sv_322  sr.uk.un_220 ha.az.un_980
  0x280652a4, 0x2100121b, 0x0d005508, 0x1107520c,   // ha.de.sw_433 ur.fa.un_770  rw.cs.un_430 ha.it.ro_543
  0x080a1f04, 0x2d0d29a0, 0x0b182308, 0x23002005,   // cy.pt.no_332 sl.cs.sk_322  ca.ga.es_443 sq.ca.un_330
  // [1e50]
  0x0b0a20a4, 0x0b0a11ee, 0x286455a4, 0x21181260,   // sq.pt.es_433 ro.pt.es_422  rw.lg.sw_433 ur.ar.fa_664
  0x040a070c, 0x09000421, 0x1800121a, 0x32002a05,   // bg.mk.ru_543 fi.pl.un_860  hu.ga.un_760 mt.bs.un_330
  0x0700171a, 0x5500640e, 0x230e1907, 0x1f001b04,   // sr.bg.un_760 lg.rw.un_550  gl.is.ca_432 tr.cy.un_320
  0x0c0304ee, 0x11200c11, 0x1c001314, 0x06002322,   // fi.nl.sv_422 sv.sq.ro_653  bh.mr.un_660 ca.de.un_870
  // [1e60]
  0x0c062504, 0x0a080705, 0x18002304, 0x102304a0,   // eu.de.sv_332 bg.uk.mk_333  ca.ga.un_320 fi.ca.lt_322
  0x52002823, 0x040a07a7, 0x1912180b, 0x182d0d1a,   // sw.ha.un_880 bg.mk.ru_532  ga.hu.gl_542 cs.sk.ga_776
  0x32162909, 0x3f002305, 0x122d0d12, 0x1b003111,   // sl.hr.bs_444 ca.af.un_330  cs.sk.hu_654 az.tr.un_630
  0x0b000a09, 0x04170805, 0x17000a23, 0x122d0d0e,   // pt.es.un_440 uk.sr.ru_333  mk.sr.un_880 cs.sk.hu_555
  // [1e70]
  0x070408ec, 0x0c003f04, 0x3f000204, 0x0c1101a0,   // uk.ru.bg_644 af.sv.un_320  da.af.un_320 en.ro.sv_322
  0x25642aa4, 0x190b060c, 0x1800060c, 0x1e1c0a09,   // mt.lg.eu_433 de.es.gl_543  de.ga.un_530 pt.id.ms_444
  0x040811ee, 0x0a070405, 0x0b0e0204, 0x6b041fa7,   // ro.uk.ru_422 ru.bg.mk_333  da.is.es_332 cy.fi.ceb_532
  0x0d680407, 0x0a000504, 0x17080908, 0x1b000609,   // fi.ig.cs_432 fr.pt.un_320  pl.no.sr_443 de.tr.un_440
  // [1e80]
  0x120d2da9, 0x0e0c0807, 0x1b0b3507, 0x03000513,   // sk.cs.hu_544 no.sv.is_432  zu.es.tr_432 fr.nl.un_650
  0x12001319, 0x64190b04, 0x25002309, 0x1c5521ad,   // et.hu.un_750 es.gl.lg_332  ca.eu.un_440 jw.rw.id_643
  0x11002321, 0x0f311b5a, 0x0f000607, 0x29230509,   // ca.ro.un_860 tr.az.lv_553  de.lv.un_420 fr.ca.sl_444
  0x27002302, 0x3f00020c, 0x081e0207, 0x08000c07,   // ca.gd.un_220 da.af.un_530  da.ms.no_432 sv.no.un_420
  // [1e90]
  0x041e1c55, 0x0e0f1055, 0x031205a0, 0x130d090e,   // id.ms.fi_442 lt.lv.is_442  fr.hu.nl_322 hi.ne.bh_555
  0x100a0708, 0x08000c05, 0x04131012, 0x312a20ad,   // bg.mk.be_443 sv.no.un_330  lt.et.fi_654 sq.mt.az_643
  0x07101faf, 0x102d1ea0, 0x1e1c28af, 0x081007a9,   // cy.lt.it_655 ms.sk.lt_322  sw.id.ms_655 bg.be.uk_544
  0x320e2d08, 0x04103ba0, 0x17040a07, 0x1c000908,   // sk.is.bs_443 so.lt.fi_322  mk.ru.sr_432 hi.mr.un_430
  // [1ea0]
  0x53130407, 0x0d002d04, 0x27002d0e, 0x53016ba9,   // fi.et.ht_432 sk.cs.un_320  sk.gd.un_550 ceb.en.ht_544
  0x1c04280c, 0x19000b0d, 0x12182160, 0x13041005,   // sw.fi.id_543 es.gl.un_540  fa.ar.ur_664 lt.fi.et_333
  0x11080aa4, 0x3f2d1f12, 0x1f002d0e, 0x030908ec,   // mk.uk.ro_433 cy.sk.af_654  sk.cy.un_550 no.pl.nl_644
  0x080407af, 0x2d00061b, 0x1a133bad, 0x16006805,   // bg.ru.uk_655 de.sk.un_770  so.et.tl_643 ig.hr.un_330
  // [1eb0]
  0x55133b5a, 0x323f2da0, 0x1a553b08, 0x28135505,   // so.et.rw_553 sk.af.bs_322  so.rw.tl_443 rw.et.sw_333
  0x1f002d0c, 0x0c643b09, 0x21064a04, 0x04182804,   // sk.cy.un_530 so.lg.sv_444  yo.de.jw_332 sw.ga.fi_332
  0x0f52100c, 0x080417ee, 0x11081208, 0x112055ee,   // lt.ha.lv_543 sr.ru.uk_422  hu.no.ro_443 rw.sq.ro_422
  0x554a13ee, 0x10190a13, 0x1a6b5207, 0x270f10af,   // et.yo.rw_422 pt.gl.lt_665  ha.ceb.tl_432 lt.lv.gd_655
  // [1ec0]
  0x02001819, 0x020608a6, 0x01005508, 0x13683b0c,   // ga.da.un_750 no.de.da_521  rw.en.un_430 so.ig.et_543
  0x08021805, 0x013527a0, 0x16193bee, 0x120c0ead,   // ga.da.no_333 gd.zu.en_322  so.gl.hr_422 is.sv.hu_643
  0x0b00070c, 0x200f55a4, 0x07000805, 0x083f0614,   // it.es.un_530 rw.lv.sq_433  uk.bg.un_330 de.af.no_666
  0x1000251a, 0x273128a4, 0x0c050608, 0x18272dad,   // eu.lt.un_760 sw.az.gd_433  de.fr.sv_443 sk.gd.ga_643
  // [1ed0]
  0x3b000213, 0x3b00641b, 0x12201704, 0x55000107,   // da.so.un_650 lg.so.un_770  sr.sq.hu_332 en.rw.un_420
  0x0d001212, 0x130c3b04, 0x2903090c, 0x0c005304,   // hu.cs.un_640 so.sv.et_332  pl.nl.sl_543 ht.sv.un_320
  0x2a0713ee, 0x1a6b3b60, 0x2d0d2a0e, 0x133b64a9,   // et.it.mt_422 so.ceb.tl_664  mt.cs.sk_555 lg.so.et_544
  0x080711a0, 0x091c1360, 0x130c3ba9, 0x64001b0b,   // ro.bg.uk_322 bh.mr.hi_664  so.sv.et_544 tr.lg.un_520
  // [1ee0]
  0x0d062504, 0x553b6408, 0x13000c07, 0x00002824,   // eu.de.cs_332 lg.so.rw_443  sv.et.un_420 sw.un.un_900
  0x174a1b0e, 0x16005504, 0x05000a05, 0x12000e1a,   // tr.yo.sr_555 rw.hr.un_320  pt.fr.un_330 is.hu.un_760
  0x04130f0c, 0x05000e13, 0x1f033fa9, 0x0e05080c,   // lv.et.fi_543 is.fr.un_650  af.nl.cy_544 no.fr.is_543
  0x21041007, 0x02002d08, 0x06031812, 0x1f003b21,   // lt.fi.jw_432 sk.da.un_430  ga.nl.de_654 so.cy.un_860
  // [1ef0]
  0x170a10af, 0x1206080c, 0x070501ec, 0x011e28a7,   // be.mk.sr_655 no.de.hu_543  en.fr.it_644 sw.ms.en_532
  0x09101aa4, 0x13005222, 0x06000322, 0x07050112,   // tl.lt.pl_433 ha.et.un_870  nl.de.un_870 en.fr.it_654
  0x1a006b09, 0x3f3b02af, 0x2d0d32a0, 0x090d1c12,   // ceb.tl.un_440 da.so.af_655  bs.cs.sk_322 mr.ne.hi_654
  0x02040eec, 0x23191fac, 0x1a2b3507, 0x1600280d,   // is.fi.da_644 cy.gl.ca_632  zu.vi.tl_432 sw.hr.un_540
  // [1f00]
  0x192b07a0, 0x231f1213, 0x0411080b, 0x04060307,   // it.vi.gl_322 hu.cy.ca_665  uk.ro.ru_542 nl.de.fi_432
  0x1f3f0312, 0x040813af, 0x55002113, 0x0f001f13,   // nl.af.cy_654 et.no.fi_655  jw.rw.un_650 cy.lv.un_650
  0x64041a0c, 0x3b190a04, 0x0b351a0c, 0x21001822,   // tl.fi.lg_543 pt.gl.so_332  tl.zu.es_543 ar.fa.un_870
  0x10003b08, 0x0704110c, 0x2b003513, 0x0f1b31af,   // so.lt.un_430 ro.ru.bg_543  zu.vi.un_650 az.tr.lv_655
  // [1f10]
  0x2d052507, 0x18002112, 0x21001c12, 0x29000707,   // eu.fr.sk_432 fa.ar.un_640  id.jw.un_640 it.sl.un_420
  0x310f1ba4, 0x312164ee, 0x06080ca0, 0x1205530c,   // tr.lv.az_433 lg.jw.az_422  sv.no.de_322 ht.fr.hu_543
  0x02000f14, 0x213f0307, 0x21005508, 0x0a001208,   // lv.da.un_660 nl.af.jw_432  rw.jw.un_430 hu.pt.un_430
  0x011307a0, 0x2d0d12ee, 0x1f033f0c, 0x0e000a04,   // it.et.en_322 hu.cs.sk_422  af.nl.cy_543 pt.is.un_320
  // [1f20]
  0x122d0d08, 0x1a6b3508, 0x1a043b12, 0x04100505,   // cs.sk.hu_443 zu.ceb.tl_443  so.fi.tl_654 fr.lt.fi_333
  0x53133505, 0x13070404, 0x1c1e21ad, 0x2300270d,   // zu.et.ht_333 fi.it.et_332  jw.ms.id_643 gd.ca.un_540
  0x081206a4, 0x2d0d1904, 0x1f002502, 0x0e060805,   // de.hu.no_433 gl.cs.sk_332  eu.cy.un_220 no.de.is_333
  0x08063f05, 0x285304a4, 0x06040355, 0x0c0f080c,   // af.de.no_333 fi.ht.sw_433  nl.fi.de_442 no.lv.sv_543
  // [1f30]
  0x00003f2d, 0x23200b02, 0x0a002309, 0x033f270e,   // af.un.un_A00 es.sq.ca_222  ca.pt.un_440 gd.af.nl_555
  0x1a001318, 0x060208a4, 0x12023f60, 0x17040a08,   // et.tl.un_740 no.da.de_433  af.da.hu_664 mk.ru.sr_443
  0x0c181ba0, 0x2900030e, 0x0b050308, 0x05002502,   // tr.ga.sv_322 nl.sl.un_550  nl.fr.es_443 eu.fr.un_220
  0x1e1c1b02, 0x180227a0, 0x080a0707, 0x12002513,   // tr.id.ms_222 gd.da.ga_322  bg.mk.uk_432 eu.hu.un_650
  // [1f40]
  0x3f000e08, 0x04003b19, 0x21001834, 0x043f3b0c,   // is.af.un_430 so.fi.un_750  ar.fa.un_A80 so.af.fi_543
  0x28043b07, 0x3f040313, 0x0a00170d, 0x170710a0,   // so.fi.sw_432 nl.fi.af_665  sr.mk.un_540 be.bg.sr_322
  0x0f000e18, 0x3b033f12, 0x23000a05, 0x04022aa4,   // is.lv.un_740 af.nl.so_654  pt.ca.un_330 mt.da.fi_433
  0x3f031aaf, 0x09080e0c, 0x13271813, 0x3b1304ec,   // tl.nl.af_655 is.no.pl_543  ga.gd.et_665 fi.et.so_644
  // [1f50]
  0x0d093507, 0x6b2d0d0d, 0x020a0807, 0x06000e04,   // zu.pl.cs_432 cs.sk.ceb_554  no.pt.da_432 is.de.un_320
  0x2d002907, 0x2000320c, 0x3b2821af, 0x1c521eee,   // sl.sk.un_420 bs.sq.un_530  jw.sw.so_655 ms.ha.id_422
  0x133f0307, 0x18076bee, 0x04133b11, 0x033f0409,   // nl.af.et_432 ceb.it.ga_422  so.et.fi_653 fi.af.nl_444
  0x3f133b0c, 0x0a1711ee, 0x35002721, 0x050711a4,   // so.et.af_543 ro.sr.mk_422  gd.zu.un_860 ro.it.fr_433
  // [1f60]
  0x0c00080d, 0x04005218, 0x3b001005, 0x3b321604,   // no.sv.un_540 ha.fi.un_740  lt.so.un_330 hr.bs.so_332
  0x0b2a25a0, 0x08001705, 0x552511a7, 0x041b31ee,   // eu.mt.es_322 sr.uk.un_330  ro.eu.rw_532 az.tr.fi_422
  0x0c0220a6, 0x35002722, 0x05124a0c, 0x211f1107,   // sq.da.sv_521 gd.zu.un_870  yo.hu.fr_543 ro.cy.jw_432
  0x3f021f07, 0x08000302, 0x55003522, 0x55000d13,   // cy.da.af_432 nl.no.un_220  zu.rw.un_870 cs.rw.un_650
  // [1f70]
  0x23002012, 0x020535a4, 0x23001904, 0x2d0d1314,   // sq.ca.un_640 zu.fr.da_433  gl.ca.un_320 et.cs.sk_666
  0x201206ad, 0x0a0811ee, 0x10190f13, 0x1c0d13ad,   // de.hu.sq_643 ro.uk.mk_422  lv.gl.lt_665 bh.ne.mr_643
  0x033f1f08, 0x35000121, 0x2b002508, 0x20005202,   // cy.af.nl_443 en.zu.un_860  eu.vi.un_430 ha.sq.un_220
  0x033f3ba0, 0x031c5307, 0x2b002504, 0x033f0ca9,   // so.af.nl_322 ht.id.nl_432  eu.vi.un_320 sv.af.nl_544
  // [1f80]
  0x3b0b35a4, 0x1a006804, 0x04101104, 0x0000092d,   // zu.es.so_433 ig.tl.un_320  ro.be.ru_332 pl.un.un_A00
  0x0b0a1909, 0x3b6413a4, 0x351e1c0e, 0x13003b20,   // gl.pt.es_444 et.lg.so_433  id.ms.zu_555 so.et.un_850
  0x1c0d09a9, 0x64283bec, 0x31001b21, 0x190a0ba4,   // hi.ne.mr_544 so.sw.lg_644  tr.az.un_860 es.pt.gl_433
  0x6b281e07, 0x0a00230d, 0x2100100b, 0x0b2b19a0,   // ms.sw.ceb_432 ca.pt.un_540  lt.jw.un_520 gl.vi.es_322
  // [1f90]
  0x19005204, 0x2900350d, 0x3b2152ee, 0x18002d05,   // ha.gl.un_320 zu.sl.un_540  ha.jw.so_422 sk.ga.un_330
  0x2b4a64ad, 0x19003b0e, 0x4a133b05, 0x190b0aa9,   // lg.yo.vi_643 so.gl.un_550  so.et.yo_333 pt.es.gl_544
  0x3b006407, 0x053b1c04, 0x3b00640d, 0x276b1a60,   // lg.so.un_420 id.so.fr_332  lg.so.un_540 tl.ceb.gd_664
  0x1812210e, 0x1e0728a0, 0x64002804, 0x0b0a19af,   // fa.ur.ar_555 sw.it.ms_322  sw.lg.un_320 gl.pt.es_655
  // [1fa0]
  0x25556b0c, 0x05002007, 0x0b1a3b12, 0x19052104,   // ceb.rw.eu_543 sq.fr.un_420  so.tl.es_654 jw.fr.gl_332
  0x23190a08, 0x120a05a0, 0x643555af, 0x21001235,   // pt.gl.ca_443 fr.pt.hu_322  rw.zu.lg_655 ur.fa.un_A90
  0x2a5268ad, 0x13002a1b, 0x0c001314, 0x02001a04,   // ig.ha.mt_643 mt.et.un_770  et.sv.un_660 tl.da.un_320
  0x0e3b05ad, 0x64001904, 0x3b6428ec, 0x643b3fa9,   // fr.so.is_643 gl.lg.un_320  sw.lg.so_644 af.so.lg_544
  // [1fb0]
  0x13250204, 0x1e313bad, 0x0c0f1014, 0x08071008,   // da.eu.et_332 so.az.ms_643  lt.lv.sv_666 be.bg.uk_443
  0x090d1c13, 0x21001c19, 0x0e0206a4, 0x050701a9,   // mr.ne.hi_665 id.jw.un_750  de.da.is_433 en.it.fr_544
  0x050716a0, 0x080c0e0c, 0x0e321bee, 0x13091cec,   // hr.it.fr_322 is.sv.no_543  tr.bs.is_422 mr.hi.bh_644
  0x10002304, 0x10000a21, 0x0600310d, 0x08001709,   // ca.lt.un_320 mk.be.un_860  az.de.un_540 sr.uk.un_440
  // [1fc0]
  0x1b00180e, 0x2d0a1205, 0x16000702, 0x2a1e2707,   // ga.tr.un_550 hu.pt.sk_333  it.hr.un_220 gd.ms.mt_432
  0x10170a07, 0x0600520e, 0x03083f02, 0x322916a0,   // mk.sr.be_432 ha.de.un_550  af.no.nl_222 hr.sl.bs_322
  0x3b2820a0, 0x213b2812, 0x1e1c21a6, 0x32162aa4,   // sq.sw.so_322 sw.so.jw_654  jw.id.ms_521 mt.hr.bs_433
  0x32291602, 0x3b1a21a4, 0x29321604, 0x20351ea0,   // hr.sl.bs_222 jw.tl.so_433  hr.bs.sl_332 ms.zu.sq_322
  // [1fd0]
  0x6b131a08, 0x25001212, 0x18002007, 0x023b2155,   // tl.et.ceb_443 hu.eu.un_640  sq.ga.un_420 jw.so.da_442
  0x2d00250c, 0x11002007, 0x1a352807, 0x32522907,   // eu.sk.un_530 sq.ro.un_420  sw.zu.tl_432 sl.ha.bs_432
  0x2d0d640c, 0x3b002705, 0x2164280d, 0x17000a1b,   // lg.cs.sk_543 gd.so.un_330  sw.lg.jw_554 mk.sr.un_770
  0x10002704, 0x1f00011a, 0x643528ad, 0x162932a7,   // gd.lt.un_320 en.cy.un_760  sw.zu.lg_643 bs.sl.hr_532
  // [1fe0]
  0x1e0921ee, 0x25101fec, 0x1e1c2d0c, 0x213b120c,   // jw.pl.ms_422 cy.lt.eu_644  sk.id.ms_543 hu.so.jw_543
  0x31002012, 0x64283508, 0x13000d1b, 0x0c3f2507,   // sq.az.un_640 zu.sw.lg_443  ne.bh.un_770 eu.af.sv_432
  0x092d0d13, 0x35526455, 0x4a53050c, 0x0900121a,   // cs.sk.pl_665 lg.ha.zu_442  fr.ht.yo_543 hu.pl.un_760
  0x072501a0, 0x0900250c, 0x520c130c, 0x0413100e,   // en.eu.it_322 eu.pl.un_530  et.sv.ha_543 lt.et.fi_555
  // [1ff0]
  0x08002702, 0x0a1710a7, 0x050625ad, 0x160d2da4,   // gd.no.un_220 be.sr.mk_532  eu.de.fr_643 sk.cs.hr_433
  0x1a6428ad, 0x1218270c, 0x1a00281a, 0x2a0a04ee,   // sw.lg.tl_643 gd.ga.hu_543  sw.tl.un_760 fi.pt.mt_422
  0x1200010c, 0x0a07170d, 0x17040a0c, 0x3b003519,   // en.hu.un_530 sr.bg.mk_554  mk.ru.sr_543 zu.so.un_750
  0x19070b12, 0x123b21a7, 0x033f06a4, 0x0d005308,   // es.it.gl_654 jw.so.hu_532  de.af.nl_433 ht.cs.un_430

  // [2000]
  0x2a272107, 0x311f1b07, 0x2000110c, 0x6b682704,   // jw.gd.mt_432 tr.cy.az_432  ro.sq.un_530 gd.ig.ceb_332
  0x0f033fa0, 0x10001a04, 0x1e1f1012, 0x070411a4,   // af.nl.lv_322 tl.lt.un_320  lt.cy.ms_654 ro.ru.bg_433
  0x28001804, 0x102701a0, 0x351a2708, 0x17290d07,   // ga.sw.un_320 en.gd.lt_322  gd.tl.zu_443 cs.sl.sr_432
  0x526853a0, 0x08250c02, 0x0b002707, 0x25002809,   // ht.ig.ha_322 sv.eu.no_222  gd.es.un_420 sw.eu.un_440
  // [2010]
  0x130d0913, 0x2000251a, 0x04000802, 0x252a04af,   // hi.ne.bh_665 eu.sq.un_760  uk.ru.un_220 fi.mt.eu_655
  0x09130d0d, 0x6e00060d, 0x29160da0, 0x32000d05,   // ne.bh.hi_554 de.hmn.un_540  cs.hr.sl_322 cs.bs.un_330
  0x17001118, 0x0e1304a4, 0x2a000c04, 0x1c002304,   // ro.sr.un_740 fi.et.is_433  sv.mt.un_320 ca.id.un_320
  0x5300050c, 0x1f20275a, 0x091c0d5a, 0x041e1cad,   // fr.ht.un_530 gd.sq.cy_553  ne.mr.hi_553 id.ms.fi_643
  // [2020]
  0x28553505, 0x06350107, 0x6e0e0ba0, 0x21040ca0,   // zu.rw.sw_333 en.zu.de_432  es.is.hmn_322 sv.fi.jw_322
  0x321729a4, 0x21190b0d, 0x536e01a0, 0x0b0a19a4,   // sl.sr.bs_433 es.gl.jw_554  en.hmn.ht_322 gl.pt.es_433
  0x0c3f0204, 0x17000d07, 0x13041b55, 0x04000104,   // da.af.sv_332 cs.sr.un_420  tr.fi.et_442 en.fi.un_320
  0x25000104, 0x2904530c, 0x011b6ba0, 0x043b1bac,   // en.eu.un_320 ht.fi.sl_543  ceb.tr.en_322 tr.so.fi_632
  // [2030]
  0x25201c05, 0x3f250ba4, 0x100b06ee, 0x191a0a0d,   // id.sq.eu_333 es.eu.af_433  de.es.lt_422 pt.tl.gl_554
  0x190b07af, 0x02001f08, 0x25002807, 0x08070ba0,   // it.es.gl_655 cy.da.un_430  sw.eu.un_420 es.it.no_322
  0x011b3ba4, 0x01003b09, 0x120d0e07, 0x1c130d11,   // so.tr.en_433 so.en.un_440  is.cs.hu_432 ne.bh.mr_653
  0x040a170d, 0x53071111, 0x3f000320, 0x07002507,   // sr.mk.ru_554 ro.it.ht_653  nl.af.un_850 eu.it.un_420
  // [2040]
  0x3b1b315a, 0x03005313, 0x6b00010c, 0x162d0dee,   // az.tr.so_553 ht.nl.un_650  en.ceb.un_530 cs.sk.hr_422
  0x53000414, 0x190a01a9, 0x040a070e, 0x53050d0c,   // fi.ht.un_660 en.pt.gl_544  bg.mk.ru_555 cs.fr.ht_543
  0x291e1c04, 0x01352da0, 0x31283b02, 0x3f000413,   // id.ms.sl_332 sk.zu.en_322  so.sw.az_222 fi.af.un_650
  0x11002513, 0x02071fee, 0x040a1709, 0x0d530507,   // eu.ro.un_650 cy.it.da_422  sr.mk.ru_444 fr.ht.cs_432
  // [2050]
  0x0400250d, 0x64351fee, 0x2d0d29ec, 0x23253ba9,   // eu.fi.un_540 cy.zu.lg_422  sl.cs.sk_644 so.eu.ca_544
  0x533f030b, 0x32176409, 0x04100aa9, 0x3f040da0,   // nl.af.ht_542 lg.sr.bs_444  mk.be.ru_544 cs.fi.af_322
  0x1e001c0d, 0x0c000205, 0x53052912, 0x02060d08,   // id.ms.un_540 da.sv.un_330  sl.fr.ht_654 cs.de.da_443
  0x1008040c, 0x1f251807, 0x0d000920, 0x52002a08,   // ru.uk.be_543 ga.eu.cy_432  hi.ne.un_850 mt.ha.un_430
  // [2060]
  0x0a17080b, 0x0600290c, 0x3b002a19, 0x1f001021,   // uk.sr.mk_542 sl.de.un_530  mt.so.un_750 lt.cy.un_860
  0x170408a4, 0x13001c13, 0x07010ba0, 0x0c2128ee,   // uk.ru.sr_433 mr.bh.un_650  es.en.it_322 sw.jw.sv_422
  0x12000621, 0x534a05ad, 0x230525a9, 0x130d0905,   // de.hu.un_860 fr.yo.ht_643  eu.fr.ca_544 hi.ne.bh_333
  0x1c1309ee, 0x203b2a11, 0x0e0406a7, 0x1f212509,   // hi.bh.mr_422 mt.so.sq_653  de.fi.is_532 eu.jw.cy_444
  // [2070]
  0x06041313, 0x3f0601a4, 0x2a00131a, 0x645568ee,   // et.fi.de_665 en.de.af_433  et.mt.un_760 ig.rw.lg_422
  0x05002808, 0x31121b05, 0x130c120c, 0x64321704,   // sw.fr.un_430 tr.hu.az_333  hu.sv.et_543 sr.bs.lg_332
  0x6413060c, 0x0e000618, 0x0c1a6b07, 0x19310aad,   // de.et.lg_543 de.is.un_740  ceb.tl.sv_432 pt.az.gl_643
  0x28000204, 0x2a000e21, 0x1704100e, 0x11005302,   // da.sw.un_320 is.mt.un_860  be.ru.sr_555 ht.ro.un_220
  // [2080]
  0x02212a07, 0x1f006b07, 0x0400081b, 0x08202aad,   // mt.jw.da_432 ceb.cy.un_420  uk.ru.un_770 mt.sq.no_643
  0x0e080204, 0x08020ea4, 0x35271813, 0x0d000921,   // da.no.is_332 is.da.no_433  ga.gd.zu_665 hi.ne.un_860
  0x08033f0c, 0x04003b23, 0x12211802, 0x10081702,   // af.nl.no_543 so.fi.un_880  ar.fa.ur_222 sr.uk.be_222
  0x2a060408, 0x3b030407, 0x2a2507af, 0x13040609,   // fi.de.mt_443 fi.nl.so_432  it.eu.mt_655 de.fi.et_444
  // [2090]
  0x030413ad, 0x2d003202, 0x0b000502, 0x0804100b,   // et.fi.nl_643 bs.sk.un_220  fr.es.un_220 be.ru.uk_542
  0x062701ad, 0x21080205, 0x080203a0, 0x28006b0b,   // en.gd.de_643 da.no.jw_333  nl.da.no_322 ceb.sw.un_520
  0x3b000404, 0x3f3b1a07, 0x05000704, 0x2000350c,   // fi.so.un_320 tl.so.af_432  it.fr.un_320 zu.sq.un_530
  0x062112a0, 0x6b5301ec, 0x041a3b0e, 0x180205a0,   // hu.jw.de_322 en.ht.ceb_644  so.tl.fi_555 fr.da.ga_322
  // [20a0]
  0x1f00061a, 0x6b270111, 0x12000204, 0x11002504,   // de.cy.un_760 en.gd.ceb_653  da.hu.un_320 eu.ro.un_320
  0x1100250c, 0x06643f05, 0x25000702, 0x08171009,   // eu.ro.un_530 af.lg.de_333  it.eu.un_220 be.sr.uk_444
  0x12000804, 0x1a0768a6, 0x13002518, 0x020c0807,   // no.hu.un_320 ig.it.tl_521  eu.et.un_740 no.sv.da_432
  0x2500110d, 0x050a1b02, 0x3f0403a4, 0x0c00060b,   // ro.eu.un_540 tr.pt.fr_222  nl.fi.af_433 de.sv.un_520
  // [20b0]
  0x07002508, 0x292d1702, 0x133f03ec, 0x2d002008,   // eu.it.un_430 sr.sk.sl_222  nl.af.et_644 sq.sk.un_430
  0x53074a0c, 0x116801ee, 0x02001a08, 0x0e35520c,   // yo.it.ht_543 en.ig.ro_422  tl.da.un_430 ha.zu.is_543
  0x053f03a9, 0x080e04ee, 0x2500010d, 0x01002102,   // nl.af.fr_544 fi.is.no_422  en.eu.un_540 jw.en.un_220
  0x081304a4, 0x215227a0, 0x683b3104, 0x11032dee,   // fi.et.no_433 gd.ha.jw_322  az.so.ig_332 sk.nl.ro_422
  // [20c0]
  0x08000708, 0x1a006b1b, 0x09001102, 0x201125a0,   // bg.uk.un_430 ceb.tl.un_770  ro.pl.un_220 eu.ro.sq_322
  0x1100250b, 0x28112504, 0x09032502, 0x056b01a0,   // eu.ro.un_520 eu.ro.sw_332  eu.nl.pl_222 en.ceb.fr_322
  0x0b2519a7, 0x533113a7, 0x32102dee, 0x13033f60,   // gl.eu.es_532 et.az.ht_532  sk.lt.bs_422 af.nl.et_664
  0x12000513, 0x13000d0d, 0x03001108, 0x550464a0,   // fr.hu.un_650 ne.bh.un_540  ro.nl.un_430 lg.fi.rw_322
  // [20d0]
  0x132902ee, 0x0c1304a4, 0x11120107, 0x0f090760,   // da.sl.et_422 fi.et.sv_433  en.hu.ro_432 it.pl.lv_664
  0x193f0308, 0x530413a4, 0x25126bad, 0x55531aa4,   // nl.af.gl_443 et.fi.ht_433  ceb.hu.eu_643 tl.ht.rw_433
  0x052d1212, 0x03002d0e, 0x0a041007, 0x062b270b,   // hu.sk.fr_654 sk.nl.un_550  be.ru.mk_432 gd.vi.de_542
  0x0b070209, 0x03110fee, 0x0b005508, 0x19000a07,   // da.it.es_444 lv.ro.nl_422  rw.es.un_430 pt.gl.un_420
  // [20e0]
  0x07190bee, 0x0900270e, 0x191101a4, 0x1c002807,   // es.gl.it_422 gd.pl.un_550  en.ro.gl_433 sw.id.un_420
  0x17321613, 0x31001e0d, 0x0a0410a0, 0x1012110c,   // hr.bs.sr_665 ms.az.un_540  be.ru.mk_322 ro.hu.lt_543
  0x040a21ee, 0x0a284a07, 0x55642804, 0x043f13a0,   // jw.pt.fi_422 yo.sw.pt_432  sw.lg.rw_332 et.af.fi_322
  0x08041111, 0x21000508, 0x201101a0, 0x64321fa7,   // ro.ru.uk_653 fr.jw.un_430  en.ro.sq_322 cy.bs.lg_532
  // [20f0]
  0x08520e12, 0x0b00121a, 0x0f006b04, 0x27002d13,   // is.ha.no_654 hu.es.un_760  ceb.lv.un_320 sk.gd.un_650
  0x2000351b, 0x0600271a, 0x3f030212, 0x270f04a4,   // zu.sq.un_770 gd.de.un_760  da.nl.af_654 fi.lv.gd_433
  0x080407a7, 0x1708110c, 0x25002107, 0x232719ec,   // bg.ru.uk_532 ro.uk.sr_543  jw.eu.un_420 gl.gd.ca_644
  0x0e190b60, 0x20001123, 0x3f050313, 0x0b55520c,   // es.gl.is_664 ro.sq.un_880  nl.fr.af_665 ha.rw.es_543
  // [2100]
  0x290d2daf, 0x10081708, 0x29001705, 0x17000104,   // sk.cs.sl_655 sr.uk.be_443  sr.sl.un_330 en.sr.un_320
  0x0c00060d, 0x04070a02, 0x12000f04, 0x050a01a4,   // de.sv.un_540 mk.bg.ru_222  lv.hu.un_320 en.pt.fr_433
  0x19001104, 0x1a350712, 0x53001a07, 0x52552809,   // ro.gl.un_320 it.zu.tl_654  tl.ht.un_420 sw.rw.ha_444
  0x1c2123a0, 0x0e5308a0, 0x31001b2a, 0x21002308,   // ca.jw.id_322 no.ht.is_322  tr.az.un_970 ca.jw.un_430
  // [2110]
  0x0b271904, 0x0f001f19, 0x07000612, 0x0f130e12,   // gl.gd.es_332 cy.lv.un_750  de.it.un_640 is.et.lv_654
  0x10000834, 0x1b000807, 0x2a033f5a, 0x28352160,   // uk.be.un_A80 no.tr.un_420  af.nl.mt_553 jw.zu.sw_664
  0x21001e0d, 0x55354a07, 0x35000808, 0x29003204,   // ms.jw.un_540 yo.zu.rw_432  no.zu.un_430 bs.sl.un_320
  0x2300111b, 0x01000302, 0x0207055a, 0x272135ee,   // ro.ca.un_770 nl.en.un_220  fr.it.da_553 zu.jw.gd_422
  // [2120]
  0x04071112, 0x21000305, 0x3b002707, 0x1f003521,   // ro.bg.ru_654 nl.jw.un_330  gd.so.un_420 zu.cy.un_860
  0x04110805, 0x1c090d0d, 0x02001209, 0x35556413,   // uk.ro.ru_333 ne.hi.mr_554  hu.da.un_440 lg.rw.zu_665
  0x01060307, 0x1e001c2b, 0x0627180d, 0x123f01a4,   // nl.de.en_432 id.ms.un_980  ga.gd.de_554 en.af.hu_433
  0x181221ad, 0x29001e02, 0x19002507, 0x21001809,   // fa.ur.ar_643 ms.sl.un_220  eu.gl.un_420 ar.fa.un_440
  // [2130]
  0x033f2007, 0x172d0d0d, 0x10041307, 0x201f0304,   // sq.af.nl_432 cs.sk.sr_554  et.fi.lt_432 nl.cy.sq_332
  0x060e0c04, 0x170a08a4, 0x3f1123a0, 0x231110a4,   // sv.is.de_332 uk.mk.sr_433  ca.ro.af_322 lt.ro.ca_433
  0x07041760, 0x0a041104, 0x01036b04, 0x20531fa7,   // sr.ru.bg_664 ro.ru.mk_332  ceb.nl.en_332 cy.ht.sq_532
  0x13002722, 0x182127a0, 0x25001907, 0x25123155,   // gd.et.un_870 gd.jw.ga_322  gl.eu.un_420 az.hu.eu_442
  // [2140]
  0x6b002014, 0x1b02230c, 0x351e1c02, 0x18000302,   // sq.ceb.un_660 ca.da.tr_543  id.ms.zu_222 nl.ga.un_220
  0x53002819, 0x13271808, 0x170c5302, 0x530121a0,   // sw.ht.un_750 ga.gd.et_443  ht.sv.sr_222 jw.en.ht_322
  0x18271f07, 0x5500350d, 0x210103a0, 0x0a006e07,   // cy.gd.ga_432 zu.rw.un_540  nl.en.jw_322 hmn.pt.un_420
  0x03001105, 0x01532712, 0x1f3f010c, 0x355528af,   // ro.nl.un_330 gd.ht.en_654  en.af.cy_543 sw.rw.zu_655
  // [2150]
  0x3f1235a0, 0x232b1ca0, 0x20050aa6, 0x25000307,   // zu.hu.af_322 id.vi.ca_322  pt.fr.sq_521 nl.eu.un_420
  0x130806a6, 0x0a0710a0, 0x040717a9, 0x2700010d,   // de.no.et_521 be.bg.mk_322  sr.bg.ru_544 en.gd.un_540
  0x12132708, 0x0e2d0d08, 0x0f001702, 0x06016ba0,   // gd.et.hu_443 cs.sk.is_443  sr.lv.un_220 ceb.en.de_322
  0x081711ee, 0x0a04170d, 0x3200171b, 0x040a1708,   // ro.sr.uk_422 sr.ru.mk_554  sr.bs.un_770 sr.mk.ru_443
  // [2160]
  0x20533511, 0x286455ec, 0x1c0720ee, 0x2d0f2904,   // zu.ht.sq_653 rw.lg.sw_644  sq.it.id_422 sl.lv.sk_332
  0x21001805, 0x1b0931a4, 0x0d091cac, 0x040708ee,   // ga.jw.un_330 az.pl.tr_433  mr.hi.ne_632 uk.bg.ru_422
  0x20002a09, 0x06001309, 0x2a001212, 0x55061305,   // mt.sq.un_440 et.de.un_440  hu.mt.un_640 et.de.rw_333
  0x190a18ac, 0x13002908, 0x2d0920ec, 0x6b080cec,   // ga.pt.gl_632 sl.et.un_430  sq.pl.sk_644 sv.no.ceb_644
  // [2170]
  0x12206e04, 0x091c1304, 0x0d091c0c, 0x64043bee,   // hmn.sq.hu_332 bh.mr.hi_332  mr.hi.ne_543 so.fi.lg_422
  0x17002905, 0x0f1029a0, 0x041b3107, 0x04643bad,   // sl.sr.un_330 sl.lt.lv_322  az.tr.fi_432 so.lg.fi_643
  0x100408a9, 0x16002d05, 0x28640407, 0x3b046404,   // no.fi.lt_544 sk.hr.un_330  fi.lg.sw_432 lg.fi.so_332
  0x10000429, 0x210518ac, 0x190a07af, 0x19001804,   // ru.be.un_960 ga.fr.jw_632  it.pt.gl_655 ga.gl.un_320
  // [2180]
  0x35000209, 0x20002a0d, 0x0c12170c, 0x0d001c19,   // da.zu.un_440 mt.sq.un_540  sr.hu.sv_543 mr.ne.un_750
  0x0f120c0c, 0x131235a7, 0x6e1720a4, 0x010c0aa6,   // sv.hu.lv_543 zu.hu.et_532  sq.sr.hmn_433 pt.sv.en_521
  0x32000d08, 0x20006e13, 0x0700290d, 0x1c0d0912,   // cs.bs.un_430 hmn.sq.un_650  sl.it.un_540 hi.ne.mr_654
  0x2a0c25a0, 0x120c2a07, 0x10020fee, 0x08010c04,   // eu.sv.mt_322 mt.sv.hu_432  lv.da.lt_422 sv.en.no_332
  // [2190]
  0x21001e02, 0x29161309, 0x281a6407, 0x20001318,   // ms.jw.un_220 et.hr.sl_444  lg.tl.sw_432 et.sq.un_740
  0x18000709, 0x17070413, 0x0608020d, 0x64130455,   // it.ga.un_440 ru.bg.sr_665  da.no.de_554 fi.et.lg_442
  0x05000113, 0x2d0f100c, 0x08021bee, 0x0f003f02,   // en.fr.un_650 lt.lv.sk_543  tr.da.no_422 af.lv.un_220
  0x20005504, 0x10170405, 0x3f0604a4, 0x0b006404,   // rw.sq.un_320 ru.sr.be_333  fi.de.af_433 lg.es.un_320
  // [21a0]
  0x350107ee, 0x07000421, 0x080204a9, 0x19000709,   // it.en.zu_422 ru.bg.un_860  fi.da.no_544 it.gl.un_440
  0x0300020c, 0x12090da0, 0x09001f14, 0x3f1008a0,   // da.nl.un_530 cs.pl.hu_322  cy.pl.un_660 no.lt.af_322
  0x13640404, 0x55000611, 0x213f23a4, 0x29001304,   // fi.lg.et_332 de.rw.un_630  ca.af.jw_433 et.sl.un_320
  0x35001302, 0x02000804, 0x10060f07, 0x0803130c,   // et.zu.un_220 no.da.un_320  lv.de.lt_432 et.nl.no_543
  // [21b0]
  0x11002302, 0x2300251b, 0x080601a0, 0x1f122713,   // ca.ro.un_220 eu.ca.un_770  en.de.no_322 gd.hu.cy_665
  0x070a040c, 0x4a530512, 0x07040809, 0x21061aa0,   // ru.mk.bg_543 fr.ht.yo_654  uk.ru.bg_444 tl.de.jw_322
  0x29171605, 0x100704ec, 0x1f00110c, 0x3b0613a7,   // hr.sr.sl_333 ru.bg.be_644  ro.cy.un_530 et.de.so_532
  0x0f102904, 0x080a17a7, 0x08170a04, 0x0a00100d,   // sl.lt.lv_332 sr.mk.uk_532  mk.sr.uk_332 be.mk.un_540
  // [21c0]
  0x1b001002, 0x04005222, 0x012718a0, 0x10041e05,   // lt.tr.un_220 ha.fi.un_870  ga.gd.en_322 ms.fi.lt_333
  0x06040107, 0x121f18a4, 0x0e0f0604, 0x13003b19,   // en.fi.de_432 ga.cy.hu_433  de.lv.is_332 so.et.un_750
  0x01002502, 0x2800530d, 0x0d0929ad, 0x0d092da0,   // eu.en.un_220 ht.sw.un_540  sl.pl.cs_643 sk.pl.cs_322
  0x68006419, 0x1f000919, 0x060e1304, 0x01130455,   // lg.ig.un_750 pl.cy.un_750  et.is.de_332 fi.et.en_442
  // [21d0]
  0x0e080205, 0x10251faf, 0x3b006b13, 0x6b356855,   // da.no.is_333 cy.eu.lt_655  ceb.so.un_650 ig.zu.ceb_442
  0x290f1707, 0x163217a7, 0x3b0f2aa4, 0x2d000912,   // sr.lv.sl_432 sr.bs.hr_532  mt.lv.so_433 pl.sk.un_640
  0x01001104, 0x170229a9, 0x101f09ec, 0x100f17ee,   // ro.en.un_320 sl.da.sr_544  pl.cy.lt_644 sr.lv.lt_422
  0x521e1c04, 0x535564ad, 0x55642811, 0x6b3b1aa4,   // id.ms.ha_332 lg.rw.ht_643  sw.lg.rw_653 tl.so.ceb_433
  // [21e0]
  0x2d096e08, 0x0d001902, 0x524a6b04, 0x05126804,   // hmn.pl.sk_443 gl.cs.un_220  ceb.yo.ha_332 ig.hu.fr_332
  0x28000802, 0x0e04135a, 0x06110704, 0x4a645360,   // no.sw.un_220 et.fi.is_553  it.ro.de_332 ht.lg.yo_664
  0x0b121908, 0x5500641a, 0x200e0407, 0x071b110c,   // gl.hu.es_443 lg.rw.un_760  fi.is.sq_432 ro.tr.it_543
  0x0f0625a4, 0x09100207, 0x160d29a0, 0x55002812,   // eu.de.lv_433 da.lt.pl_432  sl.cs.hr_322 sw.rw.un_640
  // [21f0]
  0x21050ea4, 0x2d00170d, 0x026b05a0, 0x21006b13,   // is.fr.jw_433 sr.sk.un_540  fr.ceb.da_322 ceb.jw.un_650
  0x08041013, 0x3b002a1a, 0x07060dad, 0x32001004,   // be.ru.uk_665 mt.so.un_760  cs.de.it_643 lt.bs.un_320
  0x3b1e1c14, 0x08200e0c, 0x171029a9, 0x2300112a,   // id.ms.so_666 is.sq.no_543  sl.lt.sr_544 ro.ca.un_970
  0x1f1c1eec, 0x040a0708, 0x030f0502, 0x28006b05,   // ms.id.cy_644 bg.mk.ru_443  fr.lv.nl_222 ceb.sw.un_330
  // [2200]
  0x25190ba7, 0x3b026e11, 0x2000031a, 0x2d0f090c,   // es.gl.eu_532 hmn.da.so_653  nl.sq.un_760 pl.lv.sk_543
  0x12001822, 0x3f320702, 0x1200110c, 0x0f00100e,   // ar.ur.un_870 it.bs.af_222  ro.hu.un_530 lt.lv.un_550
  0x642855ad, 0x100419ad, 0x55645312, 0x35282155,   // rw.sw.lg_643 gl.fi.lt_643  ht.lg.rw_654 jw.sw.zu_442
  0x0f100a04, 0x192105a4, 0x13000d0e, 0x23002521,   // pt.lt.lv_332 fr.jw.gl_433  ne.bh.un_550 eu.ca.un_860
  // [2210]
  0x64001905, 0x13002a02, 0x0b0f1012, 0x12640713,   // gl.lg.un_330 mt.et.un_220  lt.lv.es_654 it.lg.hu_665
  0x12000913, 0x19532308, 0x190b0c05, 0x13531b04,   // pl.hu.un_650 ca.ht.gl_443  sv.es.gl_333 tr.ht.et_332
  0x190a0ba9, 0x23062560, 0x643555ee, 0x640503ee,   // es.pt.gl_544 eu.de.ca_664  rw.zu.lg_422 nl.fr.lg_422
  0x3f006e08, 0x12000922, 0x0e001902, 0x133f03ee,   // hmn.af.un_430 pl.hu.un_870  gl.is.un_220 nl.af.et_422
  // [2220]
  0x55000604, 0x1b00210c, 0x0c000208, 0x0a101708,   // de.rw.un_320 jw.tr.un_530  da.sv.un_430 sr.be.mk_443
  0x0f001013, 0x13000808, 0x19000a0b, 0x0e006404,   // lt.lv.un_650 no.et.un_430  pt.gl.un_520 lg.is.un_320
  0x0e55205a, 0x0b25190c, 0x040811a9, 0x190a0b09,   // sq.rw.is_553 gl.eu.es_543  ro.uk.ru_544 es.pt.gl_444
  0x03010602, 0x10001904, 0x255228ad, 0x3f250a04,   // de.en.nl_222 gl.lt.un_320  sw.ha.eu_643 pt.eu.af_332
  // [2230]
  0x52002804, 0x0d1c09ad, 0x2b0801ad, 0x180701a4,   // sw.ha.un_320 hi.mr.ne_643  en.no.vi_643 en.it.ga_433
  0x1c00131a, 0x1c000913, 0x2000680e, 0x6b113fa0,   // bh.mr.un_760 hi.mr.un_650  ig.sq.un_550 af.ro.ceb_322
  0x291304ec, 0x5300050e, 0x3f000a04, 0x063f135a,   // fi.et.sl_644 fr.ht.un_550  pt.af.un_320 et.af.de_553
  0x06205505, 0x070810a9, 0x2100182a, 0x033f130b,   // rw.sq.de_333 be.uk.bg_544  ar.fa.un_970 et.af.nl_542
  // [2240]
  0x070817a4, 0x21002004, 0x036e13ad, 0x190b23a4,   // sr.uk.bg_433 sq.jw.un_320  et.hmn.nl_643 ca.es.gl_433
  0x2008520c, 0x20001602, 0x10080413, 0x2d0d1faf,   // ha.no.sq_543 hr.sq.un_220  ru.uk.be_665 cy.cs.sk_655
  0x3216290d, 0x17070a08, 0x08001013, 0x232b19ee,   // sl.hr.bs_554 mk.bg.sr_443  be.uk.un_650 gl.vi.ca_422
  0x53556ba4, 0x0c080255, 0x19020b08, 0x2500121b,   // ceb.rw.ht_433 da.no.sv_442  es.da.gl_443 hu.eu.un_770
  // [2250]
  0x2d0d11ee, 0x041011ee, 0x01002407, 0x21001c09,   // ro.cs.sk_422 ro.be.ru_422  yi.iw.un_420 id.jw.un_440
  0x0b002513, 0x2d0d0e09, 0x25004a19, 0x2d0d0a05,   // eu.es.un_650 is.cs.sk_444  yo.eu.un_750 pt.cs.sk_333
  0x0f002104, 0x18001205, 0x0a040714, 0x06000302,   // jw.lv.un_320 ur.ar.un_330  bg.ru.mk_666 nl.de.un_220
  0x0a000b07, 0x04001721, 0x10002909, 0x10000307,   // es.pt.un_420 sr.ru.un_860  sl.lt.un_440 nl.lt.un_420
  // [2260]
  0x0700111a, 0x20000e07, 0x1c000d22, 0x55002822,   // ro.bg.un_760 is.sq.un_420  ne.mr.un_870 sw.rw.un_870
  0x17070809, 0x11000f11, 0x100d2dee, 0x17041155,   // uk.bg.sr_444 lv.ro.un_630  sk.cs.lt_422 ro.ru.sr_442
  0x18211205, 0x4a002308, 0x19000104, 0x3f3b0308,   // ur.fa.ar_333 ca.yo.un_430  en.gl.un_320 nl.so.af_443
  0x3b001314, 0x03643b08, 0x0e3f03a7, 0x083f030c,   // et.so.un_660 so.lg.nl_443  nl.af.is_532 nl.af.no_543
  // [2270]
  0x031c3f05, 0x0c000605, 0x0d00092c, 0x061208a0,   // af.id.nl_333 de.sv.un_330  hi.ne.un_990 no.hu.de_322
  0x35043f04, 0x03133ba4, 0x4a060407, 0x070a11af,   // af.fi.zu_332 so.et.nl_433  fi.de.yo_432 ro.mk.bg_655
  0x08643b07, 0x13002804, 0x06000c05, 0x080212a9,   // so.lg.no_432 sw.et.un_320  sv.de.un_330 hu.da.no_544
  0x0708040d, 0x55126409, 0x4a00230c, 0x2d0c1fa4,   // ru.uk.bg_554 lg.hu.rw_444  ca.yo.un_530 cy.sv.sk_433
  // [2280]
  0x3f031aee, 0x29001605, 0x122735a0, 0x2d0c09ec,   // tl.nl.af_422 hr.sl.un_330  zu.gd.hu_322 pl.sv.sk_644
  0x04081107, 0x3f3b035a, 0x3f3b0355, 0x04003b07,   // ro.uk.ru_432 nl.so.af_553  nl.so.af_442 so.fi.un_420
  0x12003205, 0x0e3f1204, 0x3f07230c, 0x17130655,   // bs.hu.un_330 hu.af.is_332  ca.it.af_543 de.et.sr_442
  0x31130407, 0x1716290c, 0x0a08070b, 0x053f23a4,   // fi.et.az_432 sl.hr.sr_543  bg.uk.mk_542 ca.af.fr_433
  // [2290]
  0x0a171002, 0x6b0523a0, 0x0b03050c, 0x551e1c04,   // be.sr.mk_222 ca.fr.ceb_322  fr.nl.es_543 id.ms.rw_332
  0x092d0d0c, 0x21003f07, 0x211218ec, 0x0b0a190c,   // cs.sk.pl_543 af.jw.un_420  ar.ur.fa_644 gl.pt.es_543
  0x18000204, 0x122d0d13, 0x0c2d09ad, 0x10190b13,   // da.ga.un_320 cs.sk.hu_665  pl.sk.sv_643 es.gl.lt_665
  0x19001008, 0x091b13a0, 0x12002905, 0x2307125a,   // lt.gl.un_430 et.tr.pl_322  sl.hu.un_330 hu.it.ca_553
  // [22a0]
  0x1c090d55, 0x11000c04, 0x0a0701a9, 0x0d091c12,   // ne.hi.mr_442 sv.ro.un_320  en.it.pt_544 mr.hi.ne_654
  0x0a190b08, 0x09002a0d, 0x0e190b13, 0x18000a08,   // es.gl.pt_443 mt.pl.un_540  es.gl.is_665 pt.ga.un_430
  0x100b0a08, 0x55002104, 0x1812215a, 0x030c06a0,   // pt.es.lt_443 jw.rw.un_320  fa.ur.ar_553 de.sv.nl_322
  0x121b2512, 0x23050313, 0x2b002d08, 0x2b3b010c,   // eu.tr.hu_654 nl.fr.ca_665  sk.vi.un_430 en.so.vi_543
  // [22b0]
  0x0f041355, 0x5500530e, 0x09001705, 0x0e2d0daf,   // et.fi.lv_442 ht.rw.un_550  sr.pl.un_330 cs.sk.is_655
  0x52102814, 0x10000a09, 0x321755af, 0x060e0807,   // sw.lt.ha_666 pt.lt.un_440  rw.sr.bs_655 no.is.de_432
  0x521a210b, 0x03022d07, 0x133b0607, 0x0f00101a,   // jw.tl.ha_542 sk.da.nl_432  de.so.et_432 lt.lv.un_760
  0x0c2a3b0d, 0x02080c11, 0x170a04a4, 0x190a0b0e,   // so.mt.sv_554 sv.no.da_653  ru.mk.sr_433 es.pt.gl_555
  // [22c0]
  0x25000f2b, 0x0c033fee, 0x08026ba4, 0x200725a0,   // lv.eu.un_980 af.nl.sv_422  ceb.da.no_433 eu.it.sq_322
  0x271118ad, 0x1e3f25ec, 0x10252313, 0x0e1a6b12,   // ga.ro.gd_643 eu.af.ms_644  ca.eu.lt_665 ceb.tl.is_654
  0x2a0810a4, 0x25000f1a, 0x1c00520d, 0x07171007,   // lt.no.mt_433 lv.eu.un_760  ha.id.un_540 be.sr.bg_432
  0x52001f12, 0x2b190b09, 0x271806a4, 0x04003f07,   // cy.ha.un_640 es.gl.vi_444  de.ga.gd_433 af.fi.un_420
  // [22d0]
  0x2723010c, 0x0a071108, 0x133127ee, 0x0a000108,   // en.ca.gd_543 ro.bg.mk_443  gd.az.et_422 en.pt.un_430
  0x01006b04, 0x0807110c, 0x53211ca9, 0x6b2a01ee,   // ceb.en.un_320 ro.bg.uk_543  id.jw.ht_544 en.mt.ceb_422
  0x310e0807, 0x31202a0c, 0x06000504, 0x3b061f09,   // no.is.az_432 mt.sq.az_543  fr.de.un_320 cy.de.so_444
  0x25646b0c, 0x062552ec, 0x070804ad, 0x521b2a0c,   // ceb.lg.eu_543 ha.eu.de_644  ru.uk.bg_643 mt.tr.ha_543
  // [22e0]
  0x01531e02, 0x0e06075a, 0x12080e13, 0x05645307,   // ms.ht.en_222 it.de.is_553  is.no.hu_665 ht.lg.fr_432
  0x10001119, 0x21001105, 0x3f321604, 0x0000191c,   // ro.be.un_750 ro.jw.un_330  hr.bs.af_332 gl.un.un_800
  0x13090d5a, 0x21002522, 0x12001e0d, 0x050f0911,   // ne.hi.bh_553 eu.jw.un_870  ms.hu.un_540 pl.lv.fr_653
  0x31004a0d, 0x19000b18, 0x170a11a4, 0x210609a9,   // yo.az.un_540 es.gl.un_740  ro.mk.sr_433 pl.de.jw_544
  // [22f0]
  0x3b13120d, 0x0d001309, 0x0e190b5a, 0x21002d0c,   // hu.et.so_554 bh.ne.un_440  es.gl.is_553 sk.jw.un_530
  0x1f030107, 0x35556407, 0x07000a12, 0x3b282507,   // en.nl.cy_432 lg.rw.zu_432  mk.bg.un_640 eu.sw.so_432
  0x163b290c, 0x0a0408a4, 0x2a003504, 0x0a1707a0,   // sl.so.hr_543 uk.ru.mk_433  zu.mt.un_320 bg.sr.mk_322
  0x55091aee, 0x1f006405, 0x01002411, 0x1708040c,   // tl.pl.rw_422 lg.cy.un_330  yi.iw.un_630 ru.uk.sr_543
  // [2300]
  0x0a00041b, 0x09001c18, 0x046e0604, 0x20001a02,   // ru.mk.un_770 mr.hi.un_740  de.hmn.fi_332 tl.sq.un_220
  0x0604100c, 0x0e000613, 0x0f0410a4, 0x21002302,   // lt.fi.de_543 de.is.un_650  lt.fi.lv_433 ca.jw.un_220
  0x11231fa4, 0x110f1055, 0x3f2d250c, 0x29002d0d,   // cy.ca.ro_433 lt.lv.ro_442  eu.sk.af_543 sk.sl.un_540
  0x10080709, 0x0803010c, 0x04252105, 0x08100f05,   // bg.uk.be_444 en.nl.no_543  jw.eu.fi_333 lv.lt.no_333
  // [2310]
  0x20356404, 0x0400171a, 0x04170804, 0x0e060f13,   // lg.zu.sq_332 sr.ru.un_760  uk.sr.ru_332 lv.de.is_665
  0x12000d18, 0x12006419, 0x102d0d04, 0x080e0207,   // cs.hu.un_740 lg.hu.un_750  cs.sk.lt_332 da.is.no_432
  0x2023050c, 0x12211c02, 0x131c0da9, 0x060f10ad,   // fr.ca.sq_543 id.jw.hu_222  ne.mr.bh_544 lt.lv.de_643
  0x04001712, 0x12002108, 0x091c0d02, 0x12641aa0,   // sr.ru.un_640 jw.hu.un_430  ne.mr.hi_222 tl.lg.hu_322
  // [2320]
  0x0f25060e, 0x17040aa9, 0x2300050e, 0x3f080904,   // de.eu.lv_555 mk.ru.sr_544  fr.ca.un_550 pl.no.af_332
  0x0f0e1007, 0x03000407, 0x1b003118, 0x0c3f2302,   // lt.is.lv_432 fi.nl.un_420  az.tr.un_740 ca.af.sv_222
  0x283b55ad, 0x0e250d0c, 0x161b31a7, 0x1e00550e,   // rw.so.sw_643 cs.eu.is_543  az.tr.hr_532 rw.ms.un_550
  0x0a001708, 0x64555313, 0x6b1a53a9, 0x2300050d,   // sr.mk.un_430 ht.rw.lg_665  ht.tl.ceb_544 fr.ca.un_540
  // [2330]
  0x2d060f55, 0x101e1c55, 0x2d1b3111, 0x5568350e,   // lv.de.sk_442 id.ms.lt_442  az.tr.sk_653 zu.ig.rw_555
  0x5500522a, 0x254a3b55, 0x3f5364ad, 0x0d00130c,   // ha.rw.un_970 so.yo.eu_442  lg.ht.af_643 bh.ne.un_530
  0x0e00131a, 0x1b6b53a6, 0x1c2105a9, 0x53351c0c,   // et.is.un_760 ht.ceb.tr_521  fr.jw.id_544 id.zu.ht_543
  0x1200641b, 0x05271808, 0x284a3ba7, 0x290d2d12,   // lg.hu.un_770 ga.gd.fr_443  so.yo.sw_532 sk.cs.sl_654
  // [2340]
  0x0e072a08, 0x10040755, 0x05002109, 0x1c006b04,   // mt.it.is_443 bg.ru.be_442  jw.fr.un_440 ceb.id.un_320
  0x1e1c04ec, 0x16004a07, 0x3b6b1a09, 0x0d002d0d,   // fi.id.ms_644 yo.hr.un_420  tl.ceb.so_444 sk.cs.un_540
  0x17040808, 0x3f030408, 0x1a1c2107, 0x133f040c,   // uk.ru.sr_443 fi.nl.af_443  jw.id.tl_432 fi.af.et_543
  0x3b55520e, 0x20000f12, 0x170a04ec, 0x1b31520d,   // ha.rw.so_555 lv.sq.un_640  ru.mk.sr_644 ha.az.tr_554
  // [2350]
  0x551b530e, 0x0d002d11, 0x553b3fee, 0x28005305,   // ht.tr.rw_555 sk.cs.un_630  af.so.rw_422 ht.sw.un_330
  0x0f092aa4, 0x645352a9, 0x20005322, 0x0408110c,   // mt.pl.lv_433 ha.ht.lg_544  ht.sq.un_870 ro.uk.ru_543
  0x0100050e, 0x0600550c, 0x31001a02, 0x0c002007,   // fr.en.un_550 rw.de.un_530  tl.az.un_220 sq.sv.un_420
  0x070a1707, 0x2d0d04a4, 0x050413ad, 0x06005508,   // sr.mk.bg_432 fi.cs.sk_433  et.fi.fr_643 rw.de.un_430
  // [2360]
  0x100417a0, 0x1300280c, 0x11002d02, 0x080a0713,   // sr.ru.be_322 sw.et.un_530  sk.ro.un_220 bg.mk.uk_665
  0x11000a07, 0x112d0d05, 0x071101a4, 0x11001c0d,   // pt.ro.un_420 cs.sk.ro_333  en.ro.it_433 id.ro.un_540
  0x0c21200d, 0x685228ec, 0x532001a4, 0x192528ad,   // sq.jw.sv_554 sw.ha.ig_644  en.sq.ht_433 sw.eu.gl_643
  0x0c001f05, 0x3b1e1c13, 0x0c051fee, 0x04080713,   // cy.sv.un_330 id.ms.so_665  cy.fr.sv_422 bg.uk.ru_665
  // [2370]
  0x04101705, 0x0400102b, 0x536b2012, 0x090d13ec,   // sr.be.ru_333 be.ru.un_980  sq.ceb.ht_654 bh.ne.hi_644
  0x1f1e1c13, 0x1a006b07, 0x64051fee, 0x060802a7,   // id.ms.cy_665 ceb.tl.un_420  cy.fr.lg_422 da.no.de_532
  0x203552ad, 0x3f1c3105, 0x190b0a55, 0x010c20a7,   // ha.zu.sq_643 az.id.af_333  pt.es.gl_442 sq.sv.en_532
  0x3b0519a0, 0x1c002a02, 0x120e1b02, 0x0a2a520c,   // gl.fr.so_322 mt.id.un_220  tr.is.hu_222 ha.mt.pt_543
  // [2380]
  0x4a1152a4, 0x3f006b0c, 0x0a005204, 0x0a040705,   // ha.ro.yo_433 ceb.af.un_530  ha.pt.un_320 bg.ru.mk_333
  0x03283f04, 0x282008a0, 0x1b213508, 0x0e033f0c,   // af.sw.nl_332 no.sq.sw_322  zu.jw.tr_443 af.nl.is_543
  0x321629af, 0x312018a7, 0x3f002005, 0x0300200e,   // sl.hr.bs_655 ga.sq.az_532  sq.af.un_330 sq.nl.un_550
  0x0c000e0d, 0x3f002702, 0x2100201b, 0x1c002119,   // is.sv.un_540 gd.af.un_220  sq.jw.un_770 jw.id.un_750
  // [2390]
  0x041011a7, 0x3f0306ac, 0x1732160d, 0x2b0601a6,   // ro.lt.fi_532 de.nl.af_632  hr.bs.sr_554 en.de.vi_521
  0x251e1c13, 0x2800350c, 0x033f1bee, 0x13000902,   // id.ms.eu_665 zu.sw.un_530  tr.af.nl_422 hi.bh.un_220
  0x2a1a6b12, 0x291304ad, 0x200401a4, 0x04001c0d,   // ceb.tl.mt_654 fi.et.sl_643  en.fi.sq_433 id.fi.un_540
  0x2a6b20ee, 0x2a001805, 0x0f04130d, 0x17321611,   // sq.ceb.mt_422 ga.mt.un_330  et.fi.lv_554 hr.bs.sr_653
  // [23a0]
  0x29002d0c, 0x190b4a05, 0x030c02a0, 0x0700041b,   // sk.sl.un_530 yo.es.gl_333  da.sv.nl_322 ru.bg.un_770
  0x3b042007, 0x08002707, 0x1e1c4aa4, 0x530f2104,   // sq.fi.so_432 gd.no.un_420  yo.id.ms_433 jw.lv.ht_332
  0x1f000613, 0x3b205212, 0x17100805, 0x3f3b1f0c,   // de.cy.un_650 ha.sq.so_654  uk.be.sr_333 cy.so.af_543
  0x200852a0, 0x1b002104, 0x12001b05, 0x21005514,   // ha.no.sq_322 jw.tr.un_320  tr.hu.un_330 rw.jw.un_660
  // [23b0]
  0x1c211ea4, 0x07170807, 0x521b3109, 0x1f006414,   // ms.jw.id_433 uk.sr.bg_432  az.tr.ha_444 lg.cy.un_660
  0x1b001f19, 0x31003505, 0x13041aa4, 0x1b211e0c,   // cy.tr.un_750 zu.az.un_330  tl.fi.et_433 ms.jw.tr_543
  0x04170a02, 0x170407a0, 0x07100a04, 0x1821120b,   // mk.sr.ru_222 bg.ru.sr_322  mk.be.bg_332 ur.fa.ar_542
  0x02000c0d, 0x20311bec, 0x16003b07, 0x08040aa4,   // sv.da.un_540 tr.az.sq_644  so.hr.un_420 mk.ru.uk_433
  // [23c0]
  0x53004a04, 0x27050da0, 0x190a1214, 0x1707040c,   // yo.ht.un_320 cs.fr.gd_322  hu.pt.gl_666 ru.bg.sr_543
  0x08021ba0, 0x1700291a, 0x204a27ec, 0x4a250504,   // tr.da.no_322 sl.sr.un_760  gd.yo.sq_644 fr.eu.yo_332
  0x1a6b55ee, 0x0b051904, 0x20001109, 0x1708045a,   // rw.ceb.tl_422 gl.fr.es_332  ro.sq.un_440 ru.uk.sr_553
  0x52313b0c, 0x6e00180e, 0x13000408, 0x523b2113,   // so.az.ha_543 ga.hmn.un_550  fi.et.un_430 jw.so.ha_665
  // [23d0]
  0x0a101705, 0x3500550c, 0x1c200f04, 0x31521aa9,   // sr.be.mk_333 rw.zu.un_530  lv.sq.id_332 tl.ha.az_544
  0x2d001c02, 0x216b0a07, 0x230f1304, 0x3b1a52a9,   // id.sk.un_220 pt.ceb.jw_432  et.lv.ca_332 ha.tl.so_544
  0x1f080202, 0x5321520c, 0x52003b1a, 0x4a643505,   // da.no.cy_222 ha.jw.ht_543  so.ha.un_760 zu.lg.yo_333
  0x31523b0c, 0x17164a0c, 0x28000408, 0x282b04ec,   // so.ha.az_543 yo.hr.sr_543  fi.sw.un_430 fi.vi.sw_644
  // [23e0]
  0x313b52ec, 0x5221310c, 0x090c0802, 0x170811a4,   // ha.so.az_644 az.jw.ha_543  no.sv.pl_222 ro.uk.sr_433
  0x2b04280c, 0x4a3b5208, 0x2b000421, 0x111f070c,   // sw.fi.vi_543 ha.so.yo_443  fi.vi.un_860 it.cy.ro_543
  0x3b00521a, 0x040a1107, 0x2b001a08, 0x0e1308a4,   // ha.so.un_760 ro.mk.ru_432  tl.vi.un_430 no.et.is_433
  0x07001a23, 0x530e1ca4, 0x355231a4, 0x10002b1a,   // tl.it.un_880 id.is.ht_433  az.ha.zu_433 vi.lt.un_760
  // [23f0]
  0x35005204, 0x206b070c, 0x2500061a, 0x110410a4,   // ha.zu.un_320 it.ceb.sq_543  de.eu.un_760 be.ru.ro_433
  0x31003b19, 0x091f52a4, 0x09075508, 0x0f001a02,   // so.az.un_750 ha.cy.pl_433  rw.it.pl_443 tl.lv.un_220
  0x531b3109, 0x040a1712, 0x190a07a4, 0x3b005519,   // az.tr.ht_444 sr.mk.ru_654  it.pt.gl_433 rw.so.un_750
  0x08001a0b, 0x20113502, 0x3b1a31ec, 0x0e000808,   // tl.no.un_520 zu.ro.sq_222  az.tl.so_644 no.is.un_430

  // [2400]
  0x08530408, 0x01681f04, 0x290f1104, 0x13000d2a,   // fi.ht.no_443 cy.ig.en_332  ro.lv.sl_332 ne.bh.un_970
  0x68280755, 0x08021fee, 0x0f0604ee, 0x042b0712,   // it.sw.ig_442 cy.da.no_422  fi.de.lv_422 it.vi.fi_654
  0x0f521355, 0x2b000419, 0x0600180c, 0x28042b13,   // et.ha.lv_442 fi.vi.un_750  ga.de.un_530 vi.fi.sw_665
  0x101f180c, 0x133b06a7, 0x06003f0e, 0x13091c0d,   // ga.cy.lt_543 de.so.et_532  af.de.un_550 mr.hi.bh_554
  // [2410]
  0x18130e04, 0x06180e04, 0x311e1c5a, 0x556b1a11,   // is.et.ga_332 is.ga.de_332  id.ms.az_553 tl.ceb.rw_653
  0x01005202, 0x2917070c, 0x21101fee, 0x1c000302,   // ha.en.un_220 it.sr.sl_543  cy.lt.jw_422 nl.id.un_220
  0x642809ad, 0x12000502, 0x0a0728ad, 0x23200a14,   // pl.sw.lg_643 fr.hu.un_220  sw.it.pt_643 pt.sq.ca_666
  0x2a0f52ec, 0x00000a37, 0x0a190b12, 0x1a0755a4,   // ha.lv.mt_644 pt.un.un_B00  es.gl.pt_654 rw.it.tl_433
  // [2420]
  0x28005205, 0x1e1c100c, 0x521206ad, 0x01000808,   // ha.sw.un_330 lt.id.ms_543  de.hu.ha_643 no.en.un_430
  0x0f0a4aa0, 0x18001f1a, 0x1e3b04ee, 0x13001013,   // yo.pt.lv_322 cy.ga.un_760  fi.so.ms_422 lt.et.un_650
  0x25213507, 0x041c1ead, 0x1c3216a0, 0x10170813,   // zu.jw.eu_432 ms.id.fi_643  hr.bs.id_322 uk.sr.be_665
  0x07041f5a, 0x0a003104, 0x29170aaf, 0x080204a4,   // cy.fi.it_553 az.pt.un_320  pt.sr.sl_655 fi.da.no_433
  // [2430]
  0x1e006b07, 0x17002919, 0x11001013, 0x17002921,   // ceb.ms.un_420 sl.sr.un_750  be.ro.un_650 sl.sr.un_860
  0x52311ea4, 0x1e001904, 0x17001107, 0x082b010c,   // ms.az.ha_433 gl.ms.un_320  ro.sr.un_420 en.vi.no_543
  0x19070aa0, 0x0c0e01a4, 0x190b200c, 0x0e080107,   // pt.it.gl_322 en.is.sv_433  sq.es.gl_543 en.no.is_432
  0x10000a13, 0x686b1a0d, 0x27002d0c, 0x01033fee,   // mk.be.un_650 tl.ceb.ig_554  sk.gd.un_530 af.nl.en_422
  // [2440]
  0x17070a5a, 0x01002307, 0x066e0405, 0x251e1ca7,   // mk.bg.sr_553 ca.en.un_420  fi.hmn.de_333 id.ms.eu_532
  0x0e002108, 0x0e000509, 0x0a135207, 0x6b001a0e,   // jw.is.un_430 fr.is.un_440  ha.et.pt_432 tl.ceb.un_550
  0x130823a9, 0x292d0d0d, 0x1b1220ac, 0x07190f04,   // ca.no.et_544 cs.sk.sl_554  sq.hu.tr_632 lv.gl.it_332
  0x12003b0e, 0x0d001c21, 0x0300041a, 0x040711af,   // so.hu.un_550 mr.ne.un_860  fi.nl.un_760 ro.bg.ru_655
  // [2450]
  0x29172daf, 0x52042008, 0x0c000807, 0x0a0708ee,   // sk.sr.sl_655 sq.fi.ha_443  no.sv.un_420 uk.bg.mk_422
  0x01003b02, 0x04002022, 0x13000e12, 0x040a0714,   // so.en.un_220 sq.fi.un_870  is.et.un_640 bg.mk.ru_666
  0x0800040d, 0x04000e09, 0x1c130913, 0x080e040c,   // ru.uk.un_540 is.fi.un_440  hi.bh.mr_665 fi.is.no_543
  0x10040807, 0x1b043ba9, 0x1f001008, 0x311b11a4,   // uk.ru.be_432 so.fi.tr_544  lt.cy.un_430 ro.tr.az_433
  // [2460]
  0x180427af, 0x3216170c, 0x28001802, 0x253216ee,   // gd.fi.ga_655 sr.hr.bs_543  ga.sw.un_220 hr.bs.eu_422
  0x520412a9, 0x18271fee, 0x08061f0c, 0x0a1704a7,   // hu.fi.ha_544 cy.gd.ga_422  cy.de.no_543 ru.sr.mk_532
  0x0300252a, 0x1f183b0c, 0x2100090c, 0x04080705,   // eu.nl.un_970 so.ga.cy_543  pl.jw.un_530 bg.uk.ru_333
  0x35005502, 0x07041007, 0x29003502, 0x2800680e,   // rw.zu.un_220 be.ru.bg_432  zu.sl.un_220 ig.sw.un_550
  // [2470]
  0x04080e05, 0x35096412, 0x13100412, 0x3f0e0305,   // is.no.fi_333 lg.pl.zu_654  fi.lt.et_654 nl.is.af_333
  0x03040ca4, 0x21002305, 0x040c0807, 0x21203fa0,   // sv.fi.nl_433 ca.jw.un_330  no.sv.fi_432 af.sq.jw_322
  0x3500680d, 0x3f000c07, 0x0a17070d, 0x3f1a6b08,   // ig.zu.un_540 sv.af.un_420  bg.sr.mk_554 ceb.tl.af_443
  0x0d2d190d, 0x0d290912, 0x0c000811, 0x3f040ea0,   // gl.sk.cs_554 pl.sl.cs_654  no.sv.un_630 is.fi.af_322
  // [2480]
  0x091c13af, 0x3f031302, 0x353b310d, 0x3255350b,   // bh.mr.hi_655 et.nl.af_222  az.so.zu_554 zu.rw.bs_542
  0x13030407, 0x191e23a4, 0x3b136e05, 0x06201ea4,   // fi.nl.et_432 ca.ms.gl_433  hmn.et.so_333 ms.sq.de_433
  0x080211ec, 0x1a033bee, 0x0e2a0413, 0x281e3bac,   // ro.da.no_644 so.nl.tl_422  fi.mt.is_665 so.ms.sw_632
  0x0804170b, 0x08170413, 0x2d000614, 0x080e6ba0,   // sr.ru.uk_542 ru.sr.uk_665  de.sk.un_660 ceb.is.no_322
  // [2490]
  0x0e04130c, 0x036b68ec, 0x04060cee, 0x4a6413ec,   // et.fi.is_543 ig.ceb.nl_644  sv.de.fi_422 et.lg.yo_644
  0x64552114, 0x35001912, 0x522a4a55, 0x053f230d,   // jw.rw.lg_666 gl.zu.un_640  yo.mt.ha_442 ca.af.fr_554
  0x642713a9, 0x6800031a, 0x641c2104, 0x170a07a4,   // et.gd.lg_544 nl.ig.un_760  jw.id.lg_332 bg.mk.sr_433
  0x04000814, 0x08026b02, 0x0c101f07, 0x2b121ca0,   // uk.ru.un_660 ceb.da.no_222  cy.lt.sv_432 id.hu.vi_322
  // [24a0]
  0x0e100855, 0x0d002d0b, 0x55001a07, 0x0e080caf,   // no.lt.is_442 sk.cs.un_520  tl.rw.un_420 sv.no.is_655
  0x6b001f0d, 0x316407a9, 0x3b002907, 0x16190a55,   // cy.ceb.un_540 it.lg.az_544  sl.so.un_420 pt.gl.hr_442
  0x1e003119, 0x06033f07, 0x0664035a, 0x033f0414,   // az.ms.un_750 af.nl.de_432  nl.lg.de_553 fi.af.nl_666
  0x023531a0, 0x28003b20, 0x64005208, 0x1e1b2aee,   // az.zu.da_322 so.sw.un_850  ha.lg.un_430 mt.tr.ms_422
  // [24b0]
  0x190a1105, 0x0704180c, 0x2d000613, 0x6b000704,   // ro.pt.gl_333 ga.fi.it_543  de.sk.un_650 it.ceb.un_320
  0x0206085a, 0x2d321605, 0x23000a12, 0x3f0e080b,   // no.de.da_553 hr.bs.sk_333  pt.ca.un_640 no.is.af_542
  0x080210a4, 0x063f01a4, 0x23000a1a, 0x27646ba7,   // lt.da.no_433 en.af.de_433  pt.ca.un_760 ceb.lg.gd_532
  0x286b52ee, 0x16352d55, 0x0a1710af, 0x11002719,   // ha.ceb.sw_422 sk.zu.hr_442  be.sr.mk_655 gd.ro.un_750
  // [24c0]
  0x08071004, 0x04102511, 0x1f0910a0, 0x1b003509,   // be.bg.uk_332 eu.lt.fi_653  lt.pl.cy_322 zu.tr.un_440
  0x25100407, 0x1000090c, 0x18001905, 0x0b001908,   // fi.lt.eu_432 pl.lt.un_530  gl.ga.un_330 gl.es.un_430
  0x536b0102, 0x29000713, 0x09100412, 0x1e1c6ba0,   // en.ceb.ht_222 it.sl.un_650  fi.lt.pl_654 ceb.id.ms_322
  0x13271104, 0x6b181108, 0x0f10125a, 0x13000918,   // ro.gd.et_332 ro.ga.ceb_443  hu.lt.lv_553 hi.bh.un_740
  // [24d0]
  0x02006b0d, 0x13000b07, 0x3f0f10a7, 0x11000419,   // ceb.da.un_540 es.et.un_420  lt.lv.af_532 ru.ro.un_750
  0x13003f08, 0x35060eaf, 0x12006e12, 0x1b230aee,   // af.et.un_430 is.de.zu_655  hmn.hu.un_640 pt.ca.tr_422
  0x1107080c, 0x21054a04, 0x01001a02, 0x53002704,   // uk.bg.ro_543 yo.fr.jw_332  tl.en.un_220 gd.ht.un_320
  0x08170407, 0x0c002302, 0x19001f1b, 0x35001904,   // ru.sr.uk_432 ca.sv.un_220  cy.gl.un_770 gl.zu.un_320
  // [24e0]
  0x18004a07, 0x0f001204, 0x07000504, 0x321710a4,   // yo.ga.un_420 hu.lv.un_320  fr.it.un_320 lt.sr.bs_433
  0x1700071a, 0x10000f14, 0x102729ad, 0x3f00030c,   // bg.sr.un_760 lv.lt.un_660  sl.gd.lt_643 nl.af.un_530
  0x1c001f04, 0x04070808, 0x090627a7, 0x13000907,   // cy.id.un_320 uk.bg.ru_443  gd.de.pl_532 hi.bh.un_420
  0x07170a04, 0x181127a4, 0x11270108, 0x6b190b0d,   // mk.sr.bg_332 gd.ro.ga_433  en.gd.ro_443 es.gl.ceb_554
  // [24f0]
  0x2300190c, 0x231811a7, 0x016b18ee, 0x1c130d0e,   // gl.ca.un_530 ro.ga.ca_532  ga.ceb.en_422 ne.bh.mr_555
  0x18001b08, 0x0500111a, 0x11001808, 0x07170a07,   // tr.ga.un_430 ro.fr.un_760  ga.ro.un_430 mk.sr.bg_432
  0x3f001102, 0x01000504, 0x64001104, 0x21000d04,   // ro.af.un_220 fr.en.un_320  ro.lg.un_320 cs.jw.un_320
  0x056b5204, 0x072710ad, 0x05042005, 0x321029ad,   // ha.ceb.fr_332 lt.gd.it_643  sq.fi.fr_333 sl.lt.bs_643
  // [2500]
  0x551e1c02, 0x20001213, 0x21005304, 0x10080407,   // id.ms.rw_222 hu.sq.un_650  ht.jw.un_320 ru.uk.be_432
  0x0c061313, 0x13251107, 0x112701a0, 0x11000119,   // et.de.sv_665 ro.eu.et_432  en.gd.ro_322 en.ro.un_750
  0x1813040c, 0x2a000f10, 0x0f254aec, 0x20000f09,   // fi.et.ga_543 lv.mt.un_620  yo.eu.lv_644 lv.sq.un_440
  0x3b006404, 0x091c13ad, 0x11001b13, 0x0f001008,   // lg.so.un_320 bh.mr.hi_643  tr.ro.un_650 lt.lv.un_430
  // [2510]
  0x2829130b, 0x0f1009a7, 0x190e0107, 0x553528af,   // et.sl.sw_542 pl.lt.lv_532  en.is.gl_432 sw.zu.rw_655
  0x08001807, 0x13001914, 0x2a002908, 0x2900551b,   // ga.no.un_420 gl.et.un_660  sl.mt.un_430 rw.sl.un_770
  0x1b0a31a0, 0x1812210c, 0x050a23ec, 0x294a6412,   // az.pt.tr_322 fa.ur.ar_543  ca.pt.fr_644 lg.yo.sl_654
  0x1707110c, 0x160f2904, 0x0810170c, 0x01213ba0,   // ro.bg.sr_543 sl.lv.hr_332  sr.be.uk_543 so.jw.en_322
  // [2520]
  0x4a0f1012, 0x4a6b6813, 0x08021fa0, 0x06051f02,   // lt.lv.yo_654 ig.ceb.yo_665  cy.da.no_322 cy.fr.de_222
  0x29090fa4, 0x080225a0, 0x0e002922, 0x06180307,   // lv.pl.sl_433 eu.da.no_322  sl.is.un_870 nl.ga.de_432
  0x0a2a1fa0, 0x10001114, 0x5529130c, 0x07104a0c,   // cy.mt.pt_322 ro.be.un_660  et.sl.rw_543 yo.lt.it_543
  0x6e04680c, 0x13552908, 0x3f033ba9, 0x6b180155,   // ig.fi.hmn_543 sl.rw.et_443  so.nl.af_544 en.ga.ceb_442
  // [2530]
  0x130608ee, 0x3b000423, 0x04032aee, 0x09001604,   // no.de.et_422 fi.so.un_880  mt.nl.fi_422 hr.pl.un_320
  0x0c12060c, 0x1f000813, 0x04074a0c, 0x036404ad,   // de.hu.sv_543 no.cy.un_650  yo.it.fi_543 fi.lg.nl_643
  0x2a645204, 0x1b033b07, 0x02085307, 0x3f002d08,   // ha.lg.mt_332 so.nl.tr_432  ht.no.da_432 sk.af.un_430
  0x05640709, 0x0a1b05ee, 0x23050708, 0x3f1a6b0c,   // it.lg.fr_444 fr.tr.pt_422  it.fr.ca_443 ceb.tl.af_543
  // [2540]
  0x52004a09, 0x0506520c, 0x311b0aa0, 0x10000711,   // yo.ha.un_440 ha.de.fr_543  pt.tr.az_322 bg.be.un_630
  0x530d2da0, 0x0c080e04, 0x08190b04, 0x030c3f04,   // sk.cs.ht_322 is.no.sv_332  es.gl.no_332 af.sv.nl_332
  0x030c08a4, 0x0a1707a4, 0x1f2708a4, 0x1b3b3104,   // no.sv.nl_433 bg.sr.mk_433  no.gd.cy_433 az.so.tr_332
  0x130752ad, 0x13080205, 0x0e08020e, 0x2a0e05a4,   // ha.it.et_643 da.no.et_333  da.no.is_555 fr.is.mt_433
  // [2550]
  0x3f130407, 0x3f2a080c, 0x033f25ad, 0x032a060c,   // fi.et.af_432 no.mt.af_543  eu.af.nl_643 de.mt.nl_543
  0x3b3f040c, 0x07002a09, 0x3f080c04, 0x13000308,   // fi.af.so_543 mt.it.un_440  sv.no.af_332 nl.et.un_430
  0x23000a1b, 0x032d2a04, 0x17041105, 0x23000a07,   // pt.ca.un_770 mt.sk.nl_332  ro.ru.sr_333 pt.ca.un_420
  0x23190b08, 0x161709a7, 0x08101713, 0x1b0131ee,   // es.gl.ca_443 pl.sr.hr_532  sr.be.uk_665 az.en.tr_422
  // [2560]
  0x2a063f0c, 0x0c010ea7, 0x17001104, 0x0c043fa0,   // af.de.mt_543 is.en.sv_532  ro.sr.un_320 af.fi.sv_322
  0x0e003112, 0x1708100c, 0x0c003f05, 0x23190b13,   // az.is.un_640 be.uk.sr_543  af.sv.un_330 es.gl.ca_665
  0x04003f0c, 0x0a0407a0, 0x030c3f02, 0x060d05a0,   // af.fi.un_530 bg.ru.mk_322  af.sv.nl_222 fr.cs.de_322
  0x5200230d, 0x100a04a0, 0x20102912, 0x0c000104,   // ca.ha.un_540 ru.mk.be_322  sl.lt.sq_654 en.sv.un_320
  // [2570]
  0x07001011, 0x1b0a2302, 0x05002314, 0x290d1602,   // lt.it.un_630 ca.pt.tr_222  ca.fr.un_660 hr.cs.sl_222
  0x2d291007, 0x2d1029ad, 0x0410170e, 0x0c052704,   // lt.sl.sk_432 sl.lt.sk_643  sr.be.ru_555 gd.fr.sv_332
  0x20190bee, 0x27000802, 0x13171608, 0x290413a4,   // es.gl.sq_422 no.gd.un_220  hr.sr.et_443 et.fi.sl_433
  0x09001613, 0x29130911, 0x06010504, 0x16001308,   // hr.pl.un_650 pl.et.sl_653  fr.en.de_332 et.hr.un_430
  // [2580]
  0x08556ba7, 0x090d1c07, 0x0e003b1b, 0x4a25520c,   // ceb.rw.no_532 mr.ne.hi_432  so.is.un_770 ha.eu.yo_543
  0x1f100fa0, 0x04002522, 0x0e003b19, 0x53102904,   // lv.lt.cy_322 eu.fi.un_870  so.is.un_750 sl.lt.ht_332
  0x4a6b10a4, 0x3252080c, 0x350f09a4, 0x10000818,   // lt.ceb.yo_433 no.ha.bs_543  pl.lv.zu_433 uk.be.un_740
  0x100f1eee, 0x1b003b1a, 0x64003202, 0x25640e04,   // ms.lv.lt_422 so.tr.un_760  bs.lg.un_220 is.lg.eu_332
  // [2590]
  0x1e1c040e, 0x12000504, 0x21003b07, 0x10066e04,   // fi.id.ms_555 fr.hu.un_320  so.jw.un_420 hmn.de.lt_332
  0x3f022aec, 0x64281f0c, 0x0f291ca4, 0x08006e07,   // mt.da.af_644 cy.sw.lg_543  id.sl.lv_433 hmn.no.un_420
  0x18162aee, 0x1b00121b, 0x05001805, 0x3b000419,   // mt.hr.ga_422 hu.tr.un_770  ga.fr.un_330 fi.so.un_750
  0x64000907, 0x0e1b3bad, 0x1a006b19, 0x1b214a05,   // pl.lg.un_420 so.tr.is_643  ceb.tl.un_750 yo.jw.tr_333
  // [25a0]
  0x201b2da0, 0x211218a9, 0x1f00550c, 0x2a001f1a,   // sk.tr.sq_322 ar.ur.fa_544  rw.cy.un_530 cy.mt.un_760
  0x04000a1b, 0x0a00230c, 0x28000119, 0x08000713,   // mk.ru.un_770 ca.pt.un_530  en.sw.un_750 bg.uk.un_650
  0x06002504, 0x08001113, 0x1f002807, 0x0800171b,   // eu.de.un_320 ro.uk.un_650  sw.cy.un_420 sr.uk.un_770
  0x04130e0c, 0x3200290e, 0x25002302, 0x0d13090b,   // is.et.fi_543 sl.bs.un_550  ca.eu.un_220 hi.bh.ne_542
  // [25b0]
  0x0a002302, 0x13015304, 0x0a1827a7, 0x0a550107,   // ca.pt.un_220 ht.en.et_332  gd.ga.pt_532 en.rw.pt_432
  0x290b10a0, 0x172d2912, 0x211a1bee, 0x0a106b04,   // lt.es.sl_322 sl.sk.sr_654  tr.tl.jw_422 ceb.lt.pt_332
  0x08131b04, 0x64001a08, 0x6b041b0d, 0x1200060e,   // tr.et.no_332 tl.lg.un_430  tr.fi.ceb_554 de.hu.un_550
  0x100a19a4, 0x35555205, 0x0c080e08, 0x3b001f02,   // gl.pt.lt_433 ha.rw.zu_333  is.no.sv_443 cy.so.un_220
  // [25c0]
  0x06002a13, 0x4a001218, 0x0e310408, 0x2a00310d,   // mt.de.un_650 hu.yo.un_740  fi.az.is_443 az.mt.un_540
  0x040e13a4, 0x08020e09, 0x20005513, 0x311b0505,   // et.is.fi_433 is.da.no_444  rw.sq.un_650 fr.tr.az_333
  0x31001e04, 0x040806a0, 0x6435120c, 0x52006b09,   // ms.az.un_320 de.no.fi_322  hu.zu.lg_543 ceb.ha.un_440
  0x08020ea0, 0x120d20a0, 0x130d1ba4, 0x04071308,   // is.da.no_322 sq.cs.hu_322  tr.cs.et_433 et.it.fi_443
  // [25d0]
  0x21134aa0, 0x1700290c, 0x292d12a6, 0x0b0103ad,   // yo.et.jw_322 sl.sr.un_530  hu.sk.sl_521 nl.en.es_643
  0x0c0e0107, 0x2d0d32a4, 0x041007a0, 0x0708045a,   // en.is.sv_432 bs.cs.sk_433  bg.be.ru_322 ru.uk.bg_553
  0x0d000a07, 0x0c1208a0, 0x0a002313, 0x063f1bee,   // pt.cs.un_420 no.hu.sv_322  ca.pt.un_650 tr.af.de_422
  0x081e3155, 0x13000712, 0x0e311bac, 0x203117a0,   // az.ms.no_442 it.et.un_640  tr.az.is_632 sr.az.sq_322
  // [25e0]
  0x20230a04, 0x06001f04, 0x21002904, 0x0c076ba0,   // pt.ca.sq_332 cy.de.un_320  sl.jw.un_320 ceb.it.sv_322
  0x3f1a6ba0, 0x020c0808, 0x03002a04, 0x0a0704a0,   // ceb.tl.af_322 no.sv.da_443  mt.nl.un_320 ru.bg.mk_322
  0x0b052108, 0x215329ee, 0x0e000619, 0x1b2d0d05,   // jw.fr.es_443 sl.ht.jw_422  de.is.un_750 cs.sk.tr_333
  0x231107af, 0x16002909, 0x080211a6, 0x2d12205a,   // it.ro.ca_655 sl.hr.un_440  ro.da.no_521 sq.hu.sk_553
  // [25f0]
  0x252d6807, 0x08210511, 0x08321604, 0x0a071012,   // ig.sk.eu_432 fr.jw.no_653  hr.bs.no_332 be.bg.mk_654
  0x2118055a, 0x35002a04, 0x0c006408, 0x04001e08,   // fr.ga.jw_553 mt.zu.un_320  lg.sv.un_430 ms.fi.un_430
  0x2d122912, 0x5300051b, 0x281e1c08, 0x321753a0,   // sl.hu.sk_654 fr.ht.un_770  id.ms.sw_443 ht.sr.bs_322
  0x321620ad, 0x2d0d03a7, 0x212852ee, 0x120208a4,   // sq.hr.bs_643 nl.cs.sk_532  ha.sw.jw_422 no.da.hu_433
  // [2600]
  0x522128a7, 0x1f000305, 0x64285211, 0x0928520c,   // sw.jw.ha_532 nl.cy.un_330  ha.sw.lg_653 ha.sw.pl_543
  0x52002114, 0x130f21a4, 0x17002a07, 0x080a17ec,   // jw.ha.un_660 jw.lv.et_433  mt.sr.un_420 sr.mk.uk_644
  0x21001c0c, 0x3b001c05, 0x2800520c, 0x1f000121,   // id.jw.un_530 id.so.un_330  ha.sw.un_530 en.cy.un_860
  0x051109ad, 0x21001307, 0x1c2113ad, 0x0a110407,   // pl.ro.fr_643 et.jw.un_420  et.jw.id_643 ru.ro.mk_432
  // [2610]
  0x070a1005, 0x17000814, 0x1e1c52ec, 0x093f0107,   // be.mk.bg_333 uk.sr.un_660  ha.id.ms_644 en.af.pl_432
  0x112d0d55, 0x3f090f08, 0x11093fa0, 0x16000d07,   // cs.sk.ro_442 lv.pl.af_443  af.pl.ro_322 cs.hr.un_420
  0x55005305, 0x09002912, 0x0419210c, 0x3b211ca0,   // ht.rw.un_330 sl.pl.un_640  jw.gl.fi_543 id.jw.so_322
  0x6428090d, 0x0400111b, 0x09000d0b, 0x07000a0e,   // pl.sw.lg_554 ro.ru.un_770  ne.hi.un_520 mk.bg.un_550
  // [2620]
  0x070905a4, 0x53001a02, 0x55006414, 0x031f3f55,   // fr.pl.it_433 tl.ht.un_220  lg.rw.un_660 af.cy.nl_442
  0x4a006821, 0x351a4a0c, 0x1c211bad, 0x12000919,   // ig.yo.un_860 yo.tl.zu_543  tr.jw.id_643 pl.hu.un_750
  0x19002b07, 0x19680b0c, 0x09000108, 0x0a1c21a7,   // vi.gl.un_420 es.ig.gl_543  en.pl.un_430 jw.id.pt_532
  0x0d1c13a4, 0x12050907, 0x20003b09, 0x21001204,   // bh.mr.ne_433 pl.fr.hu_432  so.sq.un_440 ur.fa.un_320
  // [2630]
  0x28006b0d, 0x0e031bec, 0x0b003505, 0x64000607,   // ceb.sw.un_540 tr.nl.is_644  zu.es.un_330 de.lg.un_420
  0x550e350c, 0x082331ad, 0x07041707, 0x1a070e0d,   // zu.is.rw_543 az.ca.no_643  sr.ru.bg_432 is.it.tl_554
  0x04136408, 0x1812090b, 0x04004a19, 0x13060c04,   // lg.et.fi_443 pl.hu.ga_542  yo.fi.un_750 sv.de.et_332
  0x686b01ee, 0x10040804, 0x1700090c, 0x080253a0,   // en.ceb.ig_422 uk.ru.be_332  pl.sr.un_530 ht.da.no_322
  // [2640]
  0x061a2808, 0x0a1011a7, 0x21061c07, 0x130435a0,   // sw.tl.de_443 ro.be.mk_532  id.de.jw_432 zu.fi.et_322
  0x040a11ad, 0x641c21a0, 0x285206af, 0x00000901,   // ro.mk.ru_643 jw.id.lg_322  de.ha.sw_655 pl.un.un_200
  0x1700090b, 0x6b00210d, 0x2700090c, 0x170408ad,   // pl.sr.un_520 jw.ceb.un_540  pl.gd.un_530 uk.ru.sr_643
  0x64280da0, 0x04002812, 0x13006b08, 0x13640408,   // cs.sw.lg_322 sw.fi.un_640  ceb.et.un_430 fi.lg.et_443
  // [2650]
  0x17321607, 0x041355a4, 0x16000908, 0x101352ad,   // hr.bs.sr_432 rw.et.fi_433  pl.hr.un_430 ha.et.lt_643
  0x5564200c, 0x296435ee, 0x20551c07, 0x040a17a0,   // sq.lg.rw_543 zu.lg.sl_422  id.rw.sq_432 sr.mk.ru_322
  0x64005520, 0x03002804, 0x040313ee, 0x6b001a14,   // rw.lg.un_850 sw.nl.un_320  et.nl.fi_422 tl.ceb.un_660
  0x52283513, 0x07000823, 0x20322aee, 0x2a003533,   // zu.sw.ha_665 uk.bg.un_880  mt.bs.sq_422 zu.mt.un_A70
  // [2660]
  0x1e555208, 0x25352807, 0x04293507, 0x5204100c,   // ha.rw.ms_443 sw.zu.eu_432  zu.sl.fi_432 lt.fi.ha_543
  0x1e001c21, 0x201235a0, 0x12003f05, 0x64523b08,   // id.ms.un_860 zu.hu.sq_322  af.hu.un_330 so.ha.lg_443
  0x552164a0, 0x320d2aa4, 0x0a08070c, 0x28526405,   // lg.jw.rw_322 mt.cs.bs_433  bg.uk.mk_543 lg.ha.sw_333
  0x0b0a1902, 0x0e001819, 0x25001913, 0x3b00280c,   // gl.pt.es_222 ga.is.un_750  gl.eu.un_650 sw.so.un_530
  // [2670]
  0x3b041aa0, 0x55200c05, 0x09320f04, 0x35006409,   // tl.fi.so_322 sv.sq.rw_333  lv.bs.pl_332 lg.zu.un_440
  0x13001c0c, 0x21005208, 0x05005309, 0x17202a04,   // mr.bh.un_530 ha.jw.un_430  ht.fr.un_440 mt.sq.sr_332
  0x3b006813, 0x350664a0, 0x190b2308, 0x13001c22,   // ig.so.un_650 lg.de.zu_322  ca.es.gl_443 mr.bh.un_870
  0x113218ee, 0x64532007, 0x551228a4, 0x101708ec,   // ga.bs.ro_422 sq.ht.lg_432  sw.hu.rw_433 uk.sr.be_644
  // [2680]
  0x0800100b, 0x0b002507, 0x550728ee, 0x1653280b,   // be.uk.un_520 eu.es.un_420  sw.it.rw_422 sw.ht.hr_542
  0x530c1208, 0x28531309, 0x32001212, 0x0b0a05a9,   // hu.sv.ht_443 et.ht.sw_444  hu.bs.un_640 fr.pt.es_544
  0x041e1c5a, 0x12002509, 0x01270511, 0x03133f0c,   // id.ms.fi_553 eu.hu.un_440  fr.gd.en_653 af.et.nl_543
  0x29172a07, 0x206455ad, 0x07001702, 0x12000914,   // mt.sr.sl_432 rw.lg.sq_643  sr.bg.un_220 pl.hu.un_660
  // [2690]
  0x286429ee, 0x1e1c09ec, 0x2a002909, 0x121009a4,   // sl.lg.sw_422 pl.id.ms_644  sl.mt.un_440 pl.lt.hu_433
  0x23002d08, 0x20285511, 0x64003b09, 0x4a133b5a,   // sk.ca.un_430 rw.sw.sq_653  so.lg.un_440 so.et.yo_553
  0x6800090d, 0x4a0313a4, 0x64133b11, 0x4a000509,   // pl.ig.un_540 et.nl.yo_433  so.et.lg_653 fr.yo.un_440
  0x1c13095a, 0x160f0da7, 0x07080205, 0x2d0d1ba0,   // hi.bh.mr_553 cs.lv.hr_532  da.no.it_333 tr.cs.sk_322
  // [26a0]
  0x12211814, 0x35005308, 0x230128ee, 0x4a000108,   // ar.fa.ur_666 ht.zu.un_430  sw.en.ca_422 en.yo.un_430
  0x0802010c, 0x250301a6, 0x27006e07, 0x1708040e,   // en.da.no_543 en.nl.eu_521  hmn.gd.un_420 ru.uk.sr_555
  0x1f006e2a, 0x03133f12, 0x0e001802, 0x3b130107,   // hmn.cy.un_970 af.et.nl_654  ga.is.un_220 en.et.so_432
  0x311b2a17, 0x12180e0c, 0x23000704, 0x13000c19,   // mt.tr.az_753 is.ga.hu_543  it.ca.un_320 sv.et.un_750
  // [26b0]
  0x55285202, 0x0a170855, 0x070a1112, 0x3b3508a4,   // ha.sw.rw_222 uk.sr.mk_442  ro.mk.bg_654 no.zu.so_433
  0x18000611, 0x21001f07, 0x28000602, 0x4a526807,   // de.ga.un_630 cy.jw.un_420  de.sw.un_220 ig.ha.yo_432
  0x071708af, 0x3f044a09, 0x4a060304, 0x53311b0c,   // uk.sr.bg_655 yo.fi.af_444  nl.de.yo_332 tr.az.ht_543
  0x070408a7, 0x2535640c, 0x0a071112, 0x3b130e0c,   // uk.ru.bg_532 lg.zu.eu_543  ro.bg.mk_654 is.et.so_543
  // [26c0]
  0x0e351c07, 0x2b0c0507, 0x1f061a07, 0x680d06a7,   // id.zu.is_432 fr.sv.vi_432  tl.de.cy_432 de.cs.ig_532
  0x03000c04, 0x0000552d, 0x1f2a550c, 0x3b526404,   // sv.nl.un_320 rw.un.un_A00  rw.mt.cy_543 lg.ha.so_332
  0x643f35ad, 0x0e086b07, 0x12001908, 0x3b000913,   // zu.af.lg_643 ceb.no.is_432  gl.hu.un_430 pl.so.un_650
  0x553568ec, 0x09522a11, 0x6418275a, 0x535535af,   // ig.zu.rw_644 mt.ha.pl_653  gd.ga.lg_553 zu.rw.ht_655
  // [26d0]
  0x07170a09, 0x3f080308, 0x3f000207, 0x68556408,   // mk.sr.bg_444 nl.no.af_443  da.af.un_420 lg.rw.ig_443
  0x0d063b0c, 0x0900280e, 0x283b64a9, 0x09000309,   // so.de.cs_543 sw.pl.un_550  lg.so.sw_544 nl.pl.un_440
  0x5500642a, 0x55216412, 0x16640955, 0x09003b07,   // lg.rw.un_970 lg.jw.rw_654  pl.lg.hr_442 so.pl.un_420
  0x16530ca0, 0x171632ec, 0x23000b07, 0x55000108,   // sv.ht.hr_322 bs.hr.sr_644  es.ca.un_420 en.rw.un_430
  // [26e0]
  0x190b2305, 0x13061ea0, 0x0d001f1a, 0x55006407,   // ca.es.gl_333 ms.de.et_322  cy.cs.un_760 lg.rw.un_420
  0x03520107, 0x3b231907, 0x5500352b, 0x063f21ee,   // en.ha.nl_432 gl.ca.so_432  zu.rw.un_980 jw.af.de_422
  0x18002b2b, 0x232a0da7, 0x10000d13, 0x55353f13,   // vi.ga.un_980 cs.mt.ca_532  cs.lt.un_650 af.zu.rw_665
  0x25521313, 0x05002d07, 0x55251a12, 0x3b211c07,   // et.ha.eu_665 sk.fr.un_420  tl.eu.rw_654 id.jw.so_432
  // [26f0]
  0x21356808, 0x00000324, 0x52250608, 0x643f55af,   // ig.zu.jw_443 nl.un.un_900  de.eu.ha_443 rw.af.lg_655
  0x01005507, 0x1c001904, 0x55003521, 0x211e1c14,   // rw.en.un_420 gl.id.un_320  zu.rw.un_860 id.ms.jw_666
  0x112b2102, 0x0f2510ee, 0x0d005208, 0x0a110f11,   // jw.vi.ro_222 lt.eu.lv_422  ha.cs.un_430 lv.ro.pt_653
  0x3b005504, 0x041008a9, 0x033f0205, 0x3b00310d,   // rw.so.un_320 uk.be.ru_544  da.af.nl_333 az.so.un_540
  // [2700]
  0x063f2b0b, 0x080c0313, 0x09003202, 0x3f350da7,   // vi.af.de_542 nl.sv.no_665  bs.pl.un_220 cs.zu.af_532
  0x530128a0, 0x1f090d07, 0x28004a21, 0x1f000d11,   // sw.en.ht_322 cs.pl.cy_432  yo.sw.un_860 cs.cy.un_630
  0x08000c12, 0x1c1e2111, 0x090d1c60, 0x32212aa0,   // sv.no.un_640 jw.ms.id_653  mr.ne.hi_664 mt.jw.bs_322
  0x53281602, 0x28006402, 0x21004a23, 0x6b2b280d,   // hr.sw.ht_222 lg.sw.un_220  yo.jw.un_880 sw.vi.ceb_554
  // [2710]
  0x4a000a19, 0x2a005502, 0x35006413, 0x55213511,   // pt.yo.un_750 rw.mt.un_220  lg.zu.un_650 zu.jw.rw_653
  0x233f6b07, 0x2700051b, 0x2a084aa0, 0x2a071104,   // ceb.af.ca_432 fr.gd.un_770  yo.no.mt_322 ro.it.mt_332
  0x05001914, 0x19230f5a, 0x0b0118a0, 0x06001305,   // gl.fr.un_660 lv.ca.gl_553  ga.en.es_322 et.de.un_330
  0x35005522, 0x0e2a0faf, 0x3f180b5a, 0x0a55280c,   // rw.zu.un_870 lv.mt.is_655  es.ga.af_553 sw.rw.pt_543
  // [2720]
  0x16110da4, 0x0f006404, 0x05002102, 0x170407a7,   // cs.ro.hr_433 lg.lv.un_320  jw.fr.un_220 bg.ru.sr_532
  0x13033f05, 0x0d12090c, 0x06093f02, 0x321720ee,   // af.nl.et_333 pl.hu.cs_543  af.pl.de_222 sq.sr.bs_422
  0x0e00180e, 0x1218210d, 0x10081709, 0x07002704,   // ga.is.un_550 fa.ar.ur_554  sr.uk.be_444 gd.it.un_320
  0x2d000d2c, 0x182705af, 0x080d2da7, 0x1a002813,   // cs.sk.un_990 fr.gd.ga_655  sk.cs.no_532 sw.tl.un_650
  // [2730]
  0x3b121107, 0x070411a9, 0x3b1e550e, 0x190b0a09,   // ro.hu.so_432 ro.ru.bg_544  rw.ms.so_555 pt.es.gl_444
  0x16192307, 0x0c1306ac, 0x64003204, 0x0f080204,   // ca.gl.hr_432 de.et.sv_632  bs.lg.un_320 da.no.lv_332
  0x3b000302, 0x0f2a0d07, 0x08022da4, 0x10041312,   // nl.so.un_220 cs.mt.lv_432  sk.da.no_433 et.fi.lt_654
  0x0112130c, 0x2300052a, 0x32002002, 0x0a1710a0,   // et.hu.en_543 fr.ca.un_970  sq.bs.un_220 be.sr.mk_322
  // [2740]
  0x23005312, 0x23000302, 0x08000704, 0x1200310c,   // ht.ca.un_640 nl.ca.un_220  it.no.un_320 az.hu.un_530
  0x53001921, 0x35001e02, 0x201b32a0, 0x18001a02,   // gl.ht.un_860 ms.zu.un_220  bs.tr.sq_322 tl.ga.un_220
  0x131c09ec, 0x0d00050b, 0x5364550c, 0x3f005304,   // hi.mr.bh_644 fr.cs.un_520  rw.lg.ht_543 ht.af.un_320
  0x09001c04, 0x6b5325a0, 0x071108a7, 0x3f530511,   // mr.hi.un_320 eu.ht.ceb_322  uk.ro.bg_532 fr.ht.af_653
  // [2750]
  0x18000e08, 0x00002a2d, 0x233f530d, 0x04080aa0,   // is.ga.un_430 mt.un.un_A00  ht.af.ca_554 mk.uk.ru_322
  0x03003202, 0x55351bee, 0x290f0d07, 0x060a25ad,   // bs.nl.un_220 tr.zu.rw_422  cs.lv.sl_432 eu.pt.de_643
  0x21311b5a, 0x53021ea0, 0x0b00230d, 0x16112007,   // tr.az.jw_553 ms.da.ht_322  ca.es.un_540 sq.ro.hr_432
  0x18001104, 0x0a0410a7, 0x1e1c230c, 0x092a1bee,   // ro.ga.un_320 be.ru.mk_532  ca.id.ms_543 tr.mt.pl_422
  // [2760]
  0x28556413, 0x18211213, 0x25001c13, 0x52284a0b,   // lg.rw.sw_665 ur.fa.ar_665  id.eu.un_650 yo.sw.ha_542
  0x3f001105, 0x1c2d0d14, 0x080407a9, 0x35005512,   // ro.af.un_330 cs.sk.id_666  bg.ru.uk_544 rw.zu.un_640
  0x04100707, 0x55681f60, 0x1e1c3505, 0x64282a12,   // bg.be.ru_432 cy.ig.rw_664  zu.id.ms_333 mt.sw.lg_654
  0x0a1704af, 0x28001307, 0x08033f08, 0x070408ad,   // ru.sr.mk_655 et.sw.un_420  af.nl.no_443 uk.ru.bg_643
  // [2770]
  0x083f25a0, 0x2a645509, 0x31006b08, 0x0e004a04,   // eu.af.no_322 rw.lg.mt_444  ceb.az.un_430 yo.is.un_320
  0x120802ee, 0x6435550b, 0x04070813, 0x0407080e,   // da.no.hu_422 rw.zu.lg_542  uk.bg.ru_665 uk.bg.ru_555
  0x0d292daf, 0x02002704, 0x1600090c, 0x10070a55,   // sk.sl.cs_655 gd.da.un_320  pl.hr.un_530 mk.bg.be_442
  0x0d001c08, 0x28004a0c, 0x09000804, 0x643b2155,   // mr.ne.un_430 yo.sw.un_530  no.pl.un_320 jw.so.lg_442
  // [2780]
  0x11000f12, 0x113f25ad, 0x00002924, 0x6b001a12,   // lv.ro.un_640 eu.af.ro_643  sl.un.un_900 tl.ceb.un_640
  0x072916a9, 0x07181f12, 0x016b1204, 0x1000041a,   // hr.sl.it_544 cy.ga.it_654  hu.ceb.en_332 ru.be.un_760
  0x1200290d, 0x123f6ba4, 0x2d1307a0, 0x07000607,   // sl.hu.un_540 ceb.af.hu_433  it.et.sk_322 de.it.un_420
  0x09002905, 0x3b000e13, 0x1300090d, 0x1e00640d,   // sl.pl.un_330 is.so.un_650  hi.bh.un_540 lg.ms.un_540
  // [2790]
  0x081104af, 0x03006b08, 0x3b00110d, 0x051c21a0,   // ru.ro.uk_655 ceb.nl.un_430  ro.so.un_540 jw.id.fr_322
  0x18032307, 0x1f2106ee, 0x0a0704ec, 0x2d0f0704,   // ca.nl.ga_432 de.jw.cy_422  ru.bg.mk_644 it.lv.sk_332
  0x1b0464a4, 0x0717045a, 0x0f0e08a0, 0x1a101ba0,   // lg.fi.tr_433 ru.sr.bg_553  no.is.lv_322 tr.lt.tl_322
  0x23001f04, 0x111b0fa0, 0x191f0b12, 0x0600030d,   // cy.ca.un_320 lv.tr.ro_322  es.cy.gl_654 nl.de.un_540
  // [27a0]
  0x0f3f08a0, 0x16251102, 0x211204a9, 0x132855af,   // no.af.lv_322 ro.eu.hr_222  fi.hu.jw_544 rw.sw.et_655
  0x0b001004, 0x0804070d, 0x19000302, 0x111355a9,   // lt.es.un_320 bg.ru.uk_554  nl.gl.un_220 rw.et.ro_544
  0x190b1005, 0x06003f02, 0x03001804, 0x200552a4,   // lt.es.gl_333 af.de.un_220  ga.nl.un_320 ha.fr.sq_433
  0x03055508, 0x0f28130c, 0x03023f05, 0x050311a4,   // rw.fr.nl_443 et.sw.lv_543  af.da.nl_333 ro.nl.fr_433
  // [27b0]
  0x01002007, 0x062a250c, 0x0f5210a4, 0x10002520,   // sq.en.un_420 eu.mt.de_543  lt.ha.lv_433 eu.lt.un_850
  0x05003b05, 0x521b2860, 0x3b002519, 0x6b28350c,   // so.fr.un_330 sw.tr.ha_664  eu.so.un_750 zu.sw.ceb_543
  0x35100f08, 0x06002513, 0x4a100f11, 0x20321ca0,   // lv.lt.zu_443 eu.de.un_650  lv.lt.yo_653 id.bs.sq_322
  0x1b2a07a9, 0x1e4a52ac, 0x0805230c, 0x0f1335a4,   // it.mt.tr_544 ha.yo.ms_632  ca.fr.no_543 zu.et.lv_433
  // [27c0]
  0x100e0f09, 0x2a2855ec, 0x0e282102, 0x130f25a4,   // lv.is.lt_444 rw.sw.mt_644  jw.sw.is_222 eu.lv.et_433
  0x10282104, 0x35002504, 0x07080a09, 0x1c35210c,   // jw.sw.lt_332 eu.zu.un_320  mk.uk.bg_444 jw.zu.id_543
  0x1e1c64a4, 0x07080412, 0x251e1c0d, 0x1c1b10a4,   // lg.id.ms_433 ru.uk.bg_654  id.ms.eu_554 lt.tr.id_433
  0x530e08a0, 0x3f000804, 0x06001f1b, 0x1b3b5512,   // no.is.ht_322 no.af.un_320  cy.de.un_770 rw.so.tr_654
  // [27d0]
  0x080255a4, 0x551352a9, 0x551b3b08, 0x52001a22,   // rw.da.no_433 ha.et.rw_544  so.tr.rw_443 tl.ha.un_870
  0x101708a4, 0x52211cac, 0x4a1b5512, 0x09190b02,   // uk.sr.be_433 id.jw.ha_632  rw.tr.yo_654 es.gl.pl_222
  0x1a6b1ca9, 0x31003b12, 0x6b1a53af, 0x1100071b,   // id.ceb.tl_544 so.az.un_640  ht.tl.ceb_655 bg.ro.un_770
  0x130f1013, 0x1b005521, 0x213f03ee, 0x6b001a35,   // lt.lv.et_665 rw.tr.un_860  nl.af.jw_422 tl.ceb.un_A90
  // [27e0]
  0x1100130c, 0x523b1bad, 0x2d000412, 0x55281e0b,   // et.ro.un_530 tr.so.ha_643  fi.sk.un_640 ms.sw.rw_542
  0x286b310c, 0x211a1e07, 0x1107685a, 0x110f2104,   // az.ceb.sw_543 ms.tl.jw_432  ig.it.ro_553 jw.lv.ro_332
  0x25005221, 0x53643504, 0x0f11285a, 0x3b001b08,   // ha.eu.un_860 zu.lg.ht_332  sw.ro.lv_553 tr.so.un_430
  0x534a5507, 0x2811680c, 0x21356eee, 0x28521b08,   // rw.yo.ht_432 ig.ro.sw_543  hmn.zu.jw_422 tr.ha.sw_443
  // [27f0]
  0x07000112, 0x1b0a25a0, 0x0e063f02, 0x2b033fee,   // en.it.un_640 eu.pt.tr_322  af.de.is_222 af.nl.vi_422
  0x1b041ead, 0x210f520c, 0x3b00551a, 0x1c0f1e0c,   // ms.fi.tr_643 ha.lv.jw_543  rw.so.un_760 ms.lv.id_543
  0x1b5355ad, 0x03060504, 0x030f10a9, 0x3b1b55ec,   // rw.ht.tr_643 fr.de.nl_332  lt.lv.nl_544 rw.tr.so_644
  0x27002a04, 0x03001a04, 0x09642811, 0x351b550c,   // mt.gd.un_320 tl.nl.un_320  sw.lg.pl_653 rw.tr.zu_543

  // [2800]
  0x072a1105, 0x552053a4, 0x1204525a, 0x6406050b,   // ro.mt.it_333 ht.sq.rw_433  ha.fi.hu_553 fr.de.lg_542
  0x05000a0d, 0x1318040c, 0x2700042a, 0x2500031a,   // pt.fr.un_540 fi.ga.et_543  fi.gd.un_970 nl.eu.un_760
  0x182702a0, 0x0518040c, 0x180768a0, 0x130d1cec,   // da.gd.ga_322 fi.ga.fr_543  ig.it.ga_322 mr.ne.bh_644
  0x180427ec, 0x0f1a04ad, 0x281304ad, 0x1000042b,   // gd.fi.ga_644 fi.tl.lv_643  fi.et.sw_643 ru.be.un_980
  // [2810]
  0x0f1827ec, 0x2a003b14, 0x0a002b19, 0x080a1707,   // gd.ga.lv_644 so.mt.un_660  vi.pt.un_750 sr.mk.uk_432
  0x0600130d, 0x10182704, 0x0c0229a4, 0x27000e18,   // et.de.un_540 gd.ga.lt_332  sl.da.sv_433 is.gd.un_740
  0x08270504, 0x3f06030c, 0x25006807, 0x1f002b0d,   // fr.gd.no_332 nl.de.af_543  ig.eu.un_420 vi.cy.un_540
  0x03000605, 0x10050412, 0x100f0413, 0x0f052709,   // de.nl.un_330 fi.fr.lt_654  fi.lv.lt_665 gd.fr.lv_444
  // [2820]
  0x08071708, 0x06040f0b, 0x35002812, 0x29643504,   // sr.bg.uk_443 lv.fi.de_542  sw.zu.un_640 zu.lg.sl_332
  0x64352808, 0x07001705, 0x35286408, 0x12182108,   // sw.zu.lg_443 sr.bg.un_330  lg.sw.zu_443 fa.ar.ur_443
  0x64003521, 0x07002105, 0x070a17af, 0x2d090d0d,   // zu.lg.un_860 jw.it.un_330  sr.mk.bg_655 cs.pl.sk_554
  0x10000f1b, 0x3f1a03a9, 0x07282504, 0x11000a13,   // lv.lt.un_770 nl.tl.af_544  eu.sw.it_332 mk.ro.un_650
  // [2830]
  0x0a250ead, 0x2d0d05a0, 0x1b00201a, 0x3f006407,   // is.eu.pt_643 fr.cs.sk_322  sq.tr.un_760 lg.af.un_420
  0x64003b22, 0x1f53080b, 0x3f033b0c, 0x100725a7,   // so.lg.un_870 no.ht.cy_542  so.nl.af_543 eu.it.lt_532
  0x133b070c, 0x1a006b14, 0x1a201208, 0x0a000413,   // it.so.et_543 ceb.tl.un_660  hu.sq.tl_443 ru.mk.un_650
  0x0b0c64a4, 0x52004a04, 0x53272012, 0x05001907,   // lg.sv.es_433 yo.ha.un_320  sq.gd.ht_654 gl.fr.un_420
  // [2840]
  0x13071107, 0x3b1252ee, 0x686e0107, 0x27001108,   // ro.it.et_432 ha.hu.so_422  en.hmn.ig_432 ro.gd.un_430
  0x18080208, 0x321725ec, 0x1a006b21, 0x2500520e,   // da.no.ga_443 eu.sr.bs_644  ceb.tl.un_860 ha.eu.un_550
  0x06023fa9, 0x1107010c, 0x10640f13, 0x0602230c,   // af.da.de_544 en.it.ro_543  lv.lg.lt_665 ca.da.de_543
  0x0c083107, 0x05112312, 0x2a3b3104, 0x19002308,   // az.no.sv_432 ca.ro.fr_654  az.so.mt_332 ca.gl.un_430
  // [2850]
  0x0c0708a0, 0x3f3b03af, 0x106455a4, 0x0d1c09af,   // no.it.sv_322 nl.so.af_655  rw.lg.lt_433 hi.mr.ne_655
  0x061225ad, 0x25001e08, 0x095535a0, 0x093f08a4,   // eu.hu.de_643 ms.eu.un_430  zu.rw.pl_322 no.af.pl_433
  0x06000508, 0x16113107, 0x10006407, 0x0d001809,   // fr.de.un_430 az.ro.hr_432  lg.lt.un_420 ga.cs.un_440
  0x686b0112, 0x03006e19, 0x2d000804, 0x2564550d,   // en.ceb.ig_654 hmn.nl.un_750  no.sk.un_320 rw.lg.eu_554
  // [2860]
  0x06055311, 0x0e001a04, 0x1a3b6ba4, 0x080411a4,   // ht.fr.de_653 tl.is.un_320  ceb.so.tl_433 ro.ru.uk_433
  0x3f0802ee, 0x01002420, 0x21001304, 0x6e686b05,   // da.no.af_422 yi.iw.un_850  et.jw.un_320 ceb.ig.hmn_333
  0x0e001707, 0x2a5264ad, 0x550208ee, 0x1b282a55,   // sr.is.un_420 lg.ha.mt_643  no.da.rw_422 mt.sw.tr_442
  0x28130107, 0x20002809, 0x55000908, 0x08023fa0,   // en.et.sw_432 sw.sq.un_440  pl.rw.un_430 af.da.no_322
  // [2870]
  0x16530408, 0x17002109, 0x07081107, 0x08033f0d,   // fi.ht.hr_443 jw.sr.un_440  ro.uk.bg_432 af.nl.no_554
  0x32080c04, 0x21000a08, 0x121821ac, 0x0a0408a9,   // sv.no.bs_332 pt.jw.un_430  fa.ar.ur_632 uk.ru.mk_544
  0x213b1ca4, 0x21006b04, 0x0a003b19, 0x2b001c0b,   // id.so.jw_433 ceb.jw.un_320  so.pt.un_750 id.vi.un_520
  0x170410ad, 0x0d001107, 0x210c13af, 0x6e00210c,   // be.ru.sr_643 ro.cs.un_420  et.sv.jw_655 jw.hmn.un_530
  // [2880]
  0x4a6e6804, 0x28553b60, 0x232811a7, 0x0b2d0d0d,   // ig.hmn.yo_332 so.rw.sw_664  ro.sw.ca_532 cs.sk.es_554
  0x041710a7, 0x3b553502, 0x55001f04, 0x07040808,   // be.sr.ru_532 zu.rw.so_222  cy.rw.un_320 uk.ru.bg_443
  0x110a08a0, 0x6b2a0607, 0x25000a07, 0x3b0b210c,   // no.pt.ro_322 de.mt.ceb_432  pt.eu.un_420 jw.es.so_543
  0x112305ad, 0x041710a0, 0x211c1113, 0x18001105,   // fr.ca.ro_643 be.sr.ru_322  ro.id.jw_665 ro.ga.un_330
  // [2890]
  0x0e001c1a, 0x35213b08, 0x1e1c0ea9, 0x3f20090c,   // id.is.un_760 so.jw.zu_443  is.id.ms_544 pl.sq.af_543
  0x32170ead, 0x1b680e09, 0x4a643b08, 0x12004a0d,   // is.sr.bs_643 is.ig.tr_444  so.lg.yo_443 yo.hu.un_540
  0x1f3f0305, 0x28000302, 0x13643b0b, 0x0a000e2a,   // nl.af.cy_333 nl.sw.un_220  so.lg.et_542 is.pt.un_970
  0x13043bec, 0x06000913, 0x643b13a4, 0x133b6407,   // so.fi.et_644 pl.de.un_650  et.so.lg_433 lg.so.et_432
  // [28a0]
  0x082b0107, 0x1031110c, 0x06110302, 0x64133baf,   // en.vi.no_432 ro.az.lt_543  nl.ro.de_222 so.et.lg_655
  0x0335285a, 0x10110708, 0x0f000922, 0x0b110707,   // sw.zu.nl_553 it.ro.lt_443  pl.lv.un_870 it.ro.es_432
  0x02000619, 0x3b136408, 0x316b1ba4, 0x1900010c,   // de.da.un_750 lg.et.so_443  tr.ceb.az_433 en.gl.un_530
  0x13033f04, 0x6b000919, 0x03000705, 0x02000a04,   // af.nl.et_332 pl.ceb.un_750  it.nl.un_330 pt.da.un_320
  // [28b0]
  0x04080a02, 0x0e1b010c, 0x11080a0c, 0x25190b05,   // mk.uk.ru_222 en.tr.is_543  mk.uk.ro_543 es.gl.eu_333
  0x13000407, 0x4a643b0c, 0x13003f02, 0x043b6408,   // fi.et.un_420 so.lg.yo_543  af.et.un_220 lg.so.fi_443
  0x13043bad, 0x17070a09, 0x13643b13, 0x10000807,   // so.fi.et_643 mk.bg.sr_444  so.lg.et_665 uk.be.un_420
  0x4a00040e, 0x112d0d08, 0x32001e04, 0x12290fad,   // fi.yo.un_550 cs.sk.ro_443  ms.bs.un_320 lv.sl.hu_643
  // [28c0]
  0x28003505, 0x6b010607, 0x0a1707ec, 0x29091309,   // zu.sw.un_330 de.en.ceb_432  bg.sr.mk_644 et.pl.sl_444
  0x20120304, 0x0e641aec, 0x6b1f06ac, 0x03000613,   // nl.hu.sq_332 tl.lg.is_644  de.cy.ceb_632 de.nl.un_650
  0x1f000619, 0x52355504, 0x0a170813, 0x1e1c5509,   // de.cy.un_750 rw.zu.ha_332  uk.sr.mk_665 rw.id.ms_444
  0x3b000507, 0x3b1355af, 0x170a1104, 0x09281f04,   // fr.so.un_420 rw.et.so_655  ro.mk.sr_332 cy.sw.pl_332
  // [28d0]
  0x07130e55, 0x133b0413, 0x523f53a4, 0x3b130412,   // is.et.it_442 fi.so.et_665  ht.af.ha_433 fi.et.so_654
  0x17000422, 0x55003b1b, 0x2a180911, 0x13002805,   // ru.sr.un_870 so.rw.un_770  pl.ga.mt_653 sw.et.un_330
  0x28094a0d, 0x172d0d0c, 0x1a645311, 0x2d3b550c,   // yo.pl.sw_554 cs.sk.sr_543  ht.lg.tl_653 rw.so.sk_543
  0x08040a08, 0x2100281a, 0x0e092907, 0x0f002913,   // mk.ru.uk_443 sw.jw.un_760  sl.pl.is_432 sl.lv.un_650
  // [28e0]
  0x253555ad, 0x3b64550c, 0x3b1b0455, 0x0e002a13,   // rw.zu.eu_643 rw.lg.so_543  fi.tr.so_442 mt.is.un_650
  0x1b553507, 0x55001313, 0x641a55a4, 0x6421550c,   // zu.rw.tr_432 et.rw.un_650  rw.tl.lg_433 rw.jw.lg_543
  0x130e55a4, 0x3b522804, 0x0810070c, 0x09000802,   // rw.is.et_433 sw.ha.so_332  bg.be.uk_543 no.pl.un_220
  0x11130411, 0x2a00290e, 0x644a68a4, 0x3b000408,   // fi.et.ro_653 sl.mt.un_550  ig.yo.lg_433 fi.so.un_430
  // [28f0]
  0x1c352112, 0x04001107, 0x080e1011, 0x013f2804,   // jw.zu.id_654 ro.ru.un_420  lt.is.no_653 sw.af.en_332
  0x2a00291a, 0x10000d12, 0x06005304, 0x18002804,   // sl.mt.un_760 cs.lt.un_640  ht.de.un_320 sw.ga.un_320
  0x16002004, 0x292d0d0c, 0x16003b0e, 0x1c000d0c,   // sq.hr.un_320 cs.sk.sl_543  so.hr.un_550 ne.mr.un_530
  0x29171604, 0x2500230d, 0x29190707, 0x07291604,   // hr.sr.sl_332 ca.eu.un_540  it.gl.sl_432 hr.sl.it_332
  // [2900]
  0x25130707, 0x2b00191b, 0x2d00180e, 0x1f002a13,   // it.et.eu_432 gl.vi.un_770  ga.sk.un_550 mt.cy.un_650
  0x3200290c, 0x162a2904, 0x3f00030b, 0x0d092d0c,   // sl.bs.un_530 sl.mt.hr_332  nl.af.un_520 sk.pl.cs_543
  0x1600320c, 0x29100faf, 0x162905a7, 0x6b0501a4,   // bs.hr.un_530 lv.lt.sl_655  fr.sl.hr_532 en.fr.ceb_433
  0x160720ac, 0x201a6b12, 0x0417080c, 0x1f0918a4,   // sq.it.hr_632 ceb.tl.sq_654  uk.sr.ru_543 ga.pl.cy_433
  // [2910]
  0x05001107, 0x2800520e, 0x25002307, 0x23002902,   // ro.fr.un_420 ha.sw.un_550  ca.eu.un_420 sl.ca.un_220
  0x1700040d, 0x060105a9, 0x3f055307, 0x08000414,   // ru.sr.un_540 fr.en.de_544  ht.fr.af_432 ru.uk.un_660
  0x1c0d0908, 0x55286b04, 0x282a180c, 0x2d122004,   // hi.ne.mr_443 ceb.sw.rw_332  ga.mt.sw_543 sq.hu.sk_332
  0x120a1fee, 0x122d0d55, 0x1f520b04, 0x10202504,   // cy.pt.hu_422 cs.sk.hu_442  es.ha.cy_332 eu.sq.lt_332
  // [2920]
  0x111c1ead, 0x03041307, 0x0a0711a6, 0x031101a4,   // ms.id.ro_643 et.fi.nl_432  ro.bg.mk_521 en.ro.nl_433
  0x051f01a0, 0x03002904, 0x080e0607, 0x201813ee,   // en.cy.fr_322 sl.nl.un_320  de.is.no_432 et.ga.sq_422
  0x2500201a, 0x180711af, 0x21002007, 0x072025ee,   // sq.eu.un_760 ro.it.ga_655  sq.jw.un_420 eu.sq.it_422
  0x05002804, 0x050401a6, 0x051f2308, 0x252307a7,   // sw.fr.un_320 en.fi.fr_521  ca.cy.fr_443 it.ca.eu_532
  // [2930]
  0x0a05010c, 0x52004a13, 0x02252805, 0x20000805,   // en.fr.pt_543 yo.ha.un_650  sw.eu.da_333 no.sq.un_330
  0x213b1e11, 0x6b1a1fad, 0x3f010704, 0x64005205,   // ms.so.jw_653 cy.tl.ceb_643  it.en.af_332 ha.lg.un_330
  0x1a003b20, 0x2800680c, 0x04003b13, 0x25002013,   // so.tl.un_850 ig.sw.un_530  so.fi.un_650 sq.eu.un_650
  0x2500200d, 0x1b000c08, 0x080a0405, 0x20250107,   // sq.eu.un_540 sv.tr.un_430  ru.mk.uk_333 en.eu.sq_432
  // [2940]
  0x03133f04, 0x640c520c, 0x0304130b, 0x200a07a4,   // af.et.nl_332 ha.sv.lg_543  et.fi.nl_542 it.pt.sq_433
  0x0d0105a4, 0x20050204, 0x0e00230e, 0x0a122da0,   // fr.en.cs_433 da.fr.sq_332  ca.is.un_550 sk.hu.pt_322
  0x0c0711a7, 0x0a050112, 0x08041704, 0x0c006404,   // ro.it.sv_532 en.fr.pt_654  sr.ru.uk_332 lg.sv.un_320
  0x07002a1b, 0x6b3b1aec, 0x0d1c13a0, 0x55006402,   // mt.it.un_770 tl.so.ceb_644  bh.mr.ne_322 lg.rw.un_220
  // [2950]
  0x25190b0d, 0x110410af, 0x06005204, 0x29183b04,   // es.gl.eu_554 be.ru.ro_655  ha.de.un_320 so.ga.sl_332
  0x09001f07, 0x2d000e20, 0x1700290b, 0x070411a7,   // cy.pl.un_420 is.sk.un_850  sl.sr.un_520 ro.ru.bg_532
  0x162d68a0, 0x28001219, 0x5200641a, 0x12072a12,   // ig.sk.hr_322 hu.sw.un_750  lg.ha.un_760 mt.it.hu_654
  0x52005504, 0x6b1a5212, 0x0b182707, 0x1a521ea9,   // rw.ha.un_320 ha.tl.ceb_654  gd.ga.es_432 ms.ha.tl_544
  // [2960]
  0x1c2155a9, 0x11251ea0, 0x6800251b, 0x09251813,   // rw.jw.id_544 ms.eu.ro_322  eu.ig.un_770 ga.eu.pl_665
  0x553564ad, 0x1800090d, 0x6b1a520d, 0x0e00190e,   // lg.zu.rw_643 pl.ga.un_540  ha.tl.ceb_554 gl.is.un_550
  0x2a0f2155, 0x1a003b1a, 0x6b645509, 0x272d0d0e,   // jw.lv.mt_442 so.tl.un_760  rw.lg.ceb_444 cs.sk.gd_555
  0x6b000712, 0x55356405, 0x040f25af, 0x254a6407,   // it.ceb.un_640 lg.zu.rw_333  eu.lv.fi_655 lg.yo.eu_432
  // [2970]
  0x293b520c, 0x13002022, 0x0a001107, 0x64555211,   // ha.so.sl_543 sq.et.un_870  ro.mk.un_420 ha.rw.lg_653
  0x322a1712, 0x64551ba9, 0x08040712, 0x08006b04,   // sr.mt.bs_654 tr.rw.lg_544  bg.ru.uk_654 ceb.no.un_320
  0x35084aee, 0x1c001f08, 0x1000070d, 0x046425a7,   // yo.no.zu_422 cy.id.un_430  bg.be.un_540 eu.lg.fi_532
  0x023f1f12, 0x09001222, 0x0b0407ec, 0x0f101c0c,   // cy.af.da_654 hu.pl.un_870  it.fi.es_644 id.lt.lv_543
  // [2980]
  0x0c071f07, 0x35172902, 0x1e3b2a11, 0x08000422,   // cy.it.sv_432 sl.sr.zu_222  mt.so.ms_653 ru.uk.un_870
  0x04071109, 0x130f100d, 0x28204aa0, 0x1f3b52a9,   // ro.bg.ru_444 lt.lv.et_554  yo.sq.sw_322 ha.so.cy_544
  0x13003f13, 0x13041ba9, 0x210a0b05, 0x08000c08,   // af.et.un_650 tr.fi.et_544  es.pt.jw_333 sv.no.un_430
  0x0a1011a4, 0x252d0d60, 0x20001f02, 0x130e04ec,   // ro.be.mk_433 cs.sk.eu_664  cy.sq.un_220 fi.is.et_644
  // [2990]
  0x0f254aee, 0x06006e22, 0x13250d0c, 0x08000b08,   // yo.eu.lv_422 hmn.de.un_870  cs.eu.et_543 es.no.un_430
  0x1c0e6ead, 0x08100a14, 0x0c311b13, 0x0a000604,   // hmn.is.id_643 mk.be.uk_666  tr.az.sv_665 de.pt.un_320
  0x52004a14, 0x09131c12, 0x1a6b4a13, 0x3b4a070c,   // yo.ha.un_660 mr.bh.hi_654  yo.ceb.tl_665 it.yo.so_543
  0x180127ec, 0x23006e19, 0x11190b05, 0x1f001214,   // gd.en.ga_644 hmn.ca.un_750  es.gl.ro_333 hu.cy.un_660
  // [29a0]
  0x18050807, 0x4a013502, 0x1b2b250c, 0x2d1806a7,   // no.fr.ga_432 zu.en.yo_222  eu.vi.tr_543 de.ga.sk_532
  0x08000707, 0x07520ca0, 0x021208ee, 0x161b5255,   // it.no.un_420 sv.ha.it_322  no.hu.da_422 ha.tr.hr_442
  0x23006e0c, 0x203202ad, 0x10000912, 0x08070a08,   // hmn.ca.un_530 da.bs.sq_643  pl.lt.un_640 mk.bg.uk_443
  0x1b0705a9, 0x271218a6, 0x0e00100c, 0x0a101107,   // fr.it.tr_544 ga.hu.gd_521  lt.is.un_530 ro.be.mk_432
  // [29b0]
  0x110701a4, 0x08271307, 0x071209a7, 0x0b232da4,   // en.it.ro_433 et.gd.no_432  pl.hu.it_532 sk.ca.es_433
  0x321019ee, 0x1e1b3111, 0x080410ee, 0x0817040c,   // gl.lt.bs_422 az.tr.ms_653  be.ru.uk_422 ru.sr.uk_543
  0x31201c07, 0x07235207, 0x086e06ad, 0x52002502,   // id.sq.az_432 ha.ca.it_432  de.hmn.no_643 eu.ha.un_220
  0x190b11a6, 0x080321a0, 0x0c216ea7, 0x122008a9,   // ro.es.gl_521 jw.nl.no_322  hmn.jw.sv_532 no.sq.hu_544
  // [29c0]
  0x071110a0, 0x530a05a9, 0x10000423, 0x29005205,   // lt.ro.it_322 fr.pt.ht_544  ru.be.un_880 ha.sl.un_330
  0x3f05230c, 0x52001a23, 0x52351a13, 0x162307a0,   // ca.fr.af_543 tl.ha.un_880  tl.zu.ha_665 it.ca.hr_322
  0x1a522113, 0x04171108, 0x09000705, 0x00001e1c,   // jw.ha.tl_665 ro.sr.ru_443  it.pl.un_330 ms.un.un_800
  0x092852ad, 0x03071105, 0x522128a9, 0x3b285212,   // ha.sw.pl_643 ro.it.nl_333  sw.jw.ha_544 ha.sw.so_654
  // [29d0]
  0x0b000907, 0x290f32ee, 0x020c08a7, 0x68002a08,   // pl.es.un_420 bs.lv.sl_422  no.sv.da_532 mt.ig.un_430
  0x52281aa9, 0x533b28a0, 0x10190a02, 0x3b353105,   // tl.sw.ha_544 sw.so.ht_322  pt.gl.lt_222 az.zu.so_333
  0x20110604, 0x64005209, 0x3f005205, 0x07170a05,   // de.ro.sq_332 ha.lg.un_440  ha.af.un_330 mk.sr.bg_333
  0x2a000908, 0x1e001c13, 0x02090512, 0x3b002112,   // pl.mt.un_430 id.ms.un_650  fr.pl.da_654 jw.so.un_640
  // [29e0]
  0x285209ad, 0x3b3521ec, 0x211a2807, 0x020906a0,   // pl.ha.sw_643 jw.zu.so_644  sw.tl.jw_432 de.pl.da_322
  0x1b003104, 0x6b1a520c, 0x64354a07, 0x21095212,   // az.tr.un_320 ha.tl.ceb_543  yo.zu.lg_432 ha.pl.jw_654
  0x2d0306ec, 0x281a520c, 0x3f002d04, 0x0c1c31a0,   // de.nl.sk_644 ha.tl.sw_543  sk.af.un_320 az.id.sv_322
  0x230205ad, 0x0c002d04, 0x17070808, 0x553f2dee,   // fr.da.ca_643 sk.sv.un_320  uk.bg.sr_443 sk.af.rw_422
  // [29f0]
  0x2d090607, 0x35643ba7, 0x01005308, 0x02000f04,   // de.pl.sk_432 so.lg.zu_532  ht.en.un_430 lv.da.un_320
  0x010335a0, 0x290f2d0c, 0x533b64a9, 0x645528a9,   // zu.nl.en_322 sk.lv.sl_543  lg.so.ht_544 sw.rw.lg_544
  0x31536405, 0x2d001707, 0x3b35530c, 0x02000c08,   // lg.ht.az_333 sr.sk.un_420  ht.zu.so_543 sv.da.un_430
  0x0c350205, 0x20071b55, 0x03060204, 0x170f20ee,   // da.zu.sv_333 tr.it.sq_442  da.de.nl_332 sq.lv.sr_422
  // [2a00]
  0x01190bee, 0x311b0107, 0x64321708, 0x051364af,   // es.gl.en_422 en.tr.az_432  sr.bs.lg_443 lg.et.fr_655
  0x17071007, 0x10110712, 0x0d1c0913, 0x08321609,   // be.bg.sr_432 it.ro.lt_654  hi.mr.ne_665 hr.bs.no_444
  0x2a52280c, 0x091c0da0, 0x04035504, 0x1a006b0d,   // sw.ha.mt_543 ne.mr.hi_322  rw.nl.fi_332 ceb.tl.un_540
  0x293f0107, 0x080206ee, 0x081f28a9, 0x0a0413a0,   // en.af.sl_432 de.da.no_422  sw.cy.no_544 et.fi.pt_322
  // [2a10]
  0x0e190b04, 0x030121a0, 0x106b55ee, 0x23070508,   // es.gl.is_332 jw.en.nl_322  rw.ceb.lt_422 fr.it.ca_443
  0x050c0809, 0x1b5501ee, 0x13002a13, 0x3b001c0d,   // no.sv.fr_444 en.rw.tr_422  mt.et.un_650 id.so.un_540
  0x09070a04, 0x2d000e0d, 0x281c6402, 0x09100f02,   // pt.it.pl_332 is.sk.un_540  lg.id.sw_222 lv.lt.pl_222
  0x0727010c, 0x0a2305a4, 0x29001608, 0x35001704,   // en.gd.it_543 fr.ca.pt_433  hr.sl.un_430 sr.zu.un_320
  // [2a20]
  0x21273bac, 0x072301a4, 0x0d002909, 0x181127a7,   // so.gd.jw_632 en.ca.it_433  sl.cs.un_440 gd.ro.ga_532
  0x0d001305, 0x122a0708, 0x160932ee, 0x1c001329,   // bh.ne.un_330 it.mt.hu_443  bs.pl.hr_422 bh.mr.un_960
  0x04003f04, 0x1c000d19, 0x21033f0b, 0x211e1ca9,   // af.fi.un_320 ne.mr.un_750  af.nl.jw_542 id.ms.jw_544
  0x05001702, 0x523b2855, 0x051a01a4, 0x1e1c1714,   // sr.fr.un_220 sw.so.ha_442  en.tl.fr_433 sr.id.ms_666
  // [2a30]
  0x05090707, 0x683b130d, 0x211e290c, 0x08100aec,   // it.pl.fr_432 et.so.ig_554  sl.ms.jw_543 mk.be.uk_644
  0x21352711, 0x3b0464a4, 0x35002908, 0x64352111,   // gd.zu.jw_653 lg.fi.so_433  sl.zu.un_430 jw.zu.lg_653
  0x1f3f0408, 0x1635290c, 0x0b190a13, 0x0a000719,   // fi.af.cy_443 sl.zu.hr_543  pt.gl.es_665 bg.mk.un_750
  0x13000419, 0x32000704, 0x20001702, 0x0f131005,   // fi.et.un_750 it.bs.un_320  sr.sq.un_220 lt.et.lv_333
  // [2a40]
  0x06130c0c, 0x23190a0c, 0x18060e07, 0x35000e0c,   // sv.et.de_543 pt.gl.ca_543  is.de.ga_432 is.zu.un_530
  0x2d0d0e0e, 0x1c000d14, 0x554a6460, 0x03133f02,   // is.cs.sk_555 ne.mr.un_660  lg.yo.rw_664 af.et.nl_222
  0x4a2d0d14, 0x55642812, 0x16291ca0, 0x162d0d55,   // cs.sk.yo_666 sw.lg.rw_654  id.sl.hr_322 cs.sk.hr_442
  0x061304ec, 0x3f0608a0, 0x29171602, 0x23000609,   // fi.et.de_644 no.de.af_322  hr.sr.sl_222 de.ca.un_440
  // [2a50]
  0x0f3f0807, 0x13000e04, 0x06002a02, 0x322813ad,   // no.af.lv_432 is.et.un_320  mt.de.un_220 et.sw.bs_643
  0x1c0904a7, 0x131c0d0e, 0x190b0505, 0x6b103fa0,   // fi.pl.id_532 ne.mr.bh_555  fr.es.gl_333 af.lt.ceb_322
  0x2017290c, 0x04000704, 0x11000a1a, 0x2900100e,   // sl.sr.sq_543 bg.ru.un_320  mk.ro.un_760 lt.sl.un_550
  0x3b00110c, 0x10002d19, 0x1e000305, 0x071708a0,   // ro.so.un_530 sk.lt.un_750  nl.ms.un_330 uk.sr.bg_322
  // [2a60]
  0x04003f1a, 0x07040807, 0x04100fad, 0x080e29a4,   // af.fi.un_760 uk.ru.bg_432  lv.lt.fi_643 sl.is.no_433
  0x0700080e, 0x1c002b08, 0x0e001222, 0x04000f1a,   // uk.bg.un_550 vi.id.un_430  hu.is.un_870 lv.fi.un_760
  0x0d1e1c04, 0x2b001c08, 0x04081013, 0x12000e0c,   // id.ms.cs_332 id.vi.un_430  be.uk.ru_665 is.hu.un_530
  0x16321755, 0x3b2b04a7, 0x04000713, 0x1a6b1e07,   // sr.bs.hr_442 fi.vi.so_532  bg.ru.un_650 ms.ceb.tl_432
  // [2a70]
  0x4a113b04, 0x68271813, 0x07040a07, 0x023b0407,   // so.ro.yo_332 ga.gd.ig_665  mk.ru.bg_432 fi.so.da_432
  0x28000423, 0x681a6b12, 0x130410a4, 0x071a100c,   // fi.sw.un_880 ceb.tl.ig_654  lt.fi.et_433 lt.tl.it_543
  0x00006b2d, 0x3b002814, 0x10001f0e, 0x2b001e07,   // ceb.un.un_A00 sw.so.un_660  cy.lt.un_550 ms.vi.un_420
  0x180e2702, 0x28003b07, 0x11003b04, 0x062a680b,   // gd.is.ga_222 so.sw.un_420  so.ro.un_320 ig.mt.de_542
  // [2a80]
  0x64130f08, 0x3507640c, 0x0f111313, 0x1e003104,   // lv.et.lg_443 lg.it.zu_543  et.ro.lv_665 az.ms.un_320
  0x04070aa0, 0x35130f09, 0x0b003b07, 0x011827ad,   // mk.bg.ru_322 lv.et.zu_444  so.es.un_420 gd.ga.en_643
  0x28133514, 0x073b27ad, 0x0f000807, 0x3b00041a,   // zu.et.sw_666 gd.so.it_643  no.lv.un_420 fi.so.un_760
  0x07006412, 0x0f136408, 0x043b1c07, 0x06283f07,   // lg.it.un_640 lg.et.lv_443  id.so.fi_432 af.sw.de_432
  // [2a90]
  0x07100a07, 0x6b2a2713, 0x3b0413a9, 0x1e04130c,   // mk.be.bg_432 gd.mt.ceb_665  et.fi.so_544 et.fi.ms_543
  0x68041312, 0x10310804, 0x0a00190c, 0x25270107,   // et.fi.ig_654 no.az.lt_332  gl.pt.un_530 en.gd.eu_432
  0x021b1808, 0x07000502, 0x25001108, 0x080201af,   // ga.tr.da_443 fr.it.un_220  ro.eu.un_430 en.da.no_655
  0x1000011a, 0x533f010c, 0x130401a0, 0x180506a9,   // en.lt.un_760 en.af.ht_543  en.fi.et_322 de.fr.ga_544
  // [2aa0]
  0x0c00030c, 0x32160909, 0x27061e05, 0x18000402,   // nl.sv.un_530 pl.hr.bs_444  ms.de.gd_333 fi.ga.un_220
  0x533f13ad, 0x20000219, 0x25033f09, 0x023f13a4,   // et.af.ht_643 da.sq.un_750  af.nl.eu_444 et.af.da_433
  0x0f642805, 0x521328ad, 0x203f0802, 0x0400082b,   // sw.lg.lv_333 sw.et.ha_643  no.af.sq_222 uk.ru.un_980
  0x3f1327a4, 0x0420130c, 0x17041107, 0x19001012,   // gd.et.af_433 et.sq.fi_543  ro.ru.sr_432 lt.gl.un_640
  // [2ab0]
  0x11000121, 0x10001f23, 0x130f04ee, 0x12002008,   // en.ro.un_860 cy.lt.un_880  fi.lv.et_422 sq.hu.un_430
  0x1f000107, 0x0c2552a4, 0x07001105, 0x4a001b07,   // en.cy.un_420 ha.eu.sv_433  ro.it.un_330 tr.yo.un_420
  0x09270107, 0x091827af, 0x19530b08, 0x070e08a0,   // en.gd.pl_432 gd.ga.pl_655  es.ht.gl_443 no.is.it_322
  0x523b1e07, 0x09271812, 0x3b3f1b08, 0x0c081704,   // ms.so.ha_432 ga.gd.pl_654  tr.af.so_443 sr.no.sv_332
  // [2ac0]
  0x0a0417a4, 0x10070a13, 0x2d00091a, 0x6b00011a,   // sr.ru.mk_433 mk.bg.be_665  pl.sk.un_760 en.ceb.un_760
  0x041355ec, 0x642855af, 0x19050107, 0x2a182709,   // rw.et.fi_644 rw.sw.lg_655  en.fr.gl_432 gd.ga.mt_444
  0x1f180607, 0x3f1320a9, 0x18092713, 0x20003204,   // de.ga.cy_432 sq.et.af_544  gd.pl.ga_665 bs.sq.un_320
  0x35002313, 0x040d2dad, 0x3b133502, 0x190b1055,   // ca.zu.un_650 sk.cs.fi_643  zu.et.so_222 lt.es.gl_442
  // [2ad0]
  0x09270605, 0x18272a0c, 0x12003508, 0x0800111a,   // de.gd.pl_333 mt.gd.ga_543  zu.hu.un_430 ro.uk.un_760
  0x190a0b05, 0x32002905, 0x35006418, 0x01003f02,   // es.pt.gl_333 sl.bs.un_330  lg.zu.un_740 af.en.un_220
  0x01005504, 0x35001905, 0x1e1c3ba4, 0x270918af,   // rw.en.un_320 gl.zu.un_330  so.id.ms_433 ga.pl.gd_655
  0x231e1c08, 0x1c2d0d04, 0x10000908, 0x091827a9,   // id.ms.ca_443 cs.sk.id_332  pl.lt.un_430 gd.ga.pl_544
  // [2ae0]
  0x21000c0c, 0x09271813, 0x07002a0c, 0x1f18270c,   // sv.jw.un_530 ga.gd.pl_665  mt.it.un_530 gd.ga.cy_543
  0x32172aa9, 0x182709a7, 0x0e020c0c, 0x28005502,   // mt.sr.bs_544 pl.gd.ga_532  sv.da.is_543 rw.sw.un_220
  0x28553513, 0x4a1e1ca4, 0x1e1c21ee, 0x06000912,   // zu.rw.sw_665 id.ms.yo_433  jw.id.ms_422 pl.de.un_640
  0x28090111, 0x07040a13, 0x2a001f34, 0x3b000907,   // en.pl.sw_653 mk.ru.bg_665  cy.mt.un_A80 pl.so.un_420
  // [2af0]
  0x321629a4, 0x0c3f080c, 0x23000708, 0x111b2504,   // sl.hr.bs_433 no.af.sv_543  it.ca.un_430 eu.tr.ro_332
  0x250e52ee, 0x2a001e04, 0x0f1f2aa4, 0x644a2aa4,   // ha.is.eu_422 ms.mt.un_320  mt.cy.lv_433 mt.yo.lg_433
  0x2a321704, 0x1b001108, 0x68172aa4, 0x68052b05,   // sr.bs.mt_332 ro.tr.un_430  mt.sr.ig_433 vi.fr.ig_333
  0x3528090d, 0x171609ad, 0x04000302, 0x64551c0b,   // pl.sw.zu_554 pl.hr.sr_643  nl.fi.un_220 id.rw.lg_542
  // [2b00]
  0x10002509, 0x0328090c, 0x4a00640c, 0x101f2504,   // eu.lt.un_440 pl.sw.nl_543  lg.yo.un_530 eu.cy.lt_332
  0x4a002312, 0x4a3f090b, 0x640609ee, 0x64004a2c,   // ca.yo.un_640 pl.af.yo_542  pl.de.lg_422 yo.lg.un_990
  0x10000a19, 0x05104a09, 0x32121707, 0x53004a0e,   // mk.be.un_750 yo.lt.fr_444  sr.hu.bs_432 yo.ht.un_550
  0x11132aa4, 0x6400532a, 0x3b065305, 0x1b1e1c13,   // mt.et.ro_433 ht.lg.un_970  ht.de.so_333 id.ms.tr_665
  // [2b10]
  0x12001012, 0x116b1a07, 0x0b000a05, 0x03063f02,   // lt.hu.un_640 tl.ceb.ro_432  pt.es.un_330 af.de.nl_222
  0x1e1121a4, 0x32001719, 0x07001704, 0x191218a7,   // jw.ro.ms_433 sr.bs.un_750  sr.bg.un_320 ga.hu.gl_532
  0x00000101, 0x04070a0e, 0x16005505, 0x1f1a3507,   // en.un.un_200 mk.bg.ru_555  rw.hr.un_330 zu.tl.cy_432
  0x033f6408, 0x25000107, 0x1a001b0c, 0x3f0428ac,   // lg.af.nl_443 en.eu.un_420  tr.tl.un_530 sw.fi.af_632
  // [2b20]
  0x1b001a09, 0x641e5207, 0x210e0604, 0x03000209,   // tl.tr.un_440 ha.ms.lg_432  de.is.jw_332 da.nl.un_440
  0x180627a7, 0x033f3b05, 0x3f003b1b, 0x1a006e04,   // gd.de.ga_532 so.af.nl_333  so.af.un_770 hmn.tl.un_320
  0x53001913, 0x04001c04, 0x190a23af, 0x091e1c02,   // gl.ht.un_650 id.fi.un_320  ca.pt.gl_655 id.ms.pl_222
  0x2800250d, 0x3f003b12, 0x131c090b, 0x0a1f250c,   // eu.sw.un_540 so.af.un_640  hi.mr.bh_542 eu.cy.pt_543
  // [2b30]
  0x2d003507, 0x03080204, 0x02033f08, 0x3f002502,   // zu.sk.un_420 da.no.nl_332  af.nl.da_443 eu.af.un_220
  0x033f06a0, 0x0e000a0c, 0x10000a04, 0x17081055,   // de.af.nl_322 pt.is.un_530  mk.be.un_320 be.uk.sr_442
  0x18002118, 0x23001905, 0x040e23a6, 0x35000112,   // fa.ar.un_740 gl.ca.un_330  ca.is.fi_521 en.zu.un_640
  0x533f03a4, 0x23190a12, 0x03533fa4, 0x04321704,   // nl.af.ht_433 pt.gl.ca_654  af.ht.nl_433 sr.bs.fi_332
  // [2b40]
  0x0f311b0c, 0x0e000d04, 0x533f03a0, 0x01003504,   // tr.az.lv_543 cs.is.un_320  nl.af.ht_322 zu.en.un_320
  0x19122dad, 0x1f3f2504, 0x3b1712ec, 0x55006b04,   // sk.hu.gl_643 eu.af.cy_332  hu.sr.so_644 ceb.rw.un_320
  0x2a060112, 0x070a1705, 0x1b533504, 0x350403a0,   // en.de.mt_654 sr.mk.bg_333  zu.ht.tr_332 nl.fi.zu_322
  0x08020ea9, 0x080207a0, 0x1f192d07, 0x1200010d,   // is.da.no_544 it.da.no_322  sk.gl.cy_432 en.hu.un_540
  // [2b50]
  0x0503640c, 0x35556b07, 0x053b01ee, 0x0804070e,   // lg.nl.fr_543 ceb.rw.zu_432  en.so.fr_422 bg.ru.uk_555
  0x09000321, 0x28006b20, 0x19050b0c, 0x31131bad,   // nl.pl.un_860 ceb.sw.un_850  es.fr.gl_543 tr.et.az_643
  0x20002802, 0x045528a0, 0x070f5207, 0x5200280e,   // sw.sq.un_220 sw.rw.fi_322  ha.lv.it_432 sw.ha.un_550
  0x27001112, 0x21005319, 0x1a066ba0, 0x250713ee,   // ro.gd.un_640 ht.jw.un_750  ceb.de.tl_322 et.it.eu_422
  // [2b60]
  0x35004a0e, 0x18130411, 0x1b203107, 0x2a0c08a4,   // yo.zu.un_550 fi.et.ga_653  az.sq.tr_432 no.sv.mt_433
  0x2d0d1809, 0x18002504, 0x10070a05, 0x0704080b,   // ga.cs.sk_444 eu.ga.un_320  mk.bg.be_333 uk.ru.bg_542
  0x19040708, 0x08100412, 0x04323507, 0x68131f07,   // it.fi.gl_443 ru.be.uk_654  zu.bs.fi_432 cy.et.ig_432
  0x25202109, 0x354a5207, 0x0d001c0e, 0x3564555a,   // jw.sq.eu_444 ha.yo.zu_432  mr.ne.un_550 rw.lg.zu_553
  // [2b70]
  0x232b25ad, 0x13001c21, 0x126b1a11, 0x29321707,   // eu.vi.ca_643 mr.bh.un_860  tl.ceb.hu_653 sr.bs.sl_432
  0x322d1055, 0x0b002308, 0x28000404, 0x25002313,   // lt.sk.bs_442 ca.es.un_430  fi.sw.un_320 ca.eu.un_650
  0x28002a02, 0x080717a0, 0x17080a02, 0x3b23250c,   // mt.sw.un_220 sr.bg.uk_322  mk.uk.sr_222 eu.ca.so_543
  0x3b001a02, 0x282a6ba4, 0x25041108, 0x2835640c,   // tl.so.un_220 ceb.mt.sw_433  ro.fi.eu_443 lg.zu.sw_543
  // [2b80]
  0x0e081fad, 0x0a080404, 0x03200605, 0x08060fa4,   // cy.no.is_643 ru.uk.mk_332  de.sq.nl_333 lv.de.no_433
  0x03000612, 0x0a0411a7, 0x080f0608, 0x130427ad,   // de.nl.un_640 ro.ru.mk_532  de.lv.no_443 gd.fi.et_643
  0x10040f04, 0x18000622, 0x09000d1b, 0x0600101a,   // lv.fi.lt_332 de.ga.un_870  ne.hi.un_770 lt.de.un_760
  0x030f3f08, 0x321617ad, 0x2b001a0d, 0x283b5304,   // af.lv.nl_443 sr.hr.bs_643  tl.vi.un_540 ht.so.sw_332
  // [2b90]
  0x0e061faf, 0x08060e0c, 0x23031908, 0x230b0a05,   // cy.de.is_655 is.de.no_543  gl.nl.ca_443 pt.es.ca_333
  0x040807a4, 0x291b0da0, 0x0a052ba9, 0x1c2001a0,   // bg.uk.ru_433 cs.tr.sl_322  vi.fr.pt_544 en.sq.id_322
  0x04081f08, 0x040a0707, 0x0c296bee, 0x2b1127a0,   // cy.no.fi_443 bg.mk.ru_432  ceb.sl.sv_422 gd.ro.vi_322
  0x52002007, 0x06190a09, 0x0300060d, 0x030e0607,   // sq.ha.un_420 pt.gl.de_444  de.nl.un_540 de.is.nl_432
  // [2ba0]
  0x12211812, 0x28005302, 0x12001308, 0x063f030c,   // ar.fa.ur_654 ht.sw.un_220  et.hu.un_430 nl.af.de_543
  0x0c00080e, 0x083f12a9, 0x07041008, 0x170a11a7,   // no.sv.un_550 hu.af.no_544  be.ru.bg_443 ro.mk.sr_532
  0x13060ca9, 0x00002d24, 0x6b001a29, 0x083f05ee,   // sv.de.et_544 sk.un.un_900  tl.ceb.un_960 fr.af.no_422
  0x051f28ee, 0x2b1827af, 0x0c060107, 0x6b3b2007,   // sw.cy.fr_422 gd.ga.vi_655  en.de.sv_432 sq.so.ceb_432
  // [2bb0]
  0x1600200b, 0x1200641a, 0x1e211c07, 0x31003b07,   // sq.hr.un_520 lg.hu.un_760  id.jw.ms_432 so.az.un_420
  0x31201bee, 0x190a0b02, 0x1b0c02a9, 0x05002108,   // tr.sq.az_422 es.pt.gl_222  da.sv.tr_544 jw.fr.un_430
  0x0e062705, 0x18005312, 0x1f0306ad, 0x040a0755,   // gd.de.is_333 ht.ga.un_640  de.nl.cy_643 bg.mk.ru_442
  0x1b0f52ee, 0x3b000614, 0x11000f04, 0x12051f0c,   // ha.lv.tr_422 de.so.un_660  lv.ro.un_320 cy.fr.hu_543
  // [2bc0]
  0x27001804, 0x2a0653ec, 0x0000522d, 0x3f0c08a4,   // ga.gd.un_320 ht.de.mt_644  ha.un.un_A00 no.sv.af_433
  0x13043b12, 0x130c04ee, 0x061827ec, 0x53000505,   // so.fi.et_654 fi.sv.et_422  gd.ga.de_644 fr.ht.un_330
  0x0708110d, 0x0e6406a7, 0x0e000707, 0x17001607,   // ro.uk.bg_554 de.lg.is_532  it.is.un_420 hr.sr.un_420
  0x063b55a4, 0x100f2aad, 0x1e1c2a14, 0x070408a0,   // rw.so.de_433 mt.lv.lt_643  mt.id.ms_666 uk.ru.bg_322
  // [2bd0]
  0x05640107, 0x0705010b, 0x55286413, 0x1f3b4a5a,   // en.lg.fr_432 en.fr.it_542  lg.sw.rw_665 yo.so.cy_553
  0x6b000108, 0x12180804, 0x12001104, 0x00001a2d,   // en.ceb.un_430 no.ga.hu_332  ro.hu.un_320 tl.un.un_A00
  0x01006419, 0x28550507, 0x643b55ee, 0x20092d11,   // lg.en.un_750 fr.rw.sw_432  rw.so.lg_422 sk.pl.sq_653
  0x03006422, 0x0a002814, 0x55003f14, 0x0200060c,   // lg.nl.un_870 sw.pt.un_660  af.rw.un_660 de.da.un_530
  // [2be0]
  0x2a006412, 0x1b091ca0, 0x0e3b1fa4, 0x081013a4,   // lg.mt.un_640 id.pl.tr_322  cy.so.is_433 et.lt.no_433
  0x091a6b55, 0x55356e0c, 0x08020f05, 0x31191fec,   // ceb.tl.pl_442 hmn.zu.rw_543  lv.da.no_333 cy.gl.az_644
  0x1f68200c, 0x04050112, 0x053f060c, 0x1700160e,   // sq.ig.cy_543 en.fr.fi_654  de.af.fr_543 hr.sr.un_550
  0x28684aaf, 0x08040c04, 0x080e0204, 0x0f0e52a9,   // yo.ig.sw_655 sv.fi.no_332  da.is.no_332 ha.is.lv_544
  // [2bf0]
  0x521a6414, 0x681f4aa9, 0x042a0e11, 0x12033fa0,   // lg.tl.ha_666 yo.cy.ig_544  is.mt.fi_653 af.nl.hu_322
  0x2864550d, 0x04132107, 0x06000204, 0x18030655,   // rw.lg.sw_554 jw.et.fi_432  da.de.un_320 de.nl.ga_442
  0x216404a0, 0x31006405, 0x11070408, 0x283b130c,   // fi.lg.jw_322 lg.az.un_330  ru.bg.ro_443 et.so.sw_543
  0x556428a0, 0x3f3b09ec, 0x64006812, 0x5500280e,   // sw.lg.rw_322 pl.so.af_644  ig.lg.un_640 sw.rw.un_550

  // [2c00]
  0x1732160c, 0x0f04100c, 0x100c0807, 0x0e020807,   // hr.bs.sr_543 lt.fi.lv_543  no.sv.lt_432 no.da.is_432
  0x16006808, 0x2b001308, 0x0d001602, 0x2a001702,   // ig.hr.un_430 et.vi.un_430  hr.cs.un_220 sr.mt.un_220
  0x1b3b2804, 0x1e001c22, 0x3217160d, 0x201610ad,   // sw.so.tr_332 id.ms.un_870  hr.sr.bs_554 lt.hr.sq_643
  0x5200282c, 0x28002513, 0x12004a13, 0x21532508,   // sw.ha.un_990 eu.sw.un_650  yo.hu.un_650 eu.ht.jw_443
  // [2c10]
  0x10170805, 0x04000a07, 0x103f5211, 0x0a070413,   // uk.sr.be_333 mk.ru.un_420  ha.af.lt_653 ru.bg.mk_665
  0x090c02a0, 0x28531cad, 0x0a000809, 0x1e0c1ca0,   // da.sv.pl_322 id.ht.sw_643  no.pt.un_440 id.sv.ms_322
  0x02000304, 0x12064a07, 0x2a002012, 0x3f6b1a07,   // nl.da.un_320 yo.de.hu_432  sq.mt.un_640 tl.ceb.af_432
  0x180a0560, 0x1b001a02, 0x1e006812, 0x321631a0,   // fr.pt.ga_664 tl.tr.un_220  ig.ms.un_640 az.hr.bs_322
  // [2c20]
  0x03232908, 0x3f00200c, 0x070804a4, 0x1b000420,   // sl.ca.nl_443 sq.af.un_530  ru.uk.bg_433 fi.tr.un_850
  0x2b016b0c, 0x0a112704, 0x0a170412, 0x20211ca4,   // ceb.en.vi_543 gd.ro.pt_332  ru.sr.mk_654 id.jw.sq_433
  0x0c000802, 0x190a11a0, 0x1c000a04, 0x0817040e,   // no.sv.un_220 ro.pt.gl_322  pt.id.un_320 ru.sr.uk_555
  0x0c201f0c, 0x0a2d0d05, 0x0f001014, 0x045525ee,   // cy.sq.sv_543 cs.sk.pt_333  lt.lv.un_660 eu.rw.fi_422
  // [2c30]
  0x6b130104, 0x21001207, 0x530c0208, 0x5328050c,   // en.et.ceb_332 ur.fa.un_420  da.sv.ht_443 fr.sw.ht_543
  0x1100010c, 0x06001212, 0x1c00100d, 0x08000412,   // en.ro.un_530 hu.de.un_640  lt.id.un_540 ru.uk.un_640
  0x13121b0c, 0x3f001b13, 0x04120c07, 0x07170812,   // tr.hu.et_543 tr.af.un_650  sv.hu.fi_432 uk.sr.bg_654
  0x16000f04, 0x13001b13, 0x25070cec, 0x132820ad,   // lv.hr.un_320 tr.et.un_650  sv.it.eu_644 sq.sw.et_643
  // [2c40]
  0x6b110c07, 0x041011a0, 0x3511550c, 0x0b4a1908,   // sv.ro.ceb_432 ro.be.ru_322  rw.ro.zu_543 gl.yo.es_443
  0x1e002807, 0x0a002d0d, 0x2100350c, 0x312b1c0c,   // sw.ms.un_420 sk.pt.un_540  zu.jw.un_530 id.vi.az_543
  0x190b050e, 0x08100408, 0x21356408, 0x27180c0b,   // fr.es.gl_555 ru.be.uk_443  lg.zu.jw_443 sv.ga.gd_542
  0x1004070c, 0x3f1b13af, 0x21003f04, 0x18283fa9,   // bg.ru.be_543 et.tr.af_655  af.jw.un_320 af.sw.ga_544
  // [2c50]
  0x3f1b1260, 0x052123a0, 0x17110aa4, 0x4a1a3f0c,   // hu.tr.af_664 ca.jw.fr_322  mk.ro.sr_433 af.tl.yo_543
  0x0a1704a6, 0x08004a04, 0x13190a04, 0x321617ac,   // ru.sr.mk_521 yo.no.un_320  pt.gl.et_332 sr.hr.bs_632
  0x1b006404, 0x100417a9, 0x10000f08, 0x12001707,   // lg.tr.un_320 sr.ru.be_544  lv.lt.un_430 sr.hu.un_420
  0x251e1c08, 0x0d091c60, 0x28122507, 0x130d09ad,   // id.ms.eu_443 mr.hi.ne_664  eu.hu.sw_432 hi.ne.bh_643
  // [2c60]
  0x3f0a03a4, 0x0a000307, 0x0a1e25ad, 0x1c1e2511,   // nl.pt.af_433 nl.pt.un_420  eu.ms.pt_643 eu.ms.id_653
  0x21000304, 0x210a25ee, 0x2118120e, 0x033f0208,   // nl.jw.un_320 eu.pt.jw_422  ur.ar.fa_555 da.af.nl_443
  0x0a002304, 0x21000507, 0x1200212c, 0x0708170c,   // ca.pt.un_320 fr.jw.un_420  fa.ur.un_990 sr.uk.bg_543
  0x052d0d14, 0x12000708, 0x06130a05, 0x04002504,   // cs.sk.fr_666 it.hu.un_430  pt.et.de_333 eu.fi.un_320
  // [2c70]
  0x12001302, 0x06000521, 0x1e002514, 0x1e1c25af,   // et.hu.un_220 fr.de.un_860  eu.ms.un_660 eu.id.ms_655
  0x230b19ee, 0x03001f19, 0x18005313, 0x130627a0,   // gl.es.ca_422 cy.nl.un_750  ht.ga.un_650 gd.de.et_322
  0x35003f04, 0x2a00040c, 0x4a000e18, 0x1a002105,   // af.zu.un_320 fi.mt.un_530  is.yo.un_740 jw.tl.un_330
  0x053217a0, 0x31135204, 0x13000b02, 0x19001a02,   // sr.bs.fr_322 ha.et.az_332  es.et.un_220 tl.gl.un_220
  // [2c80]
  0x23070e0c, 0x080e0c07, 0x0d00130b, 0x0b2328a7,   // is.it.ca_543 sv.is.no_432  bh.ne.un_520 sw.ca.es_532
  0x081107a9, 0x12002d08, 0x1732520c, 0x04061311,   // bg.ro.uk_544 sk.hu.un_430  ha.bs.sr_543 et.de.fi_653
  0x4a002d09, 0x13060508, 0x2b1e1c0d, 0x53002b14,   // sk.yo.un_440 fr.de.et_443  id.ms.vi_554 vi.ht.un_660
  0x0c2a08a0, 0x0f002813, 0x1b072a09, 0x0200210d,   // no.mt.sv_322 sw.lv.un_650  mt.it.tr_444 jw.da.un_540
  // [2c90]
  0x190a0bec, 0x05110111, 0x19211a0d, 0x2b115204,   // es.pt.gl_644 en.ro.fr_653  tl.jw.gl_554 ha.ro.vi_332
  0x080210a0, 0x070a10a7, 0x100a1713, 0x06001304,   // lt.da.no_322 be.mk.bg_532  sr.mk.be_665 et.de.un_320
  0x21006b08, 0x32005207, 0x18211209, 0x050201ee,   // ceb.jw.un_430 ha.bs.un_420  ur.fa.ar_444 en.da.fr_422
  0x0c000207, 0x0100070e, 0x4a00682b, 0x0b231208,   // da.sv.un_420 it.en.un_550  ig.yo.un_980 hu.ca.es_443
  // [2ca0]
  0x17102da0, 0x01232aa0, 0x643b28a4, 0x070a10a4,   // sk.lt.sr_322 mt.ca.en_322  sw.so.lg_433 be.mk.bg_433
  0x07080a04, 0x35281f04, 0x64283509, 0x0c020807,   // mk.uk.bg_332 cy.sw.zu_332  zu.sw.lg_444 no.da.sv_432
  0x19120b0c, 0x356428a7, 0x4a006813, 0x2703180e,   // es.hu.gl_543 sw.lg.zu_532  ig.yo.un_650 ga.nl.gd_555
  0x06000813, 0x040a1707, 0x0700080c, 0x10000e18,   // no.de.un_650 sr.mk.ru_432  uk.bg.un_530 is.lt.un_740
  // [2cb0]
  0x28003114, 0x033f2704, 0x1c211eec, 0x170704a9,   // az.sw.un_660 gd.af.nl_332  ms.jw.id_644 ru.bg.sr_544
  0x030a07a0, 0x0f005207, 0x0d001c1a, 0x170908a0,   // it.pt.nl_322 ha.lv.un_420  mr.ne.un_760 no.pl.sr_322
  0x081117a4, 0x5500640c, 0x0d001c05, 0x0f1629a9,   // sr.ro.uk_433 lg.rw.un_530  mr.ne.un_330 sl.hr.lv_544
  0x3f00032c, 0x04100708, 0x03011855, 0x0408100d,   // nl.af.un_990 bg.be.ru_443  ga.en.nl_442 be.uk.ru_554
  // [2cc0]
  0x13001012, 0x080a1755, 0x35092805, 0x0a081702,   // lt.et.un_640 sr.mk.uk_442  sw.pl.zu_333 sr.uk.mk_222
  0x061e1c14, 0x07000804, 0x32002108, 0x64201ea4,   // id.ms.de_666 uk.bg.un_320  jw.bs.un_430 ms.sq.lg_433
  0x1732160b, 0x046810af, 0x0d1c09a0, 0x3b004a0d,   // hr.bs.sr_542 lt.ig.fi_655  hi.mr.ne_322 yo.so.un_540
  0x20171ea0, 0x522104ad, 0x21535504, 0x2d0d4aa9,   // ms.sr.sq_322 fi.jw.ha_643  rw.ht.jw_332 yo.cs.sk_544
  // [2cd0]
  0x64005512, 0x1b3268a4, 0x31356404, 0x68001a13,   // rw.lg.un_640 ig.bs.tr_433  lg.zu.az_332 tl.ig.un_650
  0x033f27a4, 0x18000304, 0x35033f0c, 0x0d122d08,   // gd.af.nl_433 nl.ga.un_320  af.nl.zu_543 sk.hu.cs_443
  0x041708a4, 0x21102d07, 0x11001b0d, 0x0a000405,   // uk.sr.ru_433 sk.lt.jw_432  tr.ro.un_540 ru.mk.un_330
  0x643521a9, 0x17041005, 0x070a04ad, 0x12002a19,   // jw.zu.lg_544 be.ru.sr_333  ru.mk.bg_643 mt.hu.un_750
  // [2ce0]
  0x1e6807ad, 0x1004070d, 0x0e2d0d04, 0x18211208,   // it.ig.ms_643 it.fi.lt_554  cs.sk.is_332 ur.fa.ar_443
  0x6e006b12, 0x16000f07, 0x0a000f04, 0x2a003107,   // ceb.hmn.un_640 lv.hr.un_420  lv.pt.un_320 az.mt.un_420
  0x1a001c04, 0x0a0711a9, 0x1632175a, 0x0c001704,   // id.tl.un_320 ro.bg.mk_544  sr.bs.hr_553 sr.sv.un_320
  0x033f0605, 0x1c1e2155, 0x3f00060d, 0x3b002802,   // de.af.nl_333 jw.ms.id_442  de.af.un_540 sw.so.un_220
  // [2cf0]
  0x08100707, 0x080a17a0, 0x08070a55, 0x0425030c,   // bg.be.uk_432 sr.mk.uk_322  mk.bg.uk_442 nl.eu.fi_543
  0x0e002121, 0x04080704, 0x4a232107, 0x31202aa7,   // jw.is.un_860 bg.uk.ru_332  jw.ca.yo_432 mt.sq.az_532
  0x1e1c2105, 0x013f060c, 0x180b190b, 0x52285502,   // jw.id.ms_333 de.af.en_543  gl.es.ga_542 rw.sw.ha_222
  0x0e002012, 0x04000b07, 0x033f060d, 0x21003522,   // sq.is.un_640 es.fi.un_420  de.af.nl_554 zu.jw.un_870
  // [2d00]
  0x253f0655, 0x4a003b0d, 0x0428130c, 0x10081112,   // de.af.eu_442 so.yo.un_540  et.sw.fi_543 ro.uk.be_654
  0x3f0313af, 0x212a20ad, 0x0a07040d, 0x29002507,   // et.nl.af_655 sq.mt.jw_643  ru.bg.mk_554 eu.sl.un_420
  0x080e2012, 0x6404680e, 0x20000e1b, 0x1a00210c,   // sq.is.no_654 ig.fi.lg_555  is.sq.un_770 jw.tl.un_530
  0x020e0c05, 0x114a6407, 0x041321a7, 0x046821ad,   // sv.is.da_333 lg.yo.ro_432  jw.et.fi_532 jw.ig.fi_643
  // [2d10]
  0x25033f07, 0x171632a6, 0x04004a0c, 0x25003f08,   // af.nl.eu_432 bs.hr.sr_521  yo.fi.un_530 af.eu.un_430
  0x0c080ea7, 0x313f03a4, 0x0a00172b, 0x28005204,   // is.no.sv_532 nl.af.az_433  sr.mk.un_980 ha.sw.un_320
  0x120b19a7, 0x033f01a7, 0x033f6ead, 0x0b0c0607,   // gl.es.hu_532 en.af.nl_532  hmn.af.nl_643 de.sv.es_432
  0x0b0f29ee, 0x06000f0e, 0x28211c07, 0x281e1c02,   // sl.lv.es_422 lv.de.un_550  id.jw.sw_432 id.ms.sw_222
  // [2d20]
  0x04101107, 0x3f00131a, 0x6e033f13, 0x0e0f1fad,   // ro.be.ru_432 et.af.un_760  af.nl.hmn_665 cy.lv.is_643
  0x3f2d16a0, 0x532a0707, 0x53001605, 0x01003f08,   // hr.sk.af_322 it.mt.ht_432  hr.ht.un_330 af.en.un_430
  0x19002104, 0x644a21ec, 0x6e000309, 0x033f6ea4,   // jw.gl.un_320 jw.yo.lg_644  nl.hmn.un_440 hmn.af.nl_433
  0x172a1104, 0x1f6828a9, 0x0300250b, 0x52001b05,   // ro.mt.sr_332 sw.ig.cy_544  eu.nl.un_520 tr.ha.un_330
  // [2d30]
  0x28006408, 0x2d0d04a0, 0x172d0d07, 0x10041105,   // lg.sw.un_430 fi.cs.sk_322  cs.sk.sr_432 ro.ru.be_333
  0x10001c02, 0x25006b07, 0x27001f07, 0x12000713,   // id.lt.un_220 ceb.eu.un_420  cy.gd.un_420 it.hu.un_650
  0x4a1235ec, 0x13036eee, 0x040c06a9, 0x6400550d,   // zu.hu.yo_644 hmn.nl.et_422  de.sv.fi_544 rw.lg.un_540
  0x13006e13, 0x31002902, 0x08040a11, 0x1c3b1e07,   // hmn.et.un_650 sl.az.un_220  mk.ru.uk_653 ms.so.id_432
  // [2d40]
  0x0f006e02, 0x0f0e1005, 0x1f006809, 0x1b351105,   // hmn.lv.un_220 lt.is.lv_333  ig.cy.un_440 ro.zu.tr_333
  0x35001f09, 0x64135202, 0x080c1bec, 0x13041004,   // cy.zu.un_440 ha.et.lg_222  tr.sv.no_644 lt.fi.et_332
  0x0e003f09, 0x01180eee, 0x084a1f07, 0x0e4a0609,   // af.is.un_440 is.ga.en_422  cy.yo.no_432 de.yo.is_444
  0x55211e05, 0x68002508, 0x073f6e0c, 0x21004a11,   // ms.jw.rw_333 eu.ig.un_430  hmn.af.it_543 yo.jw.un_630
  // [2d50]
  0x27002a08, 0x202d17a0, 0x55000304, 0x311b3b0d,   // mt.gd.un_430 sr.sk.sq_322  nl.rw.un_320 so.tr.az_554
  0x32002804, 0x271e1fa4, 0x1e1b0609, 0x640825a4,   // sw.bs.un_320 cy.ms.gd_433  de.tr.ms_444 eu.no.lg_433
  0x080205af, 0x1f060812, 0x0000160a, 0x02003f04,   // fr.da.no_655 no.de.cy_654  hr.un.un_500 af.da.un_320
  0x2768530c, 0x0b230555, 0x0f2b0308, 0x4a00522b,   // ht.ig.gd_543 fr.ca.es_442  nl.vi.lv_443 ha.yo.un_980
  // [2d60]
  0x20000f14, 0x16291bee, 0x281f5505, 0x5500682a,   // lv.sq.un_660 tr.sl.hr_422  rw.cy.sw_333 ig.rw.un_970
  0x170a0412, 0x4a001a2b, 0x0f1a530b, 0x0c3b3fa0,   // ru.mk.sr_654 tl.yo.un_980  ht.tl.lv_542 af.so.sv_322
  0x271808a9, 0x1b250c07, 0x13352905, 0x29081ba4,   // no.ga.gd_544 sv.eu.tr_432  sl.zu.et_333 tr.no.sl_433
  0x0c1153ad, 0x03133f07, 0x032b0107, 0x2b000108,   // ht.ro.sv_643 af.et.nl_432  en.vi.nl_432 en.vi.un_430
  // [2d70]
  0x080411a0, 0x4a0f1ca0, 0x070501af, 0x190701a4,   // ro.ru.uk_322 id.lv.yo_322  en.fr.it_655 en.it.gl_433
  0x10311b5a, 0x21001113, 0x35002809, 0x20136807,   // tr.az.lt_553 ro.jw.un_650  sw.zu.un_440 ig.et.sq_432
  0x1b2d0d07, 0x0c002008, 0x6b1a100d, 0x100408af,   // cs.sk.tr_432 sq.sv.un_430  lt.tl.ceb_554 uk.ru.be_655
  0x1a311b09, 0x19100f04, 0x09023fa0, 0x21310107,   // tr.az.tl_444 lv.lt.gl_332  af.da.pl_322 en.az.jw_432
  // [2d80]
  0x1b001012, 0x1a3b1e12, 0x101b3113, 0x3b6b1a0c,   // lt.tr.un_640 ms.so.tl_654  az.tr.lt_665 tl.ceb.so_543
  0x310c1b04, 0x3500100b, 0x3b6b1ca4, 0x07033f60,   // tr.sv.az_332 lt.zu.un_520  id.ceb.so_433 af.nl.it_664
  0x3b1a6b14, 0x171108a4, 0x2100530d, 0x3b1a1c07,   // ceb.tl.so_666 uk.ro.sr_433  ht.jw.un_540 id.tl.so_432
  0x08101704, 0x1f001307, 0x53311b14, 0x21003b13,   // sr.be.uk_332 et.cy.un_420  tr.az.ht_666 so.jw.un_650
  // [2d90]
  0x0f1b2555, 0x2900100d, 0x10005219, 0x643b1a0c,   // eu.tr.lv_442 lt.sl.un_540  ha.lt.un_750 tl.so.lg_543
  0x522103a0, 0x13270eec, 0x1e1c2109, 0x2a101b13,   // nl.jw.ha_322 is.gd.et_644  jw.id.ms_444 tr.lt.mt_665
  0x03281a07, 0x6b001604, 0x28211a0c, 0x12103109,   // tl.sw.nl_432 hr.ceb.un_320  tl.jw.sw_543 az.lt.hu_444
  0x1e1a03ec, 0x52003b0c, 0x55533504, 0x521a1b09,   // nl.tl.ms_644 so.ha.un_530  zu.ht.rw_332 tr.tl.ha_444
  // [2da0]
  0x0d090bba, 0x0a040855, 0x1e6b1a13, 0x06002119,   // bn.hi.ne_843 uk.ru.mk_442  tl.ceb.ms_665 jw.de.un_750
  0x18000e18, 0x03005207, 0x136428ac, 0x27060ead,   // is.ga.un_740 ha.nl.un_420  sw.lg.et_632 is.de.gd_643
  0x081805ad, 0x1e3b1cec, 0x1c000923, 0x25001b22,   // fr.ga.no_643 id.so.ms_644  hi.mr.un_880 tr.eu.un_870
  0x52123104, 0x230a010c, 0x52095502, 0x180e01a0,   // az.hu.ha_332 en.pt.ca_543  rw.pl.ha_222 en.is.ga_322
  // [2db0]
  0x2000010c, 0x0a00050c, 0x5300050b, 0x17001005,   // en.sq.un_530 fr.pt.un_530  fr.ht.un_520 lt.sr.un_330
  0x055507a4, 0x10002908, 0x08063ba7, 0x282029a4,   // it.rw.fr_433 sl.lt.un_430  so.de.no_532 sl.sq.sw_433
  0x52000307, 0x28215202, 0x10061f0b, 0x64031aa7,   // nl.ha.un_420 ha.jw.sw_222  cy.de.lt_542 tl.nl.lg_532
  0x18270eaf, 0x52000807, 0x103b520c, 0x27180ead,   // is.gd.ga_655 no.ha.un_420  ha.so.lt_543 is.ga.gd_643
  // [2dc0]
  0x0b231913, 0x19002502, 0x0e2a270c, 0x0a1f25a4,   // gl.ca.es_665 eu.gl.un_220  gd.mt.is_543 eu.cy.pt_433
  0x270501a0, 0x04000a0e, 0x29062508, 0x3f0403a0,   // en.fr.gd_322 pt.fi.un_550  eu.de.sl_443 nl.fi.af_322
  0x07170405, 0x080c0208, 0x19001307, 0x3f0a01ad,   // ru.sr.bg_333 da.sv.no_443  et.gl.un_420 en.pt.af_643
  0x13201005, 0x1e3b1ca4, 0x1b005522, 0x53000119,   // lt.sq.et_333 id.so.ms_433  rw.tr.un_870 en.ht.un_750
  // [2dd0]
  0x1118270c, 0x040711a4, 0x281b2aa0, 0x0c00130c,   // gd.ga.ro_543 ro.bg.ru_433  mt.tr.sw_322 et.sv.un_530
  0x523b1e05, 0x170710a4, 0x1b005519, 0x01530c0b,   // ms.so.ha_333 be.bg.sr_433  rw.tr.un_750 sv.ht.en_542
  0x081711a4, 0x3b001909, 0x351b55a9, 0x1f2120a9,   // ro.sr.uk_433 gl.so.un_440  rw.tr.zu_544 sq.jw.cy_544
  0x31001b0b, 0x13643ba4, 0x3f0b23a4, 0x3b3f0313,   // tr.az.un_520 so.lg.et_433  ca.es.af_433 nl.af.so_665
  // [2de0]
  0x07000a22, 0x3b3f03af, 0x040a080e, 0x1c000920,   // mk.bg.un_870 nl.af.so_655  uk.mk.ru_555 hi.mr.un_850
  0x1b005513, 0x1600080c, 0x01002a02, 0x03003b18,   // rw.tr.un_650 no.hr.un_530  mt.en.un_220 so.nl.un_740
  0x53000204, 0x070a04af, 0x1b00551a, 0x3b3f030b,   // da.ht.un_320 ru.mk.bg_655  rw.tr.un_760 nl.af.so_542
  0x20005308, 0x4a033fad, 0x17165302, 0x551b53ad,   // ht.sq.un_430 af.nl.yo_643  ht.hr.sr_222 ht.tr.rw_643
  // [2df0]
  0x354a6404, 0x0500231a, 0x11051707, 0x0c003204,   // lg.yo.zu_332 ca.fr.un_760  sr.fr.ro_432 bs.sv.un_320
  0x3f1f0707, 0x35061faf, 0x113f0e04, 0x23000b04,   // it.cy.af_432 cy.de.zu_655  is.af.ro_332 es.ca.un_320
  0x0a170811, 0x0d004a08, 0x53080508, 0x04000719,   // uk.sr.mk_653 yo.cs.un_430  fr.no.ht_443 bg.ru.un_750
  0x02000c13, 0x1c09130b, 0x1b3f0311, 0x64003f0d,   // sv.da.un_650 bh.hi.mr_542  nl.af.tr_653 af.lg.un_540
  // [2e00]
  0x0a000508, 0x0a0807af, 0x6455350b, 0x20070ca4,   // fr.pt.un_430 bg.uk.mk_655  zu.rw.lg_542 sv.it.sq_433
  0x13000929, 0x01006e08, 0x19060a0c, 0x03253fa0,   // hi.bh.un_960 hmn.en.un_430  pt.de.gl_543 af.eu.nl_322
  0x64033f0c, 0x52080204, 0x033f25ec, 0x1e2535ee,   // af.nl.lg_543 da.no.ha_332  eu.af.nl_644 zu.eu.ms_422
  0x1b0f20ad, 0x52352907, 0x0c000e12, 0x17070404,   // sq.lv.tr_643 sl.zu.ha_432  is.sv.un_640 ru.bg.sr_332
  // [2e10]
  0x3b00350d, 0x6b2301ad, 0x2a003b04, 0x3f002504,   // zu.so.un_540 en.ca.ceb_643  so.mt.un_320 eu.af.un_320
  0x021213a7, 0x17250302, 0x2d0d12ec, 0x0e00130c,   // et.hu.da_532 nl.eu.sr_222  hu.cs.sk_644 et.is.un_530
  0x04004a11, 0x182d0d05, 0x1e1c3ba0, 0x0a0708ad,   // yo.fi.un_630 cs.sk.ga_333  so.id.ms_322 uk.bg.mk_643
  0x55283ba4, 0x2a00051b, 0x274a07a0, 0x1f52070d,   // so.sw.rw_433 fr.mt.un_770  it.yo.gd_322 it.ha.cy_554
  // [2e20]
  0x3b00350c, 0x060e04a9, 0x4a2d0d0e, 0x043b2aa4,   // zu.so.un_530 fi.is.de_544  cs.sk.yo_555 mt.so.fi_433
  0x0e2d0d0e, 0x08030e0c, 0x3b00350e, 0x27531c07,   // cs.sk.is_555 is.nl.no_543  zu.so.un_550 id.ht.gd_432
  0x640e2a05, 0x172a0f04, 0x0b001e04, 0x313b640c,   // mt.is.lg_333 lv.mt.sr_332  ms.es.un_320 lg.so.az_543
  0x170f29ad, 0x0b001008, 0x0d160fa0, 0x0c0208ee,   // sl.lv.sr_643 lt.es.un_430  lv.hr.cs_322 no.da.sv_422
  // [2e30]
  0x230501af, 0x10092d09, 0x09002d07, 0x070e5208,   // en.fr.ca_655 sk.pl.lt_444  sk.pl.un_420 ha.is.it_443
  0x0f1f2aee, 0x27001a05, 0x52001704, 0x52023ba4,   // mt.cy.lv_422 tl.gd.un_330  sr.ha.un_320 so.da.ha_433
  0x1b00530e, 0x35001819, 0x03056407, 0x2a352d09,   // ht.tr.un_550 ga.zu.un_750  lg.fr.nl_432 sk.zu.mt_444
  0x1e3b31a4, 0x313b3507, 0x0c001307, 0x192d0d04,   // az.so.ms_433 zu.so.az_432  et.sv.un_420 cs.sk.gl_332
  // [2e40]
  0x12190ba4, 0x2a353b04, 0x27186bee, 0x281b3112,   // es.gl.hu_433 so.zu.mt_332  ceb.ga.gd_422 az.tr.sw_654
  0x31002102, 0x180e27a9, 0x201e1c0c, 0x0e3b5209,   // jw.az.un_220 gd.is.ga_544  id.ms.sq_543 ha.so.is_444
  0x29003208, 0x3f321605, 0x126b27a0, 0x20111b0d,   // bs.sl.un_430 hr.bs.af_333  gd.ceb.hu_322 tr.ro.sq_554
  0x050713a4, 0x35641ea4, 0x05312aa6, 0x0e350807,   // et.it.fr_433 ms.lg.zu_433  mt.az.fr_521 no.zu.is_432
  // [2e50]
  0x07081208, 0x033f52ad, 0x0f1f5309, 0x095564ad,   // hu.no.it_443 ha.af.nl_643  ht.cy.lv_444 lg.rw.pl_643
  0x281b3204, 0x0e6408a0, 0x0b002305, 0x171107a4,   // bs.tr.sw_332 no.lg.is_322  ca.es.un_330 bg.ro.sr_433
  0x530b1ca4, 0x0b0e2a07, 0x10000719, 0x3f2106af,   // id.es.ht_433 mt.is.es_432  it.lt.un_750 de.jw.af_655
  0x2b00680c, 0x2b005308, 0x3f000407, 0x01080204,   // ig.vi.un_530 ht.vi.un_430  fi.af.un_420 da.no.en_332
  // [2e60]
  0x64553507, 0x27180e0c, 0x04081014, 0x18000c1a,   // zu.rw.lg_432 is.ga.gd_543  be.uk.ru_666 sv.ga.un_760
  0x0a00231b, 0x191c1e0c, 0x17351a55, 0x2100100c,   // ca.pt.un_770 ms.id.gl_543  tl.zu.sr_442 lt.jw.un_530
  0x041b0802, 0x31040ea7, 0x18002709, 0x28006807,   // no.tr.fi_222 is.fi.az_532  gd.ga.un_440 ig.sw.un_420
  0x0f190ba4, 0x2d0d0509, 0x060c0208, 0x08000e21,   // es.gl.lv_433 fr.cs.sk_444  da.sv.de_443 is.no.un_860
  // [2e70]
  0x17110707, 0x120d2807, 0x12000e14, 0x23000308,   // bg.ro.sr_432 sw.cs.hu_432  is.hu.un_660 nl.ca.un_430
  0x20003508, 0x19230aaf, 0x03002702, 0x233f030d,   // zu.sq.un_430 pt.ca.gl_655  gd.nl.un_220 nl.af.ca_554
  0x32001612, 0x25190aad, 0x03000d04, 0x08000e19,   // hr.bs.un_640 pt.gl.eu_643  cs.nl.un_320 is.no.un_750
  0x03000202, 0x201c28ee, 0x04000e0e, 0x08020c02,   // da.nl.un_220 sw.id.sq_422  is.fi.un_550 sv.da.no_222
  // [2e80]
  0x3500250c, 0x040a08a4, 0x18013f07, 0x0c3f1a02,   // eu.zu.un_530 uk.mk.ru_433  af.en.ga_432 tl.af.sv_222
  0x23190a14, 0x29002d1a, 0x19000b0b, 0x16002808,   // pt.gl.ca_666 sk.sl.un_760  es.gl.un_520 sw.hr.un_430
  0x642916a0, 0x010c0504, 0x0a192312, 0x28553504,   // hr.sl.lg_322 fr.sv.en_332  ca.gl.pt_654 zu.rw.sw_332
  0x06000f12, 0x286468a4, 0x553507af, 0x1c216411,   // lv.de.un_640 ig.lg.sw_433  it.zu.rw_655 lg.jw.id_653
  // [2e90]
  0x21041b07, 0x17080413, 0x12002d0c, 0x026b35a0,   // tr.fi.jw_432 ru.uk.sr_665  sk.hu.un_530 zu.ceb.da_322
  0x0c0e080c, 0x0e3f0812, 0x6b086404, 0x2b003f04,   // no.is.sv_543 no.af.is_654  lg.no.ceb_332 af.vi.un_320
  0x17080a08, 0x17071011, 0x09001904, 0x1a0e6ba4,   // mk.uk.sr_443 be.bg.sr_653  gl.pl.un_320 ceb.is.tl_433
  0x01000605, 0x3b001f04, 0x040810af, 0x3f3135af,   // de.en.un_330 cy.so.un_320  be.uk.ru_655 zu.az.af_655
  // [2ea0]
  0x1200640d, 0x28556b04, 0x35092113, 0x09006405,   // lg.hu.un_540 ceb.rw.sw_332  jw.pl.zu_665 lg.pl.un_330
  0x0c254a04, 0x2000550e, 0x35002d08, 0x0a0704ad,   // yo.eu.sv_332 rw.sq.un_550  sk.zu.un_430 ru.bg.mk_643
  0x2a000e1b, 0x5500641b, 0x182d0d20, 0x641035ee,   // is.mt.un_770 lg.rw.un_770  cs.sk.ga_875 zu.lt.lg_422
  0x2b000707, 0x06003f05, 0x2d0d6e0e, 0x12101a08,   // it.vi.un_420 af.de.un_330  hmn.cs.sk_555 tl.lt.hu_443
  // [2eb0]
  0x013f030b, 0x11040705, 0x3f1a6bec, 0x0f6435a6,   // nl.af.en_542 bg.ru.ro_333  ceb.tl.af_644 zu.lg.lv_521
  0x2b002102, 0x121821a9, 0x2b000708, 0x0e2d0dac,   // jw.vi.un_220 fa.ar.ur_544  it.vi.un_430 cs.sk.is_632
  0x0e0208af, 0x0f000e04, 0x27002d08, 0x1b0612ee,   // no.da.is_655 is.lv.un_320  sk.gd.un_430 hu.de.tr_422
  0x0911120c, 0x1c130908, 0x0d001904, 0x23060a02,   // hu.ro.pl_543 hi.bh.mr_443  gl.cs.un_320 pt.de.ca_222
  // [2ec0]
  0x0500310c, 0x060d0960, 0x10040814, 0x64001012,   // az.fr.un_530 pl.cs.de_664  uk.ru.be_666 lt.lg.un_640
  0x12002914, 0x1b2b1c0c, 0x2a3f1ba0, 0x056b6804,   // sl.hu.un_660 id.vi.tr_543  tr.af.mt_322 ig.ceb.fr_332
  0x12000609, 0x0f2d2912, 0x2d001302, 0x1a2001ee,   // de.hu.un_440 sl.sk.lv_654  et.sk.un_220 en.sq.tl_422
  0x27002a13, 0x31006e14, 0x2a0720a4, 0x01083bee,   // mt.gd.un_650 hmn.az.un_660  sq.it.mt_433 so.no.en_422
  // [2ed0]
  0x0804110b, 0x3f006e14, 0x53000808, 0x31056eee,   // ro.ru.uk_542 hmn.af.un_660  no.ht.un_430 hmn.fr.az_422
  0x12002a14, 0x3f030208, 0x0d091205, 0x3b1e31a7,   // mt.hu.un_660 da.nl.af_443  hu.pl.cs_333 az.ms.so_532
  0x23091202, 0x23056ea0, 0x21192312, 0x110717a4,   // hu.pl.ca_222 hmn.fr.ca_322  ca.gl.jw_654 sr.bg.ro_433
  0x0e31520b, 0x0a171104, 0x25200e07, 0x1a00280d,   // ha.az.is_542 ro.sr.mk_332  is.sq.eu_432 sw.tl.un_540
  // [2ee0]
  0x1c002904, 0x12000404, 0x132d0da0, 0x131a6b13,   // sl.id.un_320 fi.hu.un_320  cs.sk.et_322 ceb.tl.et_665
  0x64351a08, 0x0c2d0d0c, 0x3f190b55, 0x353128ee,   // tl.zu.lg_443 cs.sk.sv_543  es.gl.af_442 sw.az.zu_422
  0x0a001904, 0x120613a0, 0x6e005321, 0x120c1bad,   // gl.pt.un_320 et.de.hu_322  ht.hmn.un_860 tr.sv.hu_643
  0x1a006408, 0x04080cec, 0x11190b08, 0x030c0f07,   // lg.tl.un_430 sv.no.fi_644  es.gl.ro_443 lv.sv.nl_432
  // [2ef0]
  0x3216290b, 0x080602af, 0x03003b12, 0x120d09a4,   // sl.hr.bs_542 da.de.no_655  so.nl.un_640 pl.cs.hu_433
  0x2d6425a0, 0x190b53a0, 0x0c2806ee, 0x2d0d12a0,   // eu.lg.sk_322 ht.es.gl_322  de.sw.sv_422 hu.cs.sk_322
  0x35001708, 0x6b041a0c, 0x08170702, 0x04000a12,   // sr.zu.un_430 tl.fi.ceb_543  bg.sr.uk_222 mk.ru.un_640
  0x092d29a4, 0x0f2d0d08, 0x646b1a55, 0x351a2809,   // sl.sk.pl_433 cs.sk.lv_443  tl.ceb.lg_442 sw.tl.zu_444
  // [2f00]
  0x04170809, 0x12001b0d, 0x4a110709, 0x0804170d,   // uk.sr.ru_444 tr.hu.un_540  it.ro.yo_444 sr.ru.uk_554
  0x53001704, 0x0b000a07, 0x11071005, 0x23002107,   // sr.ht.un_320 pt.es.un_420  lt.it.ro_333 jw.ca.un_420
  0x25551207, 0x200f4aa0, 0x13072007, 0x0a002308,   // hu.rw.eu_432 yo.lv.sq_322  sq.it.et_432 ca.pt.un_430
  0x08001005, 0x0d6b1a0c, 0x07001f04, 0x64002807,   // be.uk.un_330 tl.ceb.cs_543  cy.it.un_320 sw.lg.un_420
  // [2f10]
  0x11000702, 0x04070a55, 0x131b1aa0, 0x1a290ea0,   // it.ro.un_220 mk.bg.ru_442  tl.tr.et_322 is.sl.tl_322
  0x32175307, 0x2d120aac, 0x4a00530e, 0x04001714,   // ht.sr.bs_432 pt.hu.sk_632  ht.yo.un_550 sr.ru.un_660
  0x04353f02, 0x1b101355, 0x6421685a, 0x05005307,   // af.zu.fi_222 et.lt.tr_442  ig.jw.lg_553 ht.fr.un_420
  0x04000e08, 0x09006421, 0x075552a4, 0x041008a4,   // is.fi.un_430 lg.pl.un_860  ha.rw.it_433 uk.be.ru_433
  // [2f20]
  0x21190ba4, 0x53000916, 0x0d001219, 0x1b005502,   // es.gl.jw_433 pl.ht.un_720  hu.cs.un_750 rw.tr.un_220
  0x04080a08, 0x080a1714, 0x2d0d12ac, 0x1a006402,   // mk.uk.ru_443 sr.mk.uk_666  hu.cs.sk_632 lg.tl.un_220
  0x31101b55, 0x2d090daf, 0x091a6bec, 0x31000609,   // tr.lt.az_442 cs.pl.sk_655  ceb.tl.pl_644 de.az.un_440
  0x12230b55, 0x0d002a04, 0x071004af, 0x641b68a6,   // es.ca.hu_442 mt.cs.un_320  ru.be.bg_655 ig.tr.lg_521
  // [2f30]
  0x18002107, 0x2d120d0e, 0x051b080c, 0x120b1814,   // fa.ar.un_420 cs.hu.sk_555  no.tr.fr_543 ga.es.hu_666
  0x0800110c, 0x21000b04, 0x13043fa0, 0x120b23af,   // ro.uk.un_530 es.jw.un_320  af.fi.et_322 ca.es.hu_655
  0x530d0455, 0x08000420, 0x00002337, 0x03043f08,   // fi.cs.ht_442 ru.uk.un_850  ca.un.un_B00 af.fi.nl_443
  0x6b0e1aec, 0x68001222, 0x25005522, 0x18271f12,   // tl.is.ceb_644 hu.ig.un_870  rw.eu.un_870 cy.gd.ga_654
  // [2f40]
  0x0d000413, 0x3b64200c, 0x35000907, 0x27524a55,   // fi.cs.un_650 sq.lg.so_543  pl.zu.un_420 yo.ha.gd_442
  0x55001c1a, 0x062308a4, 0x551b1a0c, 0x1100680d,   // id.rw.un_760 no.ca.de_433  tl.tr.rw_543 ig.ro.un_540
  0x11000709, 0x1f520d07, 0x3f0d53a9, 0x110a230e,   // it.ro.un_440 cs.ha.cy_432  ht.cs.af_544 ca.pt.ro_555
  0x0b033f04, 0x1a526ba4, 0x1a3f2912, 0x13001c07,   // af.nl.es_332 ceb.ha.tl_433  sl.af.tl_654 mr.bh.un_420
  // [2f50]
  0x080c0d0c, 0x0f103507, 0x29001f18, 0x52003508,   // cs.sv.no_543 zu.lt.lv_432  cy.sl.un_740 zu.ha.un_430
  0x32171604, 0x3b0d3fa0, 0x08201f12, 0x3f2111a9,   // hr.sr.bs_332 af.cs.so_322  cy.sq.no_654 ro.jw.af_544
  0x11105507, 0x04123509, 0x6b3b21a4, 0x0504530c,   // rw.lt.ro_432 zu.hu.fi_444  jw.so.ceb_433 ht.fi.fr_543
  0x55112007, 0x231107a0, 0x531a100c, 0x08031104,   // sq.ro.rw_432 it.ro.ca_322  lt.tl.ht_543 ro.nl.no_332
  // [2f60]
  0x033f6807, 0x10040da0, 0x64135508, 0x1a210904,   // ig.af.nl_432 cs.fi.lt_322  rw.et.lg_443 pl.jw.tl_332
  0x21001a1b, 0x350955a7, 0x211c1eee, 0x08070aaf,   // tl.jw.un_770 rw.pl.zu_532  ms.id.jw_422 mk.bg.uk_655
  0x0804100e, 0x4a230708, 0x0c31080c, 0x1e001c19,   // be.ru.uk_555 it.ca.yo_443  no.az.sv_543 id.ms.un_750
  0x0a1f19af, 0x0700230b, 0x1b006405, 0x0b1819ee,   // gl.cy.pt_655 ca.it.un_520  lg.tr.un_330 gl.ga.es_422
  // [2f70]
  0x08000e09, 0x030c0607, 0x286b1aec, 0x0700230c,   // is.no.un_440 de.sv.nl_432  tl.ceb.sw_644 ca.it.un_530
  0x13000d07, 0x531b6b55, 0x3200520c, 0x20001f12,   // ne.bh.un_420 ceb.tr.ht_442  ha.bs.un_530 cy.sq.un_640
  0x28001704, 0x6855280c, 0x161f2aa4, 0x0a190b0d,   // sr.sw.un_320 sw.rw.ig_543  mt.cy.hr_433 es.gl.pt_554
  0x05002308, 0x04000513, 0x0b072312, 0x033f640d,   // ca.fr.un_430 fr.fi.un_650  ca.it.es_654 lg.af.nl_554
  // [2f80]
  0x3f000505, 0x0e640a04, 0x23053f04, 0x1a6b2102,   // fr.af.un_330 pt.lg.is_332  af.fr.ca_332 jw.ceb.tl_222
  0x11002b13, 0x0d1b1ca4, 0x091f18af, 0x35000b04,   // vi.ro.un_650 id.tr.cs_433  ga.cy.pl_655 es.zu.un_320
  0x1100190c, 0x023f0355, 0x05005302, 0x0e2d120c,   // gl.ro.un_530 nl.af.da_442  ht.fr.un_220 hu.sk.is_543
  0x311b1f0e, 0x4a001b2b, 0x25000704, 0x0d00130d,   // cy.tr.az_555 tr.yo.un_980  it.eu.un_320 bh.ne.un_540
  // [2f90]
  0x133b3f04, 0x1c00210c, 0x18133ba0, 0x04001719,   // af.so.et_332 jw.id.un_530  so.et.ga_322 sr.ru.un_750
  0x200a2355, 0x20001c04, 0x53001f07, 0x1b130908,   // ca.pt.sq_442 id.sq.un_320  cy.ht.un_420 pl.et.tr_443
  0x0a0807ee, 0x29080213, 0x12556408, 0x64040c08,   // bg.uk.mk_422 da.no.sl_665  lg.rw.hu_443 sv.fi.lg_443
  0x211c1e07, 0x04060c0b, 0x25553b12, 0x040711ac,   // ms.id.jw_432 sv.de.fi_542  so.rw.eu_654 ro.bg.ru_632
  // [2fa0]
  0x1c080ea0, 0x11000107, 0x13000804, 0x10005507,   // is.no.id_322 en.ro.un_420  no.et.un_320 rw.lt.un_420
  0x1b686455, 0x0c000e14, 0x52122860, 0x03000e04,   // lg.ig.tr_442 is.sv.un_660  sw.hu.ha_664 is.nl.un_320
  0x4a350e0d, 0x28352aa0, 0x072a01a4, 0x3f3b13a9,   // is.zu.yo_554 mt.zu.sw_322  en.mt.it_433 et.so.af_544
  0x4a0b1aee, 0x08040704, 0x1c1621ee, 0x350e25a9,   // tl.es.yo_422 bg.ru.uk_332  jw.hr.id_422 eu.is.zu_544
  // [2fb0]
  0x1b170eee, 0x27001f0c, 0x0a0623af, 0x2d0d35a0,   // is.sr.tr_422 cy.gd.un_530  ca.de.pt_655 zu.cs.sk_322
  0x121819a0, 0x130603ee, 0x23000b05, 0x6b1a0faf,   // gl.ga.hu_322 nl.de.et_422  es.ca.un_330 lv.tl.ceb_655
  0x060325ee, 0x0b121812, 0x55002009, 0x64001113,   // eu.nl.de_422 ga.hu.es_654  sq.rw.un_440 ro.lg.un_650
  0x07170860, 0x131c09ad, 0x28003b09, 0x31020811,   // uk.sr.bg_664 hi.mr.bh_643  so.sw.un_440 no.da.az_653
  // [2fc0]
  0x162d01ee, 0x20550707, 0x13090d09, 0x64001a12,   // en.sk.hr_422 it.rw.sq_432  ne.hi.bh_444 tl.lg.un_640
  0x3b1f3555, 0x1c001e08, 0x0c001c04, 0x07111055,   // zu.cy.so_442 ms.id.un_430  id.sv.un_320 be.ro.bg_442
  0x280118a0, 0x0e080fac, 0x250c080d, 0x3b122107,   // ga.en.sw_322 lv.no.is_632  no.sv.eu_554 jw.hu.so_432
  0x12000912, 0x6e290fa4, 0x07002a22, 0x2b001e04,   // pl.hu.un_640 lv.sl.hmn_433  mt.it.un_870 ms.vi.un_320
  // [2fd0]
  0x09003213, 0x4a230707, 0x0a170407, 0x0d00120c,   // bs.pl.un_650 it.ca.yo_432  ru.sr.mk_432 hu.cs.un_530
  0x080704a4, 0x131c0dad, 0x18120d0b, 0x05000a07,   // ru.bg.uk_433 ne.mr.bh_643  cs.hu.ga_542 pt.fr.un_420
  0x2b001602, 0x3f0f100c, 0x3b001f1a, 0x2a2d1f07,   // hr.vi.un_220 lt.lv.af_543  cy.so.un_760 cy.sk.mt_432
  0x09190eee, 0x122111a7, 0x6b2a3b07, 0x0a251802,   // is.gl.pl_422 ro.jw.hu_532  so.mt.ceb_432 ga.eu.pt_222
  // [2fe0]
  0x10000e0b, 0x1f002d1a, 0x31005214, 0x0c0e08a0,   // is.lt.un_520 sk.cy.un_760  ha.az.un_660 no.is.sv_322
  0x536b1aad, 0x6b6823ee, 0x0c001902, 0x08000c22,   // tl.ceb.ht_643 ca.ig.ceb_422  gl.sv.un_220 sv.no.un_870
  0x1b001c08, 0x551b4a07, 0x0c003b04, 0x1f000808,   // id.tr.un_430 yo.tr.rw_432  so.sv.un_320 no.cy.un_430
  0x071711a0, 0x3f090f07, 0x3b002a0d, 0x0a1f2da4,   // ro.sr.bg_322 lv.pl.af_432  mt.so.un_540 sk.cy.pt_433
  // [2ff0]
  0x07002102, 0x0b2d0d02, 0x6b01110c, 0x07002a21,   // jw.it.un_220 cs.sk.es_222  ro.en.ceb_543 mt.it.un_860
  0x232a0709, 0x312855ee, 0x0c0901ad, 0x09250307,   // it.mt.ca_444 rw.sw.az_422  en.pl.sv_643 nl.eu.pl_432
  0x04170a07, 0x09131c60, 0x112d1207, 0x1b1f530c,   // mk.sr.ru_432 mr.bh.hi_664  hu.sk.ro_432 ht.cy.tr_543
  0x3f100f09, 0x1b000e1a, 0x1f2a53ec, 0x2d1a230c,   // lv.lt.af_444 is.tr.un_760  ht.mt.cy_644 ca.tl.sk_543

  // [3000]
  0x1200111a, 0x02000302, 0x683f100c, 0x521b0ea0,   // ro.hu.un_760 nl.da.un_220  lt.af.ig_543 is.tr.ha_322
  0x12190d0c, 0x1b0a0e0c, 0x1000081b, 0x4a003112,   // cs.gl.hu_543 is.pt.tr_543  uk.be.un_770 az.yo.un_640
  0x350c16a0, 0x2a313bad, 0x234a28a7, 0x10081107,   // hr.sv.zu_322 so.az.mt_643  sw.yo.ca_532 ro.uk.be_432
  0x2100200d, 0x18002122, 0x08021309, 0x12002104,   // sq.jw.un_540 fa.ar.un_870  et.da.no_444 jw.hu.un_320
  // [3010]
  0x2112050c, 0x530b21a9, 0x23000d08, 0x18041155,   // fr.hu.jw_543 jw.es.ht_544  cs.ca.un_430 ro.fi.ga_442
  0x2b086bee, 0x042d0d55, 0x09230a08, 0x0a2923a0,   // ceb.no.vi_422 cs.sk.fi_442  pt.ca.pl_443 ca.sl.pt_322
  0x253f03a4, 0x556801ee, 0x271811a4, 0x172901a4,   // nl.af.eu_433 en.ig.rw_422  ro.ga.gd_433 en.sl.sr_433
  0x203217a4, 0x0b001602, 0x012005ee, 0x0d001213,   // sr.bs.sq_433 hr.es.un_220  fr.sq.en_422 hu.cs.un_650
  // [3020]
  0x06110da0, 0x212b010c, 0x29172da9, 0x1b200a05,   // cs.ro.de_322 en.vi.jw_543  sk.sr.sl_544 pt.sq.tr_333
  0x23000a0c, 0x0510270c, 0x68552813, 0x232119a0,   // pt.ca.un_530 gd.lt.fr_543  sw.rw.ig_665 gl.jw.ca_322
  0x0a0417ee, 0x1c000918, 0x11231b07, 0x6b003109,   // sr.ru.mk_422 hi.mr.un_740  tr.ca.ro_432 az.ceb.un_440
  0x1a283bac, 0x033b08a0, 0x10000a02, 0x20002a05,   // so.sw.tl_632 no.so.nl_322  mk.be.un_220 mt.sq.un_330
  // [3030]
  0x01002807, 0x07000405, 0x0a033f07, 0x3f005505,   // sw.en.un_420 fi.it.un_330  af.nl.pt_432 rw.af.un_330
  0x040d2d0c, 0x0a1017a4, 0x321608a4, 0x031b19a0,   // sk.cs.fi_543 sr.be.mk_433  no.hr.bs_433 gl.tr.nl_322
  0x0d202d12, 0x1f3f2d0c, 0x3b1f210c, 0x1e00530c,   // sk.sq.cs_654 sk.af.cy_543  jw.cy.so_543 ht.ms.un_530
  0x6400121a, 0x23002504, 0x21002d04, 0x13090d12,   // hu.lg.un_760 eu.ca.un_320  sk.jw.un_320 ne.hi.bh_654
  // [3040]
  0x0c00210c, 0x13002505, 0x090164ee, 0x2d040daf,   // jw.sv.un_530 eu.et.un_330  lg.en.pl_422 cs.fi.sk_655
  0x12355555, 0x2a002108, 0x3b100704, 0x08041712,   // rw.zu.hu_442 jw.mt.un_430  it.lt.so_332 sr.ru.uk_654
  0x55001b22, 0x21001a19, 0x210d0908, 0x271f1811,   // tr.rw.un_870 tl.jw.un_750  pl.cs.jw_443 ga.cy.gd_653
  0x06080c04, 0x02083f07, 0x08002d0d, 0x641325a7,   // sv.no.de_332 af.no.da_432  sk.no.un_540 eu.et.lg_532
  // [3050]
  0x20212b07, 0x07040805, 0x0c080e13, 0x2a006807,   // vi.jw.sq_432 uk.ru.bg_333  is.no.sv_665 ig.mt.un_420
  0x06036ba0, 0x1f004a08, 0x120d2d0b, 0x35256404,   // ceb.nl.de_322 yo.cy.un_430  sk.cs.hu_542 lg.eu.zu_332
  0x1200231a, 0x06006807, 0x05001104, 0x0e190b08,   // ca.hu.un_760 ig.de.un_420  ro.fr.un_320 es.gl.is_443
  0x1c21100c, 0x09002d04, 0x126b1faf, 0x295528af,   // lt.jw.id_543 sk.pl.un_320  cy.ceb.hu_655 sw.rw.sl_655
  // [3060]
  0x6b1f1a60, 0x311b28a9, 0x0b2319a0, 0x1e272007,   // tl.cy.ceb_664 sw.tr.az_544  gl.ca.es_322 sq.gd.ms_432
  0x6400281b, 0x291f0d07, 0x6b1a1e12, 0x13002802,   // sw.lg.un_770 cs.cy.sl_432  ms.tl.ceb_654 sw.et.un_220
  0x55311b11, 0x12002a08, 0x2a0f1208, 0x35552855,   // tr.az.rw_653 mt.hu.un_430  hu.lv.mt_443 sw.rw.zu_442
  0x121a6bad, 0x2800070e, 0x321e55a0, 0x3b311bad,   // ceb.tl.hu_643 it.sw.un_550  rw.ms.bs_322 tr.az.so_643
  // [3070]
  0x23002d04, 0x0e130411, 0x190a0b0c, 0x2d190b0d,   // sk.ca.un_320 fi.et.is_653  es.pt.gl_543 es.gl.sk_554
  0x352555a6, 0x04003b02, 0x31531b0c, 0x31125304,   // rw.eu.zu_521 so.fi.un_220  tr.ht.az_543 ht.hu.az_332
  0x04110804, 0x18002a02, 0x131f6b0d, 0x2800352a,   // uk.ro.ru_332 mt.ga.un_220  ceb.cy.et_554 zu.sw.un_970
  0x31110dee, 0x1f1a1ea0, 0x072555a7, 0x04071008,   // cs.ro.az_422 ms.tl.cy_322  rw.eu.it_532 be.bg.ru_443
  // [3080]
  0x1c3b2aa0, 0x0f000912, 0x13190b07, 0x20556407,   // mt.so.id_322 pl.lv.un_640  es.gl.et_432 lg.rw.sq_432
  0x170a1112, 0x2d0d29ac, 0x04001a05, 0x0d001c1b,   // ro.mk.sr_654 sl.cs.sk_632  tl.fi.un_330 mr.ne.un_770
  0x29161ca0, 0x29321614, 0x20282d07, 0x19120ba4,   // id.hr.sl_322 hr.bs.sl_666  sk.sw.sq_432 es.hu.gl_433
  0x04161204, 0x19000a2a, 0x13280408, 0x6b0b1a05,   // hu.hr.fi_332 pt.gl.un_970  fi.sw.et_443 tl.es.ceb_333
  // [3090]
  0x55216407, 0x1b2a07a0, 0x121a6b05, 0x2a6407ee,   // lg.jw.rw_432 it.mt.tr_322  ceb.tl.hu_333 it.lg.mt_422
  0x211c1ea0, 0x121a0cad, 0x0a0807a7, 0x17040708,   // ms.id.jw_322 sv.tl.hu_643  bg.uk.mk_532 bg.ru.sr_443
  0x120c1aa7, 0x3b1b355a, 0x06201107, 0x180e12ad,   // tl.sv.hu_532 zu.tr.so_553  ro.sq.de_432 hu.is.ga_643
  0x0a190b13, 0x12194a04, 0x0b002302, 0x02063f05,   // es.gl.pt_665 yo.gl.hu_332  ca.es.un_220 af.de.da_333
  // [30a0]
  0x17162905, 0x2d0d19a0, 0x196468ad, 0x285264a0,   // sl.hr.sr_333 gl.cs.sk_322  ig.lg.gl_643 lg.ha.sw_322
  0x3555640d, 0x0d122dec, 0x55000c07, 0x041a6b07,   // lg.rw.zu_554 sk.hu.cs_644  sv.rw.un_420 ceb.tl.fi_432
  0x0d00090c, 0x350413af, 0x131c04ad, 0x120c1313,   // hi.ne.un_530 et.fi.zu_655  fi.id.et_643 et.sv.hu_665
  0x20210fa0, 0x281213a4, 0x09131c13, 0x0c1e0ba4,   // lv.jw.sq_322 et.hu.sw_433  mr.bh.hi_665 es.ms.sv_433
  // [30b0]
  0x21002b07, 0x130c080c, 0x29071cee, 0x0c0f3fee,   // vi.jw.un_420 no.sv.et_543  id.it.sl_422 af.lv.sv_422
  0x110108a0, 0x13041e12, 0x6b3b11a9, 0x0c061f0c,   // no.en.ro_322 ms.fi.et_654  ro.so.ceb_544 cy.de.sv_543
  0x0708020d, 0x0e063f04, 0x01192304, 0x0e231905,   // da.no.it_554 af.de.is_332  ca.gl.en_332 gl.ca.is_333
  0x52006e0e, 0x55352811, 0x0e2d180c, 0x0c002d0c,   // hmn.ha.un_550 sw.zu.rw_653  ga.sk.is_543 sk.sv.un_530
  // [30c0]
  0x040807a0, 0x13000c0c, 0x0811100c, 0x0d091312,   // bg.uk.ru_322 sv.et.un_530  be.ro.uk_543 bh.hi.ne_654
  0x2b4a5204, 0x64005314, 0x1b085308, 0x29000d09,   // ha.yo.vi_332 ht.lg.un_660  ht.no.tr_443 cs.sl.un_440
  0x31086811, 0x05002317, 0x0a000512, 0x0f003204,   // ig.no.az_653 ca.fr.un_730  fr.pt.un_640 bs.lv.un_320
  0x17070a60, 0x21001602, 0x0e1218af, 0x04000712,   // mk.bg.sr_664 hr.jw.un_220  ga.hu.is_655 bg.ru.un_640
  // [30d0]
  0x32291707, 0x17005304, 0x290828ee, 0x11001c04,   // sr.sl.bs_432 ht.sr.un_320  sw.no.sl_422 id.ro.un_320
  0x13040c11, 0x311168a4, 0x20681a07, 0x100c09a0,   // sv.fi.et_653 ig.ro.az_433  tl.ig.sq_432 pl.sv.lt_322
  0x11001c05, 0x16001104, 0x100804a4, 0x205228a4,   // id.ro.un_330 ro.hr.un_320  ru.uk.be_433 sw.ha.sq_433
  0x21112707, 0x28136809, 0x2700130d, 0x6864285a,   // gd.ro.jw_432 ig.et.sw_444  et.gd.un_540 sw.lg.ig_553
  // [30e0]
  0x1131280c, 0x01000502, 0x03080208, 0x1f0c06a9,   // sw.az.ro_543 fr.en.un_220  da.no.nl_443 de.sv.cy_544
  0x06182708, 0x64684a12, 0x092d0d04, 0x292d170c,   // gd.ga.de_443 yo.ig.lg_654  cs.sk.pl_332 sr.sk.sl_543
  0x4a251ca0, 0x316828af, 0x23002104, 0x19040b07,   // id.eu.yo_322 sw.ig.az_655  jw.ca.un_320 es.fi.gl_432
  0x35000420, 0x2a200e0c, 0x55311b07, 0x28004a04,   // fi.zu.un_850 is.sq.mt_543  tr.az.rw_432 yo.sw.un_320
  // [30f0]
  0x18031311, 0x1700550c, 0x642868a9, 0x5264680c,   // et.nl.ga_653 rw.sr.un_530  ig.sw.lg_544 ig.lg.ha_543
  0x08091f04, 0x16006804, 0x0a0923a0, 0x1e2864a4,   // cy.pl.no_332 ig.hr.un_320  ca.pl.pt_322 lg.sw.ms_433
  0x3f0913a4, 0x0c080e0e, 0x08001108, 0x03080f04,   // et.pl.af_433 is.no.sv_555  ro.uk.un_430 lv.no.nl_332
  0x0e1310ec, 0x17040805, 0x1a1e5507, 0x55002819,   // lt.et.is_644 uk.ru.sr_333  rw.ms.tl_432 sw.rw.un_750
  // [3100]
  0x0a181210, 0x270521ad, 0x16003b08, 0x216b1a11,   // hu.ga.pt_642 jw.fr.gd_643  so.hr.un_430 tl.ceb.jw_653
  0x3f033ba0, 0x0f2a250c, 0x0c0608a0, 0x646b1a08,   // so.nl.af_322 eu.mt.lv_543  no.de.sv_322 tl.ceb.lg_443
  0x2d17290d, 0x4a3b1a0c, 0x042d0d5a, 0x55356414,   // sl.sr.sk_554 tl.so.yo_543  cs.sk.fi_553 lg.zu.rw_666
  0x2d0d4a09, 0x23190b60, 0x3b000f05, 0x121b2004,   // yo.cs.sk_444 es.gl.ca_664  lv.so.un_330 sq.tr.hu_332
  // [3110]
  0x52092d08, 0x6b061a02, 0x09131bee, 0x12230a07,   // sk.pl.ha_443 tl.de.ceb_222  tr.et.pl_422 pt.ca.hu_432
  0x06000c1a, 0x0f2a280c, 0x1e0a5204, 0x551628a7,   // sv.de.un_760 sw.mt.lv_543  ha.pt.ms_332 sw.hr.rw_532
  0x3121520c, 0x170411a4, 0x6b101a05, 0x1e003b07,   // ha.jw.az_543 ro.ru.sr_433  tl.lt.ceb_333 so.ms.un_420
  0x070a1104, 0x20001f0c, 0x271805a4, 0x0410280c,   // ro.mk.bg_332 cy.sq.un_530  fr.ga.gd_433 sw.lt.fi_543
  // [3120]
  0x0a070407, 0x352864a9, 0x040a1711, 0x10002d14,   // ru.bg.mk_432 lg.sw.zu_544  sr.mk.ru_653 sk.lt.un_660
  0x556468ec, 0x1b000c13, 0x1704070c, 0x1320040c,   // ig.lg.rw_644 sv.tr.un_650  bg.ru.sr_543 fi.sq.et_543
  0x28556409, 0x551a350c, 0x1a002007, 0x1f0e04a4,   // lg.rw.sw_444 zu.tl.rw_543  sq.tl.un_420 fi.is.cy_433
  0x07002307, 0x030635ad, 0x171107a9, 0x021e080c,   // ca.it.un_420 zu.de.nl_643  bg.ro.sr_544 no.ms.da_543
  // [3130]
  0x64202307, 0x07002313, 0x20553507, 0x190b68a4,   // ca.sq.lg_432 ca.it.un_650  zu.rw.sq_432 ig.es.gl_433
  0x20002305, 0x0c000819, 0x4a3f03a4, 0x12002904,   // ca.sq.un_330 no.sv.un_750  nl.af.yo_433 sl.hu.un_320
  0x01006404, 0x35100708, 0x4a080255, 0x2d1b13ac,   // lg.en.un_320 it.lt.zu_443  da.no.yo_442 et.tr.sk_632
  0x07081004, 0x1e1c1aaf, 0x060302ee, 0x0b182807,   // be.uk.bg_332 tl.id.ms_655  da.nl.de_422 sw.ga.es_432
  // [3140]
  0x08070455, 0x162032ee, 0x0d001e02, 0x170c1b55,   // ru.bg.uk_442 bs.sq.hr_422  ms.cs.un_220 tr.sv.sr_442
  0x02000c02, 0x0810170d, 0x35314aad, 0x11530b05,   // sv.da.un_220 sr.be.uk_554  yo.az.zu_643 es.ht.ro_333
  0x131827ec, 0x64000308, 0x53311b07, 0x170410a7,   // gd.ga.et_644 nl.lg.un_430  tr.az.ht_432 be.ru.sr_532
  0x23000714, 0x1c001318, 0x23000718, 0x1c090dac,   // it.ca.un_660 bh.mr.un_740  it.ca.un_740 ne.hi.mr_632
  // [3150]
  0x1800521a, 0x170929ee, 0x04063f05, 0x07041011,   // ha.ga.un_760 sl.pl.sr_422  af.de.fi_333 be.ru.bg_653
  0x5300050d, 0x06003f04, 0x1b000e04, 0x280255a7,   // fr.ht.un_540 af.de.un_320  is.tr.un_320 rw.da.sw_532
  0x081b0c0b, 0x1c00520c, 0x1c1b1aa9, 0x02080e0b,   // sv.tr.no_542 ha.id.un_530  tl.tr.id_544 is.no.da_542
  0x2a020eee, 0x12001805, 0x27020ca0, 0x1000171a,   // is.da.mt_422 ga.hu.un_330  sv.da.gd_322 sr.be.un_760
  // [3160]
  0x121821a7, 0x0e004a05, 0x090d1ca9, 0x3217520c,   // fa.ar.ur_532 yo.is.un_330  mr.ne.hi_544 ha.sr.bs_543
  0x080a04a4, 0x0900640d, 0x2300011a, 0x321711af,   // ru.mk.uk_433 lg.pl.un_540  en.ca.un_760 ro.sr.bs_655
  0x10040808, 0x0900190d, 0x29172d05, 0x290b07ee,   // uk.ru.be_443 gl.pl.un_540  sk.sr.sl_333 it.es.sl_422
  0x553268a7, 0x0f2d0d05, 0x25000405, 0x162d2907,   // ig.bs.rw_532 cs.sk.lv_333  fi.eu.un_330 sl.sk.hr_432
  // [3170]
  0x55001212, 0x0d122d0d, 0x53000a07, 0x2d001019,   // hu.rw.un_640 sk.hu.cs_554  pt.ht.un_420 lt.sk.un_750
  0x02003f08, 0x090f2813, 0x0e001808, 0x00002001,   // af.da.un_430 sw.lv.pl_665  ga.is.un_430 sq.un.un_200
  0x17110a07, 0x55642005, 0x281a52a7, 0x062904ac,   // mk.ro.sr_432 sq.lg.rw_333  ha.tl.sw_532 fi.sl.de_632
  0x5200060e, 0x12001804, 0x5352280c, 0x64524aa4,   // de.ha.un_550 ga.hu.un_320  sw.ha.ht_543 yo.ha.lg_433
  // [3180]
  0x3f030655, 0x072a010c, 0x3f001219, 0x52353105,   // de.nl.af_442 en.mt.it_543  hu.af.un_750 az.zu.ha_333
  0x55286407, 0x3f002009, 0x353b5512, 0x0a6410ee,   // lg.sw.rw_432 sq.af.un_440  rw.so.zu_654 lt.lg.pt_422
  0x4a551b05, 0x553b28ec, 0x25000d07, 0x16001012,   // tr.rw.yo_333 sw.so.rw_644  cs.eu.un_420 lt.hr.un_640
  0x3b5255ad, 0x0f000d04, 0x03133f09, 0x6b040f0c,   // rw.ha.so_643 cs.lv.un_320  af.et.nl_444 lv.fi.ceb_543
  // [3190]
  0x0e002714, 0x4a2855a9, 0x1c0521a0, 0x355528ec,   // gd.is.un_660 rw.sw.yo_544  jw.fr.id_322 sw.rw.zu_644
  0x3b005512, 0x53002304, 0x120f1a08, 0x120f040d,   // rw.so.un_640 ca.ht.un_320  tl.lv.hu_443 fi.lv.hu_554
  0x01190b05, 0x3f03010c, 0x0c0813a7, 0x121a0ca9,   // es.gl.en_333 en.nl.af_543  et.no.sv_532 sv.tl.hu_544
  0x030601a0, 0x3f0635a4, 0x053f0307, 0x0800110e,   // en.de.nl_322 zu.de.af_433  nl.af.fr_432 ro.uk.un_550
  // [31a0]
  0x12230f05, 0x55535213, 0x0e124aa4, 0x525355a4,   // lv.ca.hu_333 ha.ht.rw_665  yo.hu.is_433 rw.ht.ha_433
  0x033f55a0, 0x05000e07, 0x55086407, 0x2d0e1bad,   // rw.af.nl_322 is.fr.un_420  lg.no.rw_432 tr.is.sk_643
  0x19530b5a, 0x3b554a05, 0x03001204, 0x5500280c,   // es.ht.gl_553 yo.rw.so_333  hu.nl.un_320 sw.rw.un_530
  0x5305520b, 0x0e531ba7, 0x3f03060c, 0x201b0fee,   // ha.fr.ht_542 tr.ht.is_532  de.nl.af_543 lv.tr.sq_422
  // [31b0]
  0x12531a04, 0x3b2864a0, 0x04001213, 0x2a001f14,   // tl.ht.hu_332 lg.sw.so_322  hu.fi.un_650 cy.mt.un_660
  0x0f001209, 0x06000e14, 0x040717ee, 0x121a0fa4,   // hu.lv.un_440 is.de.un_660  sr.bg.ru_422 lv.tl.hu_433
  0x6412550c, 0x1a356b02, 0x12000819, 0x21001211,   // rw.hu.lg_543 ceb.zu.tl_222  no.hu.un_750 ur.fa.un_630
  0x06036408, 0x28556460, 0x55641060, 0x531b0e0d,   // lg.nl.de_443 lg.rw.sw_664  lt.lg.rw_664 is.tr.ht_554
  // [31c0]
  0x0e000a05, 0x08000c19, 0x0e001b14, 0x3b1b0e55,   // pt.is.un_330 sv.no.un_750  tr.is.un_660 is.tr.so_442
  0x09033f11, 0x050c20a0, 0x352852ad, 0x211e1c07,   // af.nl.pl_653 sq.sv.fr_322  ha.sw.zu_643 id.ms.jw_432
  0x13292da4, 0x01004a02, 0x0b2319a4, 0x17000d0c,   // sk.sl.et_433 yo.en.un_220  gl.ca.es_433 cs.sr.un_530
  0x21001e07, 0x0f162907, 0x1f000b1b, 0x04000d04,   // ms.jw.un_420 sl.hr.lv_432  es.cy.un_770 cs.fi.un_320
  // [31d0]
  0x27051809, 0x09010d05, 0x35001f21, 0x2d2319a0,   // ga.fr.gd_444 cs.en.pl_333  cy.zu.un_860 gl.ca.sk_322
  0x08002504, 0x0a1e1c0c, 0x0a073507, 0x091c0dac,   // eu.no.un_320 id.ms.pt_543  zu.it.pt_432 ne.mr.hi_632
  0x281a11a4, 0x0a0717ec, 0x06001313, 0x1c080205,   // ro.tl.sw_433 sr.bg.mk_644  et.de.un_650 da.no.id_333
  0x105335a4, 0x53003121, 0x2835530e, 0x2a0c3204,   // zu.ht.lt_433 az.ht.un_860  ht.zu.sw_555 bs.sv.mt_332
  // [31e0]
  0x2a013207, 0x311b35a0, 0x29530107, 0x2a3b1fa7,   // bs.en.mt_432 zu.tr.az_322  en.ht.sl_432 cy.so.mt_532
  0x351f5304, 0x181101a7, 0x043f0eec, 0x0e0f0807,   // ht.cy.zu_332 en.ro.ga_532  is.af.fi_644 no.lv.is_432
  0x0400130e, 0x530a1c0c, 0x291153ac, 0x08122aa0,   // et.fi.un_550 id.pt.ht_543  ht.ro.sl_632 mt.hu.no_322
  0x19003504, 0x31003b0c, 0x1700101b, 0x04100805,   // zu.gl.un_320 so.az.un_530  be.sr.un_770 uk.be.ru_333
  // [31f0]
  0x16090d07, 0x0d3b13ad, 0x09002902, 0x01040907,   // cs.pl.hr_432 et.so.cs_643  sl.pl.un_220 pl.fi.en_432
  0x13001c1a, 0x281e1cad, 0x0400171b, 0x09001f19,   // mr.bh.un_760 id.ms.sw_643  sr.ru.un_770 cy.pl.un_750
  0x1c1f1e55, 0x19000b2a, 0x01036ba0, 0x52001e04,   // ms.cy.id_442 es.gl.un_970  ceb.nl.en_322 ms.ha.un_320
  0x3f0603a4, 0x0d100404, 0x1c1a2508, 0x2d0d250d,   // nl.de.af_433 fi.lt.cs_332  eu.tl.id_443 eu.cs.sk_554
  // [3200]
  0x0e00080c, 0x52281fa0, 0x170a0813, 0x3512280e,   // no.is.un_530 cy.sw.ha_322  uk.mk.sr_665 sw.hu.zu_555
  0x6800520b, 0x11003b1b, 0x06000814, 0x0c1306a4,   // ha.ig.un_520 so.ro.un_770  no.de.un_660 de.et.sv_433
  0x310f25a0, 0x1b1152a7, 0x130d0909, 0x520f1c07,   // eu.lv.az_322 ha.ro.tr_532  hi.ne.bh_444 id.lv.ha_432
  0x04071108, 0x522855ee, 0x08000c0c, 0x160f2d08,   // ro.bg.ru_443 rw.sw.ha_422  sv.no.un_530 sk.lv.hr_443
  // [3210]
  0x12002d04, 0x290f105a, 0x0d000913, 0x1100520d,   // sk.hu.un_320 lt.lv.sl_553  pl.cs.un_650 ha.ro.un_540
  0x11210f0c, 0x09290fa0, 0x55050fa0, 0x04130c09,   // lv.jw.ro_543 lv.sl.pl_322  lv.fr.rw_322 sv.et.fi_444
  0x06210913, 0x31005202, 0x1c215205, 0x1f023f55,   // pl.jw.de_665 ha.az.un_220  ha.jw.id_333 af.da.cy_442
  0x0a170714, 0x3b001c02, 0x4a006812, 0x122d0d0b,   // bg.sr.mk_666 id.so.un_220  ig.yo.un_640 cs.sk.hu_542
  // [3220]
  0x03000121, 0x6b4a1a60, 0x32171b04, 0x2800551a,   // en.nl.un_860 tl.yo.ceb_664  tr.sr.bs_332 rw.sw.un_760
  0x0c000614, 0x1c2a1e07, 0x6b0a010b, 0x6b03010c,   // de.sv.un_660 ms.mt.id_432  en.pt.ceb_542 en.nl.ceb_543
  0x2a004a04, 0x0800020c, 0x285535af, 0x112a2308,   // yo.mt.un_320 da.no.un_530  zu.rw.sw_655 ca.mt.ro_443
  0x0a171105, 0x0c130412, 0x0710080e, 0x06000408,   // ro.sr.mk_333 fi.et.sv_654  uk.be.bg_555 fi.de.un_430
  // [3230]
  0x1f004a04, 0x321e1c04, 0x183f03a0, 0x13000936,   // yo.cy.un_320 id.ms.bs_332  nl.af.ga_322 hi.bh.un_AA0
  0x3b136407, 0x0f001a0c, 0x092d0d07, 0x0f291f08,   // lg.et.so_432 tl.lv.un_530  cs.sk.pl_432 cy.sl.lv_443
  0x0e002b12, 0x09002d1a, 0x643b13a7, 0x27002008,   // vi.is.un_640 sk.pl.un_760  et.so.lg_532 sq.gd.un_430
  0x1c2a210c, 0x0700230e, 0x183b01a0, 0x27001f02,   // jw.mt.id_543 ca.it.un_550  en.so.ga_322 cy.gd.un_220
  // [3240]
  0x1a1f13a9, 0x321721a4, 0x01032704, 0x1f033f09,   // et.cy.tl_544 jw.sr.bs_433  gd.nl.en_332 af.nl.cy_444
  0x6b132da4, 0x13000d08, 0x2100250d, 0x17292d0e,   // sk.et.ceb_433 ne.bh.un_430  eu.jw.un_540 sk.sl.sr_555
  0x1e1a13a4, 0x12001f07, 0x3f172913, 0x01002521,   // et.tl.ms_433 cy.hu.un_420  sl.sr.af_665 eu.en.un_860
  0x281e3bee, 0x1c1f21a4, 0x1b3153af, 0x093f2104,   // so.ms.sw_422 jw.cy.id_433  ht.az.tr_655 jw.af.pl_332
  // [3250]
  0x4a1b17a0, 0x0400030e, 0x1211070c, 0x28311b08,   // sr.tr.yo_322 nl.fi.un_550  it.ro.hu_543 tr.az.sw_443
  0x13006e04, 0x060c0304, 0x065308a7, 0x16060e12,   // hmn.et.un_320 nl.sv.de_332  no.ht.de_532 is.de.hr_654
  0x0d192011, 0x03131fac, 0x3f2a13a4, 0x1a1b535a,   // sq.gl.cs_653 cy.et.nl_632  et.mt.af_433 ht.tr.tl_553
  0x53003521, 0x1b1119ee, 0x052d0912, 0x08001019,   // zu.ht.un_860 gl.ro.tr_422  pl.sk.fr_654 lt.no.un_750
  // [3260]
  0x134a6b04, 0x190b11a0, 0x12003507, 0x311e3b0c,   // ceb.yo.et_332 ro.es.gl_322  zu.hu.un_420 so.ms.az_543
  0x1b00350d, 0x06113ba0, 0x31111ba4, 0x163f0307,   // zu.tr.un_540 so.ro.de_322  tr.ro.az_433 nl.af.hr_432
  0x1b2864ee, 0x3f1a1f11, 0x271e130c, 0x32172daf,   // lg.sw.tr_422 cy.tl.af_653  et.ms.gd_543 sk.sr.bs_655
  0x08350c07, 0x53130107, 0x531b4aee, 0x04005307,   // sv.zu.no_432 en.et.ht_432  yo.tr.ht_422 ht.fi.un_420
  // [3270]
  0x1c0f21a0, 0x190b4a0c, 0x10170a12, 0x1b125307,   // jw.lv.id_322 yo.es.gl_543  mk.sr.be_654 ht.hu.tr_432
  0x12001807, 0x531219a0, 0x1c000107, 0x0a08170c,   // ga.hu.un_420 gl.hu.ht_322  en.id.un_420 sr.uk.mk_543
  0x016b020c, 0x3f005520, 0x551b5304, 0x1b005314,   // da.ceb.en_543 rw.af.un_850  ht.tr.rw_332 ht.tr.un_660
  0x4a190a04, 0x2a180307, 0x080417a9, 0x21003521,   // pt.gl.yo_332 nl.ga.mt_432  sr.ru.uk_544 zu.jw.un_860
  // [3280]
  0x1100250e, 0x17110705, 0x55352813, 0x0a001702,   // eu.ro.un_550 bg.ro.sr_333  sw.zu.rw_665 sr.mk.un_220
  0x0c040614, 0x0d001e04, 0x033f0204, 0x080204a0,   // de.fi.sv_666 ms.cs.un_320  da.af.nl_332 fi.da.no_322
  0x08041014, 0x55006423, 0x080a110c, 0x081103ee,   // be.ru.uk_666 lg.rw.un_880  ro.mk.uk_543 nl.ro.no_422
  0x3f1b0607, 0x07000a07, 0x0b002a04, 0x1800272c,   // de.tr.af_432 mk.bg.un_420  mt.es.un_320 gd.ga.un_990
  // [3290]
  0x211001a0, 0x05271811, 0x2a000705, 0x23000c02,   // en.lt.jw_322 ga.gd.fr_653  it.mt.un_330 sv.ca.un_220
  0x2810010b, 0x2a1106ee, 0x1b2a03ee, 0x102718a4,   // en.lt.sw_542 de.ro.mt_422  nl.mt.tr_422 ga.gd.lt_433
  0x081c1ea9, 0x0a04170e, 0x05001e08, 0x03201b14,   // ms.id.no_544 sr.ru.mk_555  ms.fr.un_430 tr.sq.nl_666
  0x08002a05, 0x1b121ea9, 0x070410a9, 0x28003f14,   // mt.no.un_330 ms.hu.tr_544  be.ru.bg_544 af.sw.un_660
  // [32a0]
  0x1e283f08, 0x3f0e03a9, 0x08070aad, 0x180504ee,   // af.sw.ms_443 nl.is.af_544  mk.bg.uk_643 fi.fr.ga_422
  0x0125050c, 0x3f350311, 0x0c002304, 0x0e000804,   // fr.eu.en_543 nl.zu.af_653  ca.sv.un_320 no.is.un_320
  0x033f01a0, 0x3b2d29ee, 0x041011a9, 0x033f04a0,   // en.af.nl_322 sl.sk.so_422  ro.be.ru_544 fi.af.nl_322
  0x071008a4, 0x06000405, 0x3f0306ec, 0x08002704,   // uk.be.bg_433 fi.de.un_330  de.nl.af_644 gd.no.un_320
  // [32b0]
  0x521b1eee, 0x04000c1b, 0x29091104, 0x0e2d0aa9,   // ms.tr.ha_422 sv.fi.un_770  ro.pl.sl_332 pt.sk.is_544
  0x0a050107, 0x35030a04, 0x1e291cec, 0x13033b04,   // en.fr.pt_432 pt.nl.zu_332  id.sl.ms_644 so.nl.et_332
  0x0705010c, 0x0900290d, 0x111008a4, 0x01000805,   // en.fr.it_543 sl.pl.un_540  uk.be.ro_433 no.en.un_330
  0x21131160, 0x28003b19, 0x3f2706ee, 0x08041304,   // ro.et.jw_664 so.sw.un_750  de.gd.af_422 et.fi.no_332
  // [32c0]
  0x52003b02, 0x03003b0c, 0x3b033f60, 0x1e1c210e,   // so.ha.un_220 so.nl.un_530  af.nl.so_664 jw.id.ms_555
  0x321623a0, 0x06000807, 0x35004a0b, 0x0b000a08,   // ca.hr.bs_322 no.de.un_420  yo.zu.un_520 pt.es.un_430
  0x11000e05, 0x0d001312, 0x050c0811, 0x0e06180d,   // is.ro.un_330 bh.ne.un_640  no.sv.fr_653 ga.de.is_554
  0x1f2718a9, 0x041827ad, 0x23003f07, 0x1300030d,   // ga.gd.cy_544 gd.ga.fi_643  af.ca.un_420 nl.et.un_540
  // [32d0]
  0x4a000c07, 0x13000d13, 0x04001319, 0x17040a05,   // sv.yo.un_420 ne.bh.un_650  et.fi.un_750 mk.ru.sr_333
  0x080411a6, 0x1f2801a7, 0x2301050c, 0x13001107,   // ro.ru.uk_521 en.sw.cy_532  fr.en.ca_543 ro.et.un_420
  0x120e0cad, 0x35002509, 0x05101f0c, 0x4a120e0c,   // sv.is.hu_643 eu.zu.un_440  cy.lt.fr_543 is.hu.yo_543
  0x0e005313, 0x01001f04, 0x3b000c08, 0x0810040e,   // ht.is.un_650 cy.en.un_320  sv.so.un_430 ru.be.uk_555
  // [32e0]
  0x11002a13, 0x0c0802a0, 0x080e1fec, 0x10000419,   // mt.ro.un_650 da.no.sv_322  cy.is.no_644 ru.be.un_750
  0x53190ba7, 0x1f001a13, 0x282b18a0, 0x03050108,   // es.gl.ht_532 tl.cy.un_650  ga.vi.sw_322 en.fr.nl_443
  0x06000104, 0x1f032507, 0x3b002819, 0x21082007,   // en.de.un_320 eu.nl.cy_432  sw.so.un_750 sq.no.jw_432
  0x1c130912, 0x27126b07, 0x0c00130d, 0x6b080204,   // hi.bh.mr_654 ceb.hu.gd_432  et.sv.un_540 da.no.ceb_332
  // [32f0]
  0x32003b08, 0x3f2102a0, 0x1b100cad, 0x352768af,   // so.bs.un_430 da.jw.af_322  sv.lt.tr_643 ig.gd.zu_655
  0x040c0608, 0x0c00041a, 0x090d13a0, 0x0d001c11,   // de.sv.fi_443 fi.sv.un_760  bh.ne.hi_322 mr.ne.un_630
  0x0810040c, 0x27352812, 0x080c0e13, 0x64043505,   // ru.be.uk_543 sw.zu.gd_654  is.sv.no_665 zu.fi.lg_333
  0x203f0313, 0x12006b12, 0x130821a4, 0x121e1c09,   // nl.af.sq_665 ceb.hu.un_640  jw.no.et_433 id.ms.hu_444
  // [3300]
  0x3b55350c, 0x0c0608ec, 0x120e08a0, 0x0413125a,   // zu.rw.so_543 no.de.sv_644  no.is.hu_322 hu.et.fi_553
  0x55006413, 0x131c2104, 0x0f3f0308, 0x07351a07,   // lg.rw.un_650 jw.id.et_332  nl.af.lv_443 tl.zu.it_432
  0x64060e5a, 0x6b3f0355, 0x101711ad, 0x641f120c,   // is.de.lg_553 nl.af.ceb_442  ro.sr.be_643 hu.cy.lg_543
  0x52001a04, 0x1b092da4, 0x18005507, 0x5364120c,   // tl.ha.un_320 sk.pl.tr_433  rw.ga.un_420 hu.lg.ht_543
  // [3310]
  0x071f0213, 0x06000d05, 0x08040307, 0x10321708,   // da.cy.it_665 cs.de.un_330  nl.fi.no_432 sr.bs.lt_443
  0x131a3b14, 0x2d0d3b0e, 0x28043ba9, 0x23001a04,   // so.tl.et_666 so.cs.sk_555  so.fi.sw_544 tl.ca.un_320
  0x060e08a0, 0x643f1aa4, 0x011353a0, 0x041e5205,   // no.is.de_322 tl.af.lg_433  ht.et.en_322 ha.ms.fi_333
  0x1e1c6b09, 0x166b2008, 0x321608ec, 0x0e1304ac,   // ceb.id.ms_444 sq.ceb.hr_443  no.hr.bs_644 fi.et.is_632
  // [3320]
  0x12080209, 0x3b4a64ad, 0x111b2aad, 0x03683b12,   // da.no.hu_444 lg.yo.so_643  mt.tr.ro_643 so.ig.nl_654
  0x08120107, 0x12003b09, 0x641a6b60, 0x1b003b1b,   // en.hu.no_432 so.hu.un_440  ceb.tl.lg_664 so.tr.un_770
  0x190a0805, 0x64003b1a, 0x0d091cad, 0x03061808,   // no.pt.gl_333 so.lg.un_760  mr.hi.ne_643 ga.de.nl_443
  0x64003b19, 0x35001f07, 0x686b0107, 0x1200350d,   // so.lg.un_750 cy.zu.un_420  en.ceb.ig_432 zu.hu.un_540
  // [3330]
  0x0a1008a0, 0x64133b05, 0x043f1aee, 0x170810ee,   // uk.be.mk_322 so.et.lg_333  tl.af.fi_422 be.uk.sr_422
  0x133f0411, 0x0a0710ad, 0x28643b08, 0x033f3ba4,   // fi.af.et_653 be.bg.mk_643  so.lg.sw_443 so.af.nl_433
  0x0a111755, 0x0d1f3102, 0x04000c14, 0x08002a12,   // sr.ro.mk_442 az.cy.cs_222  sv.fi.un_660 mt.no.un_640
  0x283132a0, 0x290d3504, 0x03006e08, 0x04081012,   // bs.az.sw_322 zu.cs.sl_332  hmn.nl.un_430 be.uk.ru_654
  // [3340]
  0x0a081704, 0x0c000608, 0x056e0d04, 0x31003204,   // sr.uk.mk_332 de.sv.un_430  cs.hmn.fr_332 bs.az.un_320
  0x13091c0e, 0x21001821, 0x35002d05, 0x081711af,   // mr.hi.bh_555 ar.fa.un_860  sk.zu.un_330 ro.sr.uk_655
  0x08020309, 0x13201002, 0x080411a7, 0x2164350b,   // nl.da.no_444 lt.sq.et_222  ro.ru.uk_532 zu.lg.jw_542
  0x25190b04, 0x6b250202, 0x0d131c0d, 0x55283509,   // es.gl.eu_332 da.eu.ceb_222  mr.bh.ne_554 zu.sw.rw_444
  // [3350]
  0x131c09a9, 0x55003202, 0x1b000f21, 0x0c131b07,   // hi.mr.bh_544 bs.rw.un_220  lv.tr.un_860 tr.et.sv_432
  0x310910af, 0x040e0c07, 0x170f1ba7, 0x060328a4,   // lt.pl.az_655 sv.is.fi_432  tr.lv.sr_532 sw.nl.de_433
  0x130f1207, 0x21201807, 0x05001b07, 0x6b2001a0,   // hu.lv.et_432 ga.sq.jw_432  tr.fr.un_420 en.sq.ceb_322
  0x02061bee, 0x32200faf, 0x13060707, 0x210f1b11,   // tr.de.da_422 lv.sq.bs_655  it.de.et_432 tr.lv.jw_653
  // [3360]
  0x32001704, 0x3b133f04, 0x53000f08, 0x0e00530e,   // sr.bs.un_320 af.et.so_332  lv.ht.un_430 ht.is.un_550
  0x0e1f250c, 0x1a001c13, 0x23111855, 0x6b1a1ea9,   // eu.cy.is_543 id.tl.un_650  ga.ro.ca_442 ms.tl.ceb_544
  0x13040f08, 0x20001302, 0x040d2055, 0x2a100f12,   // lv.fi.et_443 et.sq.un_220  sq.cs.fi_442 lv.lt.mt_654
  0x680d01a4, 0x25100f13, 0x35006b12, 0x07170a0c,   // en.cs.ig_433 lv.lt.eu_665  ceb.zu.un_640 mk.sr.bg_543
  // [3370]
  0x3f031308, 0x16000804, 0x1b062a07, 0x3f2a28a4,   // et.nl.af_443 no.hr.un_320  mt.de.tr_432 sw.mt.af_433
  0x1f000e1a, 0x230c1aa9, 0x53080eec, 0x1b1e3507,   // is.cy.un_760 tl.sv.ca_544  is.no.ht_644 zu.ms.tr_432
  0x351a5302, 0x04000823, 0x0f13170c, 0x25171b0c,   // ht.tl.zu_222 uk.ru.un_880  sr.et.lv_543 tr.sr.eu_543
  0x533b285a, 0x00002737, 0x116b0f07, 0x131017a0,   // sw.so.ht_553 gd.un.un_B00  lv.ceb.ro_432 sr.lt.et_322
  // [3380]
  0x18005302, 0x6b071aaf, 0x08001b0e, 0x18005307,   // ht.ga.un_220 tl.it.ceb_655  tr.no.un_550 ht.ga.un_420
  0x3b040e04, 0x53000805, 0x040a1755, 0x0c0408ee,   // is.fi.so_332 no.ht.un_330  sr.mk.ru_442 no.fi.sv_422
  0x06003512, 0x190b68a0, 0x11200d0c, 0x08020e0c,   // zu.de.un_640 ig.es.gl_322  cs.sq.ro_543 is.da.no_543
  0x53281b05, 0x100411a0, 0x200c2304, 0x0a002502,   // tr.sw.ht_333 ro.ru.be_322  ca.sv.sq_332 eu.pt.un_220
  // [3390]
  0x64190bad, 0x1a5321a9, 0x05532012, 0x04250fee,   // es.gl.lg_643 jw.ht.tl_544  sq.ht.fr_654 lv.eu.fi_422
  0x6b010655, 0x1120010c, 0x0d6b1aa9, 0x10001107,   // de.en.ceb_442 en.sq.ro_543  tl.ceb.cs_544 ro.be.un_420
  0x06351807, 0x06521b0c, 0x170810a9, 0x353b2808,   // ga.zu.de_432 tr.ha.de_543  be.uk.sr_544 sw.so.zu_443
  0x191a0b0b, 0x1b311007, 0x3500280e, 0x53130c02,   // es.tl.gl_542 lt.az.tr_432  sw.zu.un_550 sv.et.ht_222
  // [33a0]
  0x08070460, 0x5300080e, 0x08170aaf, 0x2a005314,   // ru.bg.uk_664 no.ht.un_550  mk.sr.uk_655 ht.mt.un_660
  0x0e013b04, 0x1e281c0c, 0x55352107, 0x25003113,   // so.en.is_332 id.sw.ms_543  jw.zu.rw_432 az.eu.un_650
  0x0e022507, 0x3b1f1ba0, 0x01001a04, 0x0d2d290b,   // eu.da.is_432 tr.cy.so_322  tl.en.un_320 sl.sk.cs_542
  0x3152280d, 0x3b311aee, 0x29001707, 0x131a28ac,   // sw.ha.az_554 tl.az.so_422  sr.sl.un_420 sw.tl.et_632
  // [33b0]
  0x06000b02, 0x3b1b1a07, 0x03103f07, 0x011b20a4,   // es.de.un_220 tl.tr.so_432  af.lt.nl_432 sq.tr.en_433
  0x12002105, 0x04005502, 0x64001005, 0x013b6bad,   // jw.hu.un_330 rw.fi.un_220  lt.lg.un_330 ceb.so.en_643
  0x192d0b07, 0x13000c08, 0x35000104, 0x351b31af,   // es.sk.gl_432 sv.et.un_430  en.zu.un_320 az.tr.zu_655
  0x3b00311a, 0x1a3b6b0c, 0x10002809, 0x211a6b0c,   // az.so.un_760 ceb.so.tl_543  sw.lt.un_440 ceb.tl.jw_543
  // [33c0]
  0x35131a07, 0x1e1c20a0, 0x10000805, 0x12004a08,   // tl.et.zu_432 sq.id.ms_322  uk.be.un_330 yo.hu.un_430
  0x11000502, 0x0900130b, 0x18002114, 0x21023fa0,   // fr.ro.un_220 bh.hi.un_520  fa.ar.un_660 af.da.jw_322
  0x3f6b1a08, 0x1600100d, 0x0a1117a4, 0x1e001213,   // tl.ceb.af_443 lt.hr.un_540  sr.ro.mk_433 hu.ms.un_650
  0x31000904, 0x0c0806a7, 0x18001221, 0x17102d02,   // pl.az.un_320 de.no.sv_532  ur.ar.un_860 sk.lt.sr_222
  // [33d0]
  0x070a1108, 0x05230b08, 0x4a002522, 0x68002821,   // ro.mk.bg_443 es.ca.fr_443  eu.yo.un_870 sw.ig.un_860
  0x170a11af, 0x0d131cad, 0x08070a12, 0x170d29a0,   // ro.mk.sr_655 mr.bh.ne_643  mk.bg.uk_654 sl.cs.sr_322
  0x1b6468ee, 0x091c13ec, 0x17292d55, 0x3200170c,   // ig.lg.tr_422 bh.mr.hi_644  sk.sl.sr_442 sr.bs.un_530
  0x1c0d090d, 0x05002319, 0x2d321655, 0x0e0208ec,   // hi.ne.mr_554 ca.fr.un_750  hr.bs.sk_442 no.da.is_644
  // [33e0]
  0x230319a0, 0x23000a0e, 0x12000f13, 0x02011207,   // gl.nl.ca_322 pt.ca.un_550  lv.hu.un_650 hu.en.da_432
  0x1a004a04, 0x0c080faf, 0x130604a0, 0x00001203,   // yo.tl.un_320 lv.no.sv_655  fi.de.et_322 ur.un.un_300
  0x01060804, 0x4a2d0d08, 0x12100fa7, 0x6b683107,   // no.de.en_332 cs.sk.yo_443  lv.lt.hu_532 az.ig.ceb_432
  0x351c2a0c, 0x0a001709, 0x20253b07, 0x12003202,   // mt.id.zu_543 sr.mk.un_440  so.eu.sq_432 bs.hu.un_220
  // [33f0]
  0x20351bad, 0x0f0c0807, 0x05003502, 0x18003202,   // tr.zu.sq_643 no.sv.lv_432  zu.fr.un_220 bs.ga.un_220
  0x0f001012, 0x1a0412ee, 0x31283b0c, 0x230b12ad,   // lt.lv.un_640 hu.fi.tl_422  so.sw.az_543 hu.es.ca_643
  0x282a52ee, 0x353b28ad, 0x4a530708, 0x1b0c3ba0,   // ha.mt.sw_422 sw.so.zu_643  it.ht.yo_443 so.sv.tr_322
  0x3b3510a4, 0x17000419, 0x190a2302, 0x1f351bec,   // lt.zu.so_433 ru.sr.un_750  ca.pt.gl_222 tr.zu.cy_644

  // [3400]
  0x0e521bec, 0x18000704, 0x2d1029a4, 0x181b27a4,   // tr.ha.is_644 it.ga.un_320  sl.lt.sk_433 gd.tr.ga_433
  0x120e1304, 0x35642809, 0x06553512, 0x040a0712,   // et.is.hu_332 sw.lg.zu_444  zu.rw.de_654 bg.mk.ru_654
  0x282d3513, 0x1e313504, 0x020e550c, 0x53112a04,   // zu.sk.sw_665 zu.az.ms_332  rw.is.da_543 mt.ro.ht_332
  0x0f002921, 0x35311ba4, 0x050713a0, 0x120b23a4,   // sl.lv.un_860 tr.az.zu_433  et.it.fr_322 ca.es.hu_433
  // [3410]
  0x09000d33, 0x53000707, 0x3f030207, 0x2b0c0611,   // ne.hi.un_A70 it.ht.un_420  da.nl.af_432 de.sv.vi_653
  0x121a0f07, 0x040208ec, 0x1e1c1214, 0x2d00092a,   // lv.tl.hu_432 no.da.fi_644  hu.id.ms_666 pl.sk.un_970
  0x2a003b19, 0x030c3fa0, 0x010c1ba0, 0x0e1e1c04,   // so.mt.un_750 af.sv.nl_322  tr.sv.en_322 id.ms.is_332
  0x2d091fec, 0x210f1211, 0x01270c0c, 0x100504ee,   // cy.pl.sk_644 hu.lv.jw_653  sv.gd.en_543 fi.fr.lt_422
  // [3420]
  0x1c211304, 0x21000519, 0x12001112, 0x100711ee,   // et.jw.id_332 fr.jw.un_750  ro.hu.un_640 ro.bg.be_422
  0x120c0f0c, 0x202a11a9, 0x3113640d, 0x203211a0,   // lv.sv.hu_543 ro.mt.sq_544  lg.et.az_554 ro.bs.sq_322
  0x1b003202, 0x08101709, 0x0c001219, 0x29000d14,   // bs.tr.un_220 sr.be.uk_444  hu.sv.un_750 cs.sl.un_660
  0x033f0604, 0x3b003102, 0x2a033f05, 0x01006b02,   // de.af.nl_332 az.so.un_220  af.nl.mt_333 ceb.en.un_220
  // [3430]
  0x2d000919, 0x170a11a6, 0x28012aa4, 0x121e1c07,   // pl.sk.un_750 ro.mk.sr_521  mt.en.sw_433 id.ms.hu_432
  0x2d091fad, 0x05002309, 0x1e1c2aee, 0x32033fa0,   // cy.pl.sk_643 ca.fr.un_440  mt.id.ms_422 af.nl.bs_322
  0x322d2905, 0x350455a9, 0x12033fa4, 0x07005508,   // sl.sk.bs_333 rw.fi.zu_544  af.nl.hu_433 rw.it.un_430
  0x55001a02, 0x191223a7, 0x1c2a2102, 0x2300070d,   // tl.rw.un_220 ca.hu.gl_532  jw.mt.id_222 it.ca.un_540
  // [3440]
  0x3b1a6bad, 0x06002905, 0x030635a7, 0x28006b08,   // ceb.tl.so_643 sl.de.un_330  zu.de.nl_532 ceb.sw.un_430
  0x211c1ea7, 0x07100a05, 0x0b2301a4, 0x013f0304,   // ms.id.jw_532 mk.be.bg_333  en.ca.es_433 nl.af.en_332
  0x06040c12, 0x093f03a9, 0x04000818, 0x012a0704,   // sv.fi.de_654 nl.af.pl_544  uk.ru.un_740 it.mt.en_332
  0x29025307, 0x10041708, 0x090c0808, 0x081707ee,   // ht.da.sl_432 sr.ru.be_443  no.sv.pl_443 bg.sr.uk_422
  // [3450]
  0x1a356ba4, 0x1a041ea0, 0x162d29a0, 0x0d00290e,   // ceb.zu.tl_433 ms.fi.tl_322  sl.sk.hr_322 sl.cs.un_550
  0x55002704, 0x2164280c, 0x070804a9, 0x070411ec,   // gd.rw.un_320 sw.lg.jw_543  ru.uk.bg_544 ro.ru.bg_644
  0x356864ec, 0x0e000208, 0x08041009, 0x08000f05,   // lg.ig.zu_644 da.is.un_430  be.ru.uk_444 lv.no.un_330
  0x64253513, 0x0c001f2b, 0x10081105, 0x3f001e04,   // zu.eu.lg_665 cy.sv.un_980  ro.uk.be_333 ms.af.un_320
  // [3460]
  0x110708a4, 0x20250807, 0x162a2d07, 0x073f010c,   // uk.bg.ro_433 no.eu.sq_432  sk.mt.hr_432 en.af.it_543
  0x251819a0, 0x531907af, 0x1c211ea0, 0x23055312,   // gl.ga.eu_322 it.gl.ht_655  ms.jw.id_322 ht.fr.ca_654
  0x190b070e, 0x07000d0d, 0x1b27530b, 0x202b5304,   // it.es.gl_555 cs.it.un_540  ht.gd.tr_542 ht.vi.sq_332
  0x531e0307, 0x19283555, 0x00005337, 0x04003b08,   // nl.ms.ht_432 zu.sw.gl_442  ht.un.un_B00 so.fi.un_430
  // [3470]
  0x0e182712, 0x08101105, 0x292d0d09, 0x200b2704,   // gd.ga.is_654 ro.be.uk_333  cs.sk.sl_444 gd.es.sq_332
  0x112701ee, 0x11130107, 0x11001f05, 0x0000062d,   // en.gd.ro_422 en.et.ro_432  cy.ro.un_330 de.un.un_A00
  0x35000c02, 0x10003b14, 0x4a000113, 0x3f31050c,   // sv.zu.un_220 so.lt.un_660  en.yo.un_650 fr.az.af_543
  0x10000f11, 0x03180613, 0x0c000413, 0x100f1602,   // lv.lt.un_630 de.ga.nl_665  fi.sv.un_650 hr.lv.lt_222
  // [3480]
  0x526455ee, 0x1f3b0413, 0x1b552155, 0x1a553513,   // rw.lg.ha_422 fi.so.cy_665  jw.rw.tr_442 zu.rw.tl_665
  0x070168a0, 0x6b1b53a4, 0x0718270c, 0x6b1b1a11,   // ig.en.it_322 ht.tr.ceb_433  gd.ga.it_543 tl.tr.ceb_653
  0x2d100da4, 0x1127180e, 0x55003519, 0x351b5505,   // cs.lt.sk_433 ga.gd.ro_555  zu.rw.un_750 rw.tr.zu_333
  0x10002911, 0x12006e04, 0x130f12af, 0x080204ee,   // sl.lt.un_630 hmn.hu.un_320  hu.lv.et_655 fi.da.no_422
  // [3490]
  0x08040aad, 0x53003519, 0x1a1b5304, 0x0612080b,   // mk.ru.uk_643 zu.ht.un_750  ht.tr.tl_332 no.hu.de_542
  0x6b012ba0, 0x130825ad, 0x170a080c, 0x6827185a,   // vi.en.ceb_322 eu.no.et_643  uk.mk.sr_543 ga.gd.ig_553
  0x212320ac, 0x553521af, 0x1b2035ee, 0x111e0707,   // sq.ca.jw_632 jw.zu.rw_655  zu.sq.tr_422 it.ms.ro_432
  0x23001216, 0x1c0d0911, 0x040a170c, 0x090d1c5a,   // hu.ca.un_720 hi.ne.mr_653  sr.mk.ru_543 mr.ne.hi_553
  // [34a0]
  0x3f1b2512, 0x1e523b04, 0x19311bee, 0x1b1e1c08,   // eu.tr.af_654 so.ha.ms_332  tr.az.gl_422 id.ms.tr_443
  0x17042a07, 0x07005308, 0x100b1912, 0x4a2112a7,   // mt.fi.sr_432 ht.it.un_430  gl.es.lt_654 hu.jw.yo_532
  0x0e032daf, 0x6e000f08, 0x3b001a07, 0x120655a4,   // sk.nl.is_655 lv.hmn.un_430  tl.so.un_420 rw.de.hu_433
  0x1e1c210c, 0x13160da4, 0x08041307, 0x0c0d2912,   // jw.id.ms_543 cs.hr.et_433  et.fi.no_432 sl.cs.sv_654
  // [34b0]
  0x3b006b08, 0x0b23110c, 0x35001a0c, 0x06033f0d,   // ceb.so.un_430 ro.ca.es_543  tl.zu.un_530 af.nl.de_554
  0x1e13200c, 0x3f181f0d, 0x2d002302, 0x55200f0c,   // sq.et.ms_543 cy.ga.af_554  ca.sk.un_220 lv.sq.rw_543
  0x3b551b60, 0x53003b0c, 0x351a6b13, 0x01003b04,   // tr.rw.so_664 so.ht.un_530  ceb.tl.zu_665 so.en.un_320
  0x52001305, 0x64001b19, 0x0c0325ee, 0x1e1c55ee,   // et.ha.un_330 tr.lg.un_750  eu.nl.sv_422 rw.id.ms_422
  // [34c0]
  0x052101a4, 0x28556b12, 0x1a6b5555, 0x19100bec,   // en.jw.fr_433 ceb.rw.sw_654  rw.ceb.tl_442 es.lt.gl_644
  0x0f190b0d, 0x19050ba0, 0x2700020c, 0x171325ee,   // es.gl.lv_554 es.fr.gl_322  da.gd.un_530 eu.et.sr_422
  0x02033f0e, 0x0e000213, 0x07100409, 0x020c08a4,   // af.nl.da_555 da.is.un_650  ru.be.bg_444 no.sv.da_433
  0x18000514, 0x525528af, 0x190a0f0e, 0x13312105,   // fr.ga.un_660 sw.rw.ha_655  lv.pt.gl_555 jw.az.et_333
  // [34d0]
  0x06033fec, 0x6b1e1c0d, 0x23000104, 0x4a135507,   // af.nl.de_644 id.ms.ceb_554  en.ca.un_320 rw.et.yo_432
  0x281e1102, 0x030e3f04, 0x081a6bad, 0x0500530e,   // ro.ms.sw_222 af.is.nl_332  ceb.tl.no_643 ht.fr.un_550
  0x130d0912, 0x35003205, 0x0e000212, 0x553513a7,   // hi.ne.bh_654 bs.zu.un_330  da.is.un_640 et.zu.rw_532
  0x17100a13, 0x6b000e13, 0x0e003511, 0x07000a0c,   // mk.be.sr_665 is.ceb.un_650  zu.is.un_630 mk.bg.un_530
  // [34e0]
  0x25092da0, 0x6b001a2b, 0x02000e19, 0x02001a12,   // sk.pl.eu_322 tl.ceb.un_980  is.da.un_750 tl.da.un_640
  0x06643509, 0x2b005307, 0x071004a9, 0x03006b05,   // zu.lg.de_444 ht.vi.un_420  ru.be.bg_544 ceb.nl.un_330
  0x0e020c55, 0x55000605, 0x212a28a4, 0x05000304,   // sv.da.is_442 de.rw.un_330  sw.mt.jw_433 nl.fr.un_320
  0x23002b04, 0x101711ee, 0x27011f07, 0x11000a0c,   // vi.ca.un_320 ro.sr.be_422  cy.en.gd_432 pt.ro.un_530
  // [34f0]
  0x64285555, 0x126e6b04, 0x35060913, 0x23190a09,   // rw.sw.lg_442 ceb.hmn.hu_332  pl.de.zu_665 pt.gl.ca_444
  0x23011b0c, 0x043f0304, 0x19002d0d, 0x01000921,   // tr.en.ca_543 nl.af.fi_332  sk.gl.un_540 pl.en.un_860
  0x04080714, 0x0a12195a, 0x2b006e08, 0x07002305,   // bg.uk.ru_666 gl.hu.pt_553  hmn.vi.un_430 ca.it.un_330
  0x11170a08, 0x1c001312, 0x0c00060e, 0x0d0935a7,   // mk.sr.ro_443 bh.mr.un_640  de.sv.un_550 zu.pl.cs_532
  // [3500]
  0x03001004, 0x19521a0d, 0x0c080260, 0x06030f07,   // lt.nl.un_320 tl.ha.gl_554  da.no.sv_664 lv.nl.de_432
  0x051a0109, 0x080e03ad, 0x28004a13, 0x0d006814,   // en.tl.fr_444 nl.is.no_643  yo.sw.un_650 ig.cs.un_660
  0x315528a4, 0x20285304, 0x0f001709, 0x0205010c,   // sw.rw.az_433 ht.sw.sq_332  sr.lv.un_440 en.fr.da_543
  0x3b3564af, 0x324a5508, 0x2d0d4aa6, 0x0c0a0809,   // lg.zu.so_655 rw.yo.bs_443  yo.cs.sk_521 no.pt.sv_444
  // [3510]
  0x0a002108, 0x11002308, 0x0a00010c, 0x550128a4,   // jw.pt.un_430 ca.ro.un_430  en.pt.un_530 sw.en.rw_433
  0x0c000621, 0x025508af, 0x13091c0c, 0x350255af,   // de.sv.un_860 no.rw.da_655  mr.hi.bh_543 rw.da.zu_655
  0x190b070c, 0x0408070e, 0x291e1ca0, 0x23000707,   // it.es.gl_543 bg.uk.ru_555  id.ms.sl_322 it.ca.un_420
  0x19002d08, 0x6800110e, 0x190b18ec, 0x020c08ee,   // sk.gl.un_430 ro.ig.un_550  ga.es.gl_644 no.sv.da_422
  // [3520]
  0x31213ba9, 0x01001904, 0x3200170d, 0x050a3b04,   // so.jw.az_544 gl.en.un_320  sr.bs.un_540 so.pt.fr_332
  0x1a53010c, 0x0c06030c, 0x1055010c, 0x1c003105,   // en.ht.tl_543 nl.de.sv_543  en.rw.lt_543 az.id.un_330
  0x17110808, 0x0a005519, 0x6455050b, 0x234a050b,   // uk.ro.sr_443 rw.pt.un_750  fr.rw.lg_542 fr.yo.ca_542
  0x23004a0d, 0x2d0a4aa0, 0x64030607, 0x550c025a,   // yo.ca.un_540 yo.pt.sk_322  de.nl.lg_432 da.sv.rw_553
  // [3530]
  0x12000305, 0x0b001919, 0x23004a12, 0x3b040ea0,   // nl.hu.un_330 gl.es.un_750  yo.ca.un_640 is.fi.so_322
  0x283b35ad, 0x4a000708, 0x190b0aa0, 0x026b01ee,   // zu.so.sw_643 it.yo.un_430  pt.es.gl_322 en.ceb.da_422
  0x1300030c, 0x23190ba7, 0x05002105, 0x08005304,   // nl.et.un_530 es.gl.ca_532  jw.fr.un_330 ht.no.un_320
  0x103f010b, 0x05006e04, 0x1b001e08, 0x061a3f08,   // en.af.lt_542 hmn.fr.un_320  ms.tr.un_430 af.tl.de_443
  // [3540]
  0x08132a0e, 0x072b23a0, 0x1c0d1302, 0x2a000723,   // mt.et.no_555 ca.vi.it_322  bh.ne.mr_222 it.mt.un_880
  0x07002322, 0x23004a13, 0x10000713, 0x01060c0c,   // ca.it.un_870 yo.ca.un_650  bg.be.un_650 sv.de.en_543
  0x31041b21, 0x04170705, 0x3b000a12, 0x04131014,   // tr.fi.az_876 bg.sr.ru_333  pt.so.un_640 lt.et.fi_666
  0x08000304, 0x25002a02, 0x08020eec, 0x126b1a60,   // nl.no.un_320 mt.eu.un_220  is.da.no_644 tl.ceb.hu_664
  // [3550]
  0x3f060c14, 0x0a000616, 0x1c0e2102, 0x100c1307,   // sv.de.af_666 de.pt.un_720  jw.is.id_222 et.sv.lt_432
  0x0c251e0c, 0x08003f09, 0x11000405, 0x0e060ca9,   // ms.eu.sv_543 af.no.un_440  ru.ro.un_330 sv.de.is_544
  0x03290fad, 0x13091c05, 0x0a1708a9, 0x110a17a4,   // lv.sl.nl_643 mr.hi.bh_333  uk.sr.mk_544 sr.mk.ro_433
  0x17081105, 0x033f0807, 0x1f033fee, 0x29033fa4,   // ro.uk.sr_333 no.af.nl_432  af.nl.cy_422 af.nl.sl_433
  // [3560]
  0x13003b05, 0x32002911, 0x1b0910a6, 0x10001f14,   // so.et.un_330 sl.bs.un_630  lt.pl.tr_521 cy.lt.un_660
  0x08033f05, 0x6428550c, 0x1004110c, 0x6b033f05,   // af.nl.no_333 rw.sw.lg_543  ro.ru.be_543 af.nl.ceb_333
  0x1c062107, 0x1e061ca4, 0x35646813, 0x04002502,   // jw.de.id_432 id.de.ms_433  ig.lg.zu_665 eu.fi.un_220
  0x256404a4, 0x2564040c, 0x2864680c, 0x13000e11,   // fi.lg.eu_433 fi.lg.eu_543  ig.lg.sw_543 is.et.un_630
  // [3570]
  0x3f351b0e, 0x18001e02, 0x12001f04, 0x531827ad,   // tr.zu.af_555 ms.ga.un_220  cy.hu.un_320 gd.ga.ht_643
  0x070a1713, 0x1c033ba0, 0x21521eee, 0x2d100d14,   // sr.mk.bg_665 so.nl.id_322  ms.ha.jw_422 cs.lt.sk_666
  0x27003f07, 0x2a031a07, 0x083521a4, 0x35000a0d,   // af.gd.un_420 tl.nl.mt_432  jw.zu.no_433 pt.zu.un_540
  0x28006412, 0x2d121aa0, 0x3f136404, 0x033f06ad,   // lg.sw.un_640 tl.hu.sk_322  lg.et.af_332 de.af.nl_643
  // [3580]
  0x03643f12, 0x12003504, 0x1200131a, 0x213568ee,   // af.lg.nl_654 zu.hu.un_320  et.hu.un_760 ig.zu.jw_422
  0x3b3f030c, 0x04006407, 0x040e060c, 0x290c5307,   // nl.af.so_543 lg.fi.un_420  de.is.fi_543 ht.sv.sl_432
  0x11231e07, 0x0400280c, 0x0264680c, 0x68526413,   // ms.ca.ro_432 sw.fi.un_530  ig.lg.da_543 lg.ha.ig_665
  0x04002805, 0x20130807, 0x311b110d, 0x130e0ca4,   // sw.fi.un_330 no.et.sq_432  ro.tr.az_554 sv.is.et_433
  // [3590]
  0x1c002502, 0x08026eee, 0x13106e07, 0x0b2501a0,   // eu.id.un_220 hmn.da.no_422  hmn.lt.et_432 en.eu.es_322
  0x230b01a4, 0x01006e05, 0x19251f07, 0x52352812,   // en.es.ca_433 hmn.en.un_330  cy.eu.gl_432 sw.zu.ha_654
  0x6e080209, 0x190b2505, 0x25005220, 0x190b25a6,   // da.no.hmn_444 eu.es.gl_333  ha.eu.un_850 eu.es.gl_521
  0x64552813, 0x10000f22, 0x17100412, 0x170f3204,   // sw.rw.lg_665 lv.lt.un_870  ru.be.sr_654 bs.lv.sr_332
  // [35a0]
  0x08033fa0, 0x07006e09, 0x28006421, 0x31111baf,   // af.nl.no_322 hmn.it.un_440  lg.sw.un_860 tr.ro.az_655
  0x09290f0c, 0x03063faf, 0x4a005322, 0x352555a9,   // lv.sl.pl_543 af.de.nl_655  ht.yo.un_870 rw.eu.zu_544
  0x08041112, 0x0600071a, 0x531e1c05, 0x3f0c0302,   // ro.ru.uk_654 it.de.un_760  id.ms.ht_333 nl.sv.af_222
  0x12001814, 0x1f2301a4, 0x0f103202, 0x0a070411,   // ga.hu.un_660 en.ca.cy_433  bs.lt.lv_222 ru.bg.mk_653
  // [35b0]
  0x10002907, 0x3f016402, 0x16062508, 0x0c006e0c,   // sl.lt.un_420 lg.en.af_222  eu.de.hr_443 hmn.sv.un_530
  0x2b006e0e, 0x162d0d0d, 0x03000c08, 0x19060bee,   // hmn.vi.un_550 cs.sk.hr_554  sv.nl.un_430 es.de.gl_422
  0x3f036eee, 0x050b07ee, 0x2d0d0ea4, 0x16001702,   // hmn.nl.af_422 it.es.fr_422  is.cs.sk_433 sr.hr.un_220
  0x0d003f0c, 0x53645555, 0x4a00531a, 0x2118120b,   // af.cs.un_530 rw.lg.ht_442  ht.yo.un_760 ur.ar.fa_542
  // [35c0]
  0x1b002809, 0x17070aa0, 0x3b2d0d05, 0x25001b05,   // sw.tr.un_440 mk.bg.sr_322  cs.sk.so_333 tr.eu.un_330
  0x53004a19, 0x3b530404, 0x4a005313, 0x07534a5a,   // yo.ht.un_750 fi.ht.so_332  ht.yo.un_650 yo.ht.it_553
  0x08000712, 0x2d190b5a, 0x0a100704, 0x2b000602,   // bg.uk.un_640 es.gl.sk_553  bg.be.mk_332 de.vi.un_220
  0x120c0107, 0x120420ac, 0x3f0c0313, 0x192d0bec,   // en.sv.hu_432 sq.fi.hu_632  nl.sv.af_665 es.sk.gl_644
  // [35d0]
  0x190e0a0c, 0x321620ee, 0x19000b36, 0x10000820,   // pt.is.gl_543 sq.hr.bs_422  es.gl.un_AA0 uk.be.un_850
  0x5306020e, 0x19120b04, 0x5300010d, 0x113528a0,   // da.de.ht_555 es.hu.gl_332  en.ht.un_540 sw.zu.ro_322
  0x11283511, 0x31002919, 0x4a2821a0, 0x05003208,   // zu.sw.ro_653 sl.az.un_750  jw.sw.yo_322 bs.fr.un_430
  0x21231ca9, 0x07005502, 0x35121104, 0x1b682513,   // id.ca.jw_544 rw.it.un_220  ro.hu.zu_332 eu.ig.tr_665
  // [35e0]
  0x55006421, 0x642809a4, 0x09282107, 0x2d00120d,   // lg.rw.un_860 pl.sw.lg_433  jw.sw.pl_432 hu.sk.un_540
  0x35314a07, 0x6b121007, 0x203564ac, 0x12000f18,   // yo.az.zu_432 lt.hu.ceb_432  lg.zu.sq_632 lv.hu.un_740
  0x111025a0, 0x3b020c0c, 0x16251aa0, 0x3b352107,   // eu.lt.ro_322 sv.da.so_543  tl.eu.hr_322 jw.zu.so_432
  0x23190bee, 0x060d35a4, 0x20002513, 0x09006413,   // es.gl.ca_422 zu.cs.de_433  eu.sq.un_650 lg.pl.un_650
  // [35f0]
  0x552804a4, 0x5521285a, 0x68005513, 0x21106ba4,   // fi.sw.rw_433 sw.jw.rw_553  rw.ig.un_650 ceb.lt.jw_433
  0x17080aa7, 0x556428af, 0x09253511, 0x5511280c,   // mk.uk.sr_532 sw.lg.rw_655  zu.eu.pl_653 sw.ro.rw_543
  0x1b00312b, 0x642555a9, 0x3564280d, 0x11003512,   // az.tr.un_980 rw.eu.lg_544  sw.lg.zu_554 zu.ro.un_640
  0x11126807, 0x02000314, 0x64552812, 0x07005305,   // ig.hu.ro_432 nl.da.un_660  sw.rw.lg_654 ht.it.un_330
  // [3600]
  0x20002104, 0x35285504, 0x1004080c, 0x2900101a,   // jw.sq.un_320 rw.sw.zu_332  uk.ru.be_543 lt.sl.un_760
  0x27063ba0, 0x4a0964a9, 0x3b001a05, 0x0f130408,   // so.de.gd_322 lg.pl.yo_544  tl.so.un_330 fi.et.lv_443
  0x0955290c, 0x230511af, 0x68162da4, 0x32102907,   // sl.rw.pl_543 ro.fr.ca_655  sk.hr.ig_433 sl.lt.bs_432
  0x031f0604, 0x321610a4, 0x093f2da4, 0x553528a0,   // de.cy.nl_332 lt.hr.bs_433  sk.af.pl_433 sw.zu.rw_322
  // [3610]
  0x20001008, 0x04000108, 0x17000414, 0x0d1c09a7,   // lt.sq.un_430 en.fi.un_430  ru.sr.un_660 hi.mr.ne_532
  0x010435a0, 0x281853ee, 0x29001019, 0x08170a55,   // zu.fi.en_322 ht.ga.sw_422  lt.sl.un_750 mk.sr.uk_442
  0x2d001814, 0x2b641cee, 0x230701a0, 0x10111fee,   // ga.sk.un_660 id.lg.vi_422  en.it.ca_322 cy.ro.lt_422
  0x09291604, 0x0700230d, 0x1c003b02, 0x19002a02,   // hr.sl.pl_332 ca.it.un_540  so.id.un_220 mt.gl.un_220
  // [3620]
  0x53002804, 0x1004170d, 0x011f0b12, 0x641e1c0d,   // sw.ht.un_320 sr.ru.be_554  es.cy.en_654 id.ms.lg_554
  0x3200090c, 0x23001112, 0x5364280c, 0x1c0e10ad,   // pl.bs.un_530 ro.ca.un_640  sw.lg.ht_543 lt.is.id_643
  0x28001a07, 0x01002434, 0x070f01ee, 0x03061ca4,   // tl.sw.un_420 yi.iw.un_A80  en.lv.it_422 id.de.nl_433
  0x2d171602, 0x032b3f07, 0x04131004, 0x070811a0,   // hr.sr.sk_222 af.vi.nl_432  lt.et.fi_332 ro.uk.bg_322
  // [3630]
  0x3b646b0b, 0x2a000204, 0x06002a05, 0x3b1e1c05,   // ceb.lg.so_542 da.mt.un_320  mt.de.un_330 id.ms.so_333
  0x64003b12, 0x2d002804, 0x0e043504, 0x23006408,   // so.lg.un_640 sw.sk.un_320  zu.fi.is_332 lg.ca.un_430
  0x040721a9, 0x1a1e1c07, 0x282718ad, 0x1e041307,   // jw.it.fi_544 id.ms.tl_432  ga.gd.sw_643 et.fi.ms_432
  0x3b006402, 0x041a6b08, 0x04001f18, 0x21041309,   // lg.so.un_220 ceb.tl.fi_443  cy.fi.un_740 et.fi.jw_444
  // [3640]
  0x4a000e0c, 0x01040ea0, 0x1a006b0c, 0x2000120e,   // is.yo.un_530 is.fi.en_322  ceb.tl.un_530 hu.sq.un_550
  0x21006b02, 0x3b6b1a08, 0x03051105, 0x2d000a04,   // ceb.jw.un_220 tl.ceb.so_443  ro.fr.nl_333 pt.sk.un_320
  0x28211ca0, 0x553f1105, 0x0700042b, 0x0e0401a0,   // id.jw.sw_322 ro.af.rw_333  ru.bg.un_980 en.fi.is_322
  0x0a04070d, 0x063f23a0, 0x1c645512, 0x2d0f110c,   // bg.ru.mk_554 ca.af.de_322  rw.lg.id_654 ro.lv.sk_543
  // [3650]
  0x040f2aa6, 0x08060208, 0x28555207, 0x1c001e0d,   // mt.lv.fi_521 da.de.no_443  ha.rw.sw_432 ms.id.un_540
  0x52001102, 0x25000412, 0x1c641e0c, 0x0f002105,   // ro.ha.un_220 fi.eu.un_640  ms.lg.id_543 jw.lv.un_330
  0x011311ad, 0x061c1e12, 0x29001e08, 0x0f5511ad,   // ro.et.en_643 ms.id.de_654  ms.sl.un_430 ro.rw.lv_643
  0x2d12110c, 0x4a11020b, 0x23001707, 0x0300060e,   // ro.hu.sk_543 da.ro.yo_542  sr.ca.un_420 de.nl.un_550
  // [3660]
  0x1e002a04, 0x12000408, 0x64002512, 0x552864ad,   // mt.ms.un_320 fi.hu.un_430  eu.lg.un_640 lg.sw.rw_643
  0x1b645513, 0x311e1c08, 0x2b521807, 0x1200030d,   // rw.lg.tr_665 id.ms.az_443  ga.ha.vi_432 nl.hu.un_540
  0x3b6864a0, 0x29551e0d, 0x10321704, 0x550711af,   // lg.ig.so_322 ms.rw.sl_554  sr.bs.lt_332 ro.it.rw_655
  0x21001c05, 0x08206ba0, 0x231120a4, 0x0c05010c,   // id.jw.un_330 ceb.sq.no_322  sq.ro.ca_433 en.fr.sv_543
  // [3670]
  0x4a121902, 0x04100807, 0x060e1713, 0x5500211a,   // gl.hu.yo_222 uk.be.ru_432  sr.is.de_665 jw.rw.un_760
  0x213f6ba0, 0x0e003204, 0x25000414, 0x1104170c,   // ceb.af.jw_322 bs.is.un_320  fi.eu.un_660 sr.ru.ro_543
  0x1e001b05, 0x2a3120a7, 0x1a001212, 0x06521107,   // tr.ms.un_330 sq.az.mt_532  hu.tl.un_640 ro.ha.de_432
  0x081a0c02, 0x2a2852ad, 0x55281aa4, 0x532128a7,   // sv.tl.no_222 ha.sw.mt_643  tl.sw.rw_433 sw.jw.ht_532
  // [3680]
  0x1f001814, 0x0e4a120c, 0x03000621, 0x55006412,   // ga.cy.un_660 hu.yo.is_543  de.nl.un_860 lg.rw.un_640
  0x350f1fa7, 0x55211c02, 0x35171bee, 0x201232af,   // cy.lv.zu_532 id.jw.rw_222  tr.sr.zu_422 bs.hu.sq_655
  0x6421200c, 0x046425ad, 0x13351e02, 0x23004a05,   // sq.jw.lg_543 eu.lg.fi_643  ms.zu.et_222 yo.ca.un_330
  0x2100200c, 0x19001f19, 0x281b64a4, 0x1f006421,   // sq.jw.un_530 cy.gl.un_750  lg.tr.sw_433 lg.cy.un_860
  // [3690]
  0x2d0c53a7, 0x53000a09, 0x29002d05, 0x18006b07,   // ht.sv.sk_532 pt.ht.un_440  sk.sl.un_330 ceb.ga.un_420
  0x25000304, 0x2b1e1c04, 0x020c08ec, 0x2500030d,   // nl.eu.un_320 id.ms.vi_332  no.sv.da_644 nl.eu.un_540
  0x4a000804, 0x2000320d, 0x530601ad, 0x1c1e1a07,   // no.yo.un_320 bs.sq.un_540  en.de.ht_643 tl.ms.id_432
  0x23001219, 0x255321ad, 0x522753ec, 0x1c000e04,   // hu.ca.un_750 jw.ht.eu_643  ht.gd.ha_644 is.id.un_320
  // [36a0]
  0x3b033f14, 0x52122ba9, 0x0a00190d, 0x2a1e1c12,   // af.nl.so_666 vi.hu.ha_544  gl.pt.un_540 id.ms.mt_654
  0x0000161c, 0x2706250c, 0x52536404, 0x2b230107,   // hr.un.un_800 eu.de.gd_543  lg.ht.ha_332 en.ca.vi_432
  0x095231a7, 0x230b1207, 0x1c0f1fa9, 0x6b073b07,   // az.ha.pl_532 hu.es.ca_432  cy.lv.id_544 so.it.ceb_432
  0x21001c14, 0x25002d13, 0x532552af, 0x4a1a52ec,   // id.jw.un_660 sk.eu.un_650  ha.eu.ht_655 ha.tl.yo_644
  // [36b0]
  0x23000910, 0x25193107, 0x022d17a4, 0x521f4aaf,   // pl.ca.un_620 az.gl.eu_432  sr.sk.da_433 yo.cy.ha_655
  0x270355ee, 0x0e060305, 0x6b1f01a0, 0x1627010c,   // rw.nl.gd_422 nl.de.is_333  en.cy.ceb_322 en.gd.hr_543
  0x20003112, 0x123f0360, 0x52531e04, 0x2a5301a0,   // az.sq.un_640 nl.af.hu_664  ms.ht.ha_332 en.ht.mt_322
  0x1c1827ee, 0x0a2705a0, 0x1b000619, 0x08001004,   // gd.ga.id_422 fr.gd.pt_322  de.tr.un_750 be.uk.un_320
  // [36c0]
  0x29321fa0, 0x3f1b1e14, 0x18001211, 0x1b001a14,   // cy.bs.sl_322 ms.tr.af_666  ur.ar.un_630 tl.tr.un_660
  0x1f1803ee, 0x0a000813, 0x1e1c1ba4, 0x2b1c2107,   // nl.ga.cy_422 uk.mk.un_650  tr.id.ms_433 jw.id.vi_432
  0x13101ba4, 0x04170709, 0x05111002, 0x281b64a7,   // tr.lt.et_433 bg.sr.ru_444  lt.ro.fr_222 lg.tr.sw_532
  0x1e005204, 0x10171104, 0x55000a12, 0x31003205,   // ha.ms.un_320 ro.sr.be_332  pt.rw.un_640 bs.az.un_330
  // [36d0]
  0x07001a02, 0x130208a4, 0x02100609, 0x0e081f12,   // tl.it.un_220 no.da.et_433  de.lt.da_444 cy.no.is_654
  0x28002007, 0x2a006b19, 0x07000e07, 0x1c002508,   // sq.sw.un_420 ceb.mt.un_750  is.it.un_420 eu.id.un_430
  0x6400350c, 0x0c0225a7, 0x2b003204, 0x2b000304,   // zu.lg.un_530 eu.da.sv_532  bs.vi.un_320 nl.vi.un_320
  0x321b0e0c, 0x28001308, 0x0e271860, 0x08201b07,   // is.tr.bs_543 et.sw.un_430  ga.gd.is_664 tr.sq.no_432
  // [36e0]
  0x0b0105a7, 0x2a091b07, 0x0e000308, 0x1e1a1b55,   // fr.en.es_532 tr.pl.mt_432  nl.is.un_430 tr.tl.ms_442
  0x2b00350c, 0x063f0e04, 0x170411a0, 0x0500230e,   // zu.vi.un_530 is.af.de_332  ro.ru.sr_322 ca.fr.un_550
  0x27185305, 0x11040a05, 0x0e001305, 0x020c1fa4,   // ht.ga.gd_333 mk.ru.ro_333  et.is.un_330 cy.sv.da_433
  0x6e011107, 0x11000708, 0x0c0e53ad, 0x060e180c,   // ro.en.hmn_432 it.ro.un_430  ht.is.sv_643 ga.is.de_543
  // [36f0]
  0x130a0855, 0x19182802, 0x070a040e, 0x0f1f130c,   // no.pt.et_442 sw.ga.gl_222  ru.mk.bg_555 et.cy.lv_543
  0x271853af, 0x01522802, 0x12002519, 0x08090e07,   // ht.ga.gd_655 sw.ha.en_222  eu.hu.un_750 is.pl.no_432
  0x100c2aa7, 0x271f0e0c, 0x19002309, 0x182708a4,   // mt.sv.lt_532 is.cy.gd_543  ca.gl.un_440 no.gd.ga_433
  0x18030605, 0x27190b07, 0x23190a02, 0x0e27250c,   // de.nl.ga_333 es.gl.gd_432  pt.gl.ca_222 eu.gd.is_543
  // [3700]
  0x0600030e, 0x550120ee, 0x080c53af, 0x0a0407a9,   // nl.de.un_550 sq.en.rw_422  ht.sv.no_655 bg.ru.mk_544
  0x53000612, 0x180e53a4, 0x0c001f02, 0x182753ec,   // de.ht.un_640 ht.is.ga_433  cy.sv.un_220 ht.gd.ga_644
  0x0b0c01a0, 0x0818530b, 0x0c185307, 0x13180407,   // en.sv.es_322 ht.ga.no_542  ht.ga.sv_432 fi.ga.et_432
  0x1f270807, 0x040711a7, 0x271018ad, 0x083f0308,   // no.gd.cy_432 ro.bg.ru_532  ga.lt.gd_643 nl.af.no_443
  // [3710]
  0x6b213512, 0x52030607, 0x1318060c, 0x074a2107,   // zu.jw.ceb_654 de.nl.ha_432  de.ga.et_543 jw.yo.it_432
  0x3f001305, 0x0a1707af, 0x0420080c, 0x35070b07,   // et.af.un_330 bg.sr.mk_655  no.sq.fi_543 es.it.zu_432
  0x3b190bad, 0x07100aa4, 0x10005307, 0x1b201312,   // es.gl.so_643 mk.be.bg_433  ht.lt.un_420 et.sq.tr_654
  0x64211aa7, 0x0f001907, 0x0d6b0e07, 0x081004a4,   // tl.jw.lg_532 gl.lv.un_420  is.ceb.cs_432 ru.be.uk_433
  // [3720]
  0x18000912, 0x131a6b12, 0x0e001f18, 0x321729a0,   // pl.ga.un_640 ceb.tl.et_654  cy.is.un_740 sl.sr.bs_322
  0x0e3f1e02, 0x11532aec, 0x23051355, 0x17163ba0,   // ms.af.is_222 mt.ht.ro_644  et.fr.ca_442 so.hr.sr_322
  0x3b001b0e, 0x0b0a1ea0, 0x07170404, 0x083b2a55,   // tr.so.un_550 ms.pt.es_322  ru.sr.bg_332 mt.so.no_442
  0x1a6b210c, 0x17000a21, 0x0a00170c, 0x27000104,   // jw.ceb.tl_543 mk.sr.un_860  sr.mk.un_530 en.gd.un_320
  // [3730]
  0x64006b19, 0x1f030e55, 0x070408ee, 0x2d0d13a0,   // ceb.lg.un_750 is.nl.cy_442  uk.ru.bg_422 et.cs.sk_322
  0x1e211ca4, 0x13001a0c, 0x10211ca4, 0x06130c04,   // id.jw.ms_433 tl.et.un_530  id.jw.lt_433 sv.et.de_332
  0x32160eee, 0x1704080d, 0x08132aa9, 0x1e1c2104,   // is.hr.bs_422 uk.ru.sr_554  mt.et.no_544 jw.id.ms_332
  0x033f04ec, 0x311e1b05, 0x180705a0, 0x2d003f13,   // fi.af.nl_644 tr.ms.az_333  fr.it.ga_322 af.sk.un_650
  // [3740]
  0x20311ea0, 0x04033f07, 0x171304ec, 0x55005304,   // ms.az.sq_322 af.nl.fi_432  fi.et.sr_644 ht.rw.un_320
  0x04000308, 0x2a0405ee, 0x042d3b02, 0x17000e05,   // nl.fi.un_430 fr.fi.mt_422  so.sk.fi_222 is.sr.un_330
  0x11001705, 0x2a051907, 0x122d0d5a, 0x03000707,   // sr.ro.un_330 gl.fr.mt_432  cs.sk.hu_553 it.nl.un_420
  0x27000504, 0x2d001702, 0x2d0d06a9, 0x12000607,   // fr.gd.un_320 sr.sk.un_220  de.cs.sk_544 de.hu.un_420
  // [3750]
  0x12002805, 0x00000906, 0x21286455, 0x060813ad,   // sw.hu.un_330 pl.un.un_400  lg.sw.jw_442 et.no.de_643
  0x270e1808, 0x212a1e07, 0x283f35ad, 0x120f0607,   // ga.is.gd_443 ms.mt.jw_432  zu.af.sw_643 de.lv.hu_432
  0x051304ee, 0x35005505, 0x211f135a, 0x0321080b,   // fi.et.fr_422 rw.zu.un_330  et.cy.jw_553 no.jw.nl_542
  0x18122d60, 0x2a2b4aa0, 0x2a1f01a9, 0x2a001f09,   // sk.hu.ga_664 yo.vi.mt_322  en.cy.mt_544 cy.mt.un_440
  // [3760]
  0x17040a0d, 0x080a1702, 0x64001f1b, 0x2a000104,   // mk.ru.sr_554 sr.mk.uk_222  cy.lg.un_770 en.mt.un_320
  0x013b2d0b, 0x31121b11, 0x231127a0, 0x1b5312a4,   // sk.so.en_542 tr.hu.az_653  gd.ro.ca_322 hu.ht.tr_433
  0x120a01af, 0x033f2aa9, 0x0a001302, 0x0d3f01a4,   // en.pt.hu_655 mt.af.nl_544  et.pt.un_220 en.af.cs_433
  0x011335a7, 0x061b13ec, 0x0800070e, 0x17071005,   // zu.et.en_532 et.tr.de_644  bg.uk.un_550 be.bg.sr_333
  // [3770]
  0x04000e20, 0x28680313, 0x0e0c1fad, 0x09001004,   // is.fi.un_850 nl.ig.sw_665  cy.sv.is_643 lt.pl.un_320
  0x0c1f6ba0, 0x1000090e, 0x0b1123ee, 0x1f002911,   // ceb.cy.sv_322 pl.lt.un_550  ca.ro.es_422 sl.cy.un_630
  0x0a0810a4, 0x1a003504, 0x1029040b, 0x20000113,   // be.uk.mk_433 zu.tl.un_320  fi.sl.lt_542 en.sq.un_650
  0x186b010c, 0x2d3528a0, 0x0b00010c, 0x311a3507,   // en.ceb.ga_543 sw.zu.sk_322  en.es.un_530 zu.tl.az_432
  // [3780]
  0x0b07205a, 0x012911a4, 0x28000b02, 0x0b072aa0,   // sq.it.es_553 ro.sl.en_433  es.sw.un_220 mt.it.es_322
  0x524a6407, 0x20321b04, 0x1f000408, 0x3b002504,   // lg.yo.ha_432 tr.bs.sq_332  fi.cy.un_430 eu.so.un_320
  0x1f003208, 0x27001820, 0x20006407, 0x322d10a0,   // bs.cy.un_430 ga.gd.un_850  lg.sq.un_420 lt.sk.bs_322
  0x271118af, 0x2700011a, 0x27011fa6, 0x04081f11,   // ga.ro.gd_655 en.gd.un_760  cy.en.gd_521 cy.no.fi_653
  // [3790]
  0x2d001e0c, 0x3b006809, 0x31182712, 0x081c0e08,   // ms.sk.un_530 ig.so.un_440  gd.ga.az_654 is.id.no_443
  0x6b6801a4, 0x1f00041a, 0x52006404, 0x12281a07,   // en.ig.ceb_433 fi.cy.un_760  lg.ha.un_320 tl.sw.hu_432
  0x2d0d1614, 0x192718ad, 0x1327010c, 0x2864350c,   // hr.cs.sk_666 ga.gd.gl_643  en.gd.et_543 zu.lg.sw_543
  0x1c0464a6, 0x20310fad, 0x13000617, 0x0c080655,   // lg.fi.id_521 lv.az.sq_643  de.et.un_730 de.no.sv_442
  // [37a0]
  0x186e2809, 0x07041307, 0x0c2916a4, 0x0c232008,   // sw.hmn.ga_444 et.fi.it_432  hr.sl.sv_433 sq.ca.sv_443
  0x1f00091a, 0x040e0c12, 0x1a1c1ea9, 0x166e1707,   // pl.cy.un_760 sv.is.fi_654  ms.id.tl_544 sr.hmn.hr_432
  0x1004070e, 0x5200310c, 0x0c6b1a07, 0x29211c08,   // bg.ru.be_555 az.ha.un_530  tl.ceb.sv_432 id.jw.sl_443
  0x0c001b05, 0x080a11a6, 0x032311a0, 0x10170804,   // tr.sv.un_330 ro.mk.uk_521  ro.ca.nl_322 uk.sr.be_332
  // [37b0]
  0x11231e04, 0x0a07080c, 0x05530404, 0x1c0d1309,   // ms.ca.ro_332 uk.bg.mk_543  fi.ht.fr_332 bh.ne.mr_444
  0x29000c04, 0x133b0111, 0x1f29010c, 0x1e1c1aee,   // sv.sl.un_320 en.so.et_653  en.sl.cy_543 tl.id.ms_422
  0x19002505, 0x12002d12, 0x13000209, 0x1312010c,   // eu.gl.un_330 sk.hu.un_640  da.et.un_440 en.hu.et_543
  0x32162a09, 0x2b005204, 0x1e1c27a4, 0x28181fac,   // mt.hr.bs_444 ha.vi.un_320  gd.id.ms_433 cy.ga.sw_632
  // [37c0]
  0x2100011a, 0x0b0a1302, 0x530a05af, 0x4a002d0c,   // en.jw.un_760 et.pt.es_222  fr.pt.ht_655 sk.yo.un_530
  0x1f3f0114, 0x040511a7, 0x0105110c, 0x0910250c,   // en.af.cy_666 ro.fr.fi_532  ro.fr.en_543 eu.lt.pl_543
  0x05202704, 0x20002108, 0x17290d0c, 0x19280ba7,   // gd.sq.fr_332 jw.sq.un_430  cs.sl.sr_543 es.sw.gl_532
  0x17000409, 0x10252da4, 0x12090111, 0x190a25ee,   // ru.sr.un_440 sk.eu.lt_433  en.pl.hu_653 eu.pt.gl_422
  // [37d0]
  0x3b000119, 0x68132514, 0x0425640c, 0x68006b13,   // en.so.un_750 eu.et.ig_666  lg.eu.fi_543 ceb.ig.un_650
  0x2a1f01ec, 0x173528a0, 0x20002507, 0x1f006404,   // en.cy.mt_644 sw.zu.sr_322  eu.sq.un_420 lg.cy.un_320
  0x1f000112, 0x20092509, 0x13000122, 0x5513255a,   // en.cy.un_640 eu.pl.sq_444  en.et.un_870 eu.et.rw_553
  0x4a00681a, 0x041711a9, 0x6b00680d, 0x3f000809,   // ig.yo.un_760 ro.sr.ru_544  ig.ceb.un_540 no.af.un_440
  // [37e0]
  0x520220ee, 0x2a092da0, 0x194a0ba0, 0x202910a9,   // sq.da.ha_422 sk.pl.mt_322  es.yo.gl_322 lt.sl.sq_544
  0x0c0625af, 0x21001e04, 0x2d000f12, 0x251355a4,   // eu.de.sv_655 ms.jw.un_320  lv.sk.un_640 rw.et.eu_433
  0x070417ad, 0x10252a0d, 0x1c3b210c, 0x2a002509,   // sr.ru.bg_643 mt.eu.lt_554  jw.so.id_543 eu.mt.un_440
  0x3b211307, 0x55130e12, 0x092a0711, 0x55001307,   // et.jw.so_432 is.et.rw_654  it.mt.pl_653 et.rw.un_420
  // [37f0]
  0x08001107, 0x050453ee, 0x070a1702, 0x3f031304,   // ro.uk.un_420 ht.fi.fr_422  sr.mk.bg_222 et.nl.af_332
  0x1300350e, 0x12060c02, 0x32001619, 0x2a00250d,   // zu.et.un_550 sv.de.hu_222  hr.bs.un_750 eu.mt.un_540
  0x07534aa7, 0x10000c08, 0x1700110c, 0x35684a12,   // yo.ht.it_532 sv.lt.un_430  ro.sr.un_530 yo.ig.zu_654
  0x3b1b0107, 0x030802ec, 0x01006e04, 0x03080213,   // en.tr.so_432 da.no.nl_644  hmn.en.un_320 da.no.nl_665

  // [3800]
  0x3b002322, 0x251b0608, 0x06080307, 0x08026e14,   // ca.so.un_870 de.tr.eu_443  nl.no.de_432 hmn.da.no_666
  0x64206805, 0x3b2a18a4, 0x05003f02, 0x033f0402,   // ig.sq.lg_333 ga.mt.so_433  af.fr.un_220 fi.af.nl_222
  0x136416a4, 0x64001312, 0x21033b0c, 0x53000914,   // hr.lg.et_433 et.lg.un_640  so.nl.jw_543 pl.ht.un_660
  0x020408ee, 0x52002508, 0x07170aee, 0x1e1a1ca0,   // no.fi.da_422 eu.ha.un_430  mk.sr.bg_422 id.tl.ms_322
  // [3810]
  0x3b001b07, 0x03000418, 0x2a0d1e0b, 0x0c0208a4,   // tr.so.un_420 fi.nl.un_740  ms.cs.mt_542 no.da.sv_433
  0x121a6b0c, 0x3b52250c, 0x17110a12, 0x203b2aad,   // ceb.tl.hu_543 eu.ha.so_543  mk.ro.sr_654 mt.so.sq_643
  0x120420a4, 0x6b3b01a7, 0x18272313, 0x3b1b3108,   // sq.fi.hu_433 en.so.ceb_532  ca.gd.ga_665 az.tr.so_443
  0x01000c05, 0x04102304, 0x326e10a4, 0x12001905,   // sv.en.un_330 ca.lt.fi_332  lt.hmn.bs_433 gl.hu.un_330
  // [3820]
  0x0a171013, 0x53106e08, 0x080203ec, 0x3b311b11,   // be.sr.mk_665 hmn.lt.ht_443  nl.da.no_644 tr.az.so_653
  0x09003512, 0x07256ea7, 0x2b006e04, 0x130f0455,   // zu.pl.un_640 hmn.eu.it_532  hmn.vi.un_320 fi.lv.et_442
  0x0e003f04, 0x12003f0d, 0x3f0c080c, 0x1c090d07,   // af.is.un_320 af.hu.un_540  no.sv.af_543 ne.hi.mr_432
  0x20002805, 0x1c091311, 0x06311bad, 0x313b1b08,   // sw.sq.un_330 bh.hi.mr_653  tr.az.de_643 tr.so.az_443
  // [3830]
  0x20001804, 0x0e001314, 0x0a2120a7, 0x55000b02,   // ga.sq.un_320 et.is.un_660  sq.jw.pt_532 es.rw.un_220
  0x64005519, 0x09080fa0, 0x29001709, 0x21531c07,   // rw.lg.un_750 lv.no.pl_322  sr.sl.un_440 id.ht.jw_432
  0x0a291a09, 0x10070404, 0x19182755, 0x050127a0,   // tl.sl.pt_444 fi.it.lt_332  gd.ga.gl_442 gd.en.fr_322
  0x13061e04, 0x0e000f1b, 0x641a55ad, 0x1e001c1a,   // ms.de.et_332 lv.is.un_770  rw.tl.lg_643 id.ms.un_760
  // [3840]
  0x08000423, 0x3b0e0804, 0x0408105a, 0x07002008,   // ru.uk.un_880 no.is.so_332  be.uk.ru_553 sq.it.un_430
  0x321b2055, 0x091c13a7, 0x04001302, 0x0f091014,   // sq.tr.bs_442 bh.mr.hi_532  et.fi.un_220 lt.pl.lv_666
  0x07001602, 0x090c1004, 0x0a190bad, 0x21230b09,   // hr.it.un_220 lt.sv.pl_332  es.gl.pt_643 es.ca.jw_444
  0x020608a0, 0x12000505, 0x19250b0c, 0x04080707,   // no.de.da_322 fr.hu.un_330  es.eu.gl_543 bg.uk.ru_432
  // [3850]
  0x2d190b08, 0x13000411, 0x07000407, 0x35004a13,   // es.gl.sk_443 fi.et.un_630  ru.bg.un_420 yo.zu.un_650
  0x100a0408, 0x23180ba0, 0x0d1c09a9, 0x19122da4,   // ru.mk.be_443 es.ga.ca_322  hi.mr.ne_544 sk.hu.gl_433
  0x230b0ea4, 0x12190b55, 0x070a0807, 0x080a040c,   // is.es.ca_433 es.gl.hu_442  uk.mk.bg_432 ru.mk.uk_543
  0x18002d0c, 0x111912a4, 0x1000190e, 0x11003508,   // sk.ga.un_530 hu.gl.ro_433  gl.lt.un_550 zu.ro.un_430
  // [3860]
  0x28072d08, 0x0f001c02, 0x18001222, 0x190b4a0e,   // sk.it.sw_443 id.lv.un_220  ur.ar.un_870 yo.es.gl_555
  0x0e000f04, 0x12352d5a, 0x0f2531ad, 0x2d0d3fa0,   // lv.is.un_320 sk.zu.hu_553  az.eu.lv_643 af.cs.sk_322
  0x0b002508, 0x16210507, 0x18190b08, 0x0920070b,   // eu.es.un_430 fr.jw.hr_432  es.gl.ga_443 it.sq.pl_542
  0x190b0a13, 0x23052004, 0x286b1a60, 0x0a000414,   // pt.es.gl_665 sq.fr.ca_332  tl.ceb.sw_664 ru.mk.un_660
  // [3870]
  0x55002008, 0x1f3525a9, 0x29161904, 0x131c0d12,   // sq.rw.un_430 eu.zu.cy_544  gl.hr.sl_332 ne.mr.bh_654
  0x20190ba6, 0x01001907, 0x3b641aa0, 0x1c6b640c,   // es.gl.sq_521 gl.en.un_420  tl.lg.so_322 lg.ceb.id_543
  0x23012aa4, 0x20351108, 0x11001f0c, 0x13040555,   // mt.en.ca_433 ro.zu.sq_443  cy.ro.un_530 fr.fi.et_442
  0x0a04070c, 0x071101a0, 0x201b06a0, 0x3f08040c,   // bg.ru.mk_543 en.ro.it_322  de.tr.sq_322 fi.no.af_543
  // [3880]
  0x0500120d, 0x05110708, 0x120a2305, 0x1f1a5212,   // hu.fr.un_540 it.ro.fr_443  ca.pt.hu_333 ha.tl.cy_654
  0x190b0a0c, 0x27002b13, 0x07200fee, 0x53004a34,   // pt.es.gl_543 vi.gd.un_650  lv.sq.it_422 yo.ht.un_A80
  0x01060708, 0x2b534aad, 0x3b001e0d, 0x0a313b04,   // it.de.en_443 yo.ht.vi_643  ms.so.un_540 so.az.pt_332
  0x2b534a12, 0x0302080c, 0x28521ea0, 0x1e1c3ba9,   // yo.ht.vi_654 no.da.nl_543  ms.ha.sw_322 so.id.ms_544
  // [3890]
  0x190b23a9, 0x2b4a5360, 0x051a6ba9, 0x2b002719,   // ca.es.gl_544 ht.yo.vi_664  ceb.tl.fr_544 gd.vi.un_750
  0x0500190d, 0x53004a22, 0x060e0412, 0x1a2009a4,   // gl.fr.un_540 yo.ht.un_870  fi.is.de_654 pl.sq.tl_433
  0x08040705, 0x1013040c, 0x29003205, 0x07110a55,   // bg.ru.uk_333 fi.et.lt_543  bs.sl.un_330 mk.ro.bg_442
  0x206b1c07, 0x13000405, 0x53004a20, 0x1e1c28ac,   // id.ceb.sq_432 fi.et.un_330  yo.ht.un_850 sw.id.ms_632
  // [38a0]
  0x07004a29, 0x0c0e0655, 0x28001604, 0x1a002809,   // yo.it.un_960 de.is.sv_442  hr.sw.un_320 sw.tl.un_440
  0x17002902, 0x0b070107, 0x3f1f0f07, 0x0b0a1a02,   // sl.sr.un_220 en.it.es_432  lv.cy.af_432 tl.pt.es_222
  0x2700030d, 0x2900281a, 0x18000205, 0x10641aa4,   // nl.gd.un_540 sw.sl.un_760  da.ga.un_330 tl.lg.lt_433
  0x2d002819, 0x3b1c1ea0, 0x284a5212, 0x04033fec,   // sw.sk.un_750 ms.id.so_322  ha.yo.sw_654 af.nl.fi_644
  // [38b0]
  0x1c1e280c, 0x29352811, 0x0b0a230e, 0x0a230b0b,   // sw.ms.id_543 sw.zu.sl_653  ca.pt.es_555 es.ca.pt_542
  0x231b3ba0, 0x4a52280c, 0x1b000e12, 0x17000f07,   // so.tr.ca_322 sw.ha.yo_543  is.tr.un_640 lv.sr.un_420
  0x0b0a23af, 0x0e551b08, 0x285568a0, 0x05520aee,   // ca.pt.es_655 tr.rw.is_443  ig.rw.sw_322 pt.ha.fr_422
  0x0a1004a4, 0x1b3b6412, 0x10086b55, 0x12002704,   // ru.be.mk_433 lg.so.tr_654  ceb.no.lt_442 gd.hu.un_320
  // [38c0]
  0x0a190b60, 0x0c001f0c, 0x352a280d, 0x1e006e0c,   // es.gl.pt_664 cy.sv.un_530  sw.mt.zu_554 hmn.ms.un_530
  0x190b2314, 0x211b28ee, 0x03043fa4, 0x25002909,   // ca.es.gl_666 sw.tr.jw_422  af.fi.nl_433 sl.eu.un_440
  0x133f04ee, 0x09080208, 0x03003f2a, 0x68002b14,   // fi.af.et_422 da.no.pl_443  af.nl.un_970 vi.ig.un_660
  0x286e6812, 0x00006837, 0x122a070b, 0x2a070aa4,   // ig.hmn.sw_654 ig.un.un_B00  it.mt.hu_542 pt.it.mt_433
  // [38d0]
  0x6400521b, 0x1a00641a, 0x2d001307, 0x1e001105,   // ha.lg.un_770 lg.tl.un_760  et.sk.un_420 ro.ms.un_330
  0x1c005219, 0x00000e2d, 0x5200280c, 0x4a005212,   // ha.id.un_750 is.un.un_A00  sw.ha.un_530 ha.yo.un_640
  0x170a10a9, 0x05000119, 0x09003f0d, 0x646b5212,   // be.mk.sr_544 en.fr.un_750  af.pl.un_540 ha.ceb.lg_654
  0x0d2004a0, 0x2a3b29a9, 0x0d001113, 0x05002104,   // fi.sq.cs_322 sl.so.mt_544  ro.cs.un_650 jw.fr.un_320
  // [38e0]
  0x6b041aa9, 0x08000e11, 0x21136b07, 0x090c13a4,   // tl.fi.ceb_544 is.no.un_630  ceb.et.jw_432 et.sv.pl_433
  0x022108a0, 0x2b002507, 0x283b2514, 0x1e1b0e08,   // no.jw.da_322 eu.vi.un_420  eu.so.sw_666 is.tr.ms_443
  0x0f00520c, 0x18004a04, 0x04002008, 0x12200812,   // ha.lv.un_530 yo.ga.un_320  sq.fi.un_430 no.sq.hu_654
  0x1a6452af, 0x200812a9, 0x05201eaf, 0x6455520b,   // ha.lg.tl_655 hu.no.sq_544  ms.sq.fr_655 ha.rw.lg_542
  // [38f0]
  0x0c0208a9, 0x6400521a, 0x201b05a4, 0x643555ad,   // no.da.sv_544 ha.lg.un_760  fr.tr.sq_433 rw.zu.lg_643
  0x521f2507, 0x3b4a20a4, 0x522102a9, 0x2b005507,   // eu.cy.ha_432 sq.yo.so_433  da.jw.ha_544 rw.vi.un_420
  0x64121aad, 0x202d0da7, 0x35005207, 0x190807a4,   // tl.hu.lg_643 cs.sk.sq_532  ha.zu.un_420 it.no.gl_433
  0x05110d05, 0x28356412, 0x2d0d02ee, 0x080225a4,   // cs.ro.fr_333 lg.zu.sw_654  da.cs.sk_422 eu.da.no_433
  // [3900]
  0x2003120c, 0x080613a0, 0x2b121b0c, 0x080204ec,   // hu.nl.sq_543 et.de.no_322  tr.hu.vi_543 fi.da.no_644
  0x09041805, 0x2a0c0205, 0x19000a08, 0x21641a07,   // ga.fi.pl_333 da.sv.mt_333  pt.gl.un_430 tl.lg.jw_432
  0x1a356413, 0x3f21090c, 0x52002312, 0x0b002312,   // lg.zu.tl_665 pl.jw.af_543  ca.ha.un_640 ca.es.un_640
  0x030502ee, 0x200802a9, 0x210c08a9, 0x16000207,   // da.fr.nl_422 da.no.sq_544  no.sv.jw_544 da.hr.un_420
  // [3910]
  0x6b1f1a09, 0x0f1352a0, 0x12000b04, 0x3b1304a7,   // tl.cy.ceb_444 ha.et.lv_322  es.hu.un_320 fi.et.so_532
  0x10001221, 0x18001f13, 0x190b0a0e, 0x211c04a4,   // hu.lt.un_860 cy.ga.un_650  pt.es.gl_555 fi.id.jw_433
  0x09001f08, 0x0b210504, 0x3521520c, 0x101b3508,   // cy.pl.un_430 fr.jw.es_332  ha.jw.zu_543 zu.tr.lt_443
  0x0e004a21, 0x18002813, 0x351b1ca4, 0x18004a22,   // yo.is.un_860 sw.ga.un_650  id.tr.zu_433 yo.ga.un_870
  // [3920]
  0x281364a0, 0x17002912, 0x1300092b, 0x1a646b07,   // lg.et.sw_322 sl.sr.un_640  hi.bh.un_980 ceb.lg.tl_432
  0x4a000e29, 0x12001702, 0x32161ca9, 0x3f0308a9,   // is.yo.un_960 sr.hu.un_220  id.hr.bs_544 no.nl.af_544
  0x080a07a9, 0x01556407, 0x0e2b4a11, 0x11030a07,   // bg.mk.uk_544 lg.rw.en_432  yo.vi.is_653 pt.nl.ro_432
  0x0a001105, 0x64005518, 0x3500520e, 0x101303a9,   // ro.mk.un_330 rw.lg.un_740  ha.zu.un_550 nl.et.lt_544
  // [3930]
  0x182d4a0c, 0x08043b07, 0x64351aaf, 0x29000d19,   // yo.sk.ga_543 so.fi.no_432  tl.zu.lg_655 cs.sl.un_750
  0x251304af, 0x1b52120c, 0x35101ba4, 0x28351b07,   // fi.et.eu_655 hu.ha.tr_543  tr.lt.zu_433 tr.zu.sw_432
  0x4a0e2dec, 0x5300090d, 0x1f033f14, 0x125229ee,   // sk.is.yo_644 pl.ht.un_540  af.nl.cy_666 sl.ha.hu_422
  0x31002904, 0x0b4a18ac, 0x0407100c, 0x2a001604,   // sl.az.un_320 ga.yo.es_632  be.bg.ru_543 hr.mt.un_320
  // [3940]
  0x551a6455, 0x3b13290c, 0x13351aad, 0x13356b02,   // lg.tl.rw_442 sl.et.so_543  tl.zu.et_643 ceb.zu.et_222
  0x64003519, 0x294a6407, 0x1c21350c, 0x17100855,   // zu.lg.un_750 lg.yo.sl_432  zu.jw.id_543 uk.be.sr_442
  0x1807010c, 0x522b28a0, 0x09000114, 0x350e2511,   // en.it.ga_543 sw.vi.ha_322  en.pl.un_660 eu.is.zu_653
  0x02002804, 0x042511a4, 0x686404a4, 0x19052305,   // sw.da.un_320 ro.eu.fi_433  fi.lg.ig_433 ca.fr.gl_333
  // [3950]
  0x04642108, 0x2a000e04, 0x0d001c18, 0x27001f1b,   // jw.lg.fi_443 is.mt.un_320  mr.ne.un_740 cy.gd.un_770
  0x080e25a4, 0x355564a0, 0x6b645555, 0x29000f1b,   // eu.is.no_433 lg.rw.zu_322  rw.lg.ceb_442 lv.sl.un_770
  0x0f6b11af, 0x250b19a4, 0x310c08a9, 0x556435ee,   // ro.ceb.lv_655 gl.es.eu_433  no.sv.az_544 zu.lg.rw_422
  0x011b3107, 0x190a21a0, 0x111a04ee, 0x0e122307,   // az.tr.en_432 jw.pt.gl_322  fi.tl.ro_422 ca.hu.is_432
  // [3960]
  0x03203505, 0x1700080d, 0x19050ba4, 0x251120a4,   // zu.sq.nl_333 uk.sr.un_540  es.fr.gl_433 sq.ro.eu_433
  0x23190b14, 0x100f13ad, 0x0c2311af, 0x040817a4,   // es.gl.ca_666 et.lv.lt_643  ro.ca.sv_655 sr.uk.ru_433
  0x04170a09, 0x0c020e0c, 0x11002314, 0x2a0c040b,   // mk.sr.ru_444 is.da.sv_543  ca.ro.un_660 fi.sv.mt_542
  0x3f0301a4, 0x52000407, 0x0b02080b, 0x0b000114,   // en.nl.af_433 fi.ha.un_420  no.da.es_542 en.es.un_660
  // [3970]
  0x042d0da9, 0x1e1c0ca4, 0x0c3f180c, 0x0e1f0c12,   // cs.sk.fi_544 sv.id.ms_433  ga.af.sv_543 sv.cy.is_654
  0x070417a4, 0x3b181ba0, 0x0c6b2305, 0x1b0c06ad,   // sr.ru.bg_433 tr.ga.so_322  ca.ceb.sv_333 de.sv.tr_643
  0x19230107, 0x07081002, 0x05000a09, 0x041a13a4,   // en.ca.gl_432 be.uk.bg_222  pt.fr.un_440 et.tl.fi_433
  0x13001a21, 0x131a04a0, 0x1c090d0e, 0x53110ca0,   // tl.et.un_860 fi.tl.et_322  ne.hi.mr_555 sv.ro.ht_322
  // [3980]
  0x1b000108, 0x031f1b0c, 0x0e0803ec, 0x112a2313,   // en.tr.un_430 tr.cy.nl_543  nl.no.is_644 ca.mt.ro_665
  0x1b531f0c, 0x0e080c14, 0x642035a4, 0x0800030c,   // cy.ht.tr_543 sv.no.is_666  zu.sq.lg_433 nl.no.un_530
  0x3f000c08, 0x12050a07, 0x1f001105, 0x112706ee,   // sv.af.un_430 pt.fr.hu_432  ro.cy.un_330 de.gd.ro_422
  0x3f2a1fa4, 0x3f3b6404, 0x2555355a, 0x552868a4,   // cy.mt.af_433 lg.so.af_332  zu.rw.eu_553 ig.sw.rw_433
  // [3990]
  0x2864350d, 0x201b1f07, 0x3f033bec, 0x20356402,   // zu.lg.sw_554 cy.tr.sq_432  so.nl.af_644 lg.zu.sq_222
  0x06033f0c, 0x1e646808, 0x6b001a07, 0x1f170608,   // af.nl.de_543 ig.lg.ms_443  tl.ceb.un_420 de.sr.cy_443
  0x3f3b6405, 0x13000f05, 0x033b3fa9, 0x64003b13,   // lg.so.af_333 lv.et.un_330  af.so.nl_544 so.lg.un_650
  0x120d2b04, 0x3f036412, 0x35255508, 0x0f001311,   // vi.cs.hu_332 lg.nl.af_654  rw.eu.zu_443 et.lv.un_630
  // [39a0]
  0x211e1c0e, 0x1b005313, 0x2d0d29a9, 0x4a000b04,   // id.ms.jw_555 ht.tr.un_650  sl.cs.sk_544 es.yo.un_320
  0x53000512, 0x090306a0, 0x31003518, 0x291f01a0,   // fr.ht.un_640 de.nl.pl_322  zu.az.un_740 en.cy.sl_322
  0x1b002807, 0x11291e09, 0x53003523, 0x5500111a,   // sw.tr.un_420 ms.sl.ro_444  zu.ht.un_880 ro.rw.un_760
  0x194a010c, 0x20552508, 0x3f0364af, 0x64553512,   // en.yo.gl_543 eu.rw.sq_443  lg.nl.af_655 zu.rw.lg_654
  // [39b0]
  0x52061c0c, 0x64321602, 0x3b3f030d, 0x250f0611,   // id.de.ha_543 hr.bs.lg_222  nl.af.so_554 de.lv.eu_653
  0x64033fa4, 0x0d0906a0, 0x05190b02, 0x04101108,   // af.nl.lg_433 de.pl.cs_322  es.gl.fr_222 ro.be.ru_443
  0x64003b0d, 0x1b005308, 0x270206a0, 0x092d06a7,   // so.lg.un_540 ht.tr.un_430  de.da.gd_322 de.sk.pl_532
  0x23110107, 0x25002804, 0x523b0107, 0x010e64a4,   // en.ro.ca_432 sw.eu.un_320  en.so.ha_432 lg.is.en_433
  // [39c0]
  0x0d000612, 0x10000f1a, 0x0e030613, 0x0a23010c,   // de.cs.un_640 lv.lt.un_760  de.nl.is_665 en.ca.pt_543
  0x122d10a4, 0x3b1a13ee, 0x06000e0e, 0x643f1ba0,   // lt.sk.hu_433 et.tl.so_422  is.de.un_550 tr.af.lg_322
  0x6b002705, 0x1b3b3113, 0x55054aee, 0x0c041c04,   // gd.ceb.un_330 az.so.tr_665  yo.fr.rw_422 id.fi.sv_332
  0x682135a9, 0x01073104, 0x27186408, 0x0100531b,   // zu.jw.ig_544 az.it.en_332  lg.ga.gd_443 ht.en.un_770
  // [39d0]
  0x6400310e, 0x2a060460, 0x0f102daf, 0x35531105,   // az.lg.un_550 fi.de.mt_664  sk.lt.lv_655 ro.ht.zu_333
  0x1c000919, 0x0900030c, 0x092a2504, 0x68006e21,   // hi.mr.un_750 nl.pl.un_530  eu.mt.pl_332 hmn.ig.un_860
  0x18000511, 0x21181214, 0x19052307, 0x06003f1b,   // fr.ga.un_630 ur.ar.fa_666  ca.fr.gl_432 af.de.un_770
  0x3b00021a, 0x162901a0, 0x1f3f0311, 0x5313045a,   // da.so.un_760 en.sl.hr_322  nl.af.cy_653 fi.et.ht_553
  // [39e0]
  0x0f040704, 0x130f100c, 0x070f1009, 0x04002104,   // it.fi.lv_332 lt.lv.et_543  lt.lv.it_444 jw.fi.un_320
  0x3f00250c, 0x06030e0c, 0x013528a0, 0x29000c02,   // eu.af.un_530 is.nl.de_543  sw.zu.en_322 sv.sl.un_220
  0x2a2307a4, 0x09162907, 0x3b251a05, 0x033f0fa4,   // it.ca.mt_433 sl.hr.pl_432  tl.eu.so_333 lv.af.nl_433
  0x0b072d0c, 0x102a0f0c, 0x08022aa0, 0x2b100f0d,   // sk.it.es_543 lv.mt.lt_543  mt.da.no_322 lv.lt.vi_554
  // [39f0]
  0x04002d1a, 0x31090fa0, 0x11041011, 0x641e350c,   // sk.fi.un_760 lv.pl.az_322  be.ru.ro_653 zu.ms.lg_543
  0x0500210d, 0x080a1108, 0x23555208, 0x07252aa9,   // jw.fr.un_540 ro.mk.uk_443  ha.rw.ca_443 mt.eu.it_544
  0x0a040807, 0x1c281ea4, 0x0c066ba0, 0x111e1c08,   // uk.ru.mk_432 ms.sw.id_433  ceb.de.sv_322 id.ms.ro_443
  0x1e00070c, 0x31112dee, 0x103f35a7, 0x191007a0,   // it.ms.un_530 sk.ro.az_422  zu.af.lt_532 it.lt.gl_322
  // [3a00]
  0x10070809, 0x11522812, 0x131123ee, 0x552809a4,   // uk.bg.be_444 sw.ha.ro_654  ca.ro.et_422 pl.sw.rw_433
  0x23111c07, 0x11005308, 0x0411070e, 0x0700291a,   // id.ro.ca_432 ht.ro.un_430  bg.ro.ru_555 sl.it.un_760
  0x25521114, 0x285535ad, 0x1f1311a0, 0x55281aa9,   // ro.ha.eu_666 zu.rw.sw_643  ro.et.cy_322 tl.sw.rw_544
  0x1e1c13ee, 0x2000250c, 0x0c060202, 0x01063fa0,   // et.id.ms_422 eu.sq.un_530  da.de.sv_222 af.de.en_322
  // [3a10]
  0x03083f04, 0x23201108, 0x25231109, 0x1c1b1e07,   // af.no.nl_332 ro.sq.ca_443  ro.ca.eu_444 ms.tr.id_432
  0x1200100d, 0x102104a0, 0x25105504, 0x11002312,   // lt.hu.un_540 fi.jw.lt_322  rw.lt.eu_332 ca.ro.un_640
  0x092d0d0d, 0x190b230b, 0x13112312, 0x216b1ba0,   // cs.sk.pl_554 ca.es.gl_542  ca.ro.et_654 tr.ceb.jw_322
  0x0e6b3fee, 0x1221180d, 0x090d20ad, 0x170a070e,   // af.ceb.is_422 ar.fa.ur_554  sq.cs.pl_643 bg.mk.sr_555
  // [3a20]
  0x4a00050c, 0x0e04105a, 0x12101f0c, 0x29000604,   // fr.yo.un_530 lt.fi.is_553  cy.lt.hu_543 de.sl.un_320
  0x040652a9, 0x3f002b1b, 0x1a280407, 0x10040faf,   // ha.de.fi_544 vi.af.un_770  fi.sw.tl_432 lv.fi.lt_655
  0x25005219, 0x2b003f08, 0x2300250c, 0x071708ad,   // ha.eu.un_750 af.vi.un_430  eu.ca.un_530 uk.sr.bg_643
  0x2b000a19, 0x0a2b5302, 0x4a000c12, 0x23190b0c,   // pt.vi.un_750 ht.vi.pt_222  sv.yo.un_640 es.gl.ca_543
  // [3a30]
  0x08006404, 0x230b180c, 0x2d002018, 0x10000a08,   // lg.no.un_320 ga.es.ca_543  sq.sk.un_740 mk.be.un_430
  0x64325202, 0x083f0e0c, 0x132a2805, 0x25046805,   // ha.bs.lg_222 is.af.no_543  sw.mt.et_333 ig.fi.eu_333
  0x0500180d, 0x040f1013, 0x2b000a12, 0x0a002b0d,   // ga.fr.un_540 lt.lv.fi_665  pt.vi.un_640 vi.pt.un_540
  0x076405a0, 0x28006811, 0x235201a4, 0x0a000404,   // fr.lg.it_322 ig.sw.un_630  en.ha.ca_433 ru.mk.un_320
  // [3a40]
  0x06000c11, 0x06000507, 0x0a056413, 0x041f6b55,   // sv.de.un_630 fr.de.un_420  lg.fr.pt_665 ceb.cy.fi_442
  0x13291707, 0x076b13ee, 0x0a170404, 0x01191ea4,   // sr.sl.et_432 et.ceb.it_422  ru.sr.mk_332 ms.gl.en_433
  0x1c231eee, 0x0500180c, 0x25001807, 0x1e041ca4,   // ms.ca.id_422 ga.fr.un_530  ga.eu.un_420 id.fi.ms_433
  0x19004a07, 0x2a3216a4, 0x20002902, 0x281301a0,   // yo.gl.un_420 hr.bs.mt_433  sl.sq.un_220 en.et.sw_322
  // [3a50]
  0x1e020807, 0x0c1c03a4, 0x28130412, 0x3b04130c,   // no.da.ms_432 nl.id.sv_433  fi.et.sw_654 et.fi.so_543
  0x3f032da0, 0x0f3b1304, 0x0c0704af, 0x2d1f2509,   // sk.nl.af_322 et.so.lv_332  fi.it.sv_655 eu.cy.sk_444
  0x1c1f2007, 0x17003b02, 0x180a055e, 0x10170a13,   // sq.cy.id_432 so.sr.un_220  fr.pt.ga_652 mk.sr.be_665
  0x16000f0c, 0x09101b08, 0x1b001e09, 0x25000e07,   // lv.hr.un_530 tr.lt.pl_443  ms.tr.un_440 is.eu.un_420
  // [3a60]
  0x100a08a0, 0x171004ad, 0x10001713, 0x0c5321a0,   // no.pt.lt_322 ru.be.sr_643  sr.be.un_650 jw.ht.sv_322
  0x31522007, 0x0313045a, 0x1b3b1311, 0x180a01a0,   // sq.ha.az_432 fi.et.nl_553  et.so.tr_653 en.pt.ga_322
  0x0e040ca4, 0x08041707, 0x282053a0, 0x113b010c,   // sv.fi.is_433 sr.ru.uk_432  ht.sq.sw_322 en.so.ro_543
  0x06253ba0, 0x190b08a4, 0x02000412, 0x071708a4,   // so.eu.de_322 no.es.gl_433  fi.da.un_640 uk.sr.bg_433
  // [3a70]
  0x553520a0, 0x25002102, 0x2123050c, 0x101a0404,   // sq.zu.rw_322 jw.eu.un_220  fr.ca.jw_543 fi.tl.lt_332
  0x0b0a2302, 0x10190b55, 0x4a00230e, 0x21006804,   // ca.pt.es_222 es.gl.lt_442  ca.yo.un_550 ig.jw.un_320
  0x20002a02, 0x01045507, 0x17040aa4, 0x0602080c,   // mt.sq.un_220 rw.fi.en_432  mk.ru.sr_433 no.da.de_543
  0x1a032107, 0x20251ba9, 0x12202508, 0x180e050b,   // jw.nl.tl_432 tr.eu.sq_544  eu.sq.hu_443 fr.is.ga_542
  // [3a80]
  0x03060f12, 0x1b200107, 0x0c060eaf, 0x0a040805,   // lv.de.nl_654 en.sq.tr_432  is.de.sv_655 uk.ru.mk_333
  0x530221a4, 0x110a0da4, 0x3f082107, 0x1c3f1aa7,   // jw.da.ht_433 cs.pt.ro_433  jw.no.af_432 tl.af.id_532
  0x1a212007, 0x18211255, 0x080225a9, 0x28253108,   // sq.jw.tl_432 ur.fa.ar_442  eu.da.no_544 az.eu.sw_443
  0x0817040d, 0x28001b18, 0x1b006808, 0x6b192507,   // ru.sr.uk_554 tr.sw.un_740  ig.tr.un_430 eu.gl.ceb_432
  // [3a90]
  0x18282707, 0x3125200c, 0x030f06a7, 0x060e0309,   // gd.sw.ga_432 sq.eu.az_543  de.lv.nl_532 nl.is.de_444
  0x0c1306ad, 0x1e252707, 0x181e2707, 0x12005207,   // de.et.sv_643 gd.eu.ms_432  gd.ms.ga_432 ha.hu.un_420
  0x180b270c, 0x0e001c04, 0x12001307, 0x050b0702,   // gd.es.ga_543 id.is.un_320  et.hu.un_420 it.es.fr_222
  0x181227ee, 0x03000502, 0x1200351b, 0x19063f07,   // gd.hu.ga_422 fr.nl.un_220  zu.hu.un_770 af.de.gl_432
  // [3aa0]
  0x3200060c, 0x0a1827ee, 0x3f00070b, 0x066b0c08,   // de.bs.un_530 gd.ga.pt_422  it.af.un_520 sv.ceb.de_443
  0x281227a0, 0x11072a0c, 0x1e1c1aa9, 0x040a1004,   // gd.hu.sw_322 mt.it.ro_543  tl.id.ms_544 be.mk.ru_332
  0x6b211ea9, 0x063f5507, 0x01552507, 0x01002702,   // ms.jw.ceb_544 rw.af.de_432  eu.rw.en_432 gd.en.un_220
  0x03133fa9, 0x08021f0c, 0x1021010c, 0x1a0c0104,   // af.et.nl_544 cy.da.no_543  en.jw.lt_543 en.sv.tl_332
  // [3ab0]
  0x17352004, 0x13033f13, 0x033f0708, 0x271801ec,   // sq.zu.sr_332 af.nl.et_665  it.af.nl_443 en.ga.gd_644
  0x681b35a7, 0x2a000707, 0x29121e07, 0x6b5301a4,   // zu.tr.ig_532 it.mt.un_420  ms.hu.sl_432 en.ht.ceb_433
  0x0e0c10ee, 0x250f1a02, 0x193b3104, 0x09001c22,   // lt.sv.is_422 tl.lv.eu_222  az.so.gl_332 mr.hi.un_870
  0x3f04035a, 0x1e3f130d, 0x2d121b07, 0x11072aa4,   // nl.fi.af_553 et.af.ms_554  tr.hu.sk_432 mt.it.ro_433
  // [3ac0]
  0x06001012, 0x531901a9, 0x0c0e1305, 0x04133fee,   // lt.de.un_640 en.gl.ht_544  et.is.sv_333 af.et.fi_422
  0x0c310611, 0x2a313bec, 0x07271007, 0x1a3b6b13,   // de.az.sv_653 so.az.mt_644  lt.gd.it_432 ceb.so.tl_665
  0x070410af, 0x04000709, 0x2800681a, 0x130e0ca7,   // be.ru.bg_655 bg.ru.un_440  ig.sw.un_760 sv.is.et_532
  0x3b000304, 0x09000704, 0x27006b0d, 0x0d13090c,   // nl.so.un_320 it.pl.un_320  ceb.gd.un_540 hi.bh.ne_543
  // [3ad0]
  0x10080704, 0x1c130911, 0x08001023, 0x6428520c,   // bg.uk.be_332 hi.bh.mr_653  be.uk.un_880 ha.sw.lg_543
  0x0932310d, 0x68004a09, 0x64555202, 0x1b001309,   // az.bs.pl_554 yo.ig.un_440  ha.rw.lg_222 et.tr.un_440
  0x6b251aa0, 0x1c001e21, 0x07002718, 0x133f3b08,   // tl.eu.ceb_322 ms.id.un_860  gd.it.un_740 so.af.et_443
  0x042028a4, 0x101127a0, 0x033f040d, 0x1c270712,   // sw.sq.fi_433 gd.ro.lt_322  fi.af.nl_554 it.gd.id_654
  // [3ae0]
  0x281703a0, 0x55003f04, 0x080410af, 0x121b3104,   // nl.sr.sw_322 af.rw.un_320  be.ru.uk_655 az.tr.hu_332
  0x0400200e, 0x04080a55, 0x520821a0, 0x04070a5a,   // sq.fi.un_550 mk.uk.ru_442  jw.no.ha_322 mk.bg.ru_553
  0x04110aad, 0x04002a07, 0x2d0d10ac, 0x64001e02,   // mk.ro.ru_643 mt.fi.un_420  lt.cs.sk_632 ms.lg.un_220
  0x681a6b55, 0x642128ad, 0x091c13ee, 0x2a645208,   // ceb.tl.ig_442 sw.jw.lg_643  bh.mr.hi_422 ha.lg.mt_443
  // [3af0]
  0x17002505, 0x080f1012, 0x29321705, 0x08021a14,   // eu.sr.un_330 lt.lv.no_654  sr.bs.sl_333 tl.da.no_666
  0x1b000613, 0x04071009, 0x53006408, 0x081007ee,   // de.tr.un_650 be.bg.ru_444  lg.ht.un_430 bg.be.uk_422
  0x2a000714, 0x2b1204a9, 0x645553a0, 0x25072a08,   // it.mt.un_660 fi.hu.vi_544  ht.rw.lg_322 mt.it.eu_443
  0x32000204, 0x03001c0c, 0x2d162804, 0x203f1ca4,   // da.bs.un_320 id.nl.un_530  sw.hr.sk_332 id.af.sq_433
  // [3b00]
  0x03021faf, 0x121e2a08, 0x6e033fa4, 0x6e686b04,   // cy.da.nl_655 mt.ms.hu_443  af.nl.hmn_433 ceb.ig.hmn_332
  0x201b3208, 0x2d050da6, 0x0f041aee, 0x08001f0c,   // bs.tr.sq_443 cs.fr.sk_521  tl.fi.lv_422 cy.no.un_530
  0x09000d20, 0x12061ba7, 0x2500040e, 0x03002a08,   // ne.hi.un_850 tr.de.hu_532  fi.eu.un_550 mt.nl.un_430
  0x1012040c, 0x29090da4, 0x04231208, 0x3f000334,   // fi.hu.lt_543 cs.pl.sl_433  hu.ca.fi_443 nl.af.un_A80
  // [3b10]
  0x201b53a7, 0x3b131e12, 0x0f291705, 0x201b12ee,   // ht.tr.sq_532 ms.et.so_654  sr.sl.lv_333 hu.tr.sq_422
  0x02002a14, 0x1b041c05, 0x12002012, 0x2a0312ec,   // mt.da.un_660 id.fi.tr_333  sq.hu.un_640 hu.nl.mt_644
  0x3b133f08, 0x040c3f07, 0x10000f04, 0x0c000407,   // af.et.so_443 af.sv.fi_432  lv.lt.un_320 fi.sv.un_420
  0x1a6b0bec, 0x0c19040d, 0x21000604, 0x1f3b18ec,   // es.ceb.tl_644 fi.gl.sv_554  de.jw.un_320 ga.so.cy_644
  // [3b20]
  0x1a6b0f0c, 0x100a07a4, 0x1a6b640c, 0x1f523fa4,   // lv.ceb.tl_543 bg.mk.be_433  lg.ceb.tl_543 af.ha.cy_433
  0x6b003b09, 0x68213b08, 0x0e355512, 0x12100407,   // so.ceb.un_440 so.jw.ig_443  rw.zu.is_654 fi.lt.hu_432
  0x0f101f02, 0x3b0b6b04, 0x10041304, 0x1c11210c,   // cy.lt.lv_222 ceb.es.so_332  et.fi.lt_332 jw.ro.id_543
  0x21005214, 0x01003502, 0x1a3b6baf, 0x080411a9,   // ha.jw.un_660 zu.en.un_220  ceb.so.tl_655 ro.ru.uk_544
  // [3b30]
  0x0000132d, 0x292d0da4, 0x1f6b1a08, 0x053564a0,   // et.un.un_A00 cs.sk.sl_433  tl.ceb.cy_443 lg.zu.fr_322
  0x13083f09, 0x23010907, 0x3b1f0cec, 0x13002d04,   // af.no.et_444 pl.en.ca_432  sv.cy.so_644 sk.et.un_320
  0x160d175a, 0x190b100c, 0x09002a13, 0x313b2a12,   // sr.cs.hr_553 lt.es.gl_543  mt.pl.un_650 mt.so.az_654
  0x3b006414, 0x10190b0c, 0x2d063504, 0x53003504,   // lg.so.un_660 es.gl.lt_543  zu.de.sk_332 zu.ht.un_320
  // [3b40]
  0x040a0804, 0x6406550c, 0x0b000507, 0x1b3125a9,   // uk.mk.ru_332 rw.de.lg_543  fr.es.un_420 eu.az.tr_544
  0x101104a4, 0x126435a9, 0x0d000f13, 0x071f0112,   // ru.ro.be_433 zu.lg.hu_544  lv.cs.un_650 en.cy.it_654
  0x06000407, 0x13000c1a, 0x05001f13, 0x1a001004,   // fi.de.un_420 sv.et.un_760  cy.fr.un_650 lt.tl.un_320
  0x0a080708, 0x16292d12, 0x07000505, 0x08041012,   // bg.uk.mk_443 sk.sl.hr_654  fr.it.un_330 be.ru.uk_654
  // [3b50]
  0x32092807, 0x2a000612, 0x0e001109, 0x060c0409,   // sw.pl.bs_432 de.mt.un_640  ro.is.un_440 fi.sv.de_444
  0x3f1a0302, 0x6b004a0d, 0x03000e08, 0x130c04a4,   // nl.tl.af_222 yo.ceb.un_540  is.nl.un_430 fi.sv.et_433
  0x1a2528a0, 0x07251ea0, 0x01001211, 0x04004a04,   // sw.eu.tl_322 ms.eu.it_322  hu.en.un_630 yo.fi.un_320
  0x182801ee, 0x07111708, 0x523b1a07, 0x1f001014,   // en.sw.ga_422 sr.ro.bg_443  tl.so.ha_432 lt.cy.un_660
  // [3b60]
  0x1f2d1807, 0x0c0e06ee, 0x1e001012, 0x0b1008a0,   // ga.sk.cy_432 de.is.sv_422  lt.ms.un_640 no.lt.es_322
  0x10001305, 0x0f2d2107, 0x0a1210a0, 0x0b1b19a0,   // et.lt.un_330 jw.sk.lv_432  lt.hu.pt_322 gl.tr.es_322
  0x050a03a0, 0x12000808, 0x1e6b1a0d, 0x201f03a0,   // nl.pt.fr_322 no.hu.un_430  tl.ceb.ms_554 nl.cy.sq_322
  0x063f0312, 0x530e1f05, 0x1c1e1f11, 0x05003113,   // nl.af.de_654 cy.is.ht_333  cy.ms.id_653 az.fr.un_650
  // [3b70]
  0x100f09ee, 0x2a041a0b, 0x0f005304, 0x1f041012,   // pl.lv.lt_422 tl.fi.mt_542  ht.lv.un_320 lt.fi.cy_654
  0x08002908, 0x3b000e09, 0x162d230b, 0x35002008,   // sl.no.un_430 is.so.un_440  ca.sk.hr_542 sq.zu.un_430
  0x231a210c, 0x25000113, 0x03000804, 0x0f00170d,   // jw.tl.ca_543 en.eu.un_650  no.nl.un_320 sr.lv.un_540
  0x20000309, 0x120b0702, 0x102d01a4, 0x52311b07,   // nl.sq.un_440 it.es.hu_222  en.sk.lt_433 tr.az.ha_432
  // [3b80]
  0x17111fec, 0x3b00200d, 0x20001b0c, 0x0f000e13,   // cy.ro.sr_644 sq.so.un_540  tr.sq.un_530 is.lv.un_650
  0x0d002907, 0x040a1760, 0x29091007, 0x061b3111,   // sl.cs.un_420 sr.mk.ru_664  lt.pl.sl_432 az.tr.de_653
  0x040a0811, 0x03003b04, 0x3b6b100d, 0x31000513,   // uk.mk.ru_653 so.nl.un_320  lt.ceb.so_554 fr.az.un_650
  0x06121007, 0x17001e08, 0x23190b0b, 0x1b190b04,   // lt.hu.de_432 ms.sr.un_430  es.gl.ca_542 es.gl.tr_332
  // [3b90]
  0x0c001318, 0x0c2012a7, 0x0d321604, 0x07190b13,   // et.sv.un_740 hu.sq.sv_532  hr.bs.cs_332 es.gl.it_665
  0x29004a1a, 0x2a001b19, 0x04641eee, 0x10001604,   // yo.sl.un_760 tr.mt.un_750  ms.lg.fi_422 hr.lt.un_320
  0x2100130c, 0x1e1c1a0c, 0x28000a0d, 0x20000c12,   // et.jw.un_530 tl.id.ms_543  pt.sw.un_540 sv.sq.un_640
  0x1729100c, 0x04171112, 0x110305a0, 0x1a3b6b07,   // lt.sl.sr_543 ro.sr.ru_654  fr.nl.ro_322 ceb.so.tl_432
  // [3ba0]
  0x291055ad, 0x3b1364a4, 0x20000d02, 0x04033f0c,   // rw.lt.sl_643 lg.et.so_433  cs.sq.un_220 af.nl.fi_543
  0x1707100c, 0x13006407, 0x530d0407, 0x29162d0c,   // be.bg.sr_543 lg.et.un_420  fi.cs.ht_432 sk.hr.sl_543
  0x0c040dee, 0x13000802, 0x016b1a07, 0x1827280c,   // cs.fi.sv_422 no.et.un_220  tl.ceb.en_432 sw.gd.ga_543
  0x3b030804, 0x1b002813, 0x131201a0, 0x10070a12,   // no.nl.so_332 sw.tr.un_650  en.hu.et_322 mk.bg.be_654
  // [3bb0]
  0x03352807, 0x3f355505, 0x551b3155, 0x281805a7,   // sw.zu.nl_432 rw.zu.af_333  az.tr.rw_442 fr.ga.sw_532
  0x2500350c, 0x034a13a6, 0x3f036405, 0x1c002702,   // zu.eu.un_530 et.yo.nl_521  lg.nl.af_333 gd.id.un_220
  0x12645308, 0x27004a07, 0x0800070d, 0x32291711,   // ht.lg.hu_443 yo.gd.un_420  bg.uk.un_540 sr.sl.bs_653
  0x08001704, 0x17003208, 0x0d002102, 0x35003b0c,   // sr.uk.un_320 bs.sr.un_430  jw.cs.un_220 so.zu.un_530
  // [3bc0]
  0x233b13ec, 0x3500031a, 0x64353104, 0x4a00521b,   // et.so.ca_644 nl.zu.un_760  az.zu.lg_332 ha.yo.un_770
  0x52006420, 0x0000642d, 0x286b1a04, 0x0864350b,   // lg.ha.un_850 lg.un.un_A00  tl.ceb.sw_332 zu.lg.no_542
  0x256b4aee, 0x35063f13, 0x12211c08, 0x23005304,   // yo.ceb.eu_422 af.de.zu_665  id.jw.hu_443 ht.ca.un_320
  0x644a3504, 0x3f2d29a4, 0x130c0e07, 0x35204aa0,   // zu.yo.lg_332 sl.sk.af_433  is.sv.et_432 yo.sq.zu_322
  // [3bd0]
  0x35006420, 0x01310204, 0x3f000702, 0x0f0d0907,   // lg.zu.un_850 da.az.en_332  it.af.un_220 pl.cs.lv_432
  0x06130c11, 0x3b2752a0, 0x250c1304, 0x3b000804,   // sv.et.de_653 ha.gd.so_322  et.sv.eu_332 no.so.un_320
  0x272d0d05, 0x213b270c, 0x32160905, 0x104a6808,   // cs.sk.gd_333 gd.so.jw_543  pl.hr.bs_333 ig.yo.lt_443
  0x03080c12, 0x11001721, 0x031c2104, 0x2a011308,   // sv.no.nl_654 sr.ro.un_860  jw.id.nl_332 et.en.mt_443
  // [3be0]
  0x1a005509, 0x0b0407af, 0x1c3b6ba4, 0x0c190b0d,   // rw.tl.un_440 it.fi.es_655  ceb.so.id_433 es.gl.sv_554
  0x212b3509, 0x13005504, 0x3f034a04, 0x0c081204,   // zu.vi.jw_444 rw.et.un_320  yo.nl.af_332 hu.no.sv_332
  0x04033ba0, 0x2a07270c, 0x3f0413a4, 0x3b033f08,   // so.nl.fi_322 gd.it.mt_543  et.fi.af_433 af.nl.so_443
  0x2a00070d, 0x52000707, 0x190b2360, 0x3f031314,   // it.mt.un_540 it.ha.un_420  ca.es.gl_664 et.nl.af_666
  // [3bf0]
  0x190b230e, 0x0e645204, 0x3b033f0e, 0x0b0a1811,   // ca.es.gl_555 ha.lg.is_332  af.nl.so_555 ga.pt.es_653
  0x07016b02, 0x27011f04, 0x08070a14, 0x07100a14,   // ceb.en.it_222 cy.en.gd_332  mk.bg.uk_666 mk.be.bg_666
  0x27001807, 0x04081109, 0x133f03a4, 0x061e6ea4,   // ga.gd.un_420 ro.uk.ru_444  nl.af.et_433 hmn.ms.de_433
  0x23001212, 0x3b3f0309, 0x2a003f04, 0x1f002107,   // hu.ca.un_640 nl.af.so_444  af.mt.un_320 jw.cy.un_420

  // [3c00]
  0x1306040d, 0x2a2506a0, 0x190b5205, 0x1800210b,   // fi.de.et_554 de.eu.mt_322  ha.es.gl_333 fa.ar.un_520
  0x04070802, 0x356b1aec, 0x13003504, 0x0e001204,   // uk.bg.ru_222 tl.ceb.zu_644  zu.et.un_320 hu.is.un_320
  0x6e000512, 0x18002d08, 0x1a6b2511, 0x1731100e,   // fr.hmn.un_640 sk.ga.un_430  eu.ceb.tl_653 lt.az.sr_555
  0x35641a0c, 0x13002104, 0x1a000904, 0x100411ee,   // tl.lg.zu_543 jw.et.un_320  pl.tl.un_320 ro.ru.be_422
  // [3c10]
  0x311e1c0c, 0x1c1e2107, 0x1700110e, 0x4a08050c,   // id.ms.az_543 jw.ms.id_432  ro.sr.un_550 fr.no.yo_543
  0x07081702, 0x1e1c1a0e, 0x351a64a4, 0x1c121ea9,   // sr.uk.bg_222 tl.id.ms_555  lg.tl.zu_433 ms.hu.id_544
  0x0a110405, 0x201304a9, 0x040817a9, 0x033f0d12,   // ru.ro.mk_333 fi.et.sq_544  sr.uk.ru_544 cs.af.nl_654
  0x21001c0e, 0x3b030f0d, 0x231a1109, 0x08000a02,   // id.jw.un_550 lv.nl.so_554  ro.tl.ca_444 mk.uk.un_220
  // [3c20]
  0x09292504, 0x1e002504, 0x2300112b, 0x20001305,   // eu.sl.pl_332 eu.ms.un_320  ro.ca.un_980 et.sq.un_330
  0x2b6455a4, 0x55001a0d, 0x23002505, 0x1b113113,   // rw.lg.vi_433 tl.rw.un_540  eu.ca.un_330 az.ro.tr_665
  0x0200130c, 0x2800110d, 0x0e1220ee, 0x12250da4,   // et.da.un_530 ro.sw.un_540  sq.hu.is_422 cs.eu.hu_433
  0x0203060b, 0x0a000f08, 0x311b1e0c, 0x110c2307,   // de.nl.da_542 lv.pt.un_430  ms.tr.az_543 ca.sv.ro_432
  // [3c30]
  0x25001904, 0x0c0d0412, 0x1000071a, 0x060b25ad,   // gl.eu.un_320 fi.cs.sv_654  it.lt.un_760 eu.es.de_643
  0x0d002912, 0x112a23ec, 0x051123a0, 0x641a01ad,   // sl.cs.un_640 ca.mt.ro_644  ca.ro.fr_322 en.tl.lg_643
  0x1812200c, 0x19002513, 0x08002512, 0x1a1e1caf,   // sq.hu.ga_543 eu.gl.un_650  eu.no.un_640 id.ms.tl_655
  0x1e2a310c, 0x352368ee, 0x3b645504, 0x08002534,   // az.mt.ms_543 ig.ca.zu_422  rw.lg.so_332 eu.no.un_A80
  // [3c40]
  0x01006e0c, 0x10001a05, 0x1b1f0b0c, 0x016b68a0,   // hmn.en.un_530 tl.lt.un_330  es.cy.tr_543 ig.ceb.en_322
  0x6e003f0e, 0x0e005507, 0x07190a09, 0x3f0364a4,   // af.hmn.un_550 rw.is.un_420  pt.gl.it_444 lg.nl.af_433
  0x3555645a, 0x06181f07, 0x19110a0e, 0x23120407,   // lg.rw.zu_553 cy.ga.de_432  pt.ro.gl_555 fi.hu.ca_432
  0x5264060c, 0x2a002314, 0x12092da7, 0x6e0a3108,   // de.lg.ha_543 ca.mt.un_660  sk.pl.hu_532 az.pt.hmn_443
  // [3c50]
  0x0a081007, 0x136b3b12, 0x06000523, 0x354a6413,   // be.uk.mk_432 so.ceb.et_654  fr.de.un_880 lg.yo.zu_665
  0x040c13a4, 0x20050b0c, 0x03001021, 0x0a002508,   // et.sv.fi_433 es.fr.sq_543  lt.nl.un_860 eu.pt.un_430
  0x12024aa6, 0x11000704, 0x3f070107, 0x1a6b1309,   // yo.da.hu_521 it.ro.un_320  en.it.af_432 et.ceb.tl_444
  0x311206ee, 0x072301a0, 0x0e001f12, 0x1713520c,   // de.hu.az_422 en.ca.it_322  cy.is.un_640 ha.et.sr_543
  // [3c60]
  0x13045207, 0x010c19a0, 0x1b0e64a0, 0x1b6e0fa7,   // ha.fi.et_432 gl.sv.en_322  lg.is.tr_322 lv.hmn.tr_532
  0x55283b02, 0x64080205, 0x1a106ba9, 0x1a5564ee,   // so.sw.rw_222 da.no.lg_333  ceb.lt.tl_544 lg.rw.tl_422
  0x6b1a1ea4, 0x6e000f1a, 0x1f000b04, 0x0d002502,   // ms.tl.ceb_433 lv.hmn.un_760  es.cy.un_320 eu.cs.un_220
  0x3f072aa4, 0x101711a4, 0x53022507, 0x13000f02,   // mt.it.af_433 ro.sr.be_433  eu.da.ht_432 lv.et.un_220
  // [3c70]
  0x0c001804, 0x1f1806a0, 0x03000623, 0x5216280c,   // ga.sv.un_320 de.ga.cy_322  de.nl.un_880 sw.hr.ha_543
  0x3564530c, 0x0400080c, 0x040a17ee, 0x11041013,   // ht.lg.zu_543 uk.ru.un_530  sr.mk.ru_422 be.ru.ro_665
  0x13080e04, 0x3b313511, 0x3500270e, 0x04030f04,   // is.no.et_332 zu.az.so_653  gd.zu.un_550 lv.nl.fi_332
  0x04111704, 0x0f191007, 0x11070412, 0x25003507,   // sr.ro.ru_332 lt.gl.lv_432  ru.bg.ro_654 zu.eu.un_420
  // [3c80]
  0x0d1c09ee, 0x04060ca0, 0x1b001607, 0x35251212,   // hi.mr.ne_422 sv.de.fi_322  hr.tr.un_420 hu.eu.zu_654
  0x3100060c, 0x170a10a0, 0x3f00100e, 0x130f2507,   // de.az.un_530 be.mk.sr_322  lt.af.un_550 eu.lv.et_432
  0x1b000612, 0x0413060c, 0x12090307, 0x2a00041b,   // de.tr.un_640 de.et.fi_543  nl.pl.hu_432 fi.mt.un_770
  0x16001307, 0x0a081013, 0x071827ac, 0x190b21a9,   // et.hr.un_420 be.uk.mk_665  gd.ga.it_632 jw.es.gl_544
  // [3c90]
  0x09001219, 0x041108a4, 0x173216ad, 0x27091fa7,   // hu.pl.un_750 uk.ro.ru_433  hr.bs.sr_643 cy.pl.gd_532
  0x1b0306ad, 0x12060307, 0x04292aee, 0x040710ad,   // de.nl.tr_643 nl.de.hu_432  mt.sl.fi_422 be.bg.ru_643
  0x232a20a4, 0x10001108, 0x321629a0, 0x08100460,   // sq.mt.ca_433 ro.be.un_430  sl.hr.bs_322 ru.be.uk_664
  0x21132aa9, 0x3f1e1c08, 0x230b1907, 0x35002121,   // mt.et.jw_544 id.ms.af_443  gl.es.ca_432 jw.zu.un_860
  // [3ca0]
  0x25001b0d, 0x17290955, 0x0e1009a0, 0x320f21a4,   // tr.eu.un_540 pl.sl.sr_442  pl.lt.is_322 jw.lv.bs_433
  0x1b210112, 0x043f2a05, 0x55530507, 0x214a3b0c,   // en.jw.tr_654 mt.af.fi_333  fr.ht.rw_432 so.yo.jw_543
  0x2500320c, 0x3f0e0205, 0x2a0c0408, 0x0e0f1b04,   // bs.eu.un_530 da.is.af_333  fi.sv.mt_443 tr.lv.is_332
  0x04191c07, 0x3b5201a4, 0x1b523ba0, 0x07000508,   // id.gl.fi_432 en.ha.so_433  so.ha.tr_322 fr.it.un_430
  // [3cb0]
  0x1e1c2814, 0x3f523ba4, 0x071c1ead, 0x0a003b0e,   // sw.id.ms_666 so.ha.af_433  ms.id.it_643 so.pt.un_550
  0x3f3b0408, 0x103b19a4, 0x271707a0, 0x070511a4,   // fi.so.af_443 gl.so.lt_433  it.sr.gd_322 ro.fr.it_433
  0x041e1c08, 0x08003f07, 0x123b280c, 0x0a003b07,   // id.ms.fi_443 af.no.un_420  sw.so.hu_543 so.pt.un_420
  0x3b003f12, 0x3b643fee, 0x291c0f07, 0x08020aa0,   // af.so.un_640 af.lg.so_422  lv.id.sl_432 pt.da.no_322
  // [3cc0]
  0x070a17a7, 0x3f0108ee, 0x35004a08, 0x08023baf,   // sr.mk.bg_532 no.en.af_422  yo.zu.un_430 so.da.no_655
  0x07251907, 0x35003b19, 0x080f0ea4, 0x351f4a09,   // gl.eu.it_432 so.zu.un_750  is.lv.no_433 yo.cy.zu_444
  0x2b001102, 0x04100705, 0x2d000104, 0x02002b05,   // ro.vi.un_220 bg.be.ru_333  en.sk.un_320 vi.da.un_330
  0x2d0d310c, 0x1a000e13, 0x6b1e1c11, 0x17005507,   // az.cs.sk_543 is.tl.un_650  id.ms.ceb_653 rw.sr.un_420
  // [3cd0]
  0x1b002812, 0x23001c08, 0x5200680e, 0x28005208,   // sw.tr.un_640 id.ca.un_430  ig.ha.un_550 ha.sw.un_430
  0x0c640808, 0x133f040d, 0x27002b0d, 0x04133f0c,   // no.lg.sv_443 fi.af.et_554  vi.gd.un_540 af.et.fi_543
  0x13640414, 0x270d0607, 0x04132511, 0x180106ac,   // fi.lg.et_666 de.cs.gd_432  eu.et.fi_653 de.en.ga_632
  0x0e2155a4, 0x2b004a13, 0x0719200c, 0x27004a1a,   // rw.jw.is_433 yo.vi.un_650  sq.gl.it_543 yo.gd.un_760
  // [3ce0]
  0x13000a04, 0x251e1c55, 0x230a520b, 0x4a532104,   // pt.et.un_320 id.ms.eu_442  ha.pt.ca_542 jw.ht.yo_332
  0x35006434, 0x5568640c, 0x20320413, 0x1b311a07,   // lg.zu.un_A80 lg.ig.rw_543  fi.bs.sq_665 tl.az.tr_432
  0x12190b02, 0x212d2808, 0x1b001a04, 0x0e2807a9,   // es.gl.hu_222 sw.sk.jw_443  tl.tr.un_320 it.sw.is_544
  0x2a1c55ee, 0x321a4aa7, 0x170a0405, 0x1c1b310b,   // rw.id.mt_422 yo.tl.bs_532  ru.mk.sr_333 az.tr.id_542
  // [3cf0]
  0x686b0105, 0x0c092da0, 0x2a051308, 0x0b1b5205,   // en.ceb.ig_333 sk.pl.sv_322  et.fr.mt_443 ha.tr.es_333
  0x1c000b04, 0x311b0ba0, 0x31321704, 0x321620a9,   // es.id.un_320 es.tr.az_322  sr.bs.az_332 sq.hr.bs_544
  0x172104ee, 0x080a0705, 0x0d00290d, 0x2100060b,   // fi.jw.sr_422 bg.mk.uk_333  sl.cs.un_540 de.jw.un_520
  0x080e2aa6, 0x0e1b3160, 0x272a1804, 0x64552302,   // mt.is.no_521 az.tr.is_664  ga.mt.gd_332 ca.rw.lg_222
  // [3d00]
  0x0410070c, 0x311b0eee, 0x08110a05, 0x17071108,   // bg.be.ru_543 is.tr.az_422  mk.ro.uk_333 ro.bg.sr_443
  0x00004a37, 0x101a6b07, 0x1e524a02, 0x35213fa0,   // yo.un.un_B00 ceb.tl.lt_432  yo.ha.ms_222 af.jw.zu_322
  0x01030604, 0x6e000619, 0x27070308, 0x532513ec,   // de.nl.en_332 de.hmn.un_750  nl.it.gd_443 et.eu.ht_644
  0x0600270d, 0x0600291a, 0x0f1006a9, 0x6b000107,   // gd.de.un_540 sl.de.un_760  de.lt.lv_544 en.ceb.un_420
  // [3d10]
  0x1b001e02, 0x2d0d06ec, 0x4a00350c, 0x0c1906a7,   // ms.tr.un_220 de.cs.sk_644  zu.yo.un_530 de.gl.sv_532
  0x3f062507, 0x1b080305, 0x1a002a08, 0x21285504,   // eu.de.af_432 nl.no.tr_333  mt.tl.un_430 rw.sw.jw_332
  0x25000914, 0x354a1aa4, 0x070a04a0, 0x64282002,   // pl.eu.un_660 tl.yo.zu_433  ru.mk.bg_322 sq.sw.lg_222
  0x3f03010b, 0x555364ec, 0x082902a4, 0x1b002504,   // en.nl.af_542 lg.ht.rw_644  da.sl.no_433 eu.tr.un_320
  // [3d20]
  0x041325a4, 0x28002304, 0x08102004, 0x03060e0c,   // eu.et.fi_433 ca.sw.un_320  sq.lt.no_332 is.de.nl_543
  0x01103fa4, 0x03000622, 0x0916290c, 0x0b23010c,   // af.lt.en_433 de.nl.un_870  sl.hr.pl_543 en.ca.es_543
  0x123152ee, 0x1f1012af, 0x08006402, 0x1e000c08,   // ha.az.hu_422 hu.lt.cy_655  lg.no.un_220 sv.ms.un_430
  0x02000821, 0x2725020d, 0x19070aec, 0x2a00072c,   // no.da.un_860 da.eu.gd_554  pt.it.gl_644 it.mt.un_990
  // [3d30]
  0x052308a0, 0x18000808, 0x2a19180c, 0x271101ee,   // no.ca.fr_322 no.ga.un_430  ga.gl.mt_543 en.ro.gd_422
  0x0d09130c, 0x03001602, 0x0605010c, 0x17000708,   // bh.hi.ne_543 hr.nl.un_220  en.fr.de_543 bg.sr.un_430
  0x2b6b0107, 0x1c000305, 0x1e1c35a9, 0x642855a7,   // en.ceb.vi_432 nl.id.un_330  zu.id.ms_544 rw.sw.lg_532
  0x53050607, 0x060302a4, 0x0e0c2aad, 0x216b06a0,   // de.fr.ht_432 da.nl.de_433  mt.sv.is_643 de.ceb.jw_322
  // [3d40]
  0x3f0e0609, 0x231e1c02, 0x20002a04, 0x25001f1b,   // de.is.af_444 id.ms.ca_222  mt.sq.un_320 cy.eu.un_770
  0x2a00112a, 0x64551a0c, 0x0b000108, 0x6b1a01ee,   // ro.mt.un_970 tl.rw.lg_543  en.es.un_430 en.tl.ceb_422
  0x55641a55, 0x184a2b08, 0x1a536b09, 0x28090455,   // tl.lg.rw_442 vi.yo.ga_443  ceb.ht.tl_444 fi.pl.sw_442
  0x25102807, 0x2b004a09, 0x6455355a, 0x53001e0d,   // sw.lt.eu_432 yo.vi.un_440  zu.rw.lg_553 ms.ht.un_540
  // [3d50]
  0x091710a0, 0x101708a9, 0x0c061107, 0x3f080c0d,   // lt.sr.pl_322 uk.sr.be_544  ro.de.sv_432 sv.no.af_554
  0x05003b07, 0x0f1c2502, 0x23000502, 0x0e2b4a0c,   // so.fr.un_420 eu.id.lv_222  fr.ca.un_220 yo.vi.is_543
  0x271007a0, 0x0600020c, 0x550531ad, 0x2b004a21,   // it.lt.gd_322 da.de.un_530  az.fr.rw_643 yo.vi.un_860
  0x1e1a6b07, 0x21011aee, 0x07252904, 0x64525505,   // ceb.tl.ms_432 tl.en.jw_422  sl.eu.it_332 rw.ha.lg_333
  // [3d60]
  0x64001a19, 0x1b2855a9, 0x0b000404, 0x1a1c6b08,   // tl.lg.un_750 rw.sw.tr_544  fi.es.un_320 ceb.id.tl_443
  0x1b2155a0, 0x251304ee, 0x0d000504, 0x02063112,   // rw.jw.tr_322 fi.et.eu_422  fr.cs.un_320 az.de.da_654
  0x132025a4, 0x25001e0c, 0x31351b08, 0x191b350c,   // eu.sq.et_433 ms.eu.un_530  tr.zu.az_443 zu.tr.gl_543
  0x5531350c, 0x6431520c, 0x070a1004, 0x19003118,   // zu.az.rw_543 ha.az.lg_543  be.mk.bg_332 az.gl.un_740
  // [3d70]
  0x530509a7, 0x283f06a4, 0x55311b0d, 0x0d0553a7,   // pl.fr.ht_532 de.af.sw_433  tr.az.rw_554 ht.fr.cs_532
  0x351b310d, 0x1121280c, 0x352031a4, 0x08000404,   // az.tr.zu_554 sw.jw.ro_543  az.sq.zu_433 ru.uk.un_320
  0x0a171005, 0x06001a04, 0x1e1c1a14, 0x080410ad,   // be.sr.mk_333 tl.de.un_320  tl.id.ms_666 be.ru.uk_643
  0x08040713, 0x1200250d, 0x52214a07, 0x21005312,   // bg.ru.uk_665 eu.hu.un_540  yo.jw.ha_432 ht.jw.un_640
  // [3d80]
  0x08101104, 0x31003202, 0x12006b08, 0x08022714,   // ro.be.uk_332 bs.az.un_220  ceb.hu.un_430 gd.da.no_666
  0x1f031804, 0x03083fec, 0x232153ec, 0x190b18a0,   // ga.nl.cy_332 af.no.nl_644  ht.jw.ca_644 ga.es.gl_322
  0x061827af, 0x0e1e1c02, 0x066b1a0c, 0x1b0d0302,   // gd.ga.de_655 id.ms.is_222  tl.ceb.de_543 nl.cs.tr_222
  0x011803a0, 0x0655350c, 0x1b003b12, 0x2b182702,   // nl.ga.en_322 zu.rw.de_543  so.tr.un_640 gd.ga.vi_222
  // [3d90]
  0x2a23200c, 0x0b232708, 0x28004a0e, 0x18310707,   // sq.ca.mt_543 gd.ca.es_443  yo.sw.un_550 it.az.ga_432
  0x040a08a7, 0x6b121aaf, 0x01020fa0, 0x010c08a0,   // uk.mk.ru_532 tl.hu.ceb_655  lv.da.en_322 no.sv.en_322
  0x12002b08, 0x35000304, 0x11182704, 0x0e002b11,   // vi.hu.un_430 nl.zu.un_320  gd.ga.ro_332 vi.is.un_630
  0x0c001302, 0x3b003204, 0x3f001a07, 0x21002b08,   // et.sv.un_220 bs.so.un_320  tl.af.un_420 vi.jw.un_430
  // [3da0]
  0x03002107, 0x02002505, 0x05124aee, 0x040a07ee,   // jw.nl.un_420 eu.da.un_330  yo.hu.fr_422 bg.mk.ru_422
  0x2d002020, 0x10000a05, 0x3b5501a0, 0x0d292da0,   // sq.sk.un_850 mk.be.un_330  en.rw.so_322 sk.sl.cs_322
  0x05640704, 0x05001f08, 0x10001a02, 0x191a2107,   // it.lg.fr_332 cy.fr.un_430  tl.lt.un_220 jw.tl.gl_432
  0x3f000f04, 0x122b19ad, 0x051103a9, 0x081017a0,   // lv.af.un_320 gl.vi.hu_643  nl.ro.fr_544 sr.be.uk_322
  // [3db0]
  0x04001b0e, 0x02030f07, 0x21004a05, 0x0a001721,   // tr.fi.un_550 lv.nl.da_432  yo.jw.un_330 sr.mk.un_860
  0x05011111, 0x05110304, 0x11000322, 0x31003512,   // ro.en.fr_653 nl.ro.fr_332  nl.ro.un_870 zu.az.un_640
  0x091c1311, 0x32212d07, 0x08170a0c, 0x3b003502,   // bh.mr.hi_653 sk.jw.bs_432  mk.sr.uk_543 zu.so.un_220
  0x10000421, 0x021a3f0d, 0x1125010c, 0x2307110e,   // ru.be.un_860 af.tl.da_554  en.eu.ro_543 ro.it.ca_555
  // [3dc0]
  0x0c001f07, 0x190b230c, 0x1100270c, 0x110501ad,   // cy.sv.un_420 ca.es.gl_543  gd.ro.un_530 en.fr.ro_643
  0x255564a0, 0x06003b0c, 0x206b35ad, 0x35094aa7,   // lg.rw.eu_322 so.de.un_530  zu.ceb.sq_643 yo.pl.zu_532
  0x20051305, 0x3b063f0c, 0x11052da4, 0x2a290fa4,   // et.fr.sq_333 af.de.so_543  sk.fr.ro_433 lv.sl.mt_433
  0x53055507, 0x11032da4, 0x03001113, 0x03010505,   // rw.fr.ht_432 sk.nl.ro_433  ro.nl.un_650 fr.en.nl_333
  // [3dd0]
  0x16000108, 0x1a002702, 0x641a1c07, 0x64355513,   // en.hr.un_430 gd.tl.un_220  id.tl.lg_432 rw.zu.lg_665
  0x23090704, 0x28000e04, 0x063f0302, 0x2505010d,   // it.pl.ca_332 is.sw.un_320  nl.af.de_222 en.fr.eu_554
  0x281a01af, 0x3b203108, 0x08040309, 0x16002802,   // en.tl.sw_655 az.sq.so_443  nl.fi.no_444 sw.hr.un_220
  0x5553350c, 0x0e000204, 0x0d002a0d, 0x3f000611,   // zu.ht.rw_543 da.is.un_320  mt.cs.un_540 de.af.un_630
  // [3de0]
  0x02003f12, 0x0c005208, 0x0d0f2d0c, 0x02003f1a,   // af.da.un_640 ha.sv.un_430  sk.lv.cs_543 af.da.un_760
  0x0723095a, 0x1c35250c, 0x04292809, 0x3f0208a4,   // pl.ca.it_553 eu.zu.id_543  sw.sl.fi_444 no.da.af_433
  0x35000912, 0x11005212, 0x0a00100c, 0x08023f0c,   // pl.zu.un_640 ha.ro.un_640  be.mk.un_530 af.da.no_543
  0x176813ee, 0x17680cee, 0x132311ec, 0x252813a9,   // et.ig.sr_422 sv.ig.sr_422  ro.ca.et_644 et.sw.eu_544
  // [3df0]
  0x020e08af, 0x32001709, 0x0d0c0807, 0x072368a7,   // no.is.da_655 sr.bs.un_440  no.sv.cs_432 ig.ca.it_532
  0x1103010c, 0x013f09ad, 0x10000f23, 0x112a0f0d,   // en.nl.ro_543 pl.af.en_643  lv.lt.un_880 lv.mt.ro_554
  0x08040711, 0x1635030c, 0x17002312, 0x1a030807,   // bg.ru.uk_653 nl.zu.hr_543  ca.sr.un_640 no.nl.tl_432
  0x6b681ea0, 0x2d0d20a4, 0x53000309, 0x071304a4,   // ms.ig.ceb_322 sq.cs.sk_433  nl.ht.un_440 fi.et.it_433
  // [3e00]
  0x3f000408, 0x2829175a, 0x0a130413, 0x04060302,   // fi.af.un_430 sr.sl.sw_553  fi.et.pt_665 nl.de.fi_222
  0x04000822, 0x03310fa0, 0x0f0820a0, 0x12000e13,   // uk.ru.un_870 lv.az.nl_322  sq.no.lv_322 is.hu.un_650
  0x200803ee, 0x0700112a, 0x12004a18, 0x21003204,   // nl.no.sq_422 ro.bg.un_970  yo.hu.un_740 bs.jw.un_320
  0x0a04070e, 0x311b0e07, 0x031304a0, 0x3f031313,   // bg.ru.mk_555 is.tr.az_432  fi.et.nl_322 et.nl.af_665
  // [3e10]
  0x0a2105a0, 0x0900120e, 0x0a0804a0, 0x280d2d11,   // fr.jw.pt_322 hu.pl.un_550  ru.uk.mk_322 sk.cs.sw_653
  0x20071102, 0x0900120d, 0x0c042a0b, 0x12060e02,   // ro.it.sq_222 hu.pl.un_540  mt.fi.sv_542 is.de.hu_222
  0x07100a09, 0x0e130cee, 0x2a172907, 0x090d13af,   // mk.be.bg_444 sv.et.is_422  sl.sr.mt_432 bh.ne.hi_655
  0x100a1705, 0x2d0d18ec, 0x0a070455, 0x6e002013,   // sr.mk.be_333 ga.cs.sk_644  ru.bg.mk_442 sq.hmn.un_650
  // [3e20]
  0x0b002809, 0x0b002804, 0x53180d07, 0x0f291704,   // sw.es.un_440 sw.es.un_320  cs.ga.ht_432 sr.sl.lv_332
  0x1e00040c, 0x17163207, 0x52002807, 0x64090eee,   // fi.ms.un_530 bs.hr.sr_432  sw.ha.un_420 is.pl.lg_422
  0x041711ad, 0x3f00050d, 0x091c1307, 0x06121b1e,   // ro.sr.ru_643 fr.af.un_540  bh.mr.hi_432 tr.hu.de_863
  0x28001a08, 0x03060aa0, 0x10281ea0, 0x100411a4,   // tl.sw.un_430 pt.de.nl_322  ms.sw.lt_322 ro.ru.be_433
  // [3e30]
  0x0f001004, 0x11033f08, 0x32292d07, 0x0805010c,   // lt.lv.un_320 af.nl.ro_443  sk.sl.bs_432 en.fr.no_543
  0x0e060ca0, 0x080235a4, 0x0c08200c, 0x0107050d,   // sv.de.is_322 zu.da.no_433  sq.no.sv_543 fr.it.en_554
  0x53000304, 0x0b18070b, 0x08130207, 0x12001b14,   // nl.ht.un_320 it.ga.es_542  da.et.no_432 tr.hu.un_660
  0x060c030c, 0x0e182308, 0x233f02a4, 0x052a01a4,   // nl.sv.de_543 ca.ga.is_443  da.af.ca_433 en.mt.fr_433
  // [3e40]
  0x12231804, 0x1e000a07, 0x353f4a04, 0x12000e12,   // ga.ca.hu_332 pt.ms.un_420  yo.af.zu_332 is.hu.un_640
  0x1b000702, 0x09112da4, 0x25001021, 0x01352107,   // it.tr.un_220 sk.ro.pl_433  lt.eu.un_860 jw.zu.en_432
  0x23006b08, 0x020428ee, 0x03103f55, 0x041711a7,   // ceb.ca.un_430 sw.fi.da_422  af.lt.nl_442 ro.sr.ru_532
  0x0c5528a7, 0x050135a0, 0x013564a7, 0x100f29ec,   // sw.rw.sv_532 zu.en.fr_322  lg.zu.en_532 sl.lv.lt_644
  // [3e50]
  0x3f082007, 0x07002a23, 0x190b1aa9, 0x13040c02,   // sq.no.af_432 mt.it.un_880  tl.es.gl_544 sv.fi.et_222
  0x060c0e0b, 0x06040eee, 0x07002302, 0x13005513,   // is.sv.de_542 is.fi.de_422  ca.it.un_220 rw.et.un_650
  0x21050aa9, 0x0e00020d, 0x1b0f5302, 0x1652090c,   // pt.fr.jw_544 da.is.un_540  ht.lv.tr_222 pl.ha.hr_543
  0x02000e0e, 0x4a002108, 0x27120e07, 0x293b3202,   // is.da.un_550 jw.yo.un_430  is.hu.gd_432 bs.so.sl_222
  // [3e60]
  0x05001108, 0x08000619, 0x055325a0, 0x2300191a,   // ro.fr.un_430 de.no.un_750  eu.ht.fr_322 gl.ca.un_760
  0x0e000c0b, 0x3b000607, 0x524a3ba0, 0x2d0d10a9,   // sv.is.un_520 de.so.un_420  so.yo.ha_322 lt.cs.sk_544
  0x08002308, 0x3b006b09, 0x2d190b04, 0x355564ad,   // ca.no.un_430 ceb.so.un_440  es.gl.sk_332 lg.rw.zu_643
  0x120e0860, 0x11003f13, 0x271206a4, 0x07003f04,   // no.is.hu_664 af.ro.un_650  de.hu.gd_433 af.it.un_320
  // [3e70]
  0x35003f09, 0x11003f05, 0x3f1105a4, 0x6b211a11,   // af.zu.un_440 af.ro.un_330  fr.ro.af_433 tl.jw.ceb_653
  0x122d2007, 0x16290da4, 0x0d002908, 0x1a280405,   // sq.sk.hu_432 cs.sl.hr_433  sl.cs.un_430 fi.sw.tl_333
  0x0a00040d, 0x0900270c, 0x0435280d, 0x08171004,   // ru.mk.un_540 gd.pl.un_530  sw.zu.fi_554 be.sr.uk_332
  0x18112707, 0x55046412, 0x1727110b, 0x1f001804,   // gd.ro.ga_432 lg.fi.rw_654  ro.gd.sr_542 ga.cy.un_320
  // [3e80]
  0x35000804, 0x100711a0, 0x091107a0, 0x521c1eec,   // no.zu.un_320 ro.bg.be_322  it.ro.pl_322 ms.id.ha_644
  0x203b520c, 0x21255307, 0x04081112, 0x55216404,   // ha.so.sq_543 ht.eu.jw_432  ro.uk.ru_654 lg.jw.rw_332
  0x0c1b0ea0, 0x21553502, 0x062d0d02, 0x3f0603ee,   // is.tr.sv_322 zu.rw.jw_222  cs.sk.de_222 nl.de.af_422
  0x2a1206ee, 0x0c031355, 0x16005508, 0x2d0d090d,   // de.hu.mt_422 et.nl.sv_442  rw.hr.un_430 pl.cs.sk_554
  // [3e90]
  0x0c001a0c, 0x2d001218, 0x0206080c, 0x040811ec,   // tl.sv.un_530 hu.sk.un_740  no.de.da_543 ro.uk.ru_644
  0x29000d04, 0x1f00030d, 0x0e003118, 0x120603a0,   // cs.sl.un_320 nl.cy.un_540  az.is.un_740 nl.de.hu_322
  0x0f1009ad, 0x12000604, 0x10081713, 0x21002312,   // pl.lt.lv_643 de.hu.un_320  sr.uk.be_665 ca.jw.un_640
  0x64002b08, 0x17161005, 0x2803100b, 0x02060307,   // vi.lg.un_430 lt.hr.sr_333  lt.nl.sw_542 nl.de.da_432
  // [3ea0]
  0x06040307, 0x0c000302, 0x2d0d0e05, 0x03006b09,   // nl.fi.de_432 nl.sv.un_220  is.cs.sk_333 ceb.nl.un_440
  0x2d001012, 0x1a046b13, 0x07170409, 0x0e3b045a,   // lt.sk.un_640 ceb.fi.tl_665  ru.sr.bg_444 fi.so.is_553
  0x10081712, 0x2a093b12, 0x3f060307, 0x016b05a9,   // sr.uk.be_654 so.pl.mt_654  nl.de.af_432 fr.ceb.en_544
  0x0700110e, 0x10001605, 0x5200040d, 0x3f000502,   // ro.bg.un_550 hr.lt.un_330  fi.ha.un_540 fr.af.un_220
  // [3eb0]
  0x3b090eec, 0x4a001307, 0x073f1111, 0x04006409,   // is.pl.so_644 et.yo.un_420  ro.af.it_653 lg.fi.un_440
  0x6b001e07, 0x4a5568a0, 0x06293fa4, 0x64006813,   // ms.ceb.un_420 ig.rw.yo_322  af.sl.de_433 ig.lg.un_650
  0x1f00231a, 0x0d110505, 0x01033fa4, 0x685564ec,   // ca.cy.un_760 fr.ro.cs_333  af.nl.en_433 lg.rw.ig_644
  0x1f0e2055, 0x0e2d0d55, 0x11000713, 0x0a2a0709,   // sq.is.cy_442 cs.sk.is_442  it.ro.un_650 it.mt.pt_444
  // [3ec0]
  0x213564ee, 0x0e002008, 0x160f29a9, 0x100a07ad,   // lg.zu.jw_422 sq.is.un_430  sl.lv.hr_544 bg.mk.be_643
  0x0d1c090b, 0x68003535, 0x0600090d, 0x0100090c,   // hi.mr.ne_542 zu.ig.un_A90  pl.de.un_540 pl.en.un_530
  0x2a0427a0, 0x0d091cec, 0x2d0d0aa9, 0x010402a0,   // gd.fi.mt_322 mr.hi.ne_644  pt.cs.sk_544 da.fi.en_322
  0x192d0d08, 0x1e032a04, 0x23000507, 0x2d0d11a0,   // cs.sk.gl_443 mt.nl.ms_332  fr.ca.un_420 ro.cs.sk_322
  // [3ed0]
  0x31001b04, 0x32090fa7, 0x32172009, 0x532305ad,   // tr.az.un_320 lv.pl.bs_532  sq.sr.bs_444 fr.ca.ht_643
  0x644a52ee, 0x16284aa7, 0x1811010b, 0x01002707,   // ha.yo.lg_422 yo.sw.hr_532  en.ro.ga_542 gd.en.un_420
  0x6b04010c, 0x3b006e12, 0x170f23ee, 0x18062707,   // en.fi.ceb_543 hmn.so.un_640  ca.lv.sr_422 gd.de.ga_432
  0x05002302, 0x04110713, 0x13006e22, 0x521e1c08,   // ca.fr.un_220 bg.ro.ru_665  hmn.et.un_870 id.ms.ha_443
  // [3ee0]
  0x32351b04, 0x1c532860, 0x18270660, 0x0f071e05,   // tr.zu.bs_332 sw.ht.id_664  de.gd.ga_664 ms.it.lv_333
  0x04132512, 0x09000305, 0x29002302, 0x52000d0d,   // eu.et.fi_654 nl.pl.un_330  ca.sl.un_220 cs.ha.un_540
  0x2a0b0405, 0x19001807, 0x0f00102b, 0x0b64110c,   // fi.es.mt_333 ga.gl.un_420  lt.lv.un_980 ro.lg.es_543
  0x18000909, 0x2a1f1109, 0x16073b07, 0x09182711,   // pl.ga.un_440 ro.cy.mt_444  so.it.hr_432 gd.ga.pl_653
  // [3ef0]
  0x321c1e0c, 0x27190a04, 0x4a170b07, 0x13020d0c,   // ms.id.bs_543 pt.gl.gd_332  es.sr.yo_432 cs.da.et_543
  0x21001f02, 0x0d004a19, 0x1a2a6ba7, 0x1f080ca7,   // cy.jw.un_220 yo.cs.un_750  ceb.mt.tl_532 sv.no.cy_532
  0x0a080704, 0x02003f14, 0x4a321755, 0x03001f07,   // bg.uk.mk_332 af.da.un_660  sr.bs.yo_442 cy.nl.un_420
  0x2928040c, 0x020e0811, 0x2b000302, 0x1f002722,   // fi.sw.sl_543 no.is.da_653  nl.vi.un_220 gd.cy.un_870
  // [3f00]
  0x2b6b010b, 0x032928a7, 0x06130c13, 0x53173b07,   // en.ceb.vi_542 sw.sl.nl_532  sv.et.de_665 so.sr.ht_432
  0x32160fec, 0x550368a6, 0x051108af, 0x13000307,   // lv.hr.bs_644 ig.nl.rw_521  no.ro.fr_655 nl.et.un_420
  0x06000c29, 0x1c3f1f02, 0x311b1220, 0x200f02a7,   // sv.de.un_960 cy.af.id_222  hu.tr.az_875 da.lv.sq_532
  0x291302ee, 0x1f003f14, 0x082b1fa0, 0x0c002004,   // da.et.sl_422 af.cy.un_660  cy.vi.no_322 sq.sv.un_320
  // [3f10]
  0x6b1701ee, 0x4a00351b, 0x6b6801ee, 0x060108a4,   // en.sr.ceb_422 zu.yo.un_770  en.ig.ceb_422 no.en.de_433
  0x3f100e0b, 0x03000614, 0x31001702, 0x0a002a02,   // is.lt.af_542 de.nl.un_660  sr.az.un_220 mt.pt.un_220
  0x232a0514, 0x04100860, 0x0a041004, 0x29002008,   // fr.mt.ca_666 uk.be.ru_664  be.ru.mk_332 sq.sl.un_430
  0x133f0f02, 0x080a1705, 0x0c080e12, 0x0f000108,   // lv.af.et_222 sr.mk.uk_333  is.no.sv_654 en.lv.un_430
  // [3f20]
  0x081003a0, 0x031301a6, 0x030501a4, 0x0e023f07,   // nl.lt.no_322 en.et.nl_521  en.fr.nl_433 af.da.is_432
  0x1f000304, 0x080223a0, 0x28001b07, 0x0900060e,   // nl.cy.un_320 ca.da.no_322  tr.sw.un_420 de.pl.un_550
  0x17000812, 0x3100061b, 0x3f0f10ad, 0x2d100d12,   // uk.sr.un_640 de.az.un_770  lt.lv.af_643 cs.lt.sk_654
  0x112d64ad, 0x18190b5a, 0x02000e07, 0x20071aad,   // lg.sk.ro_643 es.gl.ga_553  is.da.un_420 tl.it.sq_643
  // [3f30]
  0x556b2508, 0x06030204, 0x13551e07, 0x1f001a07,   // eu.ceb.rw_443 da.nl.de_332  ms.rw.et_432 tl.cy.un_420
  0x080c06ee, 0x01000a07, 0x0e5220ee, 0x08170408,   // de.sv.no_422 pt.en.un_420  sq.ha.is_422 ru.sr.uk_443
  0x17291e07, 0x1b062904, 0x180301a6, 0x1200350c,   // ms.sl.sr_432 sl.de.tr_332  en.nl.ga_521 zu.hu.un_530
  0x4a6e6ba0, 0x190b07a4, 0x5235640c, 0x08060ea0,   // ceb.hmn.yo_322 it.es.gl_433  lg.zu.ha_543 is.de.no_322
  // [3f40]
  0x05002313, 0x35091f05, 0x0d311b12, 0x10000104,   // ca.fr.un_650 cy.pl.zu_333  tr.az.cs_654 en.lt.un_320
  0x061e1ca0, 0x6b001109, 0x0f3f035a, 0x3b2035ee,   // id.ms.de_322 ro.ceb.un_440  nl.af.lv_553 zu.sq.so_422
  0x2a001b0e, 0x0108020d, 0x31002512, 0x0c25020c,   // tr.mt.un_550 da.no.en_554  eu.az.un_640 da.eu.sv_543
  0x066b550d, 0x3100280d, 0x08251108, 0x071008a9,   // rw.ceb.de_554 sw.az.un_540  ro.eu.no_443 uk.be.bg_544
  // [3f50]
  0x130d09a4, 0x3b3f35ad, 0x021a1213, 0x092b23ee,   // hi.ne.bh_433 zu.af.so_643  hu.tl.da_665 ca.vi.pl_422
  0x08001018, 0x5525520c, 0x082d0d0b, 0x0c311b12,   // be.uk.un_740 ha.eu.rw_543  cs.sk.no_542 tr.az.sv_654
  0x35190bee, 0x3b126bad, 0x523b2a07, 0x09060107,   // es.gl.zu_422 ceb.hu.so_643  mt.so.ha_432 en.de.pl_432
  0x285355ec, 0x353b1aa4, 0x251203a7, 0x09000702,   // rw.ht.sw_644 tl.so.zu_433  nl.hu.eu_532 it.pl.un_220
  // [3f60]
  0x190d2d07, 0x21001823, 0x31171602, 0x2964550c,   // sk.cs.gl_432 ar.fa.un_880  hr.sr.az_222 rw.lg.sl_543
  0x17292d0c, 0x1c163bee, 0x3b1e1c0c, 0x17000705,   // sk.sl.sr_543 so.hr.id_422  id.ms.so_543 bg.sr.un_330
  0x2835550c, 0x13031ca0, 0x0e003f14, 0x29006b21,   // rw.zu.sw_543 id.nl.et_322  af.is.un_660 ceb.sl.un_860
  0x110417af, 0x03000204, 0x12021a04, 0x1300031a,   // sr.ru.ro_655 da.nl.un_320  tl.da.hu_332 nl.et.un_760
  // [3f70]
  0x55080204, 0x0c003509, 0x0d004a0d, 0x0b005512,   // da.no.rw_332 zu.sv.un_440  yo.cs.un_540 rw.es.un_640
  0x6455350d, 0x21005507, 0x3f0301af, 0x110b01a4,   // zu.rw.lg_554 rw.jw.un_420  en.nl.af_655 en.es.ro_433
  0x2d000921, 0x213f03a0, 0x113f2d04, 0x2d091f11,   // pl.sk.un_860 nl.af.jw_322  sk.af.ro_332 cy.pl.sk_653
  0x286b0107, 0x11033f0c, 0x6b68010c, 0x3f00050e,   // en.ceb.sw_432 af.nl.ro_543  en.ig.ceb_543 fr.af.un_550
  // [3f80]
  0x4a2b0ead, 0x0f00090e, 0x05003f04, 0x0e000805,   // is.vi.yo_643 pl.lv.un_550  af.fr.un_320 no.is.un_330
  0x133f0aaf, 0x0e000214, 0x2d191008, 0x532d090c,   // pt.af.et_655 da.is.un_660  lt.gl.sk_443 pl.sk.ht_543
  0x0e02080b, 0x2700070c, 0x2d000913, 0x05033f0c,   // no.da.is_542 it.gd.un_530  pl.sk.un_650 af.nl.fr_543
  0x53182d04, 0x2d003f14, 0x23110508, 0x09282d09,   // sk.ga.ht_332 af.sk.un_660  fr.ro.ca_443 sk.sw.pl_444
  // [3f90]
  0x071011a7, 0x52002504, 0x25002d08, 0x32285207,   // ro.be.bg_532 eu.ha.un_320  sk.eu.un_430 ha.sw.bs_432
  0x180627ad, 0x3f001819, 0x12002d05, 0x21272807,   // gd.de.ga_643 ga.af.un_750  sk.hu.un_330 sw.gd.jw_432
  0x070408a9, 0x190d0e02, 0x04100a07, 0x04000c05,   // uk.ru.bg_544 is.cs.gl_222  mk.be.ru_432 sv.fi.un_330
  0x08170a12, 0x0f002808, 0x28231bee, 0x320e280c,   // mk.sr.uk_654 sw.lv.un_430  tr.ca.sw_422 sw.is.bs_543
  // [3fa0]
  0x35645204, 0x31552855, 0x28005533, 0x2d0d29a4,   // ha.lg.zu_332 sw.rw.az_442  rw.sw.un_A70 sl.cs.sk_433
  0x12001e11, 0x6800551a, 0x31005507, 0x55286807,   // ms.hu.un_630 rw.ig.un_760  rw.az.un_420 ig.sw.rw_432
  0x162d0d07, 0x4a6825af, 0x6e001022, 0x0c001a02,   // cs.sk.hr_432 eu.ig.yo_655  lt.hmn.un_870 tl.sv.un_220
  0x1c0d0960, 0x0c1f08a9, 0x0a1b2355, 0x28521e07,   // hi.ne.mr_664 no.cy.sv_544  ca.tr.pt_442 ms.ha.sw_432
  // [3fb0]
  0x210e1fa0, 0x645228a9, 0x0c2a0208, 0x5528680c,   // cy.is.jw_322 sw.ha.lg_544  da.mt.sv_443 ig.sw.rw_543
  0x2800551b, 0x55645213, 0x35642755, 0x3f030407,   // rw.sw.un_770 ha.lg.rw_665  gd.lg.zu_442 fi.nl.af_432
  0x13680fa4, 0x521e31a7, 0x4a3564a9, 0x13002514,   // lv.ig.et_433 az.ms.ha_532  lg.zu.yo_544 eu.et.un_660
  0x286855a4, 0x1e0f2508, 0x2012550c, 0x21003b0b,   // rw.ig.sw_433 eu.lv.ms_443  rw.hu.sq_543 so.jw.un_520
  // [3fc0]
  0x25006821, 0x522755ee, 0x133564ee, 0x1f033f13,   // ig.eu.un_860 rw.gd.ha_422  lg.zu.et_422 af.nl.cy_665
  0x3b2a0712, 0x2d0d5205, 0x231f3f07, 0x641a550c,   // it.mt.so_654 ha.cs.sk_333  af.cy.ca_432 rw.tl.lg_543
  0x20001e04, 0x35121307, 0x11200e0c, 0x020e08ad,   // ms.sq.un_320 et.hu.zu_432  is.sq.ro_543 no.is.da_643
  0x2d172907, 0x21000312, 0x4a1218a4, 0x0a081104,   // sl.sr.sk_432 nl.jw.un_640  ga.hu.yo_433 ro.uk.mk_332
  // [3fd0]
  0x13313ba7, 0x21551c11, 0x311e55ee, 0x0d1f31a4,   // so.az.et_532 id.rw.jw_653  rw.ms.az_422 az.cy.cs_433
  0x53003513, 0x2b072307, 0x02080c13, 0x213f1355,   // zu.ht.un_650 ca.it.vi_432  sv.no.da_665 et.af.jw_442
  0x110805a4, 0x2a001b13, 0x192001a0, 0x0900280c,   // fr.no.ro_433 tr.mt.un_650  en.sq.gl_322 sw.pl.un_530
  0x64003b1b, 0x1c130d08, 0x1a003b1b, 0x033f1312,   // so.lg.un_770 ne.bh.mr_443  so.tl.un_770 et.af.nl_654
  // [3fe0]
  0x311a35ee, 0x17100a0b, 0x081011a0, 0x20001e08,   // zu.tl.az_422 mk.be.sr_542  ro.be.uk_322 ms.sq.un_430
  0x0e080209, 0x050d2dee, 0x2b000a07, 0x0a170455,   // da.no.is_444 sk.cs.fr_422  pt.vi.un_420 ru.sr.mk_442
  0x2a3b03a0, 0x28005304, 0x041011a4, 0x08000e07,   // nl.so.mt_322 ht.sw.un_320  ro.be.ru_433 is.no.un_420
  0x0c104aa7, 0x03001305, 0x170a1005, 0x64001c02,   // yo.lt.sv_532 et.nl.un_330  be.mk.sr_333 id.lg.un_220
  // [3ff0]
  0x050601a0, 0x0700101a, 0x52000402, 0x1b321608,   // en.de.fr_322 be.bg.un_760  fi.ha.un_220 hr.bs.tr_443
  0x1c130dec, 0x13002a0d, 0x21251eaf, 0x041017ee,   // ne.bh.mr_644 mt.et.un_540  ms.eu.jw_655 sr.be.ru_422
  0x5500130e, 0x31000a02, 0x1f283504, 0x6400550b,   // et.rw.un_550 pt.az.un_220  zu.sw.cy_332 rw.lg.un_520
  0x1300090b, 0x0a0d180c, 0x1811270c, 0x0e001213,   // hi.bh.un_520 ga.cs.pt_543  gd.ro.ga_543 hu.is.un_650

  // [4000]
  0x0a0711a0, 0x32350607, 0x12205508, 0x12645512,   // ro.bg.mk_322 de.zu.bs_432  rw.sq.hu_443 rw.lg.hu_654
  0x09642804, 0x211a250c, 0x13552508, 0x3f001608,   // sw.lg.pl_332 eu.tl.jw_543  eu.rw.et_443 hr.af.un_430
  0x1213100c, 0x6b27180b, 0x25001305, 0x521b3112,   // lt.et.hu_543 ga.gd.ceb_542  et.eu.un_330 az.tr.ha_654
  0x20323507, 0x23120dee, 0x6b1801ee, 0x041008ad,   // zu.bs.sq_432 cs.hu.ca_422  en.ga.ceb_422 uk.be.ru_643
  // [4010]
  0x01190a0c, 0x53001b0c, 0x0e080213, 0x133f1155,   // pt.gl.en_543 tr.ht.un_530  da.no.is_665 ro.af.et_442
  0x1f521aa4, 0x523b1e12, 0x0f002d04, 0x64251ba4,   // tl.ha.cy_433 ms.so.ha_654  sk.lv.un_320 tr.eu.lg_433
  0x04001e04, 0x213b1ea4, 0x1900130d, 0x0c4a5208,   // ms.fi.un_320 ms.so.jw_433  et.gl.un_540 ha.yo.sv_443
  0x01000308, 0x07004a08, 0x2b120608, 0x06033f11,   // nl.en.un_430 yo.it.un_430  de.hu.vi_443 af.nl.de_653
  // [4020]
  0x09000319, 0x3f000808, 0x19003b19, 0x03133f0d,   // nl.pl.un_750 no.af.un_430  so.gl.un_750 af.et.nl_554
  0x4a686b07, 0x534a5512, 0x1900050b, 0x0c006402,   // ceb.ig.yo_432 rw.yo.ht_654  fr.gl.un_520 lg.sv.un_220
  0x120e2d12, 0x011905a4, 0x1710110c, 0x31203b07,   // sk.is.hu_654 fr.gl.en_433  ro.be.sr_543 so.sq.az_432
  0x100817a0, 0x010a0455, 0x0a3b200c, 0x09001012,   // sr.uk.be_322 fi.pt.en_442  sq.so.pt_543 lt.pl.un_640
  // [4030]
  0x12001008, 0x64004a04, 0x210802a4, 0x041008ee,   // lt.hu.un_430 yo.lg.un_320  da.no.jw_433 uk.be.ru_422
  0x0500230d, 0x1c00092c, 0x0a17080d, 0x016b28ee,   // ca.fr.un_540 hi.mr.un_990  uk.sr.mk_554 sw.ceb.en_422
  0x131c0da4, 0x19520ea4, 0x1f001908, 0x193b0bad,   // cs.id.et_433 is.ha.gl_433  gl.cy.un_430 es.so.gl_643
  0x534a52ee, 0x3b211c0d, 0x17110a05, 0x0811100e,   // ha.yo.ht_422 id.jw.so_554  mk.ro.sr_333 be.ro.uk_555
  // [4040]
  0x07000c0e, 0x09642507, 0x030123a0, 0x0000042d,   // sv.it.un_550 eu.lg.pl_432  ca.en.nl_322 ru.un.un_A00
  0x19230b0b, 0x35003f05, 0x0d2904a4, 0x643529a4,   // es.ca.gl_542 af.zu.un_330  fi.sl.cs_433 sl.zu.lg_433
  0x64191aa0, 0x17352904, 0x162d07a0, 0x29003504,   // tl.gl.lg_322 sl.zu.sr_332  it.sk.hr_322 zu.sl.un_320
  0x07005304, 0x32002a04, 0x086420a0, 0x092d0d11,   // ht.it.un_320 mt.bs.un_320  sq.lg.no_322 cs.sk.pl_653
  // [4050]
  0x10005204, 0x1b001e04, 0x12003f02, 0x1a1e1c5a,   // ha.lt.un_320 ms.tr.un_320  af.hu.un_220 id.ms.tl_553
  0x291613a7, 0x6b1a3bec, 0x2d002902, 0x070a11ec,   // et.hr.sl_532 so.tl.ceb_644  sl.sk.un_220 ro.mk.bg_644
  0x35006419, 0x0a17080e, 0x123f0c0c, 0x08100755,   // lg.zu.un_750 uk.sr.mk_555  sv.af.hu_543 bg.be.uk_442
  0x321855a4, 0x35001e04, 0x5500281a, 0x35006812,   // rw.ga.bs_433 ms.zu.un_320  sw.rw.un_760 ig.zu.un_640
  // [4060]
  0x3120050c, 0x1f080209, 0x070c08a0, 0x1a002108,   // fr.sq.az_543 da.no.cy_444  no.sv.it_322 jw.tl.un_430
  0x1700081a, 0x6b1101a0, 0x55290713, 0x060b2004,   // uk.sr.un_760 en.ro.ceb_322  it.sl.rw_665 sq.es.de_332
  0x29160407, 0x28295507, 0x23190507, 0x0a002d04,   // fi.hr.sl_432 rw.sl.sw_432  fr.gl.ca_432 sk.pt.un_320
  0x0e6b1a02, 0x04001b04, 0x55003504, 0x0a002509,   // tl.ceb.is_222 tr.fi.un_320  zu.rw.un_320 eu.pt.un_440
  // [4070]
  0x0a071704, 0x0a23050b, 0x3200160c, 0x12002309,   // sr.bg.mk_332 fr.ca.pt_542  hr.bs.un_530 ca.hu.un_440
  0x11001904, 0x08120c05, 0x3500551b, 0x04101713,   // gl.ro.un_320 sv.hu.no_333  rw.zu.un_770 sr.be.ru_665
  0x112501a0, 0x101632ee, 0x55093bee, 0x05000607,   // en.eu.ro_322 bs.hr.lt_422  so.pl.rw_422 de.fr.un_420
  0x3b002714, 0x0d292dec, 0x28011fee, 0x2a042da9,   // gd.so.un_660 sk.sl.cs_644  cy.en.sw_422 sk.fi.mt_544
  // [4080]
  0x09130dad, 0x2b006b12, 0x321c2aee, 0x1c2b0aac,   // ne.bh.hi_643 ceb.vi.un_640  mt.id.bs_422 pt.vi.id_632
  0x1c215308, 0x1923050b, 0x3f27280c, 0x04001722,   // ht.jw.id_443 fr.ca.gl_542  sw.gd.af_543 sr.ru.un_870
  0x0b0928a4, 0x2d292aec, 0x110932a0, 0x6b1a6807,   // sw.pl.es_433 mt.sl.sk_644  bs.pl.ro_322 ig.tl.ceb_432
  0x320d09a7, 0x2a2b1a07, 0x311b3b04, 0x19002d07,   // pl.cs.bs_532 tl.vi.mt_432  so.tr.az_332 sk.gl.un_420
  // [4090]
  0x27006b08, 0x0a006b22, 0x2d002914, 0x6b2d07a0,   // ceb.gd.un_430 ceb.pt.un_870  sl.sk.un_660 it.sk.ceb_322
  0x06000e21, 0x020c0855, 0x25000b04, 0x23190a05,   // is.de.un_860 no.sv.da_442  es.eu.un_320 pt.gl.ca_333
  0x0e2d0d13, 0x2d2029ad, 0x10001f12, 0x2a002b05,   // cs.sk.is_665 sl.sq.sk_643  cy.lt.un_640 vi.mt.un_330
  0x29000f0e, 0x64076802, 0x0d2d290d, 0x3b006b07,   // lv.sl.un_550 ig.it.lg_222  sl.sk.cs_554 ceb.so.un_420
  // [40a0]
  0x2b002302, 0x20001f1a, 0x172d2907, 0x2d002919,   // ca.vi.un_220 cy.sq.un_760  sl.sk.sr_432 sl.sk.un_750
  0x64000307, 0x022b0aec, 0x102d0d60, 0x68002713,   // nl.lg.un_420 pt.vi.da_644  cs.sk.lt_664 gd.ig.un_650
  0x29002d18, 0x080a17af, 0x0c1009a4, 0x64002102,   // sk.sl.un_740 sr.mk.uk_655  pl.lt.sv_433 jw.lg.un_220
  0x07093fa4, 0x4a643fa4, 0x08110705, 0x022b1207,   // af.pl.it_433 af.lg.yo_433  bg.ro.uk_333 hu.vi.da_432
  // [40b0]
  0x53002504, 0x10000f07, 0x101117a4, 0x0e002d1a,   // eu.ht.un_320 lv.lt.un_420  sr.ro.be_433 sk.is.un_760
  0x21250e05, 0x200c0e07, 0x0f351304, 0x53000113,   // is.eu.jw_333 is.sv.sq_432  et.zu.lv_332 en.ht.un_650
  0x3f030da0, 0x04191113, 0x1c0d13a4, 0x190a05a4,   // cs.nl.af_322 ro.gl.fi_665  bh.ne.mr_433 fr.pt.gl_433
  0x0a051912, 0x641f3504, 0x3f035309, 0x0c2927a7,   // gl.fr.pt_654 zu.cy.lg_332  ht.nl.af_444 gd.sl.sv_532
  // [40c0]
  0x11033f12, 0x09001c1a, 0x032b010c, 0x060501a4,   // af.nl.ro_654 mr.hi.un_760  en.vi.nl_543 en.fr.de_433
  0x07111755, 0x05010d09, 0x29000c0c, 0x050d53ad,   // sr.ro.bg_442 cs.en.fr_444  sv.sl.un_530 ht.cs.fr_643
  0x05000404, 0x0407110c, 0x10000821, 0x5300052a,   // fi.fr.un_320 ro.bg.ru_543  uk.be.un_860 fr.ht.un_970
  0x133525a0, 0x071710a4, 0x10040702, 0x25005304,   // eu.zu.et_322 be.sr.bg_433  bg.ru.be_222 ht.eu.un_320
  // [40d0]
  0x12100f08, 0x530305ee, 0x6b250a07, 0x0b0a01ee,   // lv.lt.hu_443 fr.nl.ht_422  pt.eu.ceb_432 en.pt.es_422
  0x53006e07, 0x080201a9, 0x020c080c, 0x080206a9,   // hmn.ht.un_420 en.da.no_544  no.sv.da_543 de.da.no_544
  0x1800040c, 0x3f000e0d, 0x02000513, 0x0c004a0c,   // fi.ga.un_530 is.af.un_540  fr.da.un_650 yo.sv.un_530
  0x0200050d, 0x1f002012, 0x19052308, 0x3f020312,   // fr.da.un_540 sq.cy.un_640  ca.fr.gl_443 nl.da.af_654
  // [40e0]
  0x0a071ca4, 0x17000822, 0x230b0a0d, 0x25001309,   // id.it.pt_433 uk.sr.un_870  pt.es.ca_554 et.eu.un_440
  0x17101112, 0x0a171155, 0x17111012, 0x2a080e11,   // ro.be.sr_654 ro.sr.mk_442  be.ro.sr_654 is.no.mt_653
  0x09000f0d, 0x033f01af, 0x0a2d19a0, 0x1b093bad,   // lv.pl.un_540 en.af.nl_655  gl.sk.pt_322 so.pl.tr_643
  0x1a046ba0, 0x1b2d090c, 0x0b0a2305, 0x046b130c,   // ceb.fi.tl_322 pl.sk.tr_543  ca.pt.es_333 et.ceb.fi_543
  // [40f0]
  0x09001013, 0x0c1e3511, 0x1000091a, 0x55681ea0,   // lt.pl.un_650 zu.ms.sv_653  pl.lt.un_760 ms.ig.rw_322
  0x1e1113ee, 0x4a5535ad, 0x1c0d1ea0, 0x030210ee,   // et.ro.ms_422 zu.rw.yo_643  ms.cs.id_322 lt.da.nl_422
  0x3b644aa0, 0x211e1b07, 0x35004a1a, 0x3b005219,   // yo.lg.so_322 tr.ms.jw_432  yo.zu.un_760 ha.so.un_750
  0x04000711, 0x1e000f07, 0x1b3501a4, 0x55316407,   // bg.ru.un_630 lv.ms.un_420  en.zu.tr_433 lg.az.rw_432
  // [4100]
  0x2800350d, 0x0c235507, 0x55003512, 0x0e000a02,   // zu.sw.un_540 rw.ca.sv_432  zu.rw.un_640 pt.is.un_220
  0x55523560, 0x32290fa4, 0x1c001a05, 0x093b5213,   // zu.ha.rw_664 lv.sl.bs_433  tl.id.un_330 ha.so.pl_665
  0x046b1a0c, 0x2d5209a4, 0x20271855, 0x351a6ba4,   // tl.ceb.fi_543 pl.ha.sk_433  ga.gd.sq_442 ceb.tl.zu_433
  0x4a2135ec, 0x211b53ee, 0x3b001c04, 0x0f2305a4,   // zu.jw.yo_644 ht.tr.jw_422  id.so.un_320 fr.ca.lv_433
  // [4110]
  0x05000c1a, 0x171007af, 0x182729ad, 0x2b0128ee,   // sv.fr.un_760 bg.be.sr_655  sl.gd.ga_643 sw.en.vi_422
  0x13003113, 0x05180107, 0x0411170c, 0x08000f12,   // az.et.un_650 en.ga.fr_432  sr.ro.ru_543 lv.no.un_640
  0x080c0204, 0x320f2308, 0x042d0d0d, 0x23000108,   // da.sv.no_332 ca.lv.bs_443  cs.sk.fi_554 en.ca.un_430
  0x0f122507, 0x5300280c, 0x251207a4, 0x023f08a6,   // eu.hu.lv_432 sw.ht.un_530  it.hu.eu_433 no.af.da_521
  // [4120]
  0x212a2004, 0x0f003207, 0x250f1007, 0x356e2802,   // sq.mt.jw_332 bs.lv.un_420  lt.lv.eu_432 sw.hmn.zu_222
  0x03253fa4, 0x35131a09, 0x07002a08, 0x1e1c27a0,   // af.eu.nl_433 tl.et.zu_444  mt.it.un_430 gd.id.ms_322
  0x03052302, 0x171108ad, 0x0100110b, 0x230f05a4,   // ca.fr.nl_222 uk.ro.sr_643  ro.en.un_520 fr.lv.ca_433
  0x20121fec, 0x230105a4, 0x091c135a, 0x0c050112,   // cy.hu.sq_644 fr.en.ca_433  bh.mr.hi_553 en.fr.sv_654
  // [4130]
  0x016b05a0, 0x25005514, 0x35005208, 0x3f12010b,   // fr.ceb.en_322 rw.eu.un_660  ha.zu.un_430 en.hu.af_542
  0x6e352809, 0x23000b1b, 0x1b000d04, 0x0a0e2855,   // sw.zu.hmn_444 es.ca.un_770  cs.tr.un_320 sw.is.pt_442
  0x1e003f04, 0x0c6b08a4, 0x05000702, 0x0e10250c,   // af.ms.un_320 no.ceb.sv_433  it.fr.un_220 eu.lt.is_543
  0x07000419, 0x02033f04, 0x2800350e, 0x5300281b,   // ru.bg.un_750 af.nl.da_332  zu.sw.un_550 sw.ht.un_770
  // [4140]
  0x553564ee, 0x0e0b02ad, 0x0b23190d, 0x192312a7,   // lg.zu.rw_422 da.es.is_643  gl.ca.es_554 hu.ca.gl_532
  0x0f002522, 0x3b286407, 0x21640408, 0x08101112,   // eu.lv.un_870 lg.sw.so_432  fi.lg.jw_443 ro.be.uk_654
  0x521b3113, 0x2d091aaf, 0x1b3b2aa7, 0x68090aee,   // az.tr.ha_665 tl.pl.sk_655  mt.so.tr_532 pt.pl.ig_422
  0x190a23a0, 0x1a130fa7, 0x2500230b, 0x0f1008a0,   // ca.pt.gl_322 lv.et.tl_532  ca.eu.un_520 no.lt.lv_322
  // [4150]
  0x232d0704, 0x093f06a4, 0x03521ea0, 0x130d1c11,   // it.sk.ca_332 de.af.pl_433  ms.ha.nl_322 mr.ne.bh_653
  0x55004a0d, 0x1a1b1f0c, 0x3f2b2107, 0x2b001807,   // yo.rw.un_540 cy.tr.tl_543  jw.vi.af_432 ga.vi.un_420
  0x52000302, 0x0a08040d, 0x1200180d, 0x210c0807,   // nl.ha.un_220 ru.uk.mk_554  ar.ur.un_540 no.sv.jw_432
  0x0a171008, 0x2500131a, 0x020c0a0c, 0x09231907,   // be.sr.mk_443 et.eu.un_760  pt.sv.da_543 gl.ca.pl_432
  // [4160]
  0x10000d08, 0x1a120504, 0x121a05ad, 0x170a08af,   // cs.lt.un_430 fr.hu.tl_332  fr.tl.hu_643 uk.mk.sr_655
  0x11270555, 0x0d00530b, 0x295310a4, 0x12056b07,   // fr.gd.ro_442 ht.cs.un_520  lt.ht.sl_433 ceb.fr.hu_432
  0x1f071907, 0x06041207, 0x080e2b02, 0x20251a13,   // gl.it.cy_432 hu.fi.de_432  vi.is.no_222 tl.eu.sq_665
  0x2b001f0c, 0x08100712, 0x20122502, 0x1200050e,   // cy.vi.un_530 bg.be.uk_654  eu.hu.sq_222 fr.hu.un_550
  // [4170]
  0x1700110b, 0x10081705, 0x122005ad, 0x05001213,   // ro.sr.un_520 sr.uk.be_333  fr.sq.hu_643 hu.fr.un_650
  0x04001311, 0x2112185a, 0x31000521, 0x0a0804af,   // et.fi.un_630 ar.ur.fa_553  fr.az.un_860 ru.uk.mk_655
  0x12310513, 0x6b1a2105, 0x130d09ec, 0x35002802,   // fr.az.hu_665 jw.tl.ceb_333  hi.ne.bh_644 sw.zu.un_220
  0x081704ec, 0x64002820, 0x131c0960, 0x0e000302,   // ru.sr.uk_644 sw.lg.un_850  hi.mr.bh_664 nl.is.un_220
  // [4180]
  0x2d0f09ad, 0x29162d5a, 0x2b0d2da7, 0x1104085a,   // pl.lv.sk_643 sk.hr.sl_553  sk.cs.vi_532 uk.ru.ro_553
  0x2000350d, 0x082004ee, 0x2a001a0c, 0x071008a0,   // zu.sq.un_540 fi.sq.no_422  tl.mt.un_530 uk.be.bg_322
  0x64006809, 0x2500351a, 0x080207ee, 0x0107030c,   // ig.lg.un_440 zu.eu.un_760  it.da.no_422 nl.it.en_543
  0x04006807, 0x3521280c, 0x060c01a0, 0x08003b2c,   // ig.fi.un_420 sw.jw.zu_543  en.sv.de_322 so.no.un_990
  // [4190]
  0x643b52af, 0x2a005212, 0x080206a0, 0x04351313,   // ha.so.lg_655 ha.mt.un_640  de.da.no_322 et.zu.fi_665
  0x09005207, 0x1f1e1c02, 0x190b1ba0, 0x2a000919,   // ha.pl.un_420 id.ms.cy_222  tr.es.gl_322 pl.mt.un_750
  0x17000b08, 0x522b1ea0, 0x16002d07, 0x1a0507a4,   // es.sr.un_430 ms.vi.ha_322  sk.hr.un_420 it.fr.tl_433
  0x4a000a12, 0x100f0c11, 0x322852ee, 0x0c0e0405,   // pt.yo.un_640 sv.lv.lt_653  ha.sw.bs_422 fi.is.sv_333
  // [41a0]
  0x03181c02, 0x316452ad, 0x1205010c, 0x0600030c,   // id.ga.nl_222 ha.lg.az_643  en.fr.hu_543 nl.de.un_530
  0x0a08110c, 0x06200705, 0x131f1804, 0x070e1fa4,   // ro.uk.mk_543 it.sq.de_333  ga.cy.et_332 cy.is.it_433
  0x20005313, 0x190a1fa9, 0x07001207, 0x643b5213,   // ht.sq.un_650 cy.pt.gl_544  hu.it.un_420 ha.so.lg_665
  0x07001f0e, 0x2a006404, 0x3255520c, 0x080c0302,   // cy.it.un_550 lg.mt.un_320  ha.rw.bs_543 nl.sv.no_222
  // [41b0]
  0x01003204, 0x101107a4, 0x0a006b07, 0x16205507,   // bs.en.un_320 bg.ro.be_433  ceb.pt.un_420 rw.sq.hr_432
  0x13001f07, 0x13040aa0, 0x040208af, 0x0e190b02,   // cy.et.un_420 pt.fi.et_322  no.da.fi_655 es.gl.is_222
  0x1b03060c, 0x06001c02, 0x1300060c, 0x20060ea0,   // de.nl.tr_543 id.de.un_220  de.et.un_530 is.de.sq_322
  0x080a1713, 0x052307ee, 0x2d003b04, 0x3b6b6808,   // sr.mk.uk_665 it.ca.fr_422  so.sk.un_320 ig.ceb.so_443
  // [41c0]
  0x110a1713, 0x2b6b01ee, 0x20003205, 0x08040aa9,   // sr.mk.ro_665 en.ceb.vi_422  bs.sq.un_330 mk.ru.uk_544
  0x01076b08, 0x03041ea4, 0x29190b04, 0x11041705,   // ceb.it.en_443 ms.fi.nl_433  es.gl.sl_332 sr.ru.ro_333
  0x07080aa0, 0x04033fa6, 0x19170b55, 0x3f13030d,   // mk.uk.bg_322 af.nl.fi_521  es.sr.gl_442 nl.et.af_554
  0x10000a23, 0x3f001c08, 0x1c3b1ea0, 0x120e2d07,   // mk.be.un_880 id.af.un_430  ms.so.id_322 sk.is.hu_432
  // [41d0]
  0x101f0e04, 0x133f03a7, 0x0d001008, 0x1c1b01a0,   // is.cy.lt_332 nl.af.et_532  lt.cs.un_430 en.tr.id_322
  0x3f1b21ad, 0x1b000312, 0x04170860, 0x25002802,   // jw.tr.af_643 nl.tr.un_640  uk.sr.ru_664 sw.eu.un_220
  0x074a53a0, 0x1c121fa4, 0x25002314, 0x1b3f030c,   // ht.yo.it_322 cy.hu.id_433  ca.eu.un_660 nl.af.tr_543
  0x1a0b6b04, 0x121304a4, 0x041e1c07, 0x3f1304ee,   // ceb.es.tl_332 fi.et.hu_433  id.ms.fi_432 fi.et.af_422
  // [41e0]
  0x1b002d14, 0x1c006e08, 0x1b080204, 0x32005508,   // sk.tr.un_660 hmn.id.un_430  da.no.tr_332 rw.bs.un_430
  0x03130604, 0x25005504, 0x13060d02, 0x08021ca0,   // de.et.nl_332 rw.eu.un_320  cs.de.et_222 id.da.no_322
  0x1c0d09ac, 0x3f000605, 0x201b0e09, 0x28070605,   // hi.ne.mr_632 de.af.un_330  is.tr.sq_444 de.it.sw_333
  0x03001705, 0x3f080309, 0x2506130c, 0x0e002d0b,   // sr.nl.un_330 nl.no.af_444  et.de.eu_543 sk.is.un_520
  // [41f0]
  0x0a0208a4, 0x13002512, 0x091c0d60, 0x170704a7,   // no.da.pt_433 eu.et.un_640  ne.mr.hi_664 ru.bg.sr_532
  0x13002308, 0x06003505, 0x06232511, 0x2a0752a7,   // ca.et.un_430 zu.de.un_330  eu.ca.de_653 ha.it.mt_532
  0x25000619, 0x2d0d2914, 0x030a2560, 0x1c1b0ea4,   // de.eu.un_750 sl.cs.sk_666  eu.pt.nl_664 is.tr.id_433
  0x530d2905, 0x64550b08, 0x1a004a0c, 0x1b2a25a0,   // sl.cs.ht_333 es.rw.lg_443  yo.tl.un_530 eu.mt.tr_322
  // [4200]
  0x2a190a08, 0x200208a4, 0x6b061fa7, 0x063f6413,   // pt.gl.mt_443 no.da.sq_433  cy.de.ceb_532 lg.af.de_665
  0x2a002807, 0x18002d0d, 0x2a002009, 0x04001322,   // sw.mt.un_420 sk.ga.un_540  sq.mt.un_440 et.fi.un_870
  0x551a6b0c, 0x2800010d, 0x2d0d0b14, 0x6452210c,   // ceb.tl.rw_543 en.sw.un_540  es.cs.sk_666 jw.ha.lg_543
  0x181364a0, 0x6b211aa9, 0x2d291707, 0x28001a14,   // lg.et.ga_322 tl.jw.ceb_544  sr.sl.sk_432 tl.sw.un_660
  // [4210]
  0x04283504, 0x6e011f07, 0x35072507, 0x0b2d0d14,   // zu.sw.fi_332 cy.en.hmn_432  eu.it.zu_432 cs.sk.es_666
  0x04081002, 0x01006407, 0x1a201e07, 0x1f3b2a05,   // be.uk.ru_222 lg.en.un_420  ms.sq.tl_432 mt.so.cy_333
  0x11001e08, 0x1f002a19, 0x0a071002, 0x282a6408,   // ms.ro.un_430 mt.cy.un_750  be.bg.mk_222 lg.mt.sw_443
  0x3f2111a7, 0x0b2d0d04, 0x35132811, 0x2112010c,   // ro.jw.af_532 cs.sk.es_332  sw.et.zu_653 en.hu.jw_543
  // [4220]
  0x0c552812, 0x1f353f12, 0x21285507, 0x17000412,   // sw.rw.sv_654 af.zu.cy_654  rw.sw.jw_432 ru.sr.un_640
  0x20095504, 0x0b000718, 0x03000508, 0x210413a0,   // rw.pl.sq_332 it.es.un_740  fr.nl.un_430 et.fi.jw_322
  0x1b001a07, 0x190b05ee, 0x1b311313, 0x55001113,   // tl.tr.un_420 fr.es.gl_422  et.az.tr_665 ro.rw.un_650
  0x0c1b3155, 0x4a0b20af, 0x0c000213, 0x1c000d23,   // az.tr.sv_442 sq.es.yo_655  da.sv.un_650 ne.mr.un_880
  // [4230]
  0x2d005504, 0x0b004a04, 0x0e00180c, 0x10170412,   // rw.sk.un_320 yo.es.un_320  ga.is.un_530 ru.sr.be_654
  0x08000a22, 0x036b3f04, 0x1f000307, 0x5216050b,   // mk.uk.un_870 af.ceb.nl_332  nl.cy.un_420 fr.hr.ha_542
  0x321653ee, 0x530f05a7, 0x05002707, 0x0d000918,   // ht.hr.bs_422 fr.lv.ht_532  gd.fr.un_420 hi.ne.un_740
  0x13005507, 0x55001a09, 0x04100804, 0x19554a0b,   // rw.et.un_420 tl.rw.un_440  uk.be.ru_332 yo.rw.gl_542
  // [4240]
  0x552835ee, 0x100a1709, 0x17000821, 0x252d0d04,   // zu.sw.rw_422 sr.mk.be_444  uk.sr.un_860 cs.sk.eu_332
  0x0b6b4aee, 0x17162da4, 0x200a0b07, 0x19003f02,   // yo.ceb.es_422 sk.hr.sr_433  es.pt.sq_432 af.gl.un_220
  0x02001e02, 0x0c00130e, 0x2d000e08, 0x2d0d32a9,   // ms.da.un_220 et.sv.un_550  is.sk.un_430 bs.cs.sk_544
  0x3b003f04, 0x12002b0c, 0x1300640e, 0x162a2807,   // af.so.un_320 vi.hu.un_530  lg.et.un_550 sw.mt.hr_432
  // [4250]
  0x2a3f35a4, 0x3f0603a0, 0x32170409, 0x212835a0,   // zu.af.mt_433 nl.de.af_322  fi.sr.bs_444 zu.sw.jw_322
  0x31250fa9, 0x130d1caf, 0x10040a0d, 0x1c1e04ee,   // lv.eu.az_544 mr.ne.bh_655  mk.ru.be_554 fi.ms.id_422
  0x4a0b28a4, 0x55126407, 0x0b000702, 0x07110aa4,   // sw.es.yo_433 lg.hu.rw_432  it.es.un_220 mk.ro.bg_433
  0x08004a07, 0x21092804, 0x136455a4, 0x12003f19,   // yo.no.un_420 sw.pl.jw_332  rw.lg.et_433 af.hu.un_750
  // [4260]
  0x02285514, 0x09291fa4, 0x25004a13, 0x211e1c12,   // rw.sw.da_666 cy.sl.pl_433  yo.eu.un_650 id.ms.jw_654
  0x6b0f01a4, 0x07186e02, 0x1a6b0e07, 0x04256404,   // en.lv.ceb_433 hmn.ga.it_222  is.ceb.tl_432 lg.eu.fi_332
  0x100417a4, 0x0f102a13, 0x55041aee, 0x0f000621,   // sr.ru.be_433 mt.lt.lv_665  tl.fi.rw_422 de.lv.un_860
  0x08041709, 0x08071713, 0x041711ec, 0x4a042a0c,   // sr.ru.uk_444 sr.bg.uk_665  ro.sr.ru_644 mt.fi.yo_543
  // [4270]
  0x231807ad, 0x0b000919, 0x1b311307, 0x180a2304,   // it.ga.ca_643 pl.es.un_750  et.az.tr_432 ca.pt.ga_332
  0x2a0609ac, 0x13001c0d, 0x19530b07, 0x0c0108a0,   // pl.de.mt_632 mr.bh.un_540  es.ht.gl_432 no.en.sv_322
  0x09002002, 0x12001f0d, 0x55250604, 0x110c68ee,   // sq.pl.un_220 cy.hu.un_540  de.eu.rw_332 ig.sv.ro_422
  0x28553511, 0x35004a09, 0x6b2504ad, 0x5200251b,   // zu.rw.sw_653 yo.zu.un_440  fi.eu.ceb_643 eu.ha.un_770
  // [4280]
  0x0d190b08, 0x06190b02, 0x0f1032a0, 0x062a08a4,   // es.gl.cs_443 es.gl.de_222  bs.lt.lv_322 no.mt.de_433
  0x07000f1a, 0x0a180707, 0x25002009, 0x12000104,   // lv.it.un_760 it.ga.pt_432  sq.eu.un_440 en.hu.un_320
  0x23191104, 0x2d002912, 0x09001c2a, 0x08130e09,   // ro.gl.ca_332 sl.sk.un_640  mr.hi.un_970 is.et.no_444
  0x121121a0, 0x0405250d, 0x09013fee, 0x0f1a040c,   // jw.ro.hu_322 eu.fr.fi_554  af.en.pl_422 fi.tl.lv_543
  // [4290]
  0x10000f21, 0x0c052305, 0x04286b0d, 0x1b001304,   // lv.lt.un_860 ca.fr.sv_333  ceb.sw.fi_554 et.tr.un_320
  0x1a012aad, 0x1b133113, 0x4a00351a, 0x01002a08,   // mt.en.tl_643 az.et.tr_665  zu.yo.un_760 mt.en.un_430
  0x02000b05, 0x3f002a0d, 0x0e002b13, 0x0000232d,   // es.da.un_330 mt.af.un_540  vi.is.un_650 ca.un.un_A00
  0x061152a4, 0x2a120ca4, 0x11005505, 0x29182302,   // ha.ro.de_433 sv.hu.mt_433  rw.ro.un_330 ca.ga.sl_222
  // [42a0]
  0x0a230ea0, 0x11070409, 0x100501ee, 0x232007a4,   // is.ca.pt_322 ru.bg.ro_444  en.fr.lt_422 it.sq.ca_433
  0x08110405, 0x083f100b, 0x532105a7, 0x04002319,   // ru.ro.uk_333 lt.af.no_542  fr.jw.ht_532 ca.fi.un_750
  0x0c005507, 0x0f110507, 0x13060f02, 0x110f1305,   // rw.sv.un_420 fr.ro.lv_432  lv.de.et_222 et.lv.ro_333
  0x0f0603a0, 0x1b001112, 0x110e04ee, 0x6e016ba0,   // nl.de.lv_322 ro.tr.un_640  fi.is.ro_422 ceb.en.hmn_322
  // [42b0]
  0x0552280d, 0x0e121811, 0x1a6b1e0c, 0x120e180e,   // sw.ha.fr_554 ga.hu.is_653  ms.ceb.tl_543 ga.is.hu_555
  0x3f03020c, 0x0511230c, 0x032852a0, 0x1c100f0c,   // da.nl.af_543 ca.ro.fr_543  ha.sw.nl_322 lv.lt.id_543
  0x02110e0c, 0x0a081705, 0x05000e29, 0x111005a0,   // is.ro.da_543 sr.uk.mk_333  is.fr.un_960 fr.lt.ro_322
  0x0e121808, 0x270d1855, 0x25190b0c, 0x20005208,   // ga.hu.is_443 ga.cs.gd_442  es.gl.eu_543 ha.sq.un_430
  // [42c0]
  0x3f033502, 0x180d4a07, 0x2300530c, 0x1c0d130c,   // zu.nl.af_222 yo.cs.ga_432  ht.ca.un_530 bh.ne.mr_543
  0x054a5312, 0x07110413, 0x53054a0c, 0x04000705,   // ht.yo.fr_654 ru.ro.bg_665  yo.fr.ht_543 bg.ru.un_330
  0x12010ca0, 0x20001708, 0x04130c0c, 0x4a001a14,   // sv.en.hu_322 sr.sq.un_430  sv.et.fi_543 tl.yo.un_660
  0x05033fa4, 0x21190b04, 0x2800640c, 0x1c003b05,   // af.nl.fr_433 es.gl.jw_332  lg.sw.un_530 so.id.un_330
  // [42d0]
  0x1e251cad, 0x0a071714, 0x4a2d0d0d, 0x0c292d07,   // id.eu.ms_643 sr.bg.mk_666  cs.sk.yo_554 sk.sl.sv_432
  0x1c000d04, 0x0d00092a, 0x230a07ee, 0x2100190d,   // ne.mr.un_320 hi.ne.un_970  it.pt.ca_422 gl.jw.un_540
  0x29000307, 0x13006e07, 0x082103a0, 0x11201eee,   // nl.sl.un_420 hmn.et.un_420  nl.jw.no_322 ms.sq.ro_422
  0x1b00130c, 0x1100100c, 0x1a00010b, 0x2a190b05,   // et.tr.un_530 lt.ro.un_530  en.tl.un_520 es.gl.mt_333
  // [42e0]
  0x170410a0, 0x21002013, 0x08001f19, 0x0b1912ac,   // be.ru.sr_322 sq.jw.un_650  cy.no.un_750 hu.gl.es_632
  0x06001214, 0x081102ec, 0x12285508, 0x12001f0e,   // hu.de.un_660 da.ro.no_644  rw.sw.hu_443 cy.hu.un_550
  0x53002913, 0x3b002102, 0x32553502, 0x0308010c,   // sl.ht.un_650 jw.so.un_220  zu.rw.bs_222 en.no.nl_543
  0x55001b19, 0x05233faf, 0x05202304, 0x1b002302,   // tr.rw.un_750 af.ca.fr_655  ca.sq.fr_332 ca.tr.un_220
  // [42f0]
  0x08020605, 0x130823af, 0x063f03ad, 0x6b190b04,   // de.da.no_333 ca.no.et_655  nl.af.de_643 es.gl.ceb_332
  0x0a041002, 0x0c00132a, 0x12001b19, 0x3b00280e,   // be.ru.mk_222 et.sv.un_970  tr.hu.un_750 sw.so.un_550
  0x0c3f1f5a, 0x051107a0, 0x171120ee, 0x2b011b5a,   // cy.af.sv_553 it.ro.fr_322  sq.ro.sr_422 tr.en.vi_553
  0x536431ad, 0x11100f05, 0x19003b02, 0x0217080c,   // az.lg.ht_643 lv.lt.ro_333  so.gl.un_220 no.sr.da_543
  // [4300]
  0x55000502, 0x100e020c, 0x050601a7, 0x1b3106ec,   // fr.rw.un_220 da.is.lt_543  en.de.fr_532 de.az.tr_644
  0x13000608, 0x201b32a9, 0x2d0d1e02, 0x11003104,   // de.et.un_430 bs.tr.sq_544  ms.cs.sk_222 az.ro.un_320
  0x321728a0, 0x040f21a4, 0x120f1304, 0x04071704,   // sw.sr.bs_322 jw.lv.fi_433  et.lv.hu_332 sr.bg.ru_332
  0x21001904, 0x0600050d, 0x120d2dee, 0x04291707,   // gl.jw.un_320 fr.de.un_540  sk.cs.hu_422 sr.sl.fi_432
  // [4310]
  0x040301ee, 0x12002007, 0x20002d08, 0x060e0ca4,   // en.nl.fi_422 sq.hu.un_420  sk.sq.un_430 sv.is.de_433
  0x201b130d, 0x033f10ec, 0x200f2507, 0x18272504,   // et.tr.sq_554 lt.af.nl_644  eu.lv.sq_432 eu.gd.ga_332
  0x4a6e6b04, 0x353f0608, 0x3b1b2109, 0x52002802,   // ceb.hmn.yo_332 de.af.zu_443  jw.tr.so_444 sw.ha.un_220
  0x1f002304, 0x203b5207, 0x0d002d2a, 0x08352812,   // ca.cy.un_320 ha.so.sq_432  sk.cs.un_970 sw.zu.no_654
  // [4320]
  0x11522507, 0x28356460, 0x19122dec, 0x212a1a04,   // eu.ha.ro_432 lg.zu.sw_664  sk.hu.gl_644 tl.mt.jw_332
  0x3b1b250c, 0x2d0d06af, 0x21003b2a, 0x031a3f04,   // eu.tr.so_543 de.cs.sk_655  so.jw.un_970 af.tl.nl_332
  0x0c0e2aa7, 0x233f13ee, 0x0300210d, 0x641a280c,   // mt.is.sv_532 et.af.ca_422  jw.nl.un_540 sw.tl.lg_543
  0x1c000105, 0x3f002113, 0x35003b12, 0x180e2dad,   // en.id.un_330 jw.af.un_650  so.zu.un_640 sk.is.ga_643
  // [4330]
  0x3b002a13, 0x1e1f52a4, 0x3f035205, 0x131018a4,   // mt.so.un_650 ha.cy.ms_433  ha.nl.af_333 ga.lt.et_433
  0x0f001708, 0x072a550c, 0x3b002304, 0x27190a08,   // sr.lv.un_430 rw.mt.it_543  ca.so.un_320 pt.gl.gd_443
  0x2b001f11, 0x1e1c28a0, 0x10041705, 0x070a0813,   // cy.vi.un_630 sw.id.ms_322  sr.ru.be_333 uk.mk.bg_665
  0x354a1ca0, 0x4a0455a6, 0x050931a7, 0x0a0710a4,   // id.yo.zu_322 rw.fi.yo_521  az.pl.fr_532 be.bg.mk_433
  // [4340]
  0x052d0d08, 0x03002104, 0x03003512, 0x0a6401a0,   // cs.sk.fr_443 jw.nl.un_320  zu.nl.un_640 en.lg.pt_322
  0x16001a0c, 0x181221a9, 0x2d0d0eaf, 0x2a3531ec,   // tl.hr.un_530 fa.ur.ar_544  is.cs.sk_655 az.zu.mt_644
  0x18000804, 0x0c2a0807, 0x352820a0, 0x281a6b12,   // no.ga.un_320 no.mt.sv_432  sq.sw.zu_322 ceb.tl.sw_654
  0x68003505, 0x0a07080b, 0x17001009, 0x320f17a4,   // zu.ig.un_330 uk.bg.mk_542  be.sr.un_440 sr.lv.bs_433
  // [4350]
  0x12000c07, 0x28063505, 0x16296eee, 0x125364a0,   // sv.hu.un_420 zu.de.sw_333  hmn.sl.hr_422 lg.ht.hu_322
  0x3b122011, 0x20000521, 0x1a6b52ec, 0x0f293ba4,   // sq.hu.so_653 fr.sq.un_860  ha.ceb.tl_644 so.sl.lv_433
  0x160f55a4, 0x170f10a0, 0x1b00640d, 0x05005212,   // rw.lv.hr_433 lt.lv.sr_322  lg.tr.un_540 ha.fr.un_640
  0x55352904, 0x53070560, 0x0f00290c, 0x3f040302,   // sl.zu.rw_332 fr.it.ht_664  sl.lv.un_530 nl.fi.af_222
  // [4360]
  0x16293ba4, 0x0c000418, 0x0b1819a4, 0x2300110d,   // so.sl.hr_433 fi.sv.un_740  gl.ga.es_433 ro.ca.un_540
  0x0d130904, 0x11202313, 0x55002914, 0x11070414,   // hi.bh.ne_332 ca.sq.ro_665  sl.rw.un_660 ru.bg.ro_666
  0x321655a4, 0x20002302, 0x12002a12, 0x20000507,   // rw.hr.bs_433 ca.sq.un_220  mt.hu.un_640 fr.sq.un_420
  0x1b00312c, 0x07110412, 0x23002a04, 0x05000107,   // az.tr.un_990 ru.ro.bg_654  mt.ca.un_320 en.fr.un_420
  // [4370]
  0x1a005508, 0x2900550c, 0x0f092905, 0x6b201a07,   // rw.tl.un_430 rw.sl.un_530  sl.pl.lv_333 tl.sq.ceb_432
  0x554a2904, 0x282535a7, 0x2855645a, 0x2d0d04af,   // sl.yo.rw_332 zu.eu.sw_532  lg.rw.sw_553 fi.cs.sk_655
  0x06556408, 0x32002504, 0x64092aad, 0x20112313,   // lg.rw.de_443 eu.bs.un_320  mt.pl.lg_643 ca.ro.sq_665
  0x10000f20, 0x112a23af, 0x17211e04, 0x1e005307,   // lv.lt.un_850 ca.mt.ro_655  ms.jw.sr_332 ht.ms.un_420
  // [4380]
  0x125320ad, 0x64095511, 0x03006407, 0x07041109,   // sq.ht.hu_643 rw.pl.lg_653  lg.nl.un_420 ro.ru.bg_444
  0x18000308, 0x03063f04, 0x19004a04, 0x3b521f08,   // nl.ga.un_430 af.de.nl_332  yo.gl.un_320 cy.ha.so_443
  0x3f0627a0, 0x2000290d, 0x1c201eec, 0x080203a9,   // gd.de.af_322 sl.sq.un_540  ms.sq.id_644 nl.da.no_544
  0x2d0d1c05, 0x1710080c, 0x68190a13, 0x1a2a53af,   // id.cs.sk_333 uk.be.sr_543  pt.gl.ig_665 ht.mt.tl_655
  // [4390]
  0x2d321704, 0x19110b08, 0x08642711, 0x1e002507,   // sr.bs.sk_332 es.ro.gl_443  gd.lg.no_653 eu.ms.un_420
  0x3b005222, 0x014a03a0, 0x014a08a4, 0x0e0825ee,   // ha.so.un_870 nl.yo.en_322  no.yo.en_433 eu.no.is_422
  0x082b0ea4, 0x103228a4, 0x0327180c, 0x25313bad,   // is.vi.no_433 sw.bs.lt_433  ga.gd.nl_543 so.az.eu_643
  0x082152a0, 0x0d1c0960, 0x110408a4, 0x08005204,   // ha.jw.no_322 hi.mr.ne_664  uk.ru.ro_433 ha.no.un_320
  // [43a0]
  0x0e030607, 0x52002523, 0x01002302, 0x27033f05,   // de.nl.is_432 eu.ha.un_880  ca.en.un_220 af.nl.gd_333
  0x31201ba4, 0x1f012bee, 0x06041307, 0x27185214,   // tr.sq.az_433 vi.en.cy_422  et.fi.de_432 ha.ga.gd_666
  0x201e52ad, 0x0a041107, 0x27130412, 0x35003b14,   // ha.ms.sq_643 ro.ru.mk_432  fi.et.gd_654 so.zu.un_660
  0x640c080c, 0x52001b09, 0x130401a9, 0x32001618,   // no.sv.lg_543 tr.ha.un_440  en.fi.et_544 hr.bs.un_740
  // [43b0]
  0x1b202a07, 0x016b09ee, 0x0900132a, 0x4a001214,   // mt.sq.tr_432 pl.ceb.en_422  bh.hi.un_970 hu.yo.un_660
  0x1e001c35, 0x3b001e04, 0x17070402, 0x0a111709,   // id.ms.un_A90 ms.so.un_320  ru.bg.sr_222 sr.ro.mk_444
  0x070f110e, 0x081e3b07, 0x041e6b07, 0x31002805,   // ro.lv.it_555 so.ms.no_432  ceb.ms.fi_432 sw.az.un_330
  0x0d000f0c, 0x21000707, 0x29000f0c, 0x2a000304,   // lv.cs.un_530 it.jw.un_420  lv.sl.un_530 nl.mt.un_320
  // [43c0]
  0x2700071b, 0x5200070e, 0x1100171b, 0x07002a02,   // it.gd.un_770 it.ha.un_550  sr.ro.un_770 mt.it.un_220
  0x18001223, 0x0d001702, 0x0c00080b, 0x17000402,   // ur.ar.un_880 sr.cs.un_220  no.sv.un_520 ru.sr.un_220
  0x12003b13, 0x52000712, 0x1a003b05, 0x04110708,   // so.hu.un_650 it.ha.un_640  so.tl.un_330 bg.ro.ru_443
  0x02080c04, 0x10002004, 0x230c0e12, 0x210b190c,   // sv.no.da_332 sq.lt.un_320  is.sv.ca_654 gl.es.jw_543
  // [43d0]
  0x0a000419, 0x2a201204, 0x29200105, 0x08064a08,   // ru.mk.un_750 hu.sq.mt_332  en.sq.sl_333 yo.de.no_443
  0x05000721, 0x27181ea0, 0x06000b04, 0x2a280707,   // it.fr.un_860 ms.ga.gd_322  es.de.un_320 it.sw.mt_432
  0x0f006b07, 0x522a07a7, 0x64000304, 0x0e004a08,   // ceb.lv.un_420 it.mt.ha_532  nl.lg.un_320 yo.is.un_430
  0x03001f05, 0x35686b12, 0x29000b09, 0x556821ee,   // cy.nl.un_330 ceb.ig.zu_654  es.sl.un_440 jw.ig.rw_422
  // [43e0]
  0x07000f0d, 0x6400280e, 0x1c0d090b, 0x29006429,   // lv.it.un_540 sw.lg.un_550  hi.ne.mr_542 lg.sl.un_960
  0x323b5207, 0x09006804, 0x3f002807, 0x131a1bad,   // ha.so.bs_432 ig.pl.un_320  sw.af.un_420 tr.tl.et_643
  0x033f6412, 0x05033f08, 0x1b6b0f04, 0x4a3568ec,   // lg.af.nl_654 af.nl.fr_443  lv.ceb.tr_332 ig.zu.yo_644
  0x08040aa6, 0x12041aad, 0x132d3504, 0x0e001e04,   // mk.ru.uk_521 tl.fi.hu_643  zu.sk.et_332 ms.is.un_320
  // [43f0]
  0x0f131bad, 0x100717a4, 0x136b11ad, 0x04281a0c,   // tr.et.lv_643 sr.bg.be_433  ro.ceb.et_643 tl.sw.fi_543
  0x1e002813, 0x1c132107, 0x3500010d, 0x04170704,   // sw.ms.un_650 jw.et.id_432  en.zu.un_540 bg.sr.ru_332
  0x0500120c, 0x09001329, 0x3f003504, 0x12000422,   // hu.fr.un_530 bh.hi.un_960  zu.af.un_320 fi.hu.un_870
  0x06006b07, 0x2d0d04ee, 0x25551307, 0x13171604,   // ceb.de.un_420 fi.cs.sk_422  et.rw.eu_432 hr.sr.et_332

  // [4400]
  0x041009ad, 0x64033f55, 0x07001712, 0x161b1a08,   // pl.lt.fi_643 af.nl.lg_442  sr.bg.un_640 tl.tr.hr_443
  0x1b252804, 0x13282507, 0x11170a13, 0x041a1ea4,   // sw.eu.tr_332 eu.sw.et_432  mk.sr.ro_665 ms.tl.fi_433
  0x286825ee, 0x09001b04, 0x130425ee, 0x28000422,   // eu.ig.sw_422 tr.pl.un_320  eu.fi.et_422 fi.sw.un_870
  0x00001e24, 0x53001e04, 0x02133b05, 0x19230ba9,   // ms.un.un_900 ms.ht.un_320  so.et.da_333 es.ca.gl_544
  // [4410]
  0x0e000809, 0x04006b2a, 0x19001216, 0x3f10040c,   // no.is.un_440 ceb.fi.un_970  hu.gl.un_720 fi.lt.af_543
  0x04000735, 0x09081007, 0x1f353f02, 0x010503a4,   // bg.ru.un_A90 lt.no.pl_432  af.zu.cy_222 nl.fr.en_433
  0x0d092dee, 0x4a005307, 0x17250d0c, 0x315235a6,   // sk.pl.cs_422 ht.yo.un_420  cs.eu.sr_543 zu.ha.az_521
  0x190b2304, 0x3b2519a0, 0x35003b13, 0x0408100b,   // ca.es.gl_332 gl.eu.so_322  so.zu.un_650 be.uk.ru_542
  // [4420]
  0x641a35a0, 0x09002107, 0x0d001319, 0x270e08a7,   // zu.tl.lg_322 jw.pl.un_420  bh.ne.un_750 no.is.gd_532
  0x0700250d, 0x203b13a0, 0x133b04af, 0x3b062bee,   // eu.it.un_540 et.so.sq_322  fi.so.et_655 vi.de.so_422
  0x19005304, 0x2a092007, 0x03643f05, 0x28130460,   // ht.gl.un_320 sq.pl.mt_432  af.lg.nl_333 fi.et.sw_664
  0x21001108, 0x0a002a12, 0x3b041307, 0x1c00350d,   // ro.jw.un_430 mt.pt.un_640  et.fi.so_432 zu.id.un_540
  // [4430]
  0x2d100904, 0x170a07ee, 0x0a002a0d, 0x2d0d01a0,   // pl.lt.sk_332 bg.mk.sr_422  mt.pt.un_540 en.cs.sk_322
  0x18006402, 0x06000c1b, 0x092d2907, 0x1204060e,   // lg.ga.un_220 sv.de.un_770  sl.sk.pl_432 de.fi.hu_555
  0x1700111a, 0x1a3f0107, 0x0c131e07, 0x06000208,   // ro.sr.un_760 en.af.tl_432  ms.et.sv_432 da.de.un_430
  0x06100907, 0x06003f09, 0x082a0aa4, 0x311711ec,   // pl.lt.de_432 af.de.un_440  pt.mt.no_433 ro.sr.az_644
  // [4440]
  0x11000607, 0x04100812, 0x04100814, 0x321c2508,   // de.ro.un_420 uk.be.ru_654  uk.be.ru_666 eu.id.bs_443
  0x17040704, 0x0b2319a7, 0x07080a11, 0x041017a0,   // bg.ru.sr_332 gl.ca.es_532  mk.uk.bg_653 sr.be.ru_322
  0x11001f02, 0x0d23110b, 0x25003f04, 0x522520a6,   // cy.ro.un_220 ro.ca.cs_542  af.eu.un_320 sq.eu.ha_521
  0x212519a0, 0x282718af, 0x1c3221a6, 0x080417a7,   // gl.eu.jw_322 ga.gd.sw_655  jw.bs.id_521 sr.ru.uk_532
  // [4450]
  0x1800272b, 0x013f06a4, 0x13002008, 0x031827ad,   // gd.ga.un_980 de.af.en_433  sq.et.un_430 gd.ga.nl_643
  0x0b000513, 0x3100110e, 0x6b3f06a9, 0x08033f02,   // fr.es.un_650 ro.az.un_550  de.af.ceb_544 af.nl.no_222
  0x4a006405, 0x07003f02, 0x073b6404, 0x0e326405,   // lg.yo.un_330 af.it.un_220  lg.so.it_332 lg.bs.is_333
  0x3f3b03a0, 0x1312110c, 0x133b6455, 0x2700182c,   // nl.so.af_322 ro.hu.et_543  lg.so.et_442 ga.gd.un_990
  // [4460]
  0x0a1711ad, 0x060f10a4, 0x03065504, 0x3b641307,   // ro.sr.mk_643 lt.lv.de_433  rw.de.nl_332 et.lg.so_432
  0x033f13ee, 0x0a002711, 0x0a000507, 0x23190b55,   // et.af.nl_422 gd.pt.un_630  fr.pt.un_420 es.gl.ca_442
  0x2d0d05ec, 0x060e08a4, 0x0800200c, 0x0b00191a,   // fr.cs.sk_644 no.is.de_433  sq.no.un_530 gl.es.un_760
  0x6400030d, 0x2d0d120c, 0x133f3ba0, 0x2a003111,   // nl.lg.un_540 hu.cs.sk_543  so.af.et_322 az.mt.un_630
  // [4470]
  0x190a09af, 0x190d35ec, 0x040f52ad, 0x1c00090b,   // pl.pt.gl_655 zu.cs.gl_644  ha.lv.fi_643 hi.mr.un_520
  0x101c0404, 0x27282008, 0x32002708, 0x3b061908,   // fi.id.lt_332 sq.sw.gd_443  gd.bs.un_430 gl.de.so_443
  0x13000c12, 0x3f002805, 0x27002119, 0x0e3b2708,   // sv.et.un_640 sw.af.un_330  jw.gd.un_750 gd.so.is_443
  0x09182705, 0x113b10ec, 0x53060ca0, 0x0f096ba6,   // gd.ga.pl_333 lt.so.ro_644  sv.de.ht_322 ceb.pl.lv_521
  // [4480]
  0x2d001604, 0x55086ba4, 0x311b5207, 0x18000720,   // hr.sk.un_320 ceb.no.rw_433  ha.tr.az_432 it.ga.un_850
  0x0a180709, 0x18271c07, 0x07182708, 0x04110808,   // it.ga.pt_444 id.gd.ga_432  gd.ga.it_443 uk.ro.ru_443
  0x072b0107, 0x010410ee, 0x0807040d, 0x31003b13,   // en.vi.it_432 lt.fi.en_422  ru.bg.uk_554 so.az.un_650
  0x091e1cad, 0x0e556807, 0x2d000f09, 0x213b0911,   // id.ms.pl_643 ig.rw.is_432  lv.sk.un_440 pl.so.jw_653
  // [4490]
  0x0a271055, 0x11170705, 0x0c000202, 0x18192708,   // lt.gd.pt_442 bg.sr.ro_333  da.sv.un_220 gd.gl.ga_443
  0x3f001f19, 0x2800271b, 0x1b002829, 0x281e1c11,   // cy.af.un_750 gd.sw.un_770  sw.tr.un_960 id.ms.sw_653
  0x23052da4, 0x0b001219, 0x1c521e0c, 0x230e0bee,   // sk.fr.ca_433 hu.es.un_750  ms.ha.id_543 es.is.ca_422
  0x0f1a09a7, 0x2800522a, 0x2021520c, 0x07230608,   // pl.tl.lv_532 ha.sw.un_970  ha.jw.sq_543 de.ca.it_443
  // [44a0]
  0x6b1a1ca0, 0x17080705, 0x0b001104, 0x07000120,   // id.tl.ceb_322 bg.uk.sr_333  ro.es.un_320 en.it.un_850
  0x1a355504, 0x52001122, 0x0d005304, 0x070810af,   // rw.zu.tl_332 ro.ha.un_870  ht.cs.un_320 be.uk.bg_655
  0x0c0a11a4, 0x524a1aa7, 0x0a1710a4, 0x0a1708a4,   // ro.pt.sv_433 tl.yo.ha_532  be.sr.mk_433 uk.sr.mk_433
  0x1e010c02, 0x2a030605, 0x11070105, 0x0e005204,   // sv.en.ms_222 de.nl.mt_333  en.it.ro_333 ha.is.un_320
  // [44b0]
  0x23072a08, 0x0f080ea7, 0x17001113, 0x25091b07,   // mt.it.ca_443 is.no.lv_532  ro.sr.un_650 tr.pl.eu_432
  0x3b0e0b04, 0x17000407, 0x0d0e2da4, 0x170752ee,   // es.is.so_332 ru.sr.un_420  sk.is.cs_433 ha.it.sr_422
  0x52002519, 0x070b3104, 0x0d091ca7, 0x122152ee,   // eu.ha.un_750 az.es.it_332  mr.hi.ne_532 ha.jw.hu_422
  0x0b0a2da7, 0x04000a09, 0x080402a4, 0x55000511,   // sk.pt.es_532 mk.ru.un_440  da.fi.no_433 fr.rw.un_630
  // [44c0]
  0x21035207, 0x06001b08, 0x190b0aec, 0x23000a13,   // ha.nl.jw_432 tr.de.un_430  pt.es.gl_644 pt.ca.un_650
  0x10005305, 0x0a000705, 0x10292a04, 0x033f23a0,   // ht.lt.un_330 bg.mk.un_330  mt.sl.lt_332 ca.af.nl_322
  0x170411ac, 0x190c0bad, 0x1310090d, 0x0c000309,   // ro.ru.sr_632 es.sv.gl_643  pl.lt.et_554 nl.sv.un_440
  0x17282d07, 0x093f0aa7, 0x0a000421, 0x0f350405,   // sk.sw.sr_432 pt.af.pl_532  ru.mk.un_860 fi.zu.lv_333
  // [44d0]
  0x062a35a4, 0x4a001b12, 0x551b520c, 0x321609a4,   // zu.mt.de_433 tr.yo.un_640  ha.tr.rw_543 pl.hr.bs_433
  0x1f002a0e, 0x0413680d, 0x05006408, 0x64000419,   // mt.cy.un_550 ig.et.fi_554  lg.fr.un_430 fi.lg.un_750
  0x28000313, 0x64555204, 0x200c08ee, 0x07005214,   // nl.sw.un_650 ha.rw.lg_332  no.sv.sq_422 ha.it.un_660
  0x3f1352ee, 0x1f052308, 0x4a0123a0, 0x010c0802,   // ha.et.af_422 ca.fr.cy_443  ca.en.yo_322 no.sv.en_222
  // [44e0]
  0x3f076407, 0x061b0302, 0x532a07a4, 0x3f002b09,   // lg.it.af_432 nl.tr.de_222  it.mt.ht_433 vi.af.un_440
  0x0e051fa0, 0x11061205, 0x1703110c, 0x285552ad,   // cy.fr.is_322 hu.de.ro_333  ro.nl.sr_543 ha.rw.sw_643
  0x525528ad, 0x2a033f07, 0x4a1a5507, 0x02002504,   // sw.rw.ha_643 af.nl.mt_432  rw.tl.yo_432 eu.da.un_320
  0x080711a7, 0x1e002b0d, 0x281827ec, 0x6b3b5512,   // ro.bg.uk_532 vi.ms.un_540  gd.ga.sw_644 rw.so.ceb_654
  // [44f0]
  0x1c182755, 0x06001802, 0x2868010c, 0x04071702,   // gd.ga.id_442 ga.de.un_220  en.ig.sw_543 sr.bg.ru_222
  0x04132804, 0x112718af, 0x2100200b, 0x16001f04,   // sw.et.fi_332 ga.gd.ro_655  sq.jw.un_520 cy.hr.un_320
  0x0a1f0604, 0x01081fa0, 0x285201a4, 0x11053509,   // de.cy.pt_332 cy.no.en_322  en.ha.sw_433 zu.fr.ro_444
  0x27351807, 0x10000a1a, 0x18003b04, 0x12080ea4,   // ga.zu.gd_432 mk.be.un_760  so.ga.un_320 is.no.hu_433
  // [4500]
  0x2a001f05, 0x190a0802, 0x2900160c, 0x020b0a05,   // cy.mt.un_330 no.pt.gl_222  hr.sl.un_530 pt.es.da_333
  0x28552504, 0x3f3508a4, 0x0b0813a9, 0x120425a0,   // eu.rw.sw_332 no.zu.af_433  et.no.es_544 eu.fi.hu_322
  0x0a0c5211, 0x1225060c, 0x0f02290c, 0x0c1f0ea7,   // ha.sv.pt_653 de.eu.hu_543  sl.da.lv_543 is.cy.sv_532
  0x551a6412, 0x0f00130d, 0x0a171108, 0x2100180e,   // lg.tl.rw_654 et.lv.un_540  ro.sr.mk_443 ar.fa.un_550
  // [4510]
  0x061b0cee, 0x293517ee, 0x0b2d05a4, 0x2855350d,   // sv.tr.de_422 sr.zu.sl_422  fr.sk.es_433 zu.rw.sw_554
  0x0704130c, 0x2a052107, 0x55282aa4, 0x0713110c,   // et.fi.it_543 jw.fr.mt_432  mt.sw.rw_433 ro.et.it_543
  0x2013110c, 0x050601ee, 0x11122112, 0x08201104,   // ro.et.sq_543 en.de.fr_422  jw.hu.ro_654 ro.sq.no_332
  0x3f00530d, 0x6431550c, 0x110701a0, 0x0500010c,   // ht.af.un_540 rw.az.lg_543  en.it.ro_322 en.fr.un_530
  // [4520]
  0x01002a04, 0x04321304, 0x110f29a4, 0x0f1713ee,   // mt.en.un_320 et.bs.fi_332  sl.lv.ro_433 et.sr.lv_422
  0x3555640c, 0x1f645507, 0x130223a7, 0x55641ca0,   // lg.rw.zu_543 rw.lg.cy_432  ca.da.et_532 id.lg.rw_322
  0x1f00200d, 0x1a213b04, 0x0d0c1307, 0x11050707,   // sq.cy.un_540 so.jw.tl_332  et.sv.cs_432 it.fr.ro_432
  0x0a052155, 0x13002508, 0x53002809, 0x52213ba4,   // jw.fr.pt_442 eu.et.un_430  sw.ht.un_440 so.jw.ha_433
  // [4530]
  0x23102da4, 0x0e03250c, 0x17000707, 0x0f00130c,   // sk.lt.ca_433 eu.nl.is_543  it.sr.un_420 et.lv.un_530
  0x1b1325a9, 0x19250604, 0x250e08a0, 0x120e08a4,   // eu.et.tr_544 de.eu.gl_332  no.is.eu_322 no.is.hu_433
  0x0e052d0c, 0x2d291607, 0x3f031305, 0x04000722,   // sk.fr.is_543 hr.sl.sk_432  et.nl.af_333 bg.ru.un_870
  0x030608a9, 0x5200640c, 0x10001b04, 0x231121a4,   // no.de.nl_544 lg.ha.un_530  tr.lt.un_320 jw.ro.ca_433
  // [4540]
  0x3500070d, 0x2d07110c, 0x031b2512, 0x0a002808,   // it.zu.un_540 ro.it.sk_543  eu.tr.nl_654 sw.pt.un_430
  0x1f00210c, 0x5521280c, 0x01251804, 0x29071705,   // jw.cy.un_530 sw.jw.rw_543  ga.eu.en_332 sr.it.sl_333
  0x1e061213, 0x25031b09, 0x530602a0, 0x21686b11,   // hu.de.ms_665 tr.nl.eu_444  da.de.ht_322 ceb.ig.jw_653
  0x31041312, 0x3f0103ee, 0x1c0f3512, 0x0d001114,   // et.fi.az_654 nl.en.af_422  zu.lv.id_654 ro.cs.un_660
  // [4550]
  0x13311b5a, 0x0f1a6bac, 0x17003508, 0x04003504,   // tr.az.et_553 ceb.tl.lv_632  zu.sr.un_430 zu.fi.un_320
  0x3f080e08, 0x1700041b, 0x521f3baf, 0x030e1b04,   // is.no.af_443 ru.sr.un_770  so.cy.ha_655 tr.is.nl_332
  0x0a1301a4, 0x08020eee, 0x270b23a4, 0x04070a08,   // en.et.pt_433 is.da.no_422  ca.es.gd_433 mk.bg.ru_443
  0x2d0d180c, 0x1c0853ee, 0x1b0a01a0, 0x0a00041a,   // ga.cs.sk_543 ht.no.id_422  en.pt.tr_322 ru.mk.un_760
  // [4560]
  0x162935ee, 0x0b0a2314, 0x13040807, 0x0f000c04,   // zu.sl.hr_422 ca.pt.es_666  no.fi.et_432 sv.lv.un_320
  0x04170aa4, 0x35001605, 0x0f1e35a0, 0x03003b02,   // mk.sr.ru_433 hr.zu.un_330  zu.ms.lv_322 so.nl.un_220
  0x1e1c35ee, 0x06001902, 0x033b3f0c, 0x28003204,   // zu.id.ms_422 gl.de.un_220  af.so.nl_543 bs.sw.un_320
  0x05000b04, 0x170a1002, 0x551e1c55, 0x040a07af,   // es.fr.un_320 be.mk.sr_222  id.ms.rw_442 bg.mk.ru_655
  // [4570]
  0x23190da0, 0x0e004a07, 0x082a20a0, 0x2d00120c,   // cs.gl.ca_322 yo.is.un_420  sq.mt.no_322 hu.sk.un_530
  0x08000305, 0x100a175a, 0x1800351a, 0x2835185a,   // nl.no.un_330 sr.mk.be_553  zu.ga.un_760 ga.zu.sw_553
  0x1a550455, 0x2b000808, 0x35001814, 0x182827af,   // fi.rw.tl_442 no.vi.un_430  ga.zu.un_660 gd.sw.ga_655
  0x212835ad, 0x5300180d, 0x0d006b07, 0x080410ec,   // zu.sw.jw_643 ga.ht.un_540  ceb.cs.un_420 lt.fi.no_644
  // [4580]
  0x31646ba0, 0x1820280c, 0x2d0d1602, 0x05004a12,   // ceb.lg.az_322 sw.sq.ga_543  hr.cs.sk_222 yo.fr.un_640
  0x28001e13, 0x02123f12, 0x2800131b, 0x0a071009,   // ms.sw.un_650 af.hu.da_654  et.sw.un_770 be.bg.mk_444
  0x3518270b, 0x0553010c, 0x28642107, 0x3f001a12,   // gd.ga.zu_542 en.ht.fr_543  jw.lg.sw_432 tl.af.un_640
  0x21283b0c, 0x64040b02, 0x0e0c210d, 0x18352155,   // so.sw.jw_543 es.fi.lg_222  jw.sv.is_554 jw.zu.ga_442
  // [4590]
  0x100708a6, 0x522a1ea0, 0x3f00020d, 0x685564a9,   // uk.bg.be_521 ms.mt.ha_322  da.af.un_540 lg.rw.ig_544
  0x20005205, 0x64215508, 0x3f03130c, 0x553f35a0,   // ha.sq.un_330 rw.jw.lg_443  et.nl.af_543 zu.af.rw_322
  0x033f3105, 0x52006402, 0x06001b19, 0x125564a4,   // az.af.nl_333 lg.ha.un_220  tr.de.un_750 lg.rw.hu_433
  0x1f0b19ad, 0x02001f21, 0x18003521, 0x010810a0,   // gl.es.cy_643 cy.da.un_860  zu.ga.un_860 lt.no.en_322
  // [45a0]
  0x2d004a07, 0x10001e0c, 0x2b000122, 0x55211e0c,   // yo.sk.un_420 ms.lt.un_530  en.vi.un_870 ms.jw.rw_543
  0x28352904, 0x1f080c05, 0x080c0e0d, 0x1c1e2112,   // sl.zu.sw_332 sv.no.cy_333  is.sv.no_554 jw.ms.id_654
  0x09002a09, 0x35645507, 0x0b1223ee, 0x201b2508,   // mt.pl.un_440 rw.lg.zu_432  ca.hu.es_422 eu.tr.sq_443
  0x2a002705, 0x131228a4, 0x03130111, 0x13641cee,   // gd.mt.un_330 sw.hu.et_433  en.et.nl_653 id.lg.et_422
  // [45b0]
  0x05005305, 0x08170a0d, 0x351b2a07, 0x10002912,   // ht.fr.un_330 mk.sr.uk_554  mt.tr.zu_432 sl.lt.un_640
  0x19230b0c, 0x11001019, 0x2a550707, 0x0a011a0c,   // es.ca.gl_543 be.ro.un_750  it.rw.mt_432 tl.en.pt_543
  0x07020807, 0x4a271ba4, 0x0c1f3b0e, 0x190a2509,   // no.da.it_432 tr.gd.yo_433  so.cy.sv_555 eu.pt.gl_444
  0x1c27200c, 0x11053f0c, 0x03006404, 0x68001a0e,   // sq.gd.id_543 af.fr.ro_543  lg.nl.un_320 tl.ig.un_550
  // [45c0]
  0x25001119, 0x0b122305, 0x2d000f07, 0x3b232104,   // ro.eu.un_750 ca.hu.es_333  lv.sk.un_420 jw.ca.so_332
  0x23001205, 0x190b20ee, 0x056b0c08, 0x04136807,   // hu.ca.un_330 sq.es.gl_422  sv.ceb.fr_443 ig.et.fi_432
  0x13091c09, 0x646813a7, 0x16002d04, 0x6b2a070c,   // mr.hi.bh_444 et.ig.lg_532  sk.hr.un_320 it.mt.ceb_543
  0x6400131b, 0x21000302, 0x28523ba0, 0x190a2307,   // et.lg.un_770 nl.jw.un_220  so.ha.sw_322 ca.pt.gl_432
  // [45d0]
  0x3f036411, 0x23132807, 0x1304010c, 0x2a210ea4,   // lg.nl.af_653 sw.et.ca_432  en.fi.et_543 is.jw.mt_433
  0x0318275a, 0x1e00080c, 0x17100813, 0x4a0128a0,   // gd.ga.nl_553 no.ms.un_530  uk.be.sr_665 sw.en.yo_322
  0x171632ac, 0x08000c02, 0x321701a4, 0x08110a55,   // bs.hr.sr_632 sv.no.un_220  en.sr.bs_433 mk.ro.uk_442
  0x10082507, 0x6e1b53a9, 0x2d001211, 0x121a6b07,   // eu.no.lt_432 ht.tr.hmn_544  hu.sk.un_630 ceb.tl.hu_432
  // [45e0]
  0x55002805, 0x2a00351a, 0x060e0c0c, 0x35181c07,   // sw.rw.un_330 zu.mt.un_760  sv.is.de_543 id.ga.zu_432
  0x35000605, 0x68523513, 0x04002508, 0x35211e04,   // de.zu.un_330 zu.ha.ig_665  eu.fi.un_430 ms.jw.zu_332
  0x0f006e07, 0x35006421, 0x060c0fa4, 0x0f290707,   // hmn.lv.un_420 lg.zu.un_860  lv.sv.de_433 it.sl.lv_432
  0x06190bec, 0x29071c07, 0x52003114, 0x112123a4,   // es.gl.de_644 id.it.sl_432  az.ha.un_660 ca.jw.ro_433
  // [45f0]
  0x1300200c, 0x022825a4, 0x2035130c, 0x55643507,   // sq.et.un_530 eu.sw.da_433  et.zu.sq_543 zu.lg.rw_432
  0x17040755, 0x02005305, 0x1a640914, 0x12002b18,   // bg.ru.sr_442 ht.da.un_330  pl.lg.tl_666 vi.hu.un_740
  0x0b190a04, 0x04001104, 0x521e0f13, 0x641c2108,   // pt.gl.es_332 ro.fi.un_320  lv.ms.ha_665 jw.id.lg_443
  0x02112007, 0x1b002304, 0x0f003b12, 0x1f3b1a07,   // sq.ro.da_432 ca.tr.un_320  so.lv.un_640 tl.so.cy_432
  // [4600]
  0x0e020302, 0x07281aa0, 0x0a0810ad, 0x10000a12,   // nl.da.is_222 tl.sw.it_322  be.uk.mk_643 mk.be.un_640
  0x55005221, 0x210d1c07, 0x20356455, 0x0e002a09,   // ha.rw.un_860 id.cs.jw_432  lg.zu.sq_442 mt.is.un_440
  0x311b55a9, 0x1e1c1aa4, 0x55116404, 0x071710a0,   // rw.tr.az_544 tl.id.ms_433  lg.ro.rw_332 be.sr.bg_322
  0x35005509, 0x641e1c5a, 0x29162da4, 0x29080ca4,   // rw.zu.un_440 id.ms.lg_553  sk.hr.sl_433 sv.no.sl_433
  // [4610]
  0x21121ca0, 0x4a001a12, 0x04532507, 0x281225af,   // id.hu.jw_322 tl.yo.un_640  eu.ht.fi_432 eu.hu.sw_655
  0x25006422, 0x100f2508, 0x3b2a6812, 0x231b3ba4,   // lg.eu.un_870 eu.lv.lt_443  ig.mt.so_654 so.tr.ca_433
  0x11310d07, 0x201b6e08, 0x1800270b, 0x32001e08,   // cs.az.ro_432 hmn.tr.sq_443  gd.ga.un_520 ms.bs.un_430
  0x08311804, 0x1b293102, 0x27050107, 0x08020a09,   // ga.az.no_332 az.sl.tr_222  en.fr.gd_432 pt.da.no_444
  // [4620]
  0x32251f08, 0x55004a04, 0x08252707, 0x1f3105a4,   // cy.eu.bs_443 yo.rw.un_320  gd.eu.no_432 fr.az.cy_433
  0x64093507, 0x23121f08, 0x6b1f05ee, 0x3f021bad,   // zu.pl.lg_432 cy.hu.ca_443  fr.cy.ceb_422 tr.da.af_643
  0x31003b0d, 0x1c642809, 0x1c002511, 0x0a171014,   // so.az.un_540 sw.lg.id_444  eu.id.un_630 be.sr.mk_666
  0x1f002104, 0x01550507, 0x35033fa0, 0x2800100e,   // jw.cy.un_320 fr.rw.en_432  af.nl.zu_322 lt.sw.un_550
  // [4630]
  0x1e251ba4, 0x090d2da9, 0x521f645a, 0x2500041a,   // tr.eu.ms_433 sk.cs.pl_544  lg.cy.ha_553 fi.eu.un_760
  0x10000619, 0x3b080260, 0x1700082c, 0x28271808,   // de.lt.un_750 da.no.so_664  uk.sr.un_990 ga.gd.sw_443
  0x13000409, 0x2b550504, 0x290e08a4, 0x04170a5a,   // fi.et.un_440 fr.rw.vi_332  no.is.sl_433 mk.sr.ru_553
  0x08000a09, 0x210b1ca4, 0x04071005, 0x06090112,   // mk.uk.un_440 id.es.jw_433  be.bg.ru_333 en.pl.de_654
  // [4640]
  0x0f002004, 0x093216a7, 0x02000b04, 0x555364a7,   // sq.lv.un_320 hr.bs.pl_532  es.da.un_320 lg.ht.rw_532
  0x230501ad, 0x05006e08, 0x05002b0c, 0x23000a02,   // en.fr.ca_643 hmn.fr.un_430  vi.fr.un_530 pt.ca.un_220
  0x3b002107, 0x046452a4, 0x11005207, 0x130c04ec,   // jw.so.un_420 ha.lg.fi_433  ha.ro.un_420 fi.sv.et_644
  0x101e250c, 0x1c005307, 0x1325040c, 0x0a000502,   // eu.ms.lt_543 ht.id.un_420  fi.eu.et_543 fr.pt.un_220
  // [4650]
  0x25001008, 0x0d003202, 0x170a08a9, 0x2500290d,   // lt.eu.un_430 bs.cs.un_220  uk.mk.sr_544 sl.eu.un_540
  0x25002905, 0x17292d0b, 0x0c080302, 0x10001118,   // sl.eu.un_330 sk.sl.sr_542  nl.no.sv_222 ro.be.un_740
  0x08060c09, 0x0a080460, 0x130e08a9, 0x3b2a25a9,   // sv.de.no_444 ru.uk.mk_664  no.is.et_544 eu.mt.so_544
  0x03642502, 0x1a6b35a4, 0x0e033f04, 0x0c081b07,   // eu.lg.nl_222 zu.ceb.tl_433  af.nl.is_332 tr.no.sv_432
  // [4660]
  0x13091ca4, 0x063153a4, 0x643528a9, 0x2b250cad,   // mr.hi.bh_433 ht.az.de_433  sw.zu.lg_544 sv.eu.vi_643
  0x641635ee, 0x1f001013, 0x1f101ea9, 0x190b06ba,   // zu.hr.lg_422 lt.cy.un_650  ms.lt.cy_544 de.es.gl_843
  0x12002d1a, 0x28001b14, 0x25000813, 0x6455280c,   // sk.hu.un_760 tr.sw.un_660  no.eu.un_650 sw.rw.lg_543
  0x0f552807, 0x28001e09, 0x2a00280c, 0x64095504,   // sw.rw.lv_432 ms.sw.un_440  sw.mt.un_530 rw.pl.lg_332
  // [4670]
  0x0a003507, 0x556428ec, 0x0e080ca0, 0x11002509,   // zu.pt.un_420 sw.lg.rw_644  sv.no.is_322 eu.ro.un_440
  0x20551107, 0x1f001018, 0x1f00101a, 0x2d120e07,   // ro.rw.sq_432 lt.cy.un_740  lt.cy.un_760 is.hu.sk_432
  0x060c2a07, 0x283b18a0, 0x11170808, 0x32000d0c,   // mt.sv.de_432 ga.so.sw_322  uk.sr.ro_443 cs.bs.un_530
  0x12211cee, 0x13110ca0, 0x2d55060d, 0x1b005512,   // id.jw.hu_422 sv.ro.et_322  de.rw.sk_554 rw.tr.un_640
  // [4680]
  0x311b4aa7, 0x35645511, 0x23005305, 0x25285204,   // yo.tr.az_532 rw.lg.zu_653  ht.ca.un_330 ha.sw.eu_332
  0x0c002108, 0x12001c05, 0x5500280d, 0x10001f1b,   // jw.sv.un_430 id.hu.un_330  sw.rw.un_540 cy.lt.un_770
  0x070a175a, 0x10001f21, 0x13040c07, 0x234a0b02,   // sr.mk.bg_553 cy.lt.un_860  sv.fi.et_432 es.yo.ca_222
  0x17000a0c, 0x04080709, 0x64080208, 0x100a17ee,   // mk.sr.un_530 bg.uk.ru_444  da.no.lg_443 sr.mk.be_422
  // [4690]
  0x28002312, 0x12000d08, 0x1c001212, 0x1812270c,   // ca.sw.un_640 cs.hu.un_430  hu.id.un_640 gd.hu.ga_543
  0x0d1c130c, 0x09002a04, 0x3f1264a7, 0x31003504,   // bh.mr.ne_543 mt.pl.un_320  lg.hu.af_532 zu.az.un_320
  0x01003505, 0x27002105, 0x1f000512, 0x02033f0d,   // zu.en.un_330 jw.gd.un_330  fr.cy.un_640 af.nl.da_554
  0x0e1923ee, 0x09033fa4, 0x6b554a55, 0x02000e1a,   // ca.gl.is_422 af.nl.pl_433  yo.rw.ceb_442 is.da.un_760
  // [46a0]
  0x3b640707, 0x06001707, 0x3b003f07, 0x324a3504,   // it.lg.so_432 sr.de.un_420  af.so.un_420 zu.yo.bs_332
  0x21001a05, 0x684a5508, 0x4a000520, 0x28006818,   // tl.jw.un_330 rw.yo.ig_443  fr.yo.un_850 ig.sw.un_740
  0x284a55a4, 0x27011807, 0x071710ee, 0x06000e19,   // rw.yo.sw_433 ga.en.gd_432  be.sr.bg_422 is.de.un_750
  0x043564ad, 0x180603a4, 0x1a1b21a0, 0x070804ee,   // lg.zu.fi_643 nl.de.ga_433  jw.tr.tl_322 ru.uk.bg_422
  // [46b0]
  0x135568a0, 0x196428ee, 0x062d0d55, 0x680d2da7,   // ig.rw.et_322 sw.lg.gl_422  cs.sk.de_442 sk.cs.ig_532
  0x0b00190c, 0x2d000e12, 0x2800550e, 0x3b2305a0,   // gl.es.un_530 is.sk.un_640  rw.sw.un_550 fr.ca.so_322
  0x280d1ea0, 0x2b2d2504, 0x1a6b2513, 0x2a180604,   // ms.cs.sw_322 eu.sk.vi_332  eu.ceb.tl_665 de.ga.mt_332
  0x35641e04, 0x01000b05, 0x12002804, 0x033555af,   // ms.lg.zu_332 es.en.un_330  sw.hu.un_320 rw.zu.nl_655
  // [46c0]
  0x352528ee, 0x063b1204, 0x6b2d0d04, 0x1c001e13,   // sw.eu.zu_422 hu.so.de_332  cs.sk.ceb_332 ms.id.un_650
  0x18001f20, 0x010d2da0, 0x28001312, 0x061c0502,   // cy.ga.un_850 sk.cs.en_322  et.sw.un_640 fr.id.de_222
  0x2a0764ec, 0x642506ad, 0x35000d13, 0x312305ee,   // lg.it.mt_644 de.eu.lg_643  cs.zu.un_650 fr.ca.az_422
  0x211c3104, 0x1e120607, 0x205511a4, 0x3b002721,   // az.id.jw_332 de.hu.ms_432  ro.rw.sq_433 gd.so.un_860
  // [46d0]
  0x2a00111b, 0x091827ad, 0x1a2a11ec, 0x202855a4,   // ro.mt.un_770 gd.ga.pl_643  ro.mt.tl_644 rw.sw.sq_433
  0x281e1ca4, 0x28551b0d, 0x20525508, 0x1c111ea4,   // id.ms.sw_433 tr.rw.sw_554  rw.ha.sq_443 ms.ro.id_433
  0x1e211cee, 0x28002b04, 0x52112a08, 0x213b5508,   // id.jw.ms_422 vi.sw.un_320  mt.ro.ha_443 rw.so.jw_443
  0x55011fee, 0x28521108, 0x205211a4, 0x0e111307,   // cy.en.rw_422 ro.ha.sw_443  ro.ha.sq_433 et.ro.is_432
  // [46e0]
  0x01212ba0, 0x5500250d, 0x55281108, 0x036b050b,   // vi.jw.en_322 eu.rw.un_540  ro.sw.rw_443 fr.ceb.nl_542
  0x20213b0c, 0x273f030c, 0x31211b0c, 0x2b181fa4,   // so.jw.sq_543 nl.af.gd_543  tr.jw.az_543 cy.ga.vi_433
  0x1f001813, 0x0c085204, 0x033f1a07, 0x551128ad,   // ga.cy.un_650 ha.no.sv_332  tl.af.nl_432 sw.ro.rw_643
  0x250668ee, 0x04112aa4, 0x2d0d0602, 0x55216804,   // ig.de.eu_422 mt.ro.fi_433  de.cs.sk_222 ig.jw.rw_332
  // [46f0]
  0x102a1160, 0x03002307, 0x3100111a, 0x21525508,   // ro.mt.lt_664 ca.nl.un_420  ro.az.un_760 rw.ha.jw_443
  0x201a110c, 0x041a110c, 0x68211307, 0x3b003122,   // ro.tl.sq_543 ro.tl.fi_543  et.jw.ig_432 az.so.un_870
  0x281b31af, 0x55682107, 0x131e1c09, 0x03000f02,   // az.tr.sw_655 jw.ig.rw_432  id.ms.et_444 lv.nl.un_220
  0x3f32290c, 0x6b2b01a4, 0x1c231107, 0x0a001707,   // sl.bs.af_543 en.vi.ceb_433  ro.ca.id_432 sr.mk.un_420
  // [4700]
  0x06002505, 0x172007a9, 0x05120b02, 0x026b3f07,   // eu.de.un_330 it.sq.sr_544  es.hu.fr_222 af.ceb.da_432
  0x52001a08, 0x230e3f04, 0x0e006419, 0x12002308,   // tl.ha.un_430 af.is.ca_332  lg.is.un_750 ca.hu.un_430
  0x25640c02, 0x13211ea0, 0x0a230c04, 0x28135213,   // sv.lg.eu_222 ms.jw.et_322  sv.ca.pt_332 ha.et.sw_665
  0x0f64250c, 0x0a17080c, 0x12001809, 0x190b1205,   // eu.lg.lv_543 uk.sr.mk_543  ga.hu.un_440 hu.es.gl_333
  // [4710]
  0x6400040d, 0x3b001e13, 0x1b0a4a60, 0x523b0b55,   // fi.lg.un_540 ms.so.un_650  yo.pt.tr_664 es.so.ha_442
  0x2d120d08, 0x20172907, 0x4a046407, 0x041708ec,   // cs.hu.sk_443 sl.sr.sq_432  lg.fi.yo_432 uk.sr.ru_644
  0x13001602, 0x12062507, 0x64001f02, 0x09002d18,   // hr.et.un_220 eu.de.hu_432  cy.lg.un_220 sk.pl.un_740
  0x08120302, 0x05122d02, 0x52002721, 0x322d29a0,   // nl.hu.no_222 sk.hu.fr_222  gd.ha.un_860 sl.sk.bs_322
  // [4720]
  0x3b041309, 0x171321ad, 0x101c2109, 0x12002809,   // et.fi.so_444 jw.et.sr_643  jw.id.lt_444 sw.hu.un_440
  0x0f001323, 0x3b1c1ea4, 0x190b27a0, 0x161e1c55,   // et.lv.un_880 ms.id.so_433  gd.es.gl_322 id.ms.hr_442
  0x1e04640c, 0x120d2d12, 0x290d2d07, 0x09000f04,   // lg.fi.ms_543 sk.cs.hu_654  sk.cs.sl_432 lv.pl.un_320
  0x1200091a, 0x0c001f08, 0x211c4aad, 0x1f010504,   // pl.hu.un_760 cy.sv.un_430  yo.id.jw_643 fr.en.cy_332
  // [4730]
  0x13041ba4, 0x32001e0c, 0x17160205, 0x5300680c,   // tr.fi.et_433 ms.bs.un_530  da.hr.sr_333 ig.ht.un_530
  0x5512280c, 0x1c000d0b, 0x680c1109, 0x352168a9,   // sw.hu.rw_543 ne.mr.un_520  ro.sv.ig_444 ig.jw.zu_544
  0x28214a07, 0x29001219, 0x1e216ba0, 0x1228640c,   // yo.jw.sw_432 hu.sl.un_750  ceb.jw.ms_322 lg.sw.hu_543
  0x0c643504, 0x06000411, 0x06185307, 0x190a2709,   // zu.lg.sv_332 fi.de.un_630  ht.ga.de_432 gd.pt.gl_444
  // [4740]
  0x550a1bee, 0x0c080eee, 0x2d3b1ea6, 0x1f000c0d,   // tr.pt.rw_422 is.no.sv_422  ms.so.sk_521 sv.cy.un_540
  0x55000d08, 0x0501110c, 0x19312a11, 0x64001f19,   // cs.rw.un_430 ro.en.fr_543  mt.az.gl_653 cy.lg.un_750
  0x25001308, 0x252023a0, 0x1c1e3f0c, 0x0e1905a0,   // et.eu.un_430 ca.sq.eu_322  af.ms.id_543 fr.gl.is_322
  0x0708110e, 0x6423350d, 0x170a1009, 0x25556808,   // ro.uk.bg_555 zu.ca.lg_554  be.mk.sr_444 ig.rw.eu_443
  // [4750]
  0x1100280e, 0x68005514, 0x253f6ba0, 0x35285513,   // sw.ro.un_550 rw.ig.un_660  ceb.af.eu_322 rw.sw.zu_665
  0x0455280d, 0x12002807, 0x1728290d, 0x3b351ca0,   // sw.rw.fi_554 sw.hu.un_420  sl.sw.sr_554 id.zu.so_322
  0x550f0708, 0x1803050c, 0x01681b0d, 0x033f2804,   // it.lv.rw_443 fr.nl.ga_543  tr.ig.en_554 sw.af.nl_332
  0x042111a4, 0x20002713, 0x10270408, 0x11282009,   // ro.jw.fi_433 gd.sq.un_650  fi.gd.lt_443 sq.sw.ro_444
  // [4760]
  0x2a0955a7, 0x646b550c, 0x033f0609, 0x2d001212,   // rw.pl.mt_532 rw.ceb.lg_543  de.af.nl_444 hu.sk.un_640
  0x1827010c, 0x051827af, 0x10070409, 0x523b21a4,   // en.gd.ga_543 gd.ga.fr_655  ru.bg.be_444 jw.so.ha_433
  0x230501a4, 0x31113bec, 0x1c083fa0, 0x553564a9,   // en.fr.ca_433 so.ro.az_644  af.no.id_322 lg.zu.rw_544
  0x28006b22, 0x52000a04, 0x17551e0d, 0x553f1f07,   // ceb.sw.un_870 pt.ha.un_320  ms.rw.sr_554 cy.af.rw_432
  // [4770]
  0x64523509, 0x06050ea0, 0x190a23a4, 0x0800291a,   // zu.ha.lg_444 is.fr.de_322  ca.pt.gl_433 sl.no.un_760
  0x08070a0b, 0x29072aee, 0x0a0807ad, 0x2d190a55,   // mk.bg.uk_542 mt.it.sl_422  bg.uk.mk_643 pt.gl.sk_442
  0x0710040c, 0x060301a0, 0x291705ad, 0x0c2925a9,   // ru.be.bg_543 en.nl.de_322  fr.sr.sl_643 eu.sl.sv_544
  0x551a2812, 0x1a641c0c, 0x072125ee, 0x6b1a2814,   // sw.tl.rw_654 id.lg.tl_543  eu.jw.it_422 sw.tl.ceb_666
  // [4780]
  0x3f0c0811, 0x103b520d, 0x0f0c08af, 0x0a000814,   // no.sv.af_653 ha.so.lt_554  no.sv.lv_655 uk.mk.un_660
  0x2d002920, 0x08171107, 0x1b002902, 0x35001e08,   // sl.sk.un_850 ro.sr.uk_432  sl.tr.un_220 ms.zu.un_430
  0x64002809, 0x3b1052a9, 0x52531fa0, 0x1a3b5212,   // sw.lg.un_440 ha.lt.so_544  cy.ht.ha_322 ha.so.tl_654
  0x64094a02, 0x0a072d05, 0x293525a9, 0x2d0c025a,   // yo.pl.lg_222 sk.it.pt_333  eu.zu.sl_544 da.sv.sk_553
  // [4790]
  0x35645509, 0x170a2d07, 0x0c0f040c, 0x04522555,   // rw.lg.zu_444 sk.pt.sr_432  fi.lv.sv_543 eu.ha.fi_442
  0x00000a2d, 0x092d0d0b, 0x020c08a9, 0x3b281e0c,   // mk.un.un_A00 cs.sk.pl_542  no.sv.da_544 ms.sw.so_543
  0x0c0208ad, 0x11100813, 0x270c08a4, 0x6b184a11,   // no.da.sv_643 uk.be.ro_665  no.sv.gd_433 yo.ga.ceb_653
  0x321729af, 0x645535a9, 0x2b1f0611, 0x084a6b02,   // sl.sr.bs_655 zu.rw.lg_544  de.cy.vi_653 ceb.yo.no_222
  // [47a0]
  0x13001208, 0x050b0a04, 0x0d000221, 0x0b002512,   // hu.et.un_430 pt.es.fr_332  da.cs.un_860 eu.es.un_640
  0x53000d13, 0x0b1107a0, 0x01001902, 0x3f0d11ee,   // cs.ht.un_650 it.ro.es_322  gl.en.un_220 ro.cs.af_422
  0x012523ad, 0x0f3b28a0, 0x0c082905, 0x09010da4,   // ca.eu.en_643 sw.so.lv_322  sl.no.sv_333 cs.en.pl_433
  0x13352108, 0x0620010c, 0x132108af, 0x53006409,   // jw.zu.et_443 en.sq.de_543  no.jw.et_655 lg.ht.un_440
  // [47b0]
  0x070a100c, 0x0e000820, 0x04080204, 0x2a3b11ad,   // be.mk.bg_543 no.is.un_850  da.no.fi_332 ro.so.mt_643
  0x28000704, 0x11350502, 0x121311ec, 0x0d1218ad,   // it.sw.un_320 fr.zu.ro_222  ro.et.hu_644 ga.hu.cs_643
  0x131e1c0c, 0x1300110c, 0x292d09a9, 0x533b6407,   // id.ms.et_543 ro.et.un_530  pl.sk.sl_544 lg.so.ht_432
  0x11000120, 0x10131108, 0x1e005202, 0x02001007,   // en.ro.un_850 ro.et.lt_443  ha.ms.un_220 lt.da.un_420
  // [47c0]
  0x286b35a0, 0x211b310c, 0x3b002811, 0x3b002807,   // zu.ceb.sw_322 az.tr.jw_543  sw.so.un_630 sw.so.un_420
  0x08040702, 0x35520eee, 0x1e0413a0, 0x4a535511,   // bg.ru.uk_222 is.ha.zu_422  et.fi.ms_322 rw.ht.yo_653
  0x68086b0c, 0x251211ad, 0x28524a09, 0x1c122107,   // ceb.no.ig_543 ro.hu.eu_643  yo.ha.sw_444 jw.hu.id_432
  0x3b001113, 0x170a0809, 0x3f001108, 0x28352104,   // ro.so.un_650 uk.mk.sr_444  ro.af.un_430 jw.zu.sw_332
  // [47d0]
  0x100f1304, 0x640a3505, 0x1e2a11ec, 0x3b285555,   // et.lv.lt_332 zu.pt.lg_333  ro.mt.ms_644 rw.sw.so_442
  0x3f3503ee, 0x2100110c, 0x21005307, 0x1327110c,   // nl.zu.af_422 ro.jw.un_530  ht.jw.un_420 ro.gd.et_543
  0x23101307, 0x0a251108, 0x125564a7, 0x0c3f08a4,   // et.lt.ca_432 ro.eu.pt_443  lg.rw.hu_532 no.af.sv_433
  0x23006404, 0x062a3f55, 0x0c0a080b, 0x3500640b,   // lg.ca.un_320 af.mt.de_442  no.pt.sv_542 lg.zu.un_520
  // [47e0]
  0x0e283508, 0x2d0d1009, 0x020c2305, 0x32002a19,   // zu.sw.is_443 lt.cs.sk_444  ca.sv.da_333 mt.bs.un_750
  0x25002a04, 0x535213ad, 0x17001c04, 0x53003f02,   // mt.eu.un_320 et.ha.ht_643  id.sr.un_320 af.ht.un_220
  0x16520c07, 0x170a1111, 0x09001c02, 0x080e3f0c,   // sv.ha.hr_432 ro.mk.sr_653  mr.hi.un_220 af.is.no_543
  0x0a53030c, 0x250b2307, 0x212a1c12, 0x0d291604,   // nl.ht.pt_543 ca.es.eu_432  id.mt.jw_654 hr.sl.cs_332
  // [47f0]
  0x0c04135a, 0x102017ee, 0x5500121b, 0x0a0511ee,   // et.fi.sv_553 sr.sq.lt_422  hu.rw.un_770 ro.fr.pt_422
  0x32001b0d, 0x0c033f07, 0x280f520c, 0x1a6b01a7,   // tr.bs.un_540 af.nl.sv_432  ha.lv.sw_543 en.ceb.tl_532
  0x27190b11, 0x1752290c, 0x1b18270c, 0x072327a0,   // es.gl.gd_653 sl.ha.sr_543  gd.ga.tr_543 gd.ca.it_322
  0x190b11ec, 0x21006404, 0x0f105208, 0x07100405,   // ro.es.gl_644 lg.jw.un_320  ha.lt.lv_443 ru.be.bg_333

  // [4800]
  0x0a1e1c0b, 0x0800031b, 0x04000835, 0x101b2d07,   // id.ms.pt_542 nl.no.un_770  uk.ru.un_A90 sk.tr.lt_432
  0x53551bec, 0x1b553504, 0x31003f04, 0x35002105,   // tr.rw.ht_644 zu.rw.tr_332  af.az.un_320 jw.zu.un_330
  0x55311b0c, 0x0d132d12, 0x21100fa7, 0x3100281b,   // tr.az.rw_543 sk.et.cs_654  lv.lt.jw_532 sw.az.un_770
  0x091203a0, 0x1a252807, 0x0a07010c, 0x09122707,   // nl.hu.pl_322 sw.eu.tl_432  en.it.pt_543 gd.hu.pl_432
  // [4810]
  0x17001e07, 0x12002907, 0x130f1004, 0x32171b0c,   // ms.sr.un_420 sl.hu.un_420  lt.lv.et_332 tr.sr.bs_543
  0x052701a0, 0x32110aa0, 0x55352812, 0x01190b13,   // en.gd.fr_322 pt.ro.bs_322  sw.zu.rw_654 es.gl.en_665
  0x0b52280b, 0x0c0e3f12, 0x081218af, 0x3b211c04,   // sw.ha.es_542 af.is.sv_654  ga.hu.no_655 id.jw.so_332
  0x12000714, 0x07002309, 0x05002708, 0x0b2319a9,   // it.hu.un_660 ca.it.un_440  gd.fr.un_430 gl.ca.es_544
  // [4820]
  0x01000707, 0x2a1107a7, 0x0c6b1a0c, 0x1e1c29af,   // it.en.un_420 it.ro.mt_532  tl.ceb.sv_543 sl.id.ms_655
  0x0b070aee, 0x09006e04, 0x1a1c6ba4, 0x686b010c,   // pt.it.es_422 hmn.pl.un_320  ceb.id.tl_433 en.ceb.ig_543
  0x3b00310e, 0x28005508, 0x05110104, 0x01000702,   // az.so.un_550 rw.sw.un_430  en.ro.fr_332 it.en.un_220
  0x31000712, 0x3b131f0c, 0x130b6bec, 0x6b001334,   // it.az.un_640 cy.et.so_543  ceb.es.et_644 et.ceb.un_A80
  // [4830]
  0x08006b13, 0x6b130d11, 0x1e3b1312, 0x082002a0,   // ceb.no.un_650 cs.et.ceb_653  et.so.ms_654 da.sq.no_322
  0x080213ee, 0x28005504, 0x01186ba0, 0x081e1c08,   // et.da.no_422 rw.sw.un_320  ceb.ga.en_322 id.ms.no_443
  0x23181f12, 0x123f1002, 0x11000504, 0x07080a14,   // cy.ga.ca_654 lt.af.hu_222  fr.ro.un_320 mk.uk.bg_666
  0x1a006b02, 0x12001c02, 0x23010e09, 0x121e1c02,   // ceb.tl.un_220 id.hu.un_220  is.en.ca_444 id.ms.hu_222
  // [4840]
  0x08120c02, 0x13080209, 0x19001813, 0x6b000d13,   // sv.hu.no_222 da.no.et_444  ga.gl.un_650 cs.ceb.un_650
  0x13006b13, 0x190b1809, 0x0d190b02, 0x190b13a0,   // ceb.et.un_650 ga.es.gl_444  es.gl.cs_222 et.es.gl_322
  0x0600100d, 0x212d0d04, 0x35002804, 0x1a002102,   // lt.de.un_540 cs.sk.jw_332  sw.zu.un_320 jw.tl.un_220
  0x07110405, 0x0c0e1f04, 0x0e1308ec, 0x092d0dee,   // ru.ro.bg_333 cy.is.sv_332  no.et.is_644 cs.sk.pl_422
  // [4850]
  0x11002505, 0x53040d0b, 0x3b55350d, 0x211c01a9,   // eu.ro.un_330 cs.fi.ht_542  zu.rw.so_554 en.id.jw_544
  0x2a006402, 0x6b080209, 0x4a000414, 0x521a1ca0,   // lg.mt.un_220 da.no.ceb_444  fi.yo.un_660 id.tl.ha_322
  0x64355514, 0x11521a0d, 0x0911230b, 0x082302ee,   // rw.zu.lg_666 tl.ha.ro_554  ca.ro.pl_542 da.ca.no_422
  0x6b521aa9, 0x4a005213, 0x1b00350c, 0x090b2508,   // tl.ha.ceb_544 ha.yo.un_650  zu.tr.un_530 eu.es.pl_443
  // [4860]
  0x550b1bee, 0x0d092a04, 0x063b1ca4, 0x3b521e07,   // tr.es.rw_422 mt.pl.cs_332  id.so.de_433 ms.ha.so_432
  0x64355504, 0x32162da9, 0x28104aec, 0x1b55310e,   // rw.zu.lg_332 sk.hr.bs_544  yo.lt.sw_644 az.rw.tr_555
  0x012305ad, 0x27005507, 0x31003b1b, 0x0c120808,   // fr.ca.en_643 rw.gd.un_420  so.az.un_770 no.hu.sv_443
  0x64520404, 0x3b031fa6, 0x0c002704, 0x1e212a12,   // fi.ha.lg_332 cy.nl.so_521  gd.sv.un_320 mt.jw.ms_654
  // [4870]
  0x356b1a07, 0x0f000905, 0x31003b2b, 0x2d001219,   // tl.ceb.zu_432 pl.lv.un_330  so.az.un_980 hu.sk.un_750
  0x64003513, 0x130f0409, 0x08170707, 0x21553bad,   // zu.lg.un_650 fi.lv.et_444  bg.sr.uk_432 so.rw.jw_643
  0x521b0807, 0x3f350304, 0x211812ee, 0x20282755,   // no.tr.ha_432 nl.zu.af_332  ur.ar.fa_422 gd.sw.sq_442
  0x0c0e0807, 0x4a1b0f11, 0x4a0f3507, 0x0a081008,   // no.is.sv_432 lv.tr.yo_653  zu.lv.yo_432 be.uk.mk_443
  // [4880]
  0x04001309, 0x1b003107, 0x32286b07, 0x00001337,   // et.fi.un_440 az.tr.un_420  ceb.sw.bs_432 bh.un.un_B00
  0x23072013, 0x2a230f04, 0x12061b04, 0x20003b0d,   // sq.it.ca_665 lv.ca.mt_332  tr.de.hu_332 so.sq.un_540
  0x180c06a0, 0x683f06a4, 0x3f003509, 0x01062705,   // de.sv.ga_322 de.af.ig_433  zu.af.un_440 gd.de.en_333
  0x322d2907, 0x5300200c, 0x1c0e1204, 0x122d0d02,   // sl.sk.bs_432 sq.ht.un_530  hu.is.id_332 cs.sk.hu_222
  // [4890]
  0x020301a4, 0x0c100f55, 0x282a18a4, 0x060c08a0,   // en.nl.da_433 lv.lt.sv_442  ga.mt.sw_433 no.sv.de_322
  0x176b25ad, 0x5300020d, 0x3f06080c, 0x0d321708,   // eu.ceb.sr_643 da.ht.un_540  no.de.af_543 sr.bs.cs_443
  0x0f180607, 0x06200c04, 0x0c270804, 0x1752200b,   // de.ga.lv_432 sv.sq.de_332  no.gd.sv_332 sq.ha.sr_542
  0x13001a02, 0x0800042b, 0x3f00090d, 0x041707ee,   // tl.et.un_220 ru.uk.un_980  pl.af.un_540 bg.sr.ru_422
  // [48a0]
  0x6b012b07, 0x2300290c, 0x0711050c, 0x16002007,   // vi.en.ceb_432 sl.ca.un_530  fr.ro.it_543 sq.hr.un_420
  0x21550a04, 0x3b255208, 0x03060c07, 0x2d00060c,   // pt.rw.jw_332 ha.eu.so_443  sv.de.nl_432 de.sk.un_530
  0x312b0604, 0x0a002305, 0x251a6b60, 0x3f1306a4,   // de.vi.az_332 ca.pt.un_330  ceb.tl.eu_664 de.et.af_433
  0x20001108, 0x08170412, 0x53000509, 0x0d0c12a0,   // ro.sq.un_430 ru.sr.uk_654  fr.ht.un_440 hu.sv.cs_322
  // [48b0]
  0x230603a4, 0x321703a0, 0x12002107, 0x06310f02,   // nl.de.ca_433 nl.sr.bs_322  fa.ur.un_420 lv.az.de_222
  0x02080e08, 0x6b000608, 0x0c005202, 0x18120507,   // is.no.da_443 de.ceb.un_430  ha.sv.un_220 fr.hu.ga_432
  0x0c005504, 0x110a19a0, 0x054a09a9, 0x05000213,   // rw.sv.un_320 gl.pt.ro_322  pl.yo.fr_544 da.fr.un_650
  0x1b6b1a08, 0x0a0407ad, 0x0c0604ee, 0x19113b05,   // tl.ceb.tr_443 bg.ru.mk_643  fi.de.sv_422 so.ro.gl_333
  // [48c0]
  0x02042ba0, 0x25054aa7, 0x120b0a09, 0x2a1a20a0,   // vi.fi.da_322 yo.fr.eu_532  pt.es.hu_444 sq.tl.mt_322
  0x0a52010b, 0x0e001119, 0x252b1fee, 0x070a0413,   // en.ha.pt_542 ro.is.un_750  cy.vi.eu_422 ru.mk.bg_665
  0x0e2d18ec, 0x033f21af, 0x0c000414, 0x1f2b0a09,   // ga.sk.is_644 jw.af.nl_655  fi.sv.un_660 pt.vi.cy_444
  0x536b01ee, 0x04111ba4, 0x04000614, 0x12556404,   // en.ceb.ht_422 tr.ro.fi_433  de.fi.un_660 lg.rw.hu_332
  // [48d0]
  0x01556807, 0x28321655, 0x0e521807, 0x64003507,   // ig.rw.en_432 hr.bs.sw_442  ga.ha.is_432 zu.lg.un_420
  0x1c001e2b, 0x522855ec, 0x0c001905, 0x09111704,   // ms.id.un_980 rw.sw.ha_644  gl.sv.un_330 sr.ro.pl_332
  0x0c031907, 0x1b000808, 0x192010ee, 0x030c19ee,   // gl.nl.sv_432 no.tr.un_430  lt.sq.gl_422 gl.sv.nl_422
  0x0e081f0c, 0x64006821, 0x06210eee, 0x0464130c,   // cy.no.is_543 ig.lg.un_860  is.jw.de_422 et.lg.fi_543
  // [48e0]
  0x0f0728a0, 0x1b2307a0, 0x031b3104, 0x052923a0,   // sw.it.lv_322 it.ca.tr_322  az.tr.nl_332 ca.sl.fr_322
  0x08281fee, 0x2d0d1ea4, 0x31001c02, 0x13063fa0,   // cy.sw.no_422 ms.cs.sk_433  id.az.un_220 af.de.et_322
  0x35251c12, 0x12000b14, 0x0710170c, 0x06000323,   // id.eu.zu_654 es.hu.un_660  sr.be.bg_543 nl.de.un_880
  0x4a006422, 0x01251c04, 0x1c081ba0, 0x060164a0,   // lg.yo.un_870 id.eu.en_332  tr.no.id_322 lg.en.de_322
  // [48f0]
  0x19000a19, 0x061207a0, 0x0c060e0c, 0x04000609,   // pt.gl.un_750 it.hu.de_322  is.de.sv_543 de.fi.un_440
  0x01000b04, 0x21000a05, 0x524a20a4, 0x20002b0c,   // es.en.un_320 pt.jw.un_330  sq.yo.ha_433 vi.sq.un_530
  0x4a1b2aac, 0x29535513, 0x112a07a4, 0x2300070c,   // mt.tr.yo_632 rw.ht.sl_665  it.mt.ro_433 it.ca.un_530
  0x01000c02, 0x19001212, 0x29682dec, 0x0c270107,   // sv.en.un_220 hu.gl.un_640  sk.ig.sl_644 en.gd.sv_432
  // [4900]
  0x063f03a0, 0x030c06a7, 0x03003f11, 0x29005212,   // nl.af.de_322 de.sv.nl_532  af.nl.un_630 ha.sl.un_640
  0x08000f18, 0x68005312, 0x04171104, 0x5200290d,   // lv.no.un_740 ht.ig.un_640  ro.sr.ru_332 sl.ha.un_540
  0x0e0c2307, 0x27005504, 0x090d1ca7, 0x0b000c04,   // ca.sv.is_432 rw.gd.un_320  mr.ne.hi_532 sv.es.un_320
  0x070a1107, 0x17000713, 0x05000302, 0x23556407,   // ro.mk.bg_432 bg.sr.un_650  nl.fr.un_220 lg.rw.ca_432
  // [4910]
  0x0a5355a4, 0x07081007, 0x07002a07, 0x13324a02,   // rw.ht.pt_433 be.uk.bg_432  mt.it.un_420 yo.bs.et_222
  0x20000c1a, 0x0a00080c, 0x313f0fad, 0x32000f19,   // sv.sq.un_760 uk.mk.un_530  lv.af.az_643 lv.bs.un_750
  0x2d000c04, 0x07100aa0, 0x55001e08, 0x29001a02,   // sv.sk.un_320 mk.be.bg_322  ms.rw.un_430 tl.sl.un_220
  0x27002b08, 0x0a1711ac, 0x0e1b3ba4, 0x0e1b0404,   // vi.gd.un_430 ro.sr.mk_632  so.tr.is_433 fi.tr.is_332
  // [4920]
  0x020608a9, 0x03080405, 0x04070aa7, 0x211e1b04,   // no.de.da_544 fi.no.nl_333  mk.bg.ru_532 tr.ms.jw_332
  0x20320355, 0x060403ad, 0x0f000c0c, 0x3f1f0e60,   // nl.bs.sq_442 nl.fi.de_643  sv.lv.un_530 is.cy.af_664
  0x1c131eac, 0x1f002714, 0x21041eee, 0x05202b04,   // ms.et.id_632 gd.cy.un_660  ms.fi.jw_422 vi.sq.fr_332
  0x1b315204, 0x21001305, 0x13352aee, 0x1c530808,   // ha.az.tr_332 et.jw.un_330  mt.zu.et_422 no.ht.id_443
  // [4930]
  0x21006b09, 0x100428ac, 0x04000a0b, 0x2300040d,   // ceb.jw.un_440 sw.fi.lt_632  mk.ru.un_520 fi.ca.un_540
  0x11040d0b, 0x20002122, 0x04110807, 0x201e1c0d,   // cs.fi.ro_542 jw.sq.un_870  uk.ro.ru_432 id.ms.sq_554
  0x11001c09, 0x1c001e19, 0x11002a0c, 0x6b20230c,   // id.ro.un_440 ms.id.un_750  mt.ro.un_530 ca.sq.ceb_543
  0x04171105, 0x0410070d, 0x050c5304, 0x21131ca0,   // ro.sr.ru_333 bg.be.ru_554  ht.sv.fr_332 id.et.jw_322
  // [4940]
  0x160e0a04, 0x08041714, 0x070335a0, 0x0f111055,   // pt.is.hr_332 sr.ru.uk_666  zu.nl.it_322 lt.ro.lv_442
  0x64003512, 0x21001b05, 0x1b2a04ad, 0x061c2107,   // zu.lg.un_640 tr.jw.un_330  fi.mt.tr_643 jw.id.de_432
  0x1b002a19, 0x13041ea4, 0x07005504, 0x041711a6,   // mt.tr.un_750 ms.fi.et_433  rw.it.un_320 ro.sr.ru_521
  0x6b6809a4, 0x23002522, 0x0d282da7, 0x27000309,   // pl.ig.ceb_433 eu.ca.un_870  sk.sw.cs_532 nl.gd.un_440
  // [4950]
  0x35002b07, 0x3100090c, 0x4a00230d, 0x550728af,   // vi.zu.un_420 pl.az.un_530  ca.yo.un_540 sw.it.rw_655
  0x1135070c, 0x18002a07, 0x1a1e1c0d, 0x06003b0e,   // it.zu.ro_543 mt.ga.un_420  id.ms.tl_554 so.de.un_550
  0x2800351b, 0x17000307, 0x27000307, 0x080f0204,   // zu.sw.un_770 nl.sr.un_420  nl.gd.un_420 da.lv.no_332
  0x17100402, 0x18003507, 0x35533105, 0x08040714,   // ru.be.sr_222 zu.ga.un_420  az.ht.zu_333 bg.ru.uk_666
  // [4960]
  0x091a6ba4, 0x3f12030c, 0x09000513, 0x1b000704,   // ceb.tl.pl_433 nl.hu.af_543  fr.pl.un_650 it.tr.un_320
  0x351a13af, 0x080212a0, 0x64352809, 0x23001f19,   // et.tl.zu_655 hu.da.no_322  sw.zu.lg_444 cy.ca.un_750
  0x352564ec, 0x53211c02, 0x111a640c, 0x095564a0,   // lg.eu.zu_644 id.jw.ht_222  lg.tl.ro_543 lg.rw.pl_322
  0x25002a13, 0x2d160d0d, 0x6b001005, 0x041b35a9,   // mt.eu.un_650 cs.hr.sk_554  lt.ceb.un_330 zu.tr.fi_544
  // [4970]
  0x556435a9, 0x170f0307, 0x09001309, 0x1100531b,   // zu.lg.rw_544 nl.lv.sr_432  bh.hi.un_440 ht.ro.un_770
  0x1c121eaf, 0x0b001807, 0x0e2a23a7, 0x271813a4,   // ms.hu.id_655 ga.es.un_420  ca.mt.is_532 et.ga.gd_433
  0x310f2555, 0x04120a04, 0x1200080b, 0x042810a0,   // eu.lv.az_442 pt.hu.fi_332  no.hu.un_520 lt.sw.fi_322
  0x352532ee, 0x11002908, 0x12000a19, 0x100a070d,   // bs.eu.zu_422 sl.ro.un_430  pt.hu.un_750 bg.mk.be_554
  // [4980]
  0x0a0813ee, 0x131e53a7, 0x03120aad, 0x6404100c,   // et.no.pt_422 ht.ms.et_532  pt.hu.nl_643 lt.fi.lg_543
  0x1a352811, 0x20001c08, 0x04006412, 0x643525a9,   // sw.zu.tl_653 id.sq.un_430  lg.fi.un_640 eu.zu.lg_544
  0x08111711, 0x292d08a0, 0x3f00680e, 0x6b3f0312,   // sr.ro.uk_653 no.sk.sl_322  ig.af.un_550 nl.af.ceb_654
  0x10172dee, 0x011f0407, 0x3f1e1ca4, 0x2d001102,   // sk.sr.lt_422 fi.cy.en_432  id.ms.af_433 ro.sk.un_220
  // [4990]
  0x231729ee, 0x08030611, 0x03002d08, 0x08170705,   // sl.sr.ca_422 de.nl.no_653  sk.nl.un_430 bg.sr.uk_333
  0x0e1c1aa4, 0x032718a9, 0x04111c04, 0x0a0410af,   // tl.id.is_433 ga.gd.nl_544  id.ro.fi_332 be.ru.mk_655
  0x2d1c35a0, 0x2d230204, 0x100704a9, 0x02080e55,   // zu.id.sk_322 da.ca.sk_332  ru.bg.be_544 is.no.da_442
  0x122d0daf, 0x0a2d0da4, 0x122d0d60, 0x07041114,   // cs.sk.hu_655 cs.sk.pt_433  cs.sk.hu_664 ro.ru.bg_666
  // [49a0]
  0x032d20a4, 0x17292d11, 0x173129a4, 0x211820af,   // sq.sk.nl_433 sk.sl.sr_653  sl.az.sr_433 sq.ga.jw_655
  0x12552107, 0x0e0c0607, 0x0a00081a, 0x32292da0,   // jw.rw.hu_432 de.sv.is_432  uk.mk.un_760 sk.sl.bs_322
  0x2a645255, 0x53350a08, 0x230b0a04, 0x2d2a18a9,   // ha.lg.mt_442 pt.zu.ht_443  pt.es.ca_332 ga.mt.sk_544
  0x0e001304, 0x072a3505, 0x27001f19, 0x0e321704,   // et.is.un_320 zu.mt.it_333  cy.gd.un_750 sr.bs.is_332
  // [49b0]
  0x216b52a0, 0x291353a0, 0x20001222, 0x64041307,   // ha.ceb.jw_322 ht.et.sl_322  hu.sq.un_870 et.fi.lg_432
  0x2000121a, 0x122a0408, 0x031e010c, 0x100804ad,   // hu.sq.un_760 fi.mt.hu_443  en.ms.nl_543 ru.uk.be_643
  0x32000907, 0x0800210d, 0x2d003b22, 0x1b5253a4,   // pl.bs.un_420 jw.no.un_540  so.sk.un_870 ht.ha.tr_433
  0x03063f0d, 0x52000112, 0x174a52af, 0x06000e22,   // af.de.nl_554 en.ha.un_640  ha.yo.sr_655 is.de.un_870
  // [49c0]
  0x120818a0, 0x20282104, 0x061f18a4, 0x03001f0c,   // ga.no.hu_322 jw.sw.sq_332  ga.cy.de_433 cy.nl.un_530
  0x2d0d35ee, 0x27003f0c, 0x524a35a7, 0x6b2b0107,   // zu.cs.sk_422 af.gd.un_530  zu.yo.ha_532 en.vi.ceb_432
  0x6b1820ee, 0x20005521, 0x08002022, 0x2d161f07,   // sq.ga.ceb_422 rw.sq.un_860  sq.no.un_870 cy.hr.sk_432
  0x10041107, 0x165504ee, 0x09004a05, 0x28001f02,   // ro.ru.be_432 fi.rw.hr_422  yo.pl.un_330 cy.sw.un_220
  // [49d0]
  0x160e04a4, 0x160d2904, 0x522a10ad, 0x2b002511,   // fi.is.hr_433 sl.cs.hr_332  lt.mt.ha_643 eu.vi.un_630
  0x211c0107, 0x0c2b1aa0, 0x0e00120c, 0x06081307,   // en.id.jw_432 tl.vi.sv_322  hu.is.un_530 et.no.de_432
  0x1e120f0b, 0x5301280c, 0x3b001912, 0x12080202,   // lv.hu.ms_542 sw.en.ht_543  gl.so.un_640 da.no.hu_222
  0x200c08a4, 0x20002107, 0x21201ea0, 0x3125280c,   // no.sv.sq_433 jw.sq.un_420  ms.sq.jw_322 sw.eu.az_543
  // [49e0]
  0x08070a13, 0x165228a4, 0x021b17a0, 0x28033f04,   // mk.bg.uk_665 sw.ha.hr_433  sr.tr.da_322 af.nl.sw_332
  0x1b1a6b0d, 0x011311a0, 0x32031e07, 0x2b006b08,   // ceb.tl.tr_554 ro.et.en_322  ms.nl.bs_432 ceb.vi.un_430
  0x1c531f04, 0x2b002804, 0x21352812, 0x0b231fec,   // cy.ht.id_332 sw.vi.un_320  sw.zu.jw_654 cy.ca.es_644
  0x2b006b07, 0x1a1b6bad, 0x0c003b07, 0x19272d07,   // ceb.vi.un_420 ceb.tr.tl_643  so.sv.un_420 sk.gd.gl_432
  // [49f0]
  0x19000504, 0x35133113, 0x180153a0, 0x010553a0,   // fr.gl.un_320 az.et.zu_665  ht.en.ga_322 ht.fr.en_322
  0x0a0710ee, 0x132506a4, 0x12251b08, 0x0b293ba0,   // be.bg.mk_422 de.eu.et_433  tr.eu.hu_443 so.sl.es_322
  0x4a050107, 0x64010507, 0x0828010c, 0x080201ee,   // en.fr.yo_432 fr.en.lg_432  en.sw.no_543 en.da.no_422
  0x356829ad, 0x0e033fa0, 0x27130405, 0x12182155,   // sl.ig.zu_643 af.nl.is_322  fi.et.gd_333 fa.ar.ur_442
  // [4a00]
  0x04001a04, 0x251064a4, 0x351e1c08, 0x19000d07,   // tl.fi.un_320 lg.lt.eu_433  id.ms.zu_443 cs.gl.un_420
  0x0a000d12, 0x1b0435a0, 0x081b04ad, 0x5505010c,   // cs.pt.un_640 zu.fi.tr_322  fi.tr.no_643 en.fr.rw_543
  0x2d120d04, 0x17040aa0, 0x27181ca0, 0x1c3b1eaf,   // cs.hu.sk_332 mk.ru.sr_322  id.ga.gd_322 ms.so.id_655
  0x07042a60, 0x0b000e05, 0x1c282104, 0x10000f18,   // mt.fi.it_664 is.es.un_330  jw.sw.id_332 lv.lt.un_740
  // [4a10]
  0x25002709, 0x08021faf, 0x2d0d0aa4, 0x07001009,   // gd.eu.un_440 cy.da.no_655  pt.cs.sk_433 be.bg.un_440
  0x53006b0b, 0x080e0413, 0x3500640d, 0x4a252355,   // ceb.ht.un_520 fi.is.no_665  lg.zu.un_540 ca.eu.yo_442
  0x3b1e5204, 0x1a006b12, 0x0d000a0e, 0x25070ea0,   // ha.ms.so_332 ceb.tl.un_640  pt.cs.un_550 is.it.eu_322
  0x0a000d13, 0x081b040c, 0x020c52a7, 0x13201f12,   // cs.pt.un_650 fi.tr.no_543  ha.sv.da_532 cy.sq.et_654
  // [4a20]
  0x190a18a6, 0x1000270e, 0x2a3f0308, 0x31532812,   // ga.pt.gl_521 gd.lt.un_550  nl.af.mt_443 sw.ht.az_654
  0x35011fa0, 0x3b000707, 0x3f0625ad, 0x0e063504,   // cy.en.zu_322 it.so.un_420  eu.de.af_643 zu.de.is_332
  0x1b000304, 0x1f2701a4, 0x6b001f09, 0x23033f0b,   // nl.tr.un_320 en.gd.cy_433  cy.ceb.un_440 af.nl.ca_542
  0x04050c11, 0x20286407, 0x0c06030d, 0x18001121,   // sv.fr.fi_653 lg.sw.sq_432  nl.de.sv_554 ro.ga.un_860
  // [4a30]
  0x070804ec, 0x182327a4, 0x290d1f04, 0x120306ee,   // ru.uk.bg_644 gd.ca.ga_433  cy.cs.sl_332 de.nl.hu_422
  0x0c02035a, 0x08060c02, 0x0c021f07, 0x04030611,   // nl.da.sv_553 sv.de.no_222  cy.da.sv_432 de.nl.fi_653
  0x0e355504, 0x3500110d, 0x02001f11, 0x10000802,   // rw.zu.is_332 ro.zu.un_540  cy.da.un_630 no.lt.un_220
  0x06292504, 0x321617a6, 0x032a3fa7, 0x3200350b,   // eu.sl.de_332 sr.hr.bs_521  af.mt.nl_532 zu.bs.un_520
  // [4a40]
  0x32001208, 0x23002907, 0x080e2a09, 0x3b0e1b04,   // hu.bs.un_430 sl.ca.un_420  mt.is.no_444 tr.is.so_332
  0x12002313, 0x0c231fa4, 0x07040811, 0x32021fee,   // ca.hu.un_650 cy.ca.sv_433  uk.ru.bg_653 cy.da.bs_422
  0x230c0404, 0x1b531a0c, 0x07001714, 0x12001a12,   // fi.sv.ca_332 tl.ht.tr_543  sr.bg.un_660 tl.hu.un_640
  0x09001108, 0x0a00100e, 0x0a0817a4, 0x2d321702,   // ro.pl.un_430 be.mk.un_550  sr.uk.mk_433 sr.bs.sk_222
  // [4a50]
  0x0b000302, 0x190a11ee, 0x0a08070d, 0x04111755,   // nl.es.un_220 ro.pt.gl_422  bg.uk.mk_554 sr.ro.ru_442
  0x170711a4, 0x122a21a4, 0x0c0e0308, 0x21073104,   // ro.bg.sr_433 jw.mt.hu_433  nl.is.sv_443 az.it.jw_332
  0x12005202, 0x0c0e01a0, 0x0f033fa4, 0x02031304,   // ha.hu.un_220 en.is.sv_322  af.nl.lv_433 et.nl.da_332
  0x200c11ee, 0x062718a9, 0x06002512, 0x020f080c,   // ro.sv.sq_422 ga.gd.de_544  eu.de.un_640 no.lv.da_543
  // [4a60]
  0x2902030c, 0x0a11040c, 0x02000108, 0x290c35a0,   // nl.da.sl_543 ru.ro.mk_543  en.da.un_430 zu.sv.sl_322
  0x23000113, 0x06030e11, 0x1e6b1ca4, 0x06106b08,   // en.ca.un_650 is.nl.de_653  id.ceb.ms_433 ceb.lt.de_443
  0x05232011, 0x2300531a, 0x23000607, 0x64552504,   // sq.ca.fr_653 ht.ca.un_760  de.ca.un_420 eu.rw.lg_332
  0x1b003508, 0x32131607, 0x20231907, 0x10080405,   // zu.tr.un_430 hr.et.bs_432  gl.ca.sq_432 ru.uk.be_333
  // [4a70]
  0x20252a07, 0x06033f14, 0x180501ec, 0x2d001f1a,   // mt.eu.sq_432 af.nl.de_666  en.fr.ga_644 cy.sk.un_760
  0x21122d0c, 0x08020e05, 0x052718a4, 0x080e0ca0,   // sk.hu.jw_543 is.da.no_333  ga.gd.fr_433 sv.is.no_322
  0x110a080c, 0x130c0612, 0x080e350c, 0x20002522,   // uk.mk.ro_543 de.sv.et_654  zu.is.no_543 eu.sq.un_870
  0x5300231d, 0x103b12ec, 0x13080ea7, 0x10001f19,   // ca.ht.un_820 hu.so.lt_644  is.no.et_532 cy.lt.un_750
  // [4a80]
  0x0718275a, 0x0e03010c, 0x0600251b, 0x080c06a9,   // gd.ga.it_553 en.nl.is_543  eu.de.un_770 de.sv.no_544
  0x112501ad, 0x05000a14, 0x130e0607, 0x0a2d0d08,   // en.eu.ro_643 pt.fr.un_660  de.is.et_432 cs.sk.pt_443
  0x3b1827ee, 0x12001311, 0x080c02a0, 0x2a1828a0,   // gd.ga.so_422 et.hu.un_630  da.sv.no_322 sw.ga.mt_322
  0x021b6b12, 0x1b2d0d55, 0x1b521fa6, 0x04250513,   // ceb.tr.da_654 cs.sk.tr_442  cy.ha.tr_521 fr.eu.fi_665
  // [4a90]
  0x2500680d, 0x1805010c, 0x64093f0b, 0x2a002904,   // ig.eu.un_540 en.fr.ga_543  af.pl.lg_542 sl.mt.un_320
  0x0500280d, 0x31002804, 0x100c3f13, 0x64315504,   // sw.fr.un_540 sw.az.un_320  af.sv.lt_665 rw.az.lg_332
  0x27000607, 0x3b356412, 0x050b23a0, 0x03080255,   // de.gd.un_420 lg.zu.so_654  ca.es.fr_322 da.no.nl_442
  0x3b045207, 0x116b07a0, 0x281e1ca0, 0x35521a07,   // ha.fi.so_432 it.ceb.ro_322  id.ms.sw_322 tl.ha.zu_432
  // [4aa0]
  0x5200640e, 0x0e00080e, 0x1c213108, 0x32000702,   // lg.ha.un_550 no.is.un_550  az.jw.id_443 it.bs.un_220
  0x05005312, 0x1e521f07, 0x16003f02, 0x551a07ee,   // ht.fr.un_640 cy.ha.ms_432  af.hr.un_220 it.tl.rw_422
  0x35523b0d, 0x0717040d, 0x08001713, 0x64001f0d,   // so.ha.zu_554 ru.sr.bg_554  sr.uk.un_650 cy.lg.un_540
  0x252718ec, 0x10002104, 0x271718a9, 0x0c1a0604,   // ga.gd.eu_644 jw.lt.un_320  ga.sr.gd_544 de.tl.sv_332
  // [4ab0]
  0x5255535a, 0x1c0f1305, 0x13000c04, 0x29175307,   // ht.rw.ha_553 et.lv.id_333  sv.et.un_320 ht.sr.sl_432
  0x13212004, 0x170a07ec, 0x295255a4, 0x232719ee,   // sq.jw.et_332 bg.mk.sr_644  rw.ha.sl_433 gl.gd.ca_422
  0x2d005204, 0x2a100f0c, 0x0f522da0, 0x0a0417ec,   // ha.sk.un_320 lv.lt.mt_543  sk.ha.lv_322 sr.ru.mk_644
  0x171c52a0, 0x06080ea0, 0x09005507, 0x2a001804,   // ha.id.sr_322 is.no.de_322  rw.pl.un_420 ga.mt.un_320
  // [4ac0]
  0x32161309, 0x53322912, 0x521827a0, 0x52201e04,   // et.hr.bs_444 sl.bs.ht_654  gd.ga.ha_322 ms.sq.ha_332
  0x4a005507, 0x55005220, 0x0d005202, 0x07520f0d,   // rw.yo.un_420 ha.rw.un_850  ha.cs.un_220 lv.ha.it_554
  0x52001014, 0x25002b04, 0x253f080e, 0x03082504,   // lt.ha.un_660 vi.eu.un_320  no.af.eu_555 eu.no.nl_332
  0x0804250d, 0x062103ee, 0x080225ec, 0x1900230e,   // eu.fi.no_554 nl.jw.de_422  eu.da.no_644 ca.gl.un_550
  // [4ad0]
  0x25033fad, 0x210105ee, 0x25000805, 0x1a216bee,   // af.nl.eu_643 fr.en.jw_422  no.eu.un_330 ceb.jw.tl_422
  0x27213ba6, 0x05002b0e, 0x352001ac, 0x1f1235ad,   // so.jw.gd_521 vi.fr.un_550  en.sq.zu_632 zu.hu.cy_643
  0x110501a9, 0x1c000f05, 0x1f080255, 0x25000313,   // en.fr.ro_544 lv.id.un_330  da.no.cy_442 nl.eu.un_650
  0x32132d0b, 0x13005519, 0x21003519, 0x05005208,   // sk.et.bs_542 rw.et.un_750  zu.jw.un_750 ha.fr.un_430
  // [4ae0]
  0x20213508, 0x06001002, 0x03002505, 0x190a10a4,   // zu.jw.sq_443 lt.de.un_220  eu.nl.un_330 lt.pt.gl_433
  0x1f061004, 0x3f002514, 0x045228ad, 0x1f00010c,   // lt.de.cy_332 eu.af.un_660  sw.ha.fi_643 en.cy.un_530
  0x25101a07, 0x521b2102, 0x0f095304, 0x1f003519,   // tl.lt.eu_432 jw.tr.ha_222  ht.pl.lv_332 zu.cy.un_750
  0x52001309, 0x35001214, 0x281b35ad, 0x2b001207,   // et.ha.un_440 hu.zu.un_660  zu.tr.sw_643 hu.vi.un_420
  // [4af0]
  0x35001f22, 0x0c123504, 0x05033f05, 0x020c01a4,   // cy.zu.un_870 zu.hu.sv_332  af.nl.fr_333 en.sv.da_433
  0x35002b08, 0x550525a4, 0x3b211cee, 0x190b12a4,   // vi.zu.un_430 eu.fr.rw_433  id.jw.so_422 hu.es.gl_433
  0x3f030613, 0x0a232507, 0x17292da4, 0x1e6b3ba0,   // de.nl.af_665 eu.ca.pt_432  sk.sl.sr_433 so.ceb.ms_322
  0x12190ea9, 0x1e1a1ca4, 0x0d055307, 0x355306ad,   // is.gl.hu_544 id.tl.ms_433  ht.fr.cs_432 de.ht.zu_643
  // [4b00]
  0x182d0d55, 0x3b1a2aee, 0x3b1a6bec, 0x53002004,   // cs.sk.ga_442 mt.tl.so_422  ceb.tl.so_644 sq.ht.un_320
  0x11006404, 0x0e001211, 0x206e1a0c, 0x1c002b21,   // lg.ro.un_320 hu.is.un_630  tl.hmn.sq_543 vi.id.un_860
  0x68004a0d, 0x1e3b1c0c, 0x1b4a5504, 0x521e280c,   // yo.ig.un_540 id.so.ms_543  rw.yo.tr_332 sw.ms.ha_543
  0x1b5553ec, 0x3f0301ad, 0x2d090604, 0x19002b09,   // ht.rw.tr_644 en.nl.af_643  de.pl.sk_332 vi.gl.un_440
  // [4b10]
  0x1a1e1c0c, 0x043f0355, 0x01271812, 0x25000629,   // id.ms.tl_543 nl.af.fi_442  ga.gd.en_654 de.eu.un_960
  0x3b002105, 0x1e131c07, 0x0c000a0e, 0x1f000621,   // jw.so.un_330 id.et.ms_432  pt.sv.un_550 de.cy.un_860
  0x112916a4, 0x0d004a14, 0x255255a7, 0x6b1a3b0d,   // hr.sl.ro_433 yo.cs.un_660  rw.ha.eu_532 so.tl.ceb_554
  0x21205304, 0x190a53a0, 0x131104ee, 0x00001924,   // ht.sq.jw_332 ht.pt.gl_322  fi.ro.et_422 gl.un.un_900
  // [4b20]
  0x1a2821a4, 0x641a350c, 0x0f001023, 0x0a171113,   // jw.sw.tl_433 zu.tl.lg_543  lt.lv.un_880 ro.sr.mk_665
  0x09005508, 0x1a2155a9, 0x6b1a1ca9, 0x02283502,   // rw.pl.un_430 rw.jw.tl_544  id.tl.ceb_544 zu.sw.da_222
  0x190b12a0, 0x21005504, 0x0e000404, 0x551b3104,   // hu.es.gl_322 rw.jw.un_320  fi.is.un_320 az.tr.rw_332
  0x1e1c04a4, 0x3500520d, 0x23006e07, 0x01001b08,   // fi.id.ms_433 ha.zu.un_540  hmn.ca.un_420 tr.en.un_430
  // [4b30]
  0x530e01a0, 0x0c532308, 0x080a04ad, 0x0c1b5305,   // en.is.ht_322 ca.ht.sv_443  ru.mk.uk_643 ht.tr.sv_333
  0x17071008, 0x52002905, 0x283f5308, 0x121a6b12,   // be.bg.sr_443 sl.ha.un_330  ht.af.sw_443 ceb.tl.hu_654
  0x231304ad, 0x08000219, 0x6b6853a7, 0x0c5323a4,   // fi.et.ca_643 da.no.un_750  ht.ig.ceb_532 ca.ht.sv_433
  0x213f0302, 0x0c531f55, 0x0200310e, 0x532301a0,   // nl.af.jw_222 cy.ht.sv_442  az.da.un_550 en.ca.ht_322
  // [4b40]
  0x2b3f16a7, 0x18052307, 0x04230108, 0x01001604,   // hr.af.vi_532 ca.fr.ga_432  en.ca.fi_443 hr.en.un_320
  0x2912040d, 0x32211c02, 0x311b53ad, 0x13040e04,   // fi.hu.sl_554 id.jw.bs_222  ht.tr.az_643 is.fi.et_332
  0x213f1ea0, 0x0c005305, 0x25041ea0, 0x0e0c5308,   // ms.af.jw_322 ht.sv.un_330  ms.fi.eu_322 ht.sv.is_443
  0x28001314, 0x231b53ad, 0x212813ad, 0x0c0353ee,   // et.sw.un_660 ht.tr.ca_643  et.sw.jw_643 ht.nl.sv_422
  // [4b50]
  0x13321607, 0x645520a0, 0x1f522aa4, 0x29173507,   // hr.bs.et_432 sq.rw.lg_322  mt.ha.cy_433 zu.sr.sl_432
  0x27231a07, 0x1b12350c, 0x172916ad, 0x3f032b0b,   // tl.ca.gd_432 zu.hu.tr_543  hr.sl.sr_643 vi.nl.af_542
  0x0b0a19a7, 0x130110a4, 0x011805ee, 0x3227180c,   // gl.pt.es_532 lt.en.et_433  fr.ga.en_422 ga.gd.bs_543
  0x05033ba6, 0x0c006b04, 0x1b2d0d04, 0x28002102,   // so.nl.fr_521 ceb.sv.un_320  cs.sk.tr_332 jw.sw.un_220
  // [4b60]
  0x1a1c21a0, 0x180107ee, 0x28003519, 0x1000290e,   // jw.id.tl_322 it.en.ga_422  zu.sw.un_750 sl.lt.un_550
  0x534a5209, 0x192b0ba9, 0x550603ad, 0x0f0b53a4,   // ha.yo.ht_444 es.vi.gl_544  nl.de.rw_643 ht.es.lv_433
  0x0f0d2dad, 0x28030604, 0x1e211c08, 0x030208a9,   // sk.cs.lv_643 de.nl.sw_332  id.jw.ms_443 no.da.nl_544
  0x35033fee, 0x0300020d, 0x0204080c, 0x170b295a,   // af.nl.zu_422 da.nl.un_540  no.fi.da_543 sl.es.sr_553
  // [4b70]
  0x4a003b23, 0x18001904, 0x06000119, 0x0e5227a9,   // so.yo.un_880 gl.ga.un_320  en.de.un_750 gd.ha.is_544
  0x4a001113, 0x06031f09, 0x1f0603a4, 0x53004a21,   // ro.yo.un_650 cy.nl.de_444  nl.de.cy_433 yo.ht.un_860
  0x190601a0, 0x12000c02, 0x1a3b0bee, 0x182711af,   // en.de.gl_322 sv.hu.un_220  es.so.tl_422 ro.gd.ga_655
  0x0a002704, 0x4a191e07, 0x2b1c2707, 0x4a003b12,   // gd.pt.un_320 ms.gl.yo_432  gd.id.vi_432 so.yo.un_640
  // [4b80]
  0x0e1f210c, 0x211e2005, 0x211e1cec, 0x6b3b2709,   // jw.cy.is_543 sq.ms.jw_333  id.ms.jw_644 gd.so.ceb_444
  0x02006b0c, 0x07001102, 0x0d1b3b07, 0x12190ba0,   // ceb.da.un_530 ro.it.un_220  so.tr.cs_432 es.gl.hu_322
  0x52000113, 0x19101105, 0x524a1e12, 0x0a100712,   // en.ha.un_650 ro.lt.gl_333  ms.yo.ha_654 bg.be.mk_654
  0x684a3b08, 0x100a07ec, 0x203553a4, 0x1a68350c,   // so.yo.ig_443 bg.mk.be_644  ht.zu.sq_433 zu.ig.tl_543
  // [4b90]
  0x0b0523a7, 0x1f00180e, 0x253f4aee, 0x2a0f0ca7,   // ca.fr.es_532 ga.cy.un_550  yo.af.eu_422 sv.lv.mt_532
  0x01001a08, 0x04111712, 0x08002007, 0x351a0c07,   // tl.en.un_430 sr.ro.ru_654  sq.no.un_420 sv.tl.zu_432
  0x161029a9, 0x03322aee, 0x16292a07, 0x01530407,   // sl.lt.hr_544 mt.bs.nl_422  mt.sl.hr_432 fi.ht.en_432
  0x1b0435ad, 0x060801a6, 0x02250811, 0x35641ba7,   // zu.fi.tr_643 en.no.de_521  no.eu.da_653 tr.lg.zu_532
  // [4ba0]
  0x016b04ad, 0x1b3f01a0, 0x3f004a02, 0x102a2dee,   // fi.ceb.en_643 en.af.tr_322  yo.af.un_220 sk.mt.lt_422
  0x04000502, 0x012135af, 0x0e12080c, 0x1700080e,   // fr.fi.un_220 zu.jw.en_655  no.hu.is_543 uk.sr.un_550
  0x08002102, 0x13283b0c, 0x13310cac, 0x3f000414,   // jw.no.un_220 so.sw.et_543  sv.az.et_632 fi.af.un_660
  0x17000a2c, 0x3f0305a6, 0x2d032802, 0x1b3212a7,   // mk.sr.un_990 fr.nl.af_521  sw.nl.sk_222 hu.bs.tr_532
  // [4bb0]
  0x6b041f04, 0x0c0106a4, 0x31080204, 0x12290cee,   // cy.fi.ceb_332 de.en.sv_433  da.no.az_332 sv.sl.hu_422
  0x06030107, 0x08000312, 0x02006b02, 0x082d0d04,   // en.nl.de_432 nl.no.un_640  ceb.da.un_220 cs.sk.no_332
  0x110305ee, 0x03005304, 0x10000304, 0x115305a9,   // fr.nl.ro_422 ht.nl.un_320  nl.lt.un_320 fr.ht.ro_544
  0x013f0355, 0x3b001a13, 0x27110507, 0x120e4a5a,   // nl.af.en_442 tl.so.un_650  fr.ro.gd_432 yo.is.hu_553
  // [4bc0]
  0x1e00211a, 0x11030512, 0x0c001013, 0x0e003113,   // jw.ms.un_760 fr.nl.ro_654  lt.sv.un_650 az.is.un_650
  0x04000621, 0x0d1c13a7, 0x23071b0c, 0x04000619,   // de.fi.un_860 bh.mr.ne_532  tr.it.ca_543 de.fi.un_750
  0x311c1ba0, 0x01680ea4, 0x311b0707, 0x08000604,   // tr.id.az_322 is.ig.en_433  it.tr.az_432 de.no.un_320
  0x170a07a6, 0x2a002504, 0x521c1e07, 0x3f1a210c,   // bg.mk.sr_521 eu.mt.un_320  ms.id.ha_432 jw.tl.af_543
  // [4bd0]
  0x020305a9, 0x3510640c, 0x0e0c0613, 0x6b110507,   // fr.nl.da_544 lg.lt.zu_543  de.sv.is_665 fr.ro.ceb_432
  0x2b00160e, 0x0311050c, 0x0501235a, 0x64193ba0,   // hr.vi.un_550 fr.ro.nl_543  ca.en.fr_553 so.gl.lg_322
  0x06033f08, 0x20521fad, 0x11000717, 0x21003512,   // af.nl.de_443 cy.ha.sq_643  it.ro.un_730 zu.jw.un_640
  0x01002802, 0x253564a0, 0x08072a0d, 0x1207640c,   // sw.en.un_220 lg.zu.eu_322  mt.it.no_554 lg.it.hu_543
  // [4be0]
  0x2b231008, 0x06002708, 0x00001737, 0x6e6b0707,   // lt.ca.vi_443 gd.de.un_430  sr.un.un_B00 it.ceb.hmn_432
  0x0400172c, 0x210d32a0, 0x02060c13, 0x170804a4,   // sr.ru.un_990 bs.cs.jw_322  sv.de.da_665 ru.uk.sr_433
  0x530308a9, 0x03132507, 0x030604ad, 0x25002a05,   // no.nl.ht_544 eu.et.nl_432  fi.de.nl_643 mt.eu.un_330
  0x25005314, 0x21001112, 0x3210160d, 0x060b03a4,   // ht.eu.un_660 ro.jw.un_640  hr.lt.bs_554 nl.es.de_433
  // [4bf0]
  0x21006e04, 0x060c0205, 0x555352a9, 0x03002a07,   // hmn.jw.un_320 da.sv.de_333  ha.ht.rw_544 mt.nl.un_420
  0x08002d04, 0x4a213f11, 0x2307110c, 0x204a2112,   // sk.no.un_320 af.jw.yo_653  ro.it.ca_543 jw.yo.sq_654
  0x13004a19, 0x080201a4, 0x120e0807, 0x180627ac,   // yo.et.un_750 en.da.no_433  no.is.hu_432 gd.de.ga_632
  0x021c2ba7, 0x2820070c, 0x3f640755, 0x20070107,   // vi.id.da_532 it.sq.sw_543  it.lg.af_442 en.it.sq_432

  // [4c00]
  0x086e4aa0, 0x0705520c, 0x52132512, 0x29191c08,   // yo.hmn.no_322 ha.fr.it_543  eu.et.ha_654 id.gl.sl_443
  0x04001c02, 0x02006e08, 0x1a6e2855, 0x250603a9,   // id.fi.un_220 hmn.da.un_430  sw.hmn.tl_442 nl.de.eu_544
  0x550d0504, 0x2513110c, 0x2b681808, 0x04000922,   // fr.cs.rw_332 ro.et.eu_543  ga.ig.vi_443 pl.fi.un_870
  0x0d0f2902, 0x10006e2a, 0x3200520b, 0x0a1e1ca9,   // sl.lv.cs_222 hmn.lt.un_970  ha.bs.un_520 id.ms.pt_544
  // [4c10]
  0x160853a4, 0x0f112d0c, 0x0c2a0112, 0x0c1812ee,   // ht.no.hr_433 sk.ro.lv_543  en.mt.sv_654 hu.ga.sv_422
  0x11253b0c, 0x3f00090c, 0x07006e05, 0x1a1c1e07,   // so.eu.ro_543 pl.af.un_530  hmn.it.un_330 ms.id.tl_432
  0x2a030905, 0x52006e07, 0x19090b0c, 0x06523fa4,   // pl.nl.mt_333 hmn.ha.un_420  es.pl.gl_543 af.ha.de_433
  0x1100522a, 0x033f2d07, 0x033f0808, 0x11002a08,   // ha.ro.un_970 sk.af.nl_432  no.af.nl_443 mt.ro.un_430
  // [4c20]
  0x0b001913, 0x0f6e0714, 0x252006a0, 0x2a0f52af,   // gl.es.un_650 it.hmn.lv_666  de.sq.eu_322 ha.lv.mt_655
  0x031a64a4, 0x31022507, 0x0d291ea0, 0x0a6e2b05,   // lg.tl.nl_433 eu.da.az_432  ms.sl.cs_322 vi.hmn.pt_333
  0x080203a4, 0x11081ea0, 0x0c100fa4, 0x35311b08,   // nl.da.no_433 ms.no.ro_322  lv.lt.sv_433 tr.az.zu_443
  0x030f090c, 0x0b042d07, 0x1f0309ad, 0x0b000609,   // pl.lv.nl_543 sk.fi.es_432  pl.nl.cy_643 de.es.un_440
  // [4c30]
  0x030f29a9, 0x103f0405, 0x08170aa7, 0x270306ee,   // sl.lv.nl_544 fi.af.lt_333  mk.sr.uk_532 de.nl.gd_422
  0x2d190b55, 0x2900020e, 0x12190b04, 0x6b0b35a0,   // es.gl.sk_442 da.sl.un_550  es.gl.hu_332 zu.es.ceb_322
  0x250e0111, 0x0d112304, 0x10060e04, 0x0e0c04ee,   // en.is.eu_653 ca.ro.cs_332  is.de.lt_332 fi.sv.is_422
  0x10000113, 0x0e3b0408, 0x1000111a, 0x286455a0,   // en.lt.un_650 fi.so.is_443  ro.be.un_760 rw.lg.sw_322
  // [4c40]
  0x52000107, 0x20002508, 0x07001718, 0x1f005204,   // en.ha.un_420 eu.sq.un_430  sr.bg.un_740 ha.cy.un_320
  0x23003b04, 0x6e100f04, 0x08000408, 0x31003b14,   // so.ca.un_320 lv.lt.hmn_332  ru.uk.un_430 so.az.un_660
  0x136b2107, 0x0e1b0f04, 0x011f28a6, 0x11041012,   // jw.ceb.et_432 lv.tr.is_332  sw.cy.en_521 be.ru.ro_654
  0x25005307, 0x321b5308, 0x556435ad, 0x352718ec,   // ht.eu.un_420 ht.tr.bs_443  zu.lg.rw_643 ga.gd.zu_644
  // [4c50]
  0x060d01a0, 0x170d2da4, 0x20250804, 0x04002d04,   // en.cs.de_322 sk.cs.sr_433  no.eu.sq_332 sk.fi.un_320
  0x292d0d0e, 0x350625ad, 0x10111ba7, 0x170f0707,   // cs.sk.sl_555 eu.de.zu_643  tr.ro.lt_532 it.lv.sr_432
  0x1b003513, 0x53112512, 0x17291eec, 0x0d091c0d,   // zu.tr.un_650 eu.ro.ht_654  ms.sl.sr_644 mr.hi.ne_554
  0x066403a4, 0x29101f0c, 0x642d0d13, 0x3f0864a0,   // nl.lg.de_433 cy.lt.sl_543  cs.sk.lg_665 lg.no.af_322
  // [4c60]
  0x321f0ca0, 0x191f2108, 0x3b0e2aad, 0x07012a02,   // sv.cy.bs_322 jw.cy.gl_443  mt.is.so_643 mt.en.it_222
  0x101253ee, 0x0c004a02, 0x04101702, 0x11070aa9,   // ht.hu.lt_422 yo.sv.un_220  sr.be.ru_222 mk.bg.ro_544
  0x52072a07, 0x082901a0, 0x231e05a4, 0x1329090d,   // mt.it.ha_432 en.sl.no_322  fr.ms.ca_433 pl.sl.et_554
  0x53006b19, 0x18011fa0, 0x13004a04, 0x07230da4,   // ceb.ht.un_750 cy.en.ga_322  yo.et.un_320 cs.ca.it_433
  // [4c70]
  0x03110504, 0x0500110e, 0x045325ac, 0x4a002505,   // fr.ro.nl_332 ro.fr.un_550  eu.ht.fi_632 eu.yo.un_330
  0x060e0860, 0x3b552807, 0x20011f11, 0x35000c0c,   // no.is.de_664 sw.rw.so_432  cy.en.sq_653 sv.zu.un_530
  0x6b050108, 0x196455a0, 0x081b32a0, 0x1f0805a4,   // en.fr.ceb_443 rw.lg.gl_322  bs.tr.no_322 fr.no.cy_433
  0x2a003113, 0x2d000a05, 0x020e0812, 0x31006404,   // az.mt.un_650 pt.sk.un_330  no.is.da_654 lg.az.un_320
  // [4c80]
  0x53001f04, 0x040711ad, 0x17040a04, 0x07212a0c,   // cy.ht.un_320 ro.bg.ru_643  mk.ru.sr_332 mt.jw.it_543
  0x5300290c, 0x13252a0c, 0x11051908, 0x03061fa9,   // sl.ht.un_530 mt.eu.et_543  gl.fr.ro_443 cy.de.nl_544
  0x0a041702, 0x070a080c, 0x0a0717a7, 0x2b06250c,   // sr.ru.mk_222 uk.mk.bg_543  sr.bg.mk_532 eu.de.vi_543
  0x2a042560, 0x0d092d08, 0x033f0fa9, 0x230b0514,   // eu.fi.mt_664 sk.pl.cs_443  lv.af.nl_544 fr.es.ca_666
  // [4c90]
  0x041e1a08, 0x04682513, 0x060208a0, 0x55001c02,   // tl.ms.fi_443 eu.ig.fi_665  no.da.de_322 id.rw.un_220
  0x31005209, 0x21281a0c, 0x130b3bad, 0x0b1e6ea0,   // ha.az.un_440 tl.sw.jw_543  so.es.et_643 hmn.ms.es_322
  0x02052aee, 0x072b1faf, 0x230b050c, 0x21351c07,   // mt.fr.da_422 cy.vi.it_655  fr.es.ca_543 id.zu.jw_432
  0x6b001a23, 0x01001c08, 0x216e2707, 0x01002505,   // tl.ceb.un_880 id.en.un_430  gd.hmn.jw_432 eu.en.un_330
  // [4ca0]
  0x042128a4, 0x10003208, 0x6b001a0c, 0x190b31a0,   // sw.jw.fi_433 bs.lt.un_430  tl.ceb.un_530 az.es.gl_322
  0x25232a04, 0x21005305, 0x0f2304af, 0x1e214a07,   // mt.ca.eu_332 ht.jw.un_330  fi.ca.lv_655 yo.jw.ms_432
  0x1e002a08, 0x21000104, 0x5304050c, 0x23041112,   // mt.ms.un_430 en.jw.un_320  fr.fi.ht_543 ro.fi.ca_654
  0x31002a0c, 0x0d002b05, 0x022508a4, 0x043f1ca4,   // mt.az.un_530 vi.cs.un_330  no.eu.da_433 id.af.fi_433
  // [4cb0]
  0x04070805, 0x1b095312, 0x25060407, 0x0d092daf,   // uk.bg.ru_333 ht.pl.tr_654  fi.de.eu_432 sk.pl.cs_655
  0x080231ee, 0x28001e19, 0x25002708, 0x112825a9,   // az.da.no_422 ms.sw.un_750  gd.eu.un_430 eu.sw.ro_544
  0x6400310c, 0x1a6b10ad, 0x1e1a1c0c, 0x52002513,   // az.lg.un_530 lt.ceb.tl_643  id.tl.ms_543 eu.ha.un_650
  0x060c1b0c, 0x6b1e1a11, 0x0f0401a4, 0x046b1caf,   // tr.sv.de_543 tl.ms.ceb_653  en.fi.lv_433 id.ceb.fi_655
  // [4cc0]
  0x06001c08, 0x08315308, 0x252a200b, 0x17070a0e,   // id.de.un_430 ht.az.no_443  sq.mt.eu_542 mk.bg.sr_555
  0x04131a04, 0x1800252b, 0x1b1e1c5a, 0x12000e21,   // tl.et.fi_332 eu.ga.un_980  id.ms.tr_553 is.hu.un_860
  0x1e3f0304, 0x1852100c, 0x3f001f07, 0x0b00030e,   // nl.af.ms_332 lt.ha.ga_543  cy.af.un_420 nl.es.un_550
  0x13092d04, 0x07001807, 0x6b121aad, 0x25091ea4,   // sk.pl.et_332 ga.it.un_420  tl.hu.ceb_643 ms.pl.eu_433
  // [4cd0]
  0x0a07200c, 0x011f0fa7, 0x3f041308, 0x060a01a4,   // sq.it.pt_543 lv.cy.en_532  et.fi.af_443 en.pt.de_433
  0x6b006e0d, 0x01006e09, 0x0b0306a4, 0x053b0107,   // hmn.ceb.un_540 hmn.en.un_440  de.nl.es_433 en.so.fr_432
  0x013b2004, 0x033f1705, 0x0c000108, 0x12000614,   // sq.so.en_332 sr.af.nl_333  en.sv.un_430 de.hu.un_660
  0x1f0a0205, 0x190a2304, 0x281827ad, 0x270b18a4,   // da.pt.cy_333 ca.pt.gl_332  gd.ga.sw_643 ga.es.gd_433
  // [4ce0]
  0x3b001921, 0x20073ba4, 0x162d29ee, 0x0a04010b,   // gl.so.un_860 so.it.sq_433  sl.sk.hr_422 en.fi.pt_542
  0x2b1827ad, 0x0e00121a, 0x040a10a0, 0x05100fa4,   // gd.ga.vi_643 hu.is.un_760  be.mk.ru_322 lv.lt.fr_433
  0x524a2804, 0x111a27a4, 0x0e120cad, 0x100413ee,   // sw.yo.ha_332 gd.tl.ro_433  sv.hu.is_643 et.fi.lt_422
  0x25040804, 0x53133fa4, 0x643b2a07, 0x20180804,   // no.fi.eu_332 af.et.ht_433  mt.so.lg_432 no.ga.sq_332
  // [4cf0]
  0x030c040c, 0x3b0a1aa7, 0x291713a9, 0x6e000e12,   // fi.sv.nl_543 tl.pt.so_532  et.sr.sl_544 is.hmn.un_640
  0x2a110712, 0x12000e07, 0x6b000a22, 0x05091f07,   // it.ro.mt_654 is.hu.un_420  pt.ceb.un_870 cy.pl.fr_432
  0x0b0a2aa0, 0x4a32160e, 0x28180aa0, 0x19000a21,   // mt.pt.es_322 hr.bs.yo_555  pt.ga.sw_322 pt.gl.un_860
  0x6b130507, 0x3f2801ee, 0x011f0ca0, 0x530d2705,   // fr.et.ceb_432 en.sw.af_422  sv.cy.en_322 gd.cs.ht_333
  // [4d00]
  0x531c05ad, 0x052701a4, 0x0306010c, 0x02130807,   // fr.id.ht_643 en.gd.fr_433  en.de.nl_543 no.et.da_432
  0x06000a12, 0x12000a05, 0x1f002302, 0x0a001b07,   // pt.de.un_640 pt.hu.un_330  ca.cy.un_220 tr.pt.un_420
  0x29122107, 0x4a000704, 0x21002805, 0x0300130d,   // jw.hu.sl_432 it.yo.un_320  sw.jw.un_330 et.nl.un_540
  0x110a1007, 0x08030fa0, 0x0a000819, 0x3f0610ee,   // lt.pt.ro_432 lv.nl.no_322  uk.mk.un_750 lt.de.af_422
  // [4d10]
  0x1f003f0b, 0x1a2b07ee, 0x030c060c, 0x07170413,   // af.cy.un_520 it.vi.tl_422  de.sv.nl_543 ru.sr.bg_665
  0x0d130912, 0x230d0b04, 0x53002a07, 0x0a2d11af,   // hi.bh.ne_654 es.cs.ca_332  mt.ht.un_420 ro.sk.pt_655
  0x08040a05, 0x02000e23, 0x17040855, 0x08001122,   // mk.ru.uk_333 is.da.un_880  uk.ru.sr_442 ro.uk.un_870
  0x01043b07, 0x08100ea9, 0x02000e09, 0x27113bee,   // so.fi.en_432 is.lt.no_544  is.da.un_440 so.ro.gd_422
  // [4d20]
  0x4a555202, 0x11003b0d, 0x1b4a6ba4, 0x0d001819,   // ha.rw.yo_222 so.ro.un_540  ceb.yo.tr_433 ga.cs.un_750
  0x3f1c2702, 0x27001102, 0x18110704, 0x1e6e2b07,   // gd.id.af_222 ro.gd.un_220  it.ro.ga_332 vi.hmn.ms_432
  0x31002011, 0x1a1b6ba0, 0x68002b22, 0x07080aee,   // sq.az.un_630 ceb.tr.tl_322  vi.ig.un_870 mk.uk.bg_422
  0x3b5568a9, 0x2b272860, 0x20002721, 0x18001f08,   // ig.rw.so_544 sw.gd.vi_664  gd.sq.un_860 cy.ga.un_430
  // [4d30]
  0x1f006823, 0x12000b05, 0x1f281c07, 0x3f0b0107,   // ig.cy.un_880 es.hu.un_330  id.sw.cy_432 en.es.af_432
  0x5368055a, 0x0a003505, 0x2a2301a0, 0x07231102,   // fr.ig.ht_553 zu.pt.un_330  en.ca.mt_322 ro.ca.it_222
  0x11001f14, 0x0500070e, 0x21203bec, 0x35000a21,   // cy.ro.un_660 it.fr.un_550  so.sq.jw_644 pt.zu.un_860
  0x290f1007, 0x1003520c, 0x11000714, 0x072a110c,   // lt.lv.sl_432 ha.nl.lt_543  it.ro.un_660 ro.mt.it_543
  // [4d40]
  0x0810110c, 0x02003504, 0x2d001107, 0x6e1f2bec,   // ro.be.uk_543 zu.da.un_320  ro.sk.un_420 vi.cy.hmn_644
  0x31532aa0, 0x28521c0c, 0x35006e18, 0x28002704,   // mt.ht.az_322 id.ha.sw_543  hmn.zu.un_740 gd.sw.un_320
  0x281e1c07, 0x280c1a07, 0x27000822, 0x06000702,   // id.ms.sw_432 tl.sv.sw_432  no.gd.un_870 it.de.un_220
  0x01202811, 0x1a132105, 0x3b001319, 0x3b18280c,   // sw.sq.en_653 jw.et.tl_333  et.so.un_750 sw.ga.so_543
  // [4d50]
  0x13283ba4, 0x1c2352a6, 0x10002302, 0x35000a20,   // so.sw.et_433 ha.ca.id_521  ca.lt.un_220 pt.zu.un_850
  0x6b00682a, 0x172855a9, 0x0f071308, 0x0f321005,   // ig.ceb.un_970 rw.sw.sr_544  et.it.lv_443 lt.bs.lv_333
  0x1f000a07, 0x2100010d, 0x033b6411, 0x011e2ba0,   // pt.cy.un_420 en.jw.un_540  lg.so.nl_653 vi.ms.en_322
  0x1f00350c, 0x033b1a0b, 0x120501a0, 0x033b1aa7,   // zu.cy.un_530 tl.so.nl_542  en.fr.hu_322 tl.so.nl_532
  // [4d60]
  0x28030955, 0x21002808, 0x11190baf, 0x081a2802,   // pl.nl.sw_442 sw.jw.un_430  es.gl.ro_655 sw.tl.no_222
  0x041321af, 0x27122807, 0x043f0308, 0x28003b22,   // jw.et.fi_655 sw.hu.gd_432  nl.af.fi_443 so.sw.un_870
  0x043b13a4, 0x072a0405, 0x5300231a, 0x12000f05,   // et.so.fi_433 fi.mt.it_333  ca.ht.un_760 lv.hu.un_330
  0x0c000d04, 0x051c03ac, 0x0a002312, 0x02000e0d,   // cs.sv.un_320 nl.id.fr_632  ca.pt.un_640 is.da.un_540
  // [4d70]
  0x04110709, 0x291b3107, 0x060c0809, 0x6b000912,   // bg.ro.ru_444 az.tr.sl_432  no.sv.de_444 pl.ceb.un_640
  0x07311b55, 0x202d0907, 0x11001719, 0x1b2b05ec,   // tr.az.it_442 pl.sk.sq_432  sr.ro.un_750 fr.vi.tr_644
  0x201923a9, 0x17110a09, 0x0e1b3107, 0x2d090d0c,   // ca.gl.sq_544 mk.ro.sr_444  az.tr.is_432 cs.pl.sk_543
  0x1b0e31af, 0x5300011a, 0x0c2521ee, 0x2a1f1807,   // az.is.tr_655 en.ht.un_760  jw.eu.sv_422 ga.cy.mt_432
  // [4d80]
  0x0b311baf, 0x1b310b04, 0x1a002113, 0x1e003f12,   // tr.az.es_655 es.az.tr_332  jw.tl.un_650 af.ms.un_640
  0x061e1f07, 0x55684aec, 0x31001904, 0x2a001e08,   // cy.ms.de_432 yo.ig.rw_644  gl.az.un_320 ms.mt.un_430
  0x0118090c, 0x310b0eee, 0x1b0e3108, 0x23121f07,   // pl.ga.en_543 is.es.az_422  az.is.tr_443 cy.hu.ca_432
  0x68006421, 0x1f00230c, 0x12001c04, 0x0c081f08,   // lg.ig.un_860 ca.cy.un_530  id.hu.un_320 cy.no.sv_443
  // [4d90]
  0x6b2168ee, 0x1a556413, 0x16130404, 0x041017ad,   // ig.jw.ceb_422 lg.rw.tl_665  fi.et.hr_332 sr.be.ru_643
  0x01271f05, 0x08000702, 0x063f0ca4, 0x6b2d1a07,   // cy.gd.en_333 it.no.un_220  sv.af.de_433 tl.sk.ceb_432
  0x291632a0, 0x35646812, 0x2a002308, 0x6b131a09,   // bs.hr.sl_322 ig.lg.zu_654  ca.mt.un_430 tl.et.ceb_444
  0x251364a4, 0x0e231f12, 0x1f002319, 0x52002507,   // lg.et.eu_433 cy.ca.is_654  ca.cy.un_750 eu.ha.un_420
  // [4da0]
  0x282d0d5a, 0x08231fa4, 0x6455130d, 0x18551b07,   // cs.sk.sw_553 cy.ca.no_433  et.rw.lg_554 tr.rw.ga_432
  0x170811a7, 0x2a033f0b, 0x10000605, 0x352028af,   // ro.uk.sr_532 af.nl.mt_542  de.lt.un_330 sw.sq.zu_655
  0x12003509, 0x0913040c, 0x0804100d, 0x23002a22,   // zu.hu.un_440 fi.et.pl_543  be.ru.uk_554 mt.ca.un_870
  0x0600350d, 0x52011fa0, 0x3500551a, 0x0f100e12,   // zu.de.un_540 cy.en.ha_322  rw.zu.un_760 is.lt.lv_654
  // [4db0]
  0x64005507, 0x12000e02, 0x06082308, 0x080b23ee,   // rw.lg.un_420 is.hu.un_220  ca.no.de_443 ca.es.no_422
  0x6b1a1308, 0x18082a04, 0x1712080b, 0x122118a9,   // et.tl.ceb_443 mt.no.ga_332  no.hu.sr_542 ar.fa.ur_544
  0x20001c0c, 0x07110409, 0x046b13a4, 0x1e000302,   // id.sq.un_530 ru.ro.bg_444  et.ceb.fi_433 nl.ms.un_220
  0x551021ec, 0x1228550c, 0x4a0d52ee, 0x552164ee,   // jw.lt.rw_644 rw.sw.hu_543  ha.cs.yo_422 lg.jw.rw_422
  // [4dc0]
  0x13006402, 0x351a6b0c, 0x3b212012, 0x6b211c04,   // lg.et.un_220 ceb.tl.zu_543  sq.jw.so_654 id.jw.ceb_332
  0x6b281a0c, 0x094a1307, 0x55006e04, 0x6864550c,   // tl.sw.ceb_543 et.yo.pl_432  hmn.rw.un_320 rw.lg.ig_543
  0x3b000b04, 0x31000408, 0x1c0429a0, 0x251f28ee,   // es.so.un_320 fi.az.un_430  sl.fi.id_322 sw.cy.eu_422
  0x321b6407, 0x6423530c, 0x64355512, 0x1e1c10ee,   // lg.tr.bs_432 ht.ca.lg_543  rw.zu.lg_654 lt.id.ms_422
  // [4dd0]
  0x010e0604, 0x4a1218a0, 0x040807af, 0x03011007,   // de.is.en_332 ga.hu.yo_322  bg.uk.ru_655 lt.en.nl_432
  0x6e1001ee, 0x10006b12, 0x060120a0, 0x12556b0b,   // en.lt.hmn_422 ceb.lt.un_640  sq.en.de_322 ceb.rw.hu_542
  0x192d1207, 0x1b1c6ba4, 0x202a17a0, 0x4a2368a4,   // hu.sk.gl_432 ceb.id.tr_433  sr.mt.sq_322 ig.ca.yo_433
  0x02001a0d, 0x2d290dee, 0x1f1001a4, 0x040711a9,   // tl.da.un_540 cs.sl.sk_422  en.lt.cy_433 ro.bg.ru_544
  // [4de0]
  0x2a000108, 0x3b2a29a9, 0x1a0931a0, 0x2302010c,   // en.mt.un_430 sl.mt.so_544  az.pl.tl_322 en.da.ca_543
  0x3f0f0112, 0x110d2911, 0x530d0405, 0x13010f11,   // en.lv.af_654 sl.cs.ro_653  fi.cs.ht_333 lv.en.et_653
  0x3b1e1c09, 0x05100107, 0x0b050112, 0x0f00011a,   // id.ms.so_444 en.lt.fr_432  en.fr.es_654 en.lv.un_760
  0x1120210c, 0x1b030aee, 0x6b001212, 0x080229a4,   // jw.sq.ro_543 pt.nl.tr_422  hu.ceb.un_640 sl.da.no_433
  // [4df0]
  0x170d2dad, 0x0e002908, 0x0d1e1c13, 0x02000e12,   // sk.cs.sr_643 sl.is.un_430  id.ms.cs_665 is.da.un_640
  0x68013ba7, 0x12002d07, 0x04002322, 0x0b121907,   // so.en.ig_532 sk.hu.un_420  ca.fi.un_870 gl.hu.es_432
  0x3f0309a0, 0x0a0501a0, 0x3b000c07, 0x080c0e05,   // pl.nl.af_322 en.fr.pt_322  sv.so.un_420 is.sv.no_333
  0x2d0d230c, 0x3b033f02, 0x0d060cee, 0x04080a04,   // ca.cs.sk_543 af.nl.so_222  sv.de.cs_422 mk.uk.ru_332
  // [4e00]
  0x173216a7, 0x6b2d12a9, 0x4a1a5511, 0x1a2d1208,   // hr.bs.sr_532 hu.sk.ceb_544  rw.tl.yo_653 hu.sk.tl_443
  0x25122d0c, 0x2168280c, 0x1a006b23, 0x6b684aad,   // sk.hu.eu_543 sw.ig.jw_543  ceb.tl.un_880 yo.ig.ceb_643
  0x07041705, 0x1c211207, 0x212d1209, 0x13033f12,   // sr.ru.bg_333 hu.jw.id_432  hu.sk.jw_444 af.nl.et_654
  0x4a005221, 0x0f006402, 0x2125120c, 0x3f031a05,   // ha.yo.un_860 lg.lv.un_220  hu.eu.jw_543 tl.nl.af_333
  // [4e10]
  0x0807040b, 0x0c081a08, 0x3b13030c, 0x4a00682c,   // ru.bg.uk_542 tl.no.sv_443  nl.et.so_543 ig.yo.un_990
  0x12211cad, 0x01033b0d, 0x040313af, 0x0a1c21a0,   // id.jw.hu_643 so.nl.en_554  et.nl.fi_655 jw.id.pt_322
  0x2b002304, 0x11355307, 0x3b001318, 0x3f2512a4,   // ca.vi.un_320 ht.zu.ro_432  et.so.un_740 hu.eu.af_433
  0x216b12a4, 0x12006e08, 0x2d000108, 0x0500070d,   // hu.ceb.jw_433 hmn.hu.un_430  en.sk.un_430 it.fr.un_540
  // [4e20]
  0x1a122d11, 0x0c0208a0, 0x2d29120d, 0x1c1a1212,   // sk.hu.tl_653 no.da.sv_322  hu.sl.sk_554 hu.tl.id_654
  0x12001c1a, 0x280c0811, 0x0a000721, 0x640313ee,   // id.hu.un_760 no.sv.sw_653  bg.mk.un_860 et.nl.lg_422
  0x13033f07, 0x080235a6, 0x64551213, 0x530c0807,   // af.nl.et_432 zu.da.no_521  hu.rw.lg_665 no.sv.ht_432
  0x13310804, 0x4a6b1a5a, 0x130d0908, 0x12001019,   // no.az.et_332 tl.ceb.yo_553  hi.ne.bh_443 lt.hu.un_750
  // [4e30]
  0x1f0105a0, 0x55006823, 0x6b526813, 0x1f000708,   // fr.en.cy_322 ig.rw.un_880  ig.ha.ceb_665 it.cy.un_430
  0x1c3b1eee, 0x04644a08, 0x07121807, 0x0c030609,   // ms.so.id_422 yo.lg.fi_443  ga.hu.it_432 de.nl.sv_444
  0x1200101a, 0x64556808, 0x08000321, 0x6800550e,   // lt.hu.un_760 ig.rw.lg_443  nl.no.un_860 rw.ig.un_550
  0x554a0807, 0x020308a9, 0x071210ad, 0x27000108,   // no.yo.rw_432 no.nl.da_544  lt.hu.it_643 en.gd.un_430
  // [4e40]
  0x273b2011, 0x10080414, 0x10040812, 0x033f080c,   // sq.so.gd_653 ru.uk.be_666  uk.ru.be_654 no.af.nl_543
  0x1104200c, 0x12290c02, 0x0a000735, 0x23200413,   // sq.fi.ro_543 sv.sl.hu_222  bg.mk.un_A90 fi.sq.ca_665
  0x1300210c, 0x0c060111, 0x04002019, 0x0b251908,   // jw.et.un_530 en.de.sv_653  sq.fi.un_750 gl.eu.es_443
  0x033f1f13, 0x211a3508, 0x08001813, 0x041108af,   // cy.af.nl_665 zu.tl.jw_443  ga.no.un_650 uk.ro.ru_655
  // [4e50]
  0x52553ba4, 0x100e3f13, 0x08001b13, 0x35001e0d,   // so.rw.ha_433 af.is.lt_665  tr.no.un_650 ms.zu.un_540
  0x52552811, 0x55280804, 0x061b030d, 0x01001f12,   // sw.rw.ha_653 no.sw.rw_332  nl.tr.de_554 cy.en.un_640
  0x3b12350c, 0x3f001f08, 0x1000020c, 0x6e352108,   // zu.hu.so_543 cy.af.un_430  da.lt.un_530 jw.zu.hmn_443
  0x04080a0c, 0x0c0603a0, 0x12200c07, 0x08023f09,   // mk.uk.ru_543 nl.de.sv_322  sv.sq.hu_432 af.da.no_444
  // [4e60]
  0x2a2023a9, 0x20040d0b, 0x0a0710a7, 0x20000413,   // ca.sq.mt_544 cs.fi.sq_542  be.bg.mk_532 fi.sq.un_650
  0x28003512, 0x35281205, 0x17040809, 0x6b1b09a4,   // zu.sw.un_640 hu.sw.zu_333  uk.ru.sr_444 pl.tr.ceb_433
  0x04171155, 0x21521c11, 0x2700351a, 0x6b321aee,   // ro.sr.ru_442 id.ha.jw_653  zu.gd.un_760 tl.bs.ceb_422
  0x022a11a4, 0x35000108, 0x112152a4, 0x040a10ec,   // ro.mt.da_433 en.zu.un_430  ha.jw.ro_433 be.mk.ru_644
  // [4e70]
  0x13001005, 0x352804ad, 0x0d321ba7, 0x2523520b,   // lt.et.un_330 fi.sw.zu_643  tr.bs.cs_532 ha.ca.eu_542
  0x35000613, 0x20002a12, 0x1110040c, 0x64521a04,   // de.zu.un_650 mt.sq.un_640  ru.be.ro_543 tl.ha.lg_332
  0x350a07a9, 0x553529a4, 0x086410ee, 0x35556412,   // it.pt.zu_544 sl.zu.rw_433  lt.lg.no_422 lg.rw.zu_654
  0x25000302, 0x1b000308, 0x08290604, 0x25003b0c,   // nl.eu.un_220 nl.tr.un_430  de.sl.no_332 so.eu.un_530
  // [4e80]
  0x1c063502, 0x3b002108, 0x08000104, 0x28533b14,   // zu.de.id_222 jw.so.un_430  en.no.un_320 so.ht.sw_666
  0x09213507, 0x08040755, 0x1000060d, 0x350d0909,   // zu.jw.pl_432 bg.ru.uk_442  de.lt.un_540 pl.cs.zu_444
  0x52001c08, 0x100953ec, 0x05190104, 0x06021113,   // id.ha.un_430 ht.pl.lt_644  en.gl.fr_332 ro.da.de_665
  0x643555a4, 0x06000e0d, 0x32090d07, 0x21686404,   // rw.zu.lg_433 is.de.un_540  cs.pl.bs_432 lg.ig.jw_332
  // [4e90]
  0x190a200c, 0x171013a4, 0x0f190d0b, 0x2d060d07,   // sq.pt.gl_543 et.lt.sr_433  cs.gl.lv_542 cs.de.sk_432
  0x3525090c, 0x06003508, 0x2d0d120e, 0x201b3207,   // pl.eu.zu_543 zu.de.un_430  hu.cs.sk_555 bs.tr.sq_432
  0x28643560, 0x190f0ba4, 0x2b131ca9, 0x35551aa9,   // zu.lg.sw_664 es.lv.gl_433  id.et.vi_544 tl.rw.zu_544
  0x23551105, 0x6b0105a0, 0x3b2101a4, 0x1e100708,   // ro.rw.ca_333 fr.en.ceb_322  en.jw.so_433 it.lt.ms_443
  // [4ea0]
  0x552021a4, 0x35121aa0, 0x31002a0e, 0x27643508,   // jw.sq.rw_433 tl.hu.zu_322  mt.az.un_550 zu.lg.gd_443
  0x070410ad, 0x0f1953a4, 0x0c1b080c, 0x3b001a1a,   // be.ru.bg_643 ht.gl.lv_433  no.tr.sv_543 tl.so.un_760
  0x35002702, 0x21001833, 0x251a350c, 0x090d13a4,   // gd.zu.un_220 ar.fa.un_A70  zu.tl.eu_543 bh.ne.hi_433
  0x4a00681b, 0x04000805, 0x254a68ac, 0x283b01a7,   // ig.yo.un_770 uk.ru.un_330  ig.yo.eu_632 en.so.sw_532
  // [4eb0]
  0x1f000707, 0x112723a0, 0x11000514, 0x0b000511,   // it.cy.un_420 ca.gd.ro_322  fr.ro.un_660 fr.es.un_630
  0x6b1b53ec, 0x35526baf, 0x063f0f02, 0x12040fa0,   // ht.tr.ceb_644 ceb.ha.zu_655  lv.af.de_222 lv.fi.hu_322
  0x09002a05, 0x21005505, 0x090d1ca6, 0x1a066b04,   // mt.pl.un_330 rw.jw.un_330  mr.ne.hi_521 ceb.de.tl_332
  0x17080d07, 0x1b003b13, 0x3b2021ac, 0x04290304,   // cs.no.sr_432 so.tr.un_650  jw.sq.so_632 nl.sl.fi_332
  // [4ec0]
  0x10006814, 0x1c0d6404, 0x68002012, 0x521b4a0c,   // ig.lt.un_660 lg.cs.id_332  sq.ig.un_640 yo.tr.ha_543
  0x5221530c, 0x0d642d0c, 0x3b556412, 0x530527a0,   // ht.jw.ha_543 sk.lg.cs_543  lg.rw.so_654 gd.fr.ht_322
  0x3f080c08, 0x311b5312, 0x1b3b52a0, 0x552d130b,   // sv.no.af_443 ht.tr.az_654  ha.so.tr_322 et.sk.rw_542
  0x25006b08, 0x211a5507, 0x0623010c, 0x4a1b550d,   // ceb.eu.un_430 rw.tl.jw_432  en.ca.de_543 rw.tr.yo_554
  // [4ed0]
  0x060105ec, 0x120c2304, 0x03083fa0, 0x2b081f0b,   // fr.en.de_644 ca.sv.hu_332  af.no.nl_322 cy.no.vi_542
  0x03002a12, 0x090408a0, 0x2a23110d, 0x55002108,   // mt.nl.un_640 no.fi.pl_322  ro.ca.mt_554 jw.rw.un_430
  0x68003b19, 0x645335af, 0x3f050107, 0x551e1f04,   // so.ig.un_750 zu.ht.lg_655  en.fr.af_432 cy.ms.rw_332
  0x311c21a0, 0x04200ca0, 0x07040aad, 0x03230112,   // jw.id.az_322 sv.sq.fi_322  mk.ru.bg_643 en.ca.nl_654
  // [4ee0]
  0x64005302, 0x3b6b1aad, 0x28005512, 0x3b551b0b,   // ht.lg.un_220 tl.ceb.so_643  rw.sw.un_640 tr.rw.so_542
  0x110603ec, 0x311b4aac, 0x1f645511, 0x0a0817ec,   // nl.de.ro_644 yo.tr.az_632  rw.lg.cy_653 sr.uk.mk_644
  0x0c0802ee, 0x05000b0c, 0x55001f0d, 0x06120ca0,   // da.no.sv_422 es.fr.un_530  cy.rw.un_540 sv.hu.de_322
  0x0d00531a, 0x0e000607, 0x0c002a1b, 0x35001813,   // ht.cs.un_760 de.is.un_420  mt.sv.un_770 ga.zu.un_650
  // [4ef0]
  0x033f0aaf, 0x2a112308, 0x29033f55, 0x1a5564a4,   // pt.af.nl_655 ca.ro.mt_443  af.nl.sl_442 lg.rw.tl_433
  0x126b1aee, 0x23110d12, 0x35002a07, 0x0e1b3112,   // tl.ceb.hu_422 cs.ro.ca_654  mt.zu.un_420 az.tr.is_654
  0x066455ee, 0x170704a0, 0x523f230c, 0x3b64550b,   // rw.lg.de_422 ru.bg.sr_322  ca.af.ha_543 rw.lg.so_542
  0x064a550e, 0x1a003b14, 0x1700100b, 0x271f0208,   // rw.yo.de_555 so.tl.un_660  lt.sr.un_520 da.cy.gd_443
  // [4f00]
  0x1355520e, 0x252d0da7, 0x123f1007, 0x100407ad,   // ha.rw.et_555 cs.sk.eu_532  lt.af.hu_432 bg.ru.be_643
  0x1f0727a9, 0x32003505, 0x08110a04, 0x0408170c,   // gd.it.cy_544 zu.bs.un_330  mk.ro.uk_332 sr.uk.ru_543
  0x3b211b0c, 0x1a101e07, 0x1b033f0c, 0x06353bee,   // tr.jw.so_543 ms.lt.tl_432  af.nl.tr_543 so.zu.de_422
  0x292d1705, 0x170925a7, 0x2d29100c, 0x13046408,   // sr.sk.sl_333 eu.pl.sr_532  lt.sl.sk_543 lg.fi.et_443
  // [4f10]
  0x35005205, 0x1e101c0c, 0x2d170d07, 0x1a6b1207,   // ha.zu.un_330 id.lt.ms_543  cs.sr.sk_432 hu.ceb.tl_432
  0x10040802, 0x4a001308, 0x3f3b1f12, 0x322a09a4,   // uk.ru.be_222 et.yo.un_430  cy.so.af_654 pl.mt.bs_433
  0x1e004a19, 0x4a230ba0, 0x29204a13, 0x0200201a,   // yo.ms.un_750 es.ca.yo_322  yo.sq.sl_665 sq.da.un_760
  0x53001602, 0x20001014, 0x17002d12, 0x172952a7,   // hr.ht.un_220 lt.sq.un_660  sk.sr.un_640 ha.sl.sr_532
  // [4f20]
  0x0b002d0d, 0x11033fec, 0x23003f0d, 0x113f030b,   // sk.es.un_540 af.nl.ro_644  af.ca.un_540 nl.af.ro_542
  0x1c033fa0, 0x120e0cee, 0x070a0860, 0x21022905,   // af.nl.id_322 sv.is.hu_422  uk.mk.bg_664 sl.da.jw_333
  0x162d2007, 0x033f2311, 0x202902ad, 0x2d0807ac,   // sq.sk.hr_432 ca.af.nl_653  da.sl.sq_643 it.no.sk_632
  0x3f001112, 0x18000107, 0x0b002002, 0x16002912,   // ro.af.un_640 en.ga.un_420  sq.es.un_220 sl.hr.un_640
  // [4f30]
  0x201153a4, 0x0a04100c, 0x18006e08, 0x08062304,   // ht.ro.sq_433 be.ru.mk_543  hmn.ga.un_430 ca.de.no_332
  0x08001f04, 0x11000522, 0x1f2327a9, 0x11033f60,   // cy.no.un_320 fr.ro.un_870  gd.ca.cy_544 af.nl.ro_664
  0x012b53a0, 0x20000804, 0x13091cac, 0x250e0c07,   // ht.vi.en_322 no.sq.un_320  mr.hi.bh_632 sv.is.eu_432
  0x08020e55, 0x1000040b, 0x1e160da0, 0x01001307,   // is.da.no_442 ru.be.un_520  cs.hr.ms_322 et.en.un_420
  // [4f40]
  0x040810a7, 0x1c6e1e07, 0x231918a4, 0x03000704,   // be.uk.ru_532 ms.hmn.id_432  ga.gl.ca_433 it.nl.un_320
  0x11134a07, 0x0e020604, 0x206432a4, 0x18016b04,   // yo.et.ro_432 de.da.is_332  bs.lg.sq_433 ceb.en.ga_332
  0x126407a0, 0x13211cac, 0x2500640d, 0x29000813,   // it.lg.hu_322 id.jw.et_632  lg.eu.un_540 no.sl.un_650
  0x13121ba4, 0x1a6407ad, 0x18270112, 0x2032160d,   // tr.hu.et_433 it.lg.tl_643  en.gd.ga_654 hr.bs.sq_554
  // [4f50]
  0x182827ec, 0x1e204a07, 0x040825a0, 0x21040ea0,   // gd.sw.ga_644 yo.sq.ms_432  eu.no.fi_322 is.fi.jw_322
  0x0d641ba4, 0x21002029, 0x0613250c, 0x1e182712,   // tr.lg.cs_433 sq.jw.un_960  eu.et.de_543 gd.ga.ms_654
  0x321708ee, 0x032555a9, 0x09550e08, 0x10284aa0,   // no.sr.bs_422 rw.eu.nl_544  is.rw.pl_443 yo.sw.lt_322
  0x02000e14, 0x082002af, 0x52000e19, 0x523b64ad,   // is.da.un_660 da.sq.no_655  is.ha.un_750 lg.so.ha_643
  // [4f60]
  0x11061fa4, 0x12321704, 0x050820ee, 0x4a0c6804,   // cy.de.ro_433 sr.bs.hu_332  sq.no.fr_422 ig.sv.yo_332
  0x6b000105, 0x20000808, 0x2718520c, 0x18276e13,   // en.ceb.un_330 no.sq.un_430  ha.ga.gd_543 hmn.gd.ga_665
  0x04120cee, 0x20006e0d, 0x0c0204af, 0x06032702,   // sv.hu.fi_422 hmn.sq.un_540  fi.da.sv_655 gd.nl.de_222
  0x16042904, 0x053f0304, 0x21001804, 0x18276eaf,   // sl.fi.hr_332 nl.af.fr_332  ar.fa.un_320 hmn.gd.ga_655
  // [4f70]
  0x6e2b4aa0, 0x0f12250c, 0x35006b02, 0x1b351208,   // yo.vi.hmn_322 eu.hu.lv_543  ceb.zu.un_220 hu.zu.tr_443
  0x251119ee, 0x030764a7, 0x100b2da0, 0x64002108,   // gl.ro.eu_422 lg.it.nl_532  sk.es.lt_322 jw.lg.un_430
  0x3b0607ad, 0x6e0a1f0c, 0x64000713, 0x120f10ec,   // it.de.so_643 cy.pt.hmn_543  it.lg.un_650 lt.lv.hu_644
  0x13232508, 0x2d001223, 0x0b0f10ec, 0x285521a9,   // eu.ca.et_443 hu.sk.un_880  lt.lv.es_644 jw.rw.sw_544
  // [4f80]
  0x0823250c, 0x040e2007, 0x120e04a0, 0x1906050c,   // eu.ca.no_543 sq.is.fi_432  fi.is.hu_322 fr.de.gl_543
  0x12002013, 0x10002d04, 0x3b00040c, 0x10136ea0,   // sq.hu.un_650 sk.lt.un_320  fi.so.un_530 hmn.et.lt_322
  0x16002919, 0x2100122a, 0x10002804, 0x0a0b19ad,   // sl.hr.un_750 ur.fa.un_970  sw.lt.un_320 gl.es.pt_643
  0x041117a4, 0x6b001a11, 0x21180107, 0x036e6408,   // sr.ro.ru_433 tl.ceb.un_630  en.ga.jw_432 lg.hmn.nl_443
  // [4f90]
  0x231320ac, 0x08171014, 0x200e020c, 0x3f3b13ad,   // sq.et.ca_632 be.sr.uk_666  da.is.sq_543 et.so.af_643
  0x08000211, 0x68190b13, 0x20005314, 0x03001307,   // da.no.un_630 es.gl.ig_665  ht.sq.un_660 et.nl.un_420
  0x3f036455, 0x0d091cee, 0x1b130502, 0x1300201a,   // lg.nl.af_442 mr.hi.ne_422  fr.et.tr_222 sq.et.un_760
  0x32001718, 0x030e2007, 0x532105a6, 0x120e06a0,   // sr.bs.un_740 sq.is.nl_432  fr.jw.ht_521 de.is.hu_322
  // [4fa0]
  0x6b00250d, 0x06351f07, 0x18001f0e, 0x64002507,   // eu.ceb.un_540 cy.zu.de_432  cy.ga.un_550 eu.lg.un_420
  0x1e110411, 0x6b3b0e12, 0x201e1c09, 0x11000735,   // fi.ro.ms_653 is.so.ceb_654  id.ms.sq_444 bg.ro.un_A90
  0x02002304, 0x1c001f02, 0x07080414, 0x190306a4,   // ca.da.un_320 cy.id.un_220  ru.uk.bg_666 de.nl.gl_433
  0x06021e02, 0x11002305, 0x1e132107, 0x191368a7,   // ms.da.de_222 ca.ro.un_330  jw.et.ms_432 ig.et.gl_532
  // [4fb0]
  0x211b1207, 0x0700350d, 0x681b5308, 0x2500120d,   // hu.tr.jw_432 zu.it.un_540  ht.tr.ig_443 hu.eu.un_540
  0x08000a08, 0x03000207, 0x1b531c07, 0x6b001b05,   // mk.uk.un_430 da.nl.un_420  id.ht.tr_432 tr.ceb.un_330
  0x1e022505, 0x03080e08, 0x06001f02, 0x1b1e21a4,   // eu.da.ms_333 is.no.nl_443  cy.de.un_220 jw.ms.tr_433
  0x02000c0e, 0x126408a4, 0x0b0223ee, 0x11230704,   // sv.da.un_550 no.lg.hu_433  ca.da.es_422 it.ca.ro_332
  // [4fc0]
  0x02001807, 0x53121e07, 0x08060205, 0x5331120c,   // ga.da.un_420 ms.hu.ht_432  da.de.no_333 hu.az.ht_543
  0x0709110c, 0x0a1925ad, 0x2d0d2502, 0x1300080d,   // ro.pl.it_543 eu.gl.pt_643  eu.cs.sk_222 no.et.un_540
  0x110a28ee, 0x1235060c, 0x25190e0c, 0x3b006e04,   // sw.pt.ro_422 de.zu.hu_543  is.gl.eu_543 hmn.so.un_320
  0x2500230c, 0x12211c0c, 0x12092512, 0x02001908,   // ca.eu.un_530 id.jw.hu_543  eu.pl.hu_654 gl.da.un_430
  // [4fd0]
  0x21002019, 0x201655ee, 0x09251802, 0x201f11ad,   // sq.jw.un_750 rw.hr.sq_422  ga.eu.pl_222 ro.cy.sq_643
  0x292d0daf, 0x1b00680d, 0x23250fa0, 0x1c6b53a0,   // cs.sk.sl_655 ig.tr.un_540  lv.eu.ca_322 ht.ceb.id_322
  0x230621a4, 0x21000607, 0x23190708, 0x3b131ca4,   // jw.de.ca_433 de.jw.un_420  it.gl.ca_443 id.et.so_433
  0x110925a0, 0x552a25a4, 0x3f081208, 0x4a0512a9,   // eu.pl.ro_322 eu.mt.rw_433  hu.no.af_443 hu.fr.yo_544
  // [4fe0]
  0x4a642807, 0x02185504, 0x68004a21, 0x08000409,   // sw.lg.yo_432 rw.ga.da_332  yo.ig.un_860 ru.uk.un_440
  0x230a0e05, 0x05001909, 0x55640611, 0x0c030502,   // is.pt.ca_333 gl.fr.un_440  de.lg.rw_653 fr.nl.sv_222
  0x25551e0b, 0x4a07230c, 0x040a17a6, 0x35003207,   // ms.rw.eu_542 ca.it.yo_543  sr.mk.ru_521 bs.zu.un_420
  0x1b0d55a0, 0x05003107, 0x0400102c, 0x291610a0,   // rw.cs.tr_322 az.fr.un_420  be.ru.un_990 lt.hr.sl_322
  // [4ff0]
  0x13041eee, 0x131c0911, 0x1e1c35a0, 0x0000032d,   // ms.fi.et_422 hi.mr.bh_653  zu.id.ms_322 nl.un.un_A00
  0x12000c0c, 0x552820ee, 0x6b2b010c, 0x0c121fad,   // sv.hu.un_530 sq.sw.rw_422  en.vi.ceb_543 cy.hu.sv_643
  0x28550107, 0x1c1225ee, 0x4a121804, 0x0c061fac,   // en.rw.sw_432 eu.hu.id_422  ga.hu.yo_332 cy.de.sv_632
  0x3f030111, 0x1a130407, 0x645525ec, 0x0c002018,   // en.nl.af_653 fi.et.tl_432  eu.rw.lg_644 sq.sv.un_740

  // [5000]
  0x11060111, 0x35000c04, 0x1e001208, 0x52071fa4,   // en.de.ro_653 sv.zu.un_320  hu.ms.un_430 cy.it.ha_433
  0x23000604, 0x08550107, 0x016b1007, 0x2053290c,   // de.ca.un_320 en.rw.no_432  lt.ceb.en_432 sl.ht.sq_543
  0x10070a09, 0x2d000b04, 0x35640702, 0x200c2d07,   // mk.bg.be_444 es.sk.un_320  it.lg.zu_222 sk.sv.sq_432
  0x06004a08, 0x21532004, 0x29311ba9, 0x112a2305,   // yo.de.un_430 sq.ht.jw_332  tr.az.sl_544 ca.mt.ro_333
  // [5010]
  0x522a1208, 0x1700081b, 0x20001e13, 0x130601a6,   // hu.mt.ha_443 uk.sr.un_770  ms.sq.un_650 en.de.et_521
  0x110704a9, 0x20000d20, 0x213f01a0, 0x010f100c,   // ru.bg.ro_544 cs.sq.un_850  en.af.jw_322 lt.lv.en_543
  0x01521107, 0x3b002a05, 0x171606a4, 0x033f010c,   // ro.ha.en_432 mt.so.un_330  de.hr.sr_433 en.af.nl_543
  0x21066404, 0x27033f04, 0x0f0410ec, 0x162d0d05,   // lg.de.jw_332 af.nl.gd_332  lt.fi.lv_644 cs.sk.hr_333
  // [5020]
  0x0a00081b, 0x0d002304, 0x04202308, 0x4a1f060c,   // uk.mk.un_770 ca.cs.un_320  ca.sq.fi_443 de.cy.yo_543
  0x0e0c0809, 0x080e0c5a, 0x1c061e12, 0x23082007,   // no.sv.is_444 sv.is.no_553  ms.de.id_654 sq.no.ca_432
  0x0c000e1b, 0x3f040507, 0x080e0c55, 0x09000805,   // is.sv.un_770 fr.fi.af_432  sv.is.no_442 no.pl.un_330
  0x0e0c08a9, 0x2300530d, 0x52000c04, 0x0e0c1304,   // no.sv.is_544 ht.ca.un_540  sv.ha.un_320 et.sv.is_332
  // [5030]
  0x551a3b08, 0x040110a0, 0x04202105, 0x29041007,   // so.tl.rw_443 lt.en.fi_322  jw.sq.fi_333 lt.fi.sl_432
  0x130106a0, 0x131e1c02, 0x041052ad, 0x1c0f1004,   // de.en.et_322 id.ms.et_222  ha.lt.fi_643 lt.lv.id_332
  0x55682807, 0x09102555, 0x355225a4, 0x051e5302,   // sw.ig.rw_432 eu.lt.pl_442  eu.ha.zu_433 ht.ms.fr_222
  0x04170aad, 0x080e0c04, 0x1a085307, 0x291b01a4,   // mk.sr.ru_643 sv.is.no_332  ht.no.tl_432 en.tr.sl_433
  // [5040]
  0x290917a0, 0x12135213, 0x231101af, 0x012927a4,   // sr.pl.sl_322 ha.et.hu_665  en.ro.ca_655 gd.sl.en_433
  0x11016b04, 0x281225a0, 0x28356404, 0x012311a4,   // ceb.en.ro_332 eu.hu.sw_322  lg.zu.sw_332 ro.ca.en_433
  0x042010a4, 0x020b6b0c, 0x08070411, 0x04251008,   // lt.sq.fi_433 ceb.es.da_543  ru.bg.uk_653 lt.eu.fi_443
  0x23110108, 0x04182708, 0x1123010c, 0x52002908,   // en.ro.ca_443 gd.ga.fi_443  en.ca.ro_543 sl.ha.un_430
  // [5050]
  0x094a5212, 0x6b090107, 0x28073508, 0x04080712,   // ha.yo.pl_654 en.pl.ceb_432  zu.it.sw_443 bg.uk.ru_654
  0x1353250b, 0x531725ee, 0x1b250408, 0x0e0508a0,   // eu.ht.et_542 eu.sr.ht_422  fi.eu.tr_443 no.fr.is_322
  0x05001105, 0x1f002321, 0x090d1104, 0x6800351a,   // ro.fr.un_330 ca.cy.un_860  ro.cs.pl_332 zu.ig.un_760
  0x25073ba0, 0x2d0d050c, 0x11012304, 0x070e0aec,   // so.it.eu_322 fr.cs.sk_543  ca.en.ro_332 pt.is.it_644
  // [5060]
  0x1b4a6809, 0x321701a0, 0x52685305, 0x0500040d,   // ig.yo.tr_444 en.sr.bs_322  ht.ig.ha_333 fi.fr.un_540
  0x6800022c, 0x1b2068a0, 0x04201b13, 0x1b00531a,   // da.ig.un_990 ig.sq.tr_322  tr.sq.fi_665 ht.tr.un_760
  0x2b2301ad, 0x070c25af, 0x3b005209, 0x2b1c01a4,   // en.ca.vi_643 eu.sv.it_655  ha.so.un_440 en.id.vi_433
  0x4a2025ec, 0x132916a0, 0x68000822, 0x020a4aa7,   // eu.sq.yo_644 hr.sl.et_322  no.ig.un_870 yo.pt.da_532
  // [5070]
  0x6e6b6807, 0x1f103555, 0x2d2911ee, 0x680413ec,   // ig.ceb.hmn_432 zu.lt.cy_442  ro.sl.sk_422 et.fi.ig_644
  0x24000129, 0x35164a0c, 0x07000622, 0x552868ad,   // iw.yi.un_960 yo.hr.zu_543  de.it.un_870 ig.sw.rw_643
  0x2500550c, 0x231b5507, 0x681b3b0e, 0x0607050c,   // rw.eu.un_530 rw.tr.ca_432  so.tr.ig_555 fr.it.de_543
  0x525328ee, 0x06182760, 0x0f102155, 0x6b000405,   // sw.ht.ha_422 gd.ga.de_664  jw.lt.lv_442 fi.ceb.un_330
  // [5080]
  0x6400681a, 0x324a13ad, 0x23684aec, 0x682032a0,   // ig.lg.un_760 et.yo.bs_643  yo.ig.ca_644 bs.sq.ig_322
  0x2d002702, 0x4a685355, 0x21000c0d, 0x52000e04,   // gd.sk.un_220 ht.ig.yo_442  sv.jw.un_540 is.ha.un_320
  0x68132309, 0x11550907, 0x3f201112, 0x050b5304,   // ca.et.ig_444 pl.rw.ro_432  ro.sq.af_654 ht.es.fr_332
  0x0c0504ee, 0x0100682b, 0x042011ee, 0x02170cec,   // fi.fr.sv_422 ig.en.un_980  ro.sq.fi_422 sv.sr.da_644
  // [5090]
  0x20681313, 0x0768010b, 0x55286412, 0x0f00102c,   // et.ig.sq_665 en.ig.it_542  lg.sw.rw_654 lt.lv.un_990
  0x68211cad, 0x20001f0d, 0x0e001704, 0x35000a35,   // id.jw.ig_643 cy.sq.un_540  sr.is.un_320 pt.zu.un_A90
  0x03010ca4, 0x321e1ba0, 0x0c000f18, 0x53050613,   // sv.en.nl_433 tr.ms.bs_322  lv.sv.un_740 de.fr.ht_665
  0x23050114, 0x0e000c2b, 0x050e01af, 0x35111704,   // en.fr.ca_666 sv.is.un_980  en.is.fr_655 sr.ro.zu_332
  // [50a0]
  0x2a1703a7, 0x050f01a0, 0x020e01a6, 0x06321605,   // nl.sr.mt_532 en.lv.fr_322  en.is.da_521 hr.bs.de_333
  0x1c0d0904, 0x290d2da4, 0x061203a9, 0x2d0d0fa6,   // hi.ne.mr_332 sk.cs.sl_433  nl.hu.de_544 lv.cs.sk_521
  0x052719a0, 0x17000f0b, 0x0c0e3f04, 0x27002505,   // gl.gd.fr_322 lv.sr.un_520  af.is.sv_332 eu.gd.un_330
  0x35011fa4, 0x023f0f07, 0x0f2301a4, 0x12000108,   // cy.en.zu_433 lv.af.da_432  en.ca.lv_433 en.hu.un_430
  // [50b0]
  0x17000a35, 0x05080304, 0x0c001012, 0x35322307,   // mk.sr.un_A90 nl.no.fr_332  lt.sv.un_640 ca.bs.zu_432
  0x3f0203ec, 0x27000308, 0x11050760, 0x1c0c2105,   // nl.da.af_644 nl.gd.un_430  it.fr.ro_664 jw.sv.id_333
  0x16001019, 0x25070607, 0x25000f13, 0x20003509,   // lt.hr.un_750 de.it.eu_432  lv.eu.un_650 zu.sq.un_440
  0x3500060c, 0x0a0523ec, 0x200401ee, 0x0a0523a7,   // de.zu.un_530 ca.fr.pt_644  en.fi.sq_422 ca.fr.pt_532
  // [50c0]
  0x6b0305ee, 0x0a08025a, 0x35063f04, 0x1c000d2b,   // fr.nl.ceb_422 da.no.pt_553  af.de.zu_332 ne.mr.un_980
  0x285564ee, 0x0c353baf, 0x08273fa0, 0x04063512,   // lg.rw.sw_422 so.zu.sv_655  af.gd.no_322 zu.de.fi_654
  0x52534aaf, 0x0d001b05, 0x32550b0c, 0x20005204,   // yo.ht.ha_655 tr.cs.un_330  es.rw.bs_543 ha.sq.un_320
  0x55212812, 0x12001107, 0x2d320d07, 0x193209a0,   // sw.jw.rw_654 ro.hu.un_420  cs.bs.sk_432 pl.bs.gl_322
  // [50d0]
  0x1b521c08, 0x534a28a7, 0x354a2504, 0x12001602,   // id.ha.tr_443 sw.yo.ht_532  eu.yo.zu_332 hr.hu.un_220
  0x021018a0, 0x31000a04, 0x0e002d0c, 0x13090dac,   // ga.lt.da_322 pt.az.un_320  sk.is.un_530 ne.hi.bh_632
  0x06120eac, 0x05006b07, 0x091c13a0, 0x020608a4,   // is.hu.de_632 ceb.fr.un_420  bh.mr.hi_322 no.de.da_433
  0x271f1812, 0x2a2718a4, 0x1f3f0a07, 0x3f1c35a0,   // ga.cy.gd_654 ga.gd.mt_433  pt.af.cy_432 zu.id.af_322
  // [50e0]
  0x28093505, 0x2d1107ad, 0x190a20a0, 0x06001808,   // zu.pl.sw_333 it.ro.sk_643  sq.pt.gl_322 ga.de.un_430
  0x28181fee, 0x09022305, 0x20231108, 0x1b00310b,   // cy.ga.sw_422 ca.da.pl_333  ro.ca.sq_443 az.tr.un_520
  0x1b200404, 0x081004a9, 0x6b0c0807, 0x13000212,   // fi.sq.tr_332 ru.be.uk_544  no.sv.ceb_432 da.et.un_640
  0x270e1812, 0x4a520c0c, 0x29001c04, 0x121e1c04,   // ga.is.gd_654 sv.ha.yo_543  id.sl.un_320 id.ms.hu_332
  // [50f0]
  0x1800212c, 0x1c32210d, 0x0c080ea0, 0x23205508,   // fa.ar.un_990 jw.bs.id_554  is.no.sv_322 rw.sq.ca_443
  0x64130413, 0x180e4a09, 0x18232aa4, 0x0c00082a,   // fi.et.lg_665 yo.is.ga_444  mt.ca.ga_433 no.sv.un_970
  0x1f002802, 0x0601230c, 0x191b0aec, 0x135304ad,   // sw.cy.un_220 ca.en.de_543  pt.tr.gl_644 fi.ht.et_643
  0x21000204, 0x10170713, 0x08272007, 0x12111ba0,   // da.jw.un_320 bg.sr.be_665  sq.gd.no_432 tr.ro.hu_322
  // [5100]
  0x0c2a230c, 0x0c002313, 0x1e001c12, 0x020508a4,   // ca.mt.sv_543 ca.sv.un_650  id.ms.un_640 no.fr.da_433
  0x062308a7, 0x2d120cac, 0x021f0807, 0x23060108,   // no.ca.de_532 sv.hu.sk_632  no.cy.da_432 en.de.ca_443
  0x0c061ba7, 0x18201313, 0x1e1c120e, 0x060301a4,   // tr.de.sv_532 et.sq.ga_665  hu.id.ms_555 en.nl.de_433
  0x0600051a, 0x21002a04, 0x0800070c, 0x030608a4,   // fr.de.un_760 mt.jw.un_320  bg.uk.un_530 no.de.nl_433
  // [5110]
  0x556b1aa4, 0x03060412, 0x061f04a4, 0x1e1c06ac,   // tl.ceb.rw_433 fi.de.nl_654  fi.cy.de_433 de.id.ms_632
  0x011f030c, 0x13062707, 0x2a030613, 0x3100030b,   // nl.cy.en_543 gd.de.et_432  de.nl.mt_665 nl.az.un_520
  0x0f110e08, 0x0c000305, 0x1b041007, 0x270e010c,   // is.ro.lv_443 nl.sv.un_330  lt.fi.tr_432 en.is.gd_543
  0x181f0555, 0x1f06230c, 0x17100807, 0x1f3f0307,   // fr.cy.ga_442 ca.de.cy_543  uk.be.sr_432 nl.af.cy_432
  // [5120]
  0x53002514, 0x111310ec, 0x31051b04, 0x1b000408,   // eu.ht.un_660 lt.et.ro_644  tr.fr.az_332 fi.tr.un_430
  0x27051804, 0x21101c0c, 0x1f080cee, 0x1b00080d,   // ga.fr.gd_332 id.lt.jw_543  sv.no.cy_422 no.tr.un_540
  0x116b6e08, 0x05181311, 0x0804070b, 0x0f001e13,   // hmn.ceb.ro_443 et.ga.fr_653  bg.ru.uk_542 ms.lv.un_650
  0x0300041b, 0x035207ee, 0x1b06030d, 0x07190b0d,   // fi.nl.un_770 it.ha.nl_422  nl.de.tr_554 es.gl.it_554
  // [5130]
  0x1f0b05a7, 0x050a12ad, 0x230a0e55, 0x06031f13,   // fr.es.cy_532 hu.pt.fr_643  is.pt.ca_442 cy.nl.de_665
  0x10190a14, 0x2704130c, 0x07001713, 0x31351707,   // pt.gl.lt_666 et.fi.gd_543  sr.bg.un_650 sr.zu.az_432
  0x3513040c, 0x080f100c, 0x120f6808, 0x35001221,   // fi.et.zu_543 lt.lv.no_543  ig.lv.hu_443 hu.zu.un_860
  0x1a1f2111, 0x6e1001a9, 0x10000708, 0x08101707,   // jw.cy.tl_653 en.lt.hmn_544  bg.be.un_430 sr.be.uk_432
  // [5140]
  0x2a006408, 0x092d0d5a, 0x04003b0c, 0x08046ba0,   // lg.mt.un_430 cs.sk.pl_553  so.fi.un_530 ceb.fi.no_322
  0x063f0407, 0x18310102, 0x0e3217a6, 0x3b1035a7,   // fi.af.de_432 en.az.ga_222  sr.bs.is_521 zu.lt.so_532
  0x64005307, 0x101809ad, 0x4a00100d, 0x18000e0b,   // ht.lg.un_420 pl.ga.lt_643  lt.yo.un_540 is.ga.un_520
  0x10283b0d, 0x202931ee, 0x103b35a4, 0x04093b07,   // so.sw.lt_554 az.sl.sq_422  zu.so.lt_433 so.pl.fi_432
  // [5150]
  0x64072811, 0x556825af, 0x2700130c, 0x040a1008,   // sw.it.lg_653 eu.ig.rw_655  et.gd.un_530 be.mk.ru_443
  0x2b180107, 0x0407110d, 0x4a2d0d04, 0x2a000f11,   // en.ga.vi_432 ro.bg.ru_554  cs.sk.yo_332 lv.mt.un_630
  0x551f13a7, 0x1c00350b, 0x641368a9, 0x0b0a07a4,   // et.cy.rw_532 zu.id.un_520  ig.et.lg_544 it.pt.es_433
  0x554a1007, 0x10080707, 0x283b10ec, 0x0a171114,   // lt.yo.rw_432 bg.uk.be_432  lt.so.sw_644 ro.sr.mk_666
  // [5160]
  0x0e033f07, 0x1c000804, 0x082a1205, 0x106409ee,   // af.nl.is_432 no.id.un_320  hu.mt.no_333 pl.lg.lt_422
  0x6b285209, 0x0c002908, 0x0d1a6ba4, 0x1b2a020c,   // ha.sw.ceb_444 sl.sv.un_430  ceb.tl.cs_433 da.mt.tr_543
  0x3b000407, 0x2718310c, 0x04001122, 0x04554aaf,   // fi.so.un_420 az.ga.gd_543  ro.ru.un_870 yo.rw.fi_655
  0x4a001b1b, 0x212568ad, 0x09000c04, 0x08022a0c,   // tr.yo.un_770 ig.eu.jw_643  sv.pl.un_320 mt.da.no_543
  // [5170]
  0x20533f08, 0x122925ac, 0x211b640d, 0x191325ee,   // af.ht.sq_443 eu.sl.hu_632  lg.tr.jw_554 eu.et.gl_422
  0x0e0c02a4, 0x3f002018, 0x2a042d07, 0x1f134a07,   // da.sv.is_433 sq.af.un_740  sk.fi.mt_432 yo.et.cy_432
  0x07040a14, 0x1f000e11, 0x533f230c, 0x0e001f02,   // mk.ru.bg_666 is.cy.un_630  ca.af.ht_543 cy.is.un_220
  0x2b1629a0, 0x21003b1a, 0x1e1c10a4, 0x020f11ad,   // sl.hr.vi_322 so.jw.un_760  lt.id.ms_433 ro.lv.da_643
  // [5180]
  0x07100807, 0x3200550c, 0x3f002021, 0x04122807,   // uk.be.bg_432 rw.bs.un_530  sq.af.un_860 sw.hu.fi_432
  0x0d00521a, 0x10043555, 0x4a172905, 0x215255ad,   // ha.cs.un_760 zu.fi.lt_442  sl.sr.yo_333 rw.ha.jw_643
  0x0d046b07, 0x19000707, 0x4a002807, 0x35256ba4,   // ceb.fi.cs_432 it.gl.un_420  sw.yo.un_420 ceb.eu.zu_433
  0x06032709, 0x08001f0d, 0x2a1125a4, 0x126b1a0d,   // gd.nl.de_444 cy.no.un_540  eu.ro.mt_433 tl.ceb.hu_554
  // [5190]
  0x03182707, 0x292028a7, 0x2d0d07a6, 0x183f1105,   // gd.ga.nl_432 sw.sq.sl_532  it.cs.sk_521 ro.af.ga_333
  0x211c35ad, 0x252307a0, 0x5200640b, 0x1a00550c,   // zu.id.jw_643 it.ca.eu_322  lg.ha.un_520 rw.tl.un_530
  0x355525a9, 0x0e6b5307, 0x21283508, 0x2018275a,   // eu.rw.zu_544 ht.ceb.is_432  zu.sw.jw_443 gd.ga.sq_553
  0x1b002108, 0x01182707, 0x12190bad, 0x21193502,   // jw.tr.un_430 gd.ga.en_432  es.gl.hu_643 zu.gl.jw_222
  // [51a0]
  0x04006b08, 0x10531ba4, 0x231901a4, 0x4a2023a4,   // ceb.fi.un_430 tr.ht.lt_433  en.gl.ca_433 ca.sq.yo_433
  0x16002a04, 0x0200080e, 0x641b5355, 0x1b203108,   // mt.hr.un_320 no.da.un_550  ht.tr.lg_442 az.sq.tr_443
  0x1b2031a7, 0x531a6b5a, 0x536b1a55, 0x3b006b04,   // az.sq.tr_532 ceb.tl.ht_553  tl.ceb.ht_442 ceb.so.un_320
  0x20120ba0, 0x0a070404, 0x6e311b07, 0x18016ea0,   // es.hu.sq_322 ru.bg.mk_332  tr.az.hmn_432 hmn.en.ga_322
  // [51b0]
  0x53006e12, 0x6e1e1c13, 0x043b03a9, 0x10002d02,   // hmn.ht.un_640 id.ms.hmn_665  nl.so.fi_544 sk.lt.un_220
  0x253b04ad, 0x281e1c0c, 0x03043b12, 0x043f2509,   // fi.so.eu_643 id.ms.sw_543  so.fi.nl_654 eu.af.fi_444
  0x09080202, 0x5220280c, 0x25003b22, 0x28133507,   // da.no.pl_222 sw.sq.ha_543  so.eu.un_870 zu.et.sw_432
  0x030802a0, 0x31003207, 0x55281a12, 0x253f3bad,   // da.no.nl_322 bs.az.un_420  tl.sw.rw_654 so.af.eu_643
  // [51c0]
  0x101e1c13, 0x08321602, 0x5320280c, 0x1e006e08,   // id.ms.lt_665 hr.bs.no_222  sw.sq.ht_543 hmn.ms.un_430
  0x554a6408, 0x35315505, 0x3f002102, 0x25003b18,   // lg.yo.rw_443 rw.az.zu_333  jw.af.un_220 so.eu.un_740
  0x10526412, 0x033b040d, 0x645355ad, 0x033b010c,   // lg.ha.lt_654 fi.so.nl_554  rw.ht.lg_643 en.so.nl_543
  0x100413a0, 0x3b00042a, 0x2853100c, 0x01353b02,   // et.fi.lt_322 fi.so.un_970  lt.ht.sw_543 so.zu.en_222
  // [51d0]
  0x04080aa9, 0x08021bec, 0x6400280d, 0x31000e12,   // mk.uk.ru_544 tr.da.no_644  sw.lg.un_540 is.az.un_640
  0x6b003204, 0x28032b12, 0x08021baf, 0x2100120b,   // bs.ceb.un_320 vi.nl.sw_654  tr.da.no_655 ur.fa.un_520
  0x2b190513, 0x06080260, 0x2b00051a, 0x010306ac,   // fr.gl.vi_665 da.no.de_664  fr.vi.un_760 de.nl.en_632
  0x04004a13, 0x081b0208, 0x2b071112, 0x356e1e0c,   // yo.fi.un_650 da.tr.no_443  ro.it.vi_654 ms.hmn.zu_543
  // [51e0]
  0x0d122d0b, 0x23072bad, 0x4a251a07, 0x2a231904,   // sk.hu.cs_542 vi.it.ca_643  tl.eu.yo_432 gl.ca.mt_332
  0x0600010c, 0x53003b02, 0x2b002514, 0x31211ca4,   // en.de.un_530 so.ht.un_220  eu.vi.un_660 id.jw.az_433
  0x2a130708, 0x041110ad, 0x08021b12, 0x27012a07,   // it.et.mt_443 be.ro.ru_643  tr.da.no_654 mt.en.gd_432
  0x3f000504, 0x2b051f0c, 0x31051bec, 0x1108100c,   // fr.af.un_320 cy.fr.vi_543  tr.fr.az_644 be.uk.ro_543
  // [51f0]
  0x021b0808, 0x04052b08, 0x2b1104a9, 0x042b05af,   // no.tr.da_443 vi.fr.fi_443  fi.ro.vi_544 fr.vi.fi_655
  0x04005208, 0x063f3b07, 0x01003b05, 0x291b2d07,   // ha.fi.un_430 so.af.de_432  so.en.un_330 sk.tr.sl_432
  0x1e3b52ee, 0x3b000e12, 0x53001a04, 0x18002904,   // ha.so.ms_422 is.so.un_640  tl.ht.un_320 sl.ga.un_320
  0x531a6ba7, 0x1c130dad, 0x051c21ee, 0x1f1c21a4,   // ceb.tl.ht_532 ne.bh.mr_643  jw.id.fr_422 jw.id.cy_433
  // [5200]
  0x052301a0, 0x531f05ad, 0x01005302, 0x23110404,   // en.ca.fr_322 fr.cy.ht_643  ht.en.un_220 fi.ro.ca_332
  0x07100a02, 0x52053b07, 0x53001313, 0x070a10a9,   // mk.be.bg_222 so.fr.ha_432  et.ht.un_650 be.mk.bg_544
  0x2b0b23a0, 0x020106a6, 0x556b1aa0, 0x0a000511,   // ca.es.vi_322 de.en.da_521  tl.ceb.rw_322 fr.pt.un_630
  0x531b0507, 0x640413ad, 0x531c05ee, 0x35006407,   // fr.tr.ht_432 et.fi.lg_643  fr.id.ht_422 lg.zu.un_420
  // [5210]
  0x040f12a4, 0x190b1aee, 0x04120faf, 0x6b270155,   // hu.lv.fi_433 tl.es.gl_422  lv.hu.fi_655 en.gd.ceb_442
  0x2a001a04, 0x01002404, 0x12000a14, 0x040d6b0c,   // tl.mt.un_320 yi.iw.un_320  pt.hu.un_660 ceb.cs.fi_543
  0x161c290c, 0x110d0f07, 0x2a000c13, 0x1b290d0b,   // sl.id.hr_543 lv.cs.ro_432  sv.mt.un_650 cs.sl.tr_542
  0x6b1a1f04, 0x1e1f1ca0, 0x3b4a3505, 0x091c0d07,   // cy.tl.ceb_332 id.cy.ms_322  zu.yo.so_333 ne.mr.hi_432
  // [5220]
  0x2a070407, 0x0f1210a9, 0x17040a12, 0x041a1ca7,   // fi.it.mt_432 lt.hu.lv_544  mk.ru.sr_654 id.tl.fi_532
  0x1c1a6b0c, 0x6b1e1cec, 0x2b006e22, 0x1a2052a0,   // ceb.tl.id_543 id.ms.ceb_644  hmn.vi.un_870 ha.sq.tl_322
  0x0e003504, 0x0e31520c, 0x0f001019, 0x2a001f13,   // zu.is.un_320 ha.az.is_543  lt.lv.un_750 cy.mt.un_650
  0x29005202, 0x1f2d2908, 0x25521baf, 0x1b3108a4,   // ha.sl.un_220 sl.sk.cy_443  tr.ha.eu_655 no.az.tr_433
  // [5230]
  0x28004a02, 0x18311b04, 0x1c1e520b, 0x18283ba0,   // yo.sw.un_220 tr.az.ga_332  ha.ms.id_542 so.sw.ga_322
  0x6e00680d, 0x29000d11, 0x31002502, 0x070911ad,   // ig.hmn.un_540 cs.sl.un_630  eu.az.un_220 ro.pl.it_643
  0x1c000f02, 0x6e002b2a, 0x171110af, 0x07041711,   // lv.id.un_220 vi.hmn.un_970  be.ro.sr_655 sr.ru.bg_653
  0x4a5352a4, 0x35006e1a, 0x29131a07, 0x1304525a,   // ha.ht.yo_433 hmn.zu.un_760  tl.et.sl_432 ha.fi.et_553
  // [5240]
  0x4a351c07, 0x10172d07, 0x03002907, 0x290e090c,   // id.zu.yo_432 sk.sr.lt_432  sl.nl.un_420 pl.is.sl_543
  0x53000108, 0x3f25100c, 0x351b5555, 0x3b3f0314,   // en.ht.un_430 lt.eu.af_543  rw.tr.zu_442 nl.af.so_666
  0x1b295504, 0x55001102, 0x2a105505, 0x090d3b07,   // rw.sl.tr_332 ro.rw.un_220  rw.lt.mt_333 so.cs.pl_432
  0x19235302, 0x11070a0c, 0x170c21a4, 0x07190b04,   // ht.ca.gl_222 mk.bg.ro_543  jw.sv.sr_433 es.gl.it_332
  // [5250]
  0x06070e0c, 0x061368a0, 0x1e000c02, 0x13002b19,   // is.it.de_543 ig.et.de_322  sv.ms.un_220 vi.et.un_750
  0x531001a4, 0x080c0ea0, 0x25046812, 0x31001c04,   // en.lt.ht_433 is.sv.no_322  ig.fi.eu_654 id.az.un_320
  0x13046b14, 0x1827255a, 0x0a054aa7, 0x063f0355,   // ceb.fi.et_666 eu.gd.ga_553  yo.fr.pt_532 nl.af.de_442
  0x19000a22, 0x03133f5a, 0x132d0408, 0x21000c09,   // pt.gl.un_870 af.et.nl_553  fi.sk.et_443 sv.jw.un_440
  // [5260]
  0x3f645255, 0x251c1e12, 0x4a311baf, 0x2b000104,   // ha.lg.af_442 ms.id.eu_654  tr.az.yo_655 en.vi.un_320
  0x3f080202, 0x18271f13, 0x1c004a04, 0x6e272355,   // da.no.af_222 cy.gd.ga_665  yo.id.un_320 ca.gd.hmn_442
  0x03003f21, 0x1c001f07, 0x110a07a0, 0x2500130e,   // af.nl.un_860 cy.id.un_420  it.pt.ro_322 et.eu.un_550
  0x19000808, 0x3f080205, 0x2d050aee, 0x3b5553a4,   // no.gl.un_430 da.no.af_333  pt.fr.sk_422 ht.rw.so_433
  // [5270]
  0x132b2807, 0x18001e05, 0x023f0307, 0x2a211905,   // sw.vi.et_432 ms.ga.un_330  nl.af.da_432 gl.jw.mt_333
  0x27530ea4, 0x3f050304, 0x10040711, 0x101e1c02,   // is.ht.gd_433 nl.fr.af_332  bg.ru.be_653 id.ms.lt_222
  0x6e6b3502, 0x23000d04, 0x355521ee, 0x02203f12,   // zu.ceb.hmn_222 cs.ca.un_320  jw.rw.zu_422 af.sq.da_654
  0x0400642a, 0x292a0eee, 0x291c1e0b, 0x3f031b0c,   // lg.fi.un_970 is.mt.sl_422  ms.id.sl_542 tr.nl.af_543
  // [5280]
  0x2d191207, 0x112008a0, 0x06003f0d, 0x0500210b,   // hu.gl.sk_432 no.sq.ro_322  af.de.un_540 jw.fr.un_520
  0x3f1b2da0, 0x18011fad, 0x0802030c, 0x0e1e1c14,   // sk.tr.af_322 cy.en.ga_643  nl.da.no_543 id.ms.is_666
  0x0d1c2104, 0x553528ec, 0x1b310e0d, 0x1b1e1c12,   // jw.id.cs_332 sw.zu.rw_644  is.az.tr_554 id.ms.tr_654
  0x1b000e08, 0x06080eee, 0x040f21ee, 0x4a0155a0,   // is.tr.un_430 is.no.de_422  jw.lv.fi_422 rw.en.yo_322
  // [5290]
  0x642d0da7, 0x121f100d, 0x3b2a19a0, 0x31190b11,   // cs.sk.lg_532 lt.cy.hu_554  gl.mt.so_322 es.gl.az_653
  0x21132d08, 0x3b0e0ca0, 0x6b0301ee, 0x1f35090c,   // sk.et.jw_443 sv.is.so_322  en.nl.ceb_422 pl.zu.cy_543
  0x52006823, 0x11550b05, 0x520306ad, 0x3f030faf,   // ig.ha.un_880 es.rw.ro_333  de.nl.ha_643 lv.nl.af_655
  0x07101708, 0x133b030c, 0x1c1712ad, 0x121e1c0d,   // sr.be.bg_443 nl.so.et_543  hu.sr.id_643 id.ms.hu_554
  // [52a0]
  0x211268ec, 0x2a18010c, 0x07061f07, 0x0f101b08,   // ig.hu.jw_644 en.ga.mt_543  cy.de.it_432 tr.lt.lv_443
  0x1f00280d, 0x17080a0c, 0x120f10a4, 0x64001c1a,   // sw.cy.un_540 mk.uk.sr_543  lt.lv.hu_433 id.lg.un_760
  0x0e080255, 0x1b033f0d, 0x120c0812, 0x08022a05,   // da.no.is_442 af.nl.tr_554  no.sv.hu_654 mt.da.no_333
  0x0c030807, 0x100f130d, 0x0a04070b, 0x2a02010d,   // no.nl.sv_432 et.lv.lt_554  bg.ru.mk_542 en.da.mt_554
  // [52b0]
  0x68010f0b, 0x0c002a08, 0x07080208, 0x216e2b04,   // lv.en.ig_542 mt.sv.un_430  da.no.it_443 vi.hmn.jw_332
  0x35002821, 0x1f001802, 0x07003b05, 0x530e3507,   // sw.zu.un_860 ga.cy.un_220  so.it.un_330 zu.is.ht_432
  0x21031fa4, 0x12005205, 0x68283505, 0x531f2ba9,   // cy.nl.jw_433 ha.hu.un_330  zu.sw.ig_333 vi.cy.ht_544
  0x17071109, 0x21002707, 0x0a11100c, 0x160752ee,   // ro.bg.sr_444 gd.jw.un_420  be.ro.mk_543 ha.it.hr_422
  // [52c0]
  0x18001c02, 0x20001107, 0x201152a0, 0x170a11a0,   // id.ga.un_220 ro.sq.un_420  ha.ro.sq_322 ro.mk.sr_322
  0x2300111a, 0x120c2aa0, 0x21121860, 0x041b3b0c,   // ro.ca.un_760 mt.sv.hu_322  ar.ur.fa_664 so.tr.fi_543
  0x6e1f2b12, 0x5200550c, 0x0a521107, 0x6e002b2c,   // vi.cy.hmn_654 rw.ha.un_530  ro.ha.pt_432 vi.hmn.un_990
  0x6b2a2dec, 0x35002813, 0x09001019, 0x25002007,   // sk.mt.ceb_644 sw.zu.un_650  lt.pl.un_750 sq.eu.un_420
  // [52d0]
  0x0900101b, 0x55000609, 0x3b3f0304, 0x0700042c,   // lt.pl.un_770 de.rw.un_440  nl.af.so_332 ru.bg.un_990
  0x10000919, 0x08100411, 0x3f003b13, 0x10006807,   // pl.lt.un_750 ru.be.uk_653  so.af.un_650 ig.lt.un_420
  0x3b00201a, 0x55006804, 0x3f0812ee, 0x1a190bad,   // sq.so.un_760 ig.rw.un_320  hu.no.af_422 es.gl.tl_643
  0x08070a60, 0x16006b04, 0x08041011, 0x1300680d,   // mk.bg.uk_664 ceb.hr.un_320  be.ru.uk_653 ig.et.un_540
  // [52e0]
  0x03090604, 0x2d110d0c, 0x64002819, 0x0e001e02,   // de.pl.nl_332 cs.ro.sk_543  sw.lg.un_750 ms.is.un_220
  0x0e0623ee, 0x18284aa0, 0x1e002302, 0x2d290913,   // ca.de.is_422 yo.sw.ga_322  ca.ms.un_220 pl.sl.sk_665
  0x3f2d0d08, 0x1f294aad, 0x12003105, 0x0900100e,   // cs.sk.af_443 yo.sl.cy_643  az.hu.un_330 lt.pl.un_550
  0x1c1f0704, 0x09530407, 0x04000921, 0x35000604,   // it.cy.id_332 fi.ht.pl_432  pl.fi.un_860 de.zu.un_320
  // [52f0]
  0x04002119, 0x02556ba0, 0x0400640d, 0x35000e04,   // jw.fi.un_750 ceb.rw.da_322  lg.fi.un_540 is.zu.un_320
  0x27002309, 0x09033f02, 0x35645505, 0x64123504,   // ca.gd.un_440 af.nl.pl_222  rw.lg.zu_333 zu.hu.lg_332
  0x196b0bad, 0x2364250c, 0x190b0702, 0x23280714,   // es.ceb.gl_643 eu.lg.ca_543  it.es.gl_222 it.sw.ca_666
  0x110704a4, 0x0e1b2008, 0x0455530c, 0x3b551a55,   // ru.bg.ro_433 sq.tr.is_443  ht.rw.fi_543 tl.rw.so_442
  // [5300]
  0x31641b0d, 0x52211c07, 0x211b3114, 0x040a100c,   // tr.lg.az_554 id.jw.ha_432  az.tr.jw_666 be.mk.ru_543
  0x080a05a9, 0x3b00280b, 0x25100ead, 0x5500080d,   // fr.pt.no_544 sw.so.un_520  is.lt.eu_643 no.rw.un_540
  0x282555a9, 0x07100411, 0x2b000722, 0x1b3125ee,   // rw.eu.sw_544 fi.lt.it_653  it.vi.un_870 eu.az.tr_422
  0x03681f0c, 0x0e0635ec, 0x17000804, 0x55641ca4,   // cy.ig.nl_543 zu.de.is_644  uk.sr.un_320 id.lg.rw_433
  // [5310]
  0x10006404, 0x552135af, 0x230e1b07, 0x080a040b,   // lg.lt.un_320 zu.jw.rw_655  tr.is.ca_432 ru.mk.uk_542
  0x530c0404, 0x0f000320, 0x10530408, 0x04001b08,   // fi.sv.ht_332 nl.lv.un_850  fi.ht.lt_443 tr.fi.un_430
  0x1e021ca4, 0x55002514, 0x64555207, 0x03080209,   // id.da.ms_433 eu.rw.un_660  ha.rw.lg_432 da.no.nl_444
  0x25000a08, 0x0c080da0, 0x063f1ca4, 0x311b1a08,   // pt.eu.un_430 cs.no.sv_322  id.af.de_433 tl.tr.az_443
  // [5320]
  0x21000512, 0x55131a0c, 0x3100250e, 0x1a64550c,   // fr.jw.un_640 tl.et.rw_543  eu.az.un_550 rw.lg.tl_543
  0x350264a4, 0x060b55a4, 0x063564a4, 0x55061a05,   // lg.da.zu_433 rw.es.de_433  lg.zu.de_433 tl.de.rw_333
  0x21352804, 0x0e0435a4, 0x201a2507, 0x3b1b2807,   // sw.zu.jw_332 zu.fi.is_433  eu.tl.sq_432 sw.tr.so_432
  0x0c000502, 0x4a033f08, 0x5531210c, 0x08005309,   // fr.sv.un_220 af.nl.yo_443  jw.az.rw_543 ht.no.un_440
  // [5330]
  0x1b033205, 0x1b011fa0, 0x19180d0e, 0x4a000d04,   // bs.nl.tr_333 cy.en.tr_322  cs.ga.gl_555 cs.yo.un_320
  0x0800170d, 0x0a2d0d13, 0x3f292da4, 0x1b35310c,   // sr.uk.un_540 cs.sk.pt_665  sk.sl.af_433 az.zu.tr_543
  0x07112d0c, 0x1c00091a, 0x556435ec, 0x033f0614,   // sk.ro.it_543 hi.mr.un_760  zu.lg.rw_644 de.af.nl_666
  0x1907290c, 0x08002a04, 0x21001f1b, 0x03000808,   // sl.it.gl_543 mt.no.un_320  cy.jw.un_770 no.nl.un_430
  // [5340]
  0x3f0453a9, 0x531e3fad, 0x0f1b0512, 0x203531a6,   // ht.fi.af_544 af.ms.ht_643  fr.tr.lv_654 az.zu.sq_521
  0x0c1f0ead, 0x09001f21, 0x0a190b0b, 0x110a0708,   // is.cy.sv_643 cy.pl.un_860  es.gl.pt_542 bg.mk.ro_443
  0x182d0d13, 0x08100ca4, 0x4a000a05, 0x0804070c,   // cs.sk.ga_665 sv.lt.no_433  pt.yo.un_330 bg.ru.uk_543
  0x20001e05, 0x04100a05, 0x2400012b, 0x08041708,   // ms.sq.un_330 mk.be.ru_333  iw.yi.un_980 sr.ru.uk_443
  // [5350]
  0x3f030104, 0x53001002, 0x212d0d08, 0x2b5303a4,   // en.nl.af_332 lt.ht.un_220  cs.sk.jw_443 nl.ht.vi_433
  0x03001104, 0x171809ee, 0x0e0c0f04, 0x12033f07,   // ro.nl.un_320 pl.ga.sr_422  lv.sv.is_332 af.nl.hu_432
  0x06035202, 0x01000a04, 0x0c060308, 0x0c06030e,   // ha.nl.de_222 pt.en.un_320  nl.de.sv_443 nl.de.sv_555
  0x10070a11, 0x28646808, 0x07040a12, 0x03000104,   // mk.bg.be_653 ig.lg.sw_443  mk.ru.bg_654 en.nl.un_320
  // [5360]
  0x032105ee, 0x0800180e, 0x0c00030d, 0x080c05ec,   // fr.jw.nl_422 ga.no.un_550  nl.sv.un_540 fr.sv.no_644
  0x3f030811, 0x2d1205a0, 0x29002d12, 0x3b002007,   // no.nl.af_653 fr.hu.sk_322  sk.sl.un_640 sq.so.un_420
  0x0c000a05, 0x2d0d13a4, 0x3f000807, 0x285218a9,   // pt.sv.un_330 et.cs.sk_433  no.af.un_420 ga.ha.sw_544
  0x52006b02, 0x23530511, 0x06090308, 0x10001c0d,   // ceb.ha.un_220 fr.ht.ca_653  nl.pl.de_443 id.lt.un_540
  // [5370]
  0x061801a4, 0x6e6b01a0, 0x0d282d07, 0x12180e5a,   // en.ga.de_433 en.ceb.hmn_322  sk.sw.cs_432 is.ga.hu_553
  0x2d0d1214, 0x08040e12, 0x0c1b2307, 0x0e0f2908,   // hu.cs.sk_666 is.fi.no_654  ca.tr.sv_432 sl.lv.is_443
  0x0800060e, 0x52002113, 0x0825010c, 0x18271f0c,   // de.no.un_550 jw.ha.un_650  en.eu.no_543 cy.gd.ga_543
  0x06023f07, 0x05000122, 0x0c00291a, 0x3f1306a0,   // af.da.de_432 en.fr.un_870  sl.sv.un_760 de.et.af_322
  // [5380]
  0x1b250704, 0x1810270e, 0x6b530507, 0x030c0804,   // it.eu.tr_332 gd.lt.ga_555  fr.ht.ceb_432 no.sv.nl_332
  0x080206af, 0x0b230608, 0x1a3f6bee, 0x0c080708,   // de.da.no_655 de.ca.es_443  ceb.af.tl_422 it.no.sv_443
  0x530501a4, 0x0c040807, 0x19000a13, 0x53050107,   // en.fr.ht_433 no.fi.sv_432  pt.gl.un_650 en.fr.ht_432
  0x0a00072c, 0x050208a4, 0x6b020507, 0x272101ee,   // bg.mk.un_990 no.da.fr_433  fr.da.ceb_432 en.jw.gd_422
  // [5390]
  0x130f2707, 0x0b0507a4, 0x320916ee, 0x06293f02,   // gd.lv.et_432 it.fr.es_433  hr.pl.bs_422 af.sl.de_222
  0x05250d08, 0x061225a7, 0x1f012a0c, 0x10040705,   // cs.eu.fr_443 eu.hu.de_532  mt.en.cy_543 bg.ru.be_333
  0x070b2314, 0x0d052113, 0x10001113, 0x082d0207,   // ca.es.it_666 jw.fr.cs_665  ro.be.un_650 da.sk.no_432
  0x4a210d07, 0x2805010c, 0x12000c12, 0x2d210d12,   // cs.jw.yo_432 en.fr.sw_543  sv.hu.un_640 cs.jw.sk_654
  // [53a0]
  0x212d0d14, 0x55002522, 0x6b011fa9, 0x1a023f04,   // cs.sk.jw_666 eu.rw.un_870  cy.en.ceb_544 af.da.tl_332
  0x21000d08, 0x28001a22, 0x03000520, 0x0605010b,   // cs.jw.un_430 tl.sw.un_870  fr.nl.un_850 en.fr.de_542
  0x6b352112, 0x4a2d0d07, 0x13110fa4, 0x1e1c28a4,   // jw.zu.ceb_654 cs.sk.yo_432  lv.ro.et_433 sw.id.ms_433
  0x21001012, 0x2d0d4a05, 0x64351902, 0x25271204,   // lt.jw.un_640 yo.cs.sk_333  gl.zu.lg_222 hu.gd.eu_332
  // [53b0]
  0x6800211a, 0x06001122, 0x28000707, 0x12001704,   // jw.ig.un_760 ro.de.un_870  it.sw.un_420 sr.hu.un_320
  0x16001107, 0x4a21050e, 0x64014aa7, 0x052d0d60,   // ro.hr.un_420 fr.jw.yo_555  yo.en.lg_532 cs.sk.fr_664
  0x131c0912, 0x2d0d05a9, 0x27071f0c, 0x0c13045a,   // hi.mr.bh_654 fr.cs.sk_544  cy.it.gd_543 fi.et.sv_553
  0x212d0d0d, 0x2100051a, 0x4a052107, 0x25202112,   // cs.sk.jw_554 fr.jw.un_760  jw.fr.yo_432 jw.sq.eu_654
  // [53c0]
  0x17072907, 0x524a28ee, 0x28006e13, 0x211a6b12,   // sl.it.sr_432 sw.yo.ha_422  hmn.sw.un_650 ceb.tl.jw_654
  0x1e001a02, 0x4a006b04, 0x280555a0, 0x211e1804,   // tl.ms.un_220 ceb.yo.un_320  rw.fr.sw_322 ga.ms.jw_332
  0x100804a7, 0x09000508, 0x1f003f08, 0x0c53210c,   // ru.uk.be_532 fr.pl.un_430  af.cy.un_430 jw.ht.sv_543
  0x2b0e01a0, 0x55283ba0, 0x29020ea4, 0x1f001e07,   // en.is.vi_322 so.sw.rw_322  is.da.sl_433 ms.cy.un_420
  // [53d0]
  0x35016ba0, 0x522a230e, 0x0e002304, 0x1200020c,   // ceb.en.zu_322 ca.mt.ha_555  ca.is.un_320 da.hu.un_530
  0x13002905, 0x644a35ad, 0x21556407, 0x6b2135ad,   // sl.et.un_330 zu.yo.lg_643  lg.rw.jw_432 zu.jw.ceb_643
  0x3f0106a7, 0x12002908, 0x52002102, 0x13290a07,   // de.en.af_532 sl.hu.un_430  jw.ha.un_220 pt.sl.et_432
  0x31351ba4, 0x5535640c, 0x521b4aad, 0x2a000512,   // tr.zu.az_433 lg.zu.rw_543  yo.tr.ha_643 fr.mt.un_640
  // [53e0]
  0x09215509, 0x28001e0d, 0x0a081113, 0x1f005508,   // rw.jw.pl_444 ms.sw.un_540  ro.uk.mk_665 rw.cy.un_430
  0x351b1208, 0x07192b13, 0x1000522c, 0x3f030e05,   // hu.tr.zu_443 vi.gl.it_665  ha.lt.un_990 is.nl.af_333
  0x05251012, 0x521108a4, 0x4a2b0fad, 0x2d0d68a0,   // lt.eu.fr_654 no.ro.ha_433  lv.vi.yo_643 ig.cs.sk_322
  0x01002b0b, 0x64003502, 0x09001c21, 0x551228af,   // vi.en.un_520 zu.lg.un_220  mr.hi.un_860 sw.hu.rw_655
  // [53f0]
  0x0b6b0607, 0x25005213, 0x310c2aa4, 0x2d0d0fa0,   // de.ceb.es_432 ha.eu.un_650  mt.sv.az_433 lv.cs.sk_322
  0x29163207, 0x21291e04, 0x6e0752ad, 0x0a100f08,   // bs.hr.sl_432 ms.sl.jw_332  ha.it.hmn_643 lv.lt.pt_443
  0x1f07190c, 0x0d0f2dec, 0x2b00251b, 0x3500550e,   // gl.it.cy_543 sk.lv.cs_644  eu.vi.un_770 rw.zu.un_550
  0x28526e0e, 0x64281e04, 0x2b236ea9, 0x03001c02,   // hmn.ha.sw_555 ms.sw.lg_332  hmn.ca.vi_544 id.nl.un_220

  // [5400]
  0x1f002305, 0x04356807, 0x0c031311, 0x07521f08,   // ca.cy.un_330 ig.zu.fi_432  et.nl.sv_653 cy.ha.it_443
  0x12025307, 0x6e1352ec, 0x2d0d3fa4, 0x033f20ad,   // ht.da.hu_432 ha.et.hmn_644  af.cs.sk_433 sq.af.nl_643
  0x040a0f12, 0x520105a7, 0x110305a9, 0x2b041012,   // lv.pt.fi_654 fr.en.ha_532  fr.nl.ro_544 lt.fi.vi_654
  0x1e1c68a4, 0x033f0514, 0x0c3b0ea6, 0x012d05a0,   // ig.id.ms_433 fr.af.nl_666  is.so.sv_521 fr.sk.en_322
  // [5410]
  0x3f000107, 0x01000602, 0x03001e02, 0x3b002a08,   // en.af.un_420 de.en.un_220  ms.nl.un_220 mt.so.un_430
  0x10000721, 0x02063f07, 0x6b01050c, 0x2d0d0a02,   // bg.be.un_860 af.de.da_432  fr.en.ceb_543 pt.cs.sk_222
  0x19070107, 0x06192507, 0x010d050c, 0x120c08af,   // en.it.gl_432 eu.gl.de_432  fr.cs.en_543 no.sv.hu_655
  0x010305ad, 0x082d0d08, 0x04102904, 0x23001008,   // fr.nl.en_643 cs.sk.no_443  sl.lt.fi_332 lt.ca.un_430
  // [5420]
  0x2b002713, 0x23053f09, 0x11052da0, 0x060305a0,   // gd.vi.un_650 af.fr.ca_444  sk.fr.ro_322 fr.nl.de_322
  0x053f0107, 0x31001b35, 0x010607ec, 0x2d0d06ee,   // en.af.fr_432 tr.az.un_A90  it.de.en_644 de.cs.sk_422
  0x1053020c, 0x0e000c12, 0x0500110c, 0x090d2daf,   // da.ht.lt_543 sv.is.un_640  ro.fr.un_530 sk.cs.pl_655
  0x231e1ca9, 0x2b093f04, 0x08271f55, 0x552901a4,   // id.ms.ca_544 af.pl.vi_332  cy.gd.no_442 en.sl.rw_433
  // [5430]
  0x07042a07, 0x213f030c, 0x12002109, 0x00000903,   // mt.fi.it_432 nl.af.jw_543  jw.hu.un_440 pl.un.un_300
  0x0d093f07, 0x043529a0, 0x0d3f010b, 0x2b522dee,   // af.pl.cs_432 sl.zu.fi_322  en.af.cs_542 sk.ha.vi_422
  0x27011fa0, 0x0a00021a, 0x6b1c01ee, 0x04000209,   // cy.en.gd_322 da.pt.un_760  en.id.ceb_422 da.fi.un_440
  0x013f0907, 0x29002a07, 0x130420a0, 0x2d0d3fee,   // pl.af.en_432 mt.sl.un_420  sq.fi.et_322 af.cs.sk_422
  // [5440]
  0x321a16ee, 0x3f000a08, 0x2a00090d, 0x13012004,   // hr.tl.bs_422 pt.af.un_430  pl.mt.un_540 sq.en.et_332
  0x325564ee, 0x1200640c, 0x3255210c, 0x4a00040c,   // lg.rw.bs_422 lg.hu.un_530  jw.rw.bs_543 fi.yo.un_530
  0x040912a4, 0x09120da0, 0x03023f14, 0x161029ee,   // hu.pl.fi_433 cs.hu.pl_322  af.da.nl_666 sl.lt.hr_422
  0x171329ee, 0x0c2a290c, 0x64210507, 0x160d2905,   // sl.et.sr_422 sl.mt.sv_543  fr.jw.lg_432 sl.cs.hr_333
  // [5450]
  0x644a53ee, 0x0e212d04, 0x28254a11, 0x07000c04,   // ht.yo.lg_422 sk.jw.is_332  yo.eu.sw_653 sv.it.un_320
  0x28291907, 0x17002914, 0x32001220, 0x11002805,   // gl.sl.sw_432 sl.sr.un_660  hu.bs.un_850 sw.ro.un_330
  0x0802200c, 0x190b05a4, 0x04070a12, 0x1704110c,   // sq.da.no_543 fr.es.gl_433  mk.bg.ru_654 ro.ru.sr_543
  0x182d120c, 0x4a003b08, 0x17292da9, 0x680f3b0c,   // hu.sk.ga_543 so.yo.un_430  sk.sl.sr_544 so.lv.ig_543
  // [5460]
  0x0f13040c, 0x68134a0c, 0x3b1e68a4, 0x120e1809,   // fi.et.lv_543 yo.et.ig_543  ig.ms.so_433 ga.is.hu_444
  0x6b004a2b, 0x254a68a0, 0x09121808, 0x1c1f18a0,   // yo.ceb.un_980 ig.yo.eu_322  ga.hu.pl_443 ga.cy.id_322
  0x0e3f02a0, 0x684a3b0c, 0x28001c05, 0x25271c04,   // da.af.is_322 so.yo.ig_543  id.sw.un_330 id.gd.eu_332
  0x683b08a4, 0x4a003b18, 0x311b250b, 0x11090d0b,   // no.so.ig_433 so.yo.un_740  eu.tr.az_542 cs.pl.ro_542
  // [5470]
  0x55003534, 0x52006813, 0x1b1c3b0c, 0x03066402,   // zu.rw.un_A80 ig.ha.un_650  so.id.tr_543 lg.de.nl_222
  0x0d000e08, 0x3b001802, 0x27002504, 0x3b044a07,   // is.cs.un_430 ga.so.un_220  eu.gd.un_320 yo.fi.so_432
  0x28645504, 0x2813040d, 0x08021aa4, 0x2d006402,   // rw.lg.sw_332 fi.et.sw_554  tl.da.no_433 lg.sk.un_220
  0x2800040c, 0x0f3b680c, 0x256835ad, 0x02062a11,   // fi.sw.un_530 ig.so.lv_543  zu.ig.eu_643 mt.de.da_653
  // [5480]
  0x0e000702, 0x02080c07, 0x08002304, 0x1e002007,   // it.is.un_220 sv.no.da_432  ca.no.un_320 sq.ms.un_420
  0x3f032804, 0x0e0802a0, 0x1f000605, 0x1018275a,   // sw.nl.af_332 da.no.is_322  de.cy.un_330 gd.ga.lt_553
  0x12001708, 0x0e211caf, 0x273118a0, 0x1000090d,   // sr.hu.un_430 id.jw.is_655  ga.az.gd_322 pl.lt.un_540
  0x10000909, 0x13000c11, 0x113528a4, 0x11230107,   // pl.lt.un_440 sv.et.un_630  sw.zu.ro_433 en.ca.ro_432
  // [5490]
  0x0200290b, 0x1b003207, 0x050c070c, 0x2300270c,   // sl.da.un_520 bs.tr.un_420  it.sv.fr_543 gd.ca.un_530
  0x313f2008, 0x190b09a4, 0x2d0d35a9, 0x190b1a08,   // sq.af.az_443 pl.es.gl_433  zu.cs.sk_544 tl.es.gl_443
  0x1b000204, 0x121b0d0b, 0x08071014, 0x0d2512a9,   // da.tr.un_320 cs.tr.hu_542  be.bg.uk_666 hu.eu.cs_544
  0x121b1c12, 0x32161ea9, 0x2a523bee, 0x09003508,   // id.tr.hu_654 ms.hr.bs_544  so.ha.mt_422 zu.pl.un_430
  // [54a0]
  0x18002802, 0x1c1b3f07, 0x07640ea4, 0x0f001205,   // sw.ga.un_220 af.tr.id_432  is.lg.it_433 hu.lv.un_330
  0x08000a05, 0x03061804, 0x200f12a4, 0x07170411,   // mk.uk.un_330 ga.de.nl_332  hu.lv.sq_433 ru.sr.bg_653
  0x3b003513, 0x0802180c, 0x312d1b12, 0x04133b0c,   // zu.so.un_650 ga.da.no_543  tr.sk.az_654 so.et.fi_543
  0x350206a4, 0x1f00270e, 0x07002a1a, 0x250d1208,   // de.da.zu_433 gd.cy.un_550  mt.it.un_760 hu.cs.eu_443
  // [54b0]
  0x21121c12, 0x211c0908, 0x29120d0c, 0x1b121ca4,   // id.hu.jw_654 pl.id.jw_443  cs.hu.sl_543 id.hu.tr_433
  0x0d21120c, 0x0408070c, 0x29001208, 0x640752a4,   // hu.jw.cs_543 bg.uk.ru_543  hu.sl.un_430 ha.it.lg_433
  0x3b002a0c, 0x251118ec, 0x05001811, 0x231907a4,   // mt.so.un_530 ga.ro.eu_644  ga.fr.un_630 it.gl.ca_433
  0x192311a0, 0x190b2311, 0x270a1102, 0x051e2504,   // ro.ca.gl_322 ca.es.gl_653  ro.pt.gd_222 eu.ms.fr_332
  // [54c0]
  0x1000250e, 0x23001105, 0x1f112102, 0x211c1f0c,   // eu.lt.un_550 ro.ca.un_330  jw.ro.cy_222 cy.id.jw_543
  0x1b0208ee, 0x3b0b2b12, 0x18276807, 0x550105a0,   // no.da.tr_422 vi.es.so_654  ig.gd.ga_432 fr.en.rw_322
  0x12182114, 0x0b354a04, 0x01000508, 0x021f0812,   // fa.ar.ur_666 yo.zu.es_332  fr.en.un_430 no.cy.da_654
  0x1c6412ad, 0x1f0410ac, 0x6b003b12, 0x2b530107,   // hu.lg.id_643 lt.fi.cy_632  so.ceb.un_640 en.ht.vi_432
  // [54d0]
  0x1200642a, 0x6b3b2b07, 0x2b000121, 0x1b2753a0,   // lg.hu.un_970 vi.so.ceb_432  en.vi.un_860 ht.gd.tr_322
  0x53006405, 0x07110809, 0x312b6ba0, 0x6e002b12,   // lg.ht.un_330 uk.ro.bg_444  ceb.vi.az_322 vi.hmn.un_640
  0x3f352807, 0x1f080407, 0x08021f0e, 0x060501ad,   // sw.zu.af_432 fi.no.cy_432  cy.da.no_555 en.fr.de_643
  0x2b000119, 0x28315504, 0x55201105, 0x1b312bec,   // en.vi.un_750 rw.az.sw_332  ro.sq.rw_333 vi.az.tr_644
  // [54e0]
  0x100417af, 0x050129ec, 0x0e1b310c, 0x2d040d0c,   // sr.ru.be_655 sl.en.fr_644  az.tr.is_543 cs.fi.sk_543
  0x04000607, 0x5552280c, 0x12050807, 0x0e21160c,   // de.fi.un_420 sw.ha.rw_543  no.fr.hu_432 hr.jw.is_543
  0x253b5208, 0x21000908, 0x21001002, 0x35006423,   // ha.so.eu_443 pl.jw.un_430  lt.jw.un_220 lg.zu.un_880
  0x09000c09, 0x253b1ea4, 0x552d1f05, 0x6b6801a6,   // sv.pl.un_440 ms.so.eu_433  cy.sk.rw_333 en.ig.ceb_521
  // [54f0]
  0x21552811, 0x28125507, 0x02121fa0, 0x551220a0,   // sw.rw.jw_653 rw.hu.sw_432  cy.hu.da_322 sq.hu.rw_322
  0x05060112, 0x25551f0b, 0x4a643512, 0x55682d07,   // en.de.fr_654 cy.rw.eu_542  zu.lg.yo_654 sk.ig.rw_432
  0x55311ba4, 0x64311ba9, 0x31003b09, 0x21645208,   // tr.az.rw_433 tr.az.lg_544  so.az.un_440 ha.lg.jw_443
  0x120d2da4, 0x311b25ad, 0x1806010c, 0x16282909,   // sk.cs.hu_433 eu.tr.az_643  en.de.ga_543 sl.sw.hr_444
  // [5500]
  0x070410ec, 0x286b01ee, 0x642835a4, 0x09005519,   // be.ru.bg_644 en.ceb.sw_422  zu.sw.lg_433 rw.pl.un_750
  0x282a64af, 0x552d12a4, 0x111b3108, 0x68554a12,   // lg.mt.sw_655 hu.sk.rw_433  az.tr.ro_443 yo.rw.ig_654
  0x2812290c, 0x0c000e0c, 0x170a100c, 0x13000934,   // sl.hu.sw_543 is.sv.un_530  be.mk.sr_543 hi.bh.un_A80
  0x55002021, 0x10080a05, 0x1f00020d, 0x07040aaf,   // sq.rw.un_860 mk.uk.be_333  da.cy.un_540 mk.ru.bg_655
  // [5510]
  0x07000604, 0x12001a04, 0x531b2109, 0x230306a7,   // de.it.un_320 tl.hu.un_320  jw.tr.ht_444 de.nl.ca_532
  0x531b13a4, 0x16643204, 0x0d000922, 0x19250ba4,   // et.tr.ht_433 bs.lg.hr_332  hi.ne.un_870 es.eu.gl_433
  0x644a6812, 0x0c000e21, 0x0f0e0107, 0x3f095311,   // ig.yo.lg_654 is.sv.un_860  en.is.lv_432 ht.pl.af_653
  0x0e0301a9, 0x2d290d12, 0x3f010f05, 0x29000508,   // en.nl.is_544 cs.sl.sk_654  lv.en.af_333 fr.sl.un_430
  // [5520]
  0x02000312, 0x64002a14, 0x021a1ca0, 0x0e0901a0,   // nl.da.un_640 mt.lg.un_660  id.tl.da_322 en.pl.is_322
  0x0b1c21a0, 0x01003102, 0x0800210b, 0x311a1bec,   // jw.id.es_322 az.en.un_220  jw.no.un_520 tr.tl.az_644
  0x031b29ee, 0x1f3b030c, 0x1e1c68ec, 0x19080307,   // sl.tr.nl_422 nl.so.cy_543  ig.id.ms_644 nl.no.gl_432
  0x0f1064ad, 0x16000b04, 0x29642109, 0x25060107,   // lg.lt.lv_643 es.hr.un_320  jw.lg.sl_444 en.de.eu_432
  // [5530]
  0x03000607, 0x2a310f04, 0x1a6e64a7, 0x0d021304,   // de.nl.un_420 lv.az.mt_332  lg.hmn.tl_532 et.da.cs_332
  0x03080202, 0x08000e08, 0x27023fad, 0x03063fa0,   // da.no.nl_222 is.no.un_430  af.da.gd_643 af.de.nl_322
  0x020328a0, 0x10002d1b, 0x12042007, 0x32162105,   // sw.nl.da_322 sk.lt.un_770  sq.fi.hu_432 jw.hr.bs_333
  0x190b03a0, 0x0f000412, 0x050f010c, 0x3216070c,   // nl.es.gl_322 fi.lv.un_640  en.lv.fr_543 it.hr.bs_543
  // [5540]
  0x5300250e, 0x070410ee, 0x3b3f03a7, 0x02010807,   // eu.ht.un_550 be.ru.bg_422  nl.af.so_532 no.en.da_432
  0x07080411, 0x2b00280d, 0x07002104, 0x071a3b04,   // ru.uk.bg_653 sw.vi.un_540  jw.it.un_320 so.tl.it_332
  0x190b1a0c, 0x080212a4, 0x27000b04, 0x5528090c,   // tl.es.gl_543 hu.da.no_433  es.gd.un_320 pl.sw.rw_543
  0x041007a4, 0x07230b08, 0x1b3125ad, 0x3b006412,   // bg.be.ru_433 es.ca.it_443  eu.az.tr_643 lg.so.un_640
  // [5550]
  0x100408ad, 0x113507a7, 0x072a0c04, 0x3f1e1c04,   // uk.ru.be_643 it.zu.ro_532  sv.mt.it_332 id.ms.af_332
  0x4a00640e, 0x1a000707, 0x12005204, 0x04000a18,   // lg.yo.un_550 it.tl.un_420  ha.hu.un_320 mk.ru.un_740
  0x182811ec, 0x1100071a, 0x5228350c, 0x042910a9,   // ro.sw.ga_644 bg.ro.un_760  zu.sw.ha_543 lt.sl.fi_544
  0x070123a4, 0x27002808, 0x1700100c, 0x52252312,   // ca.en.it_433 sw.gd.un_430  lt.sr.un_530 ca.eu.ha_654
  // [5560]
  0x252818a4, 0x04215208, 0x05000708, 0x0f5204ac,   // ga.sw.eu_433 ha.jw.fi_443  it.fr.un_430 fi.ha.lv_632
  0x2a101708, 0x10070a08, 0x080410a9, 0x52060a04,   // sr.lt.mt_443 mk.bg.be_443  be.ru.uk_544 pt.de.ha_332
  0x2a001802, 0x23000f1a, 0x23005219, 0x11001813,   // ga.mt.un_220 lv.ca.un_760  ha.ca.un_750 ga.ro.un_650
  0x23053fee, 0x0e11250c, 0x0821520c, 0x18102704,   // af.fr.ca_422 eu.ro.is_543  ha.jw.no_543 gd.lt.ga_332
  // [5570]
  0x52002514, 0x272a01a0, 0x2a1710ad, 0x172a10ac,   // eu.ha.un_660 en.mt.gd_322  lt.sr.mt_643 lt.mt.sr_632
  0x170410ac, 0x08003f04, 0x251c28ee, 0x04001023,   // lt.fi.sr_632 af.no.un_320  sw.id.eu_422 be.ru.un_880
  0x3b4a6ba9, 0x190701ee, 0x2a100f60, 0x072a1fad,   // ceb.yo.so_544 en.it.gl_422  lv.lt.mt_664 cy.mt.it_643
  0x12080205, 0x52006419, 0x09062dad, 0x521855a4,   // da.no.hu_333 lg.ha.un_750  sk.de.pl_643 rw.ga.ha_433
  // [5580]
  0x102501a0, 0x210302ee, 0x55001e04, 0x3b002a09,   // en.eu.lt_322 da.nl.jw_422  ms.rw.un_320 mt.so.un_440
  0x554a0508, 0x64550807, 0x236b5302, 0x1c356407,   // fr.yo.rw_443 no.rw.lg_432  ht.ceb.ca_222 lg.zu.id_432
  0x6b2511af, 0x200353a0, 0x130c0fec, 0x2a52130c,   // ro.eu.ceb_655 ht.nl.sq_322  lv.sv.et_644 et.ha.mt_543
  0x12020807, 0x1a00531a, 0x3f3b1aad, 0x060c0112,   // no.da.hu_432 ht.tl.un_760  tl.so.af_643 en.sv.de_654
  // [5590]
  0x1a005307, 0x01003b13, 0x283f5314, 0x190b2302,   // ht.tl.un_420 so.en.un_650  ht.af.sw_666 ca.es.gl_222
  0x28006422, 0x1a002d22, 0x033f3bad, 0x272b3bad,   // lg.sw.un_870 sk.tl.un_870  so.af.nl_643 so.vi.gd_643
  0x17070aec, 0x4a00642b, 0x4a000107, 0x254a6808,   // mk.bg.sr_644 lg.yo.un_980  en.yo.un_420 ig.yo.eu_443
  0x0200082a, 0x4a64555a, 0x282764ad, 0x070a1009,   // no.da.un_970 rw.lg.yo_553  lg.gd.sw_643 be.mk.bg_444
  // [55a0]
  0x68005529, 0x2029120c, 0x11061213, 0x1a356407,   // rw.ig.un_960 hu.sl.sq_543  hu.de.ro_665 lg.zu.tl_432
  0x230668af, 0x18092da0, 0x170708af, 0x190b11a4,   // ig.de.ca_655 sk.pl.ga_322  uk.bg.sr_655 ro.es.gl_433
  0x53001213, 0x25001f09, 0x01003b0e, 0x0e311b05,   // hu.ht.un_650 cy.eu.un_440  so.en.un_550 tr.az.is_333
  0x01311b09, 0x0b310ea4, 0x042013ad, 0x68000808,   // tr.az.en_444 is.az.es_433  et.sq.fi_643 no.ig.un_430
  // [55b0]
  0x1b253108, 0x02005307, 0x0e000b04, 0x20292d11,   // az.eu.tr_443 ht.da.un_420  es.is.un_320 sk.sl.sq_653
  0x12030811, 0x0b0e3108, 0x20000704, 0x050106a4,   // no.nl.hu_653 az.is.es_443  it.sq.un_320 de.en.fr_433
  0x170f2da0, 0x181f01a4, 0x523555a4, 0x0b003105,   // sk.lv.sr_322 en.cy.ga_433  rw.zu.ha_433 az.es.un_330
  0x07190b05, 0x0c00120c, 0x0b311b12, 0x6b000612,   // es.gl.it_333 hu.sv.un_530  tr.az.es_654 de.ceb.un_640
  // [55c0]
  0x0212060c, 0x1e311b12, 0x0a006805, 0x0b311b0c,   // de.hu.da_543 tr.az.ms_654  ig.pt.un_330 tr.az.es_543
  0x310b1b07, 0x1e1c20ee, 0x0c1a35ee, 0x356b1a08,   // tr.es.az_432 sq.id.ms_422  zu.tl.sv_422 tl.ceb.zu_443
  0x283152a0, 0x3f1b35a0, 0x31001a04, 0x64555307,   // ha.az.sw_322 zu.tr.af_322  tl.az.un_320 ht.rw.lg_432
  0x04001133, 0x043513a9, 0x040710a7, 0x07081013,   // ro.ru.un_A70 et.zu.fi_544  be.bg.ru_532 be.uk.bg_665
  // [55d0]
  0x070a11ad, 0x1a000c05, 0x1c1e1307, 0x3f005204,   // ro.mk.bg_643 sv.tl.un_330  et.ms.id_432 ha.af.un_320
  0x6b1f3f11, 0x3b033fa4, 0x03000113, 0x16000307,   // af.cy.ceb_653 af.nl.so_433  en.nl.un_650 nl.hr.un_420
  0x554a68ee, 0x3f1c55ee, 0x171a250c, 0x5510290c,   // ig.yo.rw_422 rw.id.af_422  eu.tl.sr_543 sl.lt.rw_543
  0x100811a0, 0x1e521c12, 0x040a11a7, 0x1a25350c,   // ro.uk.be_322 id.ha.ms_654  ro.mk.ru_532 zu.eu.tl_543
  // [55e0]
  0x55351a12, 0x2d001113, 0x531f520d, 0x3f001a04,   // tl.zu.rw_654 ro.sk.un_650  ha.cy.ht_554 tl.af.un_320
  0x254a28a0, 0x12004a0e, 0x35281c08, 0x120519a0,   // sw.yo.eu_322 yo.hu.un_550  id.sw.zu_443 gl.fr.hu_322
  0x060c0204, 0x1a00640d, 0x1e681ca9, 0x23000608,   // da.sv.de_332 lg.tl.un_540  id.ig.ms_544 de.ca.un_430
  0x28646804, 0x53002309, 0x2352090c, 0x28001f1a,   // ig.lg.sw_332 ca.ht.un_440  pl.ha.ca_543 cy.sw.un_760
  // [55f0]
  0x284a6407, 0x09003b0d, 0x35005511, 0x253b10a4,   // lg.yo.sw_432 so.pl.un_540  rw.zu.un_630 lt.so.eu_433
  0x4a645507, 0x32000605, 0x2d000704, 0x0a000423,   // rw.lg.yo_432 de.bs.un_330  it.sk.un_320 ru.mk.un_880
  0x061b2a05, 0x233f0504, 0x1f121809, 0x03200b14,   // mt.tr.de_333 fr.af.ca_332  ga.hu.cy_444 es.sq.nl_666
  0x4a6452ad, 0x0923110c, 0x28532111, 0x2d0d12b3,   // ha.lg.yo_643 ro.ca.pl_543  jw.ht.sw_653 hu.cs.sk_743
  // [5600]
  0x08005312, 0x040710a9, 0x13001c02, 0x3555280b,   // ht.no.un_640 be.bg.ru_544  id.et.un_220 sw.rw.zu_542
  0x6b1e1c08, 0x35002102, 0x68000107, 0x3b1e1c08,   // id.ms.ceb_443 jw.zu.un_220  en.ig.un_420 id.ms.so_443
  0x121e3bad, 0x16173207, 0x0e4a1255, 0x251e1c5a,   // so.ms.hu_643 bs.sr.hr_432  hu.yo.is_442 id.ms.eu_553
  0x12004a2b, 0x060107a4, 0x18004a2c, 0x2d1a21ee,   // yo.hu.un_980 it.en.de_433  yo.ga.un_990 jw.tl.sk_422
  // [5610]
  0x6b2a1eee, 0x320a0f5a, 0x0400290e, 0x2b00182c,   // ms.mt.ceb_422 lv.pt.bs_553  sl.fi.un_550 ga.vi.un_990
  0x530b120c, 0x25003b21, 0x04100713, 0x171329a0,   // hu.es.ht_543 so.eu.un_860  bg.be.ru_665 sl.et.sr_322
  0x1e215202, 0x2319010b, 0x1c003b07, 0x3b1e1c5a,   // ha.jw.ms_222 en.gl.ca_542  so.id.un_420 id.ms.so_553
  0x211f3f0c, 0x00002b37, 0x18004a1b, 0x06053f05,   // af.cy.jw_543 vi.un.un_B00  yo.ga.un_770 af.fr.de_333
  // [5620]
  0x131c090d, 0x1c253bec, 0x1b2129ee, 0x01115308,   // hi.mr.bh_554 so.eu.id_644  sl.jw.tr_422 ht.ro.en_443
  0x0f0501a4, 0x041029a4, 0x18004a1a, 0x4a190a13,   // en.fr.lv_433 sl.lt.fi_433  yo.ga.un_760 pt.gl.yo_665
  0x0a004a14, 0x3f00010c, 0x25293b07, 0x04171012,   // yo.pt.un_660 en.af.un_530  so.sl.eu_432 be.sr.ru_654
  0x17291bad, 0x3b1c2905, 0x253521a6, 0x04170aa9,   // tr.sl.sr_643 sl.id.so_333  jw.zu.eu_521 mk.sr.ru_544
  // [5630]
  0x2504290c, 0x29232aa0, 0x2a002309, 0x0817110e,   // sl.fi.eu_543 mt.ca.sl_322  ca.mt.un_440 ro.sr.uk_555
  0x2d040d04, 0x12000508, 0x203528ec, 0x04132dee,   // cs.fi.sk_332 fr.hu.un_430  sw.zu.sq_644 sk.et.fi_422
  0x136404ad, 0x131011a0, 0x28006404, 0x05640ca0,   // fi.lg.et_643 ro.lt.et_322  lg.sw.un_320 sv.lg.fr_322
  0x64000f0c, 0x13321704, 0x0c2a0407, 0x0a054a07,   // lv.lg.un_530 sr.bs.et_332  fi.mt.sv_432 yo.fr.pt_432
  // [5640]
  0x20082304, 0x2d2904af, 0x190b25a0, 0x291c1bee,   // ca.no.sq_332 fi.sl.sk_655  eu.es.gl_322 tr.id.sl_422
  0x04000d12, 0x080e5207, 0x3200200d, 0x0f001308,   // cs.fi.un_640 ha.is.no_432  sq.bs.un_540 et.lv.un_430
  0x52351107, 0x09000c1a, 0x31001b18, 0x321710a9,   // ro.zu.ha_432 sv.pl.un_760  tr.az.un_740 lt.sr.bs_544
  0x2d0f0504, 0x040f10ad, 0x100f1ba6, 0x131b28a7,   // fr.lv.sk_332 lt.lv.fi_643  tr.lv.lt_521 sw.tr.et_532
  // [5650]
  0x28214a0c, 0x190b2310, 0x1e1c31a4, 0x310e09ad,   // yo.jw.sw_543 ca.es.gl_642  az.id.ms_433 pl.is.az_643
  0x02000c14, 0x10311ba0, 0x53001b04, 0x2d1b310d,   // sv.da.un_660 tr.az.lt_322  tr.ht.un_320 az.tr.sk_554
  0x28003514, 0x31205202, 0x0e001604, 0x101b52a4,   // zu.sw.un_660 ha.sq.az_222  hr.is.un_320 ha.tr.lt_433
  0x160c12ee, 0x080c21a0, 0x2a083b13, 0x10311308,   // hu.sv.hr_422 jw.sv.no_322  so.no.mt_665 et.az.lt_443
  // [5660]
  0x130d090d, 0x13001a0d, 0x090e29a4, 0x53041055,   // hi.ne.bh_554 tl.et.un_540  sl.is.pl_433 lt.fi.ht_442
  0x07112507, 0x016b04ee, 0x09000302, 0x04101ca0,   // eu.ro.it_432 fi.ceb.en_422  nl.pl.un_220 id.lt.fi_322
  0x211b04a4, 0x351008a9, 0x1a046b07, 0x642035ad,   // fi.tr.jw_433 no.lt.zu_544  ceb.fi.tl_432 zu.sq.lg_643
  0x083528a4, 0x1b001707, 0x321710b3, 0x13093b02,   // sw.zu.no_433 sr.tr.un_420  lt.sr.bs_743 so.pl.et_222
  // [5670]
  0x321735ee, 0x1a093b07, 0x160c320c, 0x2a3b3112,   // zu.sr.bs_422 so.pl.tl_432  bs.sv.hr_543 az.so.mt_654
  0x0d3b1e07, 0x01001e04, 0x3b351aa0, 0x3217530c,   // ms.so.cs_432 ms.en.un_320  tl.zu.so_322 ht.sr.bs_543
  0x12003b1a, 0x10041baf, 0x551b6ea0, 0x3f2703a0,   // so.hu.un_760 tr.fi.lt_655  hmn.tr.rw_322 nl.gd.af_322
  0x0e1a0b0c, 0x11001c07, 0x10530dad, 0x09171604,   // es.tl.is_543 id.ro.un_420  cs.ht.lt_643 hr.sr.pl_332
  // [5680]
  0x033f3555, 0x13005302, 0x1a10120c, 0x02522109,   // zu.af.nl_442 ht.et.un_220  hu.lt.tl_543 jw.ha.da_444
  0x1b313ba6, 0x13091c07, 0x230b01a9, 0x64003f0c,   // so.az.tr_521 mr.hi.bh_432  en.es.ca_544 af.lg.un_530
  0x1a00121a, 0x31103f04, 0x071008a7, 0x03273fa7,   // hu.tl.un_760 af.lt.az_332  uk.be.bg_532 af.gd.nl_532
  0x02103fec, 0x64033fa0, 0x0d32170d, 0x3f00101a,   // af.lt.da_644 af.nl.lg_322  sr.bs.cs_554 lt.af.un_760
  // [5690]
  0x0f00292b, 0x130111a4, 0x2900090c, 0x230b0705,   // sl.lv.un_980 ro.en.et_433  pl.sl.un_530 it.es.ca_333
  0x05533bee, 0x17002d07, 0x1b553107, 0x09270607,   // so.ht.fr_422 sk.sr.un_420  az.rw.tr_432 de.gd.pl_432
  0x04112a0c, 0x0a6b2a07, 0x1004120e, 0x6e000d09,   // mt.ro.fi_543 mt.ceb.pt_432  hu.fi.lt_555 cs.hmn.un_440
  0x11000a17, 0x100804ee, 0x033f2360, 0x310804ad,   // pt.ro.un_730 fi.no.lt_422  ca.af.nl_664 fi.no.az_643
  // [56a0]
  0x13000e09, 0x13000e05, 0x0c000307, 0x110464a0,   // is.et.un_440 is.et.un_330  nl.sv.un_420 lg.fi.ro_322
  0x17321008, 0x29002d19, 0x12256404, 0x311f1907,   // lt.bs.sr_443 sk.sl.un_750  lg.eu.hu_332 gl.cy.az_432
  0x180601ad, 0x0c3f64ec, 0x64252305, 0x07040aac,   // en.de.ga_643 lg.af.sv_644  ca.eu.lg_333 mk.ru.bg_632
  0x52643b12, 0x0c006412, 0x12006b07, 0x3b011f0c,   // so.lg.ha_654 lg.sv.un_640  ceb.hu.un_420 cy.en.so_543
  // [56b0]
  0x19005504, 0x3f3b52a0, 0x29000e08, 0x0a3b1907,   // rw.gl.un_320 ha.so.af_322  is.sl.un_430 gl.so.pt_432
  0x5301055a, 0x2b010304, 0x011325ee, 0x100453ad,   // fr.en.ht_553 nl.en.vi_332  eu.et.en_422 ht.fi.lt_643
  0x25191f04, 0x55202112, 0x1e1c52a4, 0x096468ac,   // cy.gl.eu_332 jw.sq.rw_654  ha.id.ms_433 ig.lg.pl_632
  0x52001904, 0x352813a7, 0x04003511, 0x2100080d,   // gl.ha.un_320 et.sw.zu_532  zu.fi.un_630 no.jw.un_540
  // [56c0]
  0x2500351b, 0x011f0ea0, 0x320c25a4, 0x2a1320a9,   // zu.eu.un_770 is.cy.en_322  eu.sv.bs_433 sq.et.mt_544
  0x130435ee, 0x2a00251b, 0x1b1a6bad, 0x102a3b11,   // zu.fi.et_422 eu.mt.un_770  ceb.tl.tr_643 so.mt.lt_653
  0x09000e0d, 0x0e0c2511, 0x52006412, 0x13552805,   // is.pl.un_540 eu.sv.is_653  lg.ha.un_640 sw.rw.et_333
  0x09000f09, 0x2a272504, 0x04092804, 0x1b2535a7,   // lv.pl.un_440 eu.gd.mt_332  sw.pl.fi_332 zu.eu.tr_532
  // [56d0]
  0x1a086ba7, 0x0825010b, 0x32170907, 0x3f016e07,   // ceb.no.tl_532 en.eu.no_542  pl.sr.bs_432 hmn.en.af_432
  0x25003f02, 0x04000f1b, 0x070a25ad, 0x53093508,   // af.eu.un_220 lv.fi.un_770  eu.pt.it_643 zu.pl.ht_443
  0x20006b04, 0x681c27ac, 0x0d091f07, 0x32175305,   // ceb.sq.un_320 gd.id.ig_632  cy.pl.cs_432 ht.sr.bs_333
  0x0c1c21ee, 0x3f1b25ec, 0x1e1c2a0c, 0x08132907,   // jw.id.sv_422 eu.tr.af_644  mt.id.ms_543 sl.et.no_432
  // [56e0]
  0x0453350c, 0x1a215304, 0x12001312, 0x13530eee,   // zu.ht.fi_543 ht.jw.tl_332  et.hu.un_640 is.ht.et_422
  0x52310507, 0x53000513, 0x28171112, 0x3b530ba0,   // fr.az.ha_432 fr.ht.un_650  ro.sr.sw_654 es.ht.so_322
  0x11002a1b, 0x073b0b09, 0x1012130c, 0x06001312,   // mt.ro.un_770 es.so.it_444  et.hu.lt_543 et.de.un_640
  0x20315302, 0x182527ec, 0x3b0b0704, 0x13001212,   // ht.az.sq_222 gd.eu.ga_644  it.es.so_332 hu.et.un_640
  // [56f0]
  0x09006e11, 0x053f0e04, 0x1b1a53a4, 0x02091f13,   // hmn.pl.un_630 is.af.fr_332  ht.tl.tr_433 cy.pl.da_665
  0x1a211e07, 0x091a6b04, 0x040817ee, 0x20000c05,   // ms.jw.tl_432 ceb.tl.pl_332  sr.uk.ru_422 sv.sq.un_330
  0x12000809, 0x29321702, 0x12080208, 0x045305ee,   // no.hu.un_440 sr.bs.sl_222  da.no.hu_443 fr.ht.fi_422
  0x1b321307, 0x05530d0c, 0x291208ee, 0x2d00090d,   // et.bs.tr_432 cs.ht.fr_543  no.hu.sl_422 pl.sk.un_540
  // [5700]
  0x4a006820, 0x523b1b07, 0x4a096407, 0x29002304,   // ig.yo.un_850 tr.so.ha_432  lg.pl.yo_432 ca.sl.un_320
  0x35005302, 0x355564a4, 0x521b64a0, 0x0c0302a0,   // ht.zu.un_220 lg.rw.zu_433  lg.tr.ha_322 da.nl.sv_322
  0x0464685a, 0x1b00520d, 0x64003505, 0x1200640e,   // ig.lg.fi_553 ha.tr.un_540  zu.lg.un_330 lg.hu.un_550
  0x091f020c, 0x1a052307, 0x3b6453ec, 0x5352640e,   // da.cy.pl_543 ca.fr.tl_432  ht.lg.so_644 lg.ha.ht_555
  // [5710]
  0x05642308, 0x643552a7, 0x1b3555ec, 0x060e27a9,   // ca.lg.fr_443 ha.zu.lg_532  rw.zu.tr_644 gd.is.de_544
  0x64355212, 0x4a122d5a, 0x162d2908, 0x232b0555,   // ha.zu.lg_654 sk.hu.yo_553  sl.sk.hr_443 fr.vi.ca_442
  0x52533bad, 0x533b01a4, 0x21525513, 0x08070412,   // so.ht.ha_643 en.so.ht_433  rw.ha.jw_665 ru.bg.uk_654
  0x0b0a230c, 0x0c550604, 0x55643513, 0x1b5264a4,   // ca.pt.es_543 de.rw.sv_332  zu.lg.rw_665 lg.ha.tr_433
  // [5720]
  0x5200551a, 0x070a11ac, 0x556452a4, 0x352128a0,   // rw.ha.un_760 ro.mk.bg_632  ha.lg.rw_433 sw.jw.zu_322
  0x0c311307, 0x2b000a09, 0x0a002b04, 0x0b002321,   // et.az.sv_432 pt.vi.un_440  vi.pt.un_320 ca.es.un_860
  0x09011fac, 0x081b3105, 0x0810020c, 0x02033f60,   // cy.en.pl_632 az.tr.no_333  da.lt.no_543 af.nl.da_664
  0x10080260, 0x03070ca0, 0x0f002d13, 0x28002d12,   // da.no.lt_664 sv.it.nl_322  sk.lv.un_650 sk.sw.un_640
  // [5730]
  0x3f02080b, 0x1f0c06a4, 0x0c060ea4, 0x0a002b0b,   // no.da.af_542 de.sv.cy_433  is.de.sv_433 vi.pt.un_520
  0x0a002b0c, 0x21005321, 0x0a081005, 0x684a315a,   // vi.pt.un_530 ht.jw.un_860  be.uk.mk_333 az.yo.ig_553
  0x0d2d09a4, 0x060c0e14, 0x1c2055a7, 0x20000607,   // pl.sk.cs_433 is.sv.de_666  rw.sq.id_532 de.sq.un_420
  0x011f0c08, 0x1e1c0d0c, 0x53002114, 0x090b1907,   // sv.cy.en_443 cs.id.ms_543  jw.ht.un_660 gl.es.pl_432
  // [5740]
  0x0700231d, 0x3b2b01ee, 0x08023faf, 0x4a3b1304,   // ca.it.un_820 en.vi.so_422  af.da.no_655 et.so.yo_332
  0x64001f14, 0x681a20ee, 0x2d006b07, 0x2a002b04,   // cy.lg.un_660 sq.tl.ig_422  ceb.sk.un_420 vi.mt.un_320
  0x0c000e09, 0x09000a0c, 0x29000d0d, 0x3f130e0c,   // is.sv.un_440 pt.pl.un_530  cs.sl.un_540 is.et.af_543
  0x35311b12, 0x07000507, 0x31211b07, 0x53002120,   // tr.az.zu_654 fr.it.un_420  tr.jw.az_432 jw.ht.un_850
  // [5750]
  0x0b000509, 0x06003519, 0x5321230e, 0x170d2d0b,   // fr.es.un_440 zu.de.un_750  ca.jw.ht_555 sk.cs.sr_542
  0x23001c04, 0x0b0a2002, 0x23002113, 0x352d530e,   // id.ca.un_320 sq.pt.es_222  jw.ca.un_650 ht.sk.zu_555
  0x05060fa0, 0x0e0c02a0, 0x1c0221a0, 0x2800680b,   // lv.de.fr_322 da.sv.is_322  jw.da.id_322 ig.sw.un_520
  0x100923a7, 0x28001814, 0x3f001b09, 0x2d002a05,   // ca.pl.lt_532 ga.sw.un_660  tr.af.un_440 mt.sk.un_330
  // [5760]
  0x230b3107, 0x0700060c, 0x68090107, 0x0c3201a4,   // az.es.ca_432 de.it.un_530  en.pl.ig_432 en.bs.sv_433
  0x04002712, 0x6e6b01ad, 0x10041702, 0x0c291704,   // gd.fi.un_640 en.ceb.hmn_643  sr.ru.be_222 sr.sl.sv_332
  0x20001104, 0x290a1b07, 0x112b0107, 0x27000807,   // ro.sq.un_320 tr.pt.sl_432  en.vi.ro_432 no.gd.un_420
  0x0a000409, 0x0a192107, 0x17100a05, 0x1b001e13,   // fi.pt.un_440 jw.gl.pt_432  mk.be.sr_333 ms.tr.un_650
  // [5770]
  0x13311b0c, 0x04122907, 0x0c080e11, 0x02232a55,   // tr.az.et_543 sl.hu.fi_432  is.no.sv_653 mt.ca.da_442
  0x2d291104, 0x02080c55, 0x0100280d, 0x321704ec,   // ro.sl.sk_332 sv.no.da_442  sw.en.un_540 fi.sr.bs_644
  0x072d010c, 0x08000714, 0x0700190e, 0x1713040b,   // en.sk.it_543 bg.uk.un_660  gl.it.un_550 fi.et.sr_542
  0x286b01a6, 0x01276ba0, 0x0b0f20ad, 0x04001805,   // en.ceb.sw_521 ceb.gd.en_322  sq.lv.es_643 ga.fi.un_330
  // [5780]
  0x072319a0, 0x10070805, 0x0a040812, 0x0c003f0d,   // gl.ca.it_322 uk.bg.be_333  uk.ru.mk_654 af.sv.un_540
  0x3500641a, 0x02033fa0, 0x070b3504, 0x07004a02,   // lg.zu.un_760 af.nl.da_322  zu.es.it_332 yo.it.un_220
  0x4a6407ee, 0x0a001011, 0x0900120c, 0x041e12ad,   // it.lg.yo_422 be.mk.un_630  hu.pl.un_530 hu.ms.fi_643
  0x041e1c13, 0x0d001c22, 0x3b2035a0, 0x1609295a,   // id.ms.fi_665 mr.ne.un_870  zu.sq.so_322 sl.pl.hr_553
  // [5790]
  0x00002037, 0x0f000319, 0x19350711, 0x03002d14,   // sq.un.un_B00 nl.lv.un_750  it.zu.gl_653 sk.nl.un_660
  0x641e1c55, 0x0f3f0307, 0x29210705, 0x3b3135a9,   // id.ms.lg_442 nl.af.lv_432  it.jw.sl_333 zu.az.so_544
  0x1a2107ee, 0x03013fa9, 0x35003b04, 0x1c052b02,   // it.jw.tl_422 af.en.nl_544  so.zu.un_320 vi.fr.id_222
  0x062a07a4, 0x04001209, 0x110407ad, 0x08000218,   // it.mt.de_433 hu.fi.un_440  bg.ru.ro_643 da.no.un_740
  // [57a0]
  0x07190ba7, 0x29000f1a, 0x00002042, 0x0a001008,   // es.gl.it_532 lv.sl.un_760  sq.un.un_C00 be.mk.un_430
  0x10000a0d, 0x53110507, 0x063f0111, 0x200d04af,   // mk.be.un_540 fr.ro.ht_432  en.af.de_653 fi.cs.sq_655
  0x04001e13, 0x0c080eaf, 0x642d0d04, 0x1e1c0d09,   // ms.fi.un_650 is.no.sv_655  cs.sk.lg_332 cs.id.ms_444
  0x175307a7, 0x311b1e09, 0x2d2a0dee, 0x1f0e0c55,   // it.ht.sr_532 ms.tr.az_444  cs.mt.sk_422 sv.is.cy_442
  // [57b0]
  0x2b002702, 0x32001108, 0x2d001108, 0x022d1e07,   // gd.vi.un_220 ro.bs.un_430  ro.sk.un_430 ms.sk.da_432
  0x20000e13, 0x23310511, 0x1300290d, 0x29002d0e,   // is.sq.un_650 fr.az.ca_653  sl.et.un_540 sk.sl.un_550
  0x522d0d04, 0x0f1025ad, 0x29322da4, 0x0e100f07,   // cs.sk.ha_332 eu.lt.lv_643  sk.bs.sl_433 lv.lt.is_432
  0x0c000f09, 0x201b1ea4, 0x02001804, 0x2d0d01ee,   // lv.sv.un_440 ms.tr.sq_433  ga.da.un_320 en.cs.sk_422
  // [57c0]
  0x0a08170d, 0x3500210d, 0x25072307, 0x10121b08,   // sr.uk.mk_554 jw.zu.un_540  ca.it.eu_432 tr.hu.lt_443
  0x060727a0, 0x64551ba4, 0x6e003519, 0x270612a0,   // gd.it.de_322 tr.rw.lg_433  zu.hmn.un_750 hu.de.gd_322
  0x1e001c34, 0x18270aa9, 0x031827af, 0x2b210605,   // id.ms.un_A80 pt.gd.ga_544  gd.ga.nl_655 de.jw.vi_333
  0x06006404, 0x250703a0, 0x1304280d, 0x64001f22,   // lg.de.un_320 nl.it.eu_322  sw.fi.et_554 cy.lg.un_870
  // [57d0]
  0x1e1801a0, 0x201b4a07, 0x215520ad, 0x0a075505,   // en.ga.ms_322 yo.tr.sq_432  sq.rw.jw_643 rw.it.pt_333
  0x06080255, 0x05003b0d, 0x23000522, 0x08001104,   // da.no.de_442 so.fr.un_540  fr.ca.un_870 ro.uk.un_320
  0x552305a7, 0x251b68af, 0x18006e0e, 0x272b180c,   // fr.ca.rw_532 ig.tr.eu_655  hmn.ga.un_550 ga.vi.gd_543
  0x16000f12, 0x3b005505, 0x3200641a, 0x09006b04,   // lv.hr.un_640 rw.so.un_330  lg.bs.un_760 ceb.pl.un_320
  // [57e0]
  0x2a000913, 0x09251c05, 0x27091808, 0x060e08ee,   // pl.mt.un_650 id.eu.pl_333  ga.pl.gd_443 no.is.de_422
  0x4a1f27ee, 0x1f00180d, 0x4a6435ee, 0x211c4aa0,   // gd.cy.yo_422 ga.cy.un_540  zu.lg.yo_422 yo.id.jw_322
  0x351827a7, 0x283509ac, 0x0c684aa0, 0x0c0e08af,   // gd.ga.zu_532 pl.zu.sw_632  yo.ig.sv_322 no.is.sv_655
  0x32020807, 0x03083fad, 0x4a291009, 0x0c001b0b,   // no.da.bs_432 af.no.nl_643  lt.sl.yo_444 tr.sv.un_520
  // [57f0]
  0x290d100e, 0x106b1b07, 0x0600040e, 0x31251e0c,   // lt.cs.sl_555 tr.ceb.lt_432  fi.de.un_550 ms.eu.az_543
  0x28001902, 0x10081ba0, 0x1e122512, 0x0c002d05,   // gl.sw.un_220 tr.no.lt_322  eu.hu.ms_654 sk.sv.un_330
  0x32170da4, 0x640328a7, 0x20212509, 0x1e251c0c,   // cs.sr.bs_433 sw.nl.lg_532  eu.jw.sq_444 id.eu.ms_543
  0x28001702, 0x1c2129a7, 0x2500210d, 0x0a070409,   // sr.sw.un_220 sl.jw.id_532  jw.eu.un_540 ru.bg.mk_444

  // [5800]
  0x091004ee, 0x21001b2b, 0x530409ee, 0x25000608,   // fi.lt.pl_422 tr.jw.un_980  pl.fi.ht_422 de.eu.un_430
  0x0400090e, 0x1b001f07, 0x0400280b, 0x25000612,   // pl.fi.un_550 cy.tr.un_420  sw.fi.un_520 de.eu.un_640
  0x100c1bee, 0x16000104, 0x211e1aa9, 0x17251c0c,   // tr.sv.lt_422 en.hr.un_320  tl.ms.jw_544 id.eu.sr_543
  0x17110a14, 0x28000c0e, 0x20001704, 0x251b1ea9,   // mk.ro.sr_666 sv.sw.un_550  sr.sq.un_320 ms.tr.eu_544
  // [5810]
  0x09292da4, 0x1b000c1b, 0x2100122c, 0x6804080c,   // sk.sl.pl_433 sv.tr.un_770  ur.fa.un_990 no.fi.ig_543
  0x283b64a0, 0x190a11a9, 0x04000914, 0x0600250c,   // lg.so.sw_322 ro.pt.gl_544  pl.fi.un_660 eu.de.un_530
  0x28100612, 0x081c21a0, 0x07000807, 0x0e2d0d0d,   // de.lt.sw_654 jw.id.no_322  no.it.un_420 cs.sk.is_554
  0x52002a04, 0x071017a7, 0x13001f04, 0x0b000f07,   // mt.ha.un_320 sr.be.bg_532  cy.et.un_320 lv.es.un_420
  // [5820]
  0x08101b08, 0x6e002a0d, 0x35211ca9, 0x13211ba4,   // tr.lt.no_443 mt.hmn.un_540  id.jw.zu_544 tr.jw.et_433
  0x32162005, 0x0a231913, 0x08000734, 0x04081113,   // sq.hr.bs_333 gl.ca.pt_665  bg.uk.un_A80 ro.no.fi_665
  0x181011a0, 0x11190b5a, 0x100711ad, 0x04130fa0,   // ro.lt.ga_322 es.gl.ro_553  ro.bg.be_643 lv.et.fi_322
  0x1b2509a4, 0x35201b08, 0x64356813, 0x2d000d2a,   // pl.eu.tr_433 tr.sq.zu_443  ig.zu.lg_665 cs.sk.un_970
  // [5830]
  0x04201b0b, 0x0406130d, 0x0852010c, 0x0a0804a4,   // tr.sq.fi_542 et.de.fi_554  en.ha.no_543 ru.uk.mk_433
  0x3f1b06ad, 0x311b6b04, 0x014a0c04, 0x31002a12,   // de.tr.af_643 ceb.tr.az_332  sv.yo.en_332 mt.az.un_640
  0x020413ad, 0x2a00010d, 0x04232a55, 0x07001019,   // et.fi.da_643 en.mt.un_540  mt.ca.fi_442 be.bg.un_750
  0x2800031a, 0x1c00640c, 0x1f0608ad, 0x250b1907,   // nl.sw.un_760 lg.id.un_530  no.de.cy_643 gl.es.eu_432
  // [5840]
  0x080c0412, 0x1703020c, 0x06001f07, 0x08006b05,   // fi.sv.no_654 da.nl.sr_543  cy.de.un_420 ceb.no.un_330
  0x0c2a0708, 0x2a0c0812, 0x04033f11, 0x11001205,   // it.mt.sv_443 no.sv.mt_654  af.nl.fi_653 hu.ro.un_330
  0x080a04af, 0x13000917, 0x1e1c2aa0, 0x3b1c1e0c,   // ru.mk.uk_655 pl.et.un_730  mt.id.ms_322 ms.id.so_543
  0x19230ba4, 0x1f3f0213, 0x2a3b0a08, 0x53003107,   // es.ca.gl_433 da.af.cy_665  pt.so.mt_443 az.ht.un_420
  // [5850]
  0x1f2d0d11, 0x6e0d2dee, 0x053f030d, 0x02001104,   // cs.sk.cy_653 sk.cs.hmn_422  nl.af.fr_554 ro.da.un_320
  0x29272b13, 0x1a00521a, 0x03002504, 0x523b21a9,   // vi.gd.sl_665 ha.tl.un_760  eu.nl.un_320 jw.so.ha_544
  0x08321708, 0x211a1e12, 0x10001714, 0x210a3507,   // sr.bs.no_443 ms.tl.jw_654  sr.be.un_660 zu.pt.jw_432
  0x1f000119, 0x29003b0d, 0x0d292d12, 0x1a0a68ee,   // en.cy.un_750 so.sl.un_540  sk.sl.cs_654 ig.pt.tl_422
  // [5860]
  0x3b002914, 0x170a1105, 0x53183ba4, 0x31001c05,   // sl.so.un_660 ro.mk.sr_333  so.ga.ht_433 id.az.un_330
  0x080232a4, 0x2900200d, 0x16293bad, 0x1b000608,   // bs.da.no_433 sq.sl.un_540  so.sl.hr_643 de.tr.un_430
  0x29001313, 0x101709a4, 0x12000618, 0x6b183bee,   // et.sl.un_650 pl.sr.lt_433  de.hu.un_740 so.ga.ceb_422
  0x0f105313, 0x3b002913, 0x13001104, 0x29003b04,   // ht.lt.lv_665 sl.so.un_650  ro.et.un_320 so.sl.un_320
  // [5870]
  0x0f0818a7, 0x2b323b04, 0x3b09120c, 0x0f00101b,   // ga.no.lv_532 so.bs.vi_332  hu.pl.so_543 lt.lv.un_770
  0x0d092d07, 0x1b313ba0, 0x07080460, 0x1a000e04,   // sk.pl.cs_432 so.az.tr_322  ru.uk.bg_664 is.tl.un_320
  0x2d0901a0, 0x29063ba4, 0x01006b14, 0x3b000912,   // en.pl.sk_322 so.de.sl_433  ceb.en.un_660 pl.so.un_640
  0x17003107, 0x28311baf, 0x16005307, 0x161310a0,   // az.sr.un_420 tr.az.sw_655  ht.hr.un_420 lt.et.hr_322
  // [5880]
  0x04101112, 0x1a250e02, 0x1f2a210c, 0x0b251107,   // ro.be.ru_654 is.eu.tl_222  jw.mt.cy_543 ro.eu.es_432
  0x281a555a, 0x08040355, 0x181b27ac, 0x35002011,   // rw.tl.sw_553 nl.fi.no_442  gd.tr.ga_632 sq.zu.un_630
  0x3f0313ad, 0x533b6855, 0x1911180c, 0x683f03a4,   // et.nl.af_643 ig.so.ht_442  ga.ro.gl_543 nl.af.ig_433
  0x0a1a6bad, 0x03643f14, 0x556b210c, 0x13033f08,   // ceb.tl.pt_643 af.lg.nl_666  jw.ceb.rw_543 af.nl.et_443
  // [5890]
  0x644a3b13, 0x21551aa4, 0x013f3b04, 0x1a556b09,   // so.yo.lg_665 tl.rw.jw_433  so.af.en_332 ceb.rw.tl_444
  0x07041709, 0x3b001c08, 0x170704ee, 0x0c1117a4,   // sr.ru.bg_444 id.so.un_430  ru.bg.sr_422 sr.ro.sv_433
  0x27003202, 0x3f036407, 0x19130ba4, 0x32120604,   // bs.gd.un_220 lg.nl.af_432  es.et.gl_433 de.hu.bs_332
  0x55211aa4, 0x27000b02, 0x081007a7, 0x17292da0,   // tl.jw.rw_433 es.gd.un_220  bg.be.uk_532 sk.sl.sr_322
  // [58a0]
  0x091c0d14, 0x355521ad, 0x133f6405, 0x1a211c08,   // ne.mr.hi_666 jw.rw.zu_643  lg.af.et_333 id.jw.tl_443
  0x043f035a, 0x033f13af, 0x3f033b14, 0x04170712,   // nl.af.fi_553 et.af.nl_655  so.nl.af_666 bg.sr.ru_654
  0x13643f05, 0x0c080e0b, 0x170a11a9, 0x3b001104,   // af.lg.et_333 is.no.sv_542  ro.mk.sr_544 ro.so.un_320
  0x01250a07, 0x170704a4, 0x25080208, 0x131c095a,   // pt.eu.en_432 ru.bg.sr_433  da.no.eu_443 hi.mr.bh_553
  // [58b0]
  0x0802250c, 0x53271107, 0x21003f02, 0x68002b0d,   // eu.da.no_543 ro.gd.ht_432  af.jw.un_220 vi.ig.un_540
  0x103f68a6, 0x0e000305, 0x0200082b, 0x0e020c07,   // ig.af.lt_521 nl.is.un_330  no.da.un_980 sv.da.is_432
  0x2d0d07a0, 0x0c124aa0, 0x012a0802, 0x2a254a07,   // it.cs.sk_322 yo.hu.sv_322  no.mt.en_222 yo.eu.mt_432
  0x31000d09, 0x04070809, 0x16094a02, 0x08554aa0,   // cs.az.un_440 uk.bg.ru_444  yo.pl.hr_222 yo.rw.no_322
  // [58c0]
  0x08100709, 0x020f0c0c, 0x3f0c0304, 0x3200290d,   // bg.be.uk_444 sv.lv.da_543  nl.sv.af_332 sl.bs.un_540
  0x29256804, 0x111310a0, 0x06003b0d, 0x2a52640d,   // ig.eu.sl_332 lt.et.ro_322  so.de.un_540 lg.ha.mt_554
  0x09006e07, 0x55001705, 0x0e080704, 0x05313f04,   // hmn.pl.un_420 sr.rw.un_330  it.no.is_332 af.az.fr_332
  0x07352808, 0x2a0c64a0, 0x1a210fa0, 0x01072a55,   // sw.zu.it_443 lg.sv.mt_322  lv.jw.tl_322 mt.it.en_442
  // [58d0]
  0x6e5305a4, 0x233b05ec, 0x2d520dec, 0x644a52ad,   // fr.ht.hmn_433 fr.so.ca_644  cs.ha.sk_644 ha.yo.lg_643
  0x1a003107, 0x53554aa0, 0x3113640c, 0x07190bec,   // az.tl.un_420 yo.rw.ht_322  lg.et.az_543 es.gl.it_644
  0x68005508, 0x281f0aee, 0x35006404, 0x31182704,   // rw.ig.un_430 pt.cy.sw_422  lg.zu.un_320 gd.ga.az_332
  0x68002a05, 0x19550a04, 0x6b1a2907, 0x3f030211,   // mt.ig.un_330 pt.rw.gl_332  sl.tl.ceb_432 da.nl.af_653
  // [58e0]
  0x1e1c13ec, 0x080e0707, 0x056b07a0, 0x0c000704,   // et.id.ms_644 it.is.no_432  it.ceb.fr_322 it.sv.un_320
  0x17080a0d, 0x03001b08, 0x03023fee, 0x02001f1a,   // mk.uk.sr_554 tr.nl.un_430  af.da.nl_422 cy.da.un_760
  0x043b64a7, 0x0c001e0d, 0x07320fa0, 0x0b0a6402,   // lg.so.fi_532 ms.sv.un_540  lv.bs.it_322 lg.pt.es_222
  0x02201f12, 0x0f100a07, 0x04283bad, 0x101b09a0,   // cy.sq.da_654 pt.lt.lv_432  so.sw.fi_643 pl.tr.lt_322
  // [58f0]
  0x2110290c, 0x21006b11, 0x08040a09, 0x0e312b55,   // sl.lt.jw_543 ceb.jw.un_630  mk.ru.uk_444 vi.az.is_442
  0x193f0b07, 0x04641055, 0x1c0d13a7, 0x08131807,   // es.af.gl_432 lt.lg.fi_442  bh.ne.mr_532 ga.et.no_432
  0x1f001b19, 0x0c530204, 0x1b3f13af, 0x131e1c04,   // tr.cy.un_750 da.ht.sv_332  et.af.tr_655 id.ms.et_332
  0x6b040c04, 0x0406250b, 0x093f0305, 0x04171005,   // sv.fi.ceb_332 eu.de.fi_542  nl.af.pl_333 be.sr.ru_333
  // [5900]
  0x0c001b12, 0x10092daf, 0x3b033f05, 0x020408a4,   // tr.sv.un_640 sk.pl.lt_655  af.nl.so_333 no.fi.da_433
  0x13043b0e, 0x04071714, 0x2d000920, 0x0f641007,   // so.fi.et_555 sr.bg.ru_666  pl.sk.un_850 lt.lg.lv_432
  0x3b006419, 0x033f3b13, 0x1000641a, 0x32002505,   // lg.so.un_750 so.af.nl_665  lg.lt.un_760 eu.bs.un_330
  0x1a356ba9, 0x3f083ba4, 0x3f000634, 0x3b003f0c,   // ceb.zu.tl_544 so.no.af_433  de.af.un_A80 af.so.un_530
  // [5910]
  0x1e6b10ee, 0x6b0610a0, 0x04170812, 0x0e350a04,   // lt.ceb.ms_422 lt.de.ceb_322  uk.sr.ru_654 pt.zu.is_332
  0x313b1ba4, 0x081210a0, 0x21001a02, 0x1c110a04,   // tr.so.az_433 lt.hu.no_322  tl.jw.un_220 pt.ro.id_332
  0x2d290dad, 0x171011a7, 0x0e1f53a0, 0x060b0708,   // cs.sl.sk_643 ro.be.sr_532  ht.cy.is_322 it.es.de_443
  0x110f2daf, 0x0f042d0c, 0x062a0914, 0x01033f0c,   // sk.lv.ro_655 sk.fi.lv_543  pl.mt.de_666 af.nl.en_543
  // [5920]
  0x3f190b08, 0x2d040da0, 0x13080407, 0x1a311b04,   // es.gl.af_443 cs.fi.sk_322  fi.no.et_432 tr.az.tl_332
  0x09190b08, 0x32001c04, 0x1a001f04, 0x2a292d07,   // es.gl.pl_443 id.bs.un_320  cy.tl.un_320 sk.sl.mt_432
  0x162d35a4, 0x1711100c, 0x6b2035a9, 0x0d0f2da4,   // zu.sk.hr_433 be.ro.sr_543  zu.sq.ceb_544 sk.lv.cs_433
  0x0e12180b, 0x10001109, 0x0c0420a6, 0x0e00020b,   // ga.hu.is_542 ro.lt.un_440  sq.fi.sv_521 da.is.un_520
  // [5930]
  0x042029a4, 0x09000412, 0x35003f0c, 0x2b200c07,   // sl.sq.fi_433 fi.pl.un_640  af.zu.un_530 sv.sq.vi_432
  0x010e25ad, 0x13000309, 0x1f1021a0, 0x0b001012,   // eu.is.en_643 nl.et.un_440  jw.lt.cy_322 lt.es.un_640
  0x11100a0c, 0x190b01ee, 0x0f001c04, 0x01006b08,   // mk.be.ro_543 en.es.gl_422  id.lv.un_320 ceb.en.un_430
  0x52532112, 0x190a1a14, 0x2000041a, 0x100f08a0,   // jw.ht.ha_654 tl.pt.gl_666  fi.sq.un_760 no.lv.lt_322
  // [5940]
  0x2021350c, 0x282552a0, 0x19001208, 0x100f1c0c,   // zu.jw.sq_543 ha.eu.sw_322  hu.gl.un_430 id.lv.lt_543
  0x12004a05, 0x31201b05, 0x1b0e3113, 0x3f0e0ca0,   // yo.hu.un_330 tr.sq.az_333  az.is.tr_665 sv.is.af_322
  0x11292da0, 0x322d0dad, 0x1a0f1e12, 0x10070aa4,   // sk.sl.ro_322 cs.sk.bs_643  ms.lv.tl_654 mk.bg.be_433
  0x06002702, 0x21200e12, 0x1f554aee, 0x040e1005,   // gd.de.un_220 is.sq.jw_654  yo.rw.cy_422 lt.is.fi_333
  // [5950]
  0x321703ee, 0x07081008, 0x31000e14, 0x09190b09,   // nl.sr.bs_422 be.uk.bg_443  is.az.un_660 es.gl.pl_444
  0x08020e0e, 0x2d170da4, 0x12004a07, 0x53004a05,   // is.da.no_555 cs.sr.sk_433  yo.hu.un_420 yo.ht.un_330
  0x21066b12, 0x0f0e4a07, 0x3b004a05, 0x0b001e08,   // ceb.de.jw_654 yo.is.lv_432  yo.so.un_330 ms.es.un_430
  0x5301130c, 0x13006e08, 0x2d001802, 0x122d18af,   // et.en.ht_543 hmn.et.un_430  ga.sk.un_220 ga.sk.hu_655
  // [5960]
  0x210410a0, 0x080710a4, 0x03010607, 0x052852ad,   // lt.fi.jw_322 be.bg.uk_433  de.en.nl_432 ha.sw.fr_643
  0x310e1baf, 0x1a535502, 0x02000c04, 0x102903ee,   // tr.is.az_655 rw.ht.tl_222  sv.da.un_320 nl.sl.lt_422
  0x0c002307, 0x31190aa0, 0x17001012, 0x1a6b55ad,   // ca.sv.un_420 pt.gl.az_322  be.sr.un_640 rw.ceb.tl_643
  0x350608a0, 0x1f0e20a4, 0x1f23190d, 0x0f1310a4,   // no.de.zu_322 sq.is.cy_433  gl.ca.cy_554 lt.et.lv_433
  // [5970]
  0x1b2555ac, 0x1e6e2007, 0x2a0b0aa4, 0x0b251955,   // rw.eu.tr_632 sq.hmn.ms_432  pt.es.mt_433 gl.eu.es_442
  0x195301a0, 0x2d000909, 0x3b55640d, 0x251a6b07,   // en.ht.gl_322 pl.sk.un_440  lg.rw.so_554 ceb.tl.eu_432
  0x070f52ad, 0x0600070d, 0x0728100c, 0x3b190ba7,   // ha.lv.it_643 it.de.un_540  lt.sw.it_543 es.gl.so_532
  0x28005313, 0x0709100c, 0x100d2d11, 0x09085507,   // ht.sw.un_650 lt.pl.it_543  sk.cs.lt_653 rw.no.pl_432
  // [5980]
  0x3b000705, 0x13006e0d, 0x1f033faf, 0x2d2307a9,   // it.so.un_330 hmn.et.un_540  af.nl.cy_655 it.ca.sk_544
  0x2d00090c, 0x071310ad, 0x190b08a0, 0x1f3f030e,   // pl.sk.un_530 lt.et.it_643  no.es.gl_322 nl.af.cy_555
  0x100907ee, 0x1a001213, 0x2d121905, 0x200a0708,   // it.pl.lt_422 hu.tl.un_650  gl.hu.sk_333 it.pt.sq_443
  0x102307a4, 0x2d280707, 0x186810a4, 0x1700041a,   // it.ca.lt_433 it.sw.sk_432  lt.ig.ga_433 ru.sr.un_760
  // [5990]
  0x19072305, 0x12001904, 0x2d0d19ee, 0x27050712,   // ca.it.gl_333 gl.hu.un_320  gl.cs.sk_422 it.fr.gd_654
  0x2d0d05af, 0x040c1307, 0x043f0312, 0x03052102,   // fr.cs.sk_655 et.sv.fi_432  nl.af.fi_654 jw.fr.nl_222
  0x270521af, 0x101707a4, 0x0100250d, 0x3f03270c,   // jw.fr.gd_655 bg.sr.be_433  eu.en.un_540 gd.nl.af_543
  0x016e6ba0, 0x11002702, 0x082a06ee, 0x0700191b,   // ceb.hmn.en_322 gd.ro.un_220  de.mt.no_422 gl.it.un_770
  // [59a0]
  0x23033f12, 0x11002008, 0x060e1e07, 0x033f25af,   // af.nl.ca_654 sq.ro.un_430  ms.is.de_432 eu.af.nl_655
  0x010c0404, 0x03002512, 0x2d1710a6, 0x1c211e0b,   // fi.sv.en_332 eu.nl.un_640  lt.sr.sk_521 ms.jw.id_542
  0x6b250fad, 0x52531902, 0x6b2521a4, 0x276b01ee,   // lv.eu.ceb_643 gl.ht.ha_222  jw.eu.ceb_433 en.ceb.gd_422
  0x190323a0, 0x2b005319, 0x111b0107, 0x1f000108,   // ca.nl.gl_322 ht.vi.un_750  en.tr.ro_432 en.cy.un_430
  // [59b0]
  0x05270408, 0x061b2107, 0x08001119, 0x3b1a6b13,   // fi.gd.fr_443 jw.tr.de_432  ro.no.un_750 ceb.tl.so_665
  0x52283b13, 0x1c1f1008, 0x0f2d0d09, 0x21552808,   // so.sw.ha_665 lt.cy.id_443  cs.sk.lv_444 sw.rw.jw_443
  0x52283511, 0x090b6b02, 0x0a001e04, 0x05110107,   // zu.sw.ha_653 ceb.es.pl_222  ms.pt.un_320 en.ro.fr_432
  0x04110705, 0x523b5508, 0x523b28a0, 0x353b5507,   // bg.ro.ru_333 rw.so.ha_443  sw.so.ha_322 rw.so.zu_432
  // [59c0]
  0x52001802, 0x21080204, 0x11001b07, 0x4a1a6b12,   // ga.ha.un_220 da.no.jw_332  tr.ro.un_420 ceb.tl.yo_654
  0x64531aa0, 0x1a206b0d, 0x01001808, 0x053111ad,   // tl.ht.lg_322 ceb.sq.tl_554  ga.en.un_430 ro.az.fr_643
  0x20000205, 0x02005309, 0x19070aee, 0x172d29a9,   // da.sq.un_330 ht.da.un_440  pt.it.gl_422 sl.sk.sr_544
  0x6b1b1004, 0x3b641004, 0x04005221, 0x1b001109,   // lt.tr.ceb_332 lt.lg.so_332  ha.fi.un_860 ro.tr.un_440
  // [59d0]
  0x3b1a6404, 0x0e002704, 0x29000413, 0x230731a0,   // lg.tl.so_332 gd.is.un_320  fi.sl.un_650 az.it.ca_322
  0x05190b08, 0x1c002a04, 0x042d0d02, 0x07116807,   // es.gl.fr_443 mt.id.un_320  cs.sk.fi_222 ig.ro.it_432
  0x281f5507, 0x060f11ee, 0x31354aaf, 0x190c0aee,   // rw.cy.sw_432 ro.lv.de_422  yo.zu.az_655 pt.sv.gl_422
  0x686b3ba4, 0x3b00010d, 0x06080ca6, 0x0c0802a6,   // so.ceb.ig_433 en.so.un_540  sv.no.de_521 da.no.sv_521
  // [59e0]
  0x12531013, 0x4a006408, 0x1e201a05, 0x1b00110d,   // lt.ht.hu_665 lg.yo.un_430  tl.sq.ms_333 ro.tr.un_540
  0x0e6864a4, 0x181f2807, 0x20002804, 0x161155ee,   // lg.ig.is_433 sw.cy.ga_432  sw.sq.un_320 rw.ro.hr_422
  0x100a21a0, 0x320f100b, 0x64350e05, 0x21006b1a,   // jw.pt.lt_322 lt.lv.bs_542  is.zu.lg_333 ceb.jw.un_760
  0x016b0607, 0x6b1f1804, 0x231901ee, 0x2100110d,   // de.ceb.en_432 ga.cy.ceb_332  en.gl.ca_422 ro.jw.un_540
  // [59f0]
  0x21005219, 0x060c2104, 0x13001c18, 0x2a001104,   // ha.jw.un_750 jw.sv.de_332  mr.bh.un_740 ro.mt.un_320
  0x0a0e28a0, 0x1f003f05, 0x1a006e07, 0x2d0f10ee,   // sw.is.pt_322 af.cy.un_330  hmn.tl.un_420 lt.lv.sk_422
  0x27000a02, 0x10000b08, 0x20061f0c, 0x31212304,   // pt.gd.un_220 es.lt.un_430  cy.de.sq_543 ca.jw.az_332
  0x0c061904, 0x2d000208, 0x23001304, 0x25041104,   // gl.de.sv_332 da.sk.un_430  et.ca.un_320 ro.fi.eu_332
  // [5a00]
  0x130b0ea0, 0x521e1c14, 0x10080a09, 0x6b121aec,   // is.es.et_322 id.ms.ha_666  mk.uk.be_444 tl.hu.ceb_644
  0x17100408, 0x281a0408, 0x55285213, 0x32000a07,   // ru.be.sr_443 fi.tl.sw_443  ha.sw.rw_665 pt.bs.un_420
  0x6b521a09, 0x080613ee, 0x0400230c, 0x1b1a25a4,   // tl.ha.ceb_444 et.de.no_422  ca.fi.un_530 eu.tl.tr_433
  0x133f03a9, 0x04005202, 0x4a003504, 0x13255504,   // nl.af.et_544 ha.fi.un_220  zu.yo.un_320 rw.eu.et_332
  // [5a10]
  0x060d03ee, 0x2800201a, 0x28552508, 0x1c3101ee,   // nl.cs.de_422 sq.sw.un_760  eu.rw.sw_443 en.az.id_422
  0x203132a0, 0x1c002122, 0x55253112, 0x681e1c07,   // bs.az.sq_322 jw.id.un_870  az.eu.rw_654 id.ms.ig_432
  0x28042da4, 0x070810a4, 0x1104255a, 0x4a5528a4,   // sk.fi.sw_433 be.uk.bg_433  eu.fi.ro_553 sw.rw.yo_433
  0x080e0fad, 0x6b000413, 0x045228a9, 0x281304af,   // lv.is.no_643 fi.ceb.un_650  sw.ha.fi_544 fi.et.sw_655
  // [5a20]
  0x3f0305ec, 0x20321609, 0x533f05a7, 0x101a1ea4,   // fr.nl.af_644 hr.bs.sq_444  fr.af.ht_532 ms.tl.lt_433
  0x53012aa0, 0x256b1a60, 0x20183508, 0x016b0507,   // mt.en.ht_322 tl.ceb.eu_664  zu.ga.sq_443 fr.ceb.en_432
  0x106b1a09, 0x3b2808a0, 0x27001904, 0x282055af,   // tl.ceb.lt_444 no.sw.so_322  gl.gd.un_320 rw.sq.sw_655
  0x2a5325a6, 0x1e1228a4, 0x042a07ee, 0x2a645507,   // eu.ht.mt_521 sw.hu.ms_433  it.mt.fi_422 rw.lg.mt_432
  // [5a30]
  0x64136ba0, 0x53023f08, 0x1100180e, 0x556435a0,   // ceb.et.lg_322 af.da.ht_443  ga.ro.un_550 zu.lg.rw_322
  0x3f000508, 0x6402080c, 0x0b000613, 0x52355502,   // fr.af.un_430 no.da.lg_543  de.es.un_650 rw.zu.ha_222
  0x232d0d02, 0x53006808, 0x10010fad, 0x18002a04,   // cs.sk.ca_222 ig.ht.un_430  lv.en.lt_643 mt.ga.un_320
  0x53000208, 0x2a000722, 0x53256404, 0x6b002112,   // da.ht.un_430 it.mt.un_870  lg.eu.ht_332 jw.ceb.un_640
  // [5a40]
  0x23001f02, 0x1a53210c, 0x0a0702a4, 0x1f001807,   // cy.ca.un_220 jw.ht.tl_543  da.it.pt_433 ga.cy.un_420
  0x23001907, 0x31002104, 0x03000512, 0x0420290b,   // gl.ca.un_420 jw.az.un_320  fr.nl.un_640 sl.sq.fi_542
  0x3f000519, 0x06030507, 0x4a2a13ad, 0x355528ad,   // fr.af.un_750 fr.nl.de_432  et.mt.yo_643 sw.rw.zu_643
  0x536b1aa0, 0x4a000e2a, 0x64002112, 0x180827ad,   // tl.ceb.ht_322 is.yo.un_970  jw.lg.un_640 gd.no.ga_643
  // [5a50]
  0x0a002a05, 0x4a002b0d, 0x25190b5a, 0x2b001809,   // mt.pt.un_330 vi.yo.un_540  es.gl.eu_553 ga.vi.un_440
  0x06001805, 0x08020602, 0x3f3507a7, 0x6b681aec,   // ga.de.un_330 de.da.no_222  it.zu.af_532 tl.ig.ceb_644
  0x09003f08, 0x4a00520c, 0x20002502, 0x64002a0d,   // af.pl.un_430 ha.yo.un_530  eu.sq.un_220 mt.lg.un_540
  0x08100404, 0x0e184a14, 0x52006e09, 0x1c0913a6,   // ru.be.uk_332 yo.ga.is_666  hmn.ha.un_440 bh.hi.mr_521
  // [5a60]
  0x0a002a07, 0x122a0aee, 0x17040aa7, 0x10003f04,   // mt.pt.un_420 pt.mt.hu_422  mk.ru.sr_532 af.lt.un_320
  0x04081714, 0x110a1705, 0x08063f07, 0x0400170c,   // sr.uk.ru_666 sr.mk.ro_333  af.de.no_432 sr.ru.un_530
  0x3500061a, 0x2100030e, 0x0d2910a4, 0x0c0802ec,   // de.zu.un_760 nl.jw.un_550  lt.sl.cs_433 da.no.sv_644
  0x11011902, 0x1c001b11, 0x29000808, 0x25554a0c,   // gl.en.ro_222 tr.id.un_630  no.sl.un_430 yo.rw.eu_543
  // [5a70]
  0x110a0405, 0x08071104, 0x31002d08, 0x13554a02,   // ru.mk.ro_333 ro.bg.uk_332  sk.az.un_430 yo.rw.et_222
  0x103f0304, 0x060c3fa4, 0x32000104, 0x062d0d08,   // nl.af.lt_332 af.sv.de_433  en.bs.un_320 cs.sk.de_443
  0x07110a07, 0x070e1f02, 0x072d0dee, 0x20003208,   // mk.ro.bg_432 cy.is.it_222  cs.sk.it_422 bs.sq.un_430
  0x0f000b04, 0x0c351807, 0x1b000a07, 0x0a000b04,   // es.lv.un_320 ga.zu.sv_432  pt.tr.un_420 es.pt.un_320
  // [5a80]
  0x0b002805, 0x10076b08, 0x040c0a08, 0x031f08a0,   // sw.es.un_330 ceb.it.lt_443  pt.sv.fi_443 no.cy.nl_322
  0x022d0d60, 0x091e1c09, 0x64531f02, 0x1900070c,   // cs.sk.da_664 id.ms.pl_444  cy.ht.lg_222 it.gl.un_530
  0x07190b08, 0x126b1a04, 0x3b553205, 0x551764ee,   // es.gl.it_443 tl.ceb.hu_332  bs.rw.so_333 lg.sr.rw_422
  0x4a00100e, 0x1c6452a0, 0x122d0dad, 0x0968285a,   // lt.yo.un_550 ha.lg.id_322  cs.sk.hu_643 sw.ig.pl_553
  // [5a90]
  0x202a0807, 0x2d080202, 0x09130404, 0x1b3152ee,   // no.mt.sq_432 da.no.sk_222  fi.et.pl_332 ha.az.tr_422
  0x1335100c, 0x19002305, 0x10000b04, 0x2a20550d,   // lt.zu.et_543 ca.gl.un_330  es.lt.un_320 rw.sq.mt_554
  0x04201305, 0x1105230c, 0x070b0a08, 0x0b0407a4,   // et.sq.fi_333 ca.fr.ro_543  pt.es.it_443 it.fi.es_433
  0x0f1e1c55, 0x6b311b07, 0x2728350c, 0x3b1e21a0,   // id.ms.lv_442 tr.az.ceb_432  zu.sw.gd_543 jw.ms.so_322
  // [5aa0]
  0x3b311b07, 0x0f553504, 0x683b130c, 0x0c001e07,   // tr.az.so_432 zu.rw.lv_332  et.so.ig_543 ms.sv.un_420
  0x0f000b07, 0x0c55280c, 0x11002309, 0x110a170c,   // es.lv.un_420 sw.rw.sv_543  ca.ro.un_440 sr.mk.ro_543
  0x0d000619, 0x1e001c08, 0x21002813, 0x21283b04,   // de.cs.un_750 id.ms.un_430  sw.jw.un_650 so.sw.jw_332
  0x3f530305, 0x52002014, 0x20646bec, 0x16202a0c,   // nl.ht.af_333 sq.ha.un_660  ceb.lg.sq_644 mt.sq.hr_543
  // [5ab0]
  0x080209ec, 0x201c1e11, 0x04080205, 0x6800132c,   // pl.da.no_644 ms.id.sq_653  da.no.fi_333 et.ig.un_990
  0x20103fec, 0x181f55ee, 0x1827110c, 0x28213b55,   // af.lt.sq_644 rw.cy.ga_422  ro.gd.ga_543 so.jw.sw_442
  0x1c64210d, 0x13201014, 0x0c55250c, 0x0e130407,   // jw.lg.id_554 lt.sq.et_666  eu.rw.sv_543 fi.et.is_432
  0x1b00100c, 0x29000304, 0x06000313, 0x31201baf,   // lt.tr.un_530 nl.sl.un_320  nl.de.un_650 tr.sq.az_655
  // [5ac0]
  0x17041004, 0x01001807, 0x3b212007, 0x08100a0c,   // be.ru.sr_332 ga.en.un_420  sq.jw.so_432 mk.be.uk_543
  0x3b00212c, 0x2b001f0d, 0x0e00060d, 0x1f002b13,   // jw.so.un_990 cy.vi.un_540  de.is.un_540 vi.cy.un_650
  0x0c032304, 0x2b001908, 0x35025511, 0x1f002b19,   // ca.nl.sv_332 gl.vi.un_430  rw.da.zu_653 vi.cy.un_750
  0x04103ba9, 0x042718af, 0x2b001f0e, 0x53004a0d,   // so.lt.fi_544 ga.gd.fi_655  cy.vi.un_550 yo.ht.un_540
  // [5ad0]
  0x35041a09, 0x3110120c, 0x523b10af, 0x3b11100d,   // tl.fi.zu_444 hu.lt.az_543  lt.so.ha_655 lt.ro.so_554
  0x03100911, 0x3b0c52af, 0x11251011, 0x1f002b1b,   // pl.lt.nl_653 ha.sv.so_655  lt.eu.ro_653 vi.cy.un_770
  0x01002d04, 0x12113512, 0x081011a4, 0x35003b0e,   // sk.en.un_320 zu.ro.hu_654  ro.be.uk_433 so.zu.un_550
  0x5212350c, 0x10110413, 0x23120107, 0x1a033b07,   // zu.hu.ha_543 fi.ro.lt_665  en.hu.ca_432 so.nl.tl_432
  // [5ae0]
  0x2d0d10a4, 0x0431100c, 0x0f002304, 0x111004a4,   // lt.cs.sk_433 lt.az.fi_543  ca.lv.un_320 fi.lt.ro_433
  0x1b043505, 0x100c08a0, 0x0804020e, 0x3b3520a0,   // zu.fi.tr_333 no.sv.lt_322  da.fi.no_555 sq.zu.so_322
  0x0a071005, 0x0b0a0702, 0x016b0eee, 0x0e004a14,   // be.bg.mk_333 it.pt.es_222  is.ceb.en_422 yo.is.un_660
  0x52554a0c, 0x0e52550c, 0x130c060c, 0x03532107,   // yo.rw.ha_543 rw.ha.is_543  de.sv.et_543 jw.ht.nl_432
  // [5af0]
  0x1610200c, 0x060c130c, 0x0c000f19, 0x190b55ee,   // sq.lt.hr_543 et.sv.de_543  lv.sv.un_750 rw.es.gl_422
  0x0a531cee, 0x29136402, 0x133b3f05, 0x55253b0c,   // id.ht.pt_422 lg.et.sl_222  af.so.et_333 so.eu.rw_543
  0x120523af, 0x01002305, 0x08171160, 0x0613645a,   // ca.fr.hu_655 ca.en.un_330  ro.sr.uk_664 lg.et.de_553
  0x6404135a, 0x180e10a4, 0x11310704, 0x133f0304,   // et.fi.lg_553 lt.is.ga_433  it.az.ro_332 nl.af.et_332
  // [5b00]
  0x0c034a0c, 0x05033f0d, 0x64003b05, 0x0e001b07,   // yo.nl.sv_543 af.nl.fr_554  so.lg.un_330 tr.is.un_420
  0x03000a02, 0x2d033bee, 0x53002b0c, 0x280e52a4,   // pt.nl.un_220 so.nl.sk_422  vi.ht.un_530 ha.is.sw_433
  0x07003502, 0x53033faf, 0x05080204, 0x2d0d0909,   // zu.it.un_220 af.nl.ht_655  da.no.fr_332 pl.cs.sk_444
  0x3f030cee, 0x0a0c01a9, 0x20033f02, 0x52211cee,   // sv.nl.af_422 en.sv.pt_544  af.nl.sq_222 id.jw.ha_422
  // [5b10]
  0x2b000621, 0x11002519, 0x3f0108a4, 0x2b002707,   // de.vi.un_860 eu.ro.un_750  no.en.af_433 gd.vi.un_420
  0x072729a0, 0x2b002708, 0x033f53af, 0x06001704,   // sl.gd.it_322 gd.vi.un_430  ht.af.nl_655 sr.de.un_320
  0x06530112, 0x17040711, 0x13000c09, 0x05000308,   // en.ht.de_654 bg.ru.sr_653  sv.et.un_440 nl.fr.un_430
  0x55106408, 0x070e0c05, 0x2d0d1fad, 0x3f090fee,   // lg.lt.rw_443 sv.is.it_333  cy.cs.sk_643 lv.pl.af_422
  // [5b20]
  0x102928a4, 0x0a2a05ee, 0x0d1710a7, 0x0335100c,   // sw.sl.lt_433 fr.mt.pt_422  lt.sr.cs_532 lt.zu.nl_543
  0x1a126b12, 0x20006807, 0x061064a0, 0x13031ea7,   // ceb.hu.tl_654 ig.sq.un_420  lg.lt.de_322 ms.nl.et_532
  0x1900250d, 0x6404130c, 0x01353204, 0x2d3f03a4,   // eu.gl.un_540 et.fi.lg_543  bs.zu.en_332 nl.af.sk_433
  0x0c061304, 0x2718280c, 0x0f1f060c, 0x06000319,   // et.de.sv_332 sw.ga.gd_543  de.cy.lv_543 nl.de.un_750
  // [5b30]
  0x28254aa0, 0x09006408, 0x53001b12, 0x352864a0,   // yo.eu.sw_322 lg.pl.un_430  tr.ht.un_640 lg.sw.zu_322
  0x09182760, 0x12001c08, 0x3b212708, 0x16291007,   // gd.ga.pl_664 id.hu.un_430  gd.jw.so_443 lt.sl.hr_432
  0x53002805, 0x6b1801a0, 0x531c1ea4, 0x170711a9,   // sw.ht.un_330 en.ga.ceb_322  ms.id.ht_433 ro.bg.sr_544
  0x06250855, 0x5535290c, 0x23110a05, 0x55642813,   // no.eu.de_442 sl.zu.rw_543  pt.ro.ca_333 sw.lg.rw_665
  // [5b40]
  0x0d092d04, 0x033f0fec, 0x1a004a08, 0x1a645502,   // sk.pl.cs_332 lv.af.nl_644  yo.tl.un_430 rw.lg.tl_222
  0x051107a4, 0x0c083fa0, 0x10000922, 0x1b004a07,   // it.ro.fr_433 af.no.sv_322  pl.lt.un_870 yo.tr.un_420
  0x3b1b31ec, 0x53091b07, 0x205528ee, 0x1a005502,   // az.tr.so_644 tr.pl.ht_432  sw.rw.sq_422 rw.tl.un_220
  0x28003112, 0x1f00041b, 0x183527ad, 0x0f2d1f08,   // az.sw.un_640 fi.cy.un_770  gd.zu.ga_643 cy.sk.lv_443
  // [5b50]
  0x2a005305, 0x04131b08, 0x0f190b08, 0x3f050307,   // ht.mt.un_330 tr.et.fi_443  es.gl.lv_443 nl.fr.af_432
  0x212007ee, 0x120964a7, 0x05120da0, 0x04003f0e,   // it.sq.jw_422 lg.pl.hu_532  cs.hu.fr_322 af.fi.un_550
  0x311b6408, 0x190a2305, 0x08020305, 0x096410ad,   // lg.tr.az_443 ca.pt.gl_333  nl.da.no_333 lt.lg.pl_643
  0x171004ec, 0x530910ad, 0x120218a0, 0x6b1b1007,   // ru.be.sr_644 lt.pl.ht_643  ga.da.hu_322 lt.tr.ceb_432
  // [5b60]
  0x01000e04, 0x35131008, 0x282519ec, 0x3f28310c,   // is.en.un_320 lt.et.zu_443  gl.eu.sw_644 az.sw.af_543
  0x35002904, 0x29530b07, 0x1b3111af, 0x3f1c1ea4,   // sl.zu.un_320 es.ht.sl_432  ro.az.tr_655 ms.id.af_433
  0x20006808, 0x20281007, 0x03000505, 0x53001012,   // ig.sq.un_430 lt.sw.sq_432  fr.nl.un_330 lt.ht.un_640
  0x100717a0, 0x12002311, 0x182312ec, 0x3f533b04,   // sr.bg.be_322 ca.hu.un_630  hu.ca.ga_644 so.ht.af_332
  // [5b70]
  0x53060355, 0x64554a08, 0x010753ee, 0x06033555,   // nl.de.ht_442 yo.rw.lg_443  ht.it.en_422 zu.nl.de_442
  0x08001708, 0x23120e0c, 0x06120707, 0x2d0a0dec,   // sr.uk.un_430 is.hu.ca_543  it.hu.de_432 cs.pt.sk_644
  0x5500310c, 0x64353114, 0x32001007, 0x2a3f0aa0,   // az.rw.un_530 az.zu.lg_666  lt.bs.un_420 pt.af.mt_322
  0x311301a0, 0x6435280c, 0x12234a0b, 0x203f130c,   // en.et.az_322 sw.zu.lg_543  yo.ca.hu_542 et.af.sq_543
  // [5b80]
  0x0a17040c, 0x3f311ea0, 0x09001907, 0x55314a5a,   // ru.sr.mk_543 ms.az.af_322  gl.pl.un_420 yo.az.rw_553
  0x06000f04, 0x03290608, 0x19002107, 0x0e080c55,   // lv.de.un_320 de.sl.nl_443  jw.gl.un_420 sv.no.is_442
  0x2a1220a9, 0x08001f02, 0x040a08ee, 0x271801a9,   // sq.hu.mt_544 cy.no.un_220  uk.mk.ru_422 en.ga.gd_544
  0x063f0308, 0x1e121b0c, 0x4a0725ad, 0x19230ba0,   // nl.af.de_443 tr.hu.ms_543  eu.it.yo_643 es.ca.gl_322
  // [5b90]
  0x235305a9, 0x1c04100c, 0x20002a08, 0x19070a07,   // fr.ht.ca_544 lt.fi.id_543  mt.sq.un_430 pt.it.gl_432
  0x10211c07, 0x12001f12, 0x12002a0d, 0x53012bec,   // id.jw.lt_432 cy.hu.un_640  mt.hu.un_540 vi.en.ht_644
  0x320c1708, 0x55001c04, 0x11101708, 0x1e003b04,   // sr.sv.bs_443 id.rw.un_320  sr.be.ro_443 so.ms.un_320
  0x02001009, 0x291e1c08, 0x1b685555, 0x11000807,   // lt.da.un_440 id.ms.sl_443  rw.ig.tr_442 no.ro.un_420
  // [5ba0]
  0x111b31ec, 0x0f001f1a, 0x55006814, 0x1b002507,   // az.tr.ro_644 cy.lv.un_760  ig.rw.un_660 eu.tr.un_420
  0x35551108, 0x64006829, 0x1e1035a7, 0x2a1e2908,   // ro.rw.zu_443 ig.lg.un_960  zu.lt.ms_532 sl.ms.mt_443
  0x25001102, 0x1f1c1ea7, 0x3f230fee, 0x312064ee,   // ro.eu.un_220 ms.id.cy_532  lv.ca.af_422 lg.sq.az_422
  0x11000e2a, 0x202821a4, 0x04001e07, 0x21351a08,   // is.ro.un_970 jw.sw.sq_433  ms.fi.un_420 tl.zu.jw_443
  // [5bb0]
  0x55102507, 0x07100aee, 0x17041013, 0x643553a4,   // eu.lt.rw_432 mk.be.bg_422  be.ru.sr_665 ht.zu.lg_433
  0x21000e0c, 0x6855640d, 0x32160ba4, 0x09201f08,   // is.jw.un_530 lg.rw.ig_554  es.hr.bs_433 cy.sq.pl_443
  0x64133511, 0x08111fa0, 0x1f002a02, 0x0b006405,   // zu.et.lg_653 cy.ro.no_322  mt.cy.un_220 lg.es.un_330
  0x20002912, 0x68181fa9, 0x3f640955, 0x252009a4,   // sl.sq.un_640 cy.ga.ig_544  pl.lg.af_442 pl.sq.eu_433
  // [5bc0]
  0x521a6ba4, 0x12000c0e, 0x32160f0e, 0x041e1c09,   // ceb.tl.ha_433 sv.hu.un_550  lv.hr.bs_555 id.ms.fi_444
  0x6b01200d, 0x081704af, 0x1700040e, 0x170804ad,   // sq.en.ceb_554 ru.sr.uk_655  ru.sr.un_550 ru.uk.sr_643
  0x17070a0b, 0x0103060d, 0x20005302, 0x20002105,   // mk.bg.sr_542 de.nl.en_554  ht.sq.un_220 jw.sq.un_330
  0x28001f08, 0x232d0d11, 0x18001202, 0x11170aec,   // cy.sw.un_430 cs.sk.ca_653  ur.ar.un_220 mk.sr.ro_644
  // [5bd0]
  0x0e000c09, 0x080e0c13, 0x033f0ea0, 0x091c13a6,   // sv.is.un_440 sv.is.no_665  is.af.nl_322 bh.mr.hi_521
  0x2d0d0414, 0x080e1f08, 0x18002302, 0x29131fa0,   // fi.cs.sk_666 cy.is.no_443  ca.ga.un_220 cy.et.sl_322
  0x08200207, 0x1b002505, 0x20081f04, 0x23190a13,   // da.sq.no_432 eu.tr.un_330  cy.no.sq_332 pt.gl.ca_665
  0x0c1f1055, 0x1800090b, 0x06070107, 0x0d292d0c,   // lt.cy.sv_442 pl.ga.un_520  en.it.de_432 sk.sl.cs_543
  // [5be0]
  0x1f0c0205, 0x29001f04, 0x6b001818, 0x070411ee,   // da.sv.cy_333 cy.sl.un_320  ga.ceb.un_740 ro.ru.bg_422
  0x32292da4, 0x25000413, 0x041707a9, 0x10080209,   // sk.sl.bs_433 fi.eu.un_650  bg.sr.ru_544 da.no.lt_444
  0x18016b07, 0x04081005, 0x100711a4, 0x0600100c,   // ceb.en.ga_432 be.uk.ru_333  ro.bg.be_433 lt.de.un_530
  0x55062108, 0x0f0428a7, 0x17070455, 0x18190b04,   // jw.de.rw_443 sw.fi.lv_532  ru.bg.sr_442 es.gl.ga_332
  // [5bf0]
  0x683519a0, 0x281e1c13, 0x03685504, 0x1f001805,   // gl.zu.ig_322 id.ms.sw_665  rw.ig.nl_332 ga.cy.un_330
  0x35092812, 0x5525680d, 0x685553af, 0x133b520d,   // sw.pl.zu_654 ig.eu.rw_554  ht.rw.ig_655 ha.so.et_554
  0x280535ee, 0x3200162c, 0x0300021a, 0x02033f05,   // zu.fr.sw_422 hr.bs.un_990  da.nl.un_760 af.nl.da_333
  0x293564ad, 0x200306ee, 0x3f021fa4, 0x281e2a04,   // lg.zu.sl_643 de.nl.sq_422  cy.da.af_433 mt.ms.sw_332

  // [5c00]
  0x02286ba7, 0x68551b12, 0x6425350c, 0x64201ea0,   // ceb.sw.da_532 tr.rw.ig_654  zu.eu.lg_543 ms.sq.lg_322
  0x3f250308, 0x06020812, 0x3f202107, 0x12000608,   // nl.eu.af_443 no.da.de_654  jw.sq.af_432 de.hu.un_430
  0x25120fa4, 0x033f0212, 0x2000081a, 0x1c214a07,   // lv.hu.eu_433 da.af.nl_654  no.sq.un_760 yo.jw.id_432
  0x6452280c, 0x2a001f07, 0x21521e08, 0x192b1b07,   // sw.ha.lg_543 cy.mt.un_420  ms.ha.jw_443 tr.vi.gl_432
  // [5c10]
  0x1f005505, 0x3b00291b, 0x1c211607, 0x132a2908,   // rw.cy.un_330 sl.so.un_770  hr.jw.id_432 sl.mt.et_443
  0x10522104, 0x04321655, 0x2100230d, 0x0d102d07,   // jw.ha.lt_332 hr.bs.fi_442  ca.jw.un_540 sk.lt.cs_432
  0x321620af, 0x52645512, 0x3b521ca0, 0x203217a0,   // sq.hr.bs_655 rw.lg.ha_654  id.ha.so_322 sr.bs.sq_322
  0x051e1c0c, 0x3b5528a0, 0x02042704, 0x06002534,   // id.ms.fr_543 sw.rw.so_322  gd.fi.da_332 eu.de.un_A80
  // [5c20]
  0x6b001c1a, 0x033f0213, 0x20355205, 0x28535508,   // id.ceb.un_760 da.af.nl_665  ha.zu.sq_333 rw.ht.sw_443
  0x0a17110b, 0x35102513, 0x102d070c, 0x64533b05,   // ro.sr.mk_542 eu.lt.zu_665  it.sk.lt_543 so.ht.lg_333
  0x08111005, 0x121b53ee, 0x68006413, 0x6b3b08a0,   // be.ro.uk_333 ht.tr.hu_422  lg.ig.un_650 no.so.ceb_322
  0x1f08020d, 0x020e06a0, 0x102320a0, 0x210452ad,   // da.no.cy_554 de.is.da_322  sq.ca.lt_322 ha.fi.jw_643
  // [5c30]
  0x2300190b, 0x23190a04, 0x03000907, 0x18080202,   // gl.ca.un_520 pt.gl.ca_332  pl.nl.un_420 da.no.ga_222
  0x170a04a0, 0x11102307, 0x23001113, 0x08170708,   // ru.mk.sr_322 ca.lt.ro_432  ro.ca.un_650 bg.sr.uk_443
  0x02080404, 0x020711a0, 0x3f180807, 0x13000704,   // fi.no.da_332 ro.it.da_322  no.ga.af_432 it.et.un_320
  0x254a1a12, 0x6e6b68a0, 0x6455280e, 0x6b1a3ba4,   // tl.yo.eu_654 ig.ceb.hmn_322  sw.rw.lg_555 so.tl.ceb_433
  // [5c40]
  0x0b102807, 0x28044a04, 0x211e3b04, 0x64551ca0,   // sw.lt.es_432 yo.fi.sw_332  so.ms.jw_332 id.rw.lg_322
  0x0d292d11, 0x04000905, 0x6400130d, 0x3f0c1f14,   // sk.sl.cs_653 pl.fi.un_330  et.lg.un_540 cy.sv.af_666
  0x190f0b0c, 0x071318a9, 0x0d001704, 0x355305a0,   // es.lv.gl_543 ga.et.it_544  sr.cs.un_320 fr.ht.zu_322
  0x07003108, 0x21001818, 0x0b002708, 0x55002d04,   // az.it.un_430 ar.fa.un_740  gd.es.un_430 sk.rw.un_320
  // [5c50]
  0x1b0513ee, 0x231807a0, 0x13001c12, 0x051b5311,   // et.fr.tr_422 it.ga.ca_322  mr.bh.un_640 ht.tr.fr_653
  0x521c1ea9, 0x1a643ba4, 0x29002d04, 0x6b1a0b08,   // ms.id.ha_544 so.lg.tl_433  sk.sl.un_320 es.tl.ceb_443
  0x0d1652ee, 0x29006e08, 0x3f1c2aa0, 0x1e1c0da4,   // ha.hr.cs_422 hmn.sl.un_430  mt.id.af_322 cs.id.ms_433
  0x251b07ad, 0x050755a7, 0x6b3b1a0c, 0x6e036b04,   // it.tr.eu_643 rw.it.fr_532  tl.so.ceb_543 ceb.nl.hmn_332
  // [5c60]
  0x23051f04, 0x022d290e, 0x10002712, 0x03063f07,   // cy.fr.ca_332 sl.sk.da_555  gd.lt.un_640 af.de.nl_432
  0x2d00290e, 0x0d000907, 0x016b64a0, 0x2b1e1ca0,   // sl.sk.un_550 pl.cs.un_420  lg.ceb.en_322 id.ms.vi_322
  0x55532855, 0x283210a9, 0x6b521c0b, 0x133255ee,   // sw.ht.rw_442 lt.bs.sw_544  id.ha.ceb_542 rw.bs.et_422
  0x29190a0d, 0x10091ea0, 0x55004a05, 0x1a1c0c0d,   // pt.gl.sl_554 ms.pl.lt_322  yo.rw.un_330 sv.id.tl_554
  // [5c70]
  0x1b001107, 0x02200602, 0x52554a08, 0x271e1c02,   // ro.tr.un_420 de.sq.da_222  yo.rw.ha_443 id.ms.gd_222
  0x05001c08, 0x080212ec, 0x32033f04, 0x03001e0d,   // id.fr.un_430 hu.da.no_644  af.nl.bs_332 ms.nl.un_540
  0x211268a9, 0x05000121, 0x18002902, 0x28645514,   // ig.hu.jw_544 en.fr.un_860  sl.ga.un_220 rw.lg.sw_666
  0x320816a4, 0x55534a07, 0x640802ad, 0x352864ad,   // hr.no.bs_433 yo.ht.rw_432  da.no.lg_643 lg.sw.zu_643
  // [5c80]
  0x04000c20, 0x18171255, 0x1e1c1aec, 0x13002017,   // sv.fi.un_850 hu.sr.ga_442  tl.id.ms_644 sq.et.un_730
  0x0a170809, 0x32170faf, 0x1f00280e, 0x3f00550c,   // uk.sr.mk_444 lv.sr.bs_655  sw.cy.un_550 rw.af.un_530
  0x1729125a, 0x0c121307, 0x10001312, 0x0c02120c,   // hu.sl.sr_553 et.hu.sv_432  et.lt.un_640 hu.da.sv_543
  0x17001207, 0x0c291255, 0x23001f0d, 0x04070807,   // hu.sr.un_420 hu.sl.sv_442  cy.ca.un_540 uk.bg.ru_432
  // [5c90]
  0x23061f12, 0x082a02a0, 0x061f2304, 0x0c0602a0,   // cy.de.ca_654 da.mt.no_322  ca.cy.de_332 da.de.sv_322
  0x27004a05, 0x1100041a, 0x20311b0b, 0x033f5309,   // yo.gd.un_330 ru.ro.un_760  tr.az.sq_542 ht.af.nl_444
  0x01030602, 0x11001f04, 0x013f03a0, 0x31001207,   // de.nl.en_222 cy.ro.un_320  nl.af.en_322 hu.az.un_420
  0x040a1012, 0x5264550c, 0x31111b0c, 0x18230713,   // be.mk.ru_654 rw.lg.ha_543  tr.ro.az_543 it.ca.ga_665
  // [5ca0]
  0x64115508, 0x6b0e125a, 0x3f0301ee, 0x07001012,   // rw.ro.lg_443 hu.is.ceb_553  en.nl.af_422 be.bg.un_640
  0x064a12a0, 0x1b2864a0, 0x0500530c, 0x112d12ee,   // hu.yo.de_322 lg.sw.tr_322  ht.fr.un_530 hu.sk.ro_422
  0x111707a4, 0x03133f0e, 0x253b1308, 0x4a1a6b08,   // bg.sr.ro_433 af.et.nl_555  et.so.eu_443 ceb.tl.yo_443
  0x0a00110c, 0x053b11a4, 0x072504a4, 0x120a07a9,   // ro.mk.un_530 ro.so.fr_433  fi.eu.it_433 it.pt.hu_544
  // [5cb0]
  0x033b3fac, 0x07040a08, 0x033f3b60, 0x1a080208,   // af.so.nl_632 mk.ru.bg_443  so.af.nl_664 da.no.tl_443
  0x03013b07, 0x280a2104, 0x20000609, 0x216b06ad,   // so.en.nl_432 jw.pt.sw_332  de.sq.un_440 de.ceb.jw_643
  0x3b520107, 0x05080c02, 0x11136e07, 0x080a10ec,   // en.ha.so_432 sv.no.fr_222  hmn.et.ro_432 be.mk.uk_644
  0x1c002a13, 0x23271f04, 0x052723a4, 0x281e1c04,   // mt.id.un_650 cy.gd.ca_332  ca.gd.fr_433 id.ms.sw_332
  // [5cc0]
  0x3b033f07, 0x162d0d5a, 0x031f27ad, 0x27000621,   // af.nl.so_432 cs.sk.hr_553  gd.cy.nl_643 de.gd.un_860
  0x272311af, 0x685301ee, 0x07081011, 0x030208a7,   // ro.ca.gd_655 en.ht.ig_422  be.uk.bg_653 no.da.nl_532
  0x0a1710ec, 0x28001a2b, 0x282555ad, 0x13000807,   // be.sr.mk_644 tl.sw.un_980  rw.eu.sw_643 no.et.un_420
  0x08071707, 0x03113f60, 0x53091113, 0x271f2308,   // sr.bg.uk_432 af.ro.nl_664  ro.pl.ht_665 ca.cy.gd_443
  // [5cd0]
  0x202852a0, 0x6813280c, 0x55682505, 0x53642807,   // ha.sw.sq_322 sw.et.ig_543  eu.ig.rw_333 sw.lg.ht_432
  0x16000c0b, 0x53001222, 0x07003505, 0x2511280c,   // sv.hr.un_520 hu.ht.un_870  zu.it.un_330 sw.ro.eu_543
  0x230b0a08, 0x25005204, 0x19050a07, 0x2307680c,   // pt.es.ca_443 ha.eu.un_320  pt.fr.gl_432 ig.it.ca_543
  0x1b0e1307, 0x100a20a9, 0x0a002b07, 0x12292aa9,   // et.is.tr_432 sq.pt.lt_544  vi.pt.un_420 mt.sl.hu_544
  // [5ce0]
  0x1c1e1ba7, 0x1e4a1ca4, 0x07001707, 0x13090da0,   // tr.ms.id_532 id.yo.ms_433  sr.it.un_420 ne.hi.bh_322
  0x3b005221, 0x1b31520c, 0x03000702, 0x02010704,   // ha.so.un_860 ha.az.tr_543  it.nl.un_220 it.en.da_332
  0x04530804, 0x53005202, 0x3528170c, 0x11522807,   // no.ht.fi_332 ha.ht.un_220  sr.sw.zu_543 sw.ha.ro_432
  0x08525312, 0x53001e1a, 0x09002302, 0x53001113,   // ht.ha.no_654 ms.ht.un_760  ca.pl.un_220 ro.ht.un_650
  // [5cf0]
  0x11002d0d, 0x0c033fa0, 0x1f001c04, 0x3f030fa4,   // sk.ro.un_540 af.nl.sv_322  id.cy.un_320 lv.nl.af_433
  0x080e2aa4, 0x1c002709, 0x0e006b08, 0x0a171004,   // mt.is.no_433 gd.id.un_440  ceb.is.un_430 be.sr.mk_332
  0x0b3b1e55, 0x0f033f04, 0x08210c07, 0x521e050c,   // ms.so.es_442 af.nl.lv_332  sv.jw.no_432 fr.ms.ha_543
  0x55311b13, 0x0727110c, 0x06080204, 0x250210ac,   // tr.az.rw_665 ro.gd.it_543  da.no.de_332 lt.da.eu_632
  // [5d00]
  0x06041b0c, 0x27002b04, 0x27283b08, 0x523b2508,   // tr.fi.de_543 vi.gd.un_320  so.sw.gd_443 eu.so.ha_443
  0x016b21a0, 0x68001e0d, 0x31001913, 0x013f035a,   // jw.ceb.en_322 ms.ig.un_540  gl.az.un_650 nl.af.en_553
  0x23000b09, 0x0a001120, 0x033f230c, 0x0e001221,   // es.ca.un_440 ro.mk.un_850  ca.af.nl_543 hu.is.un_860
  0x3b311ea9, 0x552752a9, 0x1e00200d, 0x0c060412,   // ms.az.so_544 ha.gd.rw_544  sq.ms.un_540 fi.de.sv_654
  // [5d10]
  0x1c211e12, 0x0a17040e, 0x28292d07, 0x12052da7,   // ms.jw.id_654 ru.sr.mk_555  sk.sl.sw_432 sk.fr.hu_532
  0x27000604, 0x0c1601a4, 0x10041707, 0x09000e0e,   // de.gd.un_320 en.hr.sv_433  sr.ru.be_432 is.pl.un_550
  0x17080412, 0x18000905, 0x32001711, 0x0e001219,   // ru.uk.sr_654 pl.ga.un_330  sr.bs.un_630 hu.is.un_750
  0x010504ad, 0x64005222, 0x123f030c, 0x08000e1b,   // fi.fr.en_643 ha.lg.un_870  nl.af.hu_543 is.no.un_770
  // [5d20]
  0x28002d07, 0x3b002d04, 0x0b0710af, 0x32172da4,   // sk.sw.un_420 sk.so.un_320  lt.it.es_655 sk.sr.bs_433
  0x531c5504, 0x55110f04, 0x31000807, 0x080411ac,   // rw.id.ht_332 lv.ro.rw_332  no.az.un_420 ro.ru.uk_632
  0x64000704, 0x20171107, 0x211b6ea0, 0x35086ba0,   // it.lg.un_320 ro.sr.sq_432  hmn.tr.jw_322 ceb.no.zu_322
  0x211c0602, 0x063f0aee, 0x19000704, 0x01061f07,   // de.id.jw_222 pt.af.de_422  it.gl.un_320 cy.de.en_432
  // [5d30]
  0x19002302, 0x0600180d, 0x6b001208, 0x352d0d04,   // ca.gl.un_220 ga.de.un_540  hu.ceb.un_430 cs.sk.zu_332
  0x55043b0c, 0x29000e1a, 0x1b0a1a07, 0x35016b04,   // so.fi.rw_543 is.sl.un_760  tl.pt.tr_432 ceb.en.zu_332
  0x2700050d, 0x0f120a08, 0x011c1a04, 0x13090d55,   // fr.gd.un_540 pt.hu.lv_443  tl.id.en_332 ne.hi.bh_442
  0x203f35ee, 0x100804a9, 0x13062055, 0x0d091ca0,   // zu.af.sq_422 ru.uk.be_544  sq.de.et_442 mr.hi.ne_322
  // [5d40]
  0x18003518, 0x3f000607, 0x03060407, 0x20355207,   // zu.ga.un_740 de.af.un_420  fi.de.nl_432 ha.zu.sq_432
  0x35001822, 0x10230504, 0x1c130d04, 0x10001104,   // ga.zu.un_870 fr.ca.lt_332  ne.bh.mr_332 ro.be.un_320
  0x2806520c, 0x08100414, 0x04120f55, 0x0e0713a7,   // ha.de.sw_543 ru.be.uk_666  lv.hu.fi_442 et.it.is_532
  0x20231304, 0x042d0d04, 0x2a001a02, 0x200523a9,   // et.ca.sq_332 cs.sk.fi_332  tl.mt.un_220 ca.fr.sq_544
  // [5d50]
  0x1800121b, 0x07002108, 0x0f0523a4, 0x041b270b,   // ur.ar.un_770 jw.it.un_430  ca.fr.lv_433 gd.tr.fi_542
  0x0e0429ac, 0x0b2d2904, 0x3b526460, 0x0c321607,   // sl.fi.is_632 sl.sk.es_332  lg.ha.so_664 hr.bs.sv_432
  0x101a6b60, 0x283b52a9, 0x551c2108, 0x271801af,   // ceb.tl.lt_664 ha.so.sw_544  jw.id.rw_443 en.ga.gd_655
  0x1f016804, 0x0a001920, 0x0b000a1e, 0x1f001012,   // ig.en.cy_332 gl.pt.un_850  pt.es.un_830 lt.cy.un_640
  // [5d60]
  0x29200fee, 0x1b001307, 0x10042307, 0x25006e04,   // lv.sq.sl_422 et.tr.un_420  ca.fi.lt_432 hmn.eu.un_320
  0x050429a0, 0x2b001c0d, 0x102852a0, 0x3f0510ee,   // sl.fi.fr_322 id.vi.un_540  ha.sw.lt_322 lt.fr.af_422
  0x11002a12, 0x1f020c02, 0x1e1c04af, 0x68000d13,   // mt.ro.un_640 sv.da.cy_222  fi.id.ms_655 cs.ig.un_650
  0x2d002514, 0x1b132104, 0x13080204, 0x3b003504,   // eu.sk.un_660 jw.et.tr_332  da.no.et_332 zu.so.un_320
  // [5d70]
  0x07040aec, 0x121f050d, 0x0502010c, 0x06033f12,   // mk.ru.bg_644 fr.cy.hu_554  en.da.fr_543 af.nl.de_654
  0x20001f08, 0x0e124aa9, 0x170a1007, 0x522d3fa0,   // cy.sq.un_430 yo.hu.is_544  be.mk.sr_432 af.sk.ha_322
  0x31131ba9, 0x68016b07, 0x35001211, 0x10000811,   // tr.et.az_544 ceb.en.ig_432  hu.zu.un_630 uk.be.un_630
  0x2d00041a, 0x32003b09, 0x18001b0e, 0x0b0523a4,   // fi.sk.un_760 so.bs.un_440  tr.ga.un_550 ca.fr.es_433
  // [5d80]
  0x013b2707, 0x0a004a04, 0x3b001902, 0x0708040b,   // gd.so.en_432 yo.pt.un_320  gl.so.un_220 ru.uk.bg_542
  0x11100705, 0x04285204, 0x08060ea4, 0x04251904,   // bg.be.ro_333 ha.sw.fi_332  is.de.no_433 gl.eu.fi_332
  0x12130407, 0x12173207, 0x19060c04, 0x6e002018,   // fi.et.hu_432 bs.sr.hu_432  sv.de.gl_332 sq.hmn.un_740
  0x171610a4, 0x04070855, 0x12061b07, 0x643529a7,   // lt.hr.sr_433 uk.bg.ru_442  tr.de.hu_432 sl.zu.lg_532
  // [5d90]
  0x13004a07, 0x20006e08, 0x3f031307, 0x03003508,   // yo.et.un_420 hmn.sq.un_430  et.nl.af_432 zu.nl.un_430
  0x2700110c, 0x0e0c0804, 0x132704a7, 0x1a3525a4,   // ro.gd.un_530 no.sv.is_332  fi.gd.et_532 eu.zu.tl_433
  0x270820a0, 0x64551fa4, 0x0c0e20a7, 0x18000702,   // sq.no.gd_322 cy.rw.lg_433  sq.is.sv_532 it.ga.un_220
  0x6b551a0e, 0x083f0305, 0x5355640c, 0x08280207,   // tl.rw.ceb_555 nl.af.no_333  lg.rw.ht_543 da.sw.no_432
  // [5da0]
  0x0f001312, 0x20006e19, 0x280a070c, 0x0e0c0855,   // et.lv.un_640 hmn.sq.un_750  it.pt.sw_543 no.sv.is_442
  0x6b006407, 0x0410350c, 0x290a350c, 0x2d19350b,   // lg.ceb.un_420 zu.lt.fi_543  zu.pt.sl_543 zu.gl.sk_542
  0x68533507, 0x012027ee, 0x082a0455, 0x12000704,   // zu.ht.ig_432 gd.sq.en_422  fi.mt.no_442 it.hu.un_320
  0x25000f07, 0x3f006b12, 0x0c002102, 0x19002508,   // lv.eu.un_420 ceb.af.un_640  jw.sv.un_220 eu.gl.un_430
  // [5db0]
  0x17005505, 0x04554a0d, 0x082d0d05, 0x1b2353a0,   // rw.sr.un_330 yo.rw.fi_554  cs.sk.no_333 ht.ca.tr_322
  0x130c23a0, 0x1c291e04, 0x1f6435a0, 0x53172907,   // ca.sv.et_322 ms.sl.id_332  zu.lg.cy_322 sl.sr.ht_432
  0x070417af, 0x1c001a07, 0x1e1c0ca9, 0x20231f0d,   // sr.ru.bg_655 tl.id.un_420  sv.id.ms_544 cy.ca.sq_554
  0x55121ea4, 0x6b1a1c07, 0x0717100d, 0x6b001a04,   // ms.hu.rw_433 id.tl.ceb_432  be.sr.bg_554 tl.ceb.un_320
  // [5dc0]
  0x3f0302af, 0x21070da4, 0x09002d0e, 0x19230b13,   // da.nl.af_655 cs.it.jw_433  sk.pl.un_550 es.ca.gl_665
  0x2b001c19, 0x16120407, 0x0f231055, 0x35124aee,   // id.vi.un_750 fi.hu.hr_432  lt.ca.lv_442 yo.hu.zu_422
  0x0135640c, 0x1e001704, 0x2000290c, 0x1a5564a0,   // lg.zu.en_543 sr.ms.un_320  sl.sq.un_530 lg.rw.tl_322
  0x271128af, 0x10001f13, 0x093528a4, 0x23001e04,   // sw.ro.gd_655 cy.lt.un_650  sw.zu.pl_433 ms.ca.un_320
  // [5dd0]
  0x1a1e1ba0, 0x5300051a, 0x1f00060e, 0x29000108,   // tr.ms.tl_322 fr.ht.un_760  de.cy.un_550 en.sl.un_430
  0x0d002a0c, 0x0a041713, 0x3500552a, 0x313519ad,   // mt.cs.un_530 sr.ru.mk_665  rw.zu.un_970 gl.zu.az_643
  0x31192aee, 0x0c2a200d, 0x0d09130b, 0x0c080ea9,   // mt.gl.az_422 sq.mt.sv_554  bh.hi.ne_542 is.no.sv_544
  0x12002a13, 0x17000702, 0x1f00640d, 0x1700070e,   // mt.hu.un_650 bg.sr.un_220  lg.cy.un_540 bg.sr.un_550
  // [5de0]
  0x060c08ad, 0x080711ee, 0x073f01a4, 0x171b2902,   // no.sv.de_643 ro.bg.uk_422  en.af.it_433 sl.tr.sr_222
  0x08070c08, 0x2a556404, 0x210555a0, 0x29000d08,   // sv.it.no_443 lg.rw.mt_332  rw.fr.jw_322 cs.sl.un_430
  0x0b3f03a4, 0x2a0703a4, 0x040e0107, 0x191c0ba0,   // nl.af.es_433 nl.it.mt_433  en.is.fi_432 es.id.gl_322
  0x19002813, 0x0727180c, 0x0b550dee, 0x282d2905,   // sw.gl.un_650 ga.gd.it_543  cs.rw.es_422 sl.sk.sw_333
  // [5df0]
  0x1f2012af, 0x111827a4, 0x09001207, 0x182827a7,   // hu.sq.cy_655 gd.ga.ro_433  hu.pl.un_420 gd.sw.ga_532
  0x19553504, 0x0b003204, 0x0a063fad, 0x21100fee,   // zu.rw.gl_332 bs.es.un_320  af.de.pt_643 lv.lt.jw_422
  0x2713180c, 0x17000a2a, 0x11000507, 0x2b056b07,   // ga.et.gd_543 mk.sr.un_970  fr.ro.un_420 ceb.fr.vi_432
  0x12320d07, 0x20182905, 0x0d130907, 0x202d55a0,   // cs.bs.hu_432 sl.ga.sq_333  hi.bh.ne_432 rw.sk.sq_322
  // [5e00]
  0x250b19a0, 0x0d00350e, 0x131811a7, 0x3f0302a7,   // gl.es.eu_322 zu.cs.un_550  ro.ga.et_532 da.nl.af_532
  0x0a000412, 0x17100fa0, 0x0700110b, 0x0d1c13ad,   // fi.pt.un_640 lv.lt.sr_322  ro.bg.un_520 bh.mr.ne_643
  0x2305080c, 0x1b131007, 0x5500351a, 0x2900100c,   // no.fr.ca_543 lt.et.tr_432  zu.rw.un_760 lt.sl.un_530
  0x170407af, 0x08171007, 0x19050b12, 0x19530a08,   // bg.ru.sr_655 be.sr.uk_432  es.fr.gl_654 pt.ht.gl_443
  // [5e10]
  0x23050112, 0x080c02a9, 0x2b6801ee, 0x210c2aa7,   // en.fr.ca_654 da.sv.no_544  en.ig.vi_422 mt.sv.jw_532
  0x23001013, 0x2900530e, 0x081107a4, 0x3f032760,   // lt.ca.un_650 ht.sl.un_550  bg.ro.uk_433 gd.nl.af_664
  0x10003f19, 0x23100f04, 0x1b6e10a4, 0x1e130107,   // af.lt.un_750 lv.lt.ca_332  lt.hmn.tr_433 en.et.ms_432
  0x3f031f13, 0x1c4a1ea0, 0x0f10050b, 0x1a2d21a0,   // cy.nl.af_665 ms.yo.id_322  fr.lt.lv_542 jw.sk.tl_322
  // [5e20]
  0x290f18ad, 0x050110ee, 0x6e001e08, 0x201f0855,   // ga.lv.sl_643 lt.en.fr_422  ms.hmn.un_430 no.cy.sq_442
  0x32311705, 0x11531ba0, 0x27000a04, 0x0c3b35a7,   // sr.az.bs_333 tr.ht.ro_322  pt.gd.un_320 zu.so.sv_532
  0x0a171011, 0x1a3f0305, 0x0c0f10ee, 0x271c1ea0,   // be.sr.mk_653 nl.af.tl_333  lt.lv.sv_422 ms.id.gd_322
  0x0c2b27ad, 0x3b281e07, 0x6b0f21a9, 0x3f000223,   // gd.vi.sv_643 ms.sw.so_432  jw.lv.ceb_544 da.af.un_880
  // [5e30]
  0x52202707, 0x21011e02, 0x1c1f1e12, 0x6e271809,   // gd.sq.ha_432 ms.en.jw_222  ms.cy.id_654 ga.gd.hmn_444
  0x0b2a04ad, 0x10002d18, 0x08003f12, 0x64000412,   // fi.mt.es_643 sk.lt.un_740  af.no.un_640 fi.lg.un_640
  0x0f001804, 0x170810a4, 0x3f020608, 0x1f033fa4,   // ga.lv.un_320 be.uk.sr_433  de.da.af_443 af.nl.cy_433
  0x0d001321, 0x0807040c, 0x170f1a08, 0x08001114,   // bh.ne.un_860 ru.bg.uk_543  tl.lv.sr_443 ro.uk.un_660
  // [5e40]
  0x04190bee, 0x17080405, 0x25000b1b, 0x19040508,   // es.gl.fi_422 ru.uk.sr_333  es.eu.un_770 fr.fi.gl_443
  0x1f190b05, 0x10002d07, 0x080711af, 0x11190b55,   // es.gl.cy_333 sk.lt.un_420  ro.bg.uk_655 es.gl.ro_442
  0x231105a0, 0x2d12290c, 0x35182707, 0x0c0406a7,   // fr.ro.ca_322 sl.hu.sk_543  gd.ga.zu_432 de.fi.sv_532
  0x0d093f0e, 0x102508a0, 0x190b5209, 0x52001008,   // af.pl.cs_555 no.eu.lt_322  ha.es.gl_444 lt.ha.un_430
  // [5e50]
  0x273f18a0, 0x2100181a, 0x2d0c29a0, 0x0c03040c,   // ga.af.gd_322 ar.fa.un_760  sl.sv.sk_322 fi.nl.sv_543
  0x011107ee, 0x01080e02, 0x6b271807, 0x18352707,   // it.ro.en_422 is.no.en_222  ga.gd.ceb_432 gd.zu.ga_432
  0x0a1129a0, 0x0717080b, 0x081023af, 0x19310aee,   // sl.ro.pt_322 uk.sr.bg_542  ca.lt.no_655 pt.az.gl_422
  0x29002d02, 0x3f200309, 0x11103107, 0x06120ca7,   // sk.sl.un_220 nl.sq.af_444  az.lt.ro_432 sv.hu.de_532
  // [5e60]
  0x100f040c, 0x2a522b07, 0x0f292da4, 0x2b004a04,   // fi.lv.lt_543 vi.ha.mt_432  sk.sl.lv_433 yo.vi.un_320
  0x0c020404, 0x180b1fa0, 0x08040a04, 0x250929ee,   // fi.da.sv_332 cy.es.ga_322  mk.ru.uk_332 sl.pl.eu_422
  0x23256407, 0x28351307, 0x52201fa4, 0x53000e0b,   // lg.eu.ca_432 et.zu.sw_432  cy.sq.ha_433 is.ht.un_520
  0x04171004, 0x55216408, 0x07000404, 0x04100811,   // be.sr.ru_332 lg.jw.rw_443  ru.bg.un_320 uk.be.ru_653
  // [5e70]
  0x25000308, 0x202a2907, 0x29312d04, 0x556b2104,   // nl.eu.un_430 sl.mt.sq_432  sk.az.sl_332 jw.ceb.rw_332
  0x311b110c, 0x2000551a, 0x12190aad, 0x21531fa0,   // ro.tr.az_543 rw.sq.un_760  pt.gl.hu_643 cy.ht.jw_322
  0x2d0d1209, 0x110755a4, 0x31121baf, 0x556401a4,   // hu.cs.sk_444 rw.it.ro_433  tr.hu.az_655 en.lg.rw_433
  0x063f03a7, 0x25030f55, 0x03213fa0, 0x131f03ad,   // nl.af.de_532 lv.nl.eu_442  af.jw.nl_322 nl.cy.et_643
  // [5e80]
  0x64253512, 0x0a003f04, 0x20231fa7, 0x4a3564af,   // zu.eu.lg_654 af.pt.un_320  cy.ca.sq_532 lg.zu.yo_655
  0x170704ec, 0x17040a09, 0x07001a04, 0x35030a02,   // ru.bg.sr_644 mk.ru.sr_444  tl.it.un_320 pt.nl.zu_222
  0x02003f07, 0x1f011ca4, 0x3f000c0b, 0x13001f1a,   // af.da.un_420 id.en.cy_433  sv.af.un_520 cy.et.un_760
  0x202503ad, 0x072a01a0, 0x2517290c, 0x322d0d0c,   // nl.eu.sq_643 en.mt.it_322  sl.sr.eu_543 cs.sk.bs_543
  // [5e90]
  0x551a68ec, 0x35212804, 0x28003b12, 0x35295512,   // ig.tl.rw_644 sw.jw.zu_332  so.sw.un_640 rw.sl.zu_654
  0x063f0313, 0x231908a0, 0x27060211, 0x080306ee,   // nl.af.de_665 no.gl.ca_322  da.de.gd_653 de.nl.no_422
  0x6b0c0607, 0x1e071c07, 0x1c002808, 0x2a005302,   // de.sv.ceb_432 id.it.ms_432  sw.id.un_430 ht.mt.un_220
  0x06006b05, 0x021b1fa7, 0x640835a4, 0x08001a0d,   // ceb.de.un_330 cy.tr.da_532  zu.no.lg_433 tl.no.un_540
  // [5ea0]
  0x35001f12, 0x356b2808, 0x32000208, 0x0d096ba0,   // cy.zu.un_640 sw.ceb.zu_443  da.bs.un_430 ceb.pl.cs_322
  0x023106a0, 0x1b001f14, 0x12000613, 0x13250407,   // de.az.da_322 cy.tr.un_660  de.hu.un_650 fi.eu.et_432
  0x210c1a04, 0x06001204, 0x06120ea7, 0x6400060c,   // tl.sv.jw_332 hu.de.un_320  is.hu.de_532 de.lg.un_530
  0x033f1ea0, 0x0c006805, 0x01000b02, 0x12131c04,   // ms.af.nl_322 ig.sv.un_330  es.en.un_220 id.et.hu_332
  // [5eb0]
  0x08071712, 0x02000608, 0x320512ee, 0x091a64ec,   // sr.bg.uk_654 de.da.un_430  hu.fr.bs_422 lg.tl.pl_644
  0x10130f0c, 0x28004a09, 0x102d16a0, 0x2d29160c,   // lv.et.lt_543 yo.sw.un_440  hr.sk.lt_322 hr.sl.sk_543
  0x16000404, 0x171104ee, 0x230b0a02, 0x52003202,   // fi.hr.un_320 fi.ro.sr_422  pt.es.ca_222 bs.ha.un_220
  0x23100707, 0x0e003f21, 0x1200550c, 0x102d29a9,   // it.lt.ca_432 af.is.un_860  rw.hu.un_530 sl.sk.lt_544
  // [5ec0]
  0x0b000a1b, 0x0e080214, 0x03272a04, 0x0a005207,   // pt.es.un_770 da.no.is_666  mt.gd.nl_332 ha.pt.un_420
  0x1100180c, 0x106b2507, 0x0b070a07, 0x0a3f2a05,   // ga.ro.un_530 eu.ceb.lt_432  pt.it.es_432 mt.af.pt_333
  0x3500210c, 0x1004080e, 0x091a6b5a, 0x320d2a08,   // jw.zu.un_530 uk.ru.be_555  ceb.tl.pl_553 mt.cs.bs_443
  0x6b080205, 0x0f321709, 0x29071308, 0x0a081107,   // da.no.ceb_333 sr.bs.lv_444  et.it.sl_443 ro.uk.mk_432
  // [5ed0]
  0x290704a0, 0x2810130c, 0x52353fa0, 0x0f3b1aee,   // fi.it.sl_322 et.lt.sw_543  af.zu.ha_322 tl.so.lv_422
  0x0a291008, 0x1b211ca4, 0x071a6b05, 0x13090d05,   // lt.sl.pt_443 id.jw.tr_433  ceb.tl.it_333 ne.hi.bh_333
  0x12201ba7, 0x6b0b0104, 0x08076b04, 0x35550807,   // tr.sq.hu_532 en.es.ceb_332  ceb.it.no_332 no.rw.zu_432
  0x273f230c, 0x1b292d02, 0x285529ee, 0x170710a9,   // ca.af.gd_543 sk.sl.tr_222  sl.rw.sw_422 be.bg.sr_544
  // [5ee0]
  0x02126bee, 0x10002808, 0x190b23a6, 0x036b3faf,   // ceb.hu.da_422 sw.lt.un_430  ca.es.gl_521 af.ceb.nl_655
  0x100220a4, 0x53352807, 0x17070aa7, 0x2d0d25ee,   // sq.da.lt_433 sw.zu.ht_432  mk.bg.sr_532 eu.cs.sk_422
  0x6b003f07, 0x08000e22, 0x3564280b, 0x01006402,   // af.ceb.un_420 is.no.un_870  sw.lg.zu_542 lg.en.un_220
  0x1f110508, 0x04170a13, 0x53352508, 0x07556407,   // fr.ro.cy_443 mk.sr.ru_665  eu.zu.ht_443 lg.rw.it_432
  // [5ef0]
  0x3f1f0ea0, 0x6b551aa9, 0x05011fee, 0x0c006407,   // is.cy.af_322 tl.rw.ceb_544  cy.en.fr_422 lg.sv.un_420
  0x05190b55, 0x070a12a9, 0x213b2814, 0x04002509,   // es.gl.fr_442 hu.pt.it_544  sw.so.jw_666 eu.fi.un_440
  0x25231fee, 0x25000408, 0x101204a9, 0x132935a0,   // cy.ca.eu_422 fi.eu.un_430  fi.hu.lt_544 zu.sl.et_322
  0x64043507, 0x27001e05, 0x091f25a6, 0x070a17ac,   // zu.fi.lg_432 ms.gd.un_330  eu.cy.pl_521 sr.mk.bg_632
  // [5f00]
  0x0e6435ad, 0x21202507, 0x132325af, 0x52281eaf,   // zu.lg.is_643 eu.sq.jw_432  eu.ca.et_655 ms.sw.ha_655
  0x321e29ee, 0x05092309, 0x29002019, 0x08352312,   // sl.ms.bs_422 ca.pl.fr_444  sq.sl.un_750 ca.zu.no_654
  0x2000230b, 0x351f27a0, 0x311a6b08, 0x25001919,   // ca.sq.un_520 gd.cy.zu_322  ceb.tl.az_443 gl.eu.un_750
  0x20001e0d, 0x28001e07, 0x100701a9, 0x0309060b,   // ms.sq.un_540 ms.sw.un_420  en.it.lt_544 de.pl.nl_542
  // [5f10]
  0x6b1a680c, 0x1121010c, 0x0e0925a4, 0x0d09250c,   // ig.tl.ceb_543 en.jw.ro_543  eu.pl.is_433 eu.pl.cs_543
  0x643509ad, 0x200411a7, 0x1a042511, 0x68001f12,   // pl.zu.lg_643 ro.fi.sq_532  eu.fi.tl_653 cy.ig.un_640
  0x6b3f0107, 0x182768a0, 0x01130ea7, 0x35000908,   // en.af.ceb_432 ig.gd.ga_322  is.et.en_532 pl.zu.un_430
  0x09003509, 0x3555280c, 0x1b002a04, 0x355209ad,   // zu.pl.un_440 sw.rw.zu_543  mt.tr.un_320 pl.ha.zu_643
  // [5f20]
  0x35096460, 0x023f270c, 0x21533b04, 0x02000c22,   // lg.pl.zu_664 gd.af.da_543  so.ht.jw_332 sv.da.un_870
  0x28000920, 0x355228ec, 0x3f03060e, 0x06001f0c,   // pl.sw.un_850 sw.ha.zu_644  de.nl.af_555 cy.de.un_530
  0x645535a0, 0x5200090e, 0x285235a0, 0x021301a0,   // zu.rw.lg_322 pl.ha.un_550  zu.ha.sw_322 en.et.da_322
  0x5328090c, 0x033f090c, 0x020e08ec, 0x1e211c60,   // pl.sw.ht_543 pl.af.nl_543  no.is.da_644 id.jw.ms_664
  // [5f30]
  0x111e1c55, 0x3f06035a, 0x1f003f09, 0x1100171a,   // id.ms.ro_442 nl.de.af_553  af.cy.un_440 sr.ro.un_760
  0x21181207, 0x1a000108, 0x1200040c, 0x1b001604,   // ur.ar.fa_432 en.tl.un_430  fi.hu.un_530 hr.tr.un_320
  0x250d0f55, 0x012b6b07, 0x1b001114, 0x17041104,   // lv.cs.eu_442 ceb.vi.en_432  ro.tr.un_660 ro.ru.sr_332
  0x280501a4, 0x0a3b13af, 0x276e6b11, 0x1e6b2b09,   // en.fr.sw_433 et.so.pt_655  ceb.hmn.gd_653 vi.ceb.ms_444
  // [5f40]
  0x68271860, 0x556b680d, 0x64133b12, 0x18120bec,   // ga.gd.ig_664 ig.ceb.rw_554  so.et.lg_654 es.hu.ga_644
  0x0d00060c, 0x253f03ad, 0x1f002513, 0x27006409,   // de.cs.un_530 nl.af.eu_643  eu.cy.un_650 lg.gd.un_440
  0x5568640d, 0x033f05af, 0x4a003b20, 0x18271c0c,   // lg.ig.rw_554 fr.af.nl_655  so.yo.un_850 id.gd.ga_543
  0x0d1305a9, 0x252811ec, 0x09001005, 0x18000a13,   // fr.et.cs_544 ro.sw.eu_644  lt.pl.un_330 pt.ga.un_650
  // [5f50]
  0x0e00200d, 0x3b000113, 0x55236405, 0x25001104,   // sq.is.un_540 en.so.un_650  lg.ca.rw_333 ro.eu.un_320
  0x25002002, 0x20003512, 0x10001121, 0x2b1a6bee,   // sq.eu.un_220 zu.sq.un_640  ro.be.un_860 ceb.tl.vi_422
  0x18000e13, 0x1a002807, 0x08171208, 0x3f3b1312,   // is.ga.un_650 sw.tl.un_420  hu.sr.no_443 et.so.af_654
  0x03001f0d, 0x212864a0, 0x03012907, 0x0e1a64a4,   // cy.nl.un_540 lg.sw.jw_322  sl.en.nl_432 lg.tl.is_433
  // [5f60]
  0x033f0dee, 0x0100242a, 0x10000907, 0x130823ad,   // cs.af.nl_422 yi.iw.un_970  pl.lt.un_420 ca.no.et_643
  0x010a19ee, 0x10023f0c, 0x1801040b, 0x0e005519,   // gl.pt.en_422 af.da.lt_543  fi.en.ga_542 rw.is.un_750
  0x0c05080c, 0x090316a7, 0x5564350b, 0x0f060512,   // no.fr.sv_543 hr.nl.pl_532  zu.lg.rw_542 fr.de.lv_654
  0x1b525508, 0x3f0553ad, 0x32080f07, 0x0425110c,   // rw.ha.tr_443 ht.fr.af_643  lv.no.bs_432 ro.eu.fi_543
  // [5f70]
  0x010519ad, 0x25001122, 0x091953ec, 0x1302080c,   // gl.fr.en_643 ro.eu.un_870  ht.gl.pl_644 no.da.et_543
  0x281125ad, 0x1f0c020c, 0x03083f07, 0x052a0711,   // eu.ro.sw_643 da.sv.cy_543  af.no.nl_432 it.mt.fr_653
  0x09122007, 0x12552811, 0x11000508, 0x3f0523a0,   // sq.hu.pl_432 sw.rw.hu_653  fr.ro.un_430 ca.fr.af_322
  0x1c121aa6, 0x1c006402, 0x21013bee, 0x25005512,   // tl.hu.id_521 lg.id.un_220  so.en.jw_422 rw.eu.un_640
  // [5f80]
  0x23001014, 0x321b31a4, 0x3f0a0507, 0x0f093108,   // lt.ca.un_660 az.tr.bs_433  fr.pt.af_432 az.pl.lv_443
  0x1800190d, 0x073b040c, 0x0500530d, 0x3552280d,   // gl.ga.un_540 fi.so.it_543  ht.fr.un_540 sw.ha.zu_554
  0x6b1a25a4, 0x0520010c, 0x11005519, 0x0d055311,   // eu.tl.ceb_433 en.sq.fr_543  rw.ro.un_750 ht.fr.cs_653
  0x17290fad, 0x35645313, 0x291e1c13, 0x0b0208a4,   // lv.sl.sr_643 ht.lg.zu_665  id.ms.sl_665 no.da.es_433
  // [5f90]
  0x3f055312, 0x081f1e07, 0x09641e07, 0x04005302,   // ht.fr.af_654 ms.cy.no_432  ms.lg.pl_432 ht.fi.un_220
  0x55200d05, 0x53032a04, 0x21096407, 0x32051804,   // cs.sq.rw_333 mt.nl.ht_332  lg.pl.jw_432 ga.fr.bs_332
  0x1f52640c, 0x1f003b0d, 0x11002b12, 0x5520110c,   // lg.ha.cy_543 so.cy.un_540  vi.ro.un_640 ro.sq.rw_543
  0x090603a4, 0x08010407, 0x07160a07, 0x3b521e12,   // nl.de.pl_433 fi.en.no_432  pt.hr.it_432 ms.ha.so_654
  // [5fa0]
  0x08010bee, 0x28005535, 0x01213f07, 0x040a07ec,   // es.en.no_422 rw.sw.un_A90  af.jw.en_432 bg.mk.ru_644
  0x06000d04, 0x20000f02, 0x28645512, 0x52002813,   // cs.de.un_320 lv.sq.un_220  rw.lg.sw_654 sw.ha.un_650
  0x55522812, 0x1f3b2aee, 0x025208af, 0x0c2a07a9,   // sw.ha.rw_654 mt.so.cy_422  no.ha.da_655 it.mt.sv_544
  0x13002305, 0x0664070c, 0x1b00640e, 0x0212200b,   // ca.et.un_330 it.lg.de_543  lg.tr.un_550 sq.hu.da_542
  // [5fb0]
  0x321e1c14, 0x21001e08, 0x1100040d, 0x520413a4,   // id.ms.bs_666 ms.jw.un_430  fi.ro.un_540 et.fi.ha_433
  0x0e216ba0, 0x12070107, 0x53556404, 0x1b000c0d,   // ceb.jw.is_322 en.it.hu_432  lg.rw.ht_332 sv.tr.un_540
  0x64183fa7, 0x08023f02, 0x5200010d, 0x09000d18,   // af.ga.lg_532 af.da.no_222  en.ha.un_540 ne.hi.un_740
  0x12000f12, 0x321606ec, 0x18001f0d, 0x1a3f35ee,   // lv.hu.un_640 de.hr.bs_644  cy.ga.un_540 zu.af.tl_422
  // [5fc0]
  0x06016bee, 0x04100a02, 0x051a6860, 0x646b2805,   // ceb.en.de_422 mk.be.ru_222  ig.tl.fr_664 sw.ceb.lg_333
  0x28000c0b, 0x64290eee, 0x21111a0c, 0x090d13a7,   // sv.sw.un_520 is.sl.lg_422  tl.ro.jw_543 bh.ne.hi_532
  0x191a55af, 0x2d0d1fa0, 0x6b101a0b, 0x0e280caf,   // rw.tl.gl_655 cy.cs.sk_322  tl.lt.ceb_542 sv.sw.is_655
  0x08006e0d, 0x55253b08, 0x55641aa4, 0x11070460,   // hmn.no.un_540 so.eu.rw_443  tl.lg.rw_433 ru.bg.ro_664
  // [5fd0]
  0x6b1f0c09, 0x32000804, 0x283555a0, 0x250b2304,   // sv.cy.ceb_444 no.bs.un_320  rw.zu.sw_322 ca.es.eu_332
  0x040a0808, 0x20002102, 0x55251aad, 0x081f3f04,   // uk.mk.ru_443 jw.sq.un_220  tl.eu.rw_643 af.cy.no_332
  0x2d001f05, 0x03000e05, 0x53000521, 0x0b0a2309,   // cy.sk.un_330 is.nl.un_330  fr.ht.un_860 ca.pt.es_444
  0x522055ad, 0x170a0408, 0x082916a0, 0x203f1304,   // rw.sq.ha_643 ru.mk.sr_443  hr.sl.no_322 et.af.sq_332
  // [5fe0]
  0x01000404, 0x3b3555ee, 0x0f082804, 0x1f0c0304,   // fi.en.un_320 rw.zu.so_422  sw.no.lv_332 nl.sv.cy_332
  0x08005219, 0x2a112307, 0x3f00280c, 0x35080205,   // ha.no.un_750 ca.ro.mt_432  sw.af.un_530 da.no.zu_333
  0x1f6b2707, 0x11050304, 0x3b190a08, 0x05000613,   // gd.ceb.cy_432 nl.fr.ro_332  pt.gl.so_443 de.fr.un_650
  0x3f000e21, 0x556b2812, 0x1c2952ad, 0x28001822,   // is.af.un_860 sw.ceb.rw_654  ha.sl.id_643 ga.sw.un_870
  // [5ff0]
  0x10005220, 0x28251f02, 0x05040f0c, 0x1e1c08a0,   // ha.lt.un_850 cy.eu.sw_222  lv.fi.fr_543 no.id.ms_322
  0x05001b14, 0x0c003f12, 0x190a28af, 0x29003f08,   // tr.fr.un_660 af.sv.un_640  sw.pt.gl_655 af.sl.un_430
  0x05000829, 0x0c060808, 0x3f000f23, 0x053f01a7,   // no.fr.un_960 no.de.sv_443  lv.af.un_880 en.af.fr_532
  0x10006e1a, 0x013f23af, 0x080a040d, 0x27002804,   // hmn.lt.un_760 ca.af.en_655  ru.mk.uk_554 sw.gd.un_320

  // [6000]
  0x04000820, 0x3f012a05, 0x0d000a02, 0x01531307,   // uk.ru.un_850 mt.en.af_333  pt.cs.un_220 et.ht.en_432
  0x210b05ee, 0x23075308, 0x06090f07, 0x0164180c,   // fr.es.jw_422 ht.it.ca_443  lv.pl.de_432 ga.lg.en_543
  0x0f030108, 0x3f061f08, 0x28645508, 0x030f0111,   // en.nl.lv_443 cy.de.af_443  rw.lg.sw_443 en.lv.nl_653
  0x282568af, 0x052301ec, 0x0f003f23, 0x233f0107,   // ig.eu.sw_655 en.ca.fr_644  af.lv.un_880 en.af.ca_432
  // [6010]
  0x28133bec, 0x1f001213, 0x28001309, 0x09000608,   // so.et.sw_644 hu.cy.un_650  et.sw.un_440 de.pl.un_430
  0x10000d07, 0x08020f07, 0x6e016b07, 0x1f002d02,   // cs.lt.un_420 lv.da.no_432  ceb.en.hmn_432 sk.cy.un_220
  0x1f0802ee, 0x080f0e08, 0x04130e07, 0x100e1ca0,   // da.no.cy_422 is.lv.no_443  is.et.fi_432 id.is.lt_322
  0x0e003513, 0x04003b05, 0x0b0a0eee, 0x11130ea0,   // zu.is.un_650 so.fi.un_330  is.pt.es_422 is.et.ro_322
  // [6020]
  0x110e0f04, 0x04000107, 0x1c003b12, 0x01000904,   // lv.is.ro_332 en.fi.un_420  so.id.un_640 pl.en.un_320
  0x213564a0, 0x64005202, 0x0a6b010c, 0x1b2a040c,   // lg.zu.jw_322 ha.lg.un_220  en.ceb.pt_543 fi.mt.tr_543
  0x04130d02, 0x521b1ea0, 0x1b5225ad, 0x6b4a550c,   // cs.et.fi_222 ms.tr.ha_322  eu.ha.tr_643 rw.yo.ceb_543
  0x350b0304, 0x6400210e, 0x550b19ee, 0x280903a4,   // nl.es.zu_332 jw.lg.un_550  gl.es.rw_422 nl.pl.sw_433
  // [6030]
  0x04536407, 0x0f003b0e, 0x645568ec, 0x070b2304,   // lg.ht.fi_432 so.lv.un_550  ig.rw.lg_644 ca.es.it_332
  0x6453550d, 0x21000307, 0x19003102, 0x322909a7,   // rw.ht.lg_554 nl.jw.un_420  az.gl.un_220 pl.sl.bs_532
  0x25021fa0, 0x17100aa4, 0x09050b04, 0x04000204,   // cy.da.eu_322 mk.be.sr_433  es.fr.pl_332 da.fi.un_320
  0x53001f13, 0x13005204, 0x190b0208, 0x352803a7,   // cy.ht.un_650 ha.et.un_320  da.es.gl_443 nl.sw.zu_532
  // [6040]
  0x28001812, 0x18001e04, 0x5300060d, 0x0f041aa0,   // ga.sw.un_640 ms.ga.un_320  de.ht.un_540 tl.fi.lv_322
  0x27180605, 0x2d0d68a4, 0x1c23530c, 0x0f000a08,   // de.ga.gd_333 ig.cs.sk_433  ht.ca.id_543 pt.lv.un_430
  0x10002505, 0x100b2804, 0x1c130d14, 0x12001a07,   // eu.lt.un_330 sw.es.lt_332  ne.bh.mr_666 tl.hu.un_420
  0x10071111, 0x1c641ea0, 0x211a6ba0, 0x09000a02,   // ro.bg.be_653 ms.lg.id_322  ceb.tl.jw_322 pt.pl.un_220
  // [6050]
  0x2500190e, 0x1213520c, 0x05005504, 0x1200090d,   // gl.eu.un_550 ha.et.hu_543  rw.fr.un_320 pl.hu.un_540
  0x1f05040c, 0x18210fa4, 0x28101aa0, 0x0d1613ad,   // fi.fr.cy_543 lv.jw.ga_433  tl.lt.sw_322 et.hr.cs_643
  0x281a35a7, 0x1029350c, 0x291e1c02, 0x212b1c02,   // zu.tl.sw_532 zu.sl.lt_543  id.ms.sl_222 id.vi.jw_222
  0x322935a4, 0x680c0855, 0x28004a08, 0x17286b08,   // zu.sl.bs_433 no.sv.ig_442  yo.sw.un_430 ceb.sw.sr_443
  // [6060]
  0x1c0a01a4, 0x3f1b0da0, 0x21001f21, 0x0c0820a0,   // en.pt.id_433 cs.tr.af_322  cy.jw.un_860 sq.no.sv_322
  0x1b311208, 0x32005302, 0x096435a6, 0x212a290c,   // hu.az.tr_443 ht.bs.un_220  zu.lg.pl_521 sl.mt.jw_543
  0x10130f08, 0x201605a0, 0x080313a0, 0x16006408,   // lv.et.lt_443 fr.hr.sq_322  et.nl.no_322 lg.hr.un_430
  0x1c2a1ea0, 0x200c06a4, 0x11282511, 0x03062504,   // ms.mt.id_322 de.sv.sq_433  eu.sw.ro_653 eu.de.nl_332
  // [6070]
  0x071017a0, 0x03211c0b, 0x25000a04, 0x080c0207,   // sr.be.bg_322 id.jw.nl_542  pt.eu.un_320 da.sv.no_432
  0x201b060c, 0x2800041b, 0x190b23ac, 0x030c2013,   // de.tr.sq_543 fi.sw.un_770  ca.es.gl_632 sq.sv.nl_665
  0x131827a9, 0x0e0806a0, 0x06031108, 0x02003f13,   // gd.ga.et_544 de.no.is_322  ro.nl.de_443 af.da.un_650
  0x20000e12, 0x0d000e11, 0x0200061b, 0x030806ee,   // is.sq.un_640 is.cs.un_630  de.da.un_770 de.no.nl_422
  // [6080]
  0x27002319, 0x103f04a7, 0x3f1f1008, 0x23001023,   // ca.gd.un_750 fi.af.lt_532  lt.cy.af_443 lt.ca.un_880
  0x0e001812, 0x0f022507, 0x2503060e, 0x286b1a0d,   // ga.is.un_640 eu.da.lv_432  de.nl.eu_555 tl.ceb.sw_554
  0x3f5310a4, 0x100411ad, 0x6b001a21, 0x180427a7,   // lt.ht.af_433 ro.ru.be_643  tl.ceb.un_860 gd.fi.ga_532
  0x0a23070c, 0x201f100c, 0x273f03af, 0x211c3fa0,   // it.ca.pt_543 lt.cy.sq_543  nl.af.gd_655 af.id.jw_322
  // [6090]
  0x201006a0, 0x03020cee, 0x1a3b28ee, 0x03080ca0,   // de.lt.sq_322 sv.da.nl_422  sw.so.tl_422 sv.no.nl_322
  0x35096407, 0x2100640c, 0x3f001f2a, 0x172d2904,   // lg.pl.zu_432 lg.jw.un_530  cy.af.un_970 sl.sk.sr_332
  0x1f3f100c, 0x64283512, 0x011f10ee, 0x31131ba4,   // lt.af.cy_543 zu.sw.lg_654  lt.cy.en_422 tr.et.az_433
  0x09002108, 0x0a0e235a, 0x211e1a08, 0x1a4a2813,   // jw.pl.un_430 ca.is.pt_553  tl.ms.jw_443 sw.yo.tl_665
  // [60a0]
  0x32006b04, 0x3f002307, 0x53006b07, 0x091c1355,   // ceb.bs.un_320 ca.af.un_420  ceb.ht.un_420 bh.mr.hi_442
  0x12000705, 0x0e2a0b08, 0x1b0f1012, 0x31001e08,   // it.hu.un_330 es.mt.is_443  lt.lv.tr_654 ms.az.un_430
  0x0e00120b, 0x10072d12, 0x6b213b0b, 0x18136b05,   // hu.is.un_520 sk.it.lt_654  so.jw.ceb_542 ceb.et.ga_333
  0x1900281a, 0x13000402, 0x6b111a05, 0x08001913,   // sw.gl.un_760 fi.et.un_220  tl.ro.ceb_333 gl.no.un_650
  // [60b0]
  0x05002a02, 0x27003b0c, 0x64133508, 0x0b0a5202,   // mt.fr.un_220 so.gd.un_530  zu.et.lg_443 ha.pt.es_222
  0x103b52a0, 0x2b0301ee, 0x355528a4, 0x132a6404,   // ha.so.lt_322 en.nl.vi_422  sw.rw.zu_433 lg.mt.et_332
  0x0b3b35a7, 0x3229080b, 0x3b1a6ba4, 0x3b521c07,   // zu.so.es_532 no.sl.bs_542  ceb.tl.so_433 id.ha.so_432
  0x64043baf, 0x04643b12, 0x4a0b0a14, 0x0b1853ee,   // so.fi.lg_655 so.lg.fi_654  pt.es.yo_666 ht.ga.es_422
  // [60c0]
  0x556413af, 0x1f2305a0, 0x170a2355, 0x3b000a05,   // et.lg.rw_655 fr.ca.cy_322  ca.pt.sr_442 pt.so.un_330
  0x132921a0, 0x3b0403a9, 0x35190a02, 0x52091fa0,   // jw.sl.et_322 nl.fi.so_544  pt.gl.zu_222 cy.pl.ha_322
  0x0b000104, 0x13001b09, 0x0c000e22, 0x3b1a6b08,   // en.es.un_320 tr.et.un_440  is.sv.un_870 ceb.tl.so_443
  0x553528a7, 0x2a5564a4, 0x2d290d08, 0x1707080c,   // sw.zu.rw_532 lg.rw.mt_433  cs.sl.sk_443 uk.bg.sr_543
  // [60d0]
  0x083f0204, 0x17002909, 0x0300641a, 0x0b0a19a9,   // da.af.no_332 sl.sr.un_440  lg.nl.un_760 gl.pt.es_544
  0x28643b12, 0x04006419, 0x12000911, 0x0900040d,   // so.lg.sw_654 lg.fi.un_750  pl.hu.un_630 fi.pl.un_540
  0x04136413, 0x28003508, 0x033f1fa4, 0x3f061fa4,   // lg.et.fi_665 zu.sw.un_430  cy.af.nl_433 cy.de.af_433
  0x070804a0, 0x07021007, 0x3f12105a, 0x1210010c,   // ru.uk.bg_322 lt.da.it_432  lt.hu.af_553 en.lt.hu_543
  // [60e0]
  0x4a282502, 0x2500040b, 0x35180104, 0x04001218,   // eu.sw.yo_222 fi.eu.un_520  en.ga.zu_332 hu.fi.un_740
  0x20002113, 0x64011fee, 0x0a5210a4, 0x53002105,   // jw.sq.un_650 cy.en.lg_422  lt.ha.pt_433 jw.ht.un_330
  0x35002805, 0x28203bad, 0x18000121, 0x0b522807,   // sw.zu.un_330 so.sq.sw_643  en.ga.un_860 sw.ha.es_432
  0x190a2da0, 0x1a5535a4, 0x4a6e2804, 0x1c2123a7,   // sk.pt.gl_322 zu.rw.tl_433  sw.hmn.yo_332 ca.jw.id_532
  // [60f0]
  0x28552004, 0x200f350c, 0x01001107, 0x11163211,   // sq.rw.sw_332 zu.lv.sq_543  ro.en.un_420 bs.hr.ro_653
  0x18200111, 0x02006e04, 0x55233b05, 0x18054aa0,   // en.sq.ga_653 hmn.da.un_320  so.ca.rw_333 yo.fr.ga_322
  0x1c271e07, 0x520b230c, 0x1e001802, 0x52556812,   // ms.gd.id_432 ca.es.ha_543  ga.ms.un_220 ig.rw.ha_654
  0x4a532907, 0x5528355a, 0x5535280c, 0x11004a23,   // sl.ht.yo_432 zu.sw.rw_553  sw.zu.rw_543 yo.ro.un_880
  // [6100]
  0x13000d21, 0x1a255512, 0x686b280c, 0x1b1821ee,   // ne.bh.un_860 rw.eu.tl_654  sw.ceb.ig_543 jw.ga.tr_422
  0x1f1c5307, 0x282055a7, 0x3500521a, 0x64001c08,   // ht.id.cy_432 rw.sq.sw_532  ha.zu.un_760 id.lg.un_430
  0x2800200e, 0x201b1104, 0x52005307, 0x64684aad,   // sq.sw.un_550 ro.tr.sq_332  ht.ha.un_420 yo.ig.lg_643
  0x31001709, 0x12001005, 0x1c2120ad, 0x21000107,   // sr.az.un_440 lt.hu.un_330  sq.jw.id_643 en.jw.un_420
  // [6110]
  0x29002d2b, 0x6400520c, 0x522a1fa7, 0x64005305,   // sk.sl.un_980 ha.lg.un_530  cy.mt.ha_532 ht.lg.un_330
  0x55111a09, 0x10132014, 0x10040a04, 0x23190bad,   // tl.ro.rw_444 sq.et.lt_666  mk.ru.be_332 es.gl.ca_643
  0x6b190111, 0x01093f07, 0x53003202, 0x033f06a6,   // en.gl.ceb_653 af.pl.en_432  bs.ht.un_220 de.af.nl_521
  0x3f0e08a4, 0x53001e02, 0x53182755, 0x3f0c0805,   // no.is.af_433 ms.ht.un_220  gd.ga.ht_442 no.sv.af_333
  // [6120]
  0x12083f07, 0x270618ac, 0x063f0ea0, 0x0e3f080c,   // af.no.hu_432 ga.de.gd_632  is.af.de_322 no.af.is_543
  0x1e1c3fec, 0x0400200b, 0x16001707, 0x230225ec,   // af.id.ms_644 sq.fi.un_520  sr.hr.un_420 eu.da.ca_644
  0x1a00351a, 0x351a3f0c, 0x0e103f07, 0x55642807,   // zu.tl.un_760 af.tl.zu_543  af.lt.is_432 sw.lg.rw_432
  0x1c002507, 0x2b1a6b07, 0x0c030607, 0x1b003b04,   // eu.id.un_420 ceb.tl.vi_432  de.nl.sv_432 so.tr.un_320
  // [6130]
  0x4a00180d, 0x050d53a0, 0x033f0ea4, 0x0e001a0d,   // ga.yo.un_540 ht.cs.fr_322  is.af.nl_433 tl.is.un_540
  0x5300280b, 0x17081109, 0x202d0d05, 0x2d0d0a55,   // sw.ht.un_520 ro.uk.sr_444  cs.sk.sq_333 pt.cs.sk_442
  0x13002007, 0x1c3521a4, 0x041a0fa4, 0x0f2510ad,   // sq.et.un_420 jw.zu.id_433  lv.tl.fi_433 lt.eu.lv_643
  0x190b23ec, 0x6b0604a4, 0x1e3b3f05, 0x04130e08,   // ca.es.gl_644 fi.de.ceb_433  af.so.ms_333 is.et.fi_443
  // [6140]
  0x351a6405, 0x1e100405, 0x040a08a0, 0x1c351f04,   // lg.tl.zu_333 fi.lt.ms_333  uk.mk.ru_322 cy.zu.id_332
  0x016b0807, 0x17003102, 0x28551e0b, 0x0312350b,   // no.ceb.en_432 az.sr.un_220  ms.rw.sw_542 zu.hu.nl_542
  0x2b352105, 0x2a003f05, 0x6b0810a7, 0x1f1b1213,   // jw.zu.vi_333 af.mt.un_330  lt.no.ceb_532 hu.tr.cy_665
  0x1e355505, 0x010523a0, 0x025313a9, 0x10640f55,   // rw.zu.ms_333 ca.fr.en_322  et.ht.da_544 lv.lg.lt_442
  // [6150]
  0x3200530c, 0x3f1106a0, 0x11040a12, 0x270f04a6,   // ht.bs.un_530 de.ro.af_322  mk.ru.ro_654 fi.lv.gd_521
  0x52350f08, 0x0f1006ee, 0x52213f05, 0x6b072da0,   // lv.zu.ha_443 de.lt.lv_422  af.jw.ha_333 sk.it.ceb_322
  0x112327a9, 0x35002021, 0x681c6408, 0x23071fa4,   // gd.ca.ro_544 sq.zu.un_860  lg.id.ig_443 cy.it.ca_433
  0x64000808, 0x4a006809, 0x1f2818ee, 0x07101105,   // no.lg.un_430 ig.yo.un_440  ga.sw.cy_422 ro.be.bg_333
  // [6160]
  0x1c205307, 0x0c64080b, 0x0b0952ac, 0x070b2808,   // ht.sq.id_432 no.lg.sv_542  ha.pl.es_632 sw.es.it_443
  0x35000312, 0x23000b02, 0x2152280c, 0x0955520c,   // nl.zu.un_640 es.ca.un_220  sw.ha.jw_543 ha.rw.pl_543
  0x07002a12, 0x12000521, 0x28002522, 0x21001c22,   // mt.it.un_640 fr.hu.un_860  eu.sw.un_870 id.jw.un_870
  0x012311ad, 0x21524aa9, 0x2300530b, 0x28523bad,   // ro.ca.en_643 yo.ha.jw_544  ht.ca.un_520 so.ha.sw_643
  // [6170]
  0x1e351a04, 0x01110704, 0x16002d0c, 0x01181f07,   // tl.zu.ms_332 it.ro.en_332  sk.hr.un_530 cy.ga.en_432
  0x1a005214, 0x11180955, 0x356b01ee, 0x113b2808,   // ha.tl.un_660 pl.ga.ro_442  en.ceb.zu_422 sw.so.ro_443
  0x3f030605, 0x27001107, 0x13113b11, 0x2100281b,   // de.nl.af_333 ro.gd.un_420  so.ro.et_653 sw.jw.un_770
  0x160d2955, 0x21681aad, 0x18120911, 0x1007040d,   // sl.cs.hr_442 tl.ig.jw_643  pl.hu.ga_653 ru.bg.be_554
  // [6180]
  0x64005221, 0x21000a04, 0x1c215212, 0x1a522811,   // ha.lg.un_860 pt.jw.un_320  ha.jw.id_654 sw.ha.tl_653
  0x0d2510ec, 0x211a6b07, 0x556b2802, 0x121013a0,   // lt.eu.cs_644 ceb.tl.jw_432  sw.ceb.rw_222 et.lt.hu_322
  0x07112112, 0x1b0e520c, 0x08021ba4, 0x686e0f55,   // jw.ro.it_654 ha.is.tr_543  tr.da.no_433 lv.hmn.ig_442
  0x021a5507, 0x0e311f11, 0x521c1a07, 0x08000c2b,   // rw.tl.da_432 cy.az.is_653  tl.id.ha_432 sv.no.un_980
  // [6190]
  0x21205512, 0x080c3faf, 0x250c20a7, 0x64000108,   // rw.sq.jw_654 af.sv.no_655  sq.sv.eu_532 en.lg.un_430
  0x53200908, 0x0c0225a0, 0x09113b0c, 0x04082504,   // pl.sq.ht_443 eu.da.sv_322  so.ro.pl_543 eu.no.fi_332
  0x093b1112, 0x64000e12, 0x11041709, 0x2500020e,   // ro.so.pl_654 is.lg.un_640  sr.ru.ro_444 da.eu.un_550
  0x083f02a0, 0x0b03060c, 0x4a00680e, 0x321729ad,   // da.af.no_322 de.nl.es_543  ig.yo.un_550 sl.sr.bs_643
  // [61a0]
  0x1f060905, 0x555305a0, 0x23530cee, 0x3b255504,   // pl.de.cy_333 fr.ht.rw_322  sv.ht.ca_422 rw.eu.so_332
  0x11081013, 0x20000a2b, 0x1f2b07af, 0x2d1310ee,   // be.uk.ro_665 pt.sq.un_980  it.vi.cy_655 lt.et.sk_422
  0x030c3f0c, 0x080a07ec, 0x06201f04, 0x1f0135ad,   // af.sv.nl_543 bg.mk.uk_644  cy.sq.de_332 zu.en.cy_643
  0x25081f04, 0x28553508, 0x161b25a0, 0x08111709,   // cy.no.eu_332 zu.rw.sw_443  eu.tr.hr_322 sr.ro.uk_444
  // [61b0]
  0x1200041a, 0x232025a4, 0x08023505, 0x07000423,   // fi.hu.un_760 eu.sq.ca_433  zu.da.no_333 ru.bg.un_880
  0x23202904, 0x2b190a0c, 0x13091cad, 0x18001a07,   // sl.sq.ca_332 pt.gl.vi_543  mr.hi.bh_643 tl.ga.un_420
  0x10170812, 0x10000709, 0x3f6e1312, 0x3b19070c,   // uk.sr.be_654 it.lt.un_440  et.hmn.af_654 it.gl.so_543
  0x35280755, 0x280306ec, 0x036e1302, 0x0e00190d,   // it.sw.zu_442 de.nl.sw_644  et.hmn.nl_222 gl.is.un_540
  // [61c0]
  0x1107270c, 0x031853a0, 0x3b6b5507, 0x10002819,   // gd.it.ro_543 ht.ga.nl_322  rw.ceb.so_432 sw.lt.un_750
  0x27066811, 0x68092812, 0x53006e04, 0x28000d12,   // ig.de.gd_653 sw.pl.ig_654  hmn.ht.un_320 cs.sw.un_640
  0x3f6e0307, 0x3b2907a7, 0x18273bee, 0x280705af,   // nl.hmn.af_432 it.sl.so_532  so.gd.ga_422 fr.it.sw_655
  0x276b07ee, 0x553b07a4, 0x64132308, 0x115568ec,   // it.ceb.gd_422 it.so.rw_433  ca.et.lg_443 ig.rw.ro_644
  // [61d0]
  0x2b0f25a7, 0x3500530d, 0x0a00280c, 0x3f036e05,   // eu.lv.vi_532 ht.zu.un_540  sw.pt.un_530 hmn.nl.af_333
  0x3b5564ee, 0x3512030c, 0x3529550c, 0x13036ea4,   // lg.rw.so_422 nl.hu.zu_543  rw.sl.zu_543 hmn.nl.et_433
  0x53684a08, 0x1a6452a4, 0x16002507, 0x321721a9,   // yo.ig.ht_443 ha.lg.tl_433  eu.hr.un_420 jw.sr.bs_544
  0x072853a0, 0x196e0a07, 0x4a001902, 0x0a6b070c,   // ht.sw.it_322 pt.hmn.gl_432  gl.yo.un_220 it.ceb.pt_543
  // [61e0]
  0x052707ad, 0x3b5253a4, 0x2a3b0712, 0x232511ee,   // it.gd.fr_643 ht.ha.so_433  it.so.mt_654 ro.eu.ca_422
  0x27060312, 0x0a07280c, 0x272806a9, 0x311b6b13,   // nl.de.gd_654 sw.it.pt_543  de.sw.gd_544 ceb.tr.az_665
  0x4a0f68ad, 0x55002913, 0x644a5512, 0x21000808,   // ig.lv.yo_643 sl.rw.un_650  rw.yo.lg_654 no.jw.un_430
  0x6b355511, 0x32163f14, 0x1c2764a4, 0x0a014aa0,   // rw.zu.ceb_653 af.hr.bs_666  lg.gd.id_433 yo.en.pt_322
  // [61f0]
  0x1b00110c, 0x1c00170c, 0x17000813, 0x522a0fee,   // ro.tr.un_530 sr.id.un_530  uk.sr.un_650 lv.mt.ha_422
  0x0d002914, 0x080a0408, 0x0305530c, 0x0f071107,   // sl.cs.un_660 ru.mk.uk_443  ht.fr.nl_543 ro.it.lv_432
  0x190b0aaf, 0x080221a4, 0x1f003f07, 0x0e002b04,   // pt.es.gl_655 jw.da.no_433  af.cy.un_420 vi.is.un_320
  0x1b001004, 0x6e6b1fa0, 0x211b1caf, 0x2900170d,   // lt.tr.un_320 cy.ceb.hmn_322  id.tr.jw_655 sr.sl.un_540
  // [6200]
  0x6b2835a0, 0x2d290d05, 0x120f10ee, 0x530f01a0,   // zu.sw.ceb_322 cs.sl.sk_333  lt.lv.hu_422 en.lv.ht_322
  0x21003504, 0x64002904, 0x1e1c52a0, 0x043b1ea7,   // zu.jw.un_320 sl.lg.un_320  ha.id.ms_322 ms.so.fi_532
  0x28001a02, 0x32311b08, 0x230501a0, 0x061b31a0,   // tl.sw.un_220 tr.az.bs_443  en.fr.ca_322 az.tr.de_322
  0x0a041008, 0x646b35ad, 0x551a6b08, 0x07310e04,   // be.ru.mk_443 zu.ceb.lg_643  ceb.tl.rw_443 is.az.it_332
  // [6210]
  0x1f080c07, 0x10001f0d, 0x1a5564ad, 0x6b211aa4,   // sv.no.cy_432 cy.lt.un_540  lg.rw.tl_643 tl.jw.ceb_433
  0x1120530c, 0x5355210c, 0x1b550f11, 0x1c101ea9,   // ht.sq.ro_543 jw.rw.ht_543  lv.rw.tr_653 ms.lt.id_544
  0x121f100c, 0x64551aad, 0x10003504, 0x53002802,   // lt.cy.hu_543 tl.rw.lg_643  zu.lt.un_320 sw.ht.un_220
  0x030152a0, 0x550652ad, 0x0c002505, 0x55311ba7,   // ha.en.nl_322 ha.de.rw_643  eu.sv.un_330 tr.az.rw_532
  // [6220]
  0x12100408, 0x3b002804, 0x2508025a, 0x2a005213,   // fi.lt.hu_443 sw.so.un_320  da.no.eu_553 ha.mt.un_650
  0x19120baf, 0x061b310d, 0x23200c08, 0x06311b11,   // es.hu.gl_655 az.tr.de_554  sv.sq.ca_443 tr.az.de_653
  0x03683f0d, 0x21101a0c, 0x022310a7, 0x122508a0,   // af.ig.nl_554 tl.lt.jw_543  lt.ca.da_532 no.eu.hu_322
  0x1e6425a4, 0x3b001105, 0x64211aa9, 0x0d173bad,   // eu.lg.ms_433 ro.so.un_330  tl.jw.lg_544 so.sr.cs_643
  // [6230]
  0x06172007, 0x2b0155a0, 0x102506a4, 0x0a003b04,   // sq.sr.de_432 rw.en.vi_322  de.eu.lt_433 so.pt.un_320
  0x35041f0c, 0x25060fad, 0x17111008, 0x3f0364a0,   // cy.fi.zu_543 lv.de.eu_643  be.ro.sr_443 lg.nl.af_322
  0x0e1809ec, 0x2800270c, 0x0e06130c, 0x1b2801a7,   // pl.ga.is_644 gd.sw.un_530  et.de.is_543 en.sw.tr_532
  0x52033fa4, 0x68000608, 0x073164a7, 0x3f0352ee,   // af.nl.ha_433 de.ig.un_430  lg.az.it_532 ha.nl.af_422
  // [6240]
  0x06002b02, 0x6b6806ec, 0x12230ba0, 0x06002721,   // vi.de.un_220 de.ig.ceb_644  es.ca.hu_322 gd.de.un_860
  0x0400132c, 0x23005319, 0x18062714, 0x0b2753a0,   // et.fi.un_990 ht.ca.un_750  gd.de.ga_666 ht.gd.es_322
  0x27003b08, 0x27002b19, 0x1a6b0108, 0x1f09060d,   // so.gd.un_430 vi.gd.un_750  en.ceb.tl_443 de.pl.cy_554
  0x27000121, 0x06001f13, 0x6b06010c, 0x1b2520ee,   // en.gd.un_860 cy.de.un_650  en.de.ceb_543 sq.eu.tr_422
  // [6250]
  0x2b53270c, 0x1f062bee, 0x2b001c09, 0x2b005309,   // gd.ht.vi_543 vi.de.cy_422  id.vi.un_440 ht.vi.un_440
  0x21521aec, 0x09000607, 0x06531f11, 0x2800680d,   // tl.ha.jw_644 de.pl.un_420  cy.ht.de_653 ig.sw.un_540
  0x23552aa0, 0x13043b0c, 0x4a1a11a9, 0x17001121,   // mt.rw.ca_322 so.fi.et_543  ro.tl.yo_544 ro.sr.un_860
  0x06001e02, 0x0f006408, 0x0a001134, 0x0600041b,   // ms.de.un_220 lg.lv.un_430  ro.pt.un_A80 fi.de.un_770
  // [6260]
  0x64001c04, 0x190407ee, 0x080a10a0, 0x16122055,   // id.lg.un_320 it.fi.gl_422  be.mk.uk_322 sq.hu.hr_442
  0x20030207, 0x080c020c, 0x20291711, 0x1b0768a9,   // da.nl.sq_432 da.sv.no_543  sr.sl.sq_653 ig.it.tr_544
  0x19001f02, 0x0d1016a4, 0x043528ee, 0x64070407,   // cy.gl.un_220 hr.lt.cs_433  sw.zu.fi_422 fi.it.lg_432
  0x12001f09, 0x3f00291a, 0x020553af, 0x2d0d21a4,   // cy.hu.un_440 sl.af.un_760  ht.fr.da_655 jw.cs.sk_433
  // [6270]
  0x6b010713, 0x0e000419, 0x1c1e2104, 0x0900040b,   // it.en.ceb_665 fi.is.un_750  jw.ms.id_332 fi.pl.un_520
  0x1e2d0d14, 0x3b041c04, 0x0c20120c, 0x322b16a0,   // cs.sk.ms_666 id.fi.so_332  hu.sq.sv_543 hr.vi.bs_322
  0x350206a9, 0x32000305, 0x063b1b08, 0x0820030c,   // de.da.zu_544 nl.bs.un_330  tr.so.de_443 nl.sq.no_543
  0x01001f08, 0x03002013, 0x23002513, 0x27001105,   // cy.en.un_430 sq.nl.un_650  eu.ca.un_650 ro.gd.un_330
  // [6280]
  0x17080255, 0x08020da4, 0x0c0229ad, 0x55132a0c,   // da.no.sr_442 cs.da.no_433  sl.da.sv_643 mt.et.rw_543
  0x0c00020d, 0x205528ec, 0x2028010c, 0x10000602,   // da.sv.un_540 sw.rw.sq_644  en.sw.sq_543 de.lt.un_220
  0x552801a4, 0x0a110712, 0x283555af, 0x2055280d,   // en.sw.rw_433 bg.ro.mk_654  rw.zu.sw_655 sw.rw.sq_554
  0x20000322, 0x683f06ad, 0x55352808, 0x35004a12,   // nl.sq.un_870 de.af.ig_643  sw.zu.rw_443 yo.zu.un_640
  // [6290]
  0x2000031b, 0x1c1304a9, 0x20000313, 0x2a2028a4,   // nl.sq.un_770 fi.et.id_544  nl.sq.un_650 sw.sq.mt_433
  0x080253ee, 0x2000211b, 0x28101aa4, 0x644a6804,   // ht.da.no_422 jw.sq.un_770  tl.lt.sw_433 ig.yo.lg_332
  0x64352507, 0x35001a08, 0x1b0a28a0, 0x27100f09,   // eu.zu.lg_432 tl.zu.un_430  sw.pt.tr_322 lv.lt.gd_444
  0x53092502, 0x29046807, 0x35282005, 0x10006b0d,   // eu.pl.ht_222 ig.fi.sl_432  sq.sw.zu_333 ceb.lt.un_540
  // [62a0]
  0x55002814, 0x02001308, 0x20552812, 0x0904100c,   // sw.rw.un_660 et.da.un_430  sw.rw.sq_654 lt.fi.pl_543
  0x090f350c, 0x552820af, 0x0e4a0a04, 0x352820af,   // zu.lv.pl_543 sq.sw.rw_655  pt.yo.is_332 sq.sw.zu_655
  0x010910a0, 0x3b112807, 0x110e2a07, 0x55003b21,   // lt.pl.en_322 sw.ro.so_432  mt.is.ro_432 so.rw.un_860
  0x25005214, 0x21004a09, 0x07002804, 0x1e211ca9,   // ha.eu.un_660 yo.jw.un_440  sw.it.un_320 id.jw.ms_544
  // [62b0]
  0x032a3ba0, 0x09001104, 0x3b281f02, 0x230a20a0,   // so.mt.nl_322 ro.pl.un_320  cy.sw.so_222 sq.pt.ca_322
  0x12042a12, 0x0f000205, 0x08100aa0, 0x2d090da4,   // mt.fi.hu_654 da.lv.un_330  mk.be.uk_322 cs.pl.sk_433
  0x01070509, 0x2b001112, 0x6b2052a9, 0x283b1fee,   // fr.it.en_444 ro.vi.un_640  ha.sq.ceb_544 cy.so.sw_422
  0x3f00091a, 0x17002911, 0x03001702, 0x0c001321,   // pl.af.un_760 sl.sr.un_630  sr.nl.un_220 et.sv.un_860
  // [62c0]
  0x06000c22, 0x644a0911, 0x11002813, 0x1c091312,   // sv.de.un_870 pl.yo.lg_653  sw.ro.un_650 bh.hi.mr_654
  0x0a003102, 0x55000912, 0x09005514, 0x0e004a09,   // az.pt.un_220 pl.rw.un_640  rw.pl.un_660 yo.is.un_440
  0x16190b0c, 0x2d0d3205, 0x0613040d, 0x2d0d3502,   // es.gl.hr_543 bs.cs.sk_333  fi.et.de_554 zu.cs.sk_222
  0x20005207, 0x3b00091a, 0x3b2820ad, 0x111827a0,   // ha.sq.un_420 pl.so.un_760  sq.sw.so_643 gd.ga.ro_322
  // [62d0]
  0x1e1a6b04, 0x055316a0, 0x2d0d0905, 0x0500280c,   // ceb.tl.ms_332 hr.ht.fr_322  pl.cs.sk_333 sw.fr.un_530
  0x08520504, 0x0c06130c, 0x1e551ca9, 0x352d0d08,   // fr.ha.no_332 et.de.sv_543  id.rw.ms_544 cs.sk.zu_443
  0x0900010c, 0x642810a4, 0x13000c13, 0x522a0502,   // en.pl.un_530 lt.sw.lg_433  sv.et.un_650 fr.mt.ha_222
  0x06350ea0, 0x11030507, 0x3f035509, 0x193b0bee,   // is.zu.de_322 fr.nl.ro_432  rw.nl.af_444 es.so.gl_422
  // [62e0]
  0x21103507, 0x2a001909, 0x321613ee, 0x28002120,   // zu.lt.jw_432 gl.mt.un_440  et.hr.bs_422 jw.sw.un_850
  0x1c001320, 0x283b55ee, 0x0b002a02, 0x35006b19,   // bh.mr.un_850 rw.so.sw_422  mt.es.un_220 ceb.zu.un_750
  0x0d6435a0, 0x230308a4, 0x64013f0c, 0x2a1955ee,   // zu.lg.cs_322 no.nl.ca_433  af.en.lg_543 rw.gl.mt_422
  0x214a1ca4, 0x28525304, 0x64001e08, 0x0f101e04,   // id.yo.jw_433 ht.ha.sw_332  ms.lg.un_430 ms.lt.lv_332
  // [62f0]
  0x02072a08, 0x281308a0, 0x311b13ec, 0x55351104,   // mt.it.da_443 no.et.sw_322  et.tr.az_644 ro.zu.rw_332
  0x1c6b01a4, 0x353255a4, 0x3b00310c, 0x551107ad,   // en.ceb.id_433 rw.bs.zu_433  az.so.un_530 it.ro.rw_643
  0x353b1308, 0x081104ec, 0x352555a4, 0x4a001a02,   // et.so.zu_443 ru.ro.uk_644  rw.eu.zu_433 tl.yo.un_220
  0x4a270fa0, 0x29001009, 0x1c0e4aac, 0x1600291a,   // lv.gd.yo_322 lt.sl.un_440  yo.is.id_632 sl.hr.un_760
  // [6300]
  0x0f001e07, 0x1a0e4aa0, 0x27181007, 0x4a075507,   // ms.lv.un_420 yo.is.tl_322  lt.ga.gd_432 rw.it.yo_432
  0x1e002707, 0x291310af, 0x1e1c6414, 0x64556860,   // gd.ms.un_420 lt.et.sl_655  lg.id.ms_666 ig.rw.lg_664
  0x050806ee, 0x070f05a4, 0x5500350e, 0x20255507,   // de.no.fr_422 fr.lv.it_433  zu.rw.un_550 rw.eu.sq_432
  0x1a001308, 0x0b18020c, 0x284a5208, 0x3f3b02a0,   // et.tl.un_430 da.ga.es_543  ha.yo.sw_443 da.so.af_322
  // [6310]
  0x3f060302, 0x033f4aa0, 0x060308a4, 0x2709550c,   // nl.de.af_222 yo.af.nl_322  no.nl.de_433 rw.pl.gd_543
  0x052d27a0, 0x0507010d, 0x116b6408, 0x0c64550b,   // gd.sk.fr_322 en.it.fr_554  lg.ceb.ro_443 rw.lg.sv_542
  0x100507a4, 0x0f100713, 0x070525a0, 0x070255af,   // it.fr.lt_433 it.lt.lv_665  eu.fr.it_322 rw.da.it_655
  0x1b1304ec, 0x1013025a, 0x072823a4, 0x08021caf,   // fi.et.tr_644 da.et.lt_553  ca.sw.it_433 id.da.no_655
  // [6320]
  0x19050a55, 0x11070aa4, 0x5300230e, 0x0b0a235a,   // pt.fr.gl_442 mk.bg.ro_433  ca.ht.un_550 ca.pt.es_553
  0x0d091c09, 0x082d0d02, 0x1c003f0c, 0x2123200c,   // mr.hi.ne_444 cs.sk.no_222  af.id.un_530 sq.ca.jw_543
  0x0a001118, 0x09211e04, 0x0d0602a0, 0x2b18010c,   // ro.mk.un_740 ms.jw.pl_332  da.de.cs_322 en.ga.vi_543
  0x292d2008, 0x09000d21, 0x09003f13, 0x05250107,   // sq.sk.sl_443 ne.hi.un_860  af.pl.un_650 en.eu.fr_432
  // [6330]
  0x0200100c, 0x322920af, 0x08001b12, 0x0b1923a6,   // lt.da.un_530 sq.sl.bs_655  tr.no.un_640 ca.gl.es_521
  0x0e311b0c, 0x0c005319, 0x4a006808, 0x08250f11,   // tr.az.is_543 ht.sv.un_750  ig.yo.un_430 lv.eu.no_653
  0x05001102, 0x5225100c, 0x0e002113, 0x125225a9,   // ro.fr.un_220 lt.eu.ha_543  jw.is.un_650 eu.ha.hu_544
  0x1a1c52af, 0x07100f07, 0x6b002504, 0x521a1e11,   // ha.id.tl_655 lv.lt.it_432  eu.ceb.un_320 ms.tl.ha_653
  // [6340]
  0x19110a0d, 0x0a002018, 0x2900200c, 0x2d2004af,   // pt.ro.gl_554 sq.pt.un_740  sq.sl.un_530 fi.sq.sk_655
  0x6b351a12, 0x29002018, 0x64001102, 0x13002817,   // tl.zu.ceb_654 sq.sl.un_740  ro.lg.un_220 sw.et.un_730
  0x231f6ea9, 0x13000708, 0x52682504, 0x080e6b5a,   // hmn.cy.ca_544 it.et.un_430  eu.ig.ha_332 ceb.is.no_553
  0x130452a0, 0x0b2b52a0, 0x10040fa4, 0x08001109,   // ha.fi.et_322 ha.vi.es_322  lv.fi.lt_433 ro.uk.un_440
  // [6350]
  0x1b521ea4, 0x04311bad, 0x1a643508, 0x08041113,   // ms.ha.tr_433 tr.az.fi_643  zu.lg.tl_443 ro.ru.uk_665
  0x0452070c, 0x0f130c0b, 0x311a20a0, 0x18190aad,   // it.ha.fi_543 sv.et.lv_542  sq.tl.az_322 pt.gl.ga_643
  0x0c1e2305, 0x020c2902, 0x3b11040c, 0x0f6b1a0d,   // ca.ms.sv_333 sl.sv.da_222  fi.ro.so_543 tl.ceb.lv_554
  0x313b2a07, 0x25190a05, 0x6428350c, 0x0b0a1b09,   // mt.so.az_432 pt.gl.eu_333  zu.sw.lg_543 tr.pt.es_444
  // [6360]
  0x16000c04, 0x321716ec, 0x13003107, 0x3f080ca0,   // sv.hr.un_320 hr.sr.bs_644  az.et.un_420 sv.no.af_322
  0x080220a9, 0x2b3b2807, 0x640428af, 0x01050204,   // sq.da.no_544 sw.so.vi_432  sw.fi.lg_655 da.fr.en_332
  0x1700070c, 0x0700050e, 0x0a1011ec, 0x2155640c,   // bg.sr.un_530 fr.it.un_550  ro.be.mk_644 lg.rw.jw_543
  0x280920a4, 0x53002d0d, 0x160710ee, 0x1009680e,   // sq.pl.sw_433 sk.ht.un_540  lt.it.hr_422 ig.pl.lt_555
  // [6370]
  0x0a286404, 0x10645508, 0x271825ad, 0x16202304,   // lg.sw.pt_332 rw.lg.lt_443  eu.ga.gd_643 ca.sq.hr_332
  0x3f08020d, 0x09200a55, 0x08065511, 0x1f182708,   // da.no.af_554 pt.sq.pl_442  rw.de.no_653 gd.ga.cy_443
  0x033f060c, 0x55000607, 0x25001f2b, 0x0825030c,   // de.af.nl_543 de.rw.un_420  cy.eu.un_980 nl.eu.no_543
  0x4a090da7, 0x2718050c, 0x282120ec, 0x3f0308a4,   // cs.pl.yo_532 fr.ga.gd_543  sq.jw.sw_644 no.nl.af_433
  // [6380]
  0x2d00350d, 0x190a0709, 0x0603250c, 0x06001813,   // zu.sk.un_540 it.pt.gl_444  eu.nl.de_543 ga.de.un_650
  0x082a07a9, 0x351e5209, 0x1306020d, 0x642510a7,   // it.mt.no_544 ha.ms.zu_444  da.de.et_554 lt.eu.lg_532
  0x08130405, 0x1200061a, 0x32111e0b, 0x2a000313,   // fi.et.no_333 de.hu.un_760  ms.ro.bs_542 nl.mt.un_650
  0x07081213, 0x2507640c, 0x17080a13, 0x102718ec,   // hu.no.it_665 lg.it.eu_543  mk.uk.sr_665 ga.gd.lt_644
  // [6390]
  0x18002019, 0x18190a08, 0x09001009, 0x06036407,   // sq.ga.un_750 pt.gl.ga_443  lt.pl.un_440 lg.nl.de_432
  0x03005314, 0x28001c0d, 0x3f030ca9, 0x06026405,   // ht.nl.un_660 id.sw.un_540  sv.nl.af_544 lg.da.de_333
  0x02001705, 0x05001f0c, 0x1a04680c, 0x060d25ee,   // sr.da.un_330 cy.fr.un_530  ig.fi.tl_543 eu.cs.de_422
  0x02000107, 0x133b6e05, 0x06043b07, 0x13033fa0,   // en.da.un_420 hmn.so.et_333  so.fi.de_432 af.nl.et_322
  // [63a0]
  0x11006b02, 0x120421a0, 0x6e002d0c, 0x1e285304,   // ceb.ro.un_220 jw.fi.hu_322  sk.hmn.un_530 ht.sw.ms_332
  0x18001302, 0x041328ee, 0x11321707, 0x0a111712,   // et.ga.un_220 sw.et.fi_422  sr.bs.ro_432 sr.ro.mk_654
  0x13042802, 0x04211c02, 0x20002907, 0x03001308,   // sw.fi.et_222 id.jw.fi_222  sl.sq.un_420 et.nl.un_430
  0x2b002104, 0x21003f13, 0x3b3f1307, 0x23281909,   // jw.vi.un_320 af.jw.un_650  et.af.so_432 gl.sw.ca_444
  // [63b0]
  0x643b6804, 0x21000413, 0x11006e07, 0x1a001902,   // ig.so.lg_332 fi.jw.un_650  hmn.ro.un_420 gl.tl.un_220
  0x21291e08, 0x18001a09, 0x283b64ad, 0x212d1c04,   // ms.sl.jw_443 tl.ga.un_440  lg.so.sw_643 id.sk.jw_332
  0x0e23080c, 0x323528a4, 0x281b1c0c, 0x04000c12,   // no.ca.is_543 sw.zu.bs_433  id.tr.sw_543 sv.fi.un_640
  0x522835a4, 0x16286411, 0x2b004a0e, 0x6b002304,   // zu.sw.ha_433 lg.sw.hr_653  yo.vi.un_550 ca.ceb.un_320
  // [63c0]
  0x310b19ee, 0x28006413, 0x0c060304, 0x16283508,   // gl.es.az_422 lg.sw.un_650  nl.de.sv_332 zu.sw.hr_443
  0x23181ea0, 0x21286404, 0x55356408, 0x55281f0c,   // ms.ga.ca_322 lg.sw.jw_332  lg.zu.rw_443 cy.sw.rw_543
  0x2b004a0c, 0x52283508, 0x00002a37, 0x21001f22,   // yo.vi.un_530 zu.sw.ha_443  mt.un.un_B00 cy.jw.un_870
  0x041e1cee, 0x102864af, 0x202821ad, 0x1a64555a,   // id.ms.fi_422 lg.sw.lt_655  jw.sw.sq_643 rw.lg.tl_553
  // [63d0]
  0x3b3528ec, 0x1e1c25ec, 0x09002105, 0x10640e07,   // sw.zu.so_644 eu.id.ms_644  jw.pl.un_330 is.lg.lt_432
  0x211c2008, 0x55006b22, 0x0f3f0ca9, 0x020f0807,   // sq.id.jw_443 ceb.rw.un_870  sv.af.lv_544 no.lv.da_432
  0x08050f07, 0x2d0220ec, 0x0400211a, 0x1f2a0c07,   // lv.fr.no_432 sq.da.sk_644  jw.fi.un_760 sv.mt.cy_432
  0x18002104, 0x19000f07, 0x040e28af, 0x07000a19,   // fa.ar.un_320 lv.gl.un_420  sw.is.fi_655 mk.bg.un_750
  // [63e0]
  0x0c003f0e, 0x1c0d1314, 0x271a0107, 0x3f2153a0,   // af.sv.un_550 bh.ne.mr_666  en.tl.gd_432 ht.jw.af_322
  0x0a050fa7, 0x10002507, 0x182b01ee, 0x1f0901a4,   // lv.fr.pt_532 eu.lt.un_420  en.vi.ga_422 en.pl.cy_433
  0x12001605, 0x040a2507, 0x555228a0, 0x0e002a07,   // hr.hu.un_330 eu.pt.fi_432  sw.ha.rw_322 mt.is.un_420
  0x1b2a21a4, 0x020c2907, 0x21121ea9, 0x2d006b04,   // jw.mt.tr_433 sl.sv.da_432  ms.hu.jw_544 ceb.sk.un_320
  // [63f0]
  0x17290d05, 0x0817070c, 0x1e2d0d08, 0x1e1c1205,   // cs.sl.sr_333 bg.sr.uk_543  cs.sk.ms_443 hu.id.ms_333
  0x036b01ee, 0x2500040d, 0x1e211baf, 0x082d250c,   // en.ceb.nl_422 fi.eu.un_540  tr.jw.ms_655 eu.sk.no_543
  0x10000418, 0x036b0204, 0x03001a08, 0x1b1225a4,   // ru.be.un_740 da.ceb.nl_332  tl.nl.un_430 eu.hu.tr_433
  0x2b000719, 0x311b1ca4, 0x0817110c, 0x12001a11,   // it.vi.un_750 id.tr.az_433  ro.sr.uk_543 tl.hu.un_630

  // [6400]
  0x6b080eaf, 0x29000923, 0x081c1ea4, 0x0f1e1c04,   // is.no.ceb_655 pl.sl.un_880  ms.id.no_433 id.ms.lv_332
  0x17162902, 0x3f001a0d, 0x2b0407a0, 0x10000f02,   // sl.hr.sr_222 tl.af.un_540  it.fi.vi_322 lv.lt.un_220
  0x1c521ea0, 0x6b060c0c, 0x0c080607, 0x01000f02,   // ms.ha.id_322 sv.de.ceb_543  de.no.sv_432 lv.en.un_220
  0x0928350c, 0x031e1c04, 0x4a2827a0, 0x13043b13,   // zu.sw.pl_543 id.ms.nl_332  gd.sw.yo_322 so.fi.et_665
  // [6410]
  0x531c210c, 0x553528ee, 0x643f3b0c, 0x4a002808,   // jw.id.ht_543 sw.zu.rw_422  so.af.lg_543 sw.yo.un_430
  0x23003f12, 0x4a3f3b08, 0x1e005504, 0x35006e08,   // af.ca.un_640 so.af.yo_443  rw.ms.un_320 hmn.zu.un_430
  0x09003520, 0x6e185212, 0x20252855, 0x3f4a13a4,   // zu.pl.un_850 ha.ga.hmn_654  sw.eu.sq_442 et.yo.af_433
  0x4a0e2d07, 0x0a001022, 0x0f3f130c, 0x552835ad,   // sk.is.yo_432 be.mk.un_870  et.af.lv_543 zu.sw.rw_643
  // [6420]
  0x310413a0, 0x4a002d12, 0x2d0d0ca4, 0x052d0d0d,   // et.fi.az_322 sk.yo.un_640  sv.cs.sk_433 cs.sk.fr_554
  0x281c010b, 0x0c006b08, 0x232d0d09, 0x13110d07,   // en.id.sw_542 ceb.sv.un_430  cs.sk.ca_444 cs.ro.et_432
  0x17101108, 0x0a29230b, 0x29231207, 0x230b19a7,   // ro.be.sr_443 ca.sl.pt_542  hu.ca.sl_432 gl.es.ca_532
  0x1c6b0cad, 0x132155a0, 0x2d5511ad, 0x29120ead,   // sv.ceb.id_643 rw.jw.et_322  ro.rw.sk_643 is.hu.sl_643
  // [6430]
  0x5300230c, 0x3200100c, 0x530c0da0, 0x17211c0e,   // ca.ht.un_530 lt.bs.un_530  cs.sv.ht_322 id.jw.sr_555
  0x0f23010c, 0x232b3ba0, 0x121b55a4, 0x01000614,   // en.ca.lv_543 so.vi.ca_322  rw.tr.hu_433 de.en.un_660
  0x23002b0c, 0x091355ee, 0x05551104, 0x03000108,   // vi.ca.un_530 rw.et.pl_422  ro.rw.fr_332 en.nl.un_430
  0x2a120e07, 0x1c001104, 0x1e1f1ca4, 0x553506a4,   // is.hu.mt_432 ro.id.un_320  id.cy.ms_433 de.zu.rw_433
  // [6440]
  0x0c6b2aec, 0x101c21a7, 0x0c0f050e, 0x211c53a4,   // mt.ceb.sv_644 jw.id.lt_532  fr.lv.sv_555 ht.id.jw_433
  0x0a2119ad, 0x2303010c, 0x08212a0c, 0x3f3b2504,   // gl.jw.pt_643 en.nl.ca_543  mt.jw.no_543 eu.so.af_332
  0x2a000e1a, 0x0f105207, 0x25211f08, 0x08021702,   // is.mt.un_760 ha.lt.lv_432  cy.jw.eu_443 sr.da.no_222
  0x1e1c07ee, 0x02013fa0, 0x0e002a33, 0x3f1b0304,   // it.id.ms_422 af.en.da_322  mt.is.un_A70 nl.tr.af_332
  // [6450]
  0x1a0f1b11, 0x231729ec, 0x03233fa0, 0x21641705,   // tr.lv.tl_653 sl.sr.ca_644  af.ca.nl_322 sr.lg.jw_333
  0x203b5307, 0x080c0107, 0x180f01ad, 0x20030107,   // ht.so.sq_432 en.sv.no_432  en.lv.ga_643 en.nl.sq_432
  0x351925a7, 0x19014aa0, 0x106455a9, 0x641f550c,   // eu.gl.zu_532 yo.en.gl_322  rw.lg.lt_544 rw.cy.lg_543
  0x080f2908, 0x532a21ee, 0x0f132107, 0x0e3f03a0,   // sl.lv.no_443 jw.mt.ht_422  jw.et.lv_432 nl.af.is_322
  // [6460]
  0x0e00272a, 0x25033f12, 0x033f25ac, 0x080c530c,   // gd.is.un_970 af.nl.eu_654  eu.af.nl_632 ht.sv.no_543
  0x011a5302, 0x0818270d, 0x0b2d1904, 0x551b35ee,   // ht.tl.en_222 gd.ga.no_554  gl.sk.es_332 zu.tr.rw_422
  0x2d295504, 0x3b645302, 0x5528640c, 0x3f006b04,   // rw.sl.sk_332 ht.lg.so_222  lg.sw.rw_543 ceb.af.un_320
  0x05006e07, 0x2d0b19a0, 0x28006b14, 0x2300200b,   // hmn.fr.un_420 gl.es.sk_322  ceb.sw.un_660 sq.ca.un_520
  // [6470]
  0x0c031302, 0x0900030e, 0x20000512, 0x0f001304,   // et.nl.sv_222 nl.pl.un_550  fr.sq.un_640 et.lv.un_320
  0x0900030d, 0x03002902, 0x20000312, 0x04281b55,   // nl.pl.un_540 sl.nl.un_220  nl.sq.un_640 tr.sw.fi_442
  0x211304ec, 0x2300030e, 0x1b1110a4, 0x12000d1a,   // fi.et.jw_644 nl.ca.un_550  lt.ro.tr_433 cs.hu.un_760
  0x25130460, 0x113104ee, 0x0300090c, 0x2d120dad,   // fi.et.eu_664 fi.az.ro_422  pl.nl.un_530 cs.hu.sk_643
  // [6480]
  0x04000602, 0x040e09af, 0x100a17a0, 0x1a1e06ee,   // de.fi.un_220 pl.is.fi_655  sr.mk.be_322 de.ms.tl_422
  0x11001004, 0x311b1108, 0x5200250b, 0x09080204,   // lt.ro.un_320 ro.tr.az_443  eu.ha.un_520 da.no.pl_332
  0x1b0111a0, 0x08090304, 0x3f2103ac, 0x20000307,   // ro.en.tr_322 nl.pl.no_332  nl.jw.af_632 nl.sq.un_420
  0x1b1011af, 0x1a6b2814, 0x23053ba0, 0x04311207,   // ro.lt.tr_655 sw.ceb.tl_666  so.fr.ca_322 hu.az.fi_432
  // [6490]
  0x0f200907, 0x07192307, 0x09190bad, 0x25001c04,   // pl.sq.lv_432 ca.gl.it_432  es.gl.pl_643 id.eu.un_320
  0x53060204, 0x0f00131b, 0x07001902, 0x1105130c,   // da.de.ht_332 et.lv.un_770  gl.it.un_220 et.fr.ro_543
  0x313b200c, 0x55190b08, 0x1b002509, 0x29001222,   // sq.so.az_543 es.gl.rw_443  eu.tr.un_440 hu.sl.un_870
  0x0a255307, 0x3b1f6e0d, 0x64552805, 0x19000621,   // ht.eu.pt_432 hmn.cy.so_554  sw.rw.lg_333 de.gl.un_860
  // [64a0]
  0x2a072513, 0x531b3111, 0x06000802, 0x093b1f04,   // eu.it.mt_665 az.tr.ht_653  no.de.un_220 cy.so.pl_332
  0x011f6e0b, 0x13100fa4, 0x310c2707, 0x070817ad,   // hmn.cy.en_542 lv.lt.et_433  gd.sv.az_432 sr.uk.bg_643
  0x123104af, 0x12000405, 0x536b4a04, 0x0703010c,   // fi.az.hu_655 fi.hu.un_330  yo.ceb.ht_332 en.nl.it_543
  0x1e0604a0, 0x1e0d3155, 0x04101712, 0x07190a14,   // fi.de.ms_322 az.cs.ms_442  sr.be.ru_654 pt.gl.it_666
  // [64b0]
  0x17164aa0, 0x32161b09, 0x16003f12, 0x0700011a,   // yo.hr.sr_322 tr.hr.bs_444  af.hr.un_640 en.it.un_760
  0x21055304, 0x53000a0e, 0x0409120c, 0x08001f05,   // ht.fr.jw_332 pt.ht.un_550  hu.pl.fi_543 cy.no.un_330
  0x1300310d, 0x100a17ad, 0x04071012, 0x07000a2a,   // az.et.un_540 sr.mk.be_643  be.bg.ru_654 mk.bg.un_970
  0x130812a4, 0x12101f09, 0x1f1210a9, 0x0a1229ee,   // hu.no.et_433 cy.lt.hu_444  lt.hu.cy_544 sl.hu.pt_422
  // [64c0]
  0x02001012, 0x0c200804, 0x232d0d65, 0x11001212,   // lt.da.un_640 no.sq.sv_332  cs.sk.ca_763 hu.ro.un_640
  0x52553560, 0x1e003f19, 0x0d122da0, 0x0a000d08,   // zu.rw.ha_664 af.ms.un_750  sk.hu.cs_322 cs.pt.un_430
  0x0a2a05a0, 0x1f033fa0, 0x2a1e1c05, 0x071117ad,   // fr.mt.pt_322 af.nl.cy_322  id.ms.mt_333 sr.ro.bg_643
  0x042852ad, 0x351923a0, 0x06350302, 0x190a25ec,   // ha.sw.fi_643 ca.gl.zu_322  nl.zu.de_222 eu.pt.gl_644
  // [64d0]
  0x3f061ea4, 0x110a2304, 0x19002b0b, 0x12002004,   // ms.de.af_433 ca.pt.ro_332  vi.gl.un_520 sq.hu.un_320
  0x3f2711a4, 0x112307a9, 0x271e1ca4, 0x10131ea4,   // ro.gd.af_433 it.ca.ro_544  id.ms.gd_433 ms.et.lt_433
  0x172d2902, 0x03120660, 0x281801ee, 0x131c0d5a,   // sl.sk.sr_222 de.hu.nl_664  en.ga.sw_422 ne.mr.bh_553
  0x2d001011, 0x2000190d, 0x120f10a9, 0x0f11130d,   // lt.sk.un_630 gl.sq.un_540  lt.lv.hu_544 et.ro.lv_554
  // [64e0]
  0x21273fa0, 0x01005505, 0x04120c12, 0x1b1f0911,   // af.gd.jw_322 rw.en.un_330  sv.hu.fi_654 pl.cy.tr_653
  0x06523507, 0x27005204, 0x321709a4, 0x3f3552a0,   // zu.ha.de_432 ha.gd.un_320  pl.sr.bs_433 ha.zu.af_322
  0x1e1c52af, 0x17000808, 0x1e1c21ec, 0x0f131014,   // ha.id.ms_655 uk.sr.un_430  jw.id.ms_644 lt.et.lv_666
  0x0e122aa0, 0x3229160c, 0x21523fad, 0x210f1c0c,   // mt.hu.is_322 hr.sl.bs_543  af.ha.jw_643 id.lv.jw_543
  // [64f0]
  0x21181107, 0x0b2a0708, 0x52004a02, 0x6b211cee,   // ro.ga.jw_432 it.mt.es_443  yo.ha.un_220 id.jw.ceb_422
  0x55000813, 0x021008a0, 0x135564a4, 0x12162aad,   // no.rw.un_650 no.lt.da_322  lg.rw.et_433 mt.hr.hu_643
  0x0e000813, 0x11001c08, 0x08020314, 0x0a000304,   // no.is.un_650 id.ro.un_430  nl.da.no_666 nl.pt.un_320
  0x6b6801a0, 0x03003504, 0x3f6835a4, 0x05001119,   // en.ig.ceb_322 zu.nl.un_320  zu.ig.af_433 ro.fr.un_750
  // [6500]
  0x0b000705, 0x35201708, 0x171209ee, 0x04005209,   // it.es.un_330 sr.sq.zu_443  pl.hu.sr_422 ha.fi.un_440
  0x04311b08, 0x642804ee, 0x06311b08, 0x100f0811,   // tr.az.fi_443 fi.sw.lg_422  tr.az.de_443 no.lv.lt_653
  0x2d001714, 0x1e1306ee, 0x3f000f13, 0x4a190b02,   // sr.sk.un_660 de.et.ms_422  lv.af.un_650 es.gl.yo_222
  0x64001305, 0x11170a11, 0x021a6b55, 0x09172dee,   // et.lg.un_330 mk.sr.ro_653  ceb.tl.da_442 sk.sr.pl_422
  // [6510]
  0x0400250c, 0x1c2b01a6, 0x083f0307, 0x190501ee,   // eu.fi.un_530 en.vi.id_521  nl.af.no_432 en.fr.gl_422
  0x4a1e550c, 0x311b09a7, 0x290904a0, 0x19050a0b,   // rw.ms.yo_543 pl.tr.az_532  fi.pl.sl_322 pt.fr.gl_542
  0x520e0412, 0x55005207, 0x52030107, 0x181123a4,   // fi.is.ha_654 ha.rw.un_420  en.nl.ha_432 ca.ro.ga_433
  0x18050107, 0x0d00160c, 0x01000205, 0x060c0fee,   // en.fr.ga_432 hr.cs.un_530  da.en.un_330 lv.sv.de_422
  // [6520]
  0x531f27a0, 0x0b192355, 0x1e001a05, 0x23000414,   // gd.cy.ht_322 ca.gl.es_442  tl.ms.un_330 fi.ca.un_660
  0x4a3f2504, 0x526435a7, 0x1e00030d, 0x17531107,   // eu.af.yo_332 zu.lg.ha_532  nl.ms.un_540 ro.ht.sr_432
  0x190a3205, 0x190b2312, 0x0f32250d, 0x0b005207,   // bs.pt.gl_333 ca.es.gl_654  eu.bs.lv_554 ha.es.un_420
  0x230a0bec, 0x53004a09, 0x2800011a, 0x52002d0d,   // es.pt.ca_644 yo.ht.un_440  en.sw.un_760 sk.ha.un_540
  // [6530]
  0x521729a9, 0x05520655, 0x0b002309, 0x55005307,   // sl.sr.ha_544 de.ha.fr_442  ca.es.un_440 ht.rw.un_420
  0x1e1c20ec, 0x09001804, 0x16002921, 0x0d0f5508,   // sq.id.ms_644 ga.pl.un_320  sl.hr.un_860 rw.lv.cs_443
  0x53321704, 0x01251fa0, 0x230a19a9, 0x1e043b12,   // sr.bs.ht_332 cy.eu.en_322  gl.pt.ca_544 so.fi.ms_654
  0x28003b0c, 0x29126ea4, 0x043f0a04, 0x100c0407,   // so.sw.un_530 hmn.hu.sl_433  pt.af.fi_332 fi.sv.lt_432
  // [6540]
  0x533f2a04, 0x06030fad, 0x524a10ad, 0x130f08a4,   // mt.af.ht_332 lv.nl.de_643  lt.yo.ha_643 no.lv.et_433
  0x12001709, 0x3b006e02, 0x0a002307, 0x04002308,   // sr.hu.un_440 hmn.so.un_220  ca.pt.un_420 ca.fi.un_430
  0x23000e19, 0x1c00530b, 0x270b1808, 0x04521ea4,   // is.ca.un_750 ht.id.un_520  ga.es.gd_443 ms.ha.fi_433
  0x0b4a0555, 0x203b0607, 0x1c216407, 0x06002705,   // fr.yo.es_442 de.so.sq_432  lg.jw.id_432 gd.de.un_330
  // [6550]
  0x68356411, 0x310264ec, 0x101707ee, 0x27071fad,   // lg.zu.ig_653 lg.da.az_644  bg.sr.be_422 cy.it.gd_643
  0x04283b09, 0x025364ee, 0x28643b02, 0x551064a0,   // so.sw.fi_444 lg.ht.da_422  so.lg.sw_222 lg.lt.rw_322
  0x1b316b0c, 0x29001607, 0x31000f18, 0x04132aa0,   // ceb.az.tr_543 hr.sl.un_420  lv.az.un_740 mt.et.fi_322
  0x0d062da9, 0x1a093507, 0x10006405, 0x552835af,   // sk.de.cs_544 zu.pl.tl_432  lg.lt.un_330 zu.sw.rw_655
  // [6560]
  0x1a1b02a0, 0x0407080c, 0x1c0e2908, 0x08100a02,   // da.tr.tl_322 uk.bg.ru_543  sl.is.id_443 mk.be.uk_222
  0x2d120d02, 0x291c0e04, 0x2000310d, 0x35003108,   // cs.hu.sk_222 is.id.sl_332  az.sq.un_540 az.zu.un_430
  0x09130d60, 0x2d0d31a0, 0x082d0d13, 0x32291c04,   // ne.bh.hi_664 az.cs.sk_322  cs.sk.no_665 id.sl.bs_332
  0x1000310e, 0x3b000a04, 0x3b290eee, 0x1f1020ad,   // az.lt.un_550 pt.so.un_320  is.sl.so_422 sq.lt.cy_643
  // [6570]
  0x0e1c21a0, 0x283135a4, 0x04645507, 0x210435a4,   // jw.id.is_322 zu.az.sw_433  rw.lg.fi_432 zu.fi.jw_433
  0x286b550c, 0x2a1b3507, 0x1b1304a4, 0x042031ad,   // rw.ceb.sw_543 zu.tr.mt_432  fi.et.tr_433 az.sq.fi_643
  0x28046407, 0x35135508, 0x1b313505, 0x12003511,   // lg.fi.sw_432 rw.et.zu_443  zu.az.tr_333 zu.hu.un_630
  0x0900350c, 0x553b3507, 0x1a553508, 0x2100550e,   // zu.pl.un_530 zu.so.rw_432  zu.rw.tl_443 rw.jw.un_550
  // [6580]
  0x13001702, 0x35002104, 0x12003512, 0x13005213,   // sr.et.un_220 jw.zu.un_320  zu.hu.un_640 ha.et.un_650
  0x4a002813, 0x0464280c, 0x642855a4, 0x03130407,   // sw.yo.un_650 sw.lg.fi_543  rw.sw.lg_433 fi.et.nl_432
  0x312d1b07, 0x23080207, 0x13042807, 0x3f0804ee,   // tr.sk.az_432 da.no.ca_432  sw.fi.et_432 fi.no.af_422
  0x1b1c1eee, 0x12001108, 0x64130404, 0x201c2105,   // ms.id.tr_422 ro.hu.un_430  fi.et.lg_332 jw.id.sq_333
  // [6590]
  0x4a005205, 0x321752ee, 0x033f0404, 0x4a002b19,   // ha.yo.un_330 ha.sr.bs_422  fi.af.nl_332 vi.yo.un_750
  0x31004a04, 0x05001f05, 0x0d000a08, 0x1a004a05,   // yo.az.un_320 cy.fr.un_330  pt.cs.un_430 yo.tl.un_330
  0x171b31a4, 0x250120a4, 0x3b000413, 0x00002837,   // az.tr.sr_433 sq.en.eu_433  fi.so.un_650 sw.un.un_B00
  0x0d282005, 0x53002823, 0x0d005305, 0x53006423,   // sq.sw.cs_333 sw.ht.un_880  ht.cs.un_330 lg.ht.un_880
  // [65a0]
  0x4a006419, 0x5300682a, 0x03006e04, 0x68001f1a,   // lg.yo.un_750 ig.ht.un_970  hmn.nl.un_320 cy.ig.un_760
  0x0a552008, 0x23070a0c, 0x6455680c, 0x53645513,   // sq.rw.pt_443 pt.it.ca_543  ig.rw.lg_543 rw.lg.ht_665
  0x55005302, 0x0900532a, 0x2b006808, 0x4a096411,   // ht.rw.un_220 ht.pl.un_970  ig.vi.un_430 lg.pl.yo_653
  0x253520a4, 0x0a002d07, 0x1f5564af, 0x23112004,   // sq.zu.eu_433 sk.pt.un_420  lg.rw.cy_655 sq.ro.ca_332
  // [65b0]
  0x27016ba0, 0x310913ee, 0x1f180107, 0x11201ea4,   // ceb.en.gd_322 et.pl.az_422  en.ga.cy_432 ms.sq.ro_433
  0x2a001f22, 0x0a000e02, 0x190a4a09, 0x5500531a,   // cy.mt.un_870 is.pt.un_220  yo.pt.gl_444 ht.rw.un_760
  0x556852af, 0x200102a0, 0x3f6b1a0e, 0x6b1a1faf,   // ha.ig.rw_655 da.en.sq_322  tl.ceb.af_555 cy.tl.ceb_655
  0x3f001805, 0x1000230d, 0x0200350c, 0x2a645504,   // ga.af.un_330 ca.lt.un_540  zu.da.un_530 rw.lg.mt_332
  // [65c0]
  0x01050808, 0x556b1ca0, 0x0e6b1305, 0x11000d04,   // no.fr.en_443 id.ceb.rw_322  et.ceb.is_333 cs.ro.un_320
  0x13101155, 0x111013ee, 0x3f0a1804, 0x06003b07,   // ro.lt.et_442 et.lt.ro_422  ga.pt.af_332 so.de.un_420
  0x1a5325a4, 0x160f10a0, 0x043b0804, 0x550f110b,   // eu.ht.tl_433 lt.lv.hr_322  no.so.fi_332 ro.lv.rw_542
  0x64006b05, 0x01000f04, 0x13000f12, 0x12556ba0,   // ceb.lg.un_330 lv.en.un_320  lv.et.un_640 ceb.rw.hu_322
  // [65d0]
  0x0a054aa0, 0x530f1305, 0x3b080e07, 0x1004130e,   // yo.fr.pt_322 et.lv.ht_333  is.no.so_432 et.fi.lt_555
  0x062a5507, 0x6855110c, 0x2564230b, 0x1c002002,   // rw.mt.de_432 ro.rw.ig_543  ca.lg.eu_542 sq.id.un_220
  0x05001604, 0x4a5352a0, 0x28001214, 0x18684a04,   // hr.fr.un_320 ha.ht.yo_322  hu.sw.un_660 yo.ig.ga_332
  0x0e0c08ee, 0x52001c05, 0x283564a0, 0x55004a34,   // no.sv.is_422 id.ha.un_330  lg.zu.sw_322 yo.rw.un_A80
  // [65e0]
  0x13000f1a, 0x1b4a2808, 0x010628ee, 0x03026bee,   // lv.et.un_760 sw.yo.tr_443  sw.de.en_422 ceb.da.nl_422
  0x042513ad, 0x0e02200c, 0x110d2d11, 0x6e25130d,   // et.eu.fi_643 sq.da.is_543  sk.cs.ro_653 et.eu.hmn_554
  0x281b35ee, 0x3213120c, 0x19002105, 0x2d002807,   // zu.tr.sw_422 hu.et.bs_543  jw.gl.un_330 sw.sk.un_420
  0x161035a7, 0x281a6bee, 0x080255a0, 0x1f066809,   // zu.lt.hr_532 ceb.tl.sw_422  rw.da.no_322 ig.de.cy_444
  // [65f0]
  0x2d060807, 0x021a6e07, 0x1a003b04, 0x29005504,   // no.de.sk_432 hmn.tl.da_432  so.tl.un_320 rw.sl.un_320
  0x12001a23, 0x354a53ec, 0x280855ee, 0x04131a07,   // tl.hu.un_880 ht.yo.zu_644  rw.no.sw_422 tl.et.fi_432
  0x12524aa0, 0x53231902, 0x0f000407, 0x3568285a,   // yo.ha.hu_322 gl.ca.ht_222  fi.lv.un_420 sw.ig.zu_553
  0x19030ba4, 0x31002702, 0x681f06af, 0x311b1a0b,   // es.nl.gl_433 gd.az.un_220  de.cy.ig_655 tl.tr.az_542
  // [6600]
  0x0a1011ee, 0x030b060e, 0x1825040c, 0x130c25a9,   // ro.be.mk_422 de.es.nl_555  fi.eu.ga_543 eu.sv.et_544
  0x19350b07, 0x052d530b, 0x28124aec, 0x6b2501a9,   // es.zu.gl_432 ht.sk.fr_542  yo.hu.sw_644 en.eu.ceb_544
  0x110405af, 0x033f13a0, 0x1b1228a0, 0x2527040c,   // fr.fi.ro_655 et.af.nl_322  sw.hu.tr_322 fi.gd.eu_543
  0x04170aee, 0x35286413, 0x1900120c, 0x110a0812,   // mk.sr.ru_422 lg.sw.zu_665  hu.gl.un_530 uk.mk.ro_654
  // [6610]
  0x55286455, 0x0a005307, 0x3f00230e, 0x06020cee,   // lg.sw.rw_442 ht.pt.un_420  ca.af.un_550 sv.da.de_422
  0x032012ec, 0x32170fa0, 0x3f1303a9, 0x233153a0,   // hu.sq.nl_644 lv.sr.bs_322  nl.et.af_544 ht.az.ca_322
  0x0f3f03ec, 0x20003f08, 0x1b533104, 0x0a001114,   // nl.af.lv_644 af.sq.un_430  az.ht.tr_332 ro.pt.un_660
  0x286435ad, 0x1e1c0b05, 0x040811a7, 0x11550e07,   // zu.lg.sw_643 es.id.ms_333  ro.uk.ru_532 is.rw.ro_432
  // [6620]
  0x121023a0, 0x1100040e, 0x1127180c, 0x1f00110d,   // ca.lt.hu_322 ru.ro.un_550  ga.gd.ro_543 ro.cy.un_540
  0x05002513, 0x084a01ee, 0x2d0d2108, 0x120b2302,   // eu.fr.un_650 en.yo.no_422  jw.cs.sk_443 ca.es.hu_222
  0x1c5321a0, 0x35552904, 0x0d122dad, 0x2b004a08,   // jw.ht.id_322 sl.rw.zu_332  sk.hu.cs_643 yo.vi.un_430
  0x05235309, 0x27000705, 0x10001c04, 0x53050aa7,   // ht.ca.fr_444 it.gd.un_330  id.lt.un_320 pt.fr.ht_532
  // [6630]
  0x311b25af, 0x310e3fa0, 0x21000704, 0x28005307,   // eu.tr.az_655 af.is.az_322  it.jw.un_320 ht.sw.un_420
  0x27012304, 0x1f191b55, 0x07000b04, 0x3b002305,   // ca.en.gd_332 tr.gl.cy_442  es.it.un_320 ca.so.un_330
  0x250e3bee, 0x08001e04, 0x0800042c, 0x09001214,   // so.is.eu_422 ms.no.un_320  ru.uk.un_990 hu.pl.un_660
  0x6b041aee, 0x190b0d05, 0x11550fee, 0x4a00522a,   // tl.fi.ceb_422 cs.es.gl_333  lv.rw.ro_422 ha.yo.un_970
  // [6640]
  0x120d0705, 0x52002005, 0x061f5207, 0x0213080c,   // it.cs.hu_333 sq.ha.un_330  ha.cy.de_432 no.et.da_543
  0x644a0411, 0x6e6855ad, 0x1f1a13a0, 0x6819200d,   // fi.yo.lg_653 rw.ig.hmn_643  et.tl.cy_322 sq.gl.ig_554
  0x4a1c1e07, 0x3f080cac, 0x00002537, 0x64171905,   // ms.id.yo_432 sv.no.af_632  eu.un.un_B00 gl.sr.lg_333
  0x6b2a5507, 0x0455250c, 0x1a080c0c, 0x20045502,   // rw.mt.ceb_432 eu.rw.fi_543  sv.no.tl_543 rw.fi.sq_222
  // [6650]
  0x1a313204, 0x201a5207, 0x202910ee, 0x03283f0c,   // bs.az.tl_332 ha.tl.sq_432  lt.sl.sq_422 af.sw.nl_543
  0x0621010c, 0x2d290d0d, 0x13000404, 0x28116802,   // en.jw.de_543 cs.sl.sk_554  fi.et.un_320 ig.ro.sw_222
  0x0d000c05, 0x13002907, 0x53003b12, 0x3b2b5304,   // sv.cs.un_330 sl.et.un_420  so.ht.un_640 ht.vi.so_332
  0x52002913, 0x21091c02, 0x6b001b07, 0x201113a0,   // sl.ha.un_650 id.pl.jw_222  tr.ceb.un_420 et.ro.sq_322
  // [6660]
  0x11040805, 0x0e2909ac, 0x0b0a1105, 0x04103b11,   // uk.ru.ro_333 pl.sl.is_632  ro.pt.es_333 so.lt.fi_653
  0x3120350c, 0x13006804, 0x02536804, 0x0e003f05,   // zu.sq.az_543 ig.et.un_320  ig.ht.da_332 af.is.un_330
  0x21202807, 0x0d090f14, 0x0d2d0208, 0x131b3ba0,   // sw.sq.jw_432 lv.pl.cs_666  da.sk.cs_443 so.tr.et_322
  0x64041007, 0x2d190b02, 0x110a2508, 0x18002014,   // lt.fi.lg_432 es.gl.sk_222  eu.pt.ro_443 sq.ga.un_660
  // [6670]
  0x2d0d2355, 0x04126407, 0x0500531b, 0x043b0912,   // ca.cs.sk_442 lg.hu.fi_432  ht.fr.un_770 pl.so.fi_654
  0x0500250b, 0x016b10a0, 0x0c000e05, 0x1300101b,   // eu.fr.un_520 lt.ceb.en_322  is.sv.un_330 lt.et.un_770
  0x552120a4, 0x281f3f04, 0x110a07af, 0x31200604,   // sq.jw.rw_433 af.cy.sw_332  bg.mk.ro_655 de.sq.az_332
  0x235205ad, 0x1f006419, 0x07051112, 0x060105a0,   // fr.ha.ca_643 lg.cy.un_750  ro.fr.it_654 fr.en.de_322
  // [6680]
  0x4a002809, 0x251b315a, 0x0f033f13, 0x31012055,   // sw.yo.un_440 az.tr.eu_553  af.nl.lv_665 sq.en.az_442
  0x6b681c05, 0x20682a08, 0x291e060c, 0x68642008,   // id.ig.ceb_333 mt.ig.sq_443  de.ms.sl_543 sq.lg.ig_443
  0x161b2807, 0x01233f07, 0x0b100a13, 0x4a00130d,   // sw.tr.hr_432 af.ca.en_432  pt.lt.es_665 et.yo.un_540
  0x20002a23, 0x641b3109, 0x0704110d, 0x08006409,   // mt.sq.un_880 az.tr.lg_444  ro.ru.bg_554 lg.no.un_440
  // [6690]
  0x016820a4, 0x681c1e11, 0x0c083f07, 0x0c0a550c,   // sq.ig.en_433 ms.id.ig_653  af.no.sv_432 rw.pt.sv_543
  0x170f1011, 0x3b00180d, 0x55282008, 0x644a07a4,   // lt.lv.sr_653 ga.so.un_540  sq.sw.rw_443 it.yo.lg_433
  0x645568af, 0x35000d04, 0x10130f12, 0x186b08a0,   // ig.rw.lg_655 cs.zu.un_320  lv.et.lt_654 no.ceb.ga_322
  0x4a00350d, 0x31000719, 0x4a000a18, 0x643b3507,   // zu.yo.un_540 it.az.un_750  pt.yo.un_740 zu.so.lg_432
  // [66a0]
  0x2b001905, 0x230705ec, 0x101325ad, 0x1e2868ad,   // gl.vi.un_330 fr.it.ca_644  eu.et.lt_643 ig.sw.ms_643
  0x1c6435a7, 0x19002b19, 0x016b3b07, 0x2d006e08,   // zu.lg.id_532 vi.gl.un_750  so.ceb.en_432 hmn.sk.un_430
  0x16210e04, 0x07683ba7, 0x2d0d18af, 0x18006e04,   // is.jw.hr_332 so.ig.it_532  ga.cs.sk_655 hmn.ga.un_320
  0x1c091ea4, 0x2b002013, 0x010f1011, 0x350f10ad,   // ms.pl.id_433 sq.vi.un_650  lt.lv.en_653 lt.lv.zu_643
  // [66b0]
  0x55203513, 0x1e1c0fee, 0x0402080c, 0x2855010b,   // zu.sq.rw_665 lv.id.ms_422  no.da.fi_543 en.rw.sw_542
  0x28203512, 0x1a103108, 0x283520af, 0x2000351a,   // zu.sq.sw_654 az.lt.tl_443  sq.zu.sw_655 zu.sq.un_760
  0x2d00290d, 0x6b1a1007, 0x283555ad, 0x10003207,   // sl.sk.un_540 lt.tl.ceb_432  rw.zu.sw_643 bs.lt.un_420
  0x0d2018a0, 0x060c08a9, 0x2d291107, 0x521e1c12,   // ga.sq.cs_322 no.sv.de_544  ro.sl.sk_432 id.ms.ha_654
  // [66c0]
  0x3100230d, 0x351f1a05, 0x0508060c, 0x08021ca4,   // ca.az.un_540 tl.cy.zu_333  de.no.fr_543 id.da.no_433
  0x6b641a55, 0x20282907, 0x0e040c08, 0x042a130c,   // tl.lg.ceb_442 sl.sw.sq_432  sv.fi.is_443 et.mt.fi_543
  0x02003f22, 0x321710ec, 0x06010cee, 0x11292302,   // af.da.un_870 lt.sr.bs_644  sv.en.de_422 ca.sl.ro_222
  0x1f233f07, 0x64135511, 0x31082702, 0x05020107,   // af.ca.cy_432 rw.et.lg_653  gd.no.az_222 en.da.fr_432
  // [66d0]
  0x11000a2a, 0x53000302, 0x04100aa7, 0x09130d13,   // mk.ro.un_970 nl.ht.un_220  mk.be.ru_532 ne.bh.hi_665
  0x190b0dec, 0x5355280c, 0x0f001108, 0x11002913,   // cs.es.gl_644 sw.rw.ht_543  ro.lv.un_430 sl.ro.un_650
  0x053f03ad, 0x0400550d, 0x04111312, 0x1f040ea4,   // nl.af.fr_643 rw.fi.un_540  et.ro.fi_654 is.fi.cy_433
  0x3500041a, 0x312913ad, 0x04290e0d, 0x1a002912,   // fi.zu.un_760 et.sl.az_643  is.sl.fi_554 sl.tl.un_640
  // [66e0]
  0x106b0107, 0x11170aa4, 0x1000290d, 0x08172907,   // en.ceb.lt_432 mk.sr.ro_433  sl.lt.un_540 sl.sr.no_432
  0x082718a7, 0x1a001e04, 0x1e2855ee, 0x0d1729a0,   // ga.gd.no_532 ms.tl.un_320  rw.sw.ms_422 sl.sr.cs_322
  0x12003502, 0x0e001a12, 0x35001c02, 0x2a000b04,   // zu.hu.un_220 tl.is.un_640  id.zu.un_220 es.mt.un_320
  0x64251a0c, 0x28211c09, 0x21003b18, 0x2d0d2904,   // tl.eu.lg_543 id.jw.sw_444  so.jw.un_740 sl.cs.sk_332
  // [66f0]
  0x352521ad, 0x08005521, 0x09000f19, 0x6b251aa4,   // jw.eu.zu_643 rw.no.un_860  lv.pl.un_750 tl.eu.ceb_433
  0x13003b07, 0x55000804, 0x04556408, 0x2128080d,   // so.et.un_420 no.rw.un_320  lg.rw.fi_443 no.sw.jw_554
  0x0e080b04, 0x3b001a0c, 0x640e550c, 0x19041355,   // es.no.is_332 tl.so.un_530  rw.is.lg_543 et.fi.gl_442
  0x55273bec, 0x216435a9, 0x35001a0b, 0x642a0705,   // so.gd.rw_644 zu.lg.jw_544  tl.zu.un_520 it.mt.lg_333
  // [6700]
  0x1c2a28ad, 0x281801a0, 0x211e2807, 0x01280802,   // sw.mt.id_643 en.ga.sw_322  sw.ms.jw_432 no.sw.en_222
  0x0700250e, 0x64255508, 0x351a640c, 0x0e0806a7,   // eu.it.un_550 rw.eu.lg_443  lg.tl.zu_543 de.no.is_532
  0x285564af, 0x2d0d17ee, 0x20643512, 0x1b0903ec,   // lg.rw.sw_655 sr.cs.sk_422  zu.lg.sq_654 nl.pl.tr_644
  0x1a526412, 0x1c071e0c, 0x03071007, 0x28006e19,   // lg.ha.tl_654 ms.it.id_543  lt.it.nl_432 hmn.sw.un_750
  // [6710]
  0x25551c11, 0x20281e12, 0x28005213, 0x20002b2a,   // id.rw.eu_653 ms.sw.sq_654  ha.sw.un_650 vi.sq.un_970
  0x180a11a4, 0x21526ba0, 0x082821a4, 0x3f6b3b0c,   // ro.pt.ga_433 ceb.ha.jw_322  jw.sw.no_433 so.ceb.af_543
  0x06002808, 0x0f005513, 0x082b18ad, 0x0a001602,   // sw.de.un_430 rw.lv.un_650  ga.vi.no_643 hr.pt.un_220
  0x2b006e23, 0x1c6e1e11, 0x2900270d, 0x0c001c02,   // hmn.vi.un_880 ms.hmn.id_653  gd.sl.un_540 id.sv.un_220
  // [6720]
  0x53006421, 0x6e002b0e, 0x19250ba0, 0x555364a4,   // lg.ht.un_860 vi.hmn.un_550  es.eu.gl_322 lg.ht.rw_433
  0x09001320, 0x10001709, 0x186e0a0c, 0x0c001304,   // bh.hi.un_850 sr.lt.un_440  pt.hmn.ga_543 et.sv.un_320
  0x11070a11, 0x190b53ee, 0x1f076e0d, 0x19250b12,   // pt.it.ro_653 ht.es.gl_422  hmn.it.cy_554 es.eu.gl_654
  0x6b680b0c, 0x030e2513, 0x13003f0e, 0x17000714,   // es.ig.ceb_543 eu.is.nl_665  af.et.un_550 bg.sr.un_660
  // [6730]
  0x12250eec, 0x020e0860, 0x022d0d08, 0x0600551a,   // is.eu.hu_644 no.is.da_664  cs.sk.da_443 rw.de.un_760
  0x16000f16, 0x25062b04, 0x2d130d04, 0x1a55250c,   // lv.hr.un_720 vi.de.eu_332  cs.et.sk_332 eu.rw.tl_543
  0x17000718, 0x1300100c, 0x0e122d07, 0x6b6e68a0,   // bg.sr.un_740 lt.et.un_530  sk.hu.is_432 ig.hmn.ceb_322
  0x23211ca4, 0x0e251309, 0x0e3f030d, 0x35000407,   // id.jw.ca_433 et.eu.is_444  nl.af.is_554 fi.zu.un_420
  // [6740]
  0x2b6b0104, 0x2932170c, 0x0e3b6404, 0x5300130c,   // en.ceb.vi_332 sr.bs.sl_543  lg.so.is_332 et.ht.un_530
  0x0c0e03a4, 0x182b01a4, 0x02000c0c, 0x35003b07,   // nl.is.sv_433 en.vi.ga_433  sv.da.un_530 so.zu.un_420
  0x07080cee, 0x130504a9, 0x23004a02, 0x28005519,   // sv.no.it_422 fi.fr.et_544  yo.ca.un_220 rw.sw.un_750
  0x4a1823b3, 0x05001808, 0x353f0255, 0x060c6bee,   // ca.ga.yo_743 ga.fr.un_430  da.af.zu_442 ceb.sv.de_422
  // [6750]
  0x0300120c, 0x6b003b1a, 0x170710ee, 0x1005075a,   // hu.nl.un_530 so.ceb.un_760  be.bg.sr_422 it.fr.lt_553
  0x3b001a12, 0x2a00072b, 0x231925a0, 0x130411ee,   // tl.so.un_640 it.mt.un_980  eu.gl.ca_322 ro.fi.et_422
  0x06093ba0, 0x3b001114, 0x0f002d08, 0x043b11ad,   // so.pl.de_322 ro.so.un_660  sk.lv.un_430 ro.so.fi_643
  0x53002313, 0x0f135207, 0x64281208, 0x091f31ad,   // ca.ht.un_650 ha.et.lv_432  hu.sw.lg_443 az.cy.pl_643
  // [6760]
  0x3b1a31a0, 0x0e002019, 0x043b1111, 0x11130460,   // az.tl.so_322 sq.is.un_750  ro.so.fi_653 fi.et.ro_664
  0x27016b07, 0x043b13af, 0x4a0f2a07, 0x0100350d,   // ceb.en.gd_432 et.so.fi_655  mt.lv.yo_432 zu.en.un_540
  0x35005212, 0x180b6ba0, 0x5264680d, 0x0c0801a0,   // ha.zu.un_640 ceb.es.ga_322  ig.lg.ha_554 en.no.sv_322
  0x3f003b04, 0x3b000422, 0x21002a19, 0x522155ee,   // so.af.un_320 fi.so.un_870  mt.jw.un_750 rw.jw.ha_422
  // [6770]
  0x1c08020c, 0x13114aa4, 0x18000513, 0x130452ad,   // da.no.id_543 yo.ro.et_433  fr.ga.un_650 ha.fi.et_643
  0x253f3b0c, 0x10000d19, 0x2b006b04, 0x10000d09,   // so.af.eu_543 cs.lt.un_750  ceb.vi.un_320 cs.lt.un_440
  0x2a005209, 0x0a002d0c, 0x01536402, 0x2a005202,   // ha.mt.un_440 sk.pt.un_530  lg.ht.en_222 ha.mt.un_220
  0x1c000729, 0x0802050c, 0x0b001c04, 0x11081009,   // it.id.un_960 fr.da.no_543  id.es.un_320 be.uk.ro_444
  // [6780]
  0x17291008, 0x3516250c, 0x0f3f10ec, 0x530609af,   // lt.sl.sr_443 eu.hr.zu_543  lt.af.lv_644 pl.de.ht_655
  0x093f0c0e, 0x316b20ee, 0x0910045a, 0x09001007,   // sv.af.pl_555 sq.ceb.az_422  fi.lt.pl_553 lt.pl.un_420
  0x2a005208, 0x1b003504, 0x0600080c, 0x1100101a,   // ha.mt.un_430 zu.tr.un_320  no.de.un_530 be.ro.un_760
  0x05006b19, 0x230a0511, 0x090210a4, 0x29020dee,   // ceb.fr.un_750 fr.pt.ca_653  lt.da.pl_433 cs.da.sl_422
  // [6790]
  0x28010404, 0x041f09ec, 0x18122d04, 0x1c130da9,   // fi.en.sw_332 pl.cy.fi_644  sk.hu.ga_332 ne.bh.mr_544
  0x121608a6, 0x280306a4, 0x0b0a55a4, 0x525525a7,   // no.hr.hu_521 de.nl.sw_433  rw.pt.es_433 eu.rw.ha_532
  0x132864a0, 0x060405a0, 0x52641a05, 0x06002307,   // lg.sw.et_322 fr.fi.de_322  tl.lg.ha_333 ca.de.un_420
  0x1a281ea4, 0x0c000409, 0x521a1eaf, 0x060c045a,   // ms.sw.tl_433 fi.sv.un_440  ms.tl.ha_655 fi.sv.de_553
  // [67a0]
  0x1a215208, 0x6b1964a4, 0x1c281e0c, 0x646e350c,   // ha.jw.tl_443 lg.gl.ceb_433  ms.sw.id_543 zu.hmn.lg_543
  0x09006b23, 0x10000704, 0x3f040e07, 0x1e6b1c07,   // ceb.pl.un_880 bg.be.un_320  is.fi.af_432 id.ceb.ms_432
  0x1e120404, 0x1b250ea4, 0x0a000422, 0x0a000107,   // fi.hu.ms_332 is.eu.tr_433  ru.mk.un_870 en.pt.un_420
  0x3f0304a7, 0x21041304, 0x20001111, 0x1f311b07,   // fi.nl.af_532 et.fi.jw_332  ro.sq.un_630 tr.az.cy_432
  // [67b0]
  0x641b3113, 0x09285207, 0x1a64520c, 0x0a002323,   // az.tr.lg_665 ha.sw.pl_432  ha.lg.tl_543 ca.pt.un_880
  0x12211c04, 0x64521a08, 0x1a001e08, 0x0a311112,   // id.jw.hu_332 tl.ha.lg_443  ms.tl.un_430 ro.az.pt_654
  0x1a2b6b07, 0x20000e0e, 0x2a000e23, 0x64002107,   // ceb.vi.tl_432 is.sq.un_550  is.mt.un_880 jw.lg.un_420
  0x01640ba0, 0x11001314, 0x3f211207, 0x3f1203a4,   // es.lg.en_322 et.ro.un_660  hu.jw.af_432 nl.hu.af_433
  // [67c0]
  0x20230555, 0x23062a04, 0x13002807, 0x10110411,   // fr.ca.sq_442 mt.de.ca_332  sw.et.un_420 ru.ro.be_653
  0x1e1c6bee, 0x0600350c, 0x0e00060b, 0x20003f04,   // ceb.id.ms_422 zu.de.un_530  de.is.un_520 af.sq.un_320
  0x1e1c270c, 0x08002104, 0x02080555, 0x070a0805,   // gd.id.ms_543 jw.no.un_320  fr.no.da_442 uk.mk.bg_333
  0x01000c08, 0x05000105, 0x1e1f2711, 0x16003508,   // sv.en.un_430 en.fr.un_330  gd.cy.ms_653 zu.hr.un_430
  // [67d0]
  0x1c000d20, 0x64001220, 0x080205ec, 0x1a556404,   // ne.mr.un_850 hu.lg.un_850  fr.da.no_644 lg.rw.tl_332
  0x6b230507, 0x0600050c, 0x6e0407a0, 0x6b041a55,   // fr.ca.ceb_432 fr.de.un_530  it.fi.hmn_322 tl.fi.ceb_442
  0x2d120e05, 0x04000605, 0x251b2da4, 0x131107ee,   // is.hu.sk_333 de.fi.un_330  sk.tr.eu_433 it.ro.et_422
  0x6b1a64a9, 0x090425a0, 0x0d0b190c, 0x1200250b,   // lg.tl.ceb_544 eu.fi.pl_322  gl.es.cs_543 eu.hu.un_520
  // [67e0]
  0x190d2d0b, 0x07062512, 0x070d2dad, 0x2d00290b,   // sk.cs.gl_542 eu.de.it_654  sk.cs.it_643 sl.sk.un_520
  0x11010505, 0x21126402, 0x2a0a23a9, 0x183f08a9,   // fr.en.ro_333 lg.hu.jw_222  ca.pt.mt_544 no.af.ga_544
  0x2a002b0d, 0x06002804, 0x2a003b12, 0x043b1305,   // vi.mt.un_540 sw.de.un_320  so.mt.un_640 et.so.fi_333
  0x012305ee, 0x040610ec, 0x040e1008, 0x3f03040e,   // fr.ca.en_422 lt.de.fi_644  lt.is.fi_443 fi.nl.af_555
  // [67f0]
  0x06001f19, 0x100604a4, 0x21001820, 0x0e6e060b,   // cy.de.un_750 fi.de.lt_433  ar.fa.un_850 de.hmn.is_542
  0x232519a4, 0x3b3f03ec, 0x27002507, 0x291f1e0b,   // gl.eu.ca_433 nl.af.so_644  eu.gd.un_420 ms.cy.sl_542
  0x20321ba4, 0x11006e0c, 0x0c002107, 0x680501a7,   // tr.bs.sq_433 hmn.ro.un_530  jw.sv.un_420 en.fr.ig_532
  0x4a53210c, 0x35004a0c, 0x0f103ba7, 0x01113504,   // jw.ht.yo_543 yo.zu.un_530  so.lt.lv_532 zu.ro.en_332

  // [6800]
  0x3b041312, 0x016b110c, 0x3f3b3508, 0x03041312,   // et.fi.so_654 ro.ceb.en_543  zu.so.af_443 et.fi.nl_654
  0x07081705, 0x1b185212, 0x062031ad, 0x05214a04,   // sr.uk.bg_333 ha.ga.tr_654  az.sq.de_643 yo.jw.fr_332
  0x53003f04, 0x10040612, 0x0a0708af, 0x02000607,   // af.ht.un_320 de.fi.lt_654  uk.bg.mk_655 de.da.un_420
  0x11311b11, 0x21004a07, 0x3b00311b, 0x06001908,   // tr.az.ro_653 yo.jw.un_420  az.so.un_770 gl.de.un_430
  // [6810]
  0x3b28010c, 0x322d1609, 0x32100107, 0x3500060d,   // en.sw.so_543 hr.sk.bs_444  en.lt.bs_432 de.zu.un_540
  0x0c111304, 0x1e001304, 0x12210555, 0x323504ee,   // et.ro.sv_332 et.ms.un_320  fr.jw.hu_442 fi.zu.bs_422
  0x21000505, 0x043b1e11, 0x190a05a0, 0x09120ca0,   // fr.jw.un_330 ms.so.fi_653  fr.pt.gl_322 sv.hu.pl_322
  0x55002014, 0x4a553b12, 0x11311b0b, 0x040c065a,   // sq.rw.un_660 so.rw.yo_654  tr.az.ro_542 de.sv.fi_553
  // [6820]
  0x030213ad, 0x03250507, 0x02080c0d, 0x0a002314,   // et.da.nl_643 fr.eu.nl_432  sv.no.da_554 ca.pt.un_660
  0x3f02180c, 0x55110ba0, 0x320f1707, 0x1027185a,   // ga.da.af_543 es.ro.rw_322  sr.lv.bs_432 ga.gd.lt_553
  0x08023bee, 0x171f52a0, 0x06000312, 0x09100ca0,   // so.da.no_422 ha.cy.sr_322  nl.de.un_640 sv.lt.pl_322
  0x275564ac, 0x0e001807, 0x020c080d, 0x3f133b05,   // lg.rw.gd_632 ga.is.un_420  no.sv.da_554 so.et.af_333
  // [6830]
  0x08063f13, 0x06032013, 0x353f2813, 0x06005502,   // af.de.no_665 sq.nl.de_665  sw.af.zu_665 rw.de.un_220
  0x1a3b5305, 0x3b003f0d, 0x0a2d0da7, 0x1b3b3fa0,   // ht.so.tl_333 af.so.un_540  cs.sk.pt_532 af.so.tr_322
  0x03533bee, 0x0f321604, 0x3500681b, 0x1e003512,   // so.ht.nl_422 hr.bs.lv_332  ig.zu.un_770 zu.ms.un_640
  0x16320304, 0x03533fa0, 0x04001b19, 0x09004a19,   // nl.bs.hr_332 af.ht.nl_322  tr.fi.un_750 yo.pl.un_750
  // [6840]
  0x06133fa9, 0x0b122da0, 0x55351e07, 0x3b003512,   // af.et.de_544 sk.hu.es_322  ms.zu.rw_432 zu.so.un_640
  0x1e3b280c, 0x1a276b09, 0x1a076b07, 0x01212d0c,   // sw.so.ms_543 ceb.gd.tl_444  ceb.it.tl_432 sk.jw.en_543
  0x1f000704, 0x18102707, 0x53230504, 0x11001709,   // it.cy.un_320 gd.lt.ga_432  fr.ca.ht_332 sr.ro.un_440
  0x3f005521, 0x1c002112, 0x2b4a01a0, 0x28004a05,   // rw.af.un_860 jw.id.un_640  en.yo.vi_322 yo.sw.un_330
  // [6850]
  0x0d000607, 0x3b003508, 0x211a2b07, 0x04311bac,   // de.cs.un_420 zu.so.un_430  vi.tl.jw_432 tr.az.fi_632
  0x07000a2c, 0x281221a4, 0x126b1a0c, 0x3b35200c,   // mk.bg.un_990 jw.hu.sw_433  tl.ceb.hu_543 sq.zu.so_543
  0x08000a21, 0x53006807, 0x3f080408, 0x120b05af,   // mk.uk.un_860 ig.ht.un_420  fi.no.af_443 fr.es.hu_655
  0x271c1e0c, 0x06251f60, 0x13033f0d, 0x0f080cee,   // ms.id.gd_543 cy.eu.de_664  af.nl.et_554 sv.no.lv_422
  // [6860]
  0x07006b0e, 0x011b0507, 0x6b3b320d, 0x03201707,   // ceb.it.un_550 fr.tr.en_432  bs.so.ceb_554 sr.sq.nl_432
  0x1b312107, 0x2d0d050e, 0x356468a9, 0x080a11ad,   // jw.az.tr_432 fr.cs.sk_555  ig.lg.zu_544 ro.mk.uk_643
  0x3b3555a0, 0x4a002d0d, 0x0d2d120b, 0x133f0313,   // rw.zu.so_322 sk.yo.un_540  hu.sk.cs_542 nl.af.et_665
  0x080411ad, 0x1c68550b, 0x04003b1a, 0x0b001804,   // ro.ru.uk_643 rw.ig.id_542  so.fi.un_760 ga.es.un_320
  // [6870]
  0x230f0b07, 0x081f0208, 0x0f05010c, 0x010c0807,   // es.lv.ca_432 da.cy.no_443  en.fr.lv_543 no.sv.en_432
  0x0f00010e, 0x55286404, 0x120a0d14, 0x010b0f0c,   // en.lv.un_550 lg.sw.rw_332  cs.pt.hu_666 lv.es.en_543
  0x120e18ee, 0x02031108, 0x6e6b0107, 0x23000c09,   // ga.is.hu_422 ro.nl.da_443  en.ceb.hmn_432 sv.ca.un_440
  0x06051304, 0x06080202, 0x0a00120c, 0x313f07a9,   // et.fr.de_332 da.no.de_222  hu.pt.un_530 it.af.az_544
  // [6880]
  0x2d00180d, 0x07052aa9, 0x0e2319a0, 0x010a2da0,   // ga.sk.un_540 mt.fr.it_544  gl.ca.is_322 sk.pt.en_322
  0x213f25ee, 0x2a002913, 0x016b3fee, 0x29160602,   // eu.af.jw_422 sl.mt.un_650  af.ceb.en_422 de.hr.sl_222
  0x083f0313, 0x3f0306a7, 0x05001f0d, 0x68270608,   // nl.af.no_665 de.nl.af_532  cy.fr.un_540 de.gd.ig_443
  0x18272814, 0x290209ad, 0x0e00181b, 0x04002908,   // sw.gd.ga_666 pl.da.sl_643  ga.is.un_770 sl.fi.un_430
  // [6890]
  0x08125205, 0x68271808, 0x0d201212, 0x12053bac,   // ha.hu.no_333 ga.gd.ig_443  hu.sq.cs_654 so.fr.hu_632
  0x532b2807, 0x6b533bee, 0x031c28ee, 0x060327ad,   // sw.vi.ht_432 so.ht.ceb_422  sw.id.nl_422 gd.nl.de_643
  0x03063f13, 0x520635ad, 0x093555ee, 0x2127280d,   // af.de.nl_665 zu.de.ha_643  rw.zu.pl_422 sw.gd.jw_554
  0x212a53af, 0x0a00101a, 0x68062809, 0x1a1227a9,   // ht.mt.jw_655 be.mk.un_760  sw.de.ig_444 gd.hu.tl_544
  // [68a0]
  0x4a3b1109, 0x2a1f23af, 0x31295312, 0x105268a9,   // ro.so.yo_444 ca.cy.mt_655  ht.sl.az_654 ig.ha.lt_544
  0x0a002319, 0x12045307, 0x53352808, 0x536e2a14,   // ca.pt.un_750 ht.fi.hu_432  sw.zu.ht_443 mt.hmn.ht_666
  0x041e1c02, 0x55284a12, 0x03280608, 0x2900210c,   // id.ms.fi_222 yo.sw.rw_654  de.sw.nl_443 jw.sl.un_530
  0x1e1c07af, 0x180968a4, 0x061a35a9, 0x041f130e,   // it.id.ms_655 ig.pl.ga_433  zu.tl.de_544 et.cy.fi_555
  // [68b0]
  0x2a114a12, 0x3f2a0e05, 0x05003b12, 0x086b68af,   // yo.ro.mt_654 is.mt.af_333  so.fr.un_640 ig.ceb.no_655
  0x3508060c, 0x05003b0c, 0x01083555, 0x6420110c,   // de.no.zu_543 so.fr.un_530  zu.no.en_442 ro.sq.lg_543
  0x4a005234, 0x09000d22, 0x12132807, 0x255504a7,   // ha.yo.un_A80 ne.hi.un_870  sw.et.hu_432 fi.rw.eu_532
  0x122d0408, 0x6b3b1a12, 0x293b52a0, 0x204a2712,   // fi.sk.hu_443 tl.so.ceb_654  ha.so.sl_322 gd.yo.sq_654
  // [68c0]
  0x0c033f05, 0x211a28a6, 0x641a5512, 0x056e2007,   // af.nl.sv_333 sw.tl.jw_521  rw.tl.lg_654 sq.hmn.fr_432
  0x0c003f07, 0x32534aad, 0x040e1e0c, 0x3f212b0e,   // af.sv.un_420 yo.ht.bs_643  ms.is.fi_543 vi.jw.af_555
  0x0a182b1f, 0x3500091a, 0x35551b0d, 0x3f011f0d,   // vi.ga.pt_864 pl.zu.un_760  tr.rw.zu_554 cy.en.af_554
  0x292d1108, 0x0f00040c, 0x2800521b, 0x01211ca0,   // ro.sk.sl_443 fi.lv.un_530  ha.sw.un_770 id.jw.en_322
  // [68d0]
  0x13041aa0, 0x120413a6, 0x104a6b07, 0x32003b13,   // tl.fi.et_322 et.fi.hu_521  ceb.yo.lt_432 so.bs.un_650
  0x0a0f0e08, 0x52001b22, 0x35132107, 0x3f000919,   // is.lv.pt_443 tr.ha.un_870  jw.et.zu_432 pl.af.un_750
  0x112520ad, 0x06003f1a, 0x1f18010c, 0x0e00010d,   // sq.eu.ro_643 af.de.un_760  en.ga.cy_543 en.is.un_540
  0x1b3109a9, 0x3f2301ee, 0x1000082b, 0x111001a0,   // pl.az.tr_544 en.ca.af_422  uk.be.un_980 en.lt.ro_322
  // [68e0]
  0x2000111a, 0x64041111, 0x0c04130c, 0x0e352105,   // ro.sq.un_760 ro.fi.lg_653  et.fi.sv_543 jw.zu.is_333
  0x020c085a, 0x0b002d07, 0x250c04a0, 0x2a04130c,   // no.sv.da_553 sk.es.un_420  fi.sv.eu_322 et.fi.mt_543
  0x2d060daf, 0x64551a12, 0x35171aa4, 0x1f0601af,   // cs.de.sk_655 tl.rw.lg_654  tl.sr.zu_433 en.de.cy_655
  0x04000312, 0x043f64ee, 0x03006b04, 0x190b4aa4,   // nl.fi.un_640 lg.af.fi_422  ceb.nl.un_320 yo.es.gl_433
  // [68f0]
  0x6400080d, 0x3b001a08, 0x080227ee, 0x64080202,   // no.lg.un_540 tl.so.un_430  gd.da.no_422 da.no.lg_222
  0x04130cec, 0x10001f08, 0x170a115a, 0x3b006409,   // sv.et.fi_644 cy.lt.un_430  ro.mk.sr_553 lg.so.un_440
  0x1b646b04, 0x200c6eec, 0x0d001220, 0x32002004,   // ceb.lg.tr_332 hmn.sv.sq_644  hu.cs.un_850 sq.bs.un_320
  0x2a00071b, 0x02080460, 0x556b1aee, 0x04001808,   // it.mt.un_770 fi.no.da_664  tl.ceb.rw_422 ga.fi.un_430
  // [6900]
  0x3b35550c, 0x1a00640e, 0x180631a0, 0x1f002d0d,   // rw.zu.so_543 lg.tl.un_550  az.de.ga_322 sk.cy.un_540
  0x2a3f1e0c, 0x120913a9, 0x044a07a0, 0x0c001211,   // ms.af.mt_543 et.pl.hu_544  it.yo.fi_322 hu.sv.un_630
  0x236b1b07, 0x68002b0e, 0x6e00200e, 0x4a002b0c,   // tr.ceb.ca_432 vi.ig.un_550  sq.hmn.un_550 vi.yo.un_530
  0x0d202da9, 0x1300250d, 0x21006402, 0x1b04520c,   // sk.sq.cs_544 eu.et.un_540  lg.jw.un_220 ha.fi.tr_543
  // [6910]
  0x53212312, 0x01311804, 0x0e0f045a, 0x0d006807,   // ca.jw.ht_654 ga.az.en_332  fi.lv.is_553 ig.cs.un_420
  0x641b0409, 0x0f292007, 0x0d082da0, 0x0c3b0204,   // fi.tr.lg_444 sq.sl.lv_432  sk.no.cs_322 da.so.sv_332
  0x2b006b0c, 0x13001b02, 0x64101a5a, 0x08645508,   // ceb.vi.un_530 tr.et.un_220  tl.lt.lg_553 rw.lg.no_443
  0x3b1827ad, 0x2a040a0c, 0x0e002009, 0x0a2105af,   // gd.ga.so_643 pt.fi.mt_543  sq.is.un_440 fr.jw.pt_655
  // [6920]
  0x03131fa6, 0x290f25ee, 0x06230a0c, 0x35016412,   // cy.et.nl_521 eu.lv.sl_422  pt.ca.de_543 lg.en.zu_654
  0x040a10a4, 0x200c0e55, 0x235321a0, 0x020c13a0,   // be.mk.ru_433 is.sv.sq_442  jw.ht.ca_322 et.sv.da_322
  0x231b0aad, 0x2331250c, 0x05001f04, 0x29250d12,   // pt.tr.ca_643 eu.az.ca_543  cy.fr.un_320 cs.eu.sl_654
  0x52183b07, 0x0a110408, 0x55000808, 0x53001b05,   // so.ga.ha_432 ru.ro.mk_443  no.rw.un_430 tr.ht.un_330
  // [6930]
  0x320f1012, 0x130c0411, 0x04201307, 0x202a1308,   // lt.lv.bs_654 fi.sv.et_653  et.sq.fi_432 et.mt.sq_443
  0x555235a4, 0x13000d11, 0x20353b0b, 0x3b55280b,   // zu.ha.rw_433 ne.bh.un_630  so.zu.sq_542 sw.rw.so_542
  0x09350d04, 0x2835555a, 0x0b0a19ec, 0x020e2aa4,   // cs.zu.pl_332 rw.zu.sw_553  gl.pt.es_644 mt.is.da_433
  0x27000704, 0x353b5513, 0x13211c09, 0x3b5255a9,   // it.gd.un_320 rw.so.zu_665  id.jw.et_444 rw.ha.so_544
  // [6940]
  0x1a001c08, 0x6b641aa4, 0x0d003502, 0x0a006e14,   // id.tl.un_430 tl.lg.ceb_433  zu.cs.un_220 hmn.pt.un_660
  0x1a2952ee, 0x0d00120d, 0x352164a4, 0x353b550c,   // ha.sl.tl_422 hu.cs.un_540  lg.jw.zu_433 rw.so.zu_543
  0x206b1aa4, 0x53002307, 0x200c12af, 0x28001207,   // tl.ceb.sq_433 ca.ht.un_420  hu.sv.sq_655 hu.sw.un_420
  0x3552280c, 0x05060207, 0x1a2110a4, 0x285255a4,   // sw.ha.zu_543 da.de.fr_432  lt.jw.tl_433 rw.ha.sw_433
  // [6950]
  0x2d0d3bee, 0x20553ba9, 0x12001608, 0x0f2028ad,   // so.cs.sk_422 so.rw.sq_544  hr.hu.un_430 sw.sq.lv_643
  0x35003b1b, 0x64350da6, 0x520b1e07, 0x04130d0c,   // so.zu.un_770 cs.zu.lg_521  ms.es.ha_432 cs.et.fi_543
  0x35096405, 0x641a1313, 0x11000d16, 0x2a1a53a4,   // lg.pl.zu_333 et.tl.lg_665  cs.ro.un_720 ht.tl.mt_433
  0x21080209, 0x2d090dee, 0x08000108, 0x215564af,   // da.no.jw_444 cs.pl.sk_422  en.no.un_430 lg.rw.jw_655
  // [6960]
  0x083f05a0, 0x13005304, 0x0a0b19ee, 0x0a000d0b,   // fr.af.no_322 ht.et.un_320  gl.es.pt_422 cs.pt.un_520
  0x04080aa7, 0x09000613, 0x53182712, 0x1f131a02,   // mk.uk.ru_532 de.pl.un_650  gd.ga.ht_654 tl.et.cy_222
  0x282164ee, 0x2a005307, 0x28005521, 0x64552808,   // lg.jw.sw_422 ht.mt.un_420  rw.sw.un_860 sw.rw.lg_443
  0x4a000208, 0x17290dee, 0x29130405, 0x5232200c,   // da.yo.un_430 cs.sl.sr_422  fi.et.sl_333 sq.bs.ha_543
  // [6970]
  0x53001b19, 0x53270605, 0x0c3f0207, 0x35552813,   // tr.ht.un_750 de.gd.ht_333  da.af.sv_432 sw.rw.zu_665
  0x13352512, 0x353b55a0, 0x552835a9, 0x0a2d0d5a,   // eu.zu.et_654 rw.so.zu_322  zu.sw.rw_544 cs.sk.pt_553
  0x532128a0, 0x190b09ee, 0x28002722, 0x2b0106a0,   // sw.jw.ht_322 pl.es.gl_422  gd.sw.un_870 de.en.vi_322
  0x55001f14, 0x09080c09, 0x00003b37, 0x2b322711,   // cy.rw.un_660 sv.no.pl_444  so.un.un_B00 gd.bs.vi_653
  // [6980]
  0x06271f0c, 0x1c0a1a0c, 0x281a3505, 0x270e280c,   // cy.gd.de_543 tl.pt.id_543  zu.tl.sw_333 sw.is.gd_543
  0x25001b19, 0x0c081ba0, 0x0c000619, 0x31001e05,   // tr.eu.un_750 tr.no.sv_322  de.sv.un_750 ms.az.un_330
  0x08000e23, 0x042b1f07, 0x0e083f07, 0x2b206eec,   // is.no.un_880 cy.vi.fi_432  af.no.is_432 hmn.sq.vi_644
  0x092a0860, 0x13060da9, 0x3f0703a4, 0x1c005304,   // no.mt.pl_664 cs.de.et_544  nl.it.af_433 ht.id.un_320
  // [6990]
  0x09006822, 0x09181902, 0x3f642509, 0x0420190c,   // ig.pl.un_870 gl.ga.pl_222  eu.lg.af_444 gl.sq.fi_543
  0x1c211e07, 0x040e080b, 0x101e1c0d, 0x033f6812,   // ms.jw.id_432 no.is.fi_542  id.ms.lt_554 ig.af.nl_654
  0x04172911, 0x02292d07, 0x16005507, 0x31006b04,   // sl.sr.fi_653 sk.sl.da_432  rw.hr.un_420 ceb.az.un_320
  0x52643bec, 0x1c0c0208, 0x531f0611, 0x35072555,   // so.lg.ha_644 da.sv.id_443  de.cy.ht_653 eu.it.zu_442
  // [69a0]
  0x091a100c, 0x20080202, 0x35641c0c, 0x1b000f1b,   // lt.tl.pl_543 da.no.sq_222  id.lg.zu_543 lv.tr.un_770
  0x32080208, 0x10312008, 0x55211f07, 0x3b005508,   // da.no.bs_443 sq.az.lt_443  cy.jw.rw_432 rw.so.un_430
  0x31053b0c, 0x52003b14, 0x52136b09, 0x1c00190e,   // so.fr.az_543 so.ha.un_660  ceb.et.ha_444 gl.id.un_550
  0x25191caf, 0x2700070e, 0x276b0908, 0x292025a6,   // id.gl.eu_655 it.gd.un_550  pl.ceb.gd_443 eu.sq.sl_521
  // [69b0]
  0x0c041307, 0x28641e0c, 0x215213a4, 0x532a2007,   // et.fi.sv_432 ms.lg.sw_543  et.ha.jw_433 sq.mt.ht_432
  0x281a55a9, 0x201b250d, 0x4a000613, 0x070c1307,   // rw.tl.sw_544 eu.tr.sq_554  de.yo.un_650 et.sv.it_432
  0x281a6ba9, 0x026b1a55, 0x13072004, 0x1c213fa0,   // ceb.tl.sw_544 tl.ceb.da_442  sq.it.et_332 af.jw.id_322
  0x52005514, 0x200f1108, 0x4a1819ee, 0x11002512,   // rw.ha.un_660 ro.lv.sq_443  gl.ga.yo_422 eu.ro.un_640
  // [69c0]
  0x080c0213, 0x6b2025a0, 0x20071205, 0x05201f07,   // da.sv.no_665 eu.sq.ceb_322  hu.it.sq_333 cy.sq.fr_432
  0x520f210c, 0x051b0313, 0x0c190b05, 0x251b2a09,   // jw.lv.ha_543 nl.tr.fr_665  es.gl.sv_333 mt.tr.eu_444
  0x1b2025ac, 0x18000505, 0x190b28af, 0x1b00250c,   // eu.sq.tr_632 fr.ga.un_330  sw.es.gl_655 eu.tr.un_530
  0x1300081a, 0x033f130d, 0x0e0308a7, 0x6b033fa0,   // no.et.un_760 et.af.nl_554  no.nl.is_532 af.nl.ceb_322
  // [69d0]
  0x1b132a04, 0x27000919, 0x551308a4, 0x02211c07,   // mt.et.tr_332 pl.gd.un_750  no.et.rw_433 id.jw.da_432
  0x35002a08, 0x0c03080c, 0x171629ec, 0x32160d0c,   // mt.zu.un_430 no.nl.sv_543  sl.hr.sr_644 cs.hr.bs_543
  0x080252a4, 0x131c09a4, 0x190564a0, 0x051b3511,   // ha.da.no_433 hi.mr.bh_433  lg.fr.gl_322 zu.tr.fr_653
  0x531b0512, 0x641b050d, 0x5500030e, 0x11000509,   // fr.tr.ht_654 fr.tr.lg_554  nl.rw.un_550 fr.ro.un_440
  // [69e0]
  0x0a002009, 0x17001019, 0x0c6408a4, 0x29211ca4,   // sq.pt.un_440 be.sr.un_750  no.lg.sv_433 id.jw.sl_433
  0x68191208, 0x020621ec, 0x0b1105a0, 0x160d0fa0,   // hu.gl.ig_443 jw.de.da_644  fr.ro.es_322 lv.cs.hr_322
  0x100f2d0b, 0x3b0602a9, 0x35135504, 0x0705190c,   // sk.lv.lt_542 da.de.so_544  rw.et.zu_332 gl.fr.it_543
  0x0e0413ee, 0x2d0d16a0, 0x120d0f05, 0x29172507,   // et.fi.is_422 hr.cs.sk_322  lv.cs.hu_333 eu.sr.sl_432
  // [69f0]
  0x4a1b55ad, 0x121b3f55, 0x080c02ad, 0x3f311b08,   // rw.tr.yo_643 af.tr.hu_442  da.sv.no_643 tr.az.af_443
  0x64040cad, 0x12006804, 0x1b05010b, 0x311b3f13,   // sv.fi.lg_643 ig.hu.un_320  en.fr.tr_542 af.tr.az_665
  0x285535ee, 0x0f005512, 0x01051309, 0x0f0e55ec,   // zu.rw.sw_422 rw.lv.un_640  et.fr.en_444 rw.is.lv_644
  0x311b3f08, 0x12216804, 0x682a1bee, 0x3100130e,   // af.tr.az_443 ig.jw.hu_332  tr.mt.ig_422 et.az.un_550
  // [6a00]
  0x256455a4, 0x04253512, 0x181c1fee, 0x1b313faf,   // rw.lg.eu_433 zu.eu.fi_654  cy.id.ga_422 af.az.tr_655
  0x033f0c07, 0x190b2d0c, 0x1b003f12, 0x1700101a,   // sv.af.nl_432 sk.es.gl_543  af.tr.un_640 be.sr.un_760
  0x551f6bac, 0x20531c0c, 0x29000d0e, 0x2a002804,   // ceb.cy.rw_632 id.ht.sq_543  cs.sl.un_550 sw.mt.un_320
  0x210723a7, 0x32132955, 0x1e00350d, 0x3b2b6b07,   // ca.it.jw_532 sl.et.bs_442  zu.ms.un_540 ceb.vi.so_432
  // [6a10]
  0x283555ee, 0x1b313fa0, 0x1e041cee, 0x06111307,   // rw.zu.sw_422 af.az.tr_322  id.fi.ms_422 et.ro.de_432
  0x1a126b08, 0x3f000c04, 0x0600250d, 0x311b3faf,   // ceb.hu.tl_443 sv.af.un_320  eu.de.un_540 af.tr.az_655
  0x121b1ca7, 0x212964a0, 0x1100011a, 0x2a000921,   // id.tr.hu_532 lg.sl.jw_322  en.ro.un_760 pl.mt.un_860
  0x06551307, 0x0a0c0107, 0x07230aa0, 0x27201e0c,   // et.rw.de_432 en.sv.pt_432  pt.ca.it_322 ms.sq.gd_543
  // [6a20]
  0x0c2912ec, 0x1a003509, 0x283b5208, 0x1c1a1e04,   // hu.sl.sv_644 zu.tl.un_440  ha.so.sw_443 ms.tl.id_332
  0x0b00011a, 0x6b2104ee, 0x190a0ba0, 0x1c001f09,   // en.es.un_760 fi.jw.ceb_422  es.pt.gl_322 cy.id.un_440
  0x172007ee, 0x13000f09, 0x3f02100c, 0x32000207,   // it.sq.sr_422 lv.et.un_440  lt.da.af_543 da.bs.un_420
  0x0c000f0c, 0x29001104, 0x1a001104, 0x3b130f08,   // lv.sv.un_530 ro.sl.un_320  ro.tl.un_320 lv.et.so_443
  // [6a30]
  0x1b00010d, 0x01310cee, 0x0900210d, 0x2011010c,   // en.tr.un_540 sv.az.en_422  jw.pl.un_540 en.ro.sq_543
  0x200c01a4, 0x0a1b1c0b, 0x10321605, 0x250f2908,   // en.sv.sq_433 id.tr.pt_542  hr.bs.lt_333 sl.lv.eu_443
  0x2a18115a, 0x2d000808, 0x08020fa9, 0x250f08a4,   // ro.ga.mt_553 no.sk.un_430  lv.da.no_544 no.lv.eu_433
  0x0f001009, 0x08020da0, 0x4a000e07, 0x531e1c0d,   // lt.lv.un_440 cs.da.no_322  is.yo.un_420 id.ms.ht_554
  // [6a40]
  0x110804a4, 0x55050112, 0x050608a4, 0x641c02a0,   // ru.uk.ro_433 en.fr.rw_654  no.de.fr_433 da.id.lg_322
  0x53001c05, 0x050255af, 0x0300050c, 0x0c13040c,   // id.ht.un_330 rw.da.fr_655  fr.nl.un_530 fi.et.sv_543
  0x0b190a5a, 0x3f000802, 0x200511a0, 0x53080c08,   // pt.gl.es_553 no.af.un_220  ro.fr.sq_322 sv.no.ht_443
  0x02051305, 0x5500011a, 0x28182a13, 0x01130507,   // et.fr.da_333 en.rw.un_760  mt.ga.sw_665 fr.et.en_432
  // [6a50]
  0x351f64a9, 0x09001212, 0x02120307, 0x25190b07,   // lg.cy.zu_544 hu.pl.un_640  nl.hu.da_432 es.gl.eu_432
  0x3217165a, 0x060c0ea0, 0x1c2128a9, 0x530955a7,   // hr.sr.bs_553 is.sv.de_322  sw.jw.id_544 rw.pl.ht_532
  0x25230b04, 0x23351207, 0x09645502, 0x1a4a6ba0,   // es.ca.eu_332 hu.zu.ca_432  rw.lg.pl_222 ceb.yo.tl_322
  0x35000e12, 0x080264a4, 0x29032004, 0x0f6e290b,   // is.zu.un_640 lg.da.no_433  sq.nl.sl_332 sl.hmn.lv_542
  // [6a60]
  0x1600210b, 0x28060204, 0x066435ee, 0x124a5209,   // jw.hr.un_520 da.de.sw_332  zu.lg.de_422 ha.yo.hu_444
  0x311c1ea4, 0x53100f07, 0x2b001a12, 0x64070ead,   // ms.id.az_433 lv.lt.ht_432  tl.vi.un_640 is.it.lg_643
  0x205329ec, 0x0c351e07, 0x321629a9, 0x0d192d0b,   // sl.ht.sq_644 ms.zu.sv_432  sl.hr.bs_544 sk.gl.cs_542
  0x21002a08, 0x0e2001a0, 0x290f03ad, 0x061b3fa0,   // mt.jw.un_430 en.sq.is_322  nl.lv.sl_643 af.tr.de_322
  // [6a70]
  0x0d0804a9, 0x130c28a4, 0x10171111, 0x18122dee,   // fi.no.cs_544 sw.sv.et_433  ro.sr.be_653 sk.hu.ga_422
  0x102b1307, 0x07005204, 0x29000308, 0x012a05a0,   // et.vi.lt_432 ha.it.un_320  nl.sl.un_430 fr.mt.en_322
  0x2103280c, 0x082801ee, 0x1e005512, 0x64554a0c,   // sw.nl.jw_543 en.sw.no_422  rw.ms.un_640 yo.rw.lg_543
  0x09003207, 0x0f002905, 0x2d005334, 0x0a1120ad,   // bs.pl.un_420 sl.lv.un_330  ht.sk.un_A80 sq.ro.pt_643
  // [6a80]
  0x0f2920ec, 0x2800022a, 0x29000309, 0x526e2904,   // sq.sl.lv_644 da.sw.un_970  nl.sl.un_440 sl.hmn.ha_332
  0x3b003507, 0x02121bee, 0x0d000c08, 0x1f00210b,   // zu.so.un_420 tr.hu.da_422  sv.cs.un_430 jw.cy.un_520
  0x3f211b04, 0x2800291b, 0x072b2aa0, 0x0e002705,   // tr.jw.af_332 sl.sw.un_770  mt.vi.it_322 gd.is.un_330
  0x03004a04, 0x27001e02, 0x2d3f0305, 0x08012aa0,   // yo.nl.un_320 ms.gd.un_220  nl.af.sk_333 mt.en.no_322
  // [6a90]
  0x00002d2d, 0x0f0c0904, 0x3f283b12, 0x2100641a,   // sk.un.un_A00 pl.sv.lv_332  so.sw.af_654 lg.jw.un_760
  0x0b041012, 0x1b003b07, 0x356428a0, 0x283f0912,   // lt.fi.es_654 so.tr.un_420  sw.lg.zu_322 pl.af.sw_654
  0x09001109, 0x3509640c, 0x2d1f3ba7, 0x211f3b0e,   // ro.pl.un_440 lg.pl.zu_543  so.cy.sk_532 so.cy.jw_555
  0x0100230b, 0x551b28ad, 0x643f2112, 0x211a6b0d,   // ca.en.un_520 sw.tr.rw_643  jw.af.lg_654 ceb.tl.jw_554
  // [6aa0]
  0x090c1e0c, 0x35286402, 0x2a1a28a9, 0x11040faf,   // ms.sv.pl_543 lg.sw.zu_222  sw.tl.mt_544 lv.fi.ro_655
  0x55070fad, 0x170408a7, 0x09110f0c, 0x64001a04,   // lv.it.rw_643 uk.ru.sr_532  lv.ro.pl_543 tl.lg.un_320
  0x52551ca4, 0x07171012, 0x043f07a0, 0x2100090b,   // id.rw.ha_433 be.sr.bg_654  it.af.fi_322 pl.jw.un_520
  0x200a1ba4, 0x550c6ba4, 0x093528ad, 0x0c001107,   // tr.pt.sq_433 ceb.sv.rw_433  sw.zu.pl_643 ro.sv.un_420
  // [6ab0]
  0x09641fee, 0x643255ee, 0x0a0407ee, 0x0a000723,   // cy.lg.pl_422 rw.bs.lg_422  bg.ru.mk_422 bg.mk.un_880
  0x080704a0, 0x02002904, 0x05002312, 0x020c08a0,   // ru.bg.uk_322 sl.da.un_320  ca.fr.un_640 no.sv.da_322
  0x08172904, 0x2d002308, 0x0c041ba0, 0x0d001c2b,   // sl.sr.no_332 ca.sk.un_430  tr.fi.sv_322 mr.ne.un_980
  0x311b120c, 0x17001212, 0x20000807, 0x0a230504,   // hu.tr.az_543 hu.sr.un_640  no.sq.un_420 fr.ca.pt_332
  // [6ac0]
  0x04001e02, 0x12002d23, 0x3f001308, 0x3b2a31ac,   // ms.fi.un_220 sk.hu.un_880  et.af.un_430 az.mt.so_632
  0x0b12180c, 0x53311a14, 0x6e133113, 0x31131e07,   // ga.hu.es_543 tl.az.ht_666  az.et.hmn_665 ms.et.az_432
  0x0f171604, 0x31003b21, 0x070c0804, 0x0417070b,   // hr.sr.lv_332 so.az.un_860  no.sv.it_332 bg.sr.ru_542
  0x1e132aaf, 0x3b003112, 0x4a00530c, 0x31521e0c,   // mt.et.ms_655 az.so.un_640  ht.yo.un_530 ms.ha.az_543
  // [6ad0]
  0x53281b13, 0x31005308, 0x28002907, 0x0f001005,   // tr.sw.ht_665 ht.az.un_430  sl.sw.un_420 lt.lv.un_330
  0x07000e08, 0x3b316e08, 0x212535a7, 0x520f10ec,   // is.it.un_430 hmn.az.so_443  zu.eu.jw_532 lt.lv.ha_644
  0x31001312, 0x181135ad, 0x2d0d1aee, 0x0f2910a4,   // et.az.un_640 zu.ro.ga_643  tl.cs.sk_422 lt.sl.lv_433
  0x13213112, 0x1f136ea9, 0x3b351f12, 0x3100130c,   // az.jw.et_654 hmn.et.cy_544  cy.zu.so_654 et.az.un_530
  // [6ae0]
  0x35001304, 0x1e3b31a9, 0x0f1132a0, 0x1c041e07,   // et.zu.un_320 az.so.ms_544  bs.ro.lv_322 ms.fi.id_432
  0x092004a4, 0x23080c07, 0x07001121, 0x10003f13,   // fi.sq.pl_433 sv.no.ca_432  ro.bg.un_860 af.lt.un_650
  0x28160f04, 0x16100f05, 0x0e0c0811, 0x282d0d12,   // lv.hr.sw_332 lv.lt.hr_333  no.sv.is_653 cs.sk.sw_654
  0x08003519, 0x040a08af, 0x28006819, 0x216435a4,   // zu.no.un_750 uk.mk.ru_655  ig.sw.un_750 zu.lg.jw_433
  // [6af0]
  0x35642804, 0x320728a0, 0x2d0e2aa4, 0x250b1e04,   // sw.lg.zu_332 sw.it.bs_322  mt.is.sk_433 ms.es.eu_332
  0x2d00061a, 0x2b033f05, 0x4a5564a0, 0x131b3508,   // de.sk.un_760 af.nl.vi_333  lg.rw.yo_322 zu.tr.et_443
  0x3b00040d, 0x5200030c, 0x312a1fad, 0x0d1c13ec,   // fi.so.un_540 nl.ha.un_530  cy.mt.az_643 bh.mr.ne_644
  0x3f002312, 0x283555a7, 0x021a6bee, 0x536e050c,   // ca.af.un_640 rw.zu.sw_532  ceb.tl.da_422 fr.hmn.ht_543
  // [6b00]
  0x2809550c, 0x2000060c, 0x094a28a0, 0x231101a0,   // rw.pl.sw_543 de.sq.un_530  sw.yo.pl_322 en.ro.ca_322
  0x0d162da0, 0x09002812, 0x0e120da4, 0x0d180ead,   // sk.hr.cs_322 sw.pl.un_640  cs.hu.is_433 is.ga.cs_643
  0x1b043109, 0x0d000813, 0x041a01a0, 0x03060c02,   // az.fi.tr_444 no.cs.un_650  en.tl.fi_322 sv.de.nl_222
  0x2a040712, 0x1e033fa0, 0x0b0220a7, 0x23002a19,   // it.fi.mt_654 af.nl.ms_322  sq.da.es_532 mt.ca.un_750
  // [6b10]
  0x01030607, 0x13000302, 0x1b000805, 0x04000f08,   // de.nl.en_432 nl.et.un_220  no.tr.un_330 lv.fi.un_430
  0x033f1105, 0x18011f04, 0x31001b34, 0x03001320,   // ro.af.nl_333 cy.en.ga_332  tr.az.un_A80 et.nl.un_850
  0x082a07ec, 0x531b250e, 0x3f3b0304, 0x100802a4,   // it.mt.no_644 eu.tr.ht_555  nl.so.af_332 da.no.lt_433
  0x190b25ec, 0x0f082dee, 0x32311e05, 0x1b002512,   // eu.es.gl_644 sk.no.lv_422  ms.az.bs_333 eu.tr.un_640
  // [6b20]
  0x0a110107, 0x202a1ba7, 0x2d100faf, 0x0d002504,   // en.ro.pt_432 tr.mt.sq_532  lv.lt.sk_655 eu.cs.un_320
  0x23005302, 0x04200fad, 0x1a0f1005, 0x521b25ee,   // ht.ca.un_220 lv.sq.fi_643  lt.lv.tl_333 eu.tr.ha_422
  0x3b352504, 0x1b00531b, 0x3f001e21, 0x4a001b04,   // eu.zu.so_332 ht.tr.un_770  ms.af.un_860 tr.yo.un_320
  0x09292d0b, 0x53201ba4, 0x1b0b53ee, 0x0d171602,   // sk.sl.pl_542 tr.sq.ht_433  ht.es.tr_422 hr.sr.cs_222
  // [6b30]
  0x171f32ee, 0x092321a7, 0x32290da4, 0x35004a02,   // bs.cy.sr_422 jw.ca.pl_532  cs.sl.bs_433 yo.zu.un_220
  0x35000704, 0x08211b08, 0x170f10a4, 0x2d0d13af,   // it.zu.un_320 tr.jw.no_443  lt.lv.sr_433 et.cs.sk_655
  0x3f0e0804, 0x0a3f060c, 0x1c064aa6, 0x270e53ad,   // no.is.af_332 de.af.pt_543  yo.de.id_521 ht.is.gd_643
  0x06002707, 0x6b6827ee, 0x520e3f55, 0x27030655,   // gd.de.un_420 gd.ig.ceb_422  af.is.ha_442 de.nl.gd_442
  // [6b40]
  0x18000509, 0x081011ee, 0x0e275307, 0x0c532707,   // fr.ga.un_440 ro.be.uk_422  ht.gd.is_432 gd.ht.sv_432
  0x111353a7, 0x3f030a11, 0x0c5308a4, 0x1c1e250d,   // ht.et.ro_532 pt.nl.af_653  no.ht.sv_433 eu.ms.id_554
  0x18130612, 0x0a0811a6, 0x021b08ee, 0x5500040d,   // de.et.ga_654 ro.uk.mk_521  no.tr.da_422 fi.rw.un_540
  0x010f0302, 0x041b13a0, 0x16092912, 0x3209290c,   // nl.lv.en_222 et.tr.fi_322  sl.pl.hr_654 sl.pl.bs_543
  // [6b50]
  0x03130907, 0x235502ee, 0x5500350c, 0x25006e0b,   // pl.et.nl_432 da.rw.ca_422  zu.rw.un_530 hmn.eu.un_520
  0x01000608, 0x06080c0c, 0x3b0820a0, 0x092917a0,   // de.en.un_430 sv.no.de_543  sq.no.so_322 sr.sl.pl_322
  0x180c3fa4, 0x0e083507, 0x3b0812a4, 0x11000408,   // af.sv.ga_433 zu.no.is_432  hu.no.so_433 fi.ro.un_430
  0x106409a0, 0x01005207, 0x091729a4, 0x04190aee,   // pl.lg.lt_322 ha.en.un_420  sl.sr.pl_433 pt.gl.fi_422
  // [6b60]
  0x08211a04, 0x1e091005, 0x092912ec, 0x11001807,   // tl.jw.no_332 lt.pl.ms_333  hu.sl.pl_644 ga.ro.un_420
  0x3b1f640c, 0x0411070c, 0x091a6b0c, 0x12002011,   // lg.cy.so_543 bg.ro.ru_543  ceb.tl.pl_543 sq.hu.un_630
  0x060e0c12, 0x17162da0, 0x31002704, 0x09071304,   // sv.is.de_654 sk.hr.sr_322  gd.az.un_320 et.it.pl_332
  0x231e3bad, 0x0e311b0d, 0x23050e0e, 0x1e0e1ca4,   // so.ms.ca_643 tr.az.is_554  is.fr.ca_555 id.is.ms_433
  // [6b70]
  0x1e002907, 0x520e3bee, 0x311b18af, 0x230e0807,   // sl.ms.un_420 so.is.ha_422  ga.tr.az_655 no.is.ca_432
  0x2a070413, 0x18002720, 0x190b1eaf, 0x310e080c,   // fi.it.mt_665 gd.ga.un_850  ms.es.gl_655 no.is.az_543
  0x0d121907, 0x0c3f03ee, 0x251607a4, 0x2d0d4aa4,   // gl.hu.cs_432 nl.af.sv_422  it.hr.eu_433 yo.cs.sk_433
  0x351125a0, 0x120c2dee, 0x320a3108, 0x2804550c,   // eu.ro.zu_322 sk.sv.hu_422  az.pt.bs_443 rw.fi.sw_543
  // [6b80]
  0x0d3b0604, 0x251235a4, 0x3b3119ee, 0x21124a07,   // de.so.cs_332 zu.hu.eu_433  gl.az.so_422 yo.hu.jw_432
  0x213b1fec, 0x282155ee, 0x352507af, 0x556b1a13,   // cy.so.jw_644 rw.jw.sw_422  it.eu.zu_655 tl.ceb.rw_665
  0x23310ead, 0x19122dee, 0x0e311ea4, 0x192d0d12,   // is.az.ca_643 sk.hu.gl_422  ms.az.is_433 cs.sk.gl_654
  0x19052102, 0x4a002317, 0x1e312004, 0x3f286804,   // jw.fr.gl_222 ca.yo.un_730  sq.az.ms_332 ig.sw.af_332
  // [6b90]
  0x0a0805a4, 0x0f002d0d, 0x1a00680c, 0x0e001804,   // fr.no.pt_433 sk.lv.un_540  ig.tl.un_530 ga.is.un_320
  0x0c2104ee, 0x06000d0e, 0x0e0c3fa0, 0x2d002104,   // fi.jw.sv_422 cs.de.un_550  af.sv.is_322 jw.sk.un_320
  0x35250604, 0x20110d07, 0x172868a0, 0x6b1a04a4,   // de.eu.zu_332 cs.ro.sq_432  ig.sw.sr_322 fi.tl.ceb_433
  0x28352112, 0x3b00271a, 0x2d00120e, 0x0f171012,   // jw.zu.sw_654 gd.so.un_760  hu.sk.un_550 lt.sr.lv_654
  // [6ba0]
  0x3b002708, 0x190b2da9, 0x556428a7, 0x04271160,   // gd.so.un_430 sk.es.gl_544  sw.lg.rw_532 ro.gd.fi_664
  0x08050412, 0x04000829, 0x3f0e040c, 0x033f04a4,   // fi.fr.no_654 uk.ru.un_960  fi.is.af_543 fi.af.nl_433
  0x041f0e11, 0x18293fee, 0x04061fa0, 0x3f080305,   // is.cy.fi_653 af.sl.ga_422  cy.de.fi_322 nl.no.af_333
  0x52006e0c, 0x03053fa0, 0x040503a4, 0x06031fa0,   // hmn.ha.un_530 af.fr.nl_322  nl.fr.fi_433 cy.nl.de_322
  // [6bb0]
  0x05040612, 0x13036407, 0x3b4a355a, 0x2505040b,   // de.fi.fr_654 lg.nl.et_432  zu.yo.so_553 fi.fr.eu_542
  0x04002519, 0x273f0311, 0x0c3f0355, 0x2d230a0c,   // eu.fi.un_750 nl.af.gd_653  nl.af.sv_442 pt.ca.sk_543
  0x351a6b11, 0x0c032902, 0x1b354a07, 0x0700081b,   // ceb.tl.zu_653 sl.nl.sv_222  yo.zu.tr_432 uk.bg.un_770
  0x12003513, 0x1c0d095a, 0x1b000c14, 0x1c531eee,   // zu.hu.un_650 hi.ne.mr_553  sv.tr.un_660 ms.ht.id_422
  // [6bc0]
  0x1b023104, 0x12354a12, 0x641035ad, 0x03083f08,   // az.da.tr_332 yo.zu.hu_654  zu.lt.lg_643 af.no.nl_443
  0x313555af, 0x13033fad, 0x12002514, 0x553564ac,   // rw.zu.az_655 af.nl.et_643  eu.hu.un_660 lg.zu.rw_632
  0x3f031fac, 0x1006210c, 0x0b5255ee, 0x2d120d0c,   // cy.nl.af_632 jw.de.lt_543  rw.ha.es_422 cs.hu.sk_543
  0x0c211cad, 0x641a6bec, 0x1e1c05ee, 0x0a001f02,   // id.jw.sv_643 ceb.tl.lg_644  fr.id.ms_422 cy.pt.un_220
  // [6bd0]
  0x2500681a, 0x0b0a12ee, 0x201f2d0c, 0x09000413,   // ig.eu.un_760 hu.pt.es_422  sk.cy.sq_543 fi.pl.un_650
  0x20002d0d, 0x1125100c, 0x17004a05, 0x1e1c12a4,   // sk.sq.un_540 lt.eu.ro_543  yo.sr.un_330 hu.id.ms_433
  0x2500121a, 0x1a0453a0, 0x4a2011ad, 0x1b310a07,   // hu.eu.un_760 ht.fi.tl_322  ro.sq.yo_643 pt.az.tr_432
  0x0400530e, 0x1c0b5305, 0x2b004a07, 0x011b1f07,   // ht.fi.un_550 ht.es.id_333  yo.vi.un_420 cy.tr.en_432
  // [6be0]
  0x101101a0, 0x0b091109, 0x041f4aa7, 0x04001f08,   // en.ro.lt_322 ro.pl.es_444  yo.cy.fi_532 cy.fi.un_430
  0x3b00130c, 0x09000408, 0x0c041055, 0x0a004a09,   // et.so.un_530 fi.pl.un_430  lt.fi.sv_442 yo.pt.un_440
  0x0e6404ee, 0x04130605, 0x09002908, 0x4a286460,   // fi.lg.is_422 de.et.fi_333  sl.pl.un_430 lg.sw.yo_664
  0x526828af, 0x6412280c, 0x07081111, 0x04001111,   // sw.ig.ha_655 sw.hu.lg_543  ro.uk.bg_653 ro.ru.un_630
  // [6bf0]
  0x213120ec, 0x19201804, 0x531a6ba9, 0x23000a21,   // sq.az.jw_644 ga.sq.gl_332  ceb.tl.ht_544 pt.ca.un_860
  0x25645512, 0x1c0f52ee, 0x0f082007, 0x09002a22,   // rw.lg.eu_654 ha.lv.id_422  sq.no.lv_432 mt.pl.un_870
  0x0c2a4a08, 0x1300070c, 0x6b005521, 0x18071107,   // yo.mt.sv_443 it.et.un_530  rw.ceb.un_860 ro.it.ga_432
  0x20101b12, 0x55042a08, 0x356b53a4, 0x20212dee,   // tr.lt.sq_654 mt.fi.rw_443  ht.ceb.zu_433 sk.jw.sq_422

  // [6c00]
  0x320428ad, 0x182a2007, 0x27001902, 0x531a2a05,   // sw.fi.bs_643 sq.mt.ga_432  gl.gd.un_220 mt.tl.ht_333
  0x19000e0b, 0x0d2d18af, 0x2b003202, 0x07000b0e,   // is.gl.un_520 ga.sk.cs_655  bs.vi.un_220 es.it.un_550
  0x3b3f03ee, 0x1f0a0b07, 0x6b000b07, 0x0b2d1907,   // nl.af.so_422 es.pt.cy_432  es.ceb.un_420 gl.sk.es_432
  0x042718a0, 0x04006e0b, 0x11002704, 0x4a3b29a0,   // ga.gd.fi_322 hmn.fi.un_520  gd.ro.un_320 sl.so.yo_322
  // [6c10]
  0x16272504, 0x1e072304, 0x10046407, 0x0927110e,   // eu.gd.hr_332 ca.it.ms_332  lg.fi.lt_432 ro.gd.pl_555
  0x3f640305, 0x2d120d07, 0x03003104, 0x020801ad,   // nl.lg.af_333 cs.hu.sk_432  az.nl.un_320 en.no.da_643
  0x133f0309, 0x19002807, 0x16001704, 0x1a0228a4,   // nl.af.et_444 sw.gl.un_420  sr.hr.un_320 sw.da.tl_433
  0x1311270c, 0x18132702, 0x52002a19, 0x28252aaf,   // gd.ro.et_543 gd.et.ga_222  mt.ha.un_750 mt.eu.sw_655
  // [6c20]
  0x6b00280d, 0x0c060a0c, 0x6400040e, 0x3500290b,   // sw.ceb.un_540 pt.de.sv_543  fi.lg.un_550 sl.zu.un_520
  0x5510350c, 0x2d0f29a4, 0x0f2a5255, 0x32000612,   // zu.lt.rw_543 sl.lv.sk_433  ha.mt.lv_442 de.bs.un_640
  0x4a041312, 0x05060113, 0x01020811, 0x64285305,   // et.fi.yo_654 en.de.fr_665  no.da.en_653 ht.sw.lg_333
  0x06000122, 0x55211c0c, 0x351b640c, 0x16112a0c,   // en.de.un_870 id.jw.rw_543  lg.tr.zu_543 mt.ro.hr_543
  // [6c30]
  0x07010604, 0x232b0a11, 0x050b1ea4, 0x163528a7,   // de.en.it_332 pt.vi.ca_653  ms.es.fr_433 sw.zu.hr_532
  0x350f0e05, 0x17041002, 0x04001f29, 0x1c120fa4,   // is.lv.zu_333 be.ru.sr_222  cy.fi.un_960 lv.hu.id_433
  0x033f3507, 0x0b2d0d55, 0x09002508, 0x29162a04,   // zu.af.nl_432 cs.sk.es_442  eu.pl.un_430 mt.hr.sl_332
  0x1e211c55, 0x0200350d, 0x1e072d0c, 0x06003b13,   // id.jw.ms_442 zu.da.un_540  sk.it.ms_543 so.de.un_650
  // [6c40]
  0x53291ea0, 0x1200250c, 0x01000612, 0x27001c07,   // ms.sl.ht_322 eu.hu.un_530  de.en.un_640 id.gd.un_420
  0x060a0e13, 0x21031e08, 0x0912250c, 0x190a28ec,   // is.pt.de_665 ms.nl.jw_443  eu.hu.pl_543 sw.pt.gl_644
  0x280b0aa4, 0x55282102, 0x27002102, 0x0a0712a4,   // pt.es.sw_433 jw.sw.rw_222  jw.gd.un_220 hu.it.pt_433
  0x29080205, 0x1e000a0c, 0x1e211aa0, 0x283208ee,   // da.no.sl_333 pt.ms.un_530  tl.jw.ms_322 no.bs.sw_422
  // [6c50]
  0x32170fa4, 0x1b0f10ad, 0x21000513, 0x0b002323,   // lv.sr.bs_433 lt.lv.tr_643  fr.jw.un_650 ca.es.un_880
  0x1a211c0c, 0x120925ad, 0x09202507, 0x286e1b05,   // id.jw.tl_543 eu.pl.hu_643  eu.sq.pl_432 tr.hmn.sw_333
  0x212d1c12, 0x2b003f02, 0x08001804, 0x16001b08,   // id.sk.jw_654 af.vi.un_220  ga.no.un_320 tr.hr.un_430
  0x20003214, 0x030118ee, 0x0c080ead, 0x2a000713,   // bs.sq.un_660 ga.en.nl_422  is.no.sv_643 it.mt.un_650
  // [6c60]
  0x1c210714, 0x192d0aad, 0x0a09070c, 0x2d060107,   // it.jw.id_666 pt.sk.gl_643  it.pl.pt_543 en.de.sk_432
  0x16000405, 0x68251204, 0x091c13a9, 0x290e0c0c,   // fi.hr.un_330 hu.eu.ig_332  bh.mr.hi_544 sv.is.sl_543
  0x20033f0d, 0x18120ea7, 0x55002912, 0x09000e02,   // af.nl.sq_554 is.hu.ga_532  sl.rw.un_640 is.pl.un_220
  0x2d00180c, 0x184a2da7, 0x04001011, 0x09000e05,   // ga.sk.un_530 sk.yo.ga_532  be.ru.un_630 is.pl.un_330
  // [6c70]
  0x290e0caf, 0x1a353f0c, 0x2d1218ec, 0x231b01a4,   // sv.is.sl_655 af.zu.tl_543  ga.hu.sk_644 en.tr.ca_433
  0x551b6407, 0x3b5228ec, 0x6b0f1aa4, 0x081004a0,   // lg.tr.rw_432 sw.ha.so_644  tl.lv.ceb_433 ru.be.uk_322
  0x55641aa7, 0x6b6809a0, 0x1f643baf, 0x07002319,   // tl.lg.rw_532 pl.ig.ceb_322  so.lg.cy_655 ca.it.un_750
  0x641c1e0c, 0x64551105, 0x521e21af, 0x071a0107,   // ms.id.lg_543 ro.rw.lg_333  jw.ms.ha_655 en.tl.it_432
  // [6c80]
  0x0b28535a, 0x35001109, 0x3b005212, 0x53002308,   // ht.sw.es_553 ro.zu.un_440  ha.so.un_640 ca.ht.un_430
  0x6b681aa4, 0x10000f2c, 0x02002a07, 0x10001c08,   // tl.ig.ceb_433 lv.lt.un_990  mt.da.un_420 id.lt.un_430
  0x106435a4, 0x0b1804ee, 0x2d0d0eee, 0x29002d1b,   // zu.lg.lt_433 fi.ga.es_422  is.cs.sk_422 sk.sl.un_770
  0x13000f13, 0x290d2da9, 0x2d324aee, 0x101704a7,   // lv.et.un_650 sk.cs.sl_544  yo.bs.sk_422 ru.sr.be_532
  // [6c90]
  0x28203ba4, 0x2a000804, 0x2300072c, 0x230a2a0c,   // so.sq.sw_433 no.mt.un_320  it.ca.un_990 mt.pt.ca_543
  0x12004a09, 0x17001b07, 0x524a28a7, 0x1f0d2da4,   // yo.hu.un_440 tr.sr.un_420  sw.yo.ha_532 sk.cs.cy_433
  0x0a000e05, 0x05000a02, 0x201304ee, 0x6e000d12,   // is.pt.un_330 pt.fr.un_220  fi.et.sq_422 cs.hmn.un_640
  0x13000421, 0x350a5513, 0x010b280b, 0x04551355,   // fi.et.un_860 rw.pt.zu_665  sw.es.en_542 et.rw.fi_442
  // [6ca0]
  0x64354a04, 0x2a000712, 0x19003b21, 0x12103f08,   // yo.zu.lg_332 it.mt.un_640  so.gl.un_860 af.lt.hu_443
  0x28001212, 0x0a0701a0, 0x29171608, 0x176b1a04,   // hu.sw.un_640 en.it.pt_322  hr.sr.sl_443 tl.ceb.sr_332
  0x25112313, 0x64192a04, 0x31353bad, 0x02000811,   // ca.ro.eu_665 mt.gl.lg_332  so.zu.az_643 no.da.un_630
  0x110b0aee, 0x351a5204, 0x3f005302, 0x1c2106a0,   // pt.es.ro_422 ha.tl.zu_332  ht.af.un_220 de.jw.id_322
  // [6cb0]
  0x3b0e06a0, 0x0e00061b, 0x283b0107, 0x3b1a0105,   // de.is.so_322 de.is.un_770  en.so.sw_432 en.tl.so_333
  0x530e55a4, 0x68003b18, 0x04080a0d, 0x136b55ec,   // rw.is.ht_433 so.ig.un_740  mk.uk.ru_554 rw.ceb.et_644
  0x21190205, 0x131835a4, 0x3b0e13a7, 0x520e28a7,   // da.gl.jw_333 zu.ga.et_433  et.is.so_532 sw.is.ha_532
  0x02001708, 0x13110e05, 0x35001104, 0x0c060255,   // sr.da.un_430 is.ro.et_333  ro.zu.un_320 da.de.sv_442
  // [6cc0]
  0x1a04130c, 0x110e55a4, 0x0708020c, 0x3500111a,   // et.fi.tl_543 rw.is.ro_433  da.no.it_543 ro.zu.un_760
  0x0e5513a0, 0x285564a4, 0x03020755, 0x062507af,   // et.rw.is_322 lg.rw.sw_433  it.da.nl_442 it.eu.de_655
  0x4a000e19, 0x1f2d0d04, 0x2025060c, 0x55356407,   // is.yo.un_750 cs.sk.cy_332  de.eu.sq_543 lg.zu.rw_432
  0x04002108, 0x090c1f11, 0x081007ad, 0x6455250c,   // jw.fi.un_430 cy.sv.pl_653  bg.be.uk_643 eu.rw.lg_543
  // [6cd0]
  0x0f0711a7, 0x11213507, 0x0717290c, 0x28643507,   // ro.it.lv_532 zu.jw.ro_432  sl.sr.it_543 zu.lg.sw_432
  0x1a552004, 0x120e1112, 0x3b002508, 0x0f006b33,   // sq.rw.tl_332 ro.is.hu_654  eu.so.un_430 ceb.lv.un_A70
  0x323525ee, 0x2064070c, 0x1c551ea9, 0x2007640c,   // eu.zu.bs_422 it.lg.sq_543  ms.rw.id_544 lg.it.sq_543
  0x6b1a0708, 0x0e041304, 0x040c13a6, 0x29006b04,   // it.tl.ceb_443 et.fi.is_332  et.sv.fi_521 ceb.sl.un_320
  // [6ce0]
  0x1a6b070c, 0x52004a1a, 0x0b0111ee, 0x351e1c5a,   // it.ceb.tl_543 yo.ha.un_760  ro.en.es_422 id.ms.zu_553
  0x113b1a0c, 0x10284a12, 0x2109350c, 0x0e211e07,   // tl.so.ro_543 yo.sw.lt_654  zu.pl.jw_543 ms.jw.is_432
  0x06000205, 0x190b25ee, 0x25033fee, 0x0a001007,   // da.de.un_330 eu.es.gl_422  af.nl.eu_422 be.mk.un_420
  0x11130404, 0x55526413, 0x292152a4, 0x12000d07,   // fi.et.ro_332 lg.ha.rw_665  ha.jw.sl_433 cs.hu.un_420
  // [6cf0]
  0x1a1b4aad, 0x55001c07, 0x04003202, 0x191a0708,   // yo.tr.tl_643 id.rw.un_420  bs.fi.un_220 it.tl.gl_443
  0x12002d19, 0x2913170c, 0x282107ee, 0x1a0e2155,   // sk.hu.un_750 sr.et.sl_543  it.jw.sw_422 jw.is.tl_442
  0x311b1105, 0x13080305, 0x1a4a640c, 0x17110411,   // ro.tr.az_333 nl.no.et_333  lg.yo.tl_543 ru.ro.sr_653
  0x35000f12, 0x04130312, 0x28046408, 0x21001e18,   // lv.zu.un_640 nl.et.fi_654  lg.fi.sw_443 ms.jw.un_740
  // [6d00]
  0x1c006808, 0x64551f08, 0x1b353207, 0x35551308,   // ig.id.un_430 cy.rw.lg_443  bs.zu.tr_432 et.rw.zu_443
  0x27001f12, 0x04132108, 0x08021902, 0x32350da0,   // cy.gd.un_640 jw.et.fi_443  gl.da.no_222 cs.zu.bs_322
  0x27044a02, 0x3b130207, 0x03096412, 0x05072a13,   // yo.fi.gd_222 da.et.so_432  lg.pl.nl_654 mt.it.fr_665
  0x190b1f09, 0x123f0207, 0x0e080212, 0x0f001c0b,   // cy.es.gl_444 da.af.hu_432  da.no.is_654 id.lv.un_520
  // [6d10]
  0x281f010c, 0x1f311b09, 0x2a00032a, 0x52002829,   // en.cy.sw_543 tr.az.cy_444  nl.mt.un_970 sw.ha.un_960
  0x04133b09, 0x12000f08, 0x2a5507ad, 0x3f3b64a7,   // so.et.fi_444 lv.hu.un_430  it.rw.mt_643 lg.so.af_532
  0x533135a7, 0x644a35af, 0x643b0407, 0x19230b60,   // zu.az.ht_532 zu.yo.lg_655  fi.so.lg_432 es.ca.gl_664
  0x0400082a, 0x1e286405, 0x1c0219a7, 0x232d29a7,   // uk.ru.un_970 lg.sw.ms_333  gl.da.id_532 sl.sk.ca_532
  // [6d20]
  0x0e555207, 0x28002904, 0x0c0e1bec, 0x0e00520c,   // ha.rw.is_432 sl.sw.un_320  tr.is.sv_644 ha.is.un_530
  0x552b3507, 0x2a6b6e0c, 0x0e001809, 0x121809ec,   // zu.vi.rw_432 hmn.ceb.mt_543  ga.is.un_440 pl.ga.hu_644
  0x0a001005, 0x1e1c11a4, 0x041a1b0c, 0x2d1206a9,   // be.mk.un_330 ro.id.ms_433  tr.tl.fi_543 de.hu.sk_544
  0x0900110e, 0x5225040c, 0x165564ad, 0x10230b07,   // ro.pl.un_550 fi.eu.ha_543  lg.rw.hr_643 es.ca.lt_432
  // [6d30]
  0x311b645a, 0x32005304, 0x3200160d, 0x2364280c,   // lg.tr.az_553 ht.bs.un_320  hr.bs.un_540 sw.lg.ca_543
  0x1b556408, 0x230b250d, 0x0e550a05, 0x52552813,   // lg.rw.tr_443 eu.es.ca_554  pt.rw.is_333 sw.rw.ha_665
  0x135535a7, 0x28684aac, 0x351a52af, 0x2a0731a9,   // zu.rw.et_532 yo.ig.sw_632  ha.tl.zu_655 az.it.mt_544
  0x20286408, 0x3b5564a9, 0x35110f07, 0x4a55645a,   // lg.sw.sq_443 lg.rw.so_544  lv.ro.zu_432 lg.rw.yo_553
  // [6d40]
  0x1a1b530c, 0x1a0453ec, 0x31115507, 0x10353fa0,   // ht.tr.tl_543 ht.fi.tl_644  rw.ro.az_432 af.zu.lt_322
  0x2d002307, 0x525504a4, 0x0b070d09, 0x25063ba4,   // ca.sk.un_420 fi.rw.ha_433  cs.it.es_444 so.de.eu_433
  0x3200350d, 0x6800250d, 0x5500282a, 0x04190ba7,   // zu.bs.un_540 eu.ig.un_540  sw.rw.un_970 es.gl.fi_532
  0x31556412, 0x1a6b5308, 0x033f1c12, 0x2a0f0604,   // lg.rw.az_654 ht.ceb.tl_443  id.af.nl_654 de.lv.mt_332
  // [6d50]
  0x530f5507, 0x32202904, 0x05190a08, 0x6455100d,   // rw.lv.ht_432 sl.sq.bs_332  pt.gl.fr_443 lt.rw.lg_554
  0x0d002702, 0x68001a0c, 0x351755a4, 0x12640404,   // gd.cs.un_220 tl.ig.un_530  rw.sr.zu_433 fi.lg.hu_332
  0x02080e04, 0x21123f05, 0x13552813, 0x2a0721a4,   // is.no.da_332 af.hu.jw_333  sw.rw.et_665 jw.it.mt_433
  0x05001217, 0x31001107, 0x081204a0, 0x1e1c2112,   // hu.fr.un_730 ro.az.un_420  fi.hu.no_322 jw.id.ms_654
  // [6d60]
  0x321b55a4, 0x32001008, 0x03213fa9, 0x20000605,   // rw.tr.bs_433 lt.bs.un_430  af.jw.nl_544 de.sq.un_330
  0x53001e12, 0x64001207, 0x3b536b07, 0x6b091a14,   // ms.ht.un_640 hu.lg.un_420  ceb.ht.so_432 tl.pl.ceb_666
  0x05004a0c, 0x1f0a27ee, 0x04001f11, 0x4a1208ee,   // yo.fr.un_530 gd.pt.cy_422  cy.fi.un_630 no.hu.yo_422
  0x12020812, 0x182a10a0, 0x10190b02, 0x1c1f1e0c,   // no.da.hu_654 lt.mt.ga_322  es.gl.lt_222 ms.cy.id_543
  // [6d70]
  0x0a101105, 0x35091fa7, 0x0c001b0c, 0x113b0309,   // ro.be.mk_333 cy.pl.zu_532  tr.sv.un_530 nl.so.ro_444
  0x080e065a, 0x21000e12, 0x1655030c, 0x10111709,   // de.is.no_553 is.jw.un_640  nl.rw.hr_543 sr.ro.be_444
  0x066401a4, 0x18002d13, 0x0c1e1c09, 0x1b3b1305,   // en.lg.de_433 sk.ga.un_650  id.ms.sv_444 et.so.tr_333
  0x2a00070c, 0x08230112, 0x0903060b, 0x21031313,   // it.mt.un_530 en.ca.no_654  de.nl.pl_542 et.nl.jw_665
  // [6d80]
  0x02003b13, 0x11530612, 0x6b1a6408, 0x0f001112,   // so.da.un_650 de.ht.ro_654  lg.tl.ceb_443 ro.lv.un_640
  0x5535070c, 0x05006b02, 0x02033f0c, 0x31001a0e,   // it.zu.rw_543 ceb.fr.un_220  af.nl.da_543 tl.az.un_550
  0x042128a7, 0x290f1205, 0x6b530755, 0x04000913,   // sw.jw.fi_532 hu.lv.sl_333  it.ht.ceb_442 pl.fi.un_650
  0x1c641e07, 0x2b003502, 0x55283bad, 0x112320ee,   // ms.lg.id_432 zu.vi.un_220  so.sw.rw_643 sq.ca.ro_422
  // [6d90]
  0x11005304, 0x1f276ba7, 0x35640107, 0x3b12100d,   // ht.ro.un_320 ceb.gd.cy_532  en.lg.zu_432 lt.hu.so_554
  0x1a353b04, 0x29000522, 0x0c0f19a0, 0x4a311bad,   // so.zu.tl_332 fr.sl.un_870  gl.lv.sv_322 tr.az.yo_643
  0x0e210507, 0x64284aad, 0x0d001914, 0x082927a0,   // fr.jw.is_432 yo.sw.lg_643  gl.cs.un_660 gd.sl.no_322
  0x531b0b05, 0x1a213fa0, 0x29053fa0, 0x2a00130d,   // es.tr.ht_333 af.jw.tl_322  af.fr.sl_322 et.mt.un_540
  // [6da0]
  0x072b010c, 0x04001a0e, 0x530552a0, 0x25042804,   // en.vi.it_543 tl.fi.un_550  ha.fr.ht_322 sw.fi.eu_332
  0x6b000111, 0x1e1c53af, 0x31111ba0, 0x11080412,   // en.ceb.un_630 ht.id.ms_655  tr.ro.az_322 ru.uk.ro_654
  0x32000f04, 0x2d3129a0, 0x523b55ad, 0x07520e08,   // lv.bs.un_320 sl.az.sk_322  rw.so.ha_643 is.ha.it_443
  0x29086ea0, 0x2d0d2907, 0x3b072aad, 0x1b131f02,   // hmn.no.sl_322 sl.cs.sk_432  mt.it.so_643 cy.et.tr_222
  // [6db0]
  0x2d0d12a9, 0x4a005521, 0x3b1e2aad, 0x2a0f0760,   // hu.cs.sk_544 rw.yo.un_860  mt.ms.so_643 it.lv.mt_664
  0x2d0d0ab6, 0x1c211108, 0x354a64a7, 0x112a0705,   // pt.cs.sk_766 ro.jw.id_443  lg.yo.zu_532 it.mt.ro_333
  0x12006b14, 0x64135513, 0x2a031211, 0x19002d0b,   // ceb.hu.un_660 rw.et.lg_665  hu.nl.mt_653 sk.gl.un_520
  0x0b642507, 0x1b25215a, 0x0c020e04, 0x64001214,   // eu.lg.es_432 jw.eu.tr_553  is.da.sv_332 hu.lg.un_660
  // [6dc0]
  0x2d0d3f0b, 0x13090dee, 0x311304ee, 0x1200130e,   // af.cs.sk_542 ne.hi.bh_422  fi.et.az_422 et.hu.un_550
  0x0c03020c, 0x2d0d0614, 0x20004a12, 0x19001e05,   // da.nl.sv_543 de.cs.sk_666  yo.sq.un_640 ms.gl.un_330
  0x3229170c, 0x06003504, 0x03003b19, 0x23181aac,   // sr.sl.bs_543 zu.de.un_320  so.nl.un_750 tl.ga.ca_632
  0x09355507, 0x55002504, 0x17001008, 0x20000208,   // rw.zu.pl_432 eu.rw.un_320  be.sr.un_430 da.sq.un_430
  // [6dd0]
  0x3b00060e, 0x080264ee, 0x0d0c1fa4, 0x3b004a07,   // de.so.un_550 lg.da.no_422  cy.sv.cs_433 yo.so.un_420
  0x2d0d0cec, 0x18001204, 0x0900060c, 0x0c0d2d07,   // sv.cs.sk_644 ur.ar.un_320  de.pl.un_530 sk.cs.sv_432
  0x350455a0, 0x2d0d0609, 0x28135507, 0x5500040e,   // rw.fi.zu_322 de.cs.sk_444  rw.et.sw_432 fi.rw.un_550
  0x04005508, 0x073f08a9, 0x23021b0b, 0x10351360,   // rw.fi.un_430 no.af.it_544  tr.da.ca_542 et.zu.lt_664
  // [6de0]
  0x03000609, 0x2b100307, 0x1110550b, 0x31355508,   // de.nl.un_440 nl.lt.vi_432  rw.lt.ro_542 rw.zu.az_443
  0x0c030802, 0x10005508, 0x2a081309, 0x2b3f2aa0,   // no.nl.sv_222 rw.lt.un_430  et.no.mt_444 mt.af.vi_322
  0x16290d04, 0x13080ea4, 0x08002d02, 0x3f030fec,   // cs.sl.hr_332 is.no.et_433  sk.no.un_220 lv.nl.af_644
  0x0f122d05, 0x0f3b04a4, 0x106b1a13, 0x0a00111a,   // sk.hu.lv_333 fi.so.lv_433  tl.ceb.lt_665 ro.mk.un_760
  // [6df0]
  0x04002b08, 0x190b0709, 0x1a001608, 0x121f1007,   // vi.fi.un_430 it.es.gl_444  hr.tl.un_430 lt.cy.hu_432
  0x6400680c, 0x135268a4, 0x0b231904, 0x4a1a55af,   // ig.lg.un_530 ig.ha.et_433  gl.ca.es_332 rw.tl.yo_655
  0x181a4a12, 0x070b4a13, 0x02006b04, 0x1f0901ee,   // yo.tl.ga_654 yo.es.it_665  ceb.da.un_320 en.pl.cy_422
  0x4a5529a9, 0x1a5228ec, 0x0421120c, 0x2100520c,   // sl.rw.yo_544 sw.ha.tl_644  hu.jw.fi_543 ha.jw.un_530
  // [6e00]
  0x202d04a7, 0x18002b05, 0x29000704, 0x1f4a270c,   // fi.sk.sq_532 vi.ga.un_330  it.sl.un_320 gd.yo.cy_543
  0x3f0106ee, 0x3f1a08a0, 0x52071c07, 0x522d03a9,   // de.en.af_422 no.tl.af_322  id.it.ha_432 nl.sk.ha_544
  0x12006b0d, 0x0e076407, 0x55005333, 0x0f523bad,   // ceb.hu.un_540 lg.it.is_432  ht.rw.un_A70 so.ha.lv_643
  0x2b006e13, 0x1b281c07, 0x096b2007, 0x1a6b0404,   // hmn.vi.un_650 id.sw.tr_432  sq.ceb.pl_432 fi.ceb.tl_332
  // [6e10]
  0x35286812, 0x25000613, 0x161335ee, 0x06082505,   // ig.sw.zu_654 de.eu.un_650  zu.et.hr_422 eu.no.de_333
  0x274a110d, 0x0600012b, 0x1e051ca0, 0x1623290c,   // ro.yo.gd_554 en.de.un_980  id.fr.ms_322 sl.ca.hr_543
  0x532b2dec, 0x64554aec, 0x18060111, 0x4a1601ec,   // sk.vi.ht_644 yo.rw.lg_644  en.de.ga_653 en.hr.yo_644
  0x211e3107, 0x6b211a08, 0x12000a0d, 0x042a070c,   // az.ms.jw_432 tl.jw.ceb_443  pt.hu.un_540 it.mt.fi_543
  // [6e20]
  0x19020ba4, 0x092321a4, 0x0a1223a0, 0x0a0901a0,   // es.da.gl_433 jw.ca.pl_433  ca.hu.pt_322 en.pl.pt_322
  0x21012007, 0x09002113, 0x272a2009, 0x06211ea4,   // sq.en.jw_432 jw.pl.un_650  sq.mt.gd_444 ms.jw.de_433
  0x1c101e0c, 0x2000230e, 0x2968100c, 0x1e1c2160,   // ms.lt.id_543 ca.sq.un_550  lt.ig.sl_543 jw.id.ms_664
  0x0a2a2104, 0x1e001312, 0x6400100c, 0x1c0e1e13,   // jw.mt.pt_332 et.ms.un_640  lt.lg.un_530 ms.is.id_665
  // [6e30]
  0x55642155, 0x0f001e08, 0x1e213f07, 0x110b68ad,   // jw.lg.rw_442 ms.lv.un_430  af.jw.ms_432 ig.es.ro_643
  0x532052a6, 0x256b1a12, 0x06002d0e, 0x033f0e11,   // ha.sq.ht_521 tl.ceb.eu_654  sk.de.un_550 is.af.nl_653
  0x23000a09, 0x551b25ec, 0x033f64ec, 0x04000a19,   // pt.ca.un_440 eu.tr.rw_644  lg.af.nl_644 mk.ru.un_750
  0x181f270d, 0x28644a04, 0x64251304, 0x29312504,   // gd.cy.ga_554 yo.lg.sw_332  et.eu.lg_332 eu.az.sl_332
  // [6e40]
  0x192a070c, 0x6b3518a6, 0x0a002d12, 0x18120404,   // it.mt.gl_543 ga.zu.ceb_521  sk.pt.un_640 fi.hu.ga_332
  0x04200e12, 0x6400680e, 0x21006419, 0x131b2907,   // is.sq.fi_654 ig.lg.un_550  lg.jw.un_750 sl.tr.et_432
  0x190a0da4, 0x12000a09, 0x0a0b1907, 0x07130404,   // cs.pt.gl_433 pt.hu.un_440  gl.es.pt_432 fi.et.it_332
  0x1f000109, 0x351f5308, 0x0e000218, 0x551c20ad,   // en.cy.un_440 ht.cy.zu_443  da.is.un_740 sq.id.rw_643
  // [6e50]
  0x2100180c, 0x12172904, 0x0a0708a0, 0x1300120e,   // ar.fa.un_530 sl.sr.hu_332  uk.bg.mk_322 hu.et.un_550
  0x0a1708ad, 0x09001322, 0x321711a0, 0x290c3f04,   // uk.sr.mk_643 bh.hi.un_870  ro.sr.bs_322 af.sv.sl_332
  0x2b6b01a0, 0x3b130407, 0x3b136b08, 0x3f3101ee,   // en.ceb.vi_322 fi.et.so_432  ceb.et.so_443 en.az.af_422
  0x04006b02, 0x21002008, 0x202129a9, 0x04003b11,   // ceb.fi.un_220 sq.jw.un_430  sl.jw.sq_544 so.fi.un_630
  // [6e60]
  0x64211eee, 0x18042708, 0x051c04a4, 0x1a1827a4,   // ms.jw.lg_422 gd.fi.ga_443  fi.id.fr_433 gd.ga.tl_433
  0x1727180c, 0x25041a0c, 0x0c11010c, 0x1704130c,   // ga.gd.sr_543 tl.fi.eu_543  en.ro.sv_543 et.fi.sr_543
  0x4a281fa4, 0x10252713, 0x03213faf, 0x08000308,   // cy.sw.yo_433 gd.eu.lt_665  af.jw.nl_655 nl.no.un_430
  0x1110530d, 0x0c001e08, 0x19051113, 0x3b061fa0,   // ht.lt.ro_554 ms.sv.un_430  ro.fr.gl_665 cy.de.so_322
  // [6e70]
  0x230a01a4, 0x282d0d08, 0x27002d05, 0x01040512,   // en.pt.ca_433 cs.sk.sw_443  sk.gd.un_330 fr.fi.en_654
  0x351b0804, 0x2505010c, 0x1b080c07, 0x3b0203ad,   // no.tr.zu_332 en.fr.eu_543  sv.no.tr_432 nl.da.so_643
  0x030d02ee, 0x253104ac, 0x170208ad, 0x3b006405,   // da.cs.nl_422 fi.az.eu_632  no.da.sr_643 lg.so.un_330
  0x04100aa0, 0x10130805, 0x080225af, 0x1e000d02,   // mk.be.ru_322 no.et.lt_333  eu.da.no_655 cs.ms.un_220
  // [6e80]
  0x0c17120c, 0x0d001813, 0x0d000c04, 0x11001b11,   // hu.sr.sv_543 ga.cs.un_650  sv.cs.un_320 tr.ro.un_630
  0x020c13ac, 0x25001105, 0x0b112508, 0x082a0e07,   // et.sv.da_632 ro.eu.un_330  eu.ro.es_443 is.mt.no_432
  0x08000a0e, 0x081710a7, 0x25002912, 0x040725a0,   // mk.uk.un_550 be.sr.uk_532  sl.eu.un_640 eu.it.fi_322
  0x25001123, 0x286409a4, 0x28200b02, 0x083225ee,   // ro.eu.un_880 pl.lg.sw_433  es.sq.sw_222 eu.bs.no_422
  // [6e90]
  0x17110407, 0x16023207, 0x28003502, 0x05000411,   // ru.ro.sr_432 bs.da.hr_432  zu.sw.un_220 fi.fr.un_630
  0x4a001c04, 0x23001004, 0x0209080c, 0x09006808,   // id.yo.un_320 lt.ca.un_320  no.pl.da_543 ig.pl.un_430
  0x530a05a0, 0x311c2104, 0x29205309, 0x0c2d0907,   // fr.pt.ht_322 jw.id.az_332  ht.sq.sl_444 pl.sk.sv_432
  0x281c21a6, 0x2a092d0c, 0x135210a7, 0x09002d22,   // jw.id.sw_521 sk.pl.mt_543  lt.ha.et_532 sk.pl.un_870
  // [6ea0]
  0x20002d13, 0x291609a4, 0x2d001e13, 0x202d0d0c,   // sk.sq.un_650 pl.hr.sl_433  ms.sk.un_650 cs.sk.sq_543
  0x1b102aad, 0x03060811, 0x18000604, 0x211c640c,   // mt.lt.tr_643 no.de.nl_653  de.ga.un_320 lg.id.jw_543
  0x292d0914, 0x29251b07, 0x100a04af, 0x12005308,   // pl.sk.sl_666 tr.eu.sl_432  ru.mk.be_655 ht.hu.un_430
  0x0b001007, 0x06001f18, 0x13001014, 0x190a5202,   // lt.es.un_420 cy.de.un_740  lt.et.un_660 ha.pt.gl_222
  // [6eb0]
  0x1629090c, 0x17040812, 0x1c06020b, 0x02002d21,   // pl.sl.hr_543 uk.ru.sr_654  da.de.id_542 sk.da.un_860
  0x0e0b0802, 0x53002a04, 0x28643511, 0x6e001e13,   // no.es.is_222 mt.ht.un_320  zu.lg.sw_653 ms.hmn.un_650
  0x645535ad, 0x2a3528a4, 0x35520f0c, 0x13003b33,   // zu.rw.lg_643 sw.zu.mt_433  lv.ha.zu_543 so.et.un_A70
  0x10041112, 0x1a643b0c, 0x130f280c, 0x04030604,   // ro.ru.be_654 so.lg.tl_543  sw.lv.et_543 de.nl.fi_332
  // [6ec0]
  0x2d001b0c, 0x230619a0, 0x100f0a08, 0x2d0d18ba,   // tr.sk.un_530 gl.de.ca_322  pt.lv.lt_443 ga.cs.sk_843
  0x0468030c, 0x1c001e1a, 0x03643b11, 0x31550fa4,   // nl.ig.fi_543 ms.id.un_760  so.lg.nl_653 lv.rw.az_433
  0x101b215a, 0x64003b0e, 0x060701ad, 0x133b6411,   // jw.tr.lt_553 so.lg.un_550  en.it.de_643 lg.so.et_653
  0x6e2d2b0c, 0x64003509, 0x0a0d18b3, 0x6e000104,   // vi.sk.hmn_543 zu.lg.un_440  ga.cs.pt_743 en.hmn.un_320
  // [6ed0]
  0x29003202, 0x07084a0c, 0x1c1a5207, 0x040d09a6,   // bs.sl.un_220 yo.no.it_543  ha.tl.id_432 pl.cs.fi_521
  0x64003b20, 0x210f2504, 0x0100062c, 0x0f0b0a04,   // so.lg.un_850 eu.lv.jw_332  de.en.un_990 pt.es.lv_332
  0x131b0407, 0x2a1c1eee, 0x026e27a0, 0x1a3f030c,   // fi.tr.et_432 ms.id.mt_422  gd.hmn.da_322 nl.af.tl_543
  0x0f1a6bee, 0x00001f42, 0x044a350c, 0x080d2905,   // ceb.tl.lv_422 cy.un.un_C00  zu.yo.fi_543 sl.cs.no_333
  // [6ee0]
  0x06000908, 0x07060105, 0x0c000f05, 0x050408a0,   // pl.de.un_430 en.de.it_333  lv.sv.un_330 no.fi.fr_322
  0x070c3bee, 0x213b310b, 0x1e1a3f02, 0x080f0505,   // so.sv.it_422 az.so.jw_542  af.tl.ms_222 fr.lv.no_333
  0x212010a4, 0x20006e07, 0x4a000702, 0x011a0502,   // lt.sq.jw_433 hmn.sq.un_420  it.yo.un_220 fr.tl.en_222
  0x1a005519, 0x12000d11, 0x19002318, 0x09130d08,   // rw.tl.un_750 cs.hu.un_630  ca.gl.un_740 ne.bh.hi_443
  // [6ef0]
  0x28351e11, 0x0d311fa4, 0x1f001322, 0x1a036b09,   // ms.zu.sw_653 cy.az.cs_433  et.cy.un_870 ceb.nl.tl_444
  0x0d001a09, 0x2a136e12, 0x21002a02, 0x3b0a1907,   // tl.cs.un_440 hmn.et.mt_654  mt.jw.un_220 gl.pt.so_432
  0x1b071ca0, 0x3f1b31a0, 0x010208a7, 0x0a122dee,   // id.it.tr_322 az.tr.af_322  no.da.en_532 sk.hu.pt_422
  0x050802a0, 0x0806020d, 0x2b000607, 0x11003b17,   // da.no.fr_322 da.de.no_554  de.vi.un_420 so.ro.un_730
  // [6f00]
  0x53320504, 0x1b001104, 0x6e2a1faf, 0x0c000f1a,   // fr.bs.ht_332 ro.tr.un_320  cy.mt.hmn_655 lv.sv.un_760
  0x132a0207, 0x1f132a0c, 0x0d0306a4, 0x0c0625a4,   // da.mt.et_432 mt.et.cy_543  de.nl.cs_433 eu.de.sv_433
  0x12004a12, 0x3f00071a, 0x0c0806ee, 0x07000208,   // yo.hu.un_640 it.af.un_760  de.no.sv_422 da.it.un_430
  0x1e080208, 0x13001121, 0x07004a04, 0x35000c12,   // da.no.ms_443 ro.et.un_860  yo.it.un_320 sv.zu.un_640
  // [6f10]
  0x20321702, 0x06123507, 0x1a6e5204, 0x21000802,   // sr.bs.sq_222 zu.hu.de_432  ha.hmn.tl_332 no.jw.un_220
  0x3b3f02a4, 0x0f002d14, 0x050607ec, 0x4a00530d,   // da.af.so_433 sk.lv.un_660  it.de.fr_644 ht.yo.un_540
  0x2b1f200b, 0x2a12530c, 0x6b1e20ee, 0x3b001b13,   // sq.cy.vi_542 ht.hu.mt_543  sq.ms.ceb_422 tr.so.un_650
  0x033f29a4, 0x31531208, 0x3f4a530c, 0x311b6b0c,   // sl.af.nl_433 hu.ht.az_443  ht.yo.af_543 ceb.tr.az_543
  // [6f20]
  0x04131aa0, 0x1b3b6ba0, 0x01033f04, 0x53210f0c,   // tl.et.fi_322 ceb.so.tr_322  af.nl.en_332 lv.jw.ht_543
  0x2b1123ec, 0x11000113, 0x11685307, 0x3b002822,   // ca.ro.vi_644 en.ro.un_650  ht.ig.ro_432 sw.so.un_870
  0x09321655, 0x3b1b6bad, 0x12001119, 0x29050aa0,   // hr.bs.pl_442 ceb.tr.so_643  ro.hu.un_750 pt.fr.sl_322
  0x1b531ea0, 0x1f19115a, 0x1f2d53a7, 0x1b002821,   // ms.ht.tr_322 ro.gl.cy_553  ht.sk.cy_532 sw.tr.un_860
  // [6f30]
  0x13006b22, 0x0d532d0c, 0x1e000205, 0x1b356404,   // ceb.et.un_870 sk.ht.cs_543  da.ms.un_330 lg.zu.tr_332
  0x2b00531b, 0x20190b0d, 0x2b31530c, 0x1c00010d,   // ht.vi.un_770 es.gl.sq_554  ht.az.vi_543 en.id.un_540
  0x640f02a0, 0x3b316bee, 0x0f002109, 0x2b006e0c,   // da.lv.lg_322 ceb.az.so_422  jw.lv.un_440 hmn.vi.un_530
  0x10000504, 0x25001007, 0x02006b08, 0x29006e09,   // fr.lt.un_320 lt.eu.un_420  ceb.da.un_430 hmn.sl.un_440
  // [6f40]
  0x170a110e, 0x0f6e060b, 0x04351e07, 0x10170a0b,   // ro.mk.sr_555 de.hmn.lv_542  ms.zu.fi_432 mk.sr.be_542
  0x6e2135ec, 0x21000609, 0x08000402, 0x12051ba4,   // zu.jw.hmn_644 de.jw.un_440  ru.uk.un_220 tr.fr.hu_433
  0x1a6e6b0c, 0x112505ad, 0x190b3502, 0x290525ad,   // ceb.hmn.tl_543 fr.eu.ro_643  zu.es.gl_222 eu.fr.sl_643
  0x1c061eee, 0x2502130b, 0x1220250c, 0x200b11a0,   // ms.de.id_422 et.da.eu_542  eu.sq.hu_543 ro.es.sq_322
  // [6f50]
  0x231105a7, 0x52006807, 0x12250560, 0x10002914,   // fr.ro.ca_532 ig.ha.un_420  fr.eu.hu_664 sl.lt.un_660
  0x210535ee, 0x20051b55, 0x25311b04, 0x09080da0,   // zu.fr.jw_422 tr.fr.sq_442  tr.az.eu_332 cs.no.pl_322
  0x1e1b250c, 0x6400200d, 0x1e1c29a0, 0x110525a4,   // eu.tr.ms_543 sq.lg.un_540  sl.id.ms_322 eu.fr.ro_433
  0x231f1e05, 0x1105255a, 0x23001108, 0x6b000304,   // ms.cy.ca_333 eu.fr.ro_553  ro.ca.un_430 nl.ceb.un_320
  // [6f60]
  0x04003f09, 0x0d002905, 0x16002704, 0x07000420,   // af.fi.un_440 sl.cs.un_330  gd.hr.un_320 fi.it.un_850
  0x1e1c250c, 0x2004250c, 0x1e036ba0, 0x3200171a,   // eu.id.ms_543 eu.fi.sq_543  ceb.nl.ms_322 sr.bs.un_760
  0x64000f04, 0x0c003507, 0x1a4a6bec, 0x1e311b08,   // lv.lg.un_320 zu.sv.un_420  ceb.yo.tl_644 tr.az.ms_443
  0x0e3b64ec, 0x250801a4, 0x190b01a9, 0x35286e07,   // lg.so.is_644 en.no.eu_433  en.es.gl_544 hmn.sw.zu_432
  // [6f70]
  0x11270107, 0x12002d0e, 0x3f031a0c, 0x0511010c,   // en.gd.ro_432 sk.hu.un_550  tl.nl.af_543 en.ro.fr_543
  0x0a081711, 0x062a0711, 0x202325ad, 0x12006e07,   // sr.uk.mk_653 it.mt.de_653  eu.ca.sq_643 hmn.hu.un_420
  0x07181108, 0x126403a0, 0x28193b04, 0x04002804,   // ro.ga.it_443 nl.lg.hu_322  so.gl.sw_332 sw.fi.un_320
  0x11080204, 0x201c21ee, 0x081302ec, 0x17290e04,   // da.no.ro_332 jw.id.sq_422  da.et.no_644 is.sl.sr_332
  // [6f80]
  0x0e122d04, 0x0e002308, 0x12006e0d, 0x3b005307,   // sk.hu.is_332 ca.is.un_430  hmn.hu.un_540 ht.so.un_420
  0x1a00551b, 0x08001c07, 0x3b00521b, 0x0f080c0c,   // rw.tl.un_770 id.no.un_420  ha.so.un_770 sv.no.lv_543
  0x1c6b4aee, 0x06056e02, 0x2b004a12, 0x136e1aad,   // yo.ceb.id_422 hmn.fr.de_222  yo.vi.un_640 tl.hmn.et_643
  0x0c1e0211, 0x21351fa0, 0x086b1a55, 0x13013ba7,   // da.ms.sv_653 cy.zu.jw_322  tl.ceb.no_442 so.en.et_532
  // [6f90]
  0x1f092d04, 0x0a001809, 0x0e00081b, 0x3b006e20,   // sk.pl.cy_332 ga.pt.un_440  no.is.un_770 hmn.so.un_850
  0x2b1a52a0, 0x0f130460, 0x0802060e, 0x522a68af,   // ha.tl.vi_322 fi.et.lv_664  de.da.no_555 ig.mt.ha_655
  0x3f080b0c, 0x3f522a05, 0x0506010d, 0x110b1b08,   // es.no.af_543 mt.ha.af_333  en.de.fr_554 tr.es.ro_443
  0x3f0c080d, 0x1a0328a9, 0x203b31ad, 0x0b0208ac,   // no.sv.af_554 sw.nl.tl_544  az.so.sq_643 no.da.es_632
  // [6fa0]
  0x6e001313, 0x644a5212, 0x062b11ec, 0x090d1fad,   // et.hmn.un_650 ha.yo.lg_654  ro.vi.de_644 cy.cs.pl_643
  0x251811af, 0x32201b08, 0x29000f0d, 0x4a072313,   // ro.ga.eu_655 tr.sq.bs_443  lv.sl.un_540 ca.it.yo_665
  0x29526812, 0x092d06ec, 0x25211ca0, 0x05000713,   // ig.ha.sl_654 de.sk.pl_644  id.jw.eu_322 it.fr.un_650
  0x685228af, 0x05001802, 0x6e00190d, 0x13521ca0,   // sw.ha.ig_655 ga.fr.un_220  gl.hmn.un_540 id.ha.et_322
  // [6fb0]
  0x1a006b34, 0x0a00131a, 0x120a0d07, 0x00000c37,   // ceb.tl.un_A80 et.pt.un_760  cs.pt.hu_432 sv.un.un_B00
  0x2005010c, 0x010c230c, 0x52256b12, 0x282768ee,   // en.fr.sq_543 ca.sv.en_543  ceb.eu.ha_654 ig.gd.sw_422
  0x4a6b2b0d, 0x531a6b12, 0x1f3f01af, 0x0a556bad,   // vi.ceb.yo_554 ceb.tl.ht_654  en.af.cy_655 ceb.rw.pt_643
  0x023f060c, 0x131c21ee, 0x53112360, 0x0c033fa9,   // de.af.da_543 jw.id.et_422  ca.ro.ht_664 af.nl.sv_544
  // [6fc0]
  0x554a2812, 0x52002a36, 0x354a6408, 0x53071b04,   // sw.yo.rw_654 mt.ha.un_AA0  lg.yo.zu_443 tr.it.ht_332
  0x033f29af, 0x1e315208, 0x20033fa9, 0x35001f18,   // sl.af.nl_655 ha.az.ms_443  af.nl.sq_544 cy.zu.un_740
  0x18030f08, 0x17291607, 0x28311b0d, 0x012706a0,   // lv.nl.ga_443 hr.sl.sr_432  tr.az.sw_554 de.gd.en_322
  0x05000722, 0x046b1a12, 0x6b312155, 0x0c1f1c02,   // it.fr.un_870 tl.ceb.fi_654  jw.az.ceb_442 id.cy.sv_222
  // [6fd0]
  0x0f190b11, 0x1304310c, 0x2800212a, 0x21552807,   // es.gl.lv_653 az.fi.et_543  jw.sw.un_970 sw.rw.jw_432
  0x281a6b08, 0x201a1ea0, 0x64013fa0, 0x0d0208ee,   // ceb.tl.sw_443 ms.tl.sq_322  af.en.lg_322 no.da.cs_422
  0x03251bee, 0x211b5507, 0x1a3521ee, 0x0e00020e,   // tr.eu.nl_422 rw.tr.jw_432  jw.zu.tl_422 da.is.un_550
  0x25211ea0, 0x2a00640b, 0x013f6ba4, 0x10130107,   // ms.jw.eu_322 lg.mt.un_520  ceb.af.en_433 en.et.lt_432
  // [6fe0]
  0x0d04070c, 0x0c000708, 0x17292d02, 0x12350404,   // it.fi.cs_543 it.sv.un_430  sk.sl.sr_222 fi.zu.hu_332
  0x2d002911, 0x552125a4, 0x25031bee, 0x1c295355,   // sl.sk.un_630 eu.jw.rw_433  tr.nl.eu_422 ht.sl.id_442
  0x120f100b, 0x130f0107, 0x10003f0c, 0x18000c07,   // lt.lv.hu_542 en.lv.et_432  af.lt.un_530 sv.ga.un_420
  0x13000c05, 0x52040360, 0x3f0e0c02, 0x64041ea4,   // sv.et.un_330 nl.fi.ha_664  sv.is.af_222 ms.fi.lg_433
  // [6ff0]
  0x1b1204a4, 0x55281b13, 0x0c3f25a7, 0x6404520c,   // fi.hu.tr_433 tr.sw.rw_665  eu.af.sv_532 ha.fi.lg_543
  0x52001b1a, 0x3b182502, 0x040a1002, 0x526b1a0c,   // tr.ha.un_760 eu.ga.so_222  be.mk.ru_222 tl.ceb.ha_543
  0x0d006404, 0x55521b12, 0x1b3b52a7, 0x3b521b5a,   // lg.cs.un_320 tr.ha.rw_654  ha.so.tr_532 tr.ha.so_553
  0x1f002b04, 0x08026405, 0x551b5204, 0x53212bad,   // vi.cy.un_320 lg.da.no_333  ha.tr.rw_332 vi.jw.ht_643

  // [7000]
  0x27071fa6, 0x20000e04, 0x12641e04, 0x4a001f08,   // cy.it.gd_521 is.sq.un_320  ms.lg.hu_332 cy.yo.un_430
  0x12042aee, 0x551b35a4, 0x1c641ea4, 0x6e2b2807,   // mt.fi.hu_422 zu.tr.rw_433  ms.lg.id_433 sw.vi.hmn_432
  0x050a2b0b, 0x53000121, 0x27181f0c, 0x213b1b0c,   // vi.pt.fr_542 en.ht.un_860  cy.ga.gd_543 tr.so.jw_543
  0x35281ba4, 0x130604ec, 0x6b01180e, 0x01000e07,   // tr.sw.zu_433 fi.de.et_644  ga.en.ceb_555 is.en.un_420
  // [7010]
  0x130e0407, 0x040e0807, 0x0c060e04, 0x1b1025a0,   // fi.is.et_432 no.is.fi_432  is.de.sv_332 eu.lt.tr_322
  0x11070405, 0x2500530c, 0x1a006b29, 0x311b5212,   // ru.bg.ro_333 ht.eu.un_530  ceb.tl.un_960 ha.tr.az_654
  0x3b004a1a, 0x3b006b0e, 0x1a6b64ee, 0x0e00102a,   // yo.so.un_760 ceb.so.un_550  lg.ceb.tl_422 lt.is.un_970
  0x01003507, 0x4a1327ee, 0x3b006418, 0x0e0f105a,   // zu.en.un_420 gd.et.yo_422  lg.so.un_740 lt.lv.is_553
  // [7020]
  0x1213170c, 0x21083fee, 0x07000f07, 0x08033fa7,   // sr.et.hu_543 af.no.jw_422  lv.it.un_420 af.nl.no_532
  0x522b11a0, 0x070527a4, 0x686b01a0, 0x3f3b64a4,   // ro.vi.ha_322 gd.fr.it_433  en.ceb.ig_322 lg.so.af_433
  0x641a6b07, 0x110a070e, 0x20232704, 0x23003104,   // ceb.tl.lg_432 bg.mk.ro_555  gd.ca.sq_332 az.ca.un_320
  0x01001e07, 0x04230702, 0x201216ee, 0x02162aa0,   // ms.en.un_420 it.ca.fi_222  hr.hu.sq_422 mt.hr.da_322
  // [7030]
  0x041007ee, 0x2d000f1a, 0x0400011b, 0x1b003f04,   // bg.be.ru_422 lv.sk.un_760  en.fi.un_770 af.tr.un_320
  0x12000e0b, 0x29000d0c, 0x190b05ec, 0x25120f04,   // is.hu.un_520 cs.sl.un_530  fr.es.gl_644 lv.hu.eu_332
  0x351a1e55, 0x21006808, 0x132123a0, 0x181912a9,   // ms.tl.zu_442 ig.jw.un_430  ca.jw.et_322 hu.gl.ga_544
  0x081827ad, 0x18201f07, 0x0d1918a4, 0x271820af,   // gd.ga.no_643 cy.sq.ga_432  ga.gl.cs_433 sq.ga.gd_655
  // [7040]
  0x4a002d08, 0x206e6ba0, 0x092718ee, 0x0d122d04,   // sk.yo.un_430 ceb.hmn.sq_322  ga.gd.pl_422 sk.hu.cs_332
  0x17534a04, 0x10093205, 0x0b255207, 0x0d1912ec,   // yo.ht.sr_332 bs.pl.lt_333  ha.eu.es_432 hu.gl.cs_644
  0x0b124a5a, 0x09100faf, 0x0b10280c, 0x09100fa7,   // yo.hu.es_553 lv.lt.pl_655  sw.lt.es_543 lv.lt.pl_532
  0x12000d21, 0x1820270c, 0x270907a0, 0x190b1209,   // cs.hu.un_860 gd.sq.ga_543  it.pl.gd_322 hu.es.gl_444
  // [7050]
  0x0420250c, 0x52103ba0, 0x190b2da4, 0x194a0b07,   // eu.sq.fi_543 so.lt.ha_322  sk.es.gl_433 es.yo.gl_432
  0x072718ee, 0x12184a13, 0x320720a7, 0x1200130c,   // ga.gd.it_422 yo.ga.hu_665  sq.it.bs_532 et.hu.un_530
  0x13001a34, 0x4a2a0d12, 0x162d2905, 0x18002805,   // tl.et.un_A80 cs.mt.yo_654  sl.sk.hr_333 sw.ga.un_330
  0x130a3ba4, 0x1f006e07, 0x255521af, 0x10003204,   // so.pt.et_433 hmn.cy.un_420  jw.rw.eu_655 bs.lt.un_320
  // [7060]
  0x19270aad, 0x0a0c27ad, 0x020601af, 0x6b1152a4,   // pt.gd.gl_643 gd.sv.pt_643  en.de.da_655 ha.ro.ceb_433
  0x2100280b, 0x0f000921, 0x0f005308, 0x2b001818,   // sw.jw.un_520 pl.lv.un_860  ht.lv.un_430 ga.vi.un_740
  0x31553555, 0x20001c02, 0x6b2818ad, 0x170f10a9,   // zu.rw.az_442 id.sq.un_220  ga.sw.ceb_643 lt.lv.sr_544
  0x171632a7, 0x292d0f07, 0x05002802, 0x0500520c,   // bs.hr.sr_532 lv.sk.sl_432  sw.fr.un_220 ha.fr.un_530
  // [7070]
  0x3500682b, 0x35005211, 0x171008a7, 0x1b005211,   // ig.zu.un_980 ha.zu.un_630  uk.be.sr_532 ha.tr.un_630
  0x52001e02, 0x3f2135a0, 0x131e1c55, 0x281a01a7,   // ms.ha.un_220 zu.jw.af_322  id.ms.et_442 en.tl.sw_532
  0x4a0d2da9, 0x6b531aa9, 0x3b250ca4, 0x281e5207,   // sk.cs.yo_544 tl.ht.ceb_544  sv.eu.so_433 ha.ms.sw_432
  0x53000d22, 0x17070811, 0x04005309, 0x0e081f04,   // cs.ht.un_870 uk.bg.sr_653  ht.fi.un_440 cy.no.is_332
  // [7080]
  0x0d00050e, 0x52311bad, 0x0a002507, 0x0c001e02,   // fr.cs.un_550 tr.az.ha_643  eu.pt.un_420 ms.sv.un_220
  0x11003108, 0x010705a0, 0x0608250b, 0x1c2b6ba0,   // az.ro.un_430 fr.it.en_322  eu.no.de_542 ceb.vi.id_322
  0x06000c02, 0x0a001718, 0x322d6ea0, 0x190b120e,   // sv.de.un_220 sr.mk.un_740  hmn.sk.bs_322 hu.es.gl_555
  0x53050daf, 0x53050a0e, 0x19122104, 0x036b1a04,   // cs.fr.ht_655 pt.fr.ht_555  jw.hu.gl_332 tl.ceb.nl_332
  // [7090]
  0x53000d20, 0x2d09290c, 0x08093f07, 0x061304a7,   // cs.ht.un_850 sl.pl.sk_543  af.pl.no_432 fi.et.de_532
  0x28255507, 0x08001105, 0x1a253512, 0x25190ba0,   // rw.eu.sw_432 ro.uk.un_330  zu.eu.tl_654 es.gl.eu_322
  0x351b04af, 0x1000250d, 0x550635a0, 0x3b1f1ba7,   // fi.tr.zu_655 eu.lt.un_540  zu.de.rw_322 tr.cy.so_532
  0x25554a09, 0x201f6807, 0x25104aee, 0x06296e13,   // yo.rw.eu_444 ig.cy.sq_432  yo.lt.eu_422 hmn.sl.de_665
  // [70a0]
  0x25004a14, 0x28001b1b, 0x1b4a53a4, 0x09321605,   // yo.eu.un_660 tr.sw.un_770  ht.yo.tr_433 hr.bs.pl_333
  0x170a08ec, 0x5306640d, 0x12001909, 0x3f060f07,   // uk.mk.sr_644 lg.de.ht_554  gl.hu.un_440 lv.de.af_432
  0x04020807, 0x05060104, 0x03250605, 0x35001b12,   // no.da.fi_432 en.de.fr_332  de.eu.nl_333 tr.zu.un_640
  0x19350a60, 0x3200110c, 0x0700232a, 0x2d00060e,   // pt.zu.gl_664 ro.bs.un_530  ca.it.un_970 de.sk.un_550
  // [70b0]
  0x016b1aad, 0x1c1e21a7, 0x28002512, 0x1b000913,   // tl.ceb.en_643 jw.ms.id_532  eu.sw.un_640 pl.tr.un_650
  0x100613a0, 0x32292dad, 0x01063507, 0x133f0e07,   // et.de.lt_322 sk.sl.bs_643  zu.de.en_432 is.af.et_432
  0x081b1faf, 0x0e0302a4, 0x130108a4, 0x3216110c,   // cy.tr.no_655 da.nl.is_433  no.en.et_433 ro.hr.bs_543
  0x23006e21, 0x1a003f14, 0x050420ee, 0x53011aa0,   // hmn.ca.un_860 af.tl.un_660  sq.fi.fr_422 tl.en.ht_322
  // [70c0]
  0x3b023faf, 0x1100180d, 0x1e0d1cad, 0x2b001219,   // af.da.so_655 ga.ro.un_540  id.cs.ms_643 hu.vi.un_750
  0x11000813, 0x281c1eee, 0x283b1b08, 0x2b00120d,   // uk.ro.un_650 ms.id.sw_422  tr.so.sw_443 hu.vi.un_540
  0x07273ba7, 0x08113f60, 0x3f000221, 0x0c0e0207,   // so.gd.it_532 af.ro.no_664  da.af.un_860 da.is.sv_432
  0x11001f1a, 0x3f021107, 0x0211130c, 0x3f000c0d,   // cy.ro.un_760 ro.da.af_432  et.ro.da_543 sv.af.un_540
  // [70d0]
  0x0a00072a, 0x06003509, 0x201b6b0c, 0x13090d0d,   // bg.mk.un_970 zu.de.un_440  ceb.tr.sq_543 ne.hi.bh_554
  0x096b28a4, 0x2909320d, 0x0e001b08, 0x1a042807,   // sw.ceb.pl_433 bs.pl.sl_554  tr.is.un_430 sw.fi.tl_432
  0x03000509, 0x09213fa0, 0x211a1cee, 0x061c21a7,   // fr.nl.un_440 af.jw.pl_322  id.tl.jw_422 jw.id.de_532
  0x28001b13, 0x060c3fa0, 0x1c1309ac, 0x1a6b2113,   // tr.sw.un_650 af.sv.de_322  hi.bh.mr_632 jw.ceb.tl_665
  // [70e0]
  0x20001a07, 0x645335a0, 0x1c0228ee, 0x171329a4,   // tl.sq.un_420 zu.ht.lg_322  sw.da.id_422 sl.et.sr_433
  0x251104ec, 0x25000708, 0x1c1e2108, 0x11001b0e,   // fi.ro.eu_644 it.eu.un_430  jw.ms.id_443 tr.ro.un_550
  0x08021e09, 0x18536b07, 0x1b002021, 0x0d072807,   // ms.da.no_444 ceb.ht.ga_432  sq.tr.un_860 sw.it.cs_432
  0x35556404, 0x2b004a2a, 0x09640708, 0x08021cee,   // lg.rw.zu_332 yo.vi.un_970  it.lg.pl_443 id.da.no_422
  // [70f0]
  0x2b004a11, 0x28121ea0, 0x1107350c, 0x0e311b08,   // yo.vi.un_630 ms.hu.sw_322  zu.it.ro_543 tr.az.is_443
  0x2b074a12, 0x07002821, 0x16003507, 0x6e000708,   // yo.it.vi_654 sw.it.un_860  zu.hr.un_420 it.hmn.un_430
  0x0a232104, 0x2d120d09, 0x2a350707, 0x072b4a12,   // jw.ca.pt_332 cs.hu.sk_444  it.zu.mt_432 yo.vi.it_654
  0x033564af, 0x17100a0e, 0x53001e08, 0x0625350c,   // lg.zu.nl_655 mk.be.sr_555  ms.ht.un_430 zu.eu.de_543
  // [7100]
  0x21000108, 0x1b003135, 0x071b20a4, 0x1c2164ee,   // en.jw.un_430 az.tr.un_A90  sq.tr.it_433 lg.jw.id_422
  0x04001c08, 0x04112505, 0x0d354a07, 0x6b09350d,   // id.fi.un_430 eu.ro.fi_333  yo.zu.cs_432 zu.pl.ceb_554
  0x4a1c2512, 0x082511a7, 0x282035ee, 0x28354aec,   // eu.id.yo_654 ro.eu.no_532  zu.sq.sw_422 yo.zu.sw_644
  0x13020ea4, 0x1b5311ee, 0x350368a0, 0x32120755,   // is.da.et_433 ro.ht.tr_422  ig.nl.zu_322 it.hu.bs_442
  // [7110]
  0x3b0f1ea4, 0x2025555a, 0x162d21a9, 0x12130412,   // ms.lv.so_433 rw.eu.sq_553  jw.sk.hr_544 fi.et.hu_654
  0x110625a7, 0x07640507, 0x1a00550e, 0x0b0a2109,   // eu.de.ro_532 fr.lg.it_432  rw.tl.un_550 jw.pt.es_444
  0x55002114, 0x133f030b, 0x100a0407, 0x110607ec,   // jw.rw.un_660 nl.af.et_542  ru.mk.be_432 it.de.ro_644
  0x062a01a4, 0x0400112b, 0x0e3f2aee, 0x0c000223,   // en.mt.de_433 ro.ru.un_980  mt.af.is_422 da.sv.un_880
  // [7120]
  0x1c1e5508, 0x292a07ad, 0x08202107, 0x29521ea4,   // rw.ms.id_443 it.mt.sl_643  jw.sq.no_432 ms.ha.sl_433
  0x062d0d13, 0x110b25a0, 0x2d0d1805, 0x3555680c,   // cs.sk.de_665 eu.es.ro_322  ga.cs.sk_333 ig.rw.zu_543
  0x06020c0c, 0x52004a07, 0x350928ee, 0x32171ca4,   // sv.da.de_543 yo.ha.un_420  sw.pl.zu_422 id.sr.bs_433
  0x21120d09, 0x0c031304, 0x321628a4, 0x1b00681b,   // cs.hu.jw_444 et.nl.sv_332  sw.hr.bs_433 ig.tr.un_770
  // [7130]
  0x35006804, 0x0000072d, 0x112d0d0c, 0x0f5504a7,   // ig.zu.un_320 it.un.un_A00  cs.sk.ro_543 fi.rw.lv_532
  0x051a1307, 0x35552804, 0x0d001908, 0x08000d07,   // et.tl.fr_432 sw.rw.zu_332  gl.cs.un_430 cs.no.un_420
  0x2a071e12, 0x020c0660, 0x02000c1a, 0x0c000214,   // ms.it.mt_654 de.sv.da_664  sv.da.un_760 da.sv.un_660
  0x68002512, 0x2b18270c, 0x1c001804, 0x272a68ee,   // eu.ig.un_640 gd.ga.vi_543  ga.id.un_320 ig.mt.gd_422
  // [7140]
  0x29002305, 0x132a0e0e, 0x1100230d, 0x100f1307,   // ca.sl.un_330 is.mt.et_555  ca.ro.un_540 et.lv.lt_432
  0x2d001308, 0x32173fa0, 0x20033fad, 0x1c2113a6,   // et.sk.un_430 af.sr.bs_322  af.nl.sq_643 et.jw.id_521
  0x31000a0e, 0x1b006b08, 0x08100a08, 0x290f2dad,   // pt.az.un_550 ceb.tr.un_430  mk.be.uk_443 sk.lv.sl_643
  0x091b31a4, 0x11295305, 0x20092911, 0x2a000509,   // az.tr.pl_433 ht.sl.ro_333  sl.pl.sq_653 fr.mt.un_440
  // [7150]
  0x13000935, 0x1253200d, 0x352a23a7, 0x1b005504,   // hi.bh.un_A90 sq.ht.hu_554  ca.mt.zu_532 rw.tr.un_320
  0x27681804, 0x1b000d0d, 0x3f111307, 0x09292d11,   // ga.ig.gd_332 cs.tr.un_540  et.ro.af_432 sk.sl.pl_653
  0x6e3153a7, 0x0b000c05, 0x1b005505, 0x17005308,   // ht.az.hmn_532 sv.es.un_330  rw.tr.un_330 ht.sr.un_430
  0x322817a4, 0x18131aa0, 0x2a1e1c13, 0x3f130307,   // sr.sw.bs_433 tl.et.ga_322  id.ms.mt_665 nl.et.af_432
  // [7160]
  0x531629a9, 0x01232b08, 0x20012a05, 0x643521a6,   // sl.hr.ht_544 vi.ca.en_443  mt.en.sq_333 jw.zu.lg_521
  0x4a001205, 0x3f000208, 0x53001005, 0x020c11a4,   // hu.yo.un_330 da.af.un_430  lt.ht.un_330 ro.sv.da_433
  0x2a356855, 0x20523b07, 0x1f00211a, 0x08021ea0,   // ig.zu.mt_442 so.ha.sq_432  jw.cy.un_760 ms.da.no_322
  0x18004a05, 0x11006822, 0x211a68a4, 0x20061b07,   // yo.ga.un_330 ig.ro.un_870  ig.tl.jw_433 tr.de.sq_432
  // [7170]
  0x0a211ca0, 0x25190c07, 0x53011109, 0x01643f0c,   // id.jw.pt_322 sv.gl.eu_432  ro.en.ht_444 af.lg.en_543
  0x2d0d1902, 0x202d0707, 0x4a190b09, 0x01000509,   // gl.cs.sk_222 it.sk.sq_432  es.gl.yo_444 fr.en.un_440
  0x11006823, 0x28006805, 0x01060509, 0x0500211a,   // ig.ro.un_880 ig.sw.un_330  fr.de.en_444 jw.fr.un_760
  0x23071ea4, 0x210e1ca0, 0x643f2812, 0x010c0204,   // ms.it.ca_433 id.is.jw_322  sw.af.lg_654 da.sv.en_332
  // [7180]
  0x642835a0, 0x1e1c21ac, 0x0c280f07, 0x0c00120d,   // zu.sw.lg_322 jw.id.ms_632  lv.sw.sv_432 hu.sv.un_540
  0x0e2d1260, 0x120d0aa4, 0x06002104, 0x030611a9,   // hu.sk.is_664 pt.cs.hu_433  jw.de.un_320 ro.de.nl_544
  0x1c0621a9, 0x096b53a7, 0x1f3553a0, 0x1a6b5313,   // jw.de.id_544 ht.ceb.pl_532  ht.zu.cy_322 ht.ceb.tl_665
  0x1a210604, 0x1e1c29a4, 0x171008af, 0x53352804,   // de.jw.tl_332 sl.id.ms_433  uk.be.sr_655 sw.zu.ht_332
  // [7190]
  0x1e1c13a0, 0x28160607, 0x3f6b0107, 0x09001f1b,   // et.id.ms_322 de.hr.sw_432  en.ceb.af_432 cy.pl.un_770
  0x0b005302, 0x2d000907, 0x4a002b0e, 0x04071060,   // ht.es.un_220 pl.sk.un_420  vi.yo.un_550 be.bg.ru_664
  0x033f2004, 0x211e1ca0, 0x5320110b, 0x11211c0c,   // sq.af.nl_332 id.ms.jw_322  ro.sq.ht_542 id.jw.ro_543
  0x200613ad, 0x06083fa4, 0x021220a7, 0x17110812,   // et.de.sq_643 af.no.de_433  sq.hu.da_532 uk.ro.sr_654
  // [71a0]
  0x06023fec, 0x130601a0, 0x17001614, 0x06002312,   // af.da.de_644 en.de.et_322  hr.sr.un_660 ca.de.un_640
  0x19210ba4, 0x1b003512, 0x322d0d02, 0x0e0c4a5a,   // es.jw.gl_433 zu.tr.un_640  cs.sk.bs_222 yo.sv.is_553
  0x0a101108, 0x0205080c, 0x230503ee, 0x032305ad,   // ro.be.mk_443 no.fr.da_543  nl.fr.ca_422 fr.ca.nl_643
  0x120c3fee, 0x130523a9, 0x0c0f230c, 0x08000418,   // af.sv.hu_422 ca.fr.et_544  ca.lv.sv_543 ru.uk.un_740
  // [71b0]
  0x0807175a, 0x133b1e07, 0x2800040b, 0x2b0125ee,   // sr.bg.uk_553 ms.so.et_432  fi.sw.un_520 eu.en.vi_422
  0x5331130c, 0x2d0d0a14, 0x10001723, 0x3b136e0c,   // et.az.ht_543 pt.cs.sk_666  sr.be.un_880 hmn.et.so_543
  0x5313020c, 0x1e1c13a4, 0x533b130c, 0x2a0e2355,   // da.et.ht_543 et.id.ms_433  et.so.ht_543 ca.is.mt_442
  0x080209ad, 0x3f0613ad, 0x172d290e, 0x5200200c,   // pl.da.no_643 et.de.af_643  sl.sk.sr_555 sq.ha.un_530
  // [71c0]
  0x1a005308, 0x13003121, 0x2100130d, 0x4a006b0c,   // ht.tl.un_430 az.et.un_860  et.jw.un_540 ceb.yo.un_530
  0x3b133108, 0x0e0c4aa0, 0x1e6e3ba0, 0x0106050e,   // az.et.so_443 yo.sv.is_322  so.hmn.ms_322 fr.de.en_555
  0x53355512, 0x1100040c, 0x02002907, 0x1c005302,   // rw.zu.ht_654 fi.ro.un_530  sl.da.un_420 ht.id.un_220
  0x0b0a23a4, 0x32191f08, 0x1a553512, 0x4a0c6bee,   // ca.pt.es_433 cy.gl.bs_443  zu.rw.tl_654 ceb.sv.yo_422
  // [71d0]
  0x6b681a08, 0x35031f0c, 0x20002307, 0x2d004a04,   // tl.ig.ceb_443 cy.nl.zu_543  ca.sq.un_420 yo.sk.un_320
  0x68081fec, 0x203555a0, 0x3b006e0d, 0x55001a04,   // cy.no.ig_644 rw.zu.sq_322  hmn.so.un_540 tl.rw.un_320
  0x04003107, 0x0a00180d, 0x3b001304, 0x0b001a04,   // az.fi.un_420 ga.pt.un_540  et.so.un_320 tl.es.un_320
  0x2a0c18a0, 0x0a1710ac, 0x04080c08, 0x4a136408,   // ga.sv.mt_322 be.sr.mk_632  sv.no.fi_443 lg.et.yo_443
  // [71e0]
  0x1f271812, 0x3b001305, 0x35190b04, 0x191a6b04,   // ga.gd.cy_654 et.so.un_330  es.gl.zu_332 ceb.tl.gl_332
  0x271b0fee, 0x103f0fac, 0x06190b0b, 0x282a01a4,   // lv.tr.gd_422 lv.af.lt_632  es.gl.de_542 en.mt.sw_433
  0x0f1801a4, 0x3f230f0c, 0x6e00641a, 0x6e003b19,   // en.ga.lv_433 lv.ca.af_543  lg.hmn.un_760 so.hmn.un_750
  0x05135204, 0x0e643ba6, 0x2a0619a0, 0x18001218,   // ha.et.fr_332 so.lg.is_521  gl.de.mt_322 ur.ar.un_740
  // [71f0]
  0x07000122, 0x0d001707, 0x0c55350c, 0x0b0a32a0,   // en.it.un_870 sr.cs.un_420  zu.rw.sv_543 bs.pt.es_322
  0x321e17ee, 0x6b000907, 0x01004a04, 0x01003104,   // sr.ms.bs_422 pl.ceb.un_420  yo.en.un_320 az.en.un_320
  0x16001b04, 0x1c002804, 0x02530807, 0x310f10a0,   // tr.hr.un_320 sw.id.un_320  no.ht.da_432 lt.lv.az_322
  0x050a0604, 0x25001905, 0x53356411, 0x08021aee,   // de.pt.fr_332 gl.eu.un_330  lg.zu.ht_653 tl.da.no_422
  // [7200]
  0x531225a7, 0x21311bee, 0x320d2da4, 0x08070aee,   // eu.hu.ht_532 tr.az.jw_422  sk.cs.bs_433 mk.bg.uk_422
  0x3f524a07, 0x1b531e07, 0x11552507, 0x100704a4,   // yo.ha.af_432 ms.ht.tr_432  eu.rw.ro_432 ru.bg.be_433
  0x6b282505, 0x1b2553a0, 0x0a001804, 0x216b2508,   // eu.sw.ceb_333 ht.eu.tr_322  ga.pt.un_320 eu.ceb.jw_443
  0x041125ee, 0x0e033f0e, 0x1a3525a7, 0x356825ad,   // eu.ro.fi_422 af.nl.is_555  eu.zu.tl_532 eu.ig.zu_643
  // [7210]
  0x09002512, 0x6b6401ec, 0x4a2825ad, 0x05072a05,   // eu.pl.un_640 en.lg.ceb_644  eu.sw.yo_643 mt.it.fr_333
  0x1e250d14, 0x1e001a07, 0x09252da9, 0x255535af,   // cs.eu.ms_666 tl.ms.un_420  sk.eu.pl_544 zu.rw.eu_655
  0x2d0d25a0, 0x17001f04, 0x16354aa0, 0x0d000804,   // eu.cs.sk_322 cy.sr.un_320  yo.zu.hr_322 no.cs.un_320
  0x216b1c5a, 0x2d0d250c, 0x3100060b, 0x060c25a0,   // id.ceb.jw_553 eu.cs.sk_543  de.az.un_520 eu.sv.de_322
  // [7220]
  0x163b35a0, 0x06011f0c, 0x212a1c0c, 0x552a3512,   // zu.so.hr_322 cy.en.de_543  id.mt.jw_543 zu.mt.rw_654
  0x01041355, 0x1a3b6ba0, 0x07120107, 0x52121307,   // et.fi.en_442 ceb.so.tl_322  en.hu.it_432 et.hu.ha_432
  0x251a6b12, 0x1e160ea4, 0x02280807, 0x4a002504,   // ceb.tl.eu_654 is.hr.ms_433  no.sw.da_432 eu.yo.un_320
  0x32006b20, 0x35130ca9, 0x04126b08, 0x19642804,   // ceb.bs.un_850 sv.et.zu_544  ceb.hu.fi_443 sw.lg.gl_332
  // [7230]
  0x12040f0d, 0x291208a0, 0x060a05a0, 0x0e10190c,   // lv.fi.hu_554 no.hu.sl_322  fr.pt.de_322 gl.lt.is_543
  0x0a2a11a4, 0x02055305, 0x68005219, 0x0a001817,   // ro.mt.pt_433 ht.fr.da_333  ha.ig.un_750 ga.pt.un_730
  0x21000c23, 0x10230eaf, 0x2d0d5502, 0x23520ca4,   // sv.jw.un_880 is.ca.lt_655  rw.cs.sk_222 sv.ha.ca_433
  0x52273bee, 0x080c350c, 0x1b121f0c, 0x2d003512,   // so.gd.ha_422 zu.sv.no_543  cy.hu.tr_543 zu.sk.un_640
  // [7240]
  0x5253350c, 0x293b1304, 0x645525a4, 0x17002012,   // zu.ht.ha_543 et.so.sl_332  eu.rw.lg_433 sq.sr.un_640
  0x03291313, 0x103b1aa7, 0x2100352a, 0x6b52010c,   // et.sl.nl_665 tl.so.lt_532  zu.jw.un_970 en.ha.ceb_543
  0x071306ee, 0x646855a9, 0x020d08ee, 0x033f02a9,   // de.et.it_422 rw.ig.lg_544  no.cs.da_422 da.af.nl_544
  0x1f190b14, 0x35122507, 0x052001ec, 0x28113b04,   // es.gl.cy_666 eu.hu.zu_432  en.sq.fr_644 so.ro.sw_332
  // [7250]
  0x100f1fac, 0x270c020d, 0x07002d04, 0x64002d04,   // cy.lv.lt_632 da.sv.gd_554  sk.it.un_320 sk.lg.un_320
  0x0b3552a4, 0x32000b05, 0x283f5302, 0x311202ee,   // ha.zu.es_433 es.bs.un_330  ht.af.sw_222 da.hu.az_422
  0x20000504, 0x17211c07, 0x645553ec, 0x050207a0,   // fr.sq.un_320 id.jw.sr_432  ht.rw.lg_644 it.da.fr_322
  0x550928a4, 0x640706ee, 0x3f356404, 0x090f01a4,   // sw.pl.rw_433 de.it.lg_422  lg.zu.af_332 en.lv.pl_433
  // [7260]
  0x4a006407, 0x06002b04, 0x2000050c, 0x31182aa7,   // lg.yo.un_420 vi.de.un_320  fr.sq.un_530 mt.ga.az_532
  0x28000619, 0x020520ad, 0x130e04af, 0x1f1b25ee,   // de.sw.un_750 sq.fr.da_643  fi.is.et_655 eu.tr.cy_422
  0x20000119, 0x12002307, 0x2300052c, 0x29001c08,   // en.sq.un_750 ca.hu.un_420  fr.ca.un_990 id.sl.un_430
  0x0f001319, 0x286b1a55, 0x3b1c5212, 0x190a08af,   // et.lv.un_750 tl.ceb.sw_442  ha.id.so_654 no.pt.gl_655
  // [7270]
  0x0a2301a6, 0x522a1ea9, 0x0c2b0107, 0x0e001905,   // en.ca.pt_521 ms.mt.ha_544  en.vi.sv_432 gl.is.un_330
  0x066e0fee, 0x080521a0, 0x07000113, 0x52001e22,   // lv.hmn.de_422 jw.fr.no_322  en.it.un_650 ms.ha.un_870
  0x23190a0d, 0x3f0f1007, 0x23000804, 0x202a3160,   // pt.gl.ca_554 lt.lv.af_432  no.ca.un_320 az.mt.sq_664
  0x0d212aec, 0x120f105a, 0x3b0601ac, 0x0f106ea7,   // mt.jw.cs_644 lt.lv.hu_553  en.de.so_632 hmn.lt.lv_532
  // [7280]
  0x0b55530c, 0x6b12070d, 0x27190b04, 0x011105ee,   // ht.rw.es_543 it.hu.ceb_554  es.gl.gd_332 fr.ro.en_422
  0x0e1923a0, 0x25003b12, 0x013b07ac, 0x28526407,   // ca.gl.is_322 so.eu.un_640  it.so.en_632 lg.ha.sw_432
  0x0a29070c, 0x3b27280c, 0x0d080ca4, 0x3f086eee,   // it.sl.pt_543 sw.gd.so_543  sv.no.cs_433 hmn.no.af_422
  0x6e001f05, 0x2700070d, 0x35005508, 0x07284a04,   // cy.hmn.un_330 it.gd.un_540  rw.zu.un_430 yo.sw.it_332
  // [7290]
  0x052a1307, 0x11006407, 0x3f063ba0, 0x0f13100c,   // et.mt.fr_432 lg.ro.un_420  so.de.af_322 lt.et.lv_543
  0x03131ca4, 0x3b282105, 0x06070104, 0x2b0a0504,   // id.et.nl_433 jw.sw.so_333  en.it.de_332 fr.pt.vi_332
  0x032b0c08, 0x23001c0d, 0x353b52ee, 0x03050111,   // sv.vi.nl_443 id.ca.un_540  ha.so.zu_422 en.fr.nl_653
  0x03000529, 0x2700022a, 0x08001722, 0x08020908,   // fr.nl.un_960 da.gd.un_970  sr.uk.un_870 pl.da.no_443
  // [72a0]
  0x03013fa4, 0x03013fee, 0x20000207, 0x012153a0,   // af.en.nl_433 af.en.nl_422  da.sq.un_420 ht.jw.en_322
  0x2d004a09, 0x01190b08, 0x231f0560, 0x1923010c,   // yo.sk.un_440 es.gl.en_443  fr.cy.ca_664 en.ca.gl_543
  0x190113a0, 0x1632200d, 0x21323f08, 0x1929070c,   // et.en.gl_322 sq.bs.hr_554  af.bs.jw_443 it.sl.gl_543
  0x07003204, 0x1f0264ee, 0x1c1a1e07, 0x3b002813,   // bs.it.un_320 lg.da.cy_422  ms.tl.id_432 sw.so.un_650
  // [72b0]
  0x08071002, 0x0a000519, 0x0e4a0b08, 0x64001f07,   // be.bg.uk_222 fr.pt.un_750  es.yo.is_443 cy.lg.un_420
  0x23051ea4, 0x23130508, 0x20052308, 0x12005302,   // ms.fr.ca_433 fr.et.ca_443  ca.fr.sq_443 ht.hu.un_220
  0x05001c04, 0x3f032508, 0x1f13250c, 0x080e01a0,   // id.fr.un_320 eu.nl.af_443  eu.et.cy_543 en.is.no_322
  0x1f002508, 0x041017a9, 0x16641bec, 0x1c1253ad,   // eu.cy.un_430 sr.be.ru_544  tr.lg.hr_644 ht.hu.id_643
  // [72c0]
  0x25000c05, 0x2b060107, 0x3f0325ee, 0x171c21a0,   // sv.eu.un_330 en.de.vi_432  eu.nl.af_422 jw.id.sr_322
  0x05082b07, 0x0a001b1a, 0x08002b19, 0x53001902,   // vi.no.fr_432 tr.pt.un_760  vi.no.un_750 gl.ht.un_220
  0x3f030609, 0x253f1307, 0x3f002513, 0x2a0201ad,   // de.nl.af_444 et.af.eu_432  eu.af.un_650 en.da.mt_643
  0x3f250302, 0x1b070107, 0x060501af, 0x1a23530b,   // nl.eu.af_222 en.it.tr_432  en.fr.de_655 ht.ca.tl_542
  // [72d0]
  0x3f0305af, 0x066427a0, 0x070a13ee, 0x13043fac,   // fr.nl.af_655 gd.lg.de_322  et.pt.it_422 af.fi.et_632
  0x04080c0d, 0x25353fa4, 0x64043b04, 0x35001108,   // sv.no.fi_554 af.zu.eu_433  so.fi.lg_332 ro.zu.un_430
  0x1100190e, 0x190a2312, 0x290e07a4, 0x64043ba7,   // gl.ro.un_550 ca.pt.gl_654  it.is.sl_433 so.fi.lg_532
  0x1b170907, 0x02321602, 0x190b27a4, 0x12311bee,   // pl.sr.tr_432 hr.bs.da_222  gd.es.gl_433 tr.az.hu_422
  // [72e0]
  0x10000a22, 0x2a0f3f04, 0x211c11a0, 0x6804130d,   // mk.be.un_870 af.lv.mt_332  ro.id.jw_322 et.fi.ig_554
  0x061112ec, 0x641304a0, 0x52641ca0, 0x216b1a09,   // hu.ro.de_644 fi.et.lg_322  id.lg.ha_322 tl.ceb.jw_444
  0x2300070e, 0x68355207, 0x030e0f07, 0x6b005209,   // it.ca.un_550 ha.zu.ig_432  lv.is.nl_432 ha.ceb.un_440
  0x190b05a0, 0x3b1a5208, 0x2b002323, 0x0e4a18a7,   // fr.es.gl_322 ha.tl.so_443  ca.vi.un_880 ga.yo.is_532
  // [72f0]
  0x1752550c, 0x2564290c, 0x35090d0b, 0x216452ad,   // rw.ha.sr_543 sl.lg.eu_543  cs.pl.zu_542 ha.lg.jw_643
  0x21005207, 0x4a211ea0, 0x52354a12, 0x06005205,   // ha.jw.un_420 ms.jw.yo_322  yo.zu.ha_654 ha.de.un_330
  0x353b4a04, 0x201a01a0, 0x124a2aa0, 0x641a525a,   // yo.so.zu_332 en.tl.sq_322  mt.yo.hu_322 ha.tl.lg_553
  0x642555af, 0x2155520c, 0x092d25a0, 0x4a3b1ba7,   // rw.eu.lg_655 ha.rw.jw_543  eu.sk.pl_322 tr.so.yo_532
  // [7300]
  0x642555a4, 0x641a2111, 0x0f255208, 0x28555209,   // rw.eu.lg_433 jw.tl.lg_653  ha.eu.lv_443 ha.rw.sw_444
  0x35532305, 0x170a0805, 0x17002d05, 0x1c000d21,   // ca.ht.zu_333 uk.mk.sr_333  sk.sr.un_330 ne.mr.un_860
  0x21201cee, 0x28551211, 0x17000f09, 0x08001f0e,   // id.sq.jw_422 hu.rw.sw_653  lv.sr.un_440 cy.no.un_550
  0x3f001004, 0x03003f2c, 0x0f276bee, 0x35000e19,   // lt.af.un_320 af.nl.un_990  ceb.gd.lv_422 is.zu.un_750
  // [7310]
  0x086b2aee, 0x25000718, 0x2a09180c, 0x2a003b1a,   // mt.ceb.no_422 it.eu.un_740  ga.pl.mt_543 so.mt.un_760
  0x55686460, 0x130e0cad, 0x52281007, 0x041a6baf,   // lg.ig.rw_664 sv.is.et_643  lt.sw.ha_432 ceb.tl.fi_655
  0x07230b04, 0x3f5213af, 0x1e1c09a4, 0x090d3105,   // es.ca.it_332 et.ha.af_655  pl.id.ms_433 az.cs.pl_333
  0x012806a0, 0x68643511, 0x316b13ee, 0x0d172904,   // de.sw.en_322 zu.lg.ig_653  et.ceb.az_422 sl.sr.cs_332
  // [7320]
  0x1a005204, 0x29520f55, 0x3b040f55, 0x011b55a0,   // ha.tl.un_320 lv.ha.sl_442  lv.fi.so_442 rw.tr.en_322
  0x0f002814, 0x551828a0, 0x1c181302, 0x13005207,   // sw.lv.un_660 sw.ga.rw_322  et.ga.id_222 ha.et.un_420
  0x21280fa7, 0x291728a0, 0x11002811, 0x041b640b,   // lv.sw.jw_532 sw.sr.sl_322  sw.ro.un_630 lg.tr.fi_542
  0x641e1c02, 0x1a00102a, 0x641f0607, 0x17520f04,   // id.ms.lg_222 lt.tl.un_970  de.cy.lg_432 lv.ha.sr_332
  // [7330]
  0x1a046b0c, 0x681e550c, 0x0103640b, 0x35001c13,   // ceb.fi.tl_543 rw.ms.ig_543  lg.nl.en_542 id.zu.un_650
  0x03520ead, 0x0353010c, 0x136b3504, 0x04136b12,   // is.ha.nl_643 en.ht.nl_543  zu.ceb.et_332 ceb.et.fi_654
  0x08020c07, 0x03250aee, 0x286b03a0, 0x0b6e2012,   // sv.da.no_432 pt.eu.nl_422  nl.ceb.sw_322 sq.hmn.es_654
  0x4a1805af, 0x03533f04, 0x533f1aee, 0x0b530fee,   // fr.ga.yo_655 af.ht.nl_332  tl.af.ht_422 lv.ht.es_422
  // [7340]
  0x21182b13, 0x280f2aa9, 0x11055214, 0x1c17280c,   // vi.ga.jw_665 mt.lv.sw_544  ha.fr.ro_666 sw.sr.id_543
  0x64002a04, 0x13003b34, 0x1e1c28a6, 0x4a531f14,   // mt.lg.un_320 so.et.un_A80  sw.id.ms_521 cy.ht.yo_666
  0x31005207, 0x4a0c64a9, 0x043b350c, 0x080264a0,   // ha.az.un_420 lg.sv.yo_544  zu.so.fi_543 lg.da.no_322
  0x534a640e, 0x1e1c0414, 0x10081109, 0x6b681f07,   // lg.yo.ht_555 fi.id.ms_666  ro.uk.be_444 cy.ig.ceb_432
  // [7350]
  0x314a250c, 0x32556404, 0x202d0d0d, 0x3b000420,   // eu.yo.az_543 lg.rw.bs_332  cs.sk.sq_554 fi.so.un_850
  0x09002704, 0x4a001135, 0x1c171eec, 0x31001105,   // gd.pl.un_320 ro.yo.un_A90  ms.sr.id_644 ro.az.un_330
  0x0d1b0111, 0x231302a4, 0x050123a0, 0x32645504,   // en.tr.cs_653 da.et.ca_433  ca.en.fr_322 rw.lg.bs_332
  0x3f532013, 0x324a2aa0, 0x23112aac, 0x0f000309,   // sq.ht.af_665 mt.yo.bs_322  mt.ro.ca_632 nl.lv.un_440
  // [7360]
  0x3f211ca4, 0x0c550704, 0x0f00030c, 0x04553ba0,   // id.jw.af_433 it.rw.sv_332  nl.lv.un_530 so.rw.fi_322
  0x6b180ca0, 0x020c3f02, 0x27071107, 0x213b5202,   // sv.ga.ceb_322 af.sv.da_222  ro.it.gd_432 ha.so.jw_222
  0x010605ee, 0x020507ec, 0x200a28ee, 0x120a23a0,   // fr.de.en_422 it.fr.da_644  sw.pt.sq_422 ca.pt.hu_322
  0x01050704, 0x1f002004, 0x110523a4, 0x20210a0c,   // it.fr.en_332 sq.cy.un_320  ca.fr.ro_433 pt.jw.sq_543
  // [7370]
  0x030d3f0e, 0x0d2d0c04, 0x6b000609, 0x6b3568ee,   // af.cs.nl_555 sv.sk.cs_332  de.ceb.un_440 ig.zu.ceb_422
  0x35002902, 0x293564af, 0x0e000818, 0x0c000304,   // sl.zu.un_220 lg.zu.sl_655  no.is.un_740 nl.sv.un_320
  0x1f000a04, 0x1a350ea4, 0x111b640d, 0x1e1221a0,   // pt.cy.un_320 is.zu.tl_433  lg.tr.ro_554 jw.hu.ms_322
  0x551a1b0c, 0x230a0704, 0x100407af, 0x255528a9,   // tr.tl.rw_543 it.pt.ca_332  bg.ru.be_655 sw.rw.eu_544
  // [7380]
  0x2d00290c, 0x6407250c, 0x0b001808, 0x23110755,   // sl.sk.un_530 eu.it.lg_543  ga.es.un_430 it.ro.ca_442
  0x25553513, 0x55093bec, 0x18010604, 0x1b552908,   // zu.rw.eu_665 so.pl.rw_644  de.en.ga_332 sl.rw.tr_443
  0x64551ba7, 0x210510a0, 0x28524aee, 0x11072908,   // tr.rw.lg_532 lt.fr.jw_322  yo.ha.sw_422 sl.it.ro_443
  0x53355507, 0x35555208, 0x09553bec, 0x13001004,   // rw.zu.ht_432 ha.rw.zu_443  so.rw.pl_644 lt.et.un_320
  // [7390]
  0x0700550c, 0x040153a0, 0x6b1613a0, 0x06082aa0,   // rw.it.un_530 ht.en.fi_322  et.hr.ceb_322 mt.no.de_322
  0x0313040c, 0x311a0107, 0x01111b0c, 0x250413a4,   // fi.et.nl_543 en.tl.az_432  tr.ro.en_543 et.fi.eu_433
  0x351b4aa0, 0x04030d05, 0x0b000420, 0x2d0d53a0,   // yo.tr.zu_322 cs.nl.fi_333  fi.es.un_850 ht.cs.sk_322
  0x172d0d05, 0x531905ee, 0x55000913, 0x3f0503a0,   // cs.sk.sr_333 fr.gl.ht_422  pl.rw.un_650 nl.fr.af_322
  // [73a0]
  0x08000a04, 0x0c230409, 0x2105530c, 0x641b53a0,   // mk.uk.un_320 fi.ca.sv_444  ht.fr.jw_543 ht.tr.lg_322
  0x552128a0, 0x3b5509ad, 0x05003b08, 0x0d006b04,   // sw.jw.rw_322 pl.rw.so_643  so.fr.un_430 ceb.cs.un_320
  0x170a08a7, 0x28206bec, 0x28530111, 0x01535502,   // uk.mk.sr_532 ceb.sq.sw_644  en.ht.sw_653 rw.ht.en_222
  0x0c000505, 0x55351baf, 0x52006b22, 0x03005305,   // fr.sv.un_330 tr.zu.rw_655  ceb.ha.un_870 ht.nl.un_330
  // [73b0]
  0x28003b0d, 0x1e000504, 0x0e1f0c05, 0x3520100c,   // so.sw.un_540 fr.ms.un_320  sv.cy.is_333 lt.sq.zu_543
  0x20002312, 0x060e29a6, 0x251c21ee, 0x0b000e07,   // ca.sq.un_640 sl.is.de_521  jw.id.eu_422 is.es.un_420
  0x211c3513, 0x0a311bee, 0x0e0603a4, 0x08311b0d,   // zu.id.jw_665 tr.az.pt_422  nl.de.is_433 tr.az.no_554
  0x350802ee, 0x0c2a0707, 0x1000200e, 0x200805a0,   // da.no.zu_422 it.mt.sv_432  sq.lt.un_550 fr.no.sq_322
  // [73c0]
  0x11002019, 0x021b0ea4, 0x060c0fa9, 0x251b3107,   // sq.ro.un_750 is.tr.da_433  lv.sv.de_544 az.tr.eu_432
  0x18010304, 0x35000207, 0x11080709, 0x311b0fa0,   // nl.en.ga_332 da.zu.un_420  bg.uk.ro_444 lv.tr.az_322
  0x6b100f11, 0x102d0d0d, 0x1f0d2d11, 0x1b2a35a7,   // lv.lt.ceb_653 cs.sk.lt_554  sk.cs.cy_653 zu.mt.tr_532
  0x2d003504, 0x0400070b, 0x07000811, 0x25350fa4,   // zu.sk.un_320 bg.ru.un_520  uk.bg.un_630 lv.zu.eu_433
  // [73d0]
  0x28250708, 0x11170aaf, 0x1e683504, 0x11001702,   // it.eu.sw_443 mk.sr.ro_655  zu.ig.ms_332 sr.ro.un_220
  0x3235250c, 0x25000719, 0x04000a14, 0x53033fa4,   // eu.zu.bs_543 it.eu.un_750  mk.ru.un_660 af.nl.ht_433
  0x100807ee, 0x28003b08, 0x10170709, 0x25646809,   // bg.uk.be_422 so.sw.un_430  bg.sr.be_444 ig.lg.eu_444
  0x3f000608, 0x080a070d, 0x553525ad, 0x643135af,   // de.af.un_430 bg.mk.uk_554  eu.zu.rw_643 zu.az.lg_655
  // [73e0]
  0x080a1004, 0x03532702, 0x532507a9, 0x4a1635a7,   // be.mk.uk_332 gd.ht.nl_222  it.eu.ht_544 zu.hr.yo_532
  0x2500070e, 0x07352508, 0x0e270c55, 0x0f250708,   // it.eu.un_550 eu.zu.it_443  sv.gd.is_442 it.eu.lv_443
  0x6e003512, 0x310f1b05, 0x35283f09, 0x06006b12,   // zu.hmn.un_640 tr.lv.az_333  af.sw.zu_444 ceb.de.un_640
  0x1c211e11, 0x2d0d3202, 0x2a1f3f07, 0x2a006414,   // ms.jw.id_653 bs.cs.sk_222  af.cy.mt_432 lg.mt.un_660
  // [73f0]
  0x31000302, 0x06283512, 0x13002a09, 0x1c162bee,   // nl.az.un_220 zu.sw.de_654  mt.et.un_440 vi.hr.id_422
  0x0a081155, 0x0b2868ee, 0x1c003f02, 0x530c0813,   // ro.uk.mk_442 ig.sw.es_422  af.id.un_220 no.sv.ht_665
  0x53000912, 0x090635a4, 0x3f002004, 0x17123555,   // pl.ht.un_640 zu.de.pl_433  sq.af.un_320 zu.hu.sr_442
  0x5301050c, 0x090d2dec, 0x16291208, 0x16290c07,   // fr.en.ht_543 sk.cs.pl_644  hu.sl.hr_443 sv.sl.hr_432

  // [7400]
  0x53033f13, 0x2d060907, 0x01530502, 0x3568060d,   // af.nl.ht_665 pl.de.sk_432  fr.ht.en_222 de.ig.zu_554
  0x060b2804, 0x16003502, 0x18000908, 0x080602a0,   // sw.es.de_332 zu.hr.un_220  pl.ga.un_430 da.de.no_322
  0x643f0308, 0x0d6e1ca0, 0x3b006420, 0x6b556407,   // nl.af.lg_443 id.hmn.cs_322  lg.so.un_850 lg.rw.ceb_432
  0x0a00250d, 0x20001608, 0x31003b05, 0x55005208,   // eu.pt.un_540 hr.sq.un_430  so.az.un_330 ha.rw.un_430
  // [7410]
  0x111f6ba4, 0x05005335, 0x17192908, 0x28643b0c,   // ceb.cy.ro_433 ht.fr.un_A90  sl.gl.sr_443 so.lg.sw_543
  0x3b005213, 0x01002520, 0x64040607, 0x28006e07,   // ha.so.un_650 eu.en.un_850  de.fi.lg_432 hmn.sw.un_420
  0x35001b19, 0x2a3b64ad, 0x3f100f5a, 0x1a005305,   // tr.zu.un_750 lg.so.mt_643  lv.lt.af_553 ht.tl.un_330
  0x2555640c, 0x190f6407, 0x211c6455, 0x100f0313,   // lg.rw.eu_543 lg.lv.gl_432  lg.id.jw_442 nl.lv.lt_665
  // [7420]
  0x0a101714, 0x0700030e, 0x25091013, 0x091153ad,   // sr.be.mk_666 nl.it.un_550  lt.pl.eu_665 ht.ro.pl_643
  0x290f350c, 0x2a000f14, 0x2a2564ec, 0x3f0725a4,   // zu.lv.sl_543 lv.mt.un_660  lg.eu.mt_644 eu.it.af_433
  0x3509550b, 0x35645560, 0x25090660, 0x3b006421,   // rw.pl.zu_542 rw.lg.zu_664  de.pl.eu_664 lg.so.un_860
  0x070264a4, 0x3b643f55, 0x64002d13, 0x0d1f2d07,   // lg.da.it_433 af.lg.so_442  sk.lg.un_650 sk.cy.cs_432
  // [7430]
  0x213f2507, 0x64520409, 0x35002505, 0x2d100f0c,   // eu.af.jw_432 fi.ha.lg_444  eu.zu.un_330 lv.lt.sk_543
  0x23251902, 0x0802040c, 0x19002009, 0x096864ee,   // gl.eu.ca_222 fi.da.no_543  sq.gl.un_440 lg.ig.pl_422
  0x2d0d07ee, 0x0f002309, 0x21002b05, 0x0d000a04,   // it.cs.sk_422 ca.lv.un_440  vi.jw.un_330 pt.cs.un_320
  0x10001308, 0x052d0305, 0x08001b08, 0x08021305,   // et.lt.un_430 nl.sk.fr_333  tr.no.un_430 et.da.no_333
  // [7440]
  0x10290d08, 0x28551e07, 0x1b0921a0, 0x1c0e280c,   // cs.sl.lt_443 ms.rw.sw_432  jw.pl.tr_322 sw.is.id_543
  0x1a20550c, 0x6b1a53ad, 0x2b001108, 0x1a6b53af,   // rw.sq.tl_543 ht.tl.ceb_643  ro.vi.un_430 ht.ceb.tl_655
  0x170a2111, 0x041b130c, 0x11522508, 0x55281aec,   // jw.pt.sr_653 et.tr.fi_543  eu.ha.ro_443 tl.sw.rw_644
  0x1b1a530c, 0x310a3ba7, 0x3f1c0302, 0x53001a1b,   // ht.tl.tr_543 so.pt.az_532  nl.id.af_222 tl.ht.un_770
  // [7450]
  0x1a531b04, 0x10190b0d, 0x31251bec, 0x313b2007,   // tr.ht.tl_332 es.gl.lt_554  tr.eu.az_644 sq.so.az_432
  0x0e0601a0, 0x09001002, 0x00000137, 0x53001a0d,   // en.de.is_322 lt.pl.un_220  en.un.un_B00 tl.ht.un_540
  0x6b1a53a4, 0x3f0e0212, 0x3f200e07, 0x6b531a12,   // ht.tl.ceb_433 da.is.af_654  is.sq.af_432 tl.ht.ceb_654
  0x27061807, 0x321f0ead, 0x060701a0, 0x64533507,   // ga.de.gd_432 is.cy.bs_643  en.it.de_322 zu.ht.lg_432
  // [7460]
  0x21230507, 0x53004a0c, 0x530f0514, 0x0a000513,   // fr.ca.jw_432 yo.ht.un_530  fr.lv.ht_666 fr.pt.un_650
  0x111707ec, 0x2d0d16a4, 0x18002512, 0x100553ee,   // bg.sr.ro_644 hr.cs.sk_433  eu.ga.un_640 ht.fr.lt_422
  0x0e0c64a0, 0x1b002112, 0x6b121a04, 0x12040f08,   // lg.sv.is_322 jw.tr.un_640  tl.hu.ceb_332 lv.fi.hu_443
  0x1b120f55, 0x2d170d0c, 0x11270111, 0x16005304,   // lv.hu.tr_442 cs.sr.sk_543  en.gd.ro_653 ht.hr.un_320
  // [7470]
  0x0e0208ee, 0x28533fee, 0x13002304, 0x08002004,   // no.da.is_422 af.ht.sw_422  ca.et.un_320 sq.no.un_320
  0x0d002d20, 0x0a002804, 0x122a0f08, 0x64094a09,   // sk.cs.un_850 sw.pt.un_320  lv.mt.hu_443 yo.pl.lg_444
  0x23003505, 0x0b005202, 0x0f5529a0, 0x1b214a55,   // zu.ca.un_330 ha.es.un_220  sl.rw.lv_322 yo.jw.tr_442
  0x190b2907, 0x172d09ad, 0x55115308, 0x06002d02,   // sl.es.gl_432 pl.sk.sr_643  ht.ro.rw_443 sk.de.un_220
  // [7480]
  0x08071108, 0x6b00060d, 0x040b530c, 0x29072aa0,   // ro.bg.uk_443 de.ceb.un_540  ht.es.fi_543 mt.it.sl_322
  0x08031c08, 0x2a5303a7, 0x53002521, 0x133b6b07,   // id.nl.no_443 nl.ht.mt_532  eu.ht.un_860 ceb.so.et_432
  0x3f6403a0, 0x532d0d02, 0x1f002a14, 0x3500250b,   // nl.lg.af_322 cs.sk.ht_222  mt.cy.un_660 eu.zu.un_520
  0x0900290e, 0x0f211e07, 0x2932160e, 0x1304280c,   // sl.pl.un_550 ms.jw.lv_432  hr.bs.sl_555 sw.fi.et_543
  // [7490]
  0x1c211a0c, 0x111704a4, 0x1c213507, 0x52003f04,   // tl.jw.id_543 ru.sr.ro_433  zu.jw.id_432 af.ha.un_320
  0x101b1112, 0x352068a4, 0x1c003504, 0x55641aec,   // ro.tr.lt_654 ig.sq.zu_433  zu.id.un_320 tl.lg.rw_644
  0x182721a9, 0x20002813, 0x213b1aaf, 0x53002702,   // jw.gd.ga_544 sw.sq.un_650  tl.so.jw_655 gd.ht.un_220
  0x32200f08, 0x2d1235af, 0x20135555, 0x520625ec,   // lv.sq.bs_443 zu.hu.sk_655  rw.et.sq_442 eu.de.ha_644
  // [74a0]
  0x53013fa0, 0x1b311aa9, 0x282a3508, 0x2a002b08,   // af.en.ht_322 tl.az.tr_544  zu.mt.sw_443 vi.mt.un_430
  0x132855a7, 0x32172902, 0x20553513, 0x21051e0c,   // rw.sw.et_532 sl.sr.bs_222  zu.rw.sq_665 ms.fr.jw_543
  0x11001022, 0x07001e0d, 0x210e1a09, 0x3f6b1aec,   // be.ro.un_870 ms.it.un_540  tl.is.jw_444 tl.ceb.af_644
  0x64001a0d, 0x35063bee, 0x13552808, 0x28041305,   // tl.lg.un_540 so.de.zu_422  sw.rw.et_443 et.fi.sw_333
  // [74b0]
  0x202855ad, 0x55203b02, 0x55202807, 0x3b4a35a0,   // rw.sw.sq_643 so.sq.rw_222  sw.sq.rw_432 zu.yo.so_322
  0x32291604, 0x21003507, 0x13005502, 0x321629ee,   // hr.sl.bs_332 zu.jw.un_420  rw.et.un_220 sl.hr.bs_422
  0x1f080e08, 0x09002702, 0x2d040dee, 0x2d0d180e,   // is.no.cy_443 gd.pl.un_220  cs.fi.sk_422 ga.cs.sk_555
  0x03133fee, 0x2a201804, 0x07041807, 0x2000230d,   // af.et.nl_422 ga.sq.mt_332  ga.fi.it_432 ca.sq.un_540
  // [74c0]
  0x13003b08, 0x4a000405, 0x08022302, 0x0408110d,   // so.et.un_430 fi.yo.un_330  ca.da.no_222 ro.uk.ru_554
  0x033f0c04, 0x28003b13, 0x08020e14, 0x6b680807,   // sv.af.nl_332 so.sw.un_650  is.da.no_666 no.ig.ceb_432
  0x02061fa0, 0x27041811, 0x1a3b1e04, 0x12311ba7,   // cy.de.da_322 ga.fi.gd_653  ms.so.tl_332 tr.az.hu_532
  0x081827a9, 0x03123fa4, 0x3b000b02, 0x13110107,   // gd.ga.no_544 af.hu.nl_433  es.so.un_220 en.ro.et_432
  // [74d0]
  0x52002119, 0x2a001f12, 0x0f000e09, 0x3b2916a0,   // jw.ha.un_750 cy.mt.un_640  is.lv.un_440 hr.sl.so_322
  0x1020010b, 0x3509040d, 0x1b001214, 0x06083fa0,   // en.sq.lt_542 fi.pl.zu_554  hu.tr.un_660 af.no.de_322
  0x0a0f6b07, 0x0b6452a0, 0x0a1710a9, 0x2d0d3ba4,   // ceb.lv.pt_432 ha.lg.es_322  be.sr.mk_544 so.cs.sk_433
  0x0c030612, 0x036b06ad, 0x2100182c, 0x25003508,   // de.nl.sv_654 de.ceb.nl_643  ar.fa.un_990 zu.eu.un_430
  // [74e0]
  0x0c060311, 0x123f1aa0, 0x2d030602, 0x68005319,   // nl.de.sv_653 tl.af.hu_322  de.nl.sk_222 ht.ig.un_750
  0x1f016bee, 0x1a64350d, 0x08000c1a, 0x080a120c,   // ceb.en.cy_422 zu.lg.tl_554  sv.no.un_760 hu.pt.no_543
  0x09002d08, 0x1a216b12, 0x35060c11, 0x09643507,   // sk.pl.un_430 ceb.jw.tl_654  sv.de.zu_653 zu.lg.pl_432
  0x0a080c0c, 0x212855a9, 0x55351c0c, 0x25126b08,   // sv.no.pt_543 rw.sw.jw_544  id.zu.rw_543 ceb.hu.eu_443
  // [74f0]
  0x64066ba4, 0x12202114, 0x01190bad, 0x061e21a9,   // ceb.de.lg_433 jw.sq.hu_666  es.gl.en_643 jw.ms.de_544
  0x06012708, 0x1b001221, 0x64001a34, 0x64250707,   // gd.en.de_443 hu.tr.un_860  tl.lg.un_A80 it.eu.lg_432
  0x0705110c, 0x091007ee, 0x1e172aa4, 0x0300062c,   // ro.fr.it_543 it.lt.pl_422  mt.sr.ms_433 de.nl.un_990
  0x0a17550b, 0x1e1c2308, 0x320d17a0, 0x216455ad,   // rw.sr.pt_542 ca.id.ms_443  sr.cs.bs_322 rw.lg.jw_643
  // [7500]
  0x2a276ba7, 0x32002013, 0x122135af, 0x120c080c,   // ceb.gd.mt_532 sq.bs.un_650  zu.jw.hu_655 no.sv.hu_543
  0x110427a9, 0x042821a9, 0x1e1c25a9, 0x27001104,   // gd.fi.ro_544 jw.sw.fi_544  eu.id.ms_544 ro.gd.un_320
  0x0e010602, 0x06000919, 0x21353b04, 0x0700180c,   // de.en.is_222 pl.de.un_750  so.zu.jw_332 ga.it.un_530
  0x00006b37, 0x1e1a1c12, 0x13000911, 0x044a1f07,   // ceb.un.un_B00 id.tl.ms_654  hi.bh.un_630 cy.yo.fi_432
  // [7510]
  0x251a1ca4, 0x3f011a55, 0x0f2d0d13, 0x1f033f55,   // id.tl.eu_433 tl.en.af_442  cs.sk.lv_665 af.nl.cy_442
  0x52283b09, 0x1a4a6ba7, 0x256835a0, 0x20130412,   // so.sw.ha_444 ceb.yo.tl_532  zu.ig.eu_322 fi.et.sq_654
  0x2d0d31ee, 0x3f001313, 0x4a0e2ba9, 0x2a4a07af,   // az.cs.sk_422 et.af.un_650  vi.is.yo_544 it.yo.mt_655
  0x3f00130c, 0x20313ba7, 0x3119235a, 0x644a13a0,   // et.af.un_530 so.az.sq_532  ca.gl.az_553 et.yo.lg_322
  // [7520]
  0x21281ea4, 0x215204ec, 0x526b01a0, 0x0d00291a,   // ms.sw.jw_433 fi.ha.jw_644  en.ceb.ha_322 sl.cs.un_760
  0x3f0e03a4, 0x1300061a, 0x02000611, 0x211812ac,   // nl.is.af_433 de.et.un_760  de.da.un_630 ur.ar.fa_632
  0x122305a0, 0x1320030d, 0x05030107, 0x080717ad,   // fr.ca.hu_322 nl.sq.et_554  en.nl.fr_432 sr.bg.uk_643
  0x16000d19, 0x3f033b0d, 0x0d122107, 0x1827280e,   // cs.hr.un_750 so.nl.af_554  jw.hu.cs_432 sw.gd.ga_555
  // [7530]
  0x2a0f55a4, 0x530e2707, 0x01182704, 0x2d681a08,   // rw.lv.mt_433 gd.is.ht_432  gd.ga.en_332 tl.ig.sk_443
  0x2b001812, 0x190b18a4, 0x0400112a, 0x104a0f07,   // ga.vi.un_640 ga.es.gl_433  ro.ru.un_970 lv.yo.lt_432
  0x1328070c, 0x130103a6, 0x1b185204, 0x4a55280d,   // it.sw.et_543 nl.en.et_521  ha.ga.tr_332 sw.rw.yo_554
  0x05010c08, 0x0c000a02, 0x270a18af, 0x0c080e07,   // sv.en.fr_443 pt.sv.un_220  ga.pt.gd_655 is.no.sv_432
  // [7540]
  0x02033f07, 0x55006405, 0x0e3b12ad, 0x013b64a4,   // af.nl.da_432 lg.rw.un_330  hu.so.is_643 lg.so.en_433
  0x19002322, 0x552852a4, 0x1c533bee, 0x3b001322,   // ca.gl.un_870 ha.sw.rw_433  so.ht.id_422 et.so.un_870
  0x121b3113, 0x0a1e1c08, 0x0300350c, 0x110b2aa0,   // az.tr.hu_665 id.ms.pt_443  zu.nl.un_530 mt.es.ro_322
  0x553552ec, 0x2a080204, 0x110b0a08, 0x03005508,   // ha.zu.rw_644 da.no.mt_332  pt.es.ro_443 rw.nl.un_430
  // [7550]
  0x1b101307, 0x10016ba0, 0x27171fa4, 0x35001a2b,   // et.lt.tr_432 ceb.en.lt_322  cy.sr.gd_433 tl.zu.un_980
  0x08101fad, 0x1a291ca0, 0x256b5212, 0x0f230560,   // cy.lt.no_643 id.sl.tl_322  ha.ceb.eu_654 fr.ca.lv_664
  0x01003f0e, 0x1a00550d, 0x02250812, 0x0e002302,   // af.en.un_550 rw.tl.un_540  no.eu.da_654 ca.is.un_220
  0x052353ad, 0x0c0f25a4, 0x251b0413, 0x53232112,   // ht.ca.fr_643 eu.lv.sv_433  fi.tr.eu_665 jw.ca.ht_654
  // [7560]
  0x1c6b2111, 0x166b1a0c, 0x55133ba4, 0x0c3b0807,   // jw.ceb.id_653 tl.ceb.hr_543  so.et.rw_433 no.so.sv_432
  0x2b006412, 0x131a3512, 0x13002708, 0x281a5205,   // lg.vi.un_640 zu.tl.et_654  gd.et.un_430 ha.tl.sw_333
  0x31002a05, 0x2d0d1017, 0x21532312, 0x254a3fa0,   // mt.az.un_330 lt.cs.sk_753  ca.ht.jw_654 af.yo.eu_322
  0x4a1e0fa0, 0x1c001e35, 0x2153235a, 0x28000108,   // lv.ms.yo_322 ms.id.un_A90  ca.ht.jw_553 en.sw.un_430
  // [7570]
  0x3f1f0208, 0x0603010c, 0x21532307, 0x17111e0c,   // da.cy.af_443 en.nl.de_543  ca.ht.jw_432 ms.ro.sr_543
  0x0000172d, 0x070a17a6, 0x121b13a9, 0x352855ac,   // sr.un.un_A00 sr.mk.bg_521  et.tr.hu_544 rw.sw.zu_632
  0x25351907, 0x033f04ee, 0x10000402, 0x21235312,   // gl.zu.eu_432 fi.af.nl_422  ru.be.un_220 ht.ca.jw_654
  0x1b25010c, 0x532305af, 0x04250107, 0x1c25210c,   // en.eu.tr_543 fr.ca.ht_655  en.eu.fi_432 jw.eu.id_543
  // [7580]
  0x16296b0c, 0x1a001e0d, 0x01056404, 0x1f013fa9,   // ceb.sl.hr_543 ms.tl.un_540  lg.fr.en_332 af.en.cy_544
  0x11191fa0, 0x0c1306a7, 0x114a16a4, 0x28023b04,   // cy.gl.ro_322 de.et.sv_532  hr.yo.ro_433 so.da.sw_332
  0x2a000307, 0x3f001204, 0x0700100b, 0x13002a07,   // nl.mt.un_420 hu.af.un_320  be.bg.un_520 mt.et.un_420
  0x52001707, 0x2b321602, 0x12311b12, 0x2731250c,   // sr.ha.un_420 hr.bs.vi_222  tr.az.hu_654 eu.az.gd_543
  // [7590]
  0x3f4a130b, 0x03060107, 0x060405ec, 0x6b53010c,   // et.yo.af_542 en.de.nl_432  fr.fi.de_644 en.ht.ceb_543
  0x3f0b0a02, 0x070804a7, 0x272818a4, 0x033f2505,   // pt.es.af_222 ru.uk.bg_532  ga.sw.gd_433 eu.af.nl_333
  0x21531c0c, 0x051201a0, 0x1c110605, 0x12003505,   // id.ht.jw_543 en.hu.fr_322  de.ro.id_333 zu.hu.un_330
  0x20003102, 0x18280a0c, 0x3f1368ee, 0x3f030ba9,   // az.sq.un_220 pt.sw.ga_543  ig.et.af_422 es.nl.af_544
  // [75a0]
  0x0f00290d, 0x130b3b0c, 0x0b003b08, 0x11323b07,   // sl.lv.un_540 so.es.et_543  so.es.un_430 so.bs.ro_432
  0x170711ee, 0x0b643ba0, 0x23033f08, 0x11063f5a,   // ro.bg.sr_422 so.lg.es_322  af.nl.ca_443 af.de.ro_553
  0x32286811, 0x231e1ca4, 0x11072aa0, 0x3b230b08,   // ig.sw.bs_653 id.ms.ca_433  mt.it.ro_322 es.ca.so_443
  0x231907ad, 0x0e030808, 0x3f00011a, 0x0a17105a,   // it.gl.ca_643 no.nl.is_443  en.af.un_760 be.sr.mk_553
  // [75b0]
  0x3b2319ec, 0x07050b08, 0x0c080a08, 0x3b092aa0,   // gl.ca.so_644 es.fr.it_443  pt.no.sv_443 mt.pl.so_322
  0x0a000808, 0x135201a4, 0x0c130808, 0x1b2153ee,   // no.pt.un_430 en.ha.et_433  no.et.sv_443 ht.jw.tr_422
  0x321611a9, 0x1b536b09, 0x32291612, 0x02080c5a,   // ro.hr.bs_544 ceb.ht.tr_444  hr.sl.bs_654 sv.no.da_553
  0x35285511, 0x1b00351a, 0x13002811, 0x28000413,   // rw.sw.zu_653 zu.tr.un_760  sw.et.un_630 fi.sw.un_650
  // [75c0]
  0x03130f05, 0x321b3512, 0x2d0d2714, 0x31053ba0,   // lv.et.nl_333 zu.tr.bs_654  gd.cs.sk_666 so.fr.az_322
  0x321827a9, 0x181f2760, 0x532a2807, 0x06006e0c,   // gd.ga.bs_544 gd.cy.ga_664  sw.mt.ht_432 hmn.de.un_530
  0x0b011904, 0x31003b02, 0x0e1219a7, 0x05002008,   // gl.en.es_332 so.az.un_220  gl.hu.is_532 sq.fr.un_430
  0x3f2823ee, 0x014a1905, 0x20123204, 0x1200190c,   // ca.sw.af_422 gl.yo.en_333  bs.hu.sq_332 gl.hu.un_530
  // [75d0]
  0x282d0d0e, 0x11311b0d, 0x09292d04, 0x10170408,   // cs.sk.sw_555 tr.az.ro_554  sk.sl.pl_332 ru.sr.be_443
  0x07251904, 0x2b001b07, 0x4a1e1c09, 0x3f001005,   // gl.eu.it_332 tr.vi.un_420  id.ms.yo_444 lt.af.un_330
  0x122d0ca4, 0x18023b02, 0x2d060d0c, 0x062b0aa0,   // sv.sk.hu_433 so.da.ga_222  cs.de.sk_543 pt.vi.de_322
  0x07002502, 0x0d285507, 0x18003b13, 0x04113b0c,   // eu.it.un_220 rw.sw.cs_432  so.ga.un_650 so.ro.fi_543
  // [75e0]
  0x0b0a4aa4, 0x2d0928a7, 0x3f021002, 0x280503a6,   // yo.pt.es_433 sw.pl.sk_532  lt.da.af_222 nl.fr.sw_521
  0x3b2718a9, 0x29101704, 0x281825a0, 0x21005509,   // ga.gd.so_544 sr.lt.sl_332  eu.ga.sw_322 rw.jw.un_440
  0x21355507, 0x0a002504, 0x25190a5a, 0x292d0da0,   // rw.zu.jw_432 eu.pt.un_320  pt.gl.eu_553 cs.sk.sl_322
  0x18061fee, 0x232507a7, 0x5500640b, 0x55004a0c,   // cy.de.ga_422 it.eu.ca_532  lg.rw.un_520 yo.rw.un_530
  // [75f0]
  0x31001234, 0x2d000d33, 0x0628530c, 0x0364550c,   // hu.az.un_A80 cs.sk.un_A70  ht.sw.de_543 rw.lg.nl_543
  0x0a000d04, 0x2155280d, 0x03005208, 0x0f64130d,   // cs.pt.un_320 sw.rw.jw_554  ha.nl.un_430 et.lg.lv_554
  0x556b2da9, 0x28550613, 0x32162014, 0x060d12a4,   // sk.ceb.rw_544 de.rw.sw_665  sq.hr.bs_666 hu.cs.de_433
  0x0c1604a4, 0x062d0704, 0x0d0c2da4, 0x553228ad,   // fi.hr.sv_433 it.sk.de_332  sk.sv.cs_433 sw.bs.rw_643
  // [7600]
  0x13042007, 0x0e006405, 0x2300270e, 0x086431a4,   // sq.fi.et_432 lg.is.un_330  gd.ca.un_550 az.lg.no_433
  0x0e000c02, 0x64010ba0, 0x552109ec, 0x216b1c0c,   // sv.is.un_220 es.en.lg_322  pl.jw.rw_644 id.ceb.jw_543
  0x13006408, 0x2d0d12bb, 0x250b0a04, 0x0811175a,   // lg.et.un_430 hu.cs.sk_854  pt.es.eu_332 sr.ro.uk_553
  0x07120ca0, 0x0832165a, 0x3f000609, 0x321620ec,   // sv.hu.it_322 hr.bs.no_553  de.af.un_440 sq.hr.bs_644
  // [7610]
  0x200b29a4, 0x10041b04, 0x23002710, 0x32162a0e,   // sl.es.sq_433 tr.fi.lt_332  gd.ca.un_620 mt.hr.bs_555
  0x2a2d0da4, 0x122a0704, 0x12072a09, 0x25283507,   // cs.sk.mt_433 it.mt.hu_332  mt.it.hu_444 zu.sw.eu_432
  0x25350da4, 0x35642512, 0x64531713, 0x07122a11,   // cs.zu.eu_433 eu.lg.zu_654  sr.ht.lg_665 mt.hu.it_653
  0x3f000622, 0x532123a7, 0x1a2835a0, 0x105525ac,   // de.af.un_870 ca.jw.ht_532  zu.sw.tl_322 eu.rw.lt_632
  // [7620]
  0x645525af, 0x64253508, 0x29000405, 0x042d1755,   // eu.rw.lg_655 zu.eu.lg_443  fi.sl.un_330 sr.sk.fi_442
  0x3f0429a4, 0x271f6402, 0x08021f04, 0x01070504,   // sl.fi.af_433 lg.cy.gd_222  cy.da.no_332 fr.it.en_332
  0x551135ec, 0x1c2d25a0, 0x12000d0c, 0x20311a07,   // zu.ro.rw_644 eu.sk.id_322  cs.hu.un_530 tl.az.sq_432
  0x0d002704, 0x352129a6, 0x0f002912, 0x351f06a4,   // gd.cs.un_320 sl.jw.zu_521  sl.lv.un_640 de.cy.zu_433
  // [7630]
  0x033f020d, 0x12000d19, 0x3f64030d, 0x6b1a0ba9,   // da.af.nl_554 cs.hu.un_750  nl.lg.af_554 es.tl.ceb_544
  0x28355509, 0x27005319, 0x53355555, 0x0b005304,   // rw.zu.sw_444 ht.gd.un_750  rw.zu.ht_442 ht.es.un_320
  0x06002d07, 0x06040c0d, 0x23002105, 0x18000e12,   // sk.de.un_420 sv.fi.de_554  jw.ca.un_330 is.ga.un_640
  0x4a003b05, 0x64211aee, 0x556853a9, 0x112155af,   // so.yo.un_330 tl.jw.lg_422  ht.ig.rw_544 rw.jw.ro_655
  // [7640]
  0x6b001a2c, 0x05002013, 0x231152a4, 0x35531aaf,   // tl.ceb.un_990 sq.fr.un_650  ha.ro.ca_433 tl.ht.zu_655
  0x07115555, 0x52553508, 0x6453350d, 0x19230907,   // rw.ro.it_442 zu.rw.ha_443  zu.ht.lg_554 pl.ca.gl_432
  0x0c0d060c, 0x17001105, 0x2000642b, 0x321609ee,   // de.cs.sv_543 ro.sr.un_330  lg.sq.un_980 pl.hr.bs_422
  0x0b0a0605, 0x13001c11, 0x35646807, 0x0b112355,   // de.pt.es_333 mr.bh.un_630  ig.lg.zu_432 ca.ro.es_442
  // [7650]
  0x2b640107, 0x1b00041a, 0x111c1e0c, 0x31003b04,   // en.lg.vi_432 fi.tr.un_760  ms.id.ro_543 so.az.un_320
  0x3b001a36, 0x1607280c, 0x0b2a19af, 0x640d01ec,   // tl.so.un_AA0 sw.it.hr_543  gl.mt.es_655 en.cs.lg_644
  0x0e0320ee, 0x1f00202a, 0x313b64ad, 0x55001b0e,   // sq.nl.is_422 sq.cy.un_970  lg.so.az_643 tr.rw.un_550
  0x211c0aa0, 0x0e002a04, 0x09001908, 0x120d2902,   // pt.id.jw_322 mt.is.un_320  gl.pl.un_430 sl.cs.hu_222
  // [7660]
  0x07062a12, 0x043f55ad, 0x1f003f36, 0x230f09ee,   // mt.de.it_654 rw.af.fi_643  af.cy.un_AA0 pl.lv.ca_422
  0x31091b55, 0x1e1b2005, 0x1c213512, 0x09072a11,   // tr.pl.az_442 sq.tr.ms_333  zu.jw.id_654 mt.it.pl_653
  0x3f1f0955, 0x55002702, 0x20002b0d, 0x55004a07,   // pl.cy.af_442 gd.rw.un_220  vi.sq.un_540 yo.rw.un_420
  0x1a6b2ba7, 0x2000530e, 0x35135304, 0x070a100e,   // vi.ceb.tl_532 ht.sq.un_550  ht.et.zu_332 be.mk.bg_555
  // [7670]
  0x16133207, 0x4a0912ad, 0x20001604, 0x23002112,   // bs.et.hr_432 hu.pl.yo_643  hr.sq.un_320 jw.ca.un_640
  0x1c130daf, 0x1e1c2802, 0x2b000a02, 0x0b005305,   // ne.bh.mr_655 sw.id.ms_222  pt.vi.un_220 ht.es.un_330
  0x0e001709, 0x21235304, 0x2d190b0c, 0x080221a0,   // sr.is.un_440 ht.ca.jw_332  es.gl.sk_543 jw.da.no_322
  0x352011ad, 0x032b0504, 0x21231702, 0x19251004,   // ro.sq.zu_643 fr.vi.nl_332  sr.ca.jw_222 lt.eu.gl_332
  // [7680]
  0x28000a04, 0x110f0aa4, 0x06081f04, 0x53002305,   // pt.sw.un_320 pt.lv.ro_433  cy.no.de_332 ca.ht.un_330
  0x2d200f02, 0x3b6b1a12, 0x2b001a02, 0x1a353b07,   // lv.sq.sk_222 tl.ceb.so_654  tl.vi.un_220 so.zu.tl_432
  0x6b5528a7, 0x16001008, 0x120d2dec, 0x521a6bad,   // sw.rw.ceb_532 lt.hr.un_430  sk.cs.hu_644 ceb.tl.ha_643
  0x0b190a08, 0x6b553507, 0x193b0ba0, 0x645355a4,   // pt.gl.es_443 zu.rw.ceb_432  es.so.gl_322 rw.ht.lg_433
  // [7690]
  0x533b1bee, 0x64005212, 0x1a6b64a4, 0x351c1eec,   // tr.so.ht_422 ha.lg.un_640  lg.ceb.tl_433 ms.id.zu_644
  0x09001e04, 0x64551ba0, 0x10082aad, 0x1b6b0ba4,   // ms.pl.un_320 tr.rw.lg_322  mt.no.lt_643 es.ceb.tr_433
  0x21001a0d, 0x071f1008, 0x5307210c, 0x233b270c,   // tl.jw.un_540 lt.cy.it_443  jw.it.ht_543 gd.so.ca_543
  0x09123507, 0x0b0e18a4, 0x20050c04, 0x23193504,   // zu.hu.pl_432 ga.is.es_433  sv.fr.sq_332 zu.gl.ca_332
  // [76a0]
  0x0621090c, 0x080206ec, 0x1b001a12, 0x536421a0,   // pl.jw.de_543 de.da.no_644  tl.tr.un_640 jw.lg.ht_322
  0x09536404, 0x21121005, 0x0a000823, 0x28554aa4,   // lg.ht.pl_332 lt.hu.jw_333  uk.mk.un_880 yo.rw.sw_433
  0x53250107, 0x1a0510a4, 0x2128555a, 0x1b2731ee,   // en.eu.ht_432 lt.fr.tl_433  rw.sw.jw_553 az.gd.tr_422
  0x35523b07, 0x3b002a14, 0x071b0513, 0x052918a0,   // so.ha.zu_432 mt.so.un_660  fr.tr.it_665 ga.sl.fr_322
  // [76b0]
  0x01005502, 0x0e12040e, 0x3f000913, 0x04132a14,   // rw.en.un_220 fi.hu.is_555  pl.af.un_650 mt.et.fi_666
  0x120f0e07, 0x130210ad, 0x05006b04, 0x0c061b04,   // is.lv.hu_432 lt.da.et_643  ceb.fr.un_320 tr.de.sv_332
  0x03003f0b, 0x1001230c, 0x030110a7, 0x08022305,   // af.nl.un_520 ca.en.lt_543  lt.en.nl_532 ca.da.no_333
  0x11033fa4, 0x3f000904, 0x0f002312, 0x030523a0,   // af.nl.ro_433 pl.af.un_320  ca.lv.un_640 ca.fr.nl_322
  // [76c0]
  0x23000f05, 0x12000c09, 0x132a01a4, 0x0a1707ee,   // lv.ca.un_330 sv.hu.un_440  en.mt.et_433 bg.sr.mk_422
  0x0700080d, 0x12000605, 0x3b170aee, 0x5229280e,   // uk.bg.un_540 de.hu.un_330  pt.sr.so_422 sw.sl.ha_555
  0x271828a0, 0x35191f04, 0x2b002704, 0x18072b04,   // sw.ga.gd_322 cy.gl.zu_332  gd.vi.un_320 vi.it.ga_332
  0x0307090c, 0x1c00310c, 0x21286ba0, 0x130e28a4,   // pl.it.nl_543 az.id.un_530  ceb.sw.jw_322 sw.is.et_433
  // [76d0]
  0x16352811, 0x211355ec, 0x52350ea4, 0x35002818,   // sw.zu.hr_653 rw.et.jw_644  is.zu.ha_433 sw.zu.un_740
  0x1b1153a4, 0x203f4a05, 0x53001c0d, 0x25290f12,   // ht.ro.tr_433 yo.af.sq_333  id.ht.un_540 lv.sl.eu_654
  0x0e642807, 0x04643ba0, 0x641a2108, 0x112307ad,   // sw.lg.is_432 so.lg.fi_322  jw.tl.lg_443 it.ca.ro_643
  0x6435230c, 0x27190ba7, 0x0121190c, 0x120e090c,   // ca.zu.lg_543 es.gl.gd_532  gl.jw.en_543 pl.is.hu_543
  // [76e0]
  0x4a0a52a9, 0x2718230c, 0x09000c0e, 0x0d000208,   // ha.pt.yo_544 ca.ga.gd_543  sv.pl.un_550 da.cs.un_430
  0x0e3f0308, 0x0f550304, 0x311b55a4, 0x190a2aee,   // nl.af.is_443 nl.rw.lv_332  rw.tr.az_433 mt.pt.gl_422
  0x20230b05, 0x642d35ad, 0x19230b0d, 0x102916a4,   // es.ca.sq_333 zu.sk.lg_643  es.ca.gl_554 hr.sl.lt_433
  0x1600680d, 0x171e1c04, 0x2120230b, 0x31003b0e,   // ig.hr.un_540 id.ms.sr_332  ca.sq.jw_542 so.az.un_550
  // [76f0]
  0x2d171605, 0x12200eec, 0x07285504, 0x1000082c,   // hr.sr.sk_333 is.sq.hu_644  rw.sw.it_332 uk.be.un_990
  0x17002008, 0x1f002307, 0x20063f09, 0x230a01a0,   // sq.sr.un_430 ca.cy.un_420  af.de.sq_444 en.pt.ca_322
  0x27090704, 0x060c02a0, 0x04080307, 0x170d09a4,   // it.pl.gd_332 da.sv.de_322  nl.no.fi_432 pl.cs.sr_433
  0x09003b02, 0x01093b0b, 0x0a1108ec, 0x06000102,   // so.pl.un_220 so.pl.en_542  uk.ro.mk_644 en.de.un_220
  // [7700]
  0x08550e02, 0x2a001708, 0x07002813, 0x3b002020,   // is.rw.no_222 sr.mt.un_430  sw.it.un_650 sq.so.un_850
  0x0e080c0d, 0x1e19010c, 0x12003f09, 0x0e121ba9,   // sv.no.is_554 en.gl.ms_543  af.hu.un_440 tr.hu.is_544
  0x03280f0b, 0x55000819, 0x1a0b530b, 0x02000702,   // lv.sw.nl_542 no.rw.un_750  ht.es.tl_542 it.da.un_220
  0x070601a0, 0x4a00181a, 0x12182107, 0x64093555,   // en.de.it_322 ga.yo.un_760  fa.ar.ur_432 zu.pl.lg_442
  // [7710]
  0x210908a0, 0x2b00200c, 0x0a1708a0, 0x23251914,   // no.pl.jw_322 sq.vi.un_530  uk.sr.mk_322 gl.eu.ca_666
  0x0f041311, 0x050607a0, 0x1206250c, 0x3b133f02,   // et.fi.lv_653 it.de.fr_322  eu.de.hu_543 af.et.so_222
  0x022008a4, 0x1c3521ad, 0x040625ac, 0x080e1207,   // no.sq.da_433 jw.zu.id_643  eu.de.fi_632 hu.is.no_432
  0x043f1313, 0x2a071baf, 0x1e1c0eee, 0x06000704,   // et.af.fi_665 tr.it.mt_655  is.id.ms_422 it.de.un_320
  // [7720]
  0x3f64040c, 0x01003b12, 0x6b0820ee, 0x1c1e3b07,   // fi.lg.af_543 so.en.un_640  sq.no.ceb_422 so.ms.id_432
  0x1e000e13, 0x1f251304, 0x231f0e07, 0x20003507,   // is.ms.un_650 et.eu.cy_332  is.cy.ca_432 zu.sq.un_420
  0x322a0f07, 0x011c0ea7, 0x0a0411ec, 0x0c100408,   // lv.mt.bs_432 is.id.en_532  ro.ru.mk_644 fi.lt.sv_443
  0x642a07af, 0x11170a0c, 0x070653a0, 0x3f3b01a0,   // it.mt.lg_655 mk.sr.ro_543  ht.de.it_322 en.so.af_322
  // [7730]
  0x041301a0, 0x6b001319, 0x2a006413, 0x1a086b0c,   // en.et.fi_322 et.ceb.un_750  lg.mt.un_650 ceb.no.tl_543
  0x08210eee, 0x2a1101a0, 0x11020807, 0x2a00641b,   // is.jw.no_422 en.ro.mt_322  no.da.ro_432 lg.mt.un_770
  0x252a5312, 0x1f180e0c, 0x1a6b0b04, 0x17001307,   // ht.mt.eu_654 is.ga.cy_543  es.ceb.tl_332 et.sr.un_420
  0x3f000a07, 0x3f3511a4, 0x3b000e02, 0x162910a0,   // pt.af.un_420 ro.zu.af_433  is.so.un_220 lt.sl.hr_322
  // [7740]
  0x060805a4, 0x3f000214, 0x3f1a6b5a, 0x13035307,   // fr.no.de_433 da.af.un_660  ceb.tl.af_553 ht.nl.et_432
  0x18080c07, 0x11001302, 0x53000607, 0x200111ec,   // sv.no.ga_432 et.ro.un_220  de.ht.un_420 ro.en.sq_644
  0x071711ec, 0x321710ee, 0x162d1007, 0x19072313,   // ro.sr.bg_644 lt.sr.bs_422  lt.sk.hr_432 ca.it.gl_665
  0x06351f0c, 0x64185255, 0x645328ee, 0x12100fa9,   // cy.zu.de_543 ha.ga.lg_442  sw.ht.lg_422 lv.lt.hu_544
  // [7750]
  0x2505350c, 0x131911ad, 0x03001112, 0x2a006b04,   // zu.fr.eu_543 ro.gl.et_643  ro.nl.un_640 ceb.mt.un_320
  0x13553511, 0x131102ee, 0x17162da6, 0x023f0613,   // zu.rw.et_653 da.ro.et_422  sk.hr.sr_521 de.af.da_665
  0x130e35ee, 0x1a006b2c, 0x131108a4, 0x01110808,   // zu.is.et_422 ceb.tl.un_990  no.ro.et_433 no.ro.en_443
  0x27063fa7, 0x6b183b05, 0x1f093f0c, 0x182705a7,   // af.de.gd_532 so.ga.ceb_333  af.pl.cy_543 fr.gd.ga_532
  // [7760]
  0x3b002509, 0x08020614, 0x28003205, 0x13311bee,   // eu.so.un_440 de.da.no_666  bs.sw.un_330 tr.az.et_422
  0x17102aa4, 0x2d17290c, 0x0e0313a4, 0x130407a0,   // mt.lt.sr_433 sl.sr.sk_543  et.nl.is_433 it.fi.et_322
  0x020313ee, 0x64003523, 0x17070aac, 0x0829210c,   // et.nl.da_422 zu.lg.un_880  mk.bg.sr_632 jw.sl.no_543
  0x64130307, 0x13002818, 0x10001213, 0x0e00050d,   // nl.et.lg_432 sw.et.un_740  hu.lt.un_650 fr.is.un_540
  // [7770]
  0x0c070809, 0x64322808, 0x08010304, 0x550e3507,   // no.it.sv_444 sw.bs.lg_443  nl.en.no_332 zu.is.rw_432
  0x35530b04, 0x1000070e, 0x081b12a7, 0x0c100f05,   // es.ht.zu_332 bg.be.un_550  hu.tr.no_532 lv.lt.sv_333
  0x0c060e0e, 0x04060e0c, 0x130e10a4, 0x1a3f0355,   // is.de.sv_555 is.de.fi_543  lt.is.et_433 nl.af.tl_442
  0x0332165a, 0x1b132109, 0x32281609, 0x20046b04,   // hr.bs.nl_553 jw.et.tr_444  hr.sw.bs_444 ceb.fi.sq_332
  // [7780]
  0x311b0ea9, 0x13002109, 0x1b210e08, 0x0e100c04,   // is.tr.az_544 jw.et.un_440  is.jw.tr_443 sv.lt.is_332
  0x3f2d0d13, 0x0809130c, 0x0e20080c, 0x35641ba0,   // cs.sk.af_665 et.pl.no_543  no.sq.is_543 tr.lg.zu_322
  0x132d0d55, 0x1a1b3108, 0x316b0d07, 0x6b31210c,   // cs.sk.et_442 az.tr.tl_443  cs.ceb.az_432 jw.az.ceb_543
  0x04000912, 0x0d202d0c, 0x040820a9, 0x0e002013,   // pl.fi.un_640 sk.sq.cs_543  sq.no.fi_544 sq.is.un_650
  // [7790]
  0x036b07a0, 0x07100812, 0x25001f21, 0x07002705,   // it.ceb.nl_322 uk.be.bg_654  cy.eu.un_860 gd.it.un_330
  0x3f1807a0, 0x0e180804, 0x0c6402af, 0x2d180dec,   // it.ga.af_322 no.ga.is_332  da.lg.sv_655 cs.ga.sk_644
  0x060f0804, 0x0c1f640c, 0x64001f18, 0x52006413,   // no.lv.de_332 lg.cy.sv_543  cy.lg.un_740 lg.ha.un_650
  0x1700060c, 0x0800061a, 0x523b64af, 0x09062a0c,   // de.sr.un_530 de.no.un_760  lg.so.ha_655 mt.de.pl_543
  // [77a0]
  0x3f000312, 0x060935ec, 0x355268a4, 0x01643ba4,   // nl.af.un_640 zu.pl.de_644  ig.ha.zu_433 so.lg.en_433
  0x033f01ad, 0x3b352aa4, 0x25006421, 0x4a002814,   // en.af.nl_643 mt.zu.so_433  lg.eu.un_860 sw.yo.un_660
  0x27111855, 0x016b0404, 0x68136404, 0x31051ba7,   // ga.ro.gd_442 fi.ceb.en_332  lg.et.ig_332 tr.fr.az_532
  0x091264a7, 0x080c1fac, 0x3b1e250b, 0x27000702,   // lg.hu.pl_532 cy.sv.no_632  eu.ms.so_542 it.gd.un_220
  // [77b0]
  0x13182760, 0x0c04080c, 0x0c0b64ee, 0x3b4a6407,   // gd.ga.et_664 no.fi.sv_543  lg.es.sv_422 lg.yo.so_432
  0x532811ec, 0x64021f0c, 0x556b1aad, 0x52080c14,   // ro.sw.ht_644 cy.da.lg_543  tl.ceb.rw_643 sv.no.ha_666
  0x2a006422, 0x0c002507, 0x11001a02, 0x093b060c,   // lg.mt.un_870 eu.sv.un_420  tl.ro.un_220 de.so.pl_543
  0x061335a0, 0x6400281a, 0x20100fee, 0x08130e11,   // zu.et.de_322 sw.lg.un_760  lv.lt.sq_422 is.et.no_653
  // [77c0]
  0x1c351e07, 0x270364ee, 0x643528a4, 0x04132509,   // ms.zu.id_432 lg.nl.gd_422  sw.zu.lg_433 eu.et.fi_444
  0x04134a04, 0x17161e02, 0x0d190aee, 0x1b115302,   // yo.et.fi_332 ms.hr.sr_222  pt.gl.cs_422 ht.ro.tr_222
  0x11003204, 0x1b006e13, 0x3f0623a7, 0x0628640d,   // bs.ro.un_320 hmn.tr.un_650  ca.de.af_532 lg.sw.de_554
  0x02033504, 0x05230fa7, 0x550628a7, 0x3b28530c,   // zu.nl.da_332 lv.ca.fr_532  sw.de.rw_532 ht.sw.so_543
  // [77d0]
  0x1e121a12, 0x13321708, 0x03233f04, 0x1b001113,   // tl.hu.ms_654 sr.bs.et_443  af.ca.nl_332 ro.tr.un_650
  0x0e00020c, 0x3f1702a0, 0x0b002a05, 0x3b00280d,   // da.is.un_530 da.sr.af_322  mt.es.un_330 sw.so.un_540
  0x643531a4, 0x530d05ad, 0x0c5564ac, 0x1c213b0e,   // az.zu.lg_433 fr.cs.ht_643  lg.rw.sv_632 so.jw.id_555
  0x2331100c, 0x0d011104, 0x25215204, 0x12002702,   // lt.az.ca_543 ro.en.cs_332  ha.jw.eu_332 gd.hu.un_220
  // [77e0]
  0x530501af, 0x3b4a01a0, 0x10091a0c, 0x0700290c,   // en.fr.ht_655 en.yo.so_322  tl.pl.lt_543 sl.it.un_530
  0x2300190e, 0x02003207, 0x1e64520c, 0x1c28210c,   // gl.ca.un_550 bs.da.un_420  ha.lg.ms_543 jw.sw.id_543
  0x53001007, 0x2d0d19a4, 0x4a062a55, 0x19070b07,   // lt.ht.un_420 gl.cs.sk_433  mt.de.yo_442 es.it.gl_432
  0x204a6412, 0x05000f13, 0x1f114a07, 0x2500552a,   // lg.yo.sq_654 lv.fr.un_650  yo.ro.cy_432 rw.eu.un_970
  // [77f0]
  0x0f00230e, 0x0c64040c, 0x080220a4, 0x10000e0e,   // ca.lv.un_550 fi.lg.sv_543  sq.da.no_433 is.lt.un_550
  0x0f0523a0, 0x250704a0, 0x0f23050c, 0x06003513,   // ca.fr.lv_322 fi.it.eu_322  fr.ca.lv_543 zu.de.un_650
  0x02202508, 0x0f0523ee, 0x3f2520ee, 0x05000f02,   // eu.sq.da_443 ca.fr.lv_422  sq.eu.af_422 lv.fr.un_220
  0x01000f05, 0x023b3f5a, 0x07003512, 0x64000219,   // lv.en.un_330 af.so.da_553  zu.it.un_640 da.lg.un_750

  // [7800]
  0x250855a4, 0x3f133ba7, 0x642701a4, 0x64003b07,   // rw.no.eu_433 so.et.af_532  en.gd.lg_433 so.lg.un_420
  0x033b0107, 0x285368ec, 0x6400030e, 0x0200531b,   // en.so.nl_432 ig.ht.sw_644  nl.lg.un_550 ht.da.un_770
  0x291610a4, 0x010c0804, 0x2a0c0eee, 0x01080c04,   // lt.hr.sl_433 no.sv.en_332  is.sv.mt_422 sv.no.en_332
  0x3f3b13a0, 0x120806a0, 0x3f253b12, 0x1b005307,   // et.so.af_322 de.no.hu_322  so.eu.af_654 ht.tr.un_420
  // [7810]
  0x0c002a04, 0x133f0a07, 0x2b006404, 0x2b000507,   // mt.sv.un_320 pt.af.et_432  lg.vi.un_320 fr.vi.un_420
  0x2b000519, 0x552b0508, 0x040711a0, 0x28532a0c,   // fr.vi.un_750 fr.vi.rw_443  ro.bg.ru_322 mt.ht.sw_543
  0x2300530e, 0x120e4a04, 0x01003b07, 0x05002b02,   // ht.ca.un_550 yo.is.hu_332  so.en.un_420 vi.fr.un_220
  0x643555a0, 0x12002b07, 0x120b0a05, 0x5535280e,   // rw.zu.lg_322 vi.hu.un_420  pt.es.hu_333 sw.zu.rw_555
  // [7820]
  0x05011fa4, 0x03050604, 0x100817ee, 0x31000108,   // cy.en.fr_433 de.fr.nl_332  sr.uk.be_422 en.az.un_430
  0x13091c5a, 0x0e001c08, 0x120610a0, 0x1b000f0c,   // mr.hi.bh_553 id.is.un_430  lt.de.hu_322 lv.tr.un_530
  0x28001f07, 0x212a6813, 0x101b2aee, 0x012d07a0,   // cy.sw.un_420 ig.mt.jw_665  mt.tr.lt_422 it.sk.en_322
  0x096813a0, 0x3f080e07, 0x312a2804, 0x0a011107,   // et.ig.pl_322 is.no.af_432  sw.mt.az_332 ro.en.pt_432
  // [7830]
  0x23002008, 0x23271fee, 0x4a2568ad, 0x01212302,   // sq.ca.un_430 cy.gd.ca_422  ig.eu.yo_643 ca.jw.en_222
  0x6b0118a0, 0x1b001f20, 0x311f3ba9, 0x05000307,   // ga.en.ceb_322 cy.tr.un_850  so.cy.az_544 nl.fr.un_420
  0x35005305, 0x53232005, 0x32044a02, 0x1a00030d,   // ht.zu.un_330 sq.ca.ht_333  yo.fi.bs_222 nl.tl.un_540
  0x04002004, 0x100f3b14, 0x1b1321a4, 0x08000908,   // sq.fi.un_320 so.lv.lt_666  jw.et.tr_433 pl.no.un_430
  // [7840]
  0x0411130b, 0x170429a0, 0x100e0f07, 0x0d190a02,   // et.ro.fi_542 sl.fi.sr_322  lv.is.lt_432 pt.gl.cs_222
  0x130c0107, 0x320413ee, 0x3f08130b, 0x0e00080d,   // en.sv.et_432 et.fi.bs_422  et.no.af_542 no.is.un_540
  0x5200252a, 0x180e090c, 0x110510a0, 0x2b002d07,   // eu.ha.un_970 pl.is.ga_543  lt.fr.ro_322 sk.vi.un_420
  0x10000f2b, 0x0c005207, 0x0c0f0e08, 0x254a550c,   // lv.lt.un_980 ha.sv.un_420  is.lv.sv_443 rw.yo.eu_543
  // [7850]
  0x25001f1a, 0x2d0d0ea0, 0x0811040e, 0x13002522,   // cy.eu.un_760 is.cs.sk_322  ru.ro.uk_555 eu.et.un_870
  0x070c04a4, 0x10000604, 0x1b0a010c, 0x1008130c,   // fi.sv.it_433 de.lt.un_320  en.pt.tr_543 et.no.lt_543
  0x32162914, 0x28010302, 0x2d0d08a0, 0x04005513,   // sl.hr.bs_666 nl.en.sw_222  no.cs.sk_322 rw.fi.un_650
  0x53281805, 0x64280fad, 0x2a00071a, 0x0d001320,   // ga.sw.ht_333 lv.sw.lg_643  it.mt.un_760 bh.ne.un_850
  // [7860]
  0x12000202, 0x0e080207, 0x256452ec, 0x166425ad,   // da.hu.un_220 da.no.is_432  ha.lg.eu_644 eu.lg.hr_643
  0x6b64250c, 0x28001805, 0x64105502, 0x21002502,   // eu.lg.ceb_543 ga.sw.un_330  rw.lt.lg_222 eu.jw.un_220
  0x64042dee, 0x64256b11, 0x25096407, 0x556425af,   // sk.fi.lg_422 ceb.eu.lg_653  lg.pl.eu_432 eu.lg.rw_655
  0x04001602, 0x556425ec, 0x1e120da0, 0x0000252d,   // hr.fi.un_220 eu.lg.rw_644  cs.hu.ms_322 eu.un.un_A00
  // [7870]
  0x6400252b, 0x64251008, 0x030806a0, 0x2900251a,   // eu.lg.un_980 lt.eu.lg_443  de.no.nl_322 eu.sl.un_760
  0x28520e0d, 0x06041f04, 0x3b526ba9, 0x11005205,   // is.ha.sw_554 cy.fi.de_332  ceb.ha.so_544 ha.ro.un_330
  0x1300352b, 0x2d0d280c, 0x52681ea9, 0x6b3b25a9,   // zu.et.un_980 sw.cs.sk_543  ms.ig.ha_544 eu.so.ceb_544
  0x231f06ad, 0x21005205, 0x3b00640e, 0x52551ba9,   // de.cy.ca_643 ha.jw.un_330  lg.so.un_550 tr.rw.ha_544
  // [7880]
  0x28354a08, 0x551a35a4, 0x05182704, 0x1c1e0804,   // yo.zu.sw_443 zu.tl.rw_433  gd.ga.fr_332 no.ms.id_332
  0x130435ac, 0x1f000a0c, 0x6800522c, 0x31000a07,   // zu.fi.et_632 pt.cy.un_530  ha.ig.un_990 pt.az.un_420
  0x05011a0d, 0x13251012, 0x521a28a9, 0x253506ad,   // tl.en.fr_554 lt.eu.et_654  sw.tl.ha_544 de.zu.eu_643
  0x23010508, 0x280911ac, 0x0c2708a4, 0x0d0c13a7,   // fr.en.ca_443 ro.pl.sw_632  no.gd.sv_433 et.sv.cs_532
  // [7890]
  0x532128ad, 0x0802280c, 0x10001105, 0x183b2712,   // sw.jw.ht_643 sw.da.no_543  ro.be.un_330 gd.so.ga_654
  0x0d062d0c, 0x1a0d3f02, 0x2706180c, 0x09006e0c,   // sk.de.cs_543 af.cs.tl_222  ga.de.gd_543 hmn.pl.un_530
  0x31001f12, 0x08021205, 0x25000305, 0x043f3ba4,   // cy.az.un_640 hu.da.no_333  nl.eu.un_330 so.af.fi_433
  0x0e000704, 0x19043b08, 0x29130407, 0x12000208,   // it.is.un_320 so.fi.gl_443  fi.et.sl_432 da.hu.un_430
  // [78a0]
  0x04033f02, 0x31021b55, 0x0c1a120c, 0x182704a4,   // af.nl.fi_222 tr.da.az_442  hu.tl.sv_543 fi.gd.ga_433
  0x1f0e0cee, 0x0f002918, 0x0c0820a4, 0x1329040c,   // sv.is.cy_422 sl.lv.un_740  sq.no.sv_433 fi.sl.et_543
  0x1f080213, 0x12090804, 0x2700310c, 0x2a005223,   // da.no.cy_665 no.pl.hu_332  az.gd.un_530 ha.mt.un_880
  0x12131108, 0x10120807, 0x0d0a0e04, 0x08130c12,   // ro.et.hu_443 no.hu.lt_432  is.pt.cs_332 sv.et.no_654
  // [78b0]
  0x29001309, 0x0e23270c, 0x3f090d12, 0x021f08ec,   // et.sl.un_440 gd.ca.is_543  cs.pl.af_654 no.cy.da_644
  0x12002b1a, 0x53002312, 0x1300101a, 0x08022007,   // vi.hu.un_760 ca.ht.un_640  lt.et.un_760 sq.da.no_432
  0x16130708, 0x03002507, 0x170a0460, 0x12002005,   // it.et.hr_443 eu.nl.un_420  ru.mk.sr_664 sq.hu.un_330
  0x2a001304, 0x0e002512, 0x203f2304, 0x53080c11,   // et.mt.un_320 eu.is.un_640  ca.af.sq_332 sv.no.ht_653
  // [78c0]
  0x17005202, 0x1b523b04, 0x13002504, 0x05550107,   // ha.sr.un_220 so.ha.tr_332  eu.et.un_320 en.rw.fr_432
  0x050720ec, 0x25271855, 0x0535645a, 0x551118a0,   // sq.it.fr_644 ga.gd.eu_442  lg.zu.fr_553 ga.ro.rw_322
  0x0b252005, 0x550705a0, 0x2d120ead, 0x17101104,   // sq.eu.es_333 fr.it.rw_322  is.hu.sk_643 ro.be.sr_332
  0x5500680c, 0x0a5206a4, 0x11201804, 0x0200190d,   // ig.rw.un_530 de.ha.pt_433  ga.sq.ro_332 gl.da.un_540
  // [78d0]
  0x011868ee, 0x290d2aa0, 0x27002007, 0x050820af,   // ig.ga.en_422 mt.cs.sl_322  sq.gd.un_420 sq.no.fr_655
  0x352a5204, 0x5216060c, 0x05001a0b, 0x041827a0,   // ha.mt.zu_332 de.hr.ha_543  tl.fr.un_520 gd.ga.fi_322
  0x03041e04, 0x203f0404, 0x190a5505, 0x1b0629a7,   // ms.fi.nl_332 fi.af.sq_332  rw.pt.gl_333 sl.de.tr_532
  0x0d09290d, 0x554a35a4, 0x060c1905, 0x0d292d0d,   // sl.pl.cs_554 zu.yo.rw_433  gl.sv.de_333 sk.sl.cs_554
  // [78e0]
  0x1220320c, 0x1c181e04, 0x2a35285a, 0x1811230c,   // bs.sq.hu_543 ms.ga.id_332  sw.zu.mt_553 ca.ro.ga_543
  0x27180105, 0x2b002009, 0x25041313, 0x06181f0d,   // en.ga.gd_333 sq.vi.un_440  et.fi.eu_665 cy.ga.de_554
  0x28186bad, 0x231827a9, 0x0a2535a4, 0x180403a0,   // ceb.ga.sw_643 gd.ga.ca_544  zu.eu.pt_433 nl.fi.ga_322
  0x23050b0c, 0x0c0201a4, 0x17001004, 0x18002004,   // es.fr.ca_543 en.da.sv_433  be.sr.un_320 sq.ga.un_320
  // [78f0]
  0x09683507, 0x25355205, 0x13002012, 0x281a0107,   // zu.ig.pl_432 ha.zu.eu_333  sq.et.un_640 en.tl.sw_432
  0x0a002322, 0x250a35a4, 0x08356b07, 0x25003522,   // ca.pt.un_870 zu.pt.eu_433  ceb.zu.no_432 zu.eu.un_870
  0x68003521, 0x2a1a13a0, 0x131935ee, 0x0a17350c,   // zu.ig.un_860 et.tl.mt_322  zu.gl.et_422 zu.sr.pt_543
  0x011e1c07, 0x0c0e3155, 0x1a683512, 0x03321613,   // id.ms.en_432 az.is.sv_442  zu.ig.tl_654 hr.bs.nl_665
  // [7900]
  0x010c2312, 0x6800250c, 0x171b35ac, 0x01230504,   // ca.sv.en_654 eu.ig.un_530  zu.tr.sr_632 fr.ca.en_332
  0x030c1207, 0x08000e02, 0x09005305, 0x6b130c04,   // hu.sv.nl_432 is.no.un_220  ht.pl.un_330 sv.et.ceb_332
  0x2300051b, 0x1e122104, 0x1b0519a7, 0x06350e07,   // fr.ca.un_770 jw.hu.ms_332  gl.fr.tr_532 is.zu.de_432
  0x05230107, 0x55000702, 0x3f000d04, 0x532d0604,   // en.ca.fr_432 it.rw.un_220  cs.af.un_320 de.sk.ht_332
  // [7910]
  0x123f0e05, 0x28355211, 0x120706a0, 0x070a1113,   // is.af.hu_333 ha.zu.sw_653  de.it.hu_322 ro.mk.bg_665
  0x1a005504, 0x132d0904, 0x532d0d05, 0x290913a4,   // rw.tl.un_320 pl.sk.et_332  cs.sk.ht_333 et.pl.sl_433
  0x292d32a0, 0x2d0d10a0, 0x111304a0, 0x06001b02,   // bs.sk.sl_322 lt.cs.sk_322  fi.et.ro_322 tr.de.un_220
  0x160b25a4, 0x6b201aa0, 0x11041308, 0x092568a0,   // eu.es.hr_433 tl.sq.ceb_322  et.fi.ro_443 ig.eu.pl_322
  // [7920]
  0x12005504, 0x081301a4, 0x171b310b, 0x130825a7,   // rw.hu.un_320 en.et.no_433  az.tr.sr_542 eu.no.et_532
  0x1300110e, 0x17000e07, 0x28001602, 0x08000e20,   // ro.et.un_550 is.sr.un_420  hr.sw.un_220 is.no.un_850
  0x23285302, 0x186b01ee, 0x35000302, 0x080c02a6,   // ht.sw.ca_222 en.ceb.ga_422  nl.zu.un_220 da.sv.no_521
  0x2900320d, 0x32291307, 0x03350cad, 0x0b2313a4,   // bs.sl.un_540 et.sl.bs_432  sv.zu.nl_643 et.ca.es_433
  // [7930]
  0x0b002d04, 0x532a3b5a, 0x12000807, 0x101c1e07,   // sk.es.un_320 so.mt.ht_553  no.hu.un_420 ms.id.lt_432
  0x136804ad, 0x12080e0c, 0x13000c02, 0x08250e13,   // fi.ig.et_643 is.no.hu_543  sv.et.un_220 is.eu.no_665
  0x180b1e04, 0x3b1917a4, 0x3b005304, 0x1f003514,   // ms.es.ga_332 sr.gl.so_433  ht.so.un_320 zu.cy.un_660
  0x1900290c, 0x080c020d, 0x100807af, 0x1f001a02,   // sl.gl.un_530 da.sv.no_554  bg.uk.be_655 tl.cy.un_220
  // [7940]
  0x1609110c, 0x120852a7, 0x521304ec, 0x040a1105,   // ro.pl.hr_543 ha.no.hu_532  fi.et.ha_644 ro.mk.ru_333
  0x3b002502, 0x4a002812, 0x52041ca0, 0x250728a0,   // eu.so.un_220 sw.yo.un_640  id.fi.ha_322 sw.it.eu_322
  0x523555af, 0x1e002808, 0x31201bec, 0x09643f05,   // rw.zu.ha_655 sw.ms.un_430  tr.sq.az_644 af.lg.pl_333
  0x07000107, 0x686428ad, 0x210952ee, 0x1f093512,   // en.it.un_420 sw.lg.ig_643  ha.pl.jw_422 zu.pl.cy_654
  // [7950]
  0x060f100c, 0x35525507, 0x06270fa0, 0x0b002908,   // lt.lv.de_543 rw.ha.zu_432  lv.gd.de_322 sl.es.un_430
  0x1008170d, 0x0b070507, 0x1e065255, 0x050b1107,   // sr.uk.be_554 fr.it.es_432  ha.de.ms_442 ro.es.fr_432
  0x040f13a7, 0x2a0105a0, 0x3f35520c, 0x1a52060b,   // et.lv.fi_532 fr.en.mt_322  ha.zu.af_543 de.ha.tl_542
  0x23003508, 0x1e641cee, 0x05010fa4, 0x0a001305,   // zu.ca.un_430 id.lg.ms_422  lv.en.fr_433 et.pt.un_330
  // [7960]
  0x20002814, 0x321705ee, 0x072a1208, 0x02072307,   // sw.sq.un_660 fr.sr.bs_422  hu.mt.it_443 ca.it.da_432
  0x6b010a07, 0x0a311ba4, 0x191827ee, 0x1020250b,   // pt.en.ceb_432 tr.az.pt_433  gd.ga.gl_422 eu.sq.lt_542
  0x352568a0, 0x0b0e19a7, 0x040c31ac, 0x25000d04,   // ig.eu.zu_322 gl.is.es_532  az.sv.fi_632 cs.eu.un_320
  0x25002704, 0x190a0ca4, 0x6b012aa0, 0x5308230c,   // gd.eu.un_320 sv.pt.gl_433  mt.en.ceb_322 ca.no.ht_543
  // [7970]
  0x68000f09, 0x270e18ee, 0x356452a0, 0x25310355,   // lv.ig.un_440 ga.is.gd_422  ha.lg.zu_322 nl.az.eu_442
  0x251a550c, 0x110f0a08, 0x022b0e0b, 0x25003b13,   // rw.tl.eu_543 pt.lv.ro_443  is.vi.da_542 so.eu.un_650
  0x11005309, 0x23050209, 0x110a0705, 0x1b181fee,   // ht.ro.un_440 da.fr.ca_444  bg.mk.ro_333 cy.ga.tr_422
  0x6864280c, 0x1b002704, 0x10072014, 0x07005514,   // sw.lg.ig_543 gd.tr.un_320  sq.it.lt_666 rw.it.un_660
  // [7980]
  0x033f6404, 0x2d090d12, 0x64092d05, 0x0c321602,   // lg.af.nl_332 cs.pl.sk_654  sk.pl.lg_333 hr.bs.sv_222
  0x21042d07, 0x2921100b, 0x210753a7, 0x525355ee,   // sk.fi.jw_432 lt.jw.sl_542  ht.it.jw_532 rw.ht.ha_422
  0x2d0d130c, 0x2b550a0c, 0x070301a4, 0x072b21a4,   // et.cs.sk_543 pt.rw.vi_543  en.nl.it_433 jw.vi.it_433
  0x01041855, 0x063b1b07, 0x01070907, 0x121e10a7,   // ga.fi.en_442 tr.so.de_432  pl.it.en_432 lt.ms.hu_532
  // [7990]
  0x28185202, 0x071b3107, 0x09126bad, 0x17000908,   // ha.ga.sw_222 az.tr.it_432  ceb.hu.pl_643 pl.sr.un_430
  0x172821a0, 0x0425135a, 0x3b042814, 0x311e52a0,   // jw.sw.sr_322 et.eu.fi_553  sw.fi.so_666 ha.ms.az_322
  0x1119235a, 0x21033f12, 0x1f001812, 0x16112da4,   // ca.gl.ro_553 af.nl.jw_654  ga.cy.un_640 sk.ro.hr_433
  0x01070807, 0x190b0708, 0x10311ba4, 0x64000407,   // no.it.en_432 it.es.gl_443  tr.az.lt_433 fi.lg.un_420
  // [79a0]
  0x190e18a7, 0x130e10a7, 0x080a0702, 0x27351a55,   // ga.is.gl_532 lt.is.et_532  bg.mk.uk_222 tl.zu.gd_442
  0x10001f09, 0x1200100c, 0x11100460, 0x35001807,   // cy.lt.un_440 lt.hu.un_530  ru.be.ro_664 ga.zu.un_420
  0x0f1e1c02, 0x02002502, 0x232513a9, 0x21271807,   // id.ms.lv_222 eu.da.un_220  et.eu.ca_544 ga.gd.jw_432
  0x13236b14, 0x28040f04, 0x2b1c2109, 0x2b003b08,   // ceb.ca.et_666 lv.fi.sw_332  jw.id.vi_444 so.vi.un_430
  // [79b0]
  0x110468a0, 0x52684aad, 0x230a05af, 0x112a01a0,   // ig.fi.ro_322 yo.ig.ha_643  fr.pt.ca_655 en.mt.ro_322
  0x051304ad, 0x0f2305a0, 0x132904ec, 0x52131013,   // fi.et.fr_643 fr.ca.lv_322  fi.sl.et_644 lt.et.ha_665
  0x083132a0, 0x28216ba4, 0x1f350f12, 0x3b006b0d,   // bs.az.no_322 ceb.jw.sw_433  lv.zu.cy_654 ceb.so.un_540
  0x29080255, 0x1107050c, 0x640b27a4, 0x1f183b07,   // da.no.sl_442 fr.it.ro_543  gd.es.lg_433 so.ga.cy_432
  // [79c0]
  0x681101a4, 0x1e201c0c, 0x6e0501a7, 0x6b030612,   // en.ro.ig_433 id.sq.ms_543  en.fr.hmn_532 de.nl.ceb_654
  0x2508130c, 0x3127250c, 0x01002002, 0x04103f0c,   // et.no.eu_543 eu.gd.az_543  sq.en.un_220 af.lt.fi_543
  0x3217040c, 0x130e0814, 0x0d0916a4, 0x32000e0b,   // fi.sr.bs_543 no.is.et_666  hr.pl.cs_433 is.bs.un_520
  0x321217a0, 0x021a25a0, 0x0e00061a, 0x0f25130b,   // sr.hu.bs_322 eu.tl.da_322  de.is.un_760 et.eu.lv_542
  // [79d0]
  0x27181c04, 0x6b1a3b13, 0x020e250c, 0x18122109,   // id.ga.gd_332 so.tl.ceb_665  eu.is.da_543 fa.ur.ar_444
  0x0825130c, 0x190b2511, 0x1c001602, 0x07080aad,   // et.eu.no_543 eu.es.gl_653  hr.id.un_220 mk.uk.bg_643
  0x2d0d05ee, 0x20005502, 0x291017a0, 0x1921050c,   // fr.cs.sk_422 rw.sq.un_220  sr.lt.sl_322 fr.jw.gl_543
  0x16000d05, 0x21000502, 0x0d161755, 0x201710a7,   // cs.hr.un_330 fr.jw.un_220  sr.hr.cs_442 lt.sr.sq_532
  // [79e0]
  0x050c01a4, 0x64004a0d, 0x186413a9, 0x0e1b53a4,   // en.sv.fr_433 yo.lg.un_540  et.lg.ga_544 ht.tr.is_433
  0x1c130d05, 0x1b0e21a7, 0x030c3fee, 0x351e2007,   // ne.bh.mr_333 jw.is.tr_532  af.sv.nl_422 sq.ms.zu_432
  0x0e232aa0, 0x2a130408, 0x1a1b6ba4, 0x07111012,   // mt.ca.is_322 fi.et.mt_443  ceb.tr.tl_433 be.ro.bg_654
  0x27640705, 0x551021a9, 0x18170ba0, 0x6b641b12,   // it.lg.gd_333 jw.lt.rw_544  es.sr.ga_322 tr.lg.ceb_654
  // [79f0]
  0x06020e08, 0x0800130d, 0x6b1c2a05, 0x0c133108,   // is.da.de_443 et.no.un_540  mt.id.ceb_333 az.et.sv_443
  0x1b000f04, 0x1b3109a7, 0x1a002109, 0x352b28ee,   // lv.tr.un_320 pl.az.tr_532  jw.tl.un_440 sw.vi.zu_422
  0x11002a0e, 0x0b000a23, 0x0e0c1ba4, 0x29002511,   // mt.ro.un_550 pt.es.un_880  tr.sv.is_433 eu.sl.un_630
  0x6b001e0d, 0x2517270c, 0x322a68a0, 0x0e3f1b02,   // ms.ceb.un_540 gd.sr.eu_543  ig.mt.bs_322 tr.af.is_222
  // [7a00]
  0x131a2113, 0x060823ee, 0x20110c07, 0x200b0a08,   // jw.tl.et_665 ca.no.de_422  sv.ro.sq_432 pt.es.sq_443
  0x021b1c0c, 0x2509200c, 0x28351312, 0x530628a7,   // id.tr.da_543 sq.pl.eu_543  et.zu.sw_654 sw.de.ht_532
  0x2500190d, 0x64211ea0, 0x1c0d13a9, 0x0a004a08,   // gl.eu.un_540 ms.jw.lg_322  bh.ne.mr_544 yo.pt.un_430
  0x0c1f3bad, 0x25350313, 0x1e2a3b07, 0x3b5264ec,   // so.cy.sv_643 nl.zu.eu_665  so.mt.ms_432 lg.ha.so_644
  // [7a10]
  0x3b280404, 0x1e3b52a0, 0x013b5207, 0x180e2707,   // fi.sw.so_332 ha.so.ms_322  ha.so.en_432 gd.is.ga_432
  0x0a1a0408, 0x1f003b1a, 0x55350613, 0x21006e07,   // fi.tl.pt_443 so.cy.un_760  de.zu.rw_665 hmn.jw.un_420
  0x3b00642a, 0x080228af, 0x080213a4, 0x1e006405,   // lg.so.un_970 sw.da.no_655  et.da.no_433 lg.ms.un_330
  0x19002b13, 0x16003212, 0x2a003518, 0x2b000e1a,   // vi.gl.un_650 bs.hr.un_640  zu.mt.un_740 is.vi.un_760
  // [7a20]
  0x080710ad, 0x3b0e64ec, 0x4a0413ec, 0x071f3b0c,   // be.bg.uk_643 lg.is.so_644  et.fi.yo_644 so.cy.it_543
  0x3f020c0c, 0x1e2a3b12, 0x01002a07, 0x1a002913,   // sv.da.af_543 so.mt.ms_654  mt.en.un_420 sl.tl.un_650
  0x042552ec, 0x091c1e07, 0x21001604, 0x0d130c08,   // ha.eu.fi_644 ms.id.pl_432  hr.jw.un_320 sv.et.cs_443
  0x0d0b0a05, 0x2d1729af, 0x13321702, 0x0708170d,   // pt.es.cs_333 sl.sr.sk_655  sr.bs.et_222 sr.uk.bg_554
  // [7a30]
  0x3f1b31a9, 0x2d53090d, 0x20101f04, 0x04002a05,   // az.tr.af_544 pl.ht.sk_554  cy.lt.sq_332 mt.fi.un_330
  0x1b2a0e05, 0x532d0d0e, 0x29160d02, 0x1e5228ad,   // is.mt.tr_333 cs.sk.ht_555  cs.hr.sl_222 sw.ha.ms_643
  0x1e6b1c0c, 0x251c2155, 0x1b553b55, 0x176e200b,   // id.ceb.ms_543 jw.id.eu_442  so.rw.tr_442 sq.hmn.sr_542
  0x520f080b, 0x0800060b, 0x55003507, 0x042d1055,   // no.lv.ha_542 de.no.un_520  zu.rw.un_420 lt.sk.fi_442
  // [7a40]
  0x1b0e1a07, 0x6e160da4, 0x10201f0c, 0x0b1205ec,   // tl.is.tr_432 cs.hr.hmn_433  cy.sq.lt_543 fr.hu.es_644
  0x1b006412, 0x3b0b52a0, 0x52104a55, 0x095505a4,   // lg.tr.un_640 ha.es.so_322  yo.lt.ha_442 fr.rw.pl_433
  0x232d0dec, 0x1f0413ee, 0x16091b08, 0x21001e0c,   // cs.sk.ca_644 et.fi.cy_422  tr.pl.hr_443 ms.jw.un_530
  0x18063507, 0x21121e07, 0x19180a55, 0x01003508,   // zu.de.ga_432 ms.hu.jw_432  pt.ga.gl_442 zu.en.un_430
  // [7a50]
  0x6b1a0eaf, 0x201b2307, 0x32171655, 0x070501ee,   // is.tl.ceb_655 ca.tr.sq_432  hr.sr.bs_442 en.fr.it_422
  0x09002804, 0x16203207, 0x1f005502, 0x0b310cee,   // sw.pl.un_320 bs.sq.hr_432  rw.cy.un_220 sv.az.es_422
  0x1c080cec, 0x2900091b, 0x641e1c09, 0x6400552a,   // sv.no.id_644 pl.sl.un_770  id.ms.lg_444 rw.lg.un_970
  0x01210607, 0x0500061a, 0x3f271607, 0x06001219,   // de.jw.en_432 de.fr.un_760  hr.gd.af_432 hu.de.un_750
  // [7a60]
  0x64001321, 0x2507010b, 0x29000914, 0x05016ba0,   // et.lg.un_860 en.it.eu_542  pl.sl.un_660 ceb.en.fr_322
  0x05230aee, 0x64551113, 0x2713040c, 0x1a026bee,   // pt.ca.fr_422 ro.rw.lg_665  fi.et.gd_543 ceb.da.tl_422
  0x551b11a7, 0x1b20310d, 0x10003b13, 0x0100280c,   // ro.tr.rw_532 az.sq.tr_554  so.lt.un_650 sw.en.un_530
  0x1f230b08, 0x09002919, 0x4a0519a4, 0x09285302,   // es.ca.cy_443 sl.pl.un_750  gl.fr.yo_433 ht.sw.pl_222
  // [7a70]
  0x3500251a, 0x182d0d02, 0x0f2a07ec, 0x09002921,   // eu.zu.un_760 cs.sk.ga_222  it.mt.lv_644 sl.pl.un_860
  0x0b002105, 0x21092955, 0x64551309, 0x13000107,   // jw.es.un_330 sl.pl.jw_442  et.rw.lg_444 en.et.un_420
  0x172111a4, 0x32101712, 0x32172907, 0x033f3ba9,   // ro.jw.sr_433 sr.lt.bs_654  sl.sr.bs_432 so.af.nl_544
  0x2d005507, 0x0c001114, 0x6b2552a4, 0x1b312508,   // rw.sk.un_420 ro.sv.un_660  ha.eu.ceb_433 eu.az.tr_443
  // [7a80]
  0x0f2d0d02, 0x6b071ca0, 0x11070d0c, 0x081f0ca0,   // cs.sk.lv_222 id.it.ceb_322  cs.it.ro_543 sv.cy.no_322
  0x0c08021a, 0x2b083fa4, 0x2d0d20a0, 0x08170a13,   // da.no.sv_776 af.no.vi_433  sq.cs.sk_322 mk.sr.uk_665
  0x0a101760, 0x0c2304ee, 0x215364a0, 0x1c0e1e0c,   // sr.be.mk_664 fi.ca.sv_422  lg.ht.jw_322 ms.is.id_543
  0x160d1707, 0x0f002902, 0x1c002b07, 0x10000823,   // sr.cs.hr_432 sl.lv.un_220  vi.id.un_420 uk.be.un_880
  // [7a90]
  0x53002d02, 0x2a0f1012, 0x21005313, 0x21002012,   // sk.ht.un_220 lt.lv.mt_654  ht.jw.un_650 sq.jw.un_640
  0x01001805, 0x35211c09, 0x06130fa0, 0x55645308,   // ga.en.un_330 id.jw.zu_444  lv.et.de_322 ht.lg.rw_443
  0x100807ad, 0x21001302, 0x0f1f1813, 0x52550aec,   // bg.uk.be_643 et.jw.un_220  ga.cy.lv_665 pt.rw.ha_644
  0x1b006418, 0x023f03af, 0x2d092905, 0x07030e0c,   // lg.tr.un_740 nl.af.da_655  sl.pl.sk_333 is.nl.it_543
  // [7aa0]
  0x06001307, 0x32003f07, 0x060301ee, 0x4a002105,   // et.de.un_420 af.bs.un_420  en.nl.de_422 jw.yo.un_330
  0x18006405, 0x190a2dec, 0x210553ee, 0x686b1a0c,   // lg.ga.un_330 sk.pt.gl_644  ht.fr.jw_422 tl.ceb.ig_543
  0x0b191212, 0x20122a05, 0x180127ee, 0x31532155,   // hu.gl.es_654 mt.hu.sq_333  gd.en.ga_422 jw.ht.az_442
  0x23292d0c, 0x111e20a4, 0x1e004a04, 0x2855640e,   // sk.sl.ca_543 sq.ms.ro_433  yo.ms.un_320 lg.rw.sw_555
  // [7ab0]
  0x21070608, 0x053b5304, 0x6b1a08a0, 0x2528210c,   // de.it.jw_443 ht.so.fr_332  no.tl.ceb_322 jw.sw.eu_543
  0x0a1b2b0c, 0x17212d07, 0x130c08ec, 0x0c2927a9,   // vi.tr.pt_543 sk.jw.sr_432  no.sv.et_644 gd.sl.sv_544
  0x08020f09, 0x230b11ee, 0x64135507, 0x05003b02,   // lv.da.no_444 ro.es.ca_422  rw.et.lg_432 so.fr.un_220
  0x170405a7, 0x1804270c, 0x1e1c1004, 0x25645504,   // fr.fi.sr_532 gd.fi.ga_543  lt.id.ms_332 rw.lg.eu_332
  // [7ac0]
  0x52353b07, 0x041318a0, 0x251b32af, 0x08001b04,   // so.zu.ha_432 ga.et.fi_322  bs.tr.eu_655 tr.no.un_320
  0x6b004a14, 0x031f09a7, 0x12002709, 0x0c2d0d08,   // yo.ceb.un_660 pl.cy.nl_532  gd.hu.un_440 cs.sk.sv_443
  0x110764a0, 0x311b3504, 0x0a230555, 0x05201bad,   // lg.it.ro_322 zu.tr.az_332  fr.ca.pt_442 tr.sq.fr_643
  0x6b211005, 0x20051b0c, 0x190528a4, 0x646b1a0d,   // lt.jw.ceb_333 tr.fr.sq_543  sw.fr.gl_433 tl.ceb.lg_554
  // [7ad0]
  0x051104ad, 0x0b3f06ee, 0x06003f0b, 0x05000408,   // fi.ro.fr_643 de.af.es_422  af.de.un_520 fi.fr.un_430
  0x25090f07, 0x04001809, 0x282a3f02, 0x3b521e04,   // lv.pl.eu_432 ga.fi.un_440  af.mt.sw_222 ms.ha.so_332
  0x2500090c, 0x062a09ad, 0x16001c08, 0x2a000604,   // pl.eu.un_530 pl.mt.de_643  id.hr.un_430 de.mt.un_320
  0x12050fee, 0x0f003112, 0x11001708, 0x21312007,   // lv.fr.hu_422 az.lv.un_640  sr.ro.un_430 sq.az.jw_432
  // [7ae0]
  0x09062a07, 0x2506035a, 0x11001804, 0x23000a0d,   // mt.de.pl_432 nl.de.eu_553  ga.ro.un_320 pt.ca.un_540
  0x06250708, 0x0e000108, 0x0f002a04, 0x06050104,   // it.eu.de_443 en.is.un_430  mt.lv.un_320 en.fr.de_332
  0x05190a14, 0x19180bec, 0x0e1005a7, 0x0a052308,   // pt.gl.fr_666 es.ga.gl_644  fr.lt.is_532 ca.fr.pt_443
  0x100f04a7, 0x17100f08, 0x03001302, 0x0d076455,   // fi.lv.lt_532 lv.lt.sr_443  et.nl.un_220 lg.it.cs_442
  // [7af0]
  0x123510ac, 0x06002802, 0x521a0612, 0x23192508,   // lt.zu.hu_632 sw.de.un_220  de.tl.ha_654 eu.gl.ca_443
  0x55530505, 0x23051b07, 0x030620ad, 0x126407a9,   // fr.ht.rw_333 tr.fr.ca_432  sq.de.nl_643 it.lg.hu_544
  0x2a1207af, 0x200c0811, 0x2028525a, 0x2a6412ad,   // it.hu.mt_655 no.sv.sq_653  ha.sw.sq_553 hu.lg.mt_643
  0x19230508, 0x25130407, 0x2b000509, 0x5200552a,   // fr.ca.gl_443 fi.et.eu_432  fr.vi.un_440 rw.ha.un_970
  // [7b00]
  0x1a6b04a7, 0x1a521ea4, 0x131c1e0c, 0x12060eee,   // fi.ceb.tl_532 ms.ha.tl_433  ms.id.et_543 is.de.hu_422
  0x033f2808, 0x526b1aaf, 0x641a2812, 0x281a64ec,   // sw.af.nl_443 tl.ceb.ha_655  sw.tl.lg_654 lg.tl.sw_644
  0x3f216407, 0x3b001a14, 0x1a213fad, 0x0d002312,   // lg.jw.af_432 tl.so.un_660  af.jw.tl_643 ca.cs.un_640
  0x1e3b5202, 0x1a1e1c60, 0x25002907, 0x32311b13,   // ha.so.ms_222 id.ms.tl_664  sl.eu.un_420 tr.az.bs_665
  // [7b10]
  0x111b3b0c, 0x03002112, 0x17003507, 0x311b64a9,   // so.tr.ro_543 jw.nl.un_640  zu.sr.un_420 lg.tr.az_544
  0x20522812, 0x1b6428a9, 0x642a075a, 0x3b003107,   // sw.ha.sq_654 sw.lg.tr_544  it.mt.lg_553 az.so.un_420
  0x12072a0c, 0x3b0c1f07, 0x55004a13, 0x1c102107,   // mt.it.hu_543 cy.sv.so_432  yo.rw.un_650 jw.lt.id_432
  0x0a531ea4, 0x31205207, 0x1c556409, 0x21641a5a,   // ms.ht.pt_433 ha.sq.az_432  lg.rw.id_444 tl.lg.jw_553
  // [7b20]
  0x111012ad, 0x2a1a21a4, 0x2a080cee, 0x3b001a0d,   // hu.lt.ro_643 jw.tl.mt_433  sv.no.mt_422 tl.so.un_540
  0x0325040c, 0x4a0b6408, 0x17003b04, 0x101704a4,   // fi.eu.nl_543 lg.es.yo_443  so.sr.un_320 ru.sr.be_433
  0x0c0e080d, 0x2128640d, 0x2100310e, 0x3b00100d,   // no.is.sv_554 lg.sw.jw_554  az.jw.un_550 lt.so.un_540
  0x120e2d04, 0x06002508, 0x6b001a08, 0x09001704,   // sk.is.hu_332 eu.de.un_430  tl.ceb.un_430 sr.pl.un_320
  // [7b30]
  0x17100405, 0x68004a19, 0x190b1114, 0x28105507,   // ru.be.sr_333 yo.ig.un_750  ro.es.gl_666 rw.lt.sw_432
  0x2a521055, 0x1b002012, 0x04001f07, 0x0a0817af,   // lt.ha.mt_442 sq.tr.un_640  cy.fi.un_420 sr.uk.mk_655
  0x1b311ca4, 0x090f25a0, 0x1a21010c, 0x19530b55,   // id.az.tr_433 eu.lv.pl_322  en.jw.tl_543 es.ht.gl_442
  0x181f3f0b, 0x0b0d0ea0, 0x100b0408, 0x25003b04,   // af.cy.ga_542 is.cs.es_322  fi.es.lt_443 so.eu.un_320
  // [7b40]
  0x07120412, 0x2a1c3ba0, 0x28001112, 0x10001602,   // fi.hu.it_654 so.id.mt_322  ro.sw.un_640 hr.lt.un_220
  0x19055308, 0x116b0402, 0x25012bee, 0x18120da9,   // ht.fr.gl_443 fi.ceb.ro_222  vi.en.eu_422 cs.hu.ga_544
  0x256b2807, 0x080205a4, 0x0a112ba0, 0x1c2a0d02,   // sw.ceb.eu_432 fr.da.no_433  vi.ro.pt_322 cs.mt.id_222
  0x2d060d11, 0x25116ba4, 0x134a0ea4, 0x3f0e10a9,   // cs.de.sk_653 ceb.ro.eu_433  is.yo.et_433 lt.is.af_544
  // [7b50]
  0x0e004a0c, 0x0e001002, 0x0d2d2955, 0x0b0711a0,   // yo.is.un_530 lt.is.un_220  sl.sk.cs_442 ro.it.es_322
  0x13060404, 0x280411a0, 0x213f1c04, 0x1632170c,   // fi.de.et_332 ro.fi.sw_322  id.af.jw_332 sr.bs.hr_543
  0x216811ee, 0x210810ac, 0x28001102, 0x25000714,   // ro.ig.jw_422 lt.no.jw_632  ro.sw.un_220 it.eu.un_660
  0x124a210c, 0x103b0fad, 0x3208530c, 0x020e08a4,   // jw.yo.hu_543 lv.so.lt_643  ht.no.bs_543 no.is.da_433
  // [7b60]
  0x043f0313, 0x202d07ac, 0x1e211c0d, 0x35002814,   // nl.af.fi_665 it.sk.sq_632  id.jw.ms_554 sw.zu.un_660
  0x1f52535a, 0x230f3f08, 0x52531f0c, 0x29170805,   // ht.ha.cy_553 af.lv.ca_443  cy.ht.ha_543 no.sr.sl_333
  0x32060707, 0x6e190a0e, 0x3b1935a0, 0x3b551ea0,   // it.de.bs_432 pt.gl.hmn_555  zu.gl.so_322 ms.rw.so_322
  0x06000321, 0x31285208, 0x52003b12, 0x250906a0,   // nl.de.un_860 ha.sw.az_443  so.ha.un_640 de.pl.eu_322
  // [7b70]
  0x1e04530c, 0x0601050d, 0x32193505, 0x04230508,   // ht.fi.ms_543 fr.en.de_554  zu.gl.bs_333 fr.ca.fi_443
  0x06230baf, 0x53285208, 0x04001214, 0x06080c07,   // es.ca.de_655 ha.sw.ht_443  hu.fi.un_660 sv.no.de_432
  0x04131e04, 0x53042da0, 0x680952af, 0x55002023,   // ms.et.fi_332 sk.fi.ht_322  ha.pl.ig_655 sq.rw.un_880
  0x253b1e0c, 0x1f3b0a5a, 0x55521c07, 0x350a64a4,   // ms.so.eu_543 pt.so.cy_553  id.ha.rw_432 lg.pt.zu_433
  // [7b80]
  0x5300320c, 0x271a6bad, 0x2a27520c, 0x3b0f1fa9,   // bs.ht.un_530 ceb.tl.gd_643  ha.gd.mt_543 cy.lv.so_544
  0x3f4a35ee, 0x25001318, 0x0800091a, 0x06091108,   // zu.yo.af_422 et.eu.un_740  pl.no.un_760 ro.pl.de_443
  0x355255a9, 0x07082b13, 0x3b2852a0, 0x0c010212,   // rw.ha.zu_544 vi.no.it_665  ha.sw.so_322 da.en.sv_654
  0x05010614, 0x012b12a6, 0x6b642d12, 0x64065504,   // de.en.fr_666 hu.vi.en_521  sk.lg.ceb_654 rw.de.lg_332
  // [7b90]
  0x09006e08, 0x12001604, 0x112521ad, 0x273b01a0,   // hmn.pl.un_430 hr.hu.un_320  jw.eu.ro_643 en.so.gd_322
  0x6b101c0c, 0x1e3b3112, 0x31121005, 0x100c0804,   // id.lt.ceb_543 az.so.ms_654  lt.hu.az_333 no.sv.lt_332
  0x3b00522c, 0x08355305, 0x060c1ca0, 0x1b0e120c,   // ha.so.un_990 ht.zu.no_333  id.sv.de_322 hu.is.tr_543
  0x1e1c64ec, 0x06101ba4, 0x0d122da4, 0x05060304,   // lg.id.ms_644 tr.lt.de_433  sk.hu.cs_433 nl.de.fr_332
  // [7ba0]
  0x2a0809a0, 0x1c041eee, 0x641a3512, 0x18355302,   // pl.no.mt_322 ms.fi.id_422  zu.tl.lg_654 ht.zu.ga_222
  0x011b0eee, 0x64000804, 0x070810ee, 0x211c1b12,   // is.tr.en_422 no.lg.un_320  be.uk.bg_422 tr.id.jw_654
  0x2d002319, 0x1e002804, 0x093b1002, 0x1e005304,   // ca.sk.un_750 sw.ms.un_320  lt.so.pl_222 ht.ms.un_320
  0x1e290fad, 0x3f000a12, 0x2b000a08, 0x3f000a14,   // lv.sl.ms_643 pt.af.un_640  pt.vi.un_430 pt.af.un_660
  // [7bb0]
  0x02033faf, 0x2300201b, 0x18001f04, 0x080711ac,   // af.nl.da_655 sq.ca.un_770  cy.ga.un_320 ro.bg.uk_632
  0x0a002008, 0x0b230aa0, 0x081f0e04, 0x3100231b,   // sq.pt.un_430 pt.ca.es_322  is.cy.no_332 ca.az.un_770
  0x282a5207, 0x210c2bee, 0x0e000c2c, 0x100e0cad,   // ha.mt.sw_432 vi.sv.jw_422  sv.is.un_990 sv.is.lt_643
  0x190a1809, 0x52130104, 0x080e010c, 0x29020c08,   // ga.pt.gl_444 en.et.ha_332  en.is.no_543 sv.da.sl_443
  // [7bc0]
  0x556825ad, 0x080f1007, 0x060e1f0c, 0x070411ac,   // eu.ig.rw_643 lt.lv.no_432  cy.is.de_543 ro.ru.bg_632
  0x0b120a5a, 0x2d0d02ec, 0x682135a4, 0x013f2507,   // pt.hu.es_553 da.cs.sk_644  zu.jw.ig_433 eu.af.en_432
  0x5300250c, 0x2000091b, 0x08093fee, 0x05270805,   // eu.ht.un_530 pl.sq.un_770  af.pl.no_422 no.gd.fr_333
  0x321707a4, 0x08020c5a, 0x0306250c, 0x2a2818ee,   // it.sr.bs_433 sv.da.no_553  eu.de.nl_543 ga.sw.mt_422
  // [7bd0]
  0x09002d09, 0x161004a4, 0x350625a7, 0x3f001e08,   // sk.pl.un_440 fi.lt.hr_433  eu.de.zu_532 ms.af.un_430
  0x1c211e08, 0x0c0e010c, 0x0a002d08, 0x1f002308,   // ms.jw.id_443 en.is.sv_543  sk.pt.un_430 ca.cy.un_430
  0x2d002314, 0x29000c08, 0x0c3518ec, 0x1a001708,   // ca.sk.un_660 sv.sl.un_430  ga.zu.sv_644 sr.tl.un_430
  0x28005509, 0x230605af, 0x4a082a04, 0x203f03a4,   // rw.sw.un_440 fr.de.ca_655  mt.no.yo_332 nl.af.sq_433
  // [7be0]
  0x1a3b6bad, 0x32001b13, 0x206e090c, 0x0a003b11,   // ceb.so.tl_643 tr.bs.un_650  pl.hmn.sq_543 so.pt.un_630
  0x53002908, 0x0a233bad, 0x0a002514, 0x29096e0c,   // sl.ht.un_430 so.ca.pt_643  eu.pt.un_660 hmn.pl.sl_543
  0x1a355304, 0x6b3f2a07, 0x320520a0, 0x0a283b0c,   // ht.zu.tl_332 mt.af.ceb_432  sq.fr.bs_322 so.sw.pt_543
  0x3f211c04, 0x35000212, 0x52133b0c, 0x08210cee,   // id.jw.af_332 da.zu.un_640  so.et.ha_543 sv.jw.no_422
  // [7bf0]
  0x55002a29, 0x3b003f02, 0x520a3b12, 0x3f2125ad,   // mt.rw.un_960 af.so.un_220  so.pt.ha_654 eu.jw.af_643
  0x3b352a04, 0x3b001321, 0x20192308, 0x68233bad,   // mt.zu.so_332 et.so.un_860  ca.gl.sq_443 so.ca.ig_643
  0x06012b04, 0x3b002b0c, 0x321120ee, 0x052a55ee,   // vi.en.de_332 vi.so.un_530  sq.ro.bs_422 rw.mt.fr_422
  0x09005505, 0x1b313b12, 0x062301a7, 0x0f000104,   // rw.pl.un_330 so.az.tr_654  en.ca.de_532 en.lv.un_320

  // [7c00]
  0x284a3bec, 0x0a3b130c, 0x3f03230e, 0x0a2d18a0,   // so.yo.sw_644 et.so.pt_543  ca.nl.af_555 ga.sk.pt_322
  0x2400012a, 0x19002307, 0x03000118, 0x183f0107,   // iw.yi.un_970 ca.gl.un_420  en.nl.un_740 en.af.ga_432
  0x3f230507, 0x030f3fad, 0x03053f13, 0x20121f55,   // fr.ca.af_432 af.lv.nl_643  af.fr.nl_665 cy.hu.sq_442
  0x0a001807, 0x080917a0, 0x530c6b02, 0x01640f04,   // ga.pt.un_420 sr.pl.no_322  ceb.sv.ht_222 lv.lg.en_332
  // [7c10]
  0x290910a9, 0x020c03a0, 0x0b0f25a0, 0x131c08ee,   // lt.pl.sl_544 nl.sv.da_322  eu.lv.es_322 no.id.et_422
  0x21001119, 0x1a131fa4, 0x18001907, 0x023f0360,   // ro.jw.un_750 cy.et.tl_433  gl.ga.un_420 nl.af.da_664
  0x13002919, 0x3b00131a, 0x230b080e, 0x110c2a04,   // sl.et.un_750 et.so.un_760  no.es.ca_555 mt.sv.ro_332
  0x080c2355, 0x0a003502, 0x2d2a4a07, 0x0d00530e,   // ca.sv.no_442 zu.pt.un_220  yo.mt.sk_432 ht.cs.un_550
  // [7c20]
  0x0c08350b, 0x28001f04, 0x2d00530c, 0x0e280607,   // zu.no.sv_542 cy.sw.un_320  ht.sk.un_530 de.sw.is_432
  0x0e136409, 0x012a0307, 0x100e06a4, 0x210235ad,   // lg.et.is_444 nl.mt.en_432  de.is.lt_433 zu.da.jw_643
  0x21003119, 0x3f0825ad, 0x1f2d0d0e, 0x316e13a4,   // az.jw.un_750 eu.no.af_643  cs.sk.cy_555 et.hmn.az_433
  0x21313b13, 0x060d1fad, 0x13003b21, 0x6e002b09,   // so.az.jw_665 cy.cs.de_643  so.et.un_860 vi.hmn.un_440
  // [7c30]
  0x18006414, 0x052b53a0, 0x1a2b01ad, 0x213f0313,   // lg.ga.un_660 ht.vi.fr_322  en.vi.tl_643 nl.af.jw_665
  0x061b12af, 0x091f64a4, 0x350231a0, 0x1f020812,   // hu.tr.de_655 lg.cy.pl_433  az.da.zu_322 no.da.cy_654
  0x533f0d07, 0x6b043ba7, 0x111b17a0, 0x64043b11,   // cs.af.ht_432 so.fi.ceb_532  sr.tr.ro_322 so.fi.lg_653
  0x08060307, 0x05016b04, 0x3b642804, 0x13643b12,   // nl.de.no_432 ceb.en.fr_332  sw.lg.so_332 so.lg.et_654
  // [7c40]
  0x10043509, 0x0e081aee, 0x641a3b07, 0x101235ee,   // zu.fi.lt_444 tl.no.is_422  so.tl.lg_432 zu.hu.lt_422
  0x0c042107, 0x1a214a04, 0x0f113ba7, 0x033f680c,   // jw.fi.sv_432 yo.jw.tl_332  so.ro.lv_532 ig.af.nl_543
  0x050621ee, 0x32051707, 0x27006b04, 0x1c271804,   // jw.de.fr_422 sr.fr.bs_432  ceb.gd.un_320 ga.gd.id_332
  0x1113040e, 0x2d000e09, 0x130208ee, 0x113b0405,   // fi.et.ro_555 is.sk.un_440  no.da.et_422 fi.so.ro_333
  // [7c50]
  0x68006414, 0x25001f0b, 0x04133b05, 0x1104130c,   // lg.ig.un_660 cy.eu.un_520  so.et.fi_333 et.fi.ro_543
  0x1f0335a4, 0x3f023555, 0x1c271855, 0x1f0513a0,   // zu.nl.cy_433 zu.da.af_442  ga.gd.id_442 et.fr.cy_322
  0x056421a7, 0x1e271f07, 0x0c0102a4, 0x27180407,   // jw.lg.fr_532 cy.gd.ms_432  da.en.sv_433 fi.ga.gd_432
  0x1b286b08, 0x011c21ee, 0x213f3507, 0x53000404,   // ceb.sw.tr_443 jw.id.en_422  zu.af.jw_432 fi.ht.un_320
  // [7c60]
  0x0b231109, 0x251c2104, 0x1a6b520e, 0x093528a0,   // ro.ca.es_444 jw.id.eu_332  ha.ceb.tl_555 sw.zu.pl_322
  0x18230111, 0x071108af, 0x09006419, 0x0c00280c,   // en.ca.ga_653 uk.ro.bg_655  lg.pl.un_750 sw.sv.un_530
  0x52000808, 0x250f550d, 0x080229ee, 0x1e1c01a0,   // no.ha.un_430 rw.lv.eu_554  sl.da.no_422 en.id.ms_322
  0x28050104, 0x12111ea0, 0x1b0302a7, 0x1a104aa9,   // en.fr.sw_332 ms.ro.hu_322  da.nl.tr_532 yo.lt.tl_544
  // [7c70]
  0x013b3155, 0x21522812, 0x211a1c07, 0x080d2d0b,   // az.so.en_442 sw.ha.jw_654  id.tl.jw_432 sk.cs.no_542
  0x080c29a0, 0x08020ca6, 0x18011902, 0x31351baf,   // sl.sv.no_322 sv.da.no_521  gl.en.ga_222 tr.zu.az_655
  0x0a05110c, 0x321b250d, 0x32642a04, 0x31000804,   // ro.fr.pt_543 eu.tr.bs_554  mt.lg.bs_332 no.az.un_320
  0x0b281804, 0x1b113108, 0x2b00110c, 0x05251107,   // ga.sw.es_332 az.ro.tr_443  ro.vi.un_530 ro.eu.fr_432
  // [7c80]
  0x555228a4, 0x160c0da0, 0x25002105, 0x2000640d,   // sw.ha.rw_433 cs.sv.hr_322  jw.eu.un_330 lg.sq.un_540
  0x53002507, 0x033f13a4, 0x1300250c, 0x53215204,   // eu.ht.un_420 et.af.nl_433  eu.et.un_530 ha.jw.ht_332
  0x07101702, 0x6b1a1304, 0x35002d07, 0x133f035a,   // sr.be.bg_222 et.tl.ceb_332  sk.zu.un_420 nl.af.et_553
  0x31251b60, 0x320929ee, 0x1c3b2108, 0x212025a0,   // tr.eu.az_664 sl.pl.bs_422  jw.so.id_443 eu.sq.jw_322
  // [7c90]
  0x29002713, 0x3b6b64a6, 0x0b4a3ba7, 0x114a6b04,   // gd.sl.un_650 lg.ceb.so_521  so.yo.es_532 ceb.yo.ro_332
  0x0e29100c, 0x0b00210c, 0x0e0811ec, 0x033f6ea7,   // lt.sl.is_543 jw.es.un_530  ro.no.is_644 hmn.af.nl_532
  0x033f68a0, 0x1f0d0fa7, 0x01131fee, 0x19000908,   // ig.af.nl_322 lv.cs.cy_532  cy.et.en_422 pl.gl.un_430
  0x072801a4, 0x293f3504, 0x1f09280c, 0x076b1fa4,   // en.sw.it_433 zu.af.sl_332  sw.pl.cy_543 cy.ceb.it_433
  // [7ca0]
  0x231929ee, 0x1000281b, 0x080d01ee, 0x2d0d53a4,   // sl.gl.ca_422 sw.lt.un_770  en.cs.no_422 ht.cs.sk_433
  0x2d0603ee, 0x03016b04, 0x17162505, 0x1f0518a4,   // nl.de.sk_422 ceb.en.nl_332  eu.hr.sr_333 ga.fr.cy_433
  0x0a004a07, 0x10040aa4, 0x1a1007a4, 0x21003b04,   // yo.pt.un_420 mk.ru.be_433  it.lt.tl_433 so.jw.un_320
  0x1f002b0c, 0x321920a0, 0x4a122d0c, 0x681b0708,   // vi.cy.un_530 sq.gl.bs_322  sk.hu.yo_543 it.tr.ig_443
  // [7cb0]
  0x251807a4, 0x17003b07, 0x0d092da7, 0x050108a0,   // it.ga.eu_433 so.sr.un_420  sk.pl.cs_532 no.en.fr_322
  0x28000b09, 0x0c3f080d, 0x1c281811, 0x13520da4,   // es.sw.un_440 no.af.sv_554  ga.sw.id_653 cs.ha.et_433
  0x52006809, 0x1f000d04, 0x01002d02, 0x1f10280c,   // ig.ha.un_440 cs.cy.un_320  sk.en.un_220 sw.lt.cy_543
  0x2000070d, 0x1a0d01a4, 0x2a136b04, 0x07101705,   // it.sq.un_540 en.cs.tl_433  ceb.et.mt_332 sr.be.bg_333
  // [7cc0]
  0x111368a9, 0x13002d22, 0x27094aad, 0x07005208,   // ig.et.ro_544 sk.et.un_870  yo.pl.gd_643 ha.it.un_430
  0x521155ad, 0x174a29a7, 0x03000e12, 0x110807a4,   // rw.ro.ha_643 sl.yo.sr_532  is.nl.un_640 it.no.ro_433
  0x081031ee, 0x1117040c, 0x112106ee, 0x2d000b07,   // az.lt.no_422 ru.sr.ro_543  de.jw.ro_422 es.sk.un_420
  0x13000214, 0x0e001c0d, 0x5212110b, 0x08025502,   // da.et.un_660 id.is.un_540  ro.hu.ha_542 rw.da.no_222
  // [7cd0]
  0x211c3109, 0x0e001e08, 0x136b1aa7, 0x202b31ee,   // az.id.jw_444 ms.is.un_430  tl.ceb.et_532 az.vi.sq_422
  0x1b310e60, 0x06002719, 0x0c0d3f04, 0x21526407,   // is.az.tr_664 gd.de.un_750  af.cs.sv_332 lg.ha.jw_432
  0x2a110714, 0x200e1e0c, 0x18002b0c, 0x11071ea0,   // it.ro.mt_666 ms.is.sq_543  vi.ga.un_530 ms.it.ro_322
  0x13291705, 0x11211ca4, 0x4a6828ad, 0x211c200c,   // sr.sl.et_333 id.jw.ro_433  sw.ig.yo_643 sq.id.jw_543
  // [7ce0]
  0x1f000e2a, 0x17040713, 0x20003b13, 0x23110ead,   // is.cy.un_970 bg.ru.sr_665  so.sq.un_650 is.ro.ca_643
  0x23190aad, 0x081304ad, 0x29021308, 0x20006e04,   // pt.gl.ca_643 fi.et.no_643  et.da.sl_443 hmn.sq.un_320
  0x0c190a14, 0x28001005, 0x2b230bee, 0x121b255a,   // pt.gl.sv_666 lt.sw.un_330  es.ca.vi_422 eu.tr.hu_553
  0x0c350207, 0x1b252005, 0x290507a0, 0x1b0f1155,   // da.zu.sv_432 sq.eu.tr_333  it.fr.sl_322 ro.lv.tr_442
  // [7cf0]
  0x1b0e2aad, 0x1c001a04, 0x192d0eb4, 0x200e1c0c,   // mt.is.tr_643 tl.id.un_320  is.sk.gl_754 id.is.sq_543
  0x0b230aad, 0x2b050a04, 0x310e2008, 0x211f200c,   // pt.ca.es_643 pt.fr.vi_332  sq.is.az_443 sq.cy.jw_543
  0x0e1f2009, 0x1c1e2b12, 0x27001005, 0x13080704,   // sq.cy.is_444 vi.ms.id_654  lt.gd.un_330 it.no.et_332
  0x04081307, 0x0e1f6bee, 0x131729a4, 0x04001f12,   // et.no.fi_432 ceb.cy.is_422  sl.sr.et_433 cy.fi.un_640
  // [7d00]
  0x29041355, 0x291317a0, 0x13002a0c, 0x554a280c,   // et.fi.sl_442 sr.et.sl_322  mt.et.un_530 sw.yo.rw_543
  0x3f001107, 0x3f120e07, 0x08001222, 0x1a192107,   // ro.af.un_420 is.hu.af_432  hu.no.un_870 jw.gl.tl_432
  0x0d1c6404, 0x53112012, 0x5500681b, 0x533f1c0b,   // lg.id.cs_332 sq.ro.ht_654  ig.rw.un_770 id.af.ht_542
  0x6b53280c, 0x1a531255, 0x08003b19, 0x6400250c,   // sw.ht.ceb_543 hu.ht.tl_442  so.no.un_750 eu.lg.un_530
  // [7d10]
  0x123f0804, 0x0e00120d, 0x29000908, 0x232d0a08,   // no.af.hu_332 hu.is.un_540  pl.sl.un_430 pt.sk.ca_443
  0x120a2da9, 0x125307ee, 0x080e3fa0, 0x0b003f11,   // sk.pt.hu_544 it.ht.hu_422  af.is.no_322 af.es.un_630
  0x2718060c, 0x0800121a, 0x530325ad, 0x06001121,   // de.ga.gd_543 hu.no.un_760  eu.nl.ht_643 ro.de.un_860
  0x08001213, 0x0407170d, 0x29102d04, 0x052b01a4,   // hu.no.un_650 sr.bg.ru_554  sk.lt.sl_332 en.vi.fr_433
  // [7d20]
  0x2a12070c, 0x520553a0, 0x0a00232b, 0x04003b0d,   // it.hu.mt_543 ht.fr.ha_322  ca.pt.un_980 so.fi.un_540
  0x0e1e1c0d, 0x4a32100e, 0x0c271802, 0x2a0a6b12,   // id.ms.is_554 lt.bs.yo_555  ga.gd.sv_222 ceb.pt.mt_654
  0x041a1fad, 0x1a0835ee, 0x3b2827a4, 0x321016a4,   // cy.tl.fi_643 zu.no.tl_422  gd.sw.so_433 hr.lt.bs_433
  0x0c1308a4, 0x0f000304, 0x0c052308, 0x230f02a4,   // no.et.sv_433 nl.lv.un_320  ca.fr.sv_443 da.lv.ca_433
  // [7d30]
  0x2d1629ee, 0x273518af, 0x2803010c, 0x1a046bee,   // sl.hr.sk_422 ga.zu.gd_655  en.nl.sw_543 ceb.fi.tl_422
  0x13000202, 0x27001e08, 0x3b002723, 0x230c020c,   // da.et.un_220 ms.gd.un_430  gd.so.un_880 da.sv.ca_543
  0x0e271a0c, 0x35000122, 0x05000e12, 0x6400290b,   // tl.gd.is_543 en.zu.un_870  is.fr.un_640 sl.lg.un_520
  0x68010ea4, 0x190403a0, 0x16292da6, 0x08060c04,   // is.en.ig_433 nl.fi.gl_322  sk.sl.hr_521 sv.de.no_332
  // [7d40]
  0x52003b13, 0x13040302, 0x20001214, 0x643f030c,   // so.ha.un_650 nl.fi.et_222  hu.sq.un_660 nl.af.lg_543
  0x063f08ac, 0x1b312307, 0x08000e0b, 0x2b1c01a6,   // no.af.de_632 ca.az.tr_432  is.no.un_520 en.id.vi_521
  0x0812290c, 0x03000405, 0x041e1902, 0x043f030c,   // sl.hu.no_543 fi.nl.un_330  gl.ms.fi_222 nl.af.fi_543
  0x2a00201b, 0x1f0c0ea0, 0x0f001020, 0x3f1c1eee,   // sq.mt.un_770 is.sv.cy_322  lt.lv.un_850 ms.id.af_422
  // [7d50]
  0x04001909, 0x521331ee, 0x134a5307, 0x5368350e,   // gl.fi.un_440 az.et.ha_422  ht.yo.et_432 zu.ig.ht_555
  0x5300230b, 0x0e0307a0, 0x55005308, 0x0c00020c,   // ca.ht.un_520 it.nl.is_322  ht.rw.un_430 da.sv.un_530
  0x0e000407, 0x10110408, 0x040c0e07, 0x100d29a0,   // fi.is.un_420 ru.ro.be_443  is.sv.fi_432 sl.cs.lt_322
  0x311b03a9, 0x2a102da0, 0x52645507, 0x2a281804,   // nl.tr.az_544 sk.lt.mt_322  rw.lg.ha_432 ga.sw.mt_332
  // [7d60]
  0x31080c08, 0x011a29a4, 0x080c3507, 0x64071c07,   // sv.no.az_443 sl.tl.en_433  zu.sv.no_432 id.it.lg_432
  0x520164ee, 0x2a3b5307, 0x16320d0c, 0x320f0305,   // lg.en.ha_422 ht.so.mt_432  cs.bs.hr_543 nl.lv.bs_333
  0x08005308, 0x552132a0, 0x04253508, 0x0827180c,   // ht.no.un_430 bs.jw.rw_322  zu.eu.fi_443 ga.gd.no_543
  0x21002812, 0x05042aa0, 0x3f03280d, 0x101120a9,   // sw.jw.un_640 mt.fi.fr_322  sw.nl.af_554 sq.ro.lt_544
  // [7d70]
  0x2d130855, 0x04355505, 0x04110712, 0x1a003522,   // no.et.sk_442 rw.zu.fi_333  bg.ro.ru_654 zu.tl.un_870
  0x3f130313, 0x272821a9, 0x2508060c, 0x181a6bad,   // nl.et.af_665 jw.sw.gd_544  de.no.eu_543 ceb.tl.ga_643
  0x3f040512, 0x20004a0e, 0x28055304, 0x2a2855ac,   // fr.fi.af_654 yo.sq.un_550  ht.fr.sw_332 rw.sw.mt_632
  0x03023fa0, 0x532801a4, 0x20252804, 0x536428ee,   // af.da.nl_322 en.sw.ht_433  sw.eu.sq_332 sw.lg.ht_422
  // [7d80]
  0x10040107, 0x3510010c, 0x0e25100c, 0x1b3531ad,   // en.fi.lt_432 en.lt.zu_543  lt.eu.is_543 az.zu.tr_643
  0x25042907, 0x350c0802, 0x13641a0c, 0x32003507,   // sl.fi.eu_432 no.sv.zu_222  tl.lg.et_543 zu.bs.un_420
  0x1800352c, 0x1a556ba6, 0x1e004a08, 0x282a180d,   // zu.ga.un_990 ceb.rw.tl_521  yo.ms.un_430 ga.mt.sw_554
  0x556410a4, 0x4a1b1007, 0x10641104, 0x31080ea0,   // lt.lg.rw_433 lt.tr.yo_432  ro.lg.lt_332 is.no.az_322
  // [7d90]
  0x641355ad, 0x64003514, 0x10000d0c, 0x013f1f07,   // rw.et.lg_643 zu.lg.un_660  cs.lt.un_530 cy.af.en_432
  0x29161b07, 0x1a1f02ee, 0x311b0408, 0x27351b07,   // tr.hr.sl_432 da.cy.tl_422  fi.tr.az_443 tr.zu.gd_432
  0x350e1b08, 0x1c352105, 0x35004a05, 0x01321704,   // tr.is.zu_443 jw.zu.id_333  yo.zu.un_330 sr.bs.en_332
  0x1b25350b, 0x25006b09, 0x0e351b12, 0x284a1bec,   // zu.eu.tr_542 ceb.eu.un_440  tr.zu.is_654 tr.yo.sw_644
  // [7da0]
  0x270e1b60, 0x64006807, 0x2d123b07, 0x55131005,   // tr.is.gd_664 ig.lg.un_420  so.hu.sk_432 lt.et.rw_333
  0x281a130c, 0x1b0e2509, 0x13000b04, 0x0c251b0c,   // et.tl.sw_543 eu.is.tr_444  es.et.un_320 tr.eu.sv_543
  0x35051b0c, 0x0d172dee, 0x25351b12, 0x0d1b0e0c,   // tr.fr.zu_543 sk.sr.cs_422  tr.zu.eu_654 is.tr.cs_543
  0x10000a0c, 0x090a13ee, 0x13000612, 0x2d001008,   // pt.lt.un_530 et.pt.pl_422  de.et.un_640 lt.sk.un_430
  // [7db0]
  0x2100070d, 0x0a0408ad, 0x07642a0e, 0x16006402,   // it.jw.un_540 uk.ru.mk_643  mt.lg.it_555 lg.hr.un_220
  0x0f645513, 0x13002019, 0x55642509, 0x1e211c11,   // rw.lg.lv_665 sq.et.un_750  eu.lg.rw_444 id.jw.ms_653
  0x29002a19, 0x05022d0c, 0x0c001a04, 0x190a08a4,   // mt.sl.un_750 sk.da.fr_543  tl.sv.un_320 no.pt.gl_433
  0x07002a13, 0x521e55a0, 0x2d0a2302, 0x13071fa0,   // mt.it.un_650 rw.ms.ha_322  ca.pt.sk_222 cy.it.et_322
  // [7dc0]
  0x1a20530c, 0x12006b19, 0x0100051b, 0x55110507,   // ht.sq.tl_543 ceb.hu.un_750  fr.en.un_770 fr.ro.rw_432
  0x06002009, 0x3f002007, 0x0b0a2aee, 0x180e27ad,   // sq.de.un_440 sq.af.un_420  mt.pt.es_422 gd.is.ga_643
  0x072a0da4, 0x0c642805, 0x180b1907, 0x28005522,   // cs.mt.it_433 sw.lg.sv_333  gl.es.ga_432 rw.sw.un_870
  0x06005319, 0x1000020d, 0x1b316b11, 0x28005314,   // ht.de.un_750 da.lt.un_540  ceb.az.tr_653 ht.sw.un_660
  // [7dd0]
  0x53211c55, 0x0c350807, 0x53050111, 0x2d0d1755,   // id.jw.ht_442 no.zu.sv_432  en.fr.ht_653 sr.cs.sk_442
  0x12002502, 0x4a1e1c13, 0x1b002502, 0x132911ee,   // eu.hu.un_220 id.ms.yo_665  eu.tr.un_220 ro.sl.et_422
  0x20211b12, 0x1b132512, 0x2d0d1b02, 0x351310a4,   // tr.jw.sq_654 eu.et.tr_654  tr.cs.sk_222 lt.et.zu_433
  0x0e35640c, 0x0b0a19ee, 0x11236808, 0x3500021a,   // lg.zu.is_543 gl.pt.es_422  ig.ca.ro_443 da.zu.un_760
  // [7de0]
  0x290f03a0, 0x0d003511, 0x060d35a9, 0x04004a09,   // nl.lv.sl_322 zu.cs.un_630  zu.cs.de_544 yo.fi.un_440
  0x030964a0, 0x2b050311, 0x230701a4, 0x12212b07,   // lg.pl.nl_322 nl.fr.vi_653  en.it.ca_433 vi.jw.hu_432
  0x3f05030c, 0x64001e04, 0x0f291605, 0x0f310d0b,   // nl.fr.af_543 ms.lg.un_320  hr.sl.lv_333 cs.az.lv_542
  0x17000c08, 0x100407ee, 0x6b3512ad, 0x290d3202,   // sv.sr.un_430 bg.ru.be_422  hu.zu.ceb_643 bs.cs.sl_222
  // [7df0]
  0x3f003511, 0x1c090607, 0x120b2d0c, 0x20230aee,   // zu.af.un_630 de.pl.id_432  sk.es.hu_543 pt.ca.sq_422
  0x290c2504, 0x09200f07, 0x131b31ad, 0x2d29520c,   // eu.sv.sl_332 lv.sq.pl_432  az.tr.et_643 ha.sl.sk_543
  0x19001211, 0x161e1c04, 0x0d003507, 0x2b030504,   // hu.gl.un_630 id.ms.hr_332  zu.cs.un_420 fr.nl.vi_332
  0x03000522, 0x55354a04, 0x09000611, 0x25000508,   // fr.nl.un_870 yo.zu.rw_332  de.pl.un_630 fr.eu.un_430
  // [7e00]
  0x2b0535ee, 0x080710a7, 0x190b0405, 0x0700090c,   // zu.fr.vi_422 be.bg.uk_532  fi.es.gl_333 pl.it.un_530
  0x1a000702, 0x100f55ec, 0x17212a07, 0x1e531a0b,   // it.tl.un_220 rw.lv.lt_644  mt.jw.sr_432 tl.ht.ms_542
  0x0e001009, 0x311b1ea0, 0x53033fac, 0x2a200807,   // lt.is.un_440 ms.tr.az_322  af.nl.ht_632 no.sq.mt_432
  0x64002a05, 0x130e08af, 0x112507a4, 0x07132504,   // mt.lg.un_330 no.is.et_655  it.eu.ro_433 eu.et.it_332
  // [7e10]
  0x11003b07, 0x25203ba4, 0x13000819, 0x171107a0,   // so.ro.un_420 so.sq.eu_433  no.et.un_750 it.ro.sr_322
  0x20282507, 0x2d002102, 0x060a070d, 0x0611090b,   // eu.sw.sq_432 jw.sk.un_220  it.pt.de_554 pl.ro.de_542
  0x28006407, 0x092d290c, 0x251c1a04, 0x105507a4,   // lg.sw.un_420 sl.sk.pl_543  tl.id.eu_332 it.rw.lt_433
  0x13211c04, 0x11000712, 0x13063107, 0x040708af,   // id.jw.et_332 it.ro.un_640  az.de.et_432 no.it.fi_655
  // [7e20]
  0x2a5510ec, 0x0d16290c, 0x23006807, 0x120901a0,   // lt.rw.mt_644 sl.hr.cs_543  ig.ca.un_420 en.pl.hu_322
  0x166e320c, 0x03004a07, 0x212a1b05, 0x0c000836,   // bs.hmn.hr_543 yo.nl.un_420  tr.mt.jw_333 no.sv.un_AA0
  0x1025070c, 0x2b3f0308, 0x28080c0b, 0x06352aa0,   // it.eu.lt_543 nl.af.vi_443  sv.no.sw_542 mt.zu.de_322
  0x2b230e08, 0x0900291b, 0x1f182707, 0x1200530b,   // is.ca.vi_443 sl.pl.un_770  gd.ga.cy_432 ht.hu.un_520
  // [7e30]
  0x64521f14, 0x09002807, 0x2d0d20ee, 0x040817ac,   // cy.ha.lg_666 sw.pl.un_420  sq.cs.sk_422 sr.uk.ru_632
  0x23192504, 0x182b27a0, 0x08170aec, 0x321208ac,   // eu.gl.ca_332 gd.vi.ga_322  mk.sr.uk_644 no.hu.bs_632
  0x21525507, 0x3b005302, 0x2a1f1a0c, 0x6b006805,   // rw.ha.jw_432 ht.so.un_220  tl.cy.mt_543 ig.ceb.un_330
  0x4a1f5304, 0x06350eec, 0x3b6428a0, 0x100f5208,   // ht.cy.yo_332 is.zu.de_644  sw.lg.so_322 ha.lv.lt_443
  // [7e40]
  0x5200680c, 0x2700060e, 0x0e2910ad, 0x12001907,   // ig.ha.un_530 de.gd.un_550  lt.sl.is_643 gl.hu.un_420
  0x64005213, 0x5200281a, 0x190b0a5a, 0x1f6452ec,   // ha.lg.un_650 sw.ha.un_760  pt.es.gl_553 ha.lg.cy_644
  0x28005219, 0x08022102, 0x2d0d18a4, 0x32171bee,   // ha.sw.un_750 jw.da.no_222  ga.cs.sk_433 tr.sr.bs_422
  0x53643b11, 0x1b114a02, 0x190712a0, 0x3f0902ec,   // so.lg.ht_653 yo.ro.tr_222  hu.it.gl_322 da.pl.af_644
  // [7e50]
  0x17040aee, 0x214a1c0c, 0x2d0e0c04, 0x3f082daf,   // mk.ru.sr_422 id.yo.jw_543  sv.is.sk_332 sk.no.af_655
  0x040c3ba0, 0x0d000e19, 0x050911a7, 0x211735a4,   // so.sv.fi_322 is.cs.un_750  ro.pl.fr_532 zu.sr.jw_433
  0x09200aad, 0x3b010604, 0x0c08060c, 0x642a52a0,   // pt.sq.pl_643 de.en.so_332  de.no.sv_543 ha.mt.lg_322
  0x28001807, 0x0b1101a4, 0x53070aa4, 0x082d1307,   // ga.sw.un_420 en.ro.es_433  pt.it.ht_433 et.sk.no_432
  // [7e60]
  0x354a280c, 0x11070209, 0x1f002a04, 0x0c0e3f0c,   // sw.yo.zu_543 da.it.ro_444  mt.cy.un_320 af.is.sv_543
  0x0900060d, 0x0e2d3f0c, 0x3b002507, 0x351f1860,   // de.pl.un_540 af.sk.is_543  eu.so.un_420 ga.cy.zu_664
  0x29000819, 0x216b1aa9, 0x25131209, 0x1c3521ee,   // no.sl.un_750 tl.ceb.jw_544  hu.et.eu_444 jw.zu.id_422
  0x080c2d55, 0x2a00210c, 0x2d0e0da4, 0x08003f08,   // sk.sv.no_442 jw.mt.un_530  cs.is.sk_433 af.no.un_430
  // [7e70]
  0x6b3b520c, 0x12061e04, 0x20115508, 0x286435af,   // ha.so.ceb_543 ms.de.hu_332  rw.ro.sq_443 zu.lg.sw_655
  0x1a115508, 0x0d2718a4, 0x013506a6, 0x52003507,   // rw.ro.tl_443 ga.gd.cs_433  de.zu.en_521 zu.ha.un_420
  0x0f171602, 0x080c3ba7, 0x0e20550c, 0x211a280c,   // hr.sr.lv_222 so.sv.no_532  rw.sq.is_543 sw.tl.jw_543
  0x04212855, 0x280e5508, 0x2d0d06a4, 0x556408a0,   // sw.jw.fi_442 rw.is.sw_443  de.cs.sk_433 no.lg.rw_322
  // [7e80]
  0x1b521ea0, 0x13000121, 0x522a5508, 0x3b003114,   // ms.ha.tr_322 en.et.un_860  rw.mt.ha_443 az.so.un_660
  0x04551ea0, 0x10550fa4, 0x110501af, 0x27010ba0,   // ms.rw.fi_322 lv.rw.lt_433  en.fr.ro_655 es.en.gd_322
  0x101901a0, 0x6b551ea4, 0x1b3f0802, 0x21001f12,   // en.gl.lt_322 ms.rw.ceb_433  no.af.tr_222 cy.jw.un_640
  0x1e046402, 0x686b1a08, 0x250e0707, 0x161029a4,   // lg.fi.ms_222 tl.ceb.ig_443  it.is.eu_432 sl.lt.hr_433
  // [7e90]
  0x68251107, 0x35313bad, 0x07190e02, 0x256801a0,   // ro.eu.ig_432 so.az.zu_643  is.gl.it_222 en.ig.eu_322
  0x1f033ba9, 0x2d0c1a04, 0x01003f11, 0x113155a4,   // so.nl.cy_544 tl.sv.sk_332  af.en.un_630 rw.az.ro_433
  0x6b3f1aad, 0x210f100c, 0x0e1104a4, 0x3f281307,   // tl.af.ceb_643 lt.lv.jw_543  fi.ro.is_433 et.sw.af_432
  0x0c0b2909, 0x1b0c120c, 0x3f0f2312, 0x6b041aa4,   // sl.es.sv_444 hu.sv.tr_543  ca.lv.af_654 tl.fi.ceb_433
  // [7ea0]
  0x19120a0b, 0x1e162902, 0x1e003504, 0x0100231a,   // pt.hu.gl_542 sl.hr.ms_222  zu.ms.un_320 ca.en.un_760
  0x1c000412, 0x28002521, 0x3f002518, 0x1c121b07,   // fi.id.un_640 eu.sw.un_860  eu.af.un_740 tr.hu.id_432
  0x536b250c, 0x2a120804, 0x2b0e12a7, 0x351f2107,   // eu.ceb.ht_543 no.hu.mt_332  hu.is.vi_532 jw.cy.zu_432
  0x0c0123af, 0x01002320, 0x01002312, 0x083f6407,   // ca.en.sv_655 ca.en.un_850  ca.en.un_640 lg.af.no_432
  // [7eb0]
  0x0e6b07ad, 0x32312aac, 0x0a2d0d11, 0x0e640255,   // it.ceb.is_643 mt.az.bs_632  cs.sk.pt_653 da.lg.is_442
  0x080c060d, 0x0e3b3f04, 0x070811ee, 0x060c02a4,   // de.sv.no_554 af.so.is_332  ro.uk.bg_422 da.sv.de_433
  0x16190b0d, 0x3b00071b, 0x03001904, 0x02002b08,   // es.gl.hr_554 it.so.un_770  gl.nl.un_320 vi.da.un_430
  0x11073ba4, 0x03053f07, 0x3f535213, 0x071c640c,   // so.it.ro_433 af.fr.nl_432  ha.ht.af_665 lg.id.it_543
  // [7ec0]
  0x110d0f12, 0x17000f13, 0x3f0501a0, 0x05006402,   // lv.cs.ro_654 lv.sr.un_650  en.fr.af_322 lg.fr.un_220
  0x1711040c, 0x0d0b1908, 0x211b0c04, 0x18000d1a,   // ru.ro.sr_543 gl.es.cs_443  sv.tr.jw_332 cs.ga.un_760
  0x32294aad, 0x0d051104, 0x2d000a2b, 0x2d001e04,   // yo.sl.bs_643 ro.fr.cs_332  pt.sk.un_980 ms.sk.un_320
  0x061f350c, 0x021213a0, 0x55353baf, 0x3b1e1ca0,   // zu.cy.de_543 et.hu.da_322  so.zu.rw_655 id.ms.so_322
  // [7ed0]
  0x35006809, 0x063f35ad, 0x1e5528ad, 0x352831a7,   // ig.zu.un_440 zu.af.de_643  sw.rw.ms_643 az.sw.zu_532
  0x0d1c13ac, 0x523528ec, 0x0a0410ee, 0x03020c04,   // bh.mr.ne_632 sw.zu.ha_644  be.ru.mk_422 sv.da.nl_332
  0x35000a05, 0x1e1c350e, 0x35001f19, 0x035505a4,   // pt.zu.un_330 zu.id.ms_555  cy.zu.un_750 fr.rw.nl_433
  0x11355508, 0x5300041b, 0x08210e55, 0x2d0d1812,   // rw.zu.ro_443 fi.ht.un_770  is.jw.no_442 ga.cs.sk_654
  // [7ee0]
  0x2a321708, 0x1f000618, 0x3b25030b, 0x19000307,   // sr.bs.mt_443 de.cy.un_740  nl.eu.so_542 nl.gl.un_420
  0x21080e0b, 0x32162912, 0x08060ca0, 0x0e001207,   // is.no.jw_542 sl.hr.bs_654  sv.de.no_322 hu.is.un_420
  0x23003b08, 0x07101707, 0x29202aa0, 0x0c003104,   // so.ca.un_430 sr.be.bg_432  mt.sq.sl_322 az.sv.un_320
  0x09553fec, 0x522a6455, 0x29002a12, 0x04550509,   // af.rw.pl_644 lg.mt.ha_442  mt.sl.un_640 fr.rw.fi_444
  // [7ef0]
  0x032705ee, 0x066e6ba9, 0x17001114, 0x52281f0c,   // fr.gd.nl_422 ceb.hmn.de_544  ro.sr.un_660 cy.sw.ha_543
  0x1e1c0ca6, 0x2d1c21ee, 0x13090804, 0x31080ca0,   // sv.id.ms_521 jw.id.sk_422  no.pl.et_332 sv.no.az_322
  0x1c006422, 0x12202aad, 0x23001307, 0x051310ee,   // lg.id.un_870 mt.sq.hu_643  et.ca.un_420 lt.et.fr_422
  0x09060302, 0x103b1ea0, 0x112a0508, 0x17005312,   // nl.de.pl_222 ms.so.lt_322  fr.mt.ro_443 ht.sr.un_640
  // [7f00]
  0x3b1b1f04, 0x10020fa4, 0x2300020c, 0x0c040805,   // cy.tr.so_332 lv.da.lt_433  da.ca.un_530 no.fi.sv_333
  0x06016e08, 0x3b2a1c07, 0x2a000602, 0x0501060c,   // hmn.en.de_443 id.mt.so_432  de.mt.un_220 de.en.fr_543
  0x28556ead, 0x06001b0c, 0x192d0deb, 0x18271f08,   // hmn.rw.sw_643 tr.de.un_530  cs.sk.gl_662 cy.gd.ga_443
  0x21100f12, 0x286455ee, 0x100a13a4, 0x2100680e,   // lv.lt.jw_654 rw.lg.sw_422  et.pt.lt_433 ig.jw.un_550
  // [7f10]
  0x29001b19, 0x3f1220a4, 0x32170daf, 0x1e000f21,   // tr.sl.un_750 sq.hu.af_433  cs.sr.bs_655 lv.ms.un_860
  0x1100270d, 0x0e1013a0, 0x0e00190c, 0x10080204,   // gd.ro.un_540 et.lt.is_322  gl.is.un_530 da.no.lt_332
  0x0b002504, 0x05003102, 0x182709a4, 0x13080ea0,   // eu.es.un_320 az.fr.un_220  pl.gd.ga_433 is.no.et_322
  0x642802a0, 0x0e020811, 0x09271eee, 0x0235080c,   // da.sw.lg_322 no.da.is_653  ms.gd.pl_422 no.zu.da_543
  // [7f20]
  0x5264080c, 0x011a2704, 0x2d001220, 0x55083513,   // no.lg.ha_543 gd.tl.en_332  hu.sk.un_850 zu.no.rw_665
  0x2a200704, 0x20080607, 0x3f060808, 0x04211c5a,   // it.sq.mt_332 de.no.sq_432  no.de.af_443 id.jw.fi_553
  0x19090a07, 0x29063508, 0x4a00270e, 0x53081b07,   // pt.pl.gl_432 zu.de.sl_443  gd.yo.un_550 tr.no.ht_432
  0x17100705, 0x09121813, 0x2a07010b, 0x16080208,   // bg.be.sr_333 ga.hu.pl_665  en.it.mt_542 da.no.hr_443
  // [7f30]
  0x130608a7, 0x011a2112, 0x12001f1b, 0x21006807,   // no.de.et_532 jw.tl.en_654  cy.hu.un_770 ig.jw.un_420
  0x060312a9, 0x645368a7, 0x130c040c, 0x64556ba4,   // hu.nl.de_544 ig.ht.lg_532  fi.sv.et_543 ceb.rw.lg_433
  0x6400090c, 0x35001f0d, 0x3b643f05, 0x0d1219a0,   // pl.lg.un_530 cy.zu.un_540  af.lg.so_333 gl.hu.cs_322
  0x35645355, 0x64001314, 0x17001018, 0x0d001004,   // ht.lg.zu_442 et.lg.un_660  be.sr.un_740 lt.cs.un_320
  // [7f40]
  0x531113a0, 0x21001008, 0x21026b07, 0x1b313bec,   // et.ro.ht_322 lt.jw.un_430  ceb.da.jw_432 so.az.tr_644
  0x52001a0c, 0x17033f04, 0x024a5502, 0x53355208,   // tl.ha.un_530 af.nl.sr_332  rw.yo.da_222 ha.zu.ht_443
  0x1a0b6b08, 0x1e005207, 0x351c21a7, 0x161f2702,   // ceb.es.tl_443 ha.ms.un_420  jw.id.zu_532 gd.cy.hr_222
  0x6e080eec, 0x35646b07, 0x291602a0, 0x28526b08,   // is.no.hmn_644 ceb.lg.zu_432  da.hr.sl_322 ceb.ha.sw_443
  // [7f50]
  0x0300040d, 0x531f64ac, 0x16290da0, 0x01183bee,   // fi.nl.un_540 lg.cy.ht_632  cs.sl.hr_322 so.ga.en_422
  0x645355a7, 0x130153a0, 0x312d0907, 0x355255ee,   // rw.ht.lg_532 ht.en.et_322  pl.sk.az_432 rw.ha.zu_422
  0x201b2ba4, 0x31006b07, 0x03000404, 0x09001107,   // vi.tr.sq_433 ceb.az.un_420  fi.nl.un_320 ro.pl.un_420
  0x23181f04, 0x23070ba4, 0x250723a0, 0x072a19ee,   // cy.ga.ca_332 es.it.ca_433  ca.it.eu_322 gl.mt.it_422
  // [7f60]
  0x31001f05, 0x0a001021, 0x5300550c, 0x4a00532a,   // cy.az.un_330 be.mk.un_860  rw.ht.un_530 ht.yo.un_970
  0x0d122d55, 0x640e09ee, 0x04131104, 0x043113af,   // sk.hu.cs_442 pl.is.lg_422  ro.et.fi_332 et.az.fi_655
  0x2d2920af, 0x53001308, 0x2a0413ad, 0x3213040c,   // sq.sl.sk_655 et.ht.un_430  et.fi.mt_643 fi.et.bs_543
  0x100964a4, 0x201f13ee, 0x1b312d08, 0x060e0804,   // lg.pl.lt_433 et.cy.sq_422  sk.az.tr_443 no.is.de_332
  // [7f70]
  0x160f13a4, 0x53000704, 0x09312008, 0x0b0a3ba4,   // et.lv.hr_433 it.ht.un_320  sq.az.pl_443 so.pt.es_433
  0x0e2d090c, 0x0c083fee, 0x202d0d14, 0x121013a7,   // pl.sk.is_543 af.no.sv_422  cs.sk.sq_666 et.lt.hu_532
  0x0b0a0502, 0x071013ee, 0x1e312a12, 0x2d0413ad,   // fr.pt.es_222 et.lt.it_422  mt.az.ms_654 et.fi.sk_643
  0x6e00532a, 0x12006b09, 0x1b3b55a0, 0x0c232b08,   // ht.hmn.un_970 ceb.hu.un_440  rw.so.tr_322 vi.ca.sv_443
  // [7f80]
  0x13000513, 0x20216412, 0x27183507, 0x55110a05,   // fr.et.un_650 lg.jw.sq_654  zu.ga.gd_432 pt.ro.rw_333
  0x085301a0, 0x130601ee, 0x68203555, 0x1a0b6b0c,   // en.ht.no_322 en.de.et_422  zu.sq.ig_442 ceb.es.tl_543
  0x280611ee, 0x09005321, 0x28353b0c, 0x052b0c08,   // ro.de.sw_422 ht.pl.un_860  so.zu.sw_543 sv.vi.fr_443
  0x251801ee, 0x0c00082c, 0x2304010c, 0x3b0e11a4,   // en.ga.eu_422 no.sv.un_990  en.fi.ca_543 ro.is.so_433
  // [7f90]
  0x05003504, 0x1b000e11, 0x2902160c, 0x17002308,   // zu.fr.un_320 is.tr.un_630  hr.da.sl_543 ca.sr.un_430
  0x04001113, 0x25170aa0, 0x12190e05, 0x0a6b1ba0,   // ro.ru.un_650 pt.sr.eu_322  is.gl.hu_333 tr.ceb.pt_322
  0x2d0d0ca0, 0x21283511, 0x05522aad, 0x286404ad,   // sv.cs.sk_322 zu.sw.jw_653  mt.ha.fr_643 fi.lg.sw_643
  0x20003f0d, 0x53001a0c, 0x2900110d, 0x0d2911a7,   // af.sq.un_540 tl.ht.un_530  ro.sl.un_540 ro.sl.cs_532
  // [7fa0]
  0x201c1ea0, 0x10062005, 0x07230a04, 0x0600032c,   // ms.id.sq_322 sq.de.lt_333  pt.ca.it_332 nl.de.un_990
  0x05006419, 0x1f005302, 0x08000611, 0x05282b07,   // lg.fr.un_750 ht.cy.un_220  de.no.un_630 vi.sw.fr_432
  0x6b000412, 0x0a040809, 0x10033f08, 0x2000270d,   // fi.ceb.un_640 uk.ru.mk_444  af.nl.lt_443 gd.sq.un_540
  0x02641109, 0x06020c14, 0x201703ee, 0x313f010c,   // ro.lg.da_444 sv.da.de_666  nl.sr.sq_422 en.af.az_543
  // [7fb0]
  0x1710010c, 0x0f002314, 0x13230c08, 0x13013b04,   // en.lt.sr_543 ca.lv.un_660  sv.ca.et_443 so.en.et_332
  0x040501ec, 0x050a230e, 0x25000512, 0x0500012b,   // en.fr.fi_644 ca.pt.fr_555  fr.eu.un_640 en.fr.un_980
  0x030208a4, 0x1e111caf, 0x0c0523ec, 0x0a310eac,   // no.da.nl_433 id.ro.ms_655  ca.fr.sv_644 is.az.pt_632
  0x12000a02, 0x2a2920a7, 0x3f040312, 0x050c23ad,   // pt.hu.un_220 sq.sl.mt_532  nl.fi.af_654 ca.sv.fr_643
  // [7fc0]
  0x31171008, 0x3b003f05, 0x3b002302, 0x11120807,   // lt.sr.az_443 af.so.un_330  ca.so.un_220 no.hu.ro_432
  0x250b53a0, 0x3b2813a0, 0x3500640c, 0x31001905,   // ht.es.eu_322 et.sw.so_322  lg.zu.un_530 gl.az.un_330
  0x31033fa0, 0x10033f0c, 0x070c040c, 0x0a25010c,   // af.nl.az_322 af.nl.lt_543  fi.sv.it_543 en.eu.pt_543
  0x060405a6, 0x0c040107, 0x18006b09, 0x0c002311,   // fr.fi.de_521 en.fi.sv_432  ceb.ga.un_440 ca.sv.un_630
  // [7fd0]
  0x64682160, 0x250c2308, 0x0c002308, 0x130c2307,   // jw.ig.lg_664 ca.sv.eu_443  ca.sv.un_430 ca.sv.et_432
  0x21522804, 0x29005502, 0x181f2712, 0x64133bac,   // sw.ha.jw_332 rw.sl.un_220  gd.cy.ga_654 so.et.lg_632
  0x20110f5a, 0x55190bad, 0x532023ad, 0x32172909,   // lv.ro.sq_553 es.gl.rw_643  ca.sq.ht_643 sl.sr.bs_444
  0x281827a4, 0x35254a07, 0x2818270e, 0x13002a1a,   // gd.ga.sw_433 yo.eu.zu_432  gd.ga.sw_555 mt.et.un_760
  // [7fe0]
  0x13642a0c, 0x4a002007, 0x643207ee, 0x171004a4,   // mt.lg.et_543 sq.yo.un_420  it.bs.lg_422 ru.be.sr_433
  0x07102708, 0x20000619, 0x203f0807, 0x03172007,   // gd.lt.it_443 de.sq.un_750  no.af.sq_432 sq.sr.nl_432
  0x121e1c55, 0x1f1827af, 0x6b033f0d, 0x1c121e04,   // id.ms.hu_442 gd.ga.cy_655  af.nl.ceb_554 ms.hu.id_332
  0x1b090ea4, 0x010a23a0, 0x55002d0d, 0x6b3b31a9,   // is.pl.tr_433 ca.pt.en_322  sk.rw.un_540 az.so.ceb_544
  // [7ff0]
  0x16000b02, 0x31131b08, 0x0e0164ee, 0x06002909,   // es.hr.un_220 tr.et.az_443  lg.en.is_422 sl.de.un_440
  0x3f6b28a0, 0x031e3fa0, 0x0f095508, 0x0b0a08a0,   // sw.ceb.af_322 af.ms.nl_322  rw.pl.lv_443 no.pt.es_322
  0x081f120c, 0x29001f07, 0x190a2309, 0x01033f02,   // hu.cy.no_543 cy.sl.un_420  ca.pt.gl_444 af.nl.en_222
  0x080c12a0, 0x03002302, 0x06001f08, 0x52001320,   // hu.sv.no_322 ca.nl.un_220  cy.de.un_430 et.ha.un_850

  // [8000]
  0x0f4a0a07, 0x0f1f5205, 0x23000f08, 0x1f03020c,   // pt.yo.lv_432 ha.cy.lv_333  lv.ca.un_430 da.nl.cy_543
  0x4a000e05, 0x06001114, 0x02000809, 0x1b4a2504,   // is.yo.un_330 ro.de.un_660  no.da.un_440 eu.yo.tr_332
  0x030c13ee, 0x03535555, 0x08022012, 0x1c55210c,   // et.sv.nl_422 rw.ht.nl_442  sq.da.no_654 jw.rw.id_543
  0x32002008, 0x0f202912, 0x64101f07, 0x320c0e07,   // sq.bs.un_430 sl.sq.lv_654  cy.lt.lg_432 is.sv.bs_432
  // [8010]
  0x12006e23, 0x172923a4, 0x53001022, 0x0b1f13ec,   // hmn.hu.un_880 ca.sl.sr_433  lt.ht.un_870 et.cy.es_644
  0x2a536e5a, 0x09004a12, 0x55004a02, 0x203207a0,   // hmn.ht.mt_553 yo.pl.un_640  yo.rw.un_220 it.bs.sq_322
  0x02006404, 0x4a2a06ec, 0x53002007, 0x056e3f0c,   // lg.da.un_320 de.mt.yo_644  sq.ht.un_420 af.hmn.fr_543
  0x0a063f07, 0x1f002a29, 0x6b3f08ee, 0x11006e1a,   // af.de.pt_432 mt.cy.un_960  no.af.ceb_422 hmn.ro.un_760
  // [8020]
  0x1700070d, 0x041a11af, 0x13000811, 0x170807ee,   // bg.sr.un_540 ro.tl.fi_655  no.et.un_630 bg.uk.sr_422
  0x05000109, 0x6e00272a, 0x09233108, 0x03001b04,   // en.fr.un_440 gd.hmn.un_970  az.ca.pl_443 tr.nl.un_320
  0x08003202, 0x321710a0, 0x27061aa0, 0x13103ba9,   // bs.no.un_220 lt.sr.bs_322  tl.de.gd_322 so.lt.et_544
  0x093f0308, 0x1a041812, 0x271c04a0, 0x10291a12,   // nl.af.pl_443 ga.fi.tl_654  fi.id.gd_322 tl.sl.lt_654
  // [8030]
  0x29001105, 0x023b1f0d, 0x2a001208, 0x17166ba4,   // ro.sl.un_330 cy.so.da_554  hu.mt.un_430 ceb.hr.sr_433
  0x031b2807, 0x283b0904, 0x21101ea0, 0x252b20ec,   // sw.tr.nl_432 pl.so.sw_332  ms.lt.jw_322 sq.vi.eu_644
  0x1b313b0e, 0x2a126e14, 0x55643b14, 0x32170f02,   // so.az.tr_555 hmn.hu.mt_666  so.lg.rw_666 lv.sr.bs_222
  0x4a0c200e, 0x27556460, 0x1c054a12, 0x190a53af,   // sq.sv.yo_555 lg.rw.gd_664  yo.fr.id_654 ht.pt.gl_655
  // [8040]
  0x020c11af, 0x28110513, 0x190a2314, 0x68311b13,   // ro.sv.da_655 fr.ro.sw_665  ca.pt.gl_666 tr.az.ig_665
  0x0a1923ad, 0x20002504, 0x110a1faf, 0x0723080c,   // ca.gl.pt_643 eu.sq.un_320  cy.pt.ro_655 no.ca.it_543
  0x28535207, 0x68071f0c, 0x1b2a0713, 0x080a1014,   // ha.ht.sw_432 cy.it.ig_543  it.mt.tr_665 be.mk.uk_666
  0x16002807, 0x6e002b19, 0x3b28520d, 0x0300251a,   // sw.hr.un_420 vi.hmn.un_750  ha.sw.so_554 eu.nl.un_760
  // [8050]
  0x03001208, 0x0a192307, 0x3f1304ad, 0x0f4a3113,   // hu.nl.un_430 ca.gl.pt_432  fi.et.af_643 az.yo.lv_665
  0x2b1605ec, 0x55006b1a, 0x190a23ec, 0x102b050c,   // fr.hr.vi_644 ceb.rw.un_760  ca.pt.gl_644 fr.vi.lt_543
  0x01524a07, 0x05280ba9, 0x13002a19, 0x4a2b01ee,   // yo.ha.en_432 es.sw.fr_544  mt.et.un_750 en.vi.yo_422
  0x13071f0c, 0x2b005304, 0x21190aa7, 0x525506a4,   // cy.it.et_543 ht.vi.un_320  pt.gl.jw_532 de.rw.ha_433
  // [8060]
  0x29002504, 0x2a094a08, 0x20042902, 0x07080a02,   // eu.sl.un_320 yo.pl.mt_443  sl.fi.sq_222 mk.uk.bg_222
  0x1b310e08, 0x2d250d02, 0x322907a9, 0x040764a9,   // is.az.tr_443 cs.eu.sk_222  it.sl.bs_544 lg.it.fi_544
  0x012d090d, 0x53000d04, 0x072327a4, 0x1b311213,   // pl.sk.en_554 cs.ht.un_320  gd.ca.it_433 hu.az.tr_665
  0x27003b1a, 0x31121b0c, 0x3100090d, 0x29311ba0,   // so.gd.un_760 tr.hu.az_543  pl.az.un_540 tr.az.sl_322
  // [8070]
  0x2a093b0d, 0x2a311b0c, 0x132507a0, 0x07311b0d,   // so.pl.mt_554 tr.az.mt_543  it.eu.et_322 tr.az.it_554
  0x0e0b0a05, 0x0500130b, 0x10002904, 0x09292da0,   // pt.es.is_333 et.fr.un_520  sl.lt.un_320 sk.sl.pl_322
  0x04110607, 0x12250405, 0x1f250805, 0x015305ee,   // de.ro.fi_432 fi.eu.hu_333  no.eu.cy_333 fr.ht.en_422
  0x0e061f07, 0x1b3112ec, 0x06081204, 0x055303a0,   // cy.de.is_432 hu.az.tr_644  hu.no.de_332 nl.ht.fr_322
  // [8080]
  0x171305ad, 0x2028120c, 0x3f060308, 0x080e0608,   // fr.et.sr_643 hu.sw.sq_543  nl.de.af_443 de.is.no_443
  0x040717ad, 0x35271804, 0x06033fee, 0x082102a4,   // sr.bg.ru_643 ga.gd.zu_332  af.nl.de_422 da.jw.no_433
  0x033f06a7, 0x1b000811, 0x35211814, 0x1b2113ee,   // de.af.nl_532 no.tr.un_630  ga.jw.zu_666 et.jw.tr_422
  0x1312040c, 0x27003511, 0x080c02ee, 0x1a001b22,   // fi.hu.et_543 zu.gd.un_630  da.sv.no_422 tr.tl.un_870
  // [8090]
  0x3f003202, 0x2d000204, 0x53000407, 0x27230608,   // bs.af.un_220 da.sk.un_320  fi.ht.un_420 de.ca.gd_443
  0x06000314, 0x311b01ee, 0x1800010c, 0x0f030cee,   // nl.de.un_660 en.tr.az_422  en.ga.un_530 sv.nl.lv_422
  0x13003119, 0x1a352707, 0x1b1101a4, 0x072a05a7,   // az.et.un_750 gd.zu.tl_432  en.ro.tr_433 fr.mt.it_532
  0x06000907, 0x12290407, 0x100f17a4, 0x25001604,   // pl.de.un_420 fi.sl.hu_432  sr.lv.lt_433 hr.eu.un_320
  // [80a0]
  0x28010c55, 0x1b6b1a12, 0x17005504, 0x123204ee,   // sv.en.sw_442 tl.ceb.tr_654  rw.sr.un_320 fi.bs.hu_422
  0x17000119, 0x17070d07, 0x166b2dee, 0x6b1e1c05,   // en.sr.un_750 cs.it.sr_432  sk.ceb.hr_422 id.ms.ceb_333
  0x53002109, 0x28006812, 0x3b000e05, 0x32000308,   // jw.ht.un_440 ig.sw.un_640  is.so.un_330 nl.bs.un_430
  0x19530ba7, 0x103f0907, 0x2d1b3104, 0x641a53a7,   // es.ht.gl_532 pl.af.lt_432  az.tr.sk_332 ht.tl.lg_532
  // [80b0]
  0x23110505, 0x0f1017a0, 0x52001f02, 0x10285208,   // fr.ro.ca_333 sr.lt.lv_322  cy.ha.un_220 ha.sw.lt_443
  0x4a005520, 0x04000304, 0x0b0a1fa0, 0x100b1307,   // rw.yo.un_850 nl.fi.un_320  cy.pt.es_322 et.es.lt_432
  0x551c5208, 0x0b000a12, 0x080e10a7, 0x642d6807,   // ha.id.rw_443 pt.es.un_640  lt.is.no_532 ig.sk.lg_432
  0x55006b18, 0x110d3f04, 0x0c2808a0, 0x4a25550c,   // ceb.rw.un_740 af.cs.ro_332  no.sw.sv_322 rw.eu.yo_543
  // [80c0]
  0x551e28a4, 0x201b3204, 0x686407a4, 0x2d0d35ec,   // sw.ms.rw_433 bs.tr.sq_332  it.lg.ig_433 zu.cs.sk_644
  0x4a001e04, 0x0a00040e, 0x172a0c08, 0x2d0d3514,   // ms.yo.un_320 ru.mk.un_550  sv.mt.sr_443 zu.cs.sk_666
  0x0a10080c, 0x211b1ea4, 0x28211cad, 0x2a0e2808,   // uk.be.mk_543 ms.tr.jw_433  id.jw.sw_643 sw.is.mt_443
  0x120b190c, 0x313f04a0, 0x1a282714, 0x1b000614,   // gl.es.hu_543 fi.af.az_322  gd.sw.tl_666 de.tr.un_660
  // [80d0]
  0x09001318, 0x180b280c, 0x1000311b, 0x1b000813,   // bh.hi.un_740 sw.es.ga_543  az.lt.un_770 no.tr.un_650
  0x101117ee, 0x231811a4, 0x3500040c, 0x04202bad,   // sr.ro.lt_422 ro.ga.ca_433  fi.zu.un_530 vi.sq.fi_643
  0x1e252007, 0x02001b18, 0x11200408, 0x311b1a02,   // sq.eu.ms_432 tr.da.un_740  fi.sq.ro_443 tl.tr.az_222
  0x31321bec, 0x250623a0, 0x35003f08, 0x09200408,   // tr.bs.az_644 ca.de.eu_322  af.zu.un_430 fi.sq.pl_443
  // [80e0]
  0x0c003108, 0x08310ca4, 0x25112004, 0x3b1f0904,   // az.sv.un_430 sv.az.no_433  sq.ro.eu_332 pl.cy.so_332
  0x1b0e2d07, 0x11002004, 0x04201fa4, 0x160e0da4,   // sk.is.tr_432 sq.ro.un_320  cy.sq.fi_433 cs.is.hr_433
  0x1e1c4aa0, 0x0f321702, 0x3b0e0211, 0x2800181a,   // yo.id.ms_322 sr.bs.lv_222  da.is.so_653 ga.sw.un_760
  0x02201b07, 0x68182712, 0x100408a7, 0x13311109,   // tr.sq.da_432 gd.ga.ig_654  uk.ru.be_532 ro.az.et_444
  // [80f0]
  0x27111807, 0x06531f0d, 0x25131bec, 0x21072aec,   // ga.ro.gd_432 cy.ht.de_554  tr.et.eu_644 mt.it.jw_644
  0x28130404, 0x2520190c, 0x35552512, 0x11271811,   // fi.et.sw_332 gl.sq.eu_543  eu.rw.zu_654 ga.gd.ro_653
  0x110405a4, 0x041f2013, 0x0817105a, 0x111f200c,   // fr.fi.ro_433 sq.cy.fi_665  be.sr.uk_553 sq.cy.ro_543
  0x042520a4, 0x062718a7, 0x03001c07, 0x23643509,   // sq.eu.fi_433 ga.gd.de_532  id.nl.un_420 zu.lg.ca_444
  // [8100]
  0x01061fa7, 0x0d0913a6, 0x02182711, 0x2818110c,   // cy.de.en_532 bh.hi.ne_521  gd.ga.da_653 ro.ga.sw_543
  0x07642502, 0x6e006b05, 0x04130c02, 0x17160307,   // eu.lg.it_222 ceb.hmn.un_330  sv.et.fi_222 nl.hr.sr_432
  0x1152350c, 0x1225530d, 0x0e2553a0, 0x05002b12,   // zu.ha.ro_543 ht.eu.hu_554  ht.eu.is_322 vi.fr.un_640
  0x04211c08, 0x282a010c, 0x251206ad, 0x0553060d,   // id.jw.fi_443 en.mt.sw_543  de.hu.eu_643 de.ht.fr_554
  // [8110]
  0x0e000d0c, 0x0c0413a7, 0x2900170e, 0x4a006807,   // cs.is.un_530 et.fi.sv_532  sr.sl.un_550 ig.yo.un_420
  0x64002818, 0x53120cad, 0x12002302, 0x16001f08,   // sw.lg.un_740 sv.hu.ht_643  ca.hu.un_220 cy.hr.un_430
  0x251805ad, 0x2900130e, 0x646b12ad, 0x231c550b,   // fr.ga.eu_643 et.sl.un_550  hu.ceb.lg_643 rw.id.ca_542
  0x251f17a0, 0x0c2d31ee, 0x13000e08, 0x521c1eee,   // sr.cy.eu_322 az.sk.sv_422  is.et.un_430 ms.id.ha_422
  // [8120]
  0x6400120d, 0x08020fee, 0x04001802, 0x281b53a4,   // hu.lg.un_540 lv.da.no_422  ga.fi.un_220 ht.tr.sw_433
  0x55003b07, 0x19112308, 0x64205355, 0x20005319,   // so.rw.un_420 ca.ro.gl_443  ht.sq.lg_442 ht.sq.un_750
  0x1b000e13, 0x27001119, 0x53002008, 0x35002005,   // is.tr.un_650 ro.gd.un_750  sq.ht.un_430 sq.zu.un_330
  0x3f020ead, 0x52000e08, 0x080235ec, 0x1e1c0ea0,   // is.da.af_643 is.ha.un_430  zu.da.no_644 is.id.ms_322
  // [8130]
  0x131e2a09, 0x27001c02, 0x523b0408, 0x1f00012a,   // mt.ms.et_444 id.gd.un_220  fi.so.ha_443 en.cy.un_970
  0x16290e07, 0x3b005511, 0x1f1801ee, 0x09061f02,   // is.sl.hr_432 rw.so.un_630  en.ga.cy_422 cy.de.pl_222
  0x040918a4, 0x2d010d07, 0x102007ee, 0x0d000119,   // ga.pl.fi_433 cs.en.sk_432  it.sq.lt_422 en.cs.un_750
  0x1b3b0708, 0x0a2d0d0b, 0x09121112, 0x010a2304,   // it.so.tr_443 cs.sk.pt_542  ro.hu.pl_654 ca.pt.en_332
  // [8140]
  0x2b1825a0, 0x1f070fa4, 0x0428250c, 0x0d001f11,   // eu.ga.vi_322 lv.it.cy_433  eu.sw.fi_543 cy.cs.un_630
  0x2500041b, 0x2b001319, 0x2b0421a4, 0x042825ad,   // fi.eu.un_770 et.vi.un_750  jw.fi.vi_433 eu.sw.fi_643
  0x011308ee, 0x28042508, 0x04282555, 0x280425a9,   // no.et.en_422 eu.fi.sw_443  eu.sw.fi_442 eu.fi.sw_544
  0x01000d08, 0x3b3f01ad, 0x28192512, 0x0d003b0c,   // cs.en.un_430 en.af.so_643  eu.gl.sw_654 so.cs.un_530
  // [8150]
  0x0e003b12, 0x55001b13, 0x351a1bad, 0x3b1e1c0e,   // so.is.un_640 tr.rw.un_650  tr.tl.zu_643 id.ms.so_555
  0x190a2504, 0x6b1b35a4, 0x321704af, 0x05005202,   // eu.pt.gl_332 zu.tr.ceb_433  fi.sr.bs_655 ha.fr.un_220
  0x25042812, 0x1b002308, 0x28250412, 0x351a55a4,   // sw.fi.eu_654 ca.tr.un_430  fi.eu.sw_654 rw.tl.zu_433
  0x0f135504, 0x52000504, 0x12001f23, 0x551b6bac,   // rw.et.lv_332 fr.ha.un_320  cy.hu.un_880 ceb.tr.rw_632
  // [8160]
  0x281355af, 0x35001308, 0x0d290a0b, 0x05555304,   // rw.et.sw_655 et.zu.un_430  pt.sl.cs_542 ht.rw.fr_332
  0x033f3bee, 0x0e1a6b04, 0x0c07010c, 0x02200807,   // so.af.nl_422 ceb.tl.is_332  en.it.sv_543 no.sq.da_432
  0x3b09290c, 0x310420a7, 0x1a120fa4, 0x1309270b,   // sl.pl.so_543 sq.fi.az_532  lv.hu.tl_433 gd.pl.et_542
  0x07081709, 0x170d29a4, 0x1f001113, 0x232501a4,   // sr.uk.bg_444 sl.cs.sr_433  ro.cy.un_650 en.eu.ca_433
  // [8170]
  0x07552a08, 0x092d08a0, 0x28080c08, 0x28355207,   // mt.rw.it_443 no.sk.pl_322  sv.no.sw_443 ha.zu.sw_432
  0x2a00680c, 0x6b0501ee, 0x2b002513, 0x21050dac,   // ig.mt.un_530 en.fr.ceb_422  eu.vi.un_650 cs.fr.jw_632
  0x06002304, 0x31002013, 0x35003f14, 0x046b28a0,   // ca.de.un_320 sq.az.un_650  af.zu.un_660 sw.ceb.fi_322
  0x0900280d, 0x2d000307, 0x0d0f040b, 0x3f2b35a0,   // sw.pl.un_540 nl.sk.un_420  fi.lv.cs_542 zu.vi.af_322
  // [8180]
  0x07110a14, 0x19002b0c, 0x21011bac, 0x0b0a250c,   // mk.ro.bg_666 vi.gl.un_530  tr.en.jw_632 eu.pt.es_543
  0x3f031fee, 0x17000807, 0x053b1fa7, 0x251a5507,   // cy.nl.af_422 uk.sr.un_420  cy.so.fr_532 rw.tl.eu_432
  0x0e081f07, 0x032a3507, 0x4a52060c, 0x530e28a7,   // cy.no.is_432 zu.mt.nl_432  de.ha.yo_543 sw.is.ht_532
  0x28211cee, 0x081f0204, 0x250605a7, 0x35006807,   // id.jw.sw_422 da.cy.no_332  fr.de.eu_532 ig.zu.un_420
  // [8190]
  0x0c083f5a, 0x0e1f1b11, 0x551c64a0, 0x1a2a1e0c,   // af.no.sv_553 tr.cy.is_653  lg.id.rw_322 ms.mt.tl_543
  0x01000618, 0x55642105, 0x070811ac, 0x532928a0,   // de.en.un_740 jw.lg.rw_333  ro.uk.bg_632 sw.sl.ht_322
  0x230e5255, 0x0800170b, 0x0c070eee, 0x0c550611,   // ha.is.ca_442 sr.no.un_520  is.it.sv_422 de.rw.sv_653
  0x0900250d, 0x0b00110d, 0x0f050408, 0x044a230c,   // eu.pl.un_540 ro.es.un_540  fi.fr.lv_443 ca.yo.fi_543
  // [81a0]
  0x03053fee, 0x322117a0, 0x1e1c0202, 0x1b000f0b,   // af.fr.nl_422 sr.jw.bs_322  da.id.ms_222 lv.tr.un_520
  0x53001004, 0x04251108, 0x0a182712, 0x056e0aee,   // lt.ht.un_320 ro.eu.fi_443  gd.ga.pt_654 pt.hmn.fr_422
  0x17291f0c, 0x2013075a, 0x35006b08, 0x1f520eec,   // cy.sl.sr_543 it.et.sq_553  ceb.zu.un_430 is.ha.cy_644
  0x6b011aa4, 0x293120ee, 0x4a000e12, 0x080b1aa0,   // tl.en.ceb_433 sq.az.sl_422  is.yo.un_640 tl.es.no_322
  // [81b0]
  0x0f2a1f08, 0x171011a0, 0x1c00250b, 0x01641aee,   // cy.mt.lv_443 ro.be.sr_322  eu.id.un_520 tl.lg.en_422
  0x16111e04, 0x3b132808, 0x182753a4, 0x1c1f23a7,   // ms.ro.hr_332 sw.et.so_443  ht.gd.ga_433 ca.cy.id_532
  0x2a1629a4, 0x012b1a07, 0x6b230b08, 0x3f0753a0,   // sl.hr.mt_433 tl.vi.en_432  es.ca.ceb_443 ht.it.af_322
  0x3b00680d, 0x3b211f04, 0x1000091b, 0x27642802,   // ig.so.un_540 cy.jw.so_332  pl.lt.un_770 sw.lg.gd_222
  // [81c0]
  0x1629120c, 0x0c3f0eee, 0x5300110b, 0x2a091f12,   // hu.sl.hr_543 is.af.sv_422  ro.ht.un_520 cy.pl.mt_654
  0x52552355, 0x6b1a210c, 0x0e6411a7, 0x162d6bee,   // ca.rw.ha_442 jw.tl.ceb_543  ro.lg.is_532 ceb.sk.hr_422
  0x27230d07, 0x3b00252a, 0x316b1b08, 0x3b0908a4,   // cs.ca.gd_432 eu.so.un_970  tr.ceb.az_443 no.pl.so_433
  0x6b1a2511, 0x2a002011, 0x08003504, 0x3f250ea4,   // eu.tl.ceb_653 sq.mt.un_630  zu.no.un_320 is.eu.af_433
  // [81d0]
  0x09350808, 0x551c1a0c, 0x1b0e2304, 0x212801a0,   // no.zu.pl_443 tl.id.rw_543  ca.is.tr_332 en.sw.jw_322
  0x2a3201ad, 0x1a520ead, 0x0900351a, 0x2d0a05a4,   // en.bs.mt_643 is.ha.tl_643  zu.pl.un_760 fr.pt.sk_433
  0x2d0d1ea0, 0x1a0a64a0, 0x4a003202, 0x0d5221ee,   // ms.cs.sk_322 lg.pt.tl_322  bs.yo.un_220 jw.ha.cs_422
  0x19645513, 0x0917350c, 0x556e210c, 0x11040a13,   // rw.lg.gl_665 zu.sr.pl_543  jw.hmn.rw_543 mk.ru.ro_665
  // [81e0]
  0x05013bee, 0x351355ec, 0x5500041b, 0x5235090d,   // so.en.fr_422 rw.et.zu_644  fi.rw.un_770 pl.zu.ha_554
  0x081c2104, 0x25211aa4, 0x0c002812, 0x32082da4,   // jw.id.no_332 tl.jw.eu_433  sw.sv.un_640 sk.no.bs_433
  0x355513ad, 0x21682a07, 0x21000804, 0x11131a08,   // et.rw.zu_643 mt.ig.jw_432  no.jw.un_320 tl.et.ro_443
  0x13001c05, 0x28114a05, 0x53124a04, 0x2710250c,   // mr.bh.un_330 yo.ro.sw_333  yo.hu.ht_332 eu.lt.gd_543
  // [81f0]
  0x1b3508a4, 0x07531112, 0x281b3513, 0x211c4a04,   // no.zu.tr_433 ro.ht.it_654  zu.tr.sw_665 yo.id.jw_332
  0x0c311b04, 0x2a1c1e0c, 0x04110a5a, 0x03100107,   // tr.az.sv_332 ms.id.mt_543  mk.ro.ru_553 en.lt.nl_432
  0x13020812, 0x25071ca4, 0x1300351b, 0x1a6b5513,   // no.da.et_654 id.it.eu_433  zu.et.un_770 rw.ceb.tl_665
  0x28033509, 0x173112a4, 0x64002812, 0x081b12a9,   // zu.nl.sw_444 hu.az.sr_433  sw.lg.un_640 hu.tr.no_544
  // [8200]
  0x292808a0, 0x2d05210c, 0x1b0452ad, 0x0f1b12a7,   // no.sw.sl_322 jw.fr.sk_543  ha.fi.tr_643 hu.tr.lv_532
  0x35041eee, 0x4a2052ec, 0x1e091ca0, 0x31002a0d,   // ms.fi.zu_422 ha.sq.yo_644  id.pl.ms_322 mt.az.un_540
  0x101c2ba9, 0x0912350c, 0x21534aa7, 0x090813a0,   // vi.id.lt_544 zu.hu.pl_543  yo.ht.jw_532 et.no.pl_322
  0x4a100aa7, 0x12351b60, 0x3f031208, 0x1600320d,   // pt.lt.yo_532 tr.zu.hu_664  hu.nl.af_443 bs.hr.un_540
  // [8210]
  0x111b12a9, 0x13124aa4, 0x121b0107, 0x0c120802,   // hu.tr.ro_544 yo.hu.et_433  en.tr.hu_432 no.hu.sv_222
  0x18000e14, 0x0f3b100b, 0x16291ba9, 0x100a0402,   // is.ga.un_660 lt.so.lv_542  tr.sl.hr_544 ru.mk.be_222
  0x10001b09, 0x101c1ea0, 0x3b002702, 0x101c3ba0,   // tr.lt.un_440 ms.id.lt_322  gd.so.un_220 so.id.lt_322
  0x3b020fa0, 0x030553a0, 0x08096bee, 0x1e00060d,   // lv.da.so_322 ht.fr.nl_322  ceb.pl.no_422 de.ms.un_540
  // [8220]
  0x09002809, 0x06003b14, 0x1b3b1c55, 0x13100c0d,   // sw.pl.un_440 so.de.un_660  id.so.tr_442 sv.lt.et_554
  0x053f28a6, 0x3b0e1b0e, 0x101707a0, 0x0d2d12ad,   // sw.af.fr_521 tr.is.so_555  bg.sr.be_322 hu.sk.cs_643
  0x0a002b08, 0x080c2107, 0x2d181213, 0x133b04ec,   // vi.pt.un_430 jw.sv.no_432  hu.ga.sk_665 fi.so.et_644
  0x10093f05, 0x10001a08, 0x09002808, 0x01002b02,   // af.pl.lt_333 tl.lt.un_430  sw.pl.un_430 vi.en.un_220
  // [8230]
  0x212305ec, 0x0b0d2dad, 0x281c21a0, 0x110c08a0,   // fr.ca.jw_644 sk.cs.es_643  jw.id.sw_322 no.sv.ro_322
  0x31002a1a, 0x3b2127ac, 0x2d18120c, 0x2a203b04,   // mt.az.un_760 gd.jw.so_632  hu.ga.sk_543 so.sq.mt_332
  0x081711ad, 0x2a080605, 0x122d0eec, 0x050123ee,   // ro.sr.uk_643 de.no.mt_333  is.sk.hu_644 ca.en.fr_422
  0x0e122d0b, 0x0f00530d, 0x032a08ee, 0x0e002a2b,   // sk.hu.is_542 ht.lv.un_540  no.mt.nl_422 mt.is.un_980
  // [8240]
  0x32170c05, 0x07000e0e, 0x210812ad, 0x3b18640e,   // sv.sr.bs_333 is.it.un_550  hu.no.jw_643 lg.ga.so_555
  0x0e0807af, 0x2900530d, 0x3b290da4, 0x53006404,   // it.no.is_655 ht.sl.un_540  cs.sl.so_433 lg.ht.un_320
  0x041128a9, 0x190a1111, 0x1f060204, 0x092811ec,   // sw.ro.fi_544 ro.pt.gl_653  da.de.cy_332 ro.sw.pl_644
  0x200e01a0, 0x170711ad, 0x09130d0c, 0x28091112,   // en.is.sq_322 ro.bg.sr_643  ne.bh.hi_543 ro.pl.sw_654
  // [8250]
  0x10000507, 0x016b1ba0, 0x11003b29, 0x0e093ba9,   // fr.lt.un_420 tr.ceb.en_322  so.ro.un_960 so.pl.is_544
  0x0d010504, 0x281168a0, 0x2a0c3b60, 0x21024aad,   // fr.en.cs_332 ig.ro.sw_322  so.sv.mt_664 yo.da.jw_643
  0x17000608, 0x3b2a09ec, 0x131b0c08, 0x0d091108,   // de.sr.un_430 pl.mt.so_644  sv.tr.et_443 ro.pl.cs_443
  0x0a033f60, 0x09113baf, 0x080203af, 0x10115208,   // af.nl.pt_664 so.ro.pl_655  nl.da.no_655 ha.ro.lt_443
  // [8260]
  0x3f00080d, 0x1b080260, 0x28316b08, 0x290c0da4,   // no.af.un_540 da.no.tr_664  ceb.az.sw_443 cs.sv.sl_433
  0x08311002, 0x3b2d115a, 0x03000222, 0x3b002a0e,   // lt.az.no_222 ro.sk.so_553  da.nl.un_870 mt.so.un_550
  0x3f071208, 0x08090207, 0x162a5507, 0x0e3b0814,   // hu.it.af_443 da.pl.no_432  rw.mt.hr_432 no.so.is_666
  0x64071207, 0x5303050c, 0x03193513, 0x0c0206af,   // hu.it.lg_432 fr.nl.ht_543  zu.gl.nl_665 de.da.sv_655
  // [8270]
  0x64002502, 0x25020708, 0x681e1c0d, 0x19001107,   // eu.lg.un_220 it.da.eu_443  id.ms.ig_554 ro.gl.un_420
  0x07033bee, 0x02061802, 0x07041002, 0x09110d11,   // so.nl.it_422 ga.de.da_222  be.ru.bg_222 cs.ro.pl_653
  0x643b27ee, 0x090411ad, 0x3f190a14, 0x284a68a9,   // gd.so.lg_422 ro.fi.pl_643  pt.gl.af_666 ig.yo.sw_544
  0x1b2512ee, 0x1c1a0a07, 0x11072905, 0x1f211aee,   // hu.eu.tr_422 pt.tl.id_432  sl.it.ro_333 tl.jw.cy_422
  // [8280]
  0x020b08a4, 0x09004a04, 0x083b0c04, 0x1b0e08a0,   // no.es.da_433 yo.pl.un_320  sv.so.no_332 no.is.tr_322
  0x0c041313, 0x3f031fec, 0x11000e02, 0x32000d09,   // et.fi.sv_665 cy.nl.af_644  is.ro.un_220 cs.bs.un_440
  0x08020302, 0x23033f07, 0x52006b1a, 0x162d0d64,   // nl.da.no_222 af.nl.ca_432  ceb.ha.un_760 cs.sk.hr_762
  0x251b6ba7, 0x0a10170d, 0x040e3fa9, 0x20042502,   // ceb.tr.eu_532 sr.be.mk_554  af.is.fi_544 eu.fi.sq_222
  // [8290]
  0x3f000d07, 0x1b051fa0, 0x3f005313, 0x1e080c02,   // cs.af.un_420 cy.fr.tr_322  ht.af.un_650 sv.no.ms_222
  0x2d0e0d09, 0x0c1208a4, 0x2d0d09a0, 0x170304ad,   // cs.is.sk_444 no.hu.sv_433  pl.cs.sk_322 fi.nl.sr_643
  0x03050cee, 0x073f11a0, 0x080520ee, 0x013502a0,   // sv.fr.nl_422 ro.af.it_322  sq.fr.no_422 da.zu.en_322
  0x08020d05, 0x09251fad, 0x4a55250c, 0x0e0c01a4,   // cs.da.no_333 cy.eu.pl_643  eu.rw.yo_543 en.sv.is_433
  // [82a0]
  0x230535ee, 0x1f0c0e07, 0x251e1c11, 0x3f291b55,   // zu.fr.ca_422 is.sv.cy_432  id.ms.eu_653 tr.sl.af_442
  0x12000212, 0x0a052aee, 0x040118a0, 0x103f0312,   // da.hu.un_640 mt.fr.pt_422  ga.en.fi_322 nl.af.lt_654
  0x190a0507, 0x0a080208, 0x17001604, 0x526421af,   // fr.pt.gl_432 da.no.pt_443  hr.sr.un_320 jw.lg.ha_655
  0x1b002a05, 0x3b006413, 0x35645208, 0x354a21a0,   // mt.tr.un_330 lg.so.un_650  ha.lg.zu_443 jw.yo.zu_322
  // [82b0]
  0x0d2d3f0d, 0x0d0f10a9, 0x522164ad, 0x08021214,   // af.sk.cs_554 lt.lv.cs_544  lg.jw.ha_643 hu.da.no_666
  0x19530b0c, 0x3f060c09, 0x52006409, 0x55321602,   // es.ht.gl_543 sv.de.af_444  lg.ha.un_440 hr.bs.rw_222
  0x1b040e04, 0x55526408, 0x3f0e6407, 0x4a0811ee,   // is.fi.tr_332 lg.ha.rw_443  lg.is.af_432 ro.no.yo_422
  0x181f27ee, 0x271f1008, 0x0f046b0c, 0x3b033fa9,   // gd.cy.ga_422 lt.cy.gd_443  ceb.fi.lv_543 af.nl.so_544
  // [82c0]
  0x2a350702, 0x1c100fec, 0x521c6407, 0x6b0e0607,   // it.zu.mt_222 lv.lt.id_644  lg.id.ha_432 de.is.ceb_432
  0x181f6b02, 0x2d1e1c04, 0x0f181008, 0x030206a0,   // ceb.cy.ga_222 id.ms.sk_332  lt.ga.lv_443 de.da.nl_322
  0x033f0eee, 0x063225a0, 0x04182712, 0x050a2305,   // is.af.nl_422 eu.bs.de_322  gd.ga.fi_654 ca.pt.fr_333
  0x27101f0e, 0x071028a0, 0x01091fa9, 0x06034aee,   // cy.lt.gd_555 sw.lt.it_322  cy.pl.en_544 yo.nl.de_422
  // [82d0]
  0x0d1c09ac, 0x05041f07, 0x0d092d11, 0x10170aa9,   // hi.mr.ne_632 cy.fi.fr_432  sk.pl.cs_653 mk.sr.be_544
  0x0d0805ad, 0x04002707, 0x0c5306a4, 0x1e18270c,   // fr.no.cs_643 gd.fi.un_420  de.ht.sv_433 gd.ga.ms_543
  0x0f1804a4, 0x250428a9, 0x07000802, 0x282d09af,   // fi.ga.lv_433 sw.fi.eu_544  uk.bg.un_220 pl.sk.sw_655
  0x28076e08, 0x23052aa4, 0x28001002, 0x1b001f21,   // hmn.it.sw_443 mt.fr.ca_433  lt.sw.un_220 cy.tr.un_860
  // [82e0]
  0x04002822, 0x2a5327a0, 0x0a0711ec, 0x230725a9,   // sw.fi.un_870 gd.ht.mt_322  ro.bg.mk_644 eu.it.ca_544
  0x062507a4, 0x11130707, 0x3f000909, 0x250409af,   // it.eu.de_433 it.et.ro_432  pl.af.un_440 pl.fi.eu_655
  0x3f000b02, 0x10121f07, 0x0c2a0b09, 0x1c0d1312,   // es.af.un_220 cy.hu.lt_432  es.mt.sv_444 bh.ne.mr_654
  0x090b06a7, 0x04001f0c, 0x1107250d, 0x060b095a,   // de.es.pl_532 cy.fi.un_530  eu.it.ro_554 pl.es.de_553
  // [82f0]
  0x09110b09, 0x684a09a9, 0x11282da9, 0x645528ad,   // es.ro.pl_444 pl.yo.ig_544  sk.sw.ro_544 sw.rw.lg_643
  0x64095307, 0x0f09060c, 0x252a060e, 0x3f0b0608,   // ht.pl.lg_432 de.pl.lv_543  de.mt.eu_555 de.es.af_443
  0x551a2855, 0x0f0506a4, 0x110608a0, 0x0b06255a,   // sw.tl.rw_442 de.fr.lv_433  no.de.ro_322 eu.de.es_553
  0x0f102d09, 0x11070a0d, 0x1f1a250c, 0x020e08ac,   // sk.lt.lv_444 mk.bg.ro_554  eu.tl.cy_543 no.is.da_632
  // [8300]
  0x136b1a04, 0x016b100c, 0x051f270d, 0x0500181a,   // tl.ceb.et_332 lt.ceb.en_543  gd.cy.fr_554 ga.fr.un_760
  0x16520ea7, 0x2900201a, 0x2d002019, 0x2a076860,   // is.ha.hr_532 sq.sl.un_760  sq.sk.un_750 ig.it.mt_664
  0x1b113107, 0x250501ec, 0x16292007, 0x28251e07,   // az.ro.tr_432 en.fr.eu_644  sq.sl.hr_432 ms.eu.sw_432
  0x281020ee, 0x4a0f53ee, 0x2d001602, 0x12532007,   // sq.lt.sw_422 ht.lv.yo_422  hr.sk.un_220 sq.ht.hu_432
  // [8310]
  0x53000b02, 0x050e06a0, 0x100e0fad, 0x1f130414,   // es.ht.un_220 de.is.fr_322  lv.is.lt_643 fi.et.cy_666
  0x1a050155, 0x2d003204, 0x1f001e05, 0x05002705,   // en.fr.tl_442 bs.sk.un_320  ms.cy.un_330 gd.fr.un_330
  0x20002909, 0x0f004a04, 0x04170aa7, 0x3229200c,   // sl.sq.un_440 yo.lv.un_320  mk.sr.ru_532 sq.sl.bs_543
  0x29322008, 0x2d002007, 0x17162909, 0x29003108,   // sq.bs.sl_443 sq.sk.un_420  sl.hr.sr_444 az.sl.un_430
  // [8320]
  0x682813ec, 0x19000e05, 0x0e1b1304, 0x0c2d0d02,   // et.sw.ig_644 is.gl.un_330  et.tr.is_332 cs.sk.sv_222
  0x080402ee, 0x3f001f14, 0x17060505, 0x04002b04,   // da.fi.no_422 cy.af.un_660  fr.de.sr_333 vi.fi.un_320
  0x131e0e12, 0x0704170d, 0x213b35ec, 0x3b2128a9,   // is.ms.et_654 sr.ru.bg_554  zu.so.jw_644 sw.jw.so_544
  0x4a002021, 0x5300201b, 0x11000411, 0x0700682a,   // sq.yo.un_860 sq.ht.un_770  fi.ro.un_630 ig.it.un_970
  // [8330]
  0x080c0eee, 0x1b202da0, 0x182735ee, 0x280768ec,   // is.sv.no_422 sk.sq.tr_322  zu.gd.ga_422 ig.it.sw_644
  0x120c0809, 0x04682511, 0x0c282508, 0x29200d07,   // no.sv.hu_444 eu.ig.fi_653  eu.sw.sv_443 cs.sq.sl_432
  0x19050104, 0x1a134aa7, 0x0553110b, 0x033f12a4,   // en.fr.gl_332 yo.et.tl_532  ro.ht.fr_542 hu.af.nl_433
  0x52002018, 0x06076807, 0x31283b0e, 0x31005304,   // sq.ha.un_740 ig.it.de_432  so.sw.az_555 ht.az.un_320
  // [8340]
  0x0c250107, 0x172d090c, 0x00003537, 0x2d0d55a9,   // en.eu.sv_432 pl.sk.sr_543  zu.un.un_B00 rw.cs.sk_544
  0x310452ad, 0x35522812, 0x07005322, 0x031b1211,   // ha.fi.az_643 sw.ha.zu_654  ht.it.un_870 hu.tr.nl_653
  0x53190a08, 0x32172a12, 0x2864120c, 0x130c12a4,   // pt.gl.ht_443 mt.sr.bs_654  hu.lg.sw_543 hu.sv.et_433
  0x03643f08, 0x683f53ec, 0x311b0caf, 0x284a5304,   // af.lg.nl_443 ht.af.ig_644  sv.tr.az_655 ht.yo.sw_332
  // [8350]
  0x251827ad, 0x0c081307, 0x1a04250c, 0x4a2d12a9,   // gd.ga.eu_643 et.no.sv_432  eu.fi.tl_543 hu.sk.yo_544
  0x2006120c, 0x1213040c, 0x353f5207, 0x1025270d,   // hu.de.sq_543 fi.et.hu_543  ha.af.zu_432 gd.eu.lt_554
  0x3100200d, 0x27181fad, 0x532105ec, 0x121b0ca7,   // sq.az.un_540 cy.ga.gd_643  fr.jw.ht_644 sv.tr.hu_532
  0x1a2728a4, 0x17006e08, 0x6e202a05, 0x033b3f05,   // sw.gd.tl_433 hmn.sr.un_430  mt.sq.hmn_333 af.so.nl_333
  // [8360]
  0x08000608, 0x100f25a9, 0x28521a12, 0x4a033f12,   // de.no.un_430 eu.lv.lt_544  tl.ha.sw_654 af.nl.yo_654
  0x0500210c, 0x0504250c, 0x1a003b12, 0x05001205,   // jw.fr.un_530 eu.fi.fr_543  so.tl.un_640 hu.fr.un_330
  0x31001b29, 0x04131aec, 0x01080ea4, 0x1c0d130e,   // tr.az.un_960 tl.et.fi_644  is.no.en_433 bh.ne.mr_555
  0x10051f0c, 0x081f0607, 0x27003b0d, 0x162d0d02,   // cy.fr.lt_543 de.cy.no_432  so.gd.un_540 cs.sk.hr_222
  // [8370]
  0x18002a08, 0x02000e22, 0x53006b11, 0x125204ac,   // mt.ga.un_430 is.da.un_870  ceb.ht.un_630 fi.ha.hu_632
  0x1f0b2307, 0x0900530d, 0x25000521, 0x12002512,   // ca.es.cy_432 ht.pl.un_540  fr.eu.un_860 eu.hu.un_640
  0x53110107, 0x1a2a010c, 0x556421ec, 0x16002911,   // en.ro.ht_432 en.mt.tl_543  jw.lg.rw_644 sl.hr.un_630
  0x0a00042a, 0x25003514, 0x04005509, 0x251035a0,   // ru.mk.un_970 zu.eu.un_660  rw.fi.un_440 zu.lt.eu_322
  // [8380]
  0x1c000922, 0x08021aa0, 0x1a002307, 0x4a28640c,   // hi.mr.un_870 tl.da.no_322  ca.tl.un_420 lg.sw.yo_543
  0x291b280c, 0x10552511, 0x0100350e, 0x29003213,   // sw.tr.sl_543 eu.rw.lt_653  zu.en.un_550 bs.sl.un_650
  0x130410a9, 0x64551a08, 0x2d001213, 0x01001109,   // lt.fi.et_544 tl.rw.lg_443  hu.sk.un_650 ro.en.un_440
  0x6b005518, 0x04003b0b, 0x171f3b0c, 0x35551f07,   // rw.ceb.un_740 so.fi.un_520  so.cy.sr_543 cy.rw.zu_432
  // [8390]
  0x050c6ba0, 0x2a290aaf, 0x201e31ee, 0x4a005214,   // ceb.sv.fr_322 pt.sl.mt_655  az.ms.sq_422 ha.yo.un_660
  0x06321709, 0x01106ba0, 0x55281a08, 0x231b0607,   // sr.bs.de_444 ceb.lt.en_322  tl.sw.rw_443 de.tr.ca_432
  0x351a08a4, 0x32002a12, 0x2021280d, 0x060e1f55,   // no.tl.zu_433 mt.bs.un_640  sw.jw.sq_554 cy.is.de_442
  0x25000a1a, 0x5500251b, 0x28256ba4, 0x2a00310c,   // pt.eu.un_760 eu.rw.un_770  ceb.eu.sw_433 az.mt.un_530
  // [83a0]
  0x080e06a0, 0x53014aee, 0x3b312a0d, 0x2a27350c,   // de.is.no_322 yo.en.ht_422  mt.az.so_554 zu.gd.mt_543
  0x25003504, 0x2868180d, 0x6b006408, 0x311b09a4,   // zu.eu.un_320 ga.ig.sw_554  lg.ceb.un_430 pl.tr.az_433
  0x68110708, 0x1c000705, 0x0429130d, 0x356e20ad,   // it.ro.ig_443 it.id.un_330  et.sl.fi_554 sq.hmn.zu_643
  0x16000907, 0x13290913, 0x2a090f12, 0x2700350e,   // pl.hr.un_420 pl.sl.et_665  lv.pl.mt_654 zu.gd.un_550
  // [83b0]
  0x52091804, 0x27003112, 0x040a0d02, 0x162a04a4,   // ga.pl.ha_332 az.gd.un_640  cs.pt.fi_222 fi.mt.hr_433
  0x3b312004, 0x55281ea0, 0x3b130908, 0x04643b0c,   // sq.az.so_332 ms.sw.rw_322  pl.et.so_443 so.lg.fi_543
  0x1a003b0d, 0x070105a0, 0x3f3b645a, 0x351e0d12,   // so.tl.un_540 fr.en.it_322  lg.so.af_553 cs.ms.zu_654
  0x04112355, 0x0e20060b, 0x29092512, 0x015528a4,   // ca.ro.fi_442 de.sq.is_542  eu.pl.sl_654 sw.rw.en_433
  // [83c0]
  0x1c133b07, 0x04643f0c, 0x0e3109ad, 0x1a643b08,   // so.et.id_432 af.lg.fi_543  pl.az.is_643 so.lg.tl_443
  0x0409290d, 0x4a006420, 0x64003b2b, 0x03280507,   // sl.pl.fi_554 lg.yo.un_850  so.lg.un_980 fr.sw.nl_432
  0x53090fa0, 0x0e5209a9, 0x06356804, 0x1b290914,   // lv.pl.ht_322 pl.ha.is_544  ig.zu.de_332 pl.sl.tr_666
  0x03003b0b, 0x2d003513, 0x641a3b0c, 0x3f2804a0,   // so.nl.un_520 zu.sk.un_650  so.tl.lg_543 fi.sw.af_322
  // [83d0]
  0x28643b60, 0x31001114, 0x643b1a09, 0x046b1aa4,   // so.lg.sw_664 ro.az.un_660  tl.so.lg_444 tl.ceb.fi_433
  0x64002a13, 0x03063fee, 0x1000120c, 0x09000c02,   // mt.lg.un_650 af.de.nl_422  hu.lt.un_530 sv.pl.un_220
  0x0a07100e, 0x1b002005, 0x01001f13, 0x026b0d04,   // be.bg.mk_555 sq.tr.un_330  cy.en.un_650 cs.ceb.da_332
  0x04080aad, 0x0c091007, 0x09271fee, 0x536b1aaf,   // mk.uk.ru_643 lt.pl.sv_432  cy.gd.pl_422 tl.ceb.ht_655
  // [83e0]
  0x116428a0, 0x0a1007a7, 0x1e110ba0, 0x2a061f09,   // sw.lg.ro_322 bg.be.mk_532  es.ro.ms_322 cy.de.mt_444
  0x0d000f08, 0x08023b05, 0x1a096b09, 0x0e2a1004,   // lv.cs.un_430 so.da.no_333  ceb.pl.tl_444 lt.mt.is_332
  0x021a6ba9, 0x1e001b08, 0x07002b02, 0x311a10a4,   // ceb.tl.da_544 tr.ms.un_430  vi.it.un_220 lt.tl.az_433
  0x64002704, 0x0700170e, 0x25000b02, 0x4a1a6ba0,   // gd.lg.un_320 sr.bg.un_550  es.eu.un_220 ceb.tl.yo_322
  // [83f0]
  0x190b550b, 0x6b002505, 0x31002905, 0x19270aa4,   // rw.es.gl_542 eu.ceb.un_330  sl.az.un_330 pt.gd.gl_433
  0x040f18a0, 0x53004a07, 0x3b001013, 0x102164ee,   // ga.lv.fi_322 yo.ht.un_420  lt.so.un_650 lg.jw.lt_422
  0x09130d55, 0x5500100e, 0x053211ee, 0x072705a0,   // ne.bh.hi_442 lt.rw.un_550  ro.bs.fr_422 fr.gd.it_322
  0x532a0508, 0x27186eee, 0x10000b02, 0x1f00100e,   // fr.mt.ht_443 hmn.ga.gd_422  es.lt.un_220 lt.cy.un_550

  // [8400]
  0x0b2519ee, 0x08020c11, 0x23190aa0, 0x1e0f18a0,   // gl.eu.es_422 sv.da.no_653  pt.gl.ca_322 ga.lv.ms_322
  0x29100411, 0x0f000504, 0x3b000d22, 0x1004640c,   // fi.lt.sl_653 fr.lv.un_320  cs.so.un_870 lg.fi.lt_543
  0x2d0d0a0c, 0x2d0d3bec, 0x040e640c, 0x046408a0,   // pt.cs.sk_543 so.cs.sk_644  lg.is.fi_543 no.lg.fi_322
  0x0f006409, 0x04086407, 0x211c1aa4, 0x6400681b,   // lg.lv.un_440 lg.no.fi_432  tl.id.jw_433 ig.lg.un_770
  // [8410]
  0x1a1801a7, 0x0c000d1a, 0x1700030c, 0x643f030d,   // en.ga.tl_532 cs.sv.un_760  nl.sr.un_530 nl.af.lg_554
  0x030e12af, 0x13003f07, 0x09250d07, 0x032501a9,   // hu.is.nl_655 af.et.un_420  cs.eu.pl_432 en.eu.nl_544
  0x0c0601af, 0x2a3b25ad, 0x190d0aa7, 0x0e10640b,   // en.de.sv_655 eu.so.mt_643  pt.cs.gl_532 lg.lt.is_542
  0x211a3bee, 0x2a523b12, 0x2d290dec, 0x2d0d0aaf,   // so.tl.jw_422 so.ha.mt_654  cs.sl.sk_644 pt.cs.sk_655
  // [8420]
  0x05000a08, 0x04120308, 0x3f2d0d04, 0x25045307,   // pt.fr.un_430 nl.hu.fi_443  cs.sk.af_332 ht.fi.eu_432
  0x1f1827ec, 0x0c0e0da4, 0x3f030204, 0x040f1c04,   // gd.ga.cy_644 cs.is.sv_433  da.nl.af_332 id.lv.fi_332
  0x0b23190c, 0x09131c10, 0x07002308, 0x180e23a7,   // gl.ca.es_543 mr.bh.hi_642  ca.it.un_430 ca.is.ga_532
  0x190b1fec, 0x19530507, 0x110408af, 0x041353a0,   // cy.es.gl_644 fr.ht.gl_432  uk.ru.ro_655 ht.et.fi_322
  // [8430]
  0x555328a0, 0x11080207, 0x083b0e07, 0x0c1e2504,   // sw.ht.rw_322 da.no.ro_432  is.so.no_432 eu.ms.sv_332
  0x0d2d125a, 0x18013ba0, 0x121b1807, 0x01532707,   // hu.sk.cs_553 so.en.ga_322  ga.tr.hu_432 gd.ht.en_432
  0x033f2b07, 0x29321ca0, 0x12286405, 0x1f0e18a6,   // vi.af.nl_432 id.bs.sl_322  lg.sw.hu_333 ga.is.cy_521
  0x2a3f0ea4, 0x0f001707, 0x0d1a6b08, 0x29005302,   // is.af.mt_433 sr.lv.un_420  ceb.tl.cs_443 ht.sl.un_220
  // [8440]
  0x0d2d1207, 0x030e08a4, 0x4a180e11, 0x1e0602a7,   // hu.sk.cs_432 no.is.nl_433  is.ga.yo_653 da.de.ms_532
  0x4a553504, 0x0d2d1211, 0x07001111, 0x033b3fa4,   // zu.rw.yo_332 hu.sk.cs_653  ro.bg.un_630 af.so.nl_433
  0x13004a0d, 0x1c0516a0, 0x1203530c, 0x033f1313,   // yo.et.un_540 hr.fr.id_322  ht.nl.hu_543 et.af.nl_665
  0x290919ee, 0x166b1804, 0x64001b21, 0x2b5206a4,   // gl.pl.sl_422 ga.ceb.hr_332  tr.lg.un_860 de.ha.vi_433
  // [8450]
  0x55003513, 0x3b081aa9, 0x0e031aee, 0x2921120c,   // zu.rw.un_650 tl.no.so_544  tl.nl.is_422 hu.jw.sl_543
  0x10003209, 0x4a1a6bec, 0x2d000714, 0x20001b14,   // bs.lt.un_440 ceb.tl.yo_644  it.sk.un_660 tr.sq.un_660
  0x170410af, 0x291e080c, 0x28000208, 0x68061f07,   // be.ru.sr_655 no.ms.sl_543  da.sw.un_430 cy.de.ig_432
  0x551c21a0, 0x2d1a1204, 0x1f062305, 0x12006423,   // jw.id.rw_322 hu.tl.sk_332  ca.de.cy_333 lg.hu.un_880
  // [8460]
  0x190b1109, 0x1e1c6b0e, 0x18003b12, 0x080e01a4,   // ro.es.gl_444 ceb.id.ms_555  so.ga.un_640 en.is.no_433
  0x101f040d, 0x191f1011, 0x1f040707, 0x12006e11,   // fi.cy.lt_554 lt.cy.gl_653  it.fi.cy_432 hmn.hu.un_630
  0x251c1fee, 0x23051f07, 0x04025204, 0x100305a0,   // cy.id.eu_422 cy.fr.ca_432  ha.da.fi_332 fr.nl.lt_322
  0x2a003f0d, 0x1c1208ad, 0x05001207, 0x09131c55,   // af.mt.un_540 no.hu.id_643  hu.fr.un_420 mr.bh.hi_442
  // [8470]
  0x23101fa0, 0x07190a5a, 0x04000e0c, 0x553509ee,   // cy.lt.ca_322 pt.gl.it_553  is.fi.un_530 pl.zu.rw_422
  0x2800201b, 0x0a0811af, 0x012d0d02, 0x0d002d2b,   // sq.sw.un_770 ro.uk.mk_655  cs.sk.en_222 sk.cs.un_980
  0x642a52a4, 0x32172a08, 0x19051004, 0x6800101a,   // ha.mt.lg_433 mt.sr.bs_443  lt.fr.gl_332 lt.ig.un_760
  0x1f000414, 0x0e002905, 0x190a1fa4, 0x1f0410ad,   // fi.cy.un_660 sl.is.un_330  cy.pt.gl_433 lt.fi.cy_643
  // [8480]
  0x0f292aa0, 0x100804a0, 0x27201f04, 0x17001c02,   // mt.sl.lv_322 ru.uk.be_322  cy.sq.gd_332 id.sr.un_220
  0x35283f07, 0x20005523, 0x2a00091b, 0x0d322904,   // af.sw.zu_432 rw.sq.un_880  pl.mt.un_770 sl.bs.cs_332
  0x292a0f55, 0x23060313, 0x55005313, 0x283b6407,   // lv.mt.sl_442 nl.de.ca_665  ht.rw.un_650 lg.so.sw_432
  0x312a295a, 0x0f002a19, 0x02000a07, 0x1c290207,   // sl.mt.az_553 mt.lv.un_750  pt.da.un_420 da.sl.id_432
  // [8490]
  0x070f0a08, 0x0e0a23ee, 0x180f2712, 0x0f1017a4,   // pt.lv.it_443 ca.pt.is_422  gd.lv.ga_654 sr.lt.lv_433
  0x13061804, 0x11002013, 0x13553504, 0x526b3508,   // ga.de.et_332 sq.ro.un_650  zu.rw.et_332 zu.ceb.ha_443
  0x0a100808, 0x28350908, 0x1a3555af, 0x641f07ee,   // uk.be.mk_443 pl.zu.sw_443  rw.zu.tl_655 it.cy.lg_422
  0x554a35ac, 0x52001004, 0x23001b07, 0x21556ba0,   // zu.yo.rw_632 lt.ha.un_320  tr.ca.un_420 ceb.rw.jw_322
  // [84a0]
  0x1c1b1e0b, 0x1300292a, 0x3b286b09, 0x08001f12,   // ms.tr.id_542 sl.et.un_970  ceb.sw.so_444 cy.no.un_640
  0x32061ea0, 0x28645560, 0x196b64a7, 0x0f0d1b04,   // ms.de.bs_322 rw.lg.sw_664  lg.ceb.gl_532 tr.cs.lv_332
  0x29351605, 0x35110baf, 0x3f1720a4, 0x3f5564a4,   // hr.zu.sl_333 es.ro.zu_655  sq.sr.af_433 lg.rw.af_433
  0x101a350c, 0x11070808, 0x250b08a4, 0x071801a0,   // zu.tl.lt_543 uk.bg.ro_443  no.es.eu_433 en.ga.it_322
  // [84b0]
  0x25132907, 0x081f0d0c, 0x10645504, 0x2511550c,   // sl.et.eu_432 cs.cy.no_543  rw.lg.lt_332 rw.ro.eu_543
  0x100d0508, 0x0e352108, 0x04131ea0, 0x19050b08,   // fr.cs.lt_443 jw.zu.is_443  ms.et.fi_322 es.fr.gl_443
  0x190b1a55, 0x101b0aa0, 0x1b0413a9, 0x3509250c,   // tl.es.gl_442 pt.tr.lt_322  et.fi.tr_544 eu.pl.zu_543
  0x68643507, 0x6e002012, 0x07682ba6, 0x092d0dad,   // zu.lg.ig_432 sq.hmn.un_640  vi.ig.it_521 cs.sk.pl_643
  // [84c0]
  0x092d19a7, 0x0e00351b, 0x3f122811, 0x272b11ad,   // gl.sk.pl_532 zu.is.un_770  sw.hu.af_653 ro.vi.gd_643
  0x1100120d, 0x062504ec, 0x20272ba9, 0x06002004,   // hu.ro.un_540 fi.eu.de_644  vi.gd.sq_544 sq.de.un_320
  0x1a001207, 0x21041105, 0x2b00230d, 0x19230aa0,   // hu.tl.un_420 ro.fi.jw_333  ca.vi.un_540 pt.ca.gl_322
  0x28000702, 0x0612200c, 0x09005309, 0x24000134,   // it.sw.un_220 sq.hu.de_543  ht.pl.un_440 iw.yi.un_A80
  // [84d0]
  0x17000719, 0x553b2113, 0x643b310c, 0x02120807,   // bg.sr.un_750 jw.so.rw_665  az.so.lg_543 no.hu.da_432
  0x525564ec, 0x17080aaf, 0x080211a4, 0x3b1b6404,   // lg.rw.ha_644 mk.uk.sr_655  ro.da.no_433 lg.tr.so_332
  0x190b0705, 0x55001c0d, 0x3f001b12, 0x04132013,   // it.es.gl_333 id.rw.un_540  tr.af.un_640 sq.et.fi_665
  0x2a006434, 0x29122a14, 0x1032160d, 0x131b2507,   // lg.mt.un_A80 mt.hu.sl_666  hr.bs.lt_554 eu.tr.et_432
  // [84e0]
  0x20090f07, 0x29200e0c, 0x1c120e0c, 0x1f001a08,   // lv.pl.sq_432 is.sq.sl_543  is.hu.id_543 tl.cy.un_430
  0x171b04ee, 0x13042013, 0x12292aa4, 0x31040e0c,   // fi.tr.sr_422 sq.fi.et_665  mt.sl.hu_433 is.fi.az_543
  0x01552855, 0x20000821, 0x023f6b02, 0x6404250c,   // sw.rw.en_442 no.sq.un_860  ceb.af.da_222 eu.fi.lg_543
  0x29091faf, 0x533b4aad, 0x202a0908, 0x06251b13,   // cy.pl.sl_655 yo.so.ht_643  pl.mt.sq_443 tr.eu.de_665
  // [84f0]
  0x09120e07, 0x28130304, 0x2a1229a4, 0x122a1b0c,   // is.hu.pl_432 nl.et.sw_332  sl.hu.mt_433 tr.mt.hu_543
  0x4a216ba0, 0x233b1308, 0x20251260, 0x64110f08,   // ceb.jw.yo_322 et.so.ca_443  hu.eu.sq_664 lv.ro.lg_443
  0x09202aa9, 0x2a2012ec, 0x1c1f1eee, 0x13030607,   // mt.sq.pl_544 hu.sq.mt_644  ms.cy.id_422 de.nl.et_432
  0x3b231f07, 0x3125230c, 0x3b231355, 0x082301ee,   // cy.ca.so_432 ca.eu.az_543  et.ca.so_442 en.ca.no_422
  // [8500]
  0x1c351e0c, 0x2102080c, 0x0c1f3b07, 0x3213230c,   // ms.zu.id_543 no.da.jw_543  so.cy.sv_432 ca.et.bs_543
  0x32002102, 0x09211f04, 0x230b08a0, 0x19233b08,   // jw.bs.un_220 cy.jw.pl_332  no.es.ca_322 so.ca.gl_443
  0x35006e04, 0x13020f04, 0x170a12a4, 0x0b002704,   // hmn.zu.un_320 lv.da.et_332  hu.pt.sr_433 gd.es.un_320
  0x0b003504, 0x0a5329ee, 0x09002104, 0x06130314,   // zu.es.un_320 sl.ht.pt_422  jw.pl.un_320 nl.et.de_666
  // [8510]
  0x1f213b11, 0x1e1a6b08, 0x6823130c, 0x113507ec,   // so.jw.cy_653 ceb.tl.ms_443  et.ca.ig_543 it.zu.ro_644
  0x68003b0e, 0x121b0f04, 0x23553ba4, 0x19003104,   // so.ig.un_550 lv.tr.hu_332  so.rw.ca_433 az.gl.un_320
  0x2b000c04, 0x080717ee, 0x170a08ee, 0x0a10110c,   // sv.vi.un_320 sr.bg.uk_422  uk.mk.sr_422 ro.be.mk_543
  0x3b211e04, 0x1a1b3107, 0x31131baf, 0x1b5531a9,   // ms.jw.so_332 az.tr.tl_432  tr.et.az_655 az.rw.tr_544
  // [8520]
  0x1a0464a0, 0x045331ee, 0x550464a9, 0x0f081011,   // lg.fi.tl_322 az.ht.fi_422  lg.fi.rw_544 lt.no.lv_653
  0x19000e04, 0x521c21a4, 0x1b1c1ea0, 0x09556404,   // is.gl.un_320 jw.id.ha_433  ms.id.tr_322 lg.rw.pl_332
  0x070410a7, 0x1e002b07, 0x21000904, 0x2b000107,   // be.ru.bg_532 vi.ms.un_420  pl.jw.un_320 en.vi.un_420
  0x042855a0, 0x1b1f31af, 0x0464105a, 0x680701a0,   // rw.sw.fi_322 az.cy.tr_655  lt.lg.fi_553 en.it.ig_322
  // [8530]
  0x0a081109, 0x0506110b, 0x1b6431a0, 0x12001f1a,   // ro.uk.mk_444 ro.de.fr_542  az.lg.tr_322 cy.hu.un_760
  0x1f136ea0, 0x0600121a, 0x53521aee, 0x01000505,   // hmn.et.cy_322 hu.de.un_760  tl.ha.ht_422 fr.en.un_330
  0x5318275a, 0x3f032aa9, 0x29003b09, 0x210e1204,   // gd.ga.ht_553 mt.nl.af_544  so.sl.un_440 hu.is.jw_332
  0x05121155, 0x1f065307, 0x2a000a08, 0x2353010c,   // ro.hu.fr_442 ht.de.cy_432  pt.mt.un_430 en.ht.ca_543
  // [8540]
  0x04003b1b, 0x20321bee, 0x2b000b02, 0x31003513,   // so.fi.un_770 tr.bs.sq_422  es.vi.un_220 zu.az.un_650
  0x0e000622, 0x3f211011, 0x084a0c04, 0x2d0c02a9,   // de.is.un_870 lt.jw.af_653  sv.yo.no_332 da.sv.sk_544
  0x0b005507, 0x021e64ad, 0x010c1f02, 0x1f1e64a7,   // rw.es.un_420 lg.ms.da_643  cy.sv.en_222 lg.ms.cy_532
  0x1f000419, 0x136e28a4, 0x35003114, 0x1e1c64ee,   // fi.cy.un_750 sw.hmn.et_433  az.zu.un_660 lg.id.ms_422
  // [8550]
  0x351c31a0, 0x110901a4, 0x10002a13, 0x031e1fec,   // az.id.zu_322 en.pl.ro_433  mt.lt.un_650 cy.ms.nl_644
  0x080264af, 0x6e3f1ea4, 0x210a1e07, 0x321004a9,   // lg.da.no_655 ms.af.hmn_433  ms.pt.jw_432 fi.lt.bs_544
  0x3f6e2012, 0x08230ead, 0x190b6e60, 0x083b1f07,   // sq.hmn.af_654 is.ca.no_643  hmn.es.gl_664 cy.so.no_432
  0x640e1308, 0x03062007, 0x3f036eac, 0x351f6407,   // et.is.lg_443 sq.de.nl_432  hmn.nl.af_632 lg.cy.zu_432
  // [8560]
  0x11042505, 0x07001708, 0x01000705, 0x08002508,   // eu.fi.ro_333 sr.bg.un_430  it.en.un_330 eu.no.un_430
  0x27532355, 0x4a0e2307, 0x036e3fa9, 0x31006e0c,   // ca.ht.gd_442 ca.is.yo_432  af.hmn.nl_544 hmn.az.un_530
  0x08025205, 0x1c0621ee, 0x0200640e, 0x071108a4,   // ha.da.no_333 jw.de.id_422  lg.da.un_550 uk.ro.bg_433
  0x6e003f11, 0x102305ec, 0x06092104, 0x100f6eec,   // af.hmn.un_630 fr.ca.lt_644  jw.pl.de_332 hmn.lv.lt_644
  // [8570]
  0x2a002507, 0x1a003f04, 0x0c311b08, 0x1f12100d,   // eu.mt.un_420 af.tl.un_320  tr.az.sv_443 lt.hu.cy_554
  0x2d101211, 0x27281a0c, 0x232b1807, 0x06031fee,   // hu.lt.sk_653 tl.sw.gd_543  ga.vi.ca_432 cy.nl.de_422
  0x53016ba0, 0x311828ee, 0x1a000212, 0x1819010b,   // ceb.en.ht_322 sw.ga.az_422  da.tl.un_640 en.gl.ga_542
  0x1b4a04ee, 0x0f00100b, 0x1f1009ad, 0x23353f13,   // fi.yo.tr_422 lt.lv.un_520  pl.lt.cy_643 af.zu.ca_665
  // [8580]
  0x0a2007a0, 0x033f5304, 0x20000323, 0x21000807,   // it.sq.pt_322 ht.af.nl_332  nl.sq.un_880 no.jw.un_420
  0x2a321604, 0x13006404, 0x0b532502, 0x11321608,   // hr.bs.mt_332 lg.et.un_320  eu.ht.es_222 hr.bs.ro_443
  0x520605a7, 0x11321704, 0x1f002a0b, 0x121b13a7,   // fr.de.ha_532 sr.bs.ro_332  mt.cy.un_520 et.tr.hu_532
  0x2511130c, 0x2504135a, 0x53005519, 0x25131f08,   // et.ro.eu_543 et.fi.eu_553  rw.ht.un_750 cy.et.eu_443
  // [8590]
  0x080c5204, 0x12080260, 0x0764250c, 0x1b252802,   // ha.sv.no_332 da.no.hu_664  eu.lg.it_543 sw.eu.tr_222
  0x0c005214, 0x1f071b04, 0x07001304, 0x082523a4,   // ha.sv.un_660 tr.it.cy_332  et.it.un_320 ca.eu.no_433
  0x09122509, 0x3f0802a7, 0x1b322d0d, 0x09250e55,   // eu.hu.pl_444 da.no.af_532  sk.bs.tr_554 is.eu.pl_442
  0x53052d05, 0x1c1e2d07, 0x3b2d0d55, 0x121004af,   // sk.fr.ht_333 sk.ms.id_432  cs.sk.so_442 fi.lt.hu_655
  // [85a0]
  0x230a25a9, 0x06000309, 0x1211070e, 0x2b000702,   // eu.pt.ca_544 nl.de.un_440  it.ro.hu_555 it.vi.un_220
  0x0e531b0c, 0x1c2055a4, 0x0c080b02, 0x031f0107,   // tr.ht.is_543 rw.sq.id_433  es.no.sv_222 en.cy.nl_432
  0x1f133b08, 0x20281305, 0x1e313b05, 0x10040713,   // so.et.cy_443 et.sw.sq_333  so.az.ms_333 bg.ru.be_665
  0x3b311fa9, 0x2a3b07a4, 0x011321a9, 0x0300010c,   // cy.az.so_544 it.so.mt_433  jw.et.en_544 en.nl.un_530
  // [85b0]
  0x08163ba0, 0x13100f5a, 0x073b1307, 0x0600130e,   // so.hr.no_322 lv.lt.et_553  et.so.it_432 et.de.un_550
  0x2d5509ee, 0x13001b07, 0x0602010c, 0x130b2aee,   // pl.rw.sk_422 tr.et.un_420  en.da.de_543 mt.es.et_422
  0x1f311b0b, 0x041b12ee, 0x25645508, 0x093202a0,   // tr.az.cy_542 hu.tr.fi_422  rw.lg.eu_443 da.bs.pl_322
  0x0f000709, 0x18000d05, 0x3100080d, 0x12003107,   // it.lv.un_440 cs.ga.un_330  no.az.un_540 az.hu.un_420
  // [85c0]
  0x31001a07, 0x0d5525a4, 0x313b2a0c, 0x28556405,   // tl.az.un_420 eu.rw.cs_433  mt.so.az_543 lg.rw.sw_333
  0x3b2303a0, 0x132d0d0d, 0x3f2821a4, 0x3f121fa0,   // nl.ca.so_322 cs.sk.et_554  jw.sw.af_433 cy.hu.af_322
  0x251101a4, 0x03005202, 0x1325050c, 0x110810a4,   // en.ro.eu_433 ha.nl.un_220  fr.eu.et_543 be.uk.ro_433
  0x52032d0d, 0x1b0812af, 0x030412ad, 0x1b12250c,   // sk.nl.ha_554 hu.no.tr_655  hu.fi.nl_643 eu.hu.tr_543
  // [85d0]
  0x1712010c, 0x04110813, 0x0d1c2107, 0x3f100309,   // en.hu.sr_543 uk.ro.ru_665  jw.id.cs_432 nl.lt.af_444
  0x02002902, 0x1b001021, 0x230e0da0, 0x01002d07,   // sl.da.un_220 lt.tr.un_860  cs.is.ca_322 sk.en.un_420
  0x11000a09, 0x0103070c, 0x32002502, 0x12001304,   // pt.ro.un_440 it.nl.en_543  eu.bs.un_220 et.hu.un_320
  0x070311ee, 0x06005208, 0x25041012, 0x3f0e030e,   // ro.nl.it_422 ha.de.un_430  lt.fi.eu_654 nl.is.af_555
  // [85e0]
  0x21531e07, 0x29000312, 0x11103baf, 0x3f23030c,   // ms.ht.jw_432 nl.sl.un_640  so.lt.ro_655 nl.ca.af_543
  0x1e005209, 0x18276ba4, 0x684a53a4, 0x2a001c08,   // ha.ms.un_440 ceb.gd.ga_433  ht.yo.ig_433 id.mt.un_430
  0x21002a07, 0x1e211cac, 0x061125a7, 0x04000109,   // mt.jw.un_420 id.jw.ms_632  eu.ro.de_532 en.fi.un_440
  0x350353ec, 0x52681ca4, 0x071827ad, 0x521f2aad,   // ht.nl.zu_644 id.ig.ha_433  gd.ga.it_643 mt.cy.ha_643
  // [85f0]
  0x3b531a13, 0x05012304, 0x4a005504, 0x292117a0,   // tl.ht.so_665 ca.en.fr_332  rw.yo.un_320 sr.jw.sl_322
  0x291721a4, 0x11000a12, 0x130910a4, 0x2a211755,   // jw.sr.sl_433 pt.ro.un_640  lt.pl.et_433 sr.jw.mt_442
  0x210d200d, 0x123f03a0, 0x211e5202, 0x25001022,   // sq.cs.jw_554 nl.af.hu_322  ha.ms.jw_222 lt.eu.un_870
  0x07041060, 0x274a0704, 0x16202da0, 0x25002113,   // be.ru.bg_664 it.yo.gd_332  sk.sq.hr_322 jw.eu.un_650
  // [8600]
  0x312d0d08, 0x0b003108, 0x110b6e04, 0x0b1925a7,   // cs.sk.az_443 az.es.un_430  hmn.es.ro_332 eu.gl.es_532
  0x0118060b, 0x31556413, 0x1b20310c, 0x2a3b04a4,   // de.ga.en_542 lg.rw.az_665  az.sq.tr_543 fi.so.mt_433
  0x03003f34, 0x316b1a08, 0x1b0c2aa4, 0x31000522,   // af.nl.un_A80 tl.ceb.az_443  mt.sv.tr_433 fr.az.un_870
  0x0b3b2d07, 0x130f1012, 0x1a6b0808, 0x030608a7,   // sk.so.es_432 lt.lv.et_654  no.ceb.tl_443 no.de.nl_532
  // [8610]
  0x3f0c230c, 0x12002304, 0x10283507, 0x281e2a09,   // ca.sv.af_543 ca.hu.un_320  zu.sw.lt_432 mt.ms.sw_444
  0x03040807, 0x0200031b, 0x64000421, 0x0f006b12,   // no.fi.nl_432 nl.da.un_770  fi.lg.un_860 ceb.lv.un_640
  0x3f0307a4, 0x53001608, 0x3b0604a0, 0x64001a02,   // it.nl.af_433 hr.ht.un_430  fi.de.so_322 tl.lg.un_220
  0x2d162007, 0x530d2809, 0x643f3bad, 0x2a3b09af,   // sq.hr.sk_432 sw.cs.ht_444  so.af.lg_643 pl.so.mt_655
  // [8620]
  0x110f10a4, 0x03001802, 0x6b3127a4, 0x2300060d,   // lt.lv.ro_433 ga.nl.un_220  gd.az.ceb_433 de.ca.un_540
  0x061335ad, 0x05010708, 0x1b313513, 0x0607030e,   // zu.et.de_643 it.en.fr_443  zu.az.tr_665 nl.it.de_555
  0x1f2d0d5a, 0x081306a4, 0x05000621, 0x040708a6,   // cs.sk.cy_553 de.et.no_433  de.fr.un_860 uk.bg.ru_521
  0x641304ad, 0x1a64040c, 0x6413040d, 0x03082508,   // fi.et.lg_643 fi.lg.tl_543  fi.et.lg_554 eu.no.nl_443
  // [8630]
  0x25190bec, 0x01021302, 0x13000821, 0x02550512,   // es.gl.eu_644 et.da.en_222  no.et.un_860 fr.rw.da_654
  0x06000819, 0x04001902, 0x1b133204, 0x08060302,   // no.de.un_750 gl.fi.un_220  bs.et.tr_332 nl.de.no_222
  0x53201ea0, 0x08130412, 0x13170855, 0x311b5502,   // ms.sq.ht_322 fi.et.no_654  no.sr.et_442 rw.tr.az_222
  0x0c00082b, 0x6b000112, 0x35000619, 0x1e1b350c,   // no.sv.un_980 en.ceb.un_640  de.zu.un_750 zu.tr.ms_543
  // [8640]
  0x1e0e0607, 0x27161ba0, 0x2d0952a4, 0x1b003b0e,   // de.is.ms_432 tr.hr.gd_322  ha.pl.sk_433 so.tr.un_550
  0x17000f05, 0x060e1ea9, 0x0100050c, 0x0e130405,   // lv.sr.un_330 ms.is.de_544  fr.en.un_530 fi.et.is_333
  0x1801050c, 0x351a6ba7, 0x05182bad, 0x6b0a1a07,   // fr.en.ga_543 ceb.tl.zu_532  vi.ga.fr_643 tl.pt.ceb_432
  0x530c08ad, 0x183b1307, 0x0a0f110c, 0x0a3f110c,   // no.sv.ht_643 et.so.ga_432  ro.lv.pt_543 ro.af.pt_543
  // [8650]
  0x11080aa7, 0x10123fa4, 0x0a001207, 0x11000f08,   // pt.no.ro_532 af.hu.lt_433  hu.pt.un_420 lv.ro.un_430
  0x0900160d, 0x6e0105a7, 0x10122508, 0x20000a04,   // hr.pl.un_540 fr.en.hmn_532  eu.hu.lt_443 pt.sq.un_320
  0x0f0a11a4, 0x64006b02, 0x05001f02, 0x0f6b100c,   // ro.pt.lv_433 ceb.lg.un_220  cy.fr.un_220 lt.ceb.lv_543
  0x180227a6, 0x19110a5a, 0x100f11a4, 0x033b64ac,   // gd.da.ga_521 pt.ro.gl_553  ro.lv.lt_433 lg.so.nl_632
  // [8660]
  0x3f0352a0, 0x036b3b0c, 0x0c203f55, 0x033b3f0d,   // ha.nl.af_322 so.ceb.nl_543  af.sq.sv_442 af.so.nl_554
  0x120f11a4, 0x10040aee, 0x071211a4, 0x20090805,   // ro.lv.hu_433 mk.ru.be_422  ro.hu.it_433 no.pl.sq_333
  0x10072a07, 0x6b3208a0, 0x08120ead, 0x08230ca0,   // mt.it.lt_432 no.bs.ceb_322  is.hu.no_643 sv.ca.no_322
  0x0a1105ec, 0x3f2a0908, 0x13120411, 0x08000c23,   // fr.ro.pt_644 pl.mt.af_443  fi.hu.et_653 sv.no.un_880
  // [8670]
  0x53644aee, 0x2a190a0d, 0x033b0f08, 0x08002a1b,   // yo.lg.ht_422 pt.gl.mt_554  lv.so.nl_443 mt.no.un_770
  0x070425a4, 0x17000c19, 0x2a32020c, 0x1f005304,   // eu.fi.it_433 sv.sr.un_750  da.bs.mt_543 ht.cy.un_320
  0x6b1a0404, 0x25030607, 0x2a000305, 0x526b31a4,   // fi.tl.ceb_332 de.nl.eu_432  nl.mt.un_330 az.ceb.ha_433
  0x0b190a0c, 0x25000614, 0x0c080304, 0x13003b1e,   // pt.gl.es_543 de.eu.un_660  nl.no.sv_332 so.et.un_830
  // [8680]
  0x0c005204, 0x0200121a, 0x08002012, 0x12030655,   // ha.sv.un_320 hu.da.un_760  sq.no.un_640 de.nl.hu_442
  0x041f0dad, 0x55001112, 0x0c2a010b, 0x09002918,   // cs.cy.fi_643 ro.rw.un_640  en.mt.sv_542 sl.pl.un_740
  0x64000c05, 0x0e2d12a7, 0x04001020, 0x3f2a0607,   // sv.lg.un_330 hu.sk.is_532  be.ru.un_850 de.mt.af_432
  0x6b0325ee, 0x1c12040c, 0x12002b04, 0x0c030207,   // eu.nl.ceb_422 fi.hu.id_543  vi.hu.un_320 da.nl.sv_432
  // [8690]
  0x530501a0, 0x032506a4, 0x21065207, 0x4a1b5205,   // en.fr.ht_322 de.eu.nl_433  ha.de.jw_432 ha.tr.yo_333
  0x033f0c55, 0x090d04ad, 0x23002904, 0x55100cee,   // sv.af.nl_442 fi.cs.pl_643  sl.ca.un_320 sv.lt.rw_422
  0x1e0d01a0, 0x64523513, 0x090c04ee, 0x18683fee,   // en.cs.ms_322 zu.ha.lg_665  fi.sv.pl_422 af.ig.ga_422
  0x131a3555, 0x04020c04, 0x1a642809, 0x032a0cec,   // zu.tl.et_442 sv.da.fi_332  sw.lg.tl_444 sv.mt.nl_644
  // [86a0]
  0x13643504, 0x19006b0c, 0x530c27a0, 0x64683507,   // zu.lg.et_332 ceb.gl.un_530  gd.sv.ht_322 zu.ig.lg_432
  0x352564a4, 0x212513ec, 0x110a0412, 0x19130ba7,   // lg.eu.zu_433 et.eu.jw_644  ru.mk.ro_654 es.et.gl_532
  0x11001a04, 0x11000a0d, 0x0f001a04, 0x216435af,   // tl.ro.un_320 pt.ro.un_540  tl.lv.un_320 zu.lg.jw_655
  0x351764ad, 0x31521304, 0x08002708, 0x256468ee,   // lg.sr.zu_643 et.ha.az_332  gd.no.un_430 ig.lg.eu_422
  // [86b0]
  0x27112312, 0x1135640c, 0x1c2a6407, 0x1b002007,   // ca.ro.gd_654 lg.zu.ro_543  lg.mt.id_432 sq.tr.un_420
  0x0f080ca0, 0x35553112, 0x0400072a, 0x2d200907,   // sv.no.lv_322 az.rw.zu_654  bg.ru.un_970 pl.sq.sk_432
  0x110a0fa7, 0x533564ec, 0x2528110c, 0x085523a0,   // lv.pt.ro_532 lg.zu.ht_644  ro.sw.eu_543 ca.rw.no_322
  0x11252812, 0x0b2511a9, 0x190906ee, 0x685301a4,   // sw.eu.ro_654 ro.eu.es_544  de.pl.gl_422 en.ht.ig_433
  // [86c0]
  0x042513a4, 0x2500281a, 0x0d1125a9, 0x1e251107,   // et.eu.fi_433 sw.eu.un_760  eu.ro.cs_544 ro.eu.ms_432
  0x030113a9, 0x252811af, 0x05002d0d, 0x13006405,   // et.en.nl_544 ro.sw.eu_655  sk.fr.un_540 lg.et.un_330
  0x112825ad, 0x1a000120, 0x6b6811a6, 0x031364a9,   // eu.sw.ro_643 en.tl.un_850  ro.ig.ceb_521 lg.et.nl_544
  0x12102108, 0x28250d0c, 0x530868a0, 0x2d043205,   // jw.lt.hu_443 cs.eu.sw_543  ig.no.ht_322 bs.fi.sk_333
  // [86d0]
  0x04100fee, 0x28251160, 0x25001134, 0x32643ba4,   // lv.lt.fi_422 ro.eu.sw_664  ro.eu.un_A80 so.lg.bs_433
  0x23132a0c, 0x4a3b640c, 0x3b000307, 0x1923530d,   // mt.et.ca_543 lg.so.yo_543  nl.so.un_420 ht.ca.gl_554
  0x3f0364ec, 0x25031308, 0x3b03135a, 0x130364a9,   // lg.nl.af_644 et.nl.eu_443  et.nl.so_553 lg.nl.et_544
  0x110407a9, 0x03136412, 0x17290307, 0x25192aa4,   // bg.ru.ro_544 lg.et.nl_654  nl.sl.sr_432 mt.gl.eu_433
  // [86e0]
  0x09004a02, 0x2300010c, 0x03010605, 0x1a211207,   // yo.pl.un_220 en.ca.un_530  de.en.nl_333 hu.jw.tl_432
  0x281a2904, 0x043b0c04, 0x31291bee, 0x0700640d,   // sl.tl.sw_332 sv.so.fi_332  tr.sl.az_422 lg.it.un_540
  0x55121007, 0x32002702, 0x55524a07, 0x53006412,   // lt.hu.rw_432 gd.bs.un_220  yo.ha.rw_432 lg.ht.un_640
  0x2a001307, 0x28551807, 0x17200dee, 0x4a122d12,   // et.mt.un_420 ga.rw.sw_432  cs.sq.sr_422 sk.hu.yo_654
  // [86f0]
  0x13212807, 0x6e2301ad, 0x35521307, 0x1300351a,   // sw.jw.et_432 en.ca.hmn_643  et.ha.zu_432 zu.et.un_760
  0x18122d0c, 0x2a006b21, 0x1c0310a7, 0x6e190bad,   // sk.hu.ga_543 ceb.mt.un_860  lt.nl.id_532 es.gl.hmn_643
  0x040e6b07, 0x521323ad, 0x071806a7, 0x1000121a,   // ceb.is.fi_432 ca.et.ha_643  de.ga.it_532 hu.lt.un_760
  0x04102a11, 0x11292d07, 0x32051ea4, 0x05236eec,   // mt.lt.fi_653 sk.sl.ro_432  ms.fr.bs_433 hmn.ca.fr_644
  // [8700]
  0x063f090c, 0x190a06af, 0x55002d07, 0x2700130e,   // pl.af.de_543 de.pt.gl_655  sk.rw.un_420 et.gd.un_550
  0x276e5308, 0x09000f14, 0x1b1a6b09, 0x03210fee,   // ht.hmn.gd_443 lv.pl.un_660  ceb.tl.tr_444 lv.jw.nl_422
  0x0e130f0c, 0x1a552104, 0x09352d07, 0x1f070da9,   // lv.et.is_543 jw.rw.tl_332  sk.zu.pl_432 cs.it.cy_544
  0x1b316eec, 0x3b000704, 0x216435a0, 0x135231ee,   // hmn.az.tr_644 it.so.un_320  zu.lg.jw_322 az.ha.et_422
  // [8710]
  0x06090faf, 0x190a130c, 0x1f002514, 0x12002812,   // lv.pl.de_655 et.pt.gl_543  eu.cy.un_660 sw.hu.un_640
  0x10200511, 0x080e1fa4, 0x2a3b6eec, 0x3f040704,   // fr.sq.lt_653 cy.is.no_433  hmn.so.mt_644 it.fi.af_332
  0x0600012a, 0x04190b0c, 0x1f051107, 0x0f2a6e14,   // en.de.un_970 es.gl.fi_543  ro.fr.cy_432 hmn.mt.lv_666
  0x07000f21, 0x35136ba7, 0x04002d12, 0x0c251a02,   // lv.it.un_860 ceb.et.zu_532  sk.fi.un_640 tl.eu.sv_222
  // [8720]
  0x04002905, 0x6b00090d, 0x10190bec, 0x06003108,   // sl.fi.un_330 pl.ceb.un_540  es.gl.lt_644 az.de.un_430
  0x06003104, 0x1f1b0eec, 0x4a190bee, 0x20312aee,   // az.de.un_320 is.tr.cy_644  es.gl.yo_422 mt.az.sq_422
  0x6b1a0b0d, 0x52120eaf, 0x0813040b, 0x09001f1a,   // es.tl.ceb_554 is.hu.ha_655  fi.et.no_542 cy.pl.un_760
  0x0c086b09, 0x03011f07, 0x0d2d09a7, 0x0a001002,   // ceb.no.sv_444 cy.en.nl_432  pl.sk.cs_532 lt.pt.un_220
  // [8730]
  0x281301ee, 0x092d1007, 0x01080202, 0x18000519,   // en.et.sw_422 lt.sk.pl_432  da.no.en_222 fr.ga.un_750
  0x10080c04, 0x17110405, 0x09292507, 0x18000a04,   // sv.no.lt_332 ru.ro.sr_333  eu.sl.pl_432 pt.ga.un_320
  0x1b2d0d09, 0x100a2d05, 0x524a3b07, 0x3f1c1aa0,   // cs.sk.tr_444 sk.pt.lt_333  so.yo.ha_432 tl.id.af_322
  0x23000719, 0x533b010b, 0x3b00010c, 0x10000107,   // it.ca.un_750 en.so.ht_542  en.so.un_530 en.lt.un_420
  // [8740]
  0x1b000413, 0x201105a0, 0x2d100aee, 0x182d6e02,   // fi.tr.un_650 fr.ro.sq_322  pt.lt.sk_422 hmn.sk.ga_222
  0x0e003b05, 0x1e100a07, 0x1831250c, 0x18001012,   // so.is.un_330 pt.lt.ms_432  eu.az.ga_543 lt.ga.un_640
  0x18013bad, 0x35000705, 0x2a001a07, 0x253b1f0c,   // so.en.ga_643 it.zu.un_330  tl.mt.un_420 cy.so.eu_543
  0x07292da4, 0x3f2a07a0, 0x081b2507, 0x09132aa4,   // sk.sl.it_433 it.mt.af_322  eu.tr.no_432 mt.et.pl_433
  // [8750]
  0x1e044aa0, 0x0f180a04, 0x232a01a4, 0x1f000604,   // yo.fi.ms_322 pt.ga.lv_332  en.mt.ca_433 de.cy.un_320
  0x01533b0c, 0x4a255311, 0x122a53a9, 0x03062702,   // so.ht.en_543 ht.eu.yo_653  ht.mt.hu_544 gd.de.nl_222
  0x080a0414, 0x052312ee, 0x0a2301a4, 0x0d002104,   // ru.mk.uk_666 hu.ca.fr_422  en.ca.pt_433 jw.cs.un_320
  0x03171604, 0x021208a0, 0x05002504, 0x252a0708,   // hr.sr.nl_332 no.hu.da_322  eu.fr.un_320 it.mt.eu_443
  // [8760]
  0x52002704, 0x1e000608, 0x351302a0, 0x290e1bee,   // gd.ha.un_320 de.ms.un_430  da.et.zu_322 tr.is.sl_422
  0x1f000c04, 0x2b2d10ee, 0x211310a0, 0x1a003204,   // sv.cy.un_320 lt.sk.vi_422  lt.et.jw_322 bs.tl.un_320
  0x111c2804, 0x122d0e05, 0x0a4a1fad, 0x28680e0d,   // sw.id.ro_332 is.sk.hu_333  cy.yo.pt_643 is.ig.sw_554
  0x291632a7, 0x322d2aee, 0x0e000819, 0x0a001919,   // bs.hr.sl_532 mt.sk.bs_422  no.is.un_750 gl.pt.un_750
  // [8770]
  0x1c3b6407, 0x0c041211, 0x3b1f0c02, 0x3f2a010c,   // lg.so.id_432 hu.fi.sv_653  sv.cy.so_222 en.mt.af_543
  0x04000618, 0x1b043204, 0x0c001213, 0x521e1b07,   // de.fi.un_740 bs.fi.tr_332  hu.sv.un_650 tr.ms.ha_432
  0x04001212, 0x0e001b21, 0x29005304, 0x061e1c0d,   // hu.fi.un_640 tr.is.un_860  ht.sl.un_320 id.ms.de_554
  0x111f0e0c, 0x072a1f0b, 0x2a1119a4, 0x19311ba4,   // is.cy.ro_543 cy.mt.it_542  gl.ro.mt_433 tr.az.gl_433
  // [8780]
  0x31061302, 0x29000e12, 0x1b0221ee, 0x25131fee,   // et.de.az_222 is.sl.un_640  jw.da.tr_422 cy.et.eu_422
  0x16103bee, 0x0e001f08, 0x0e00060c, 0x04120c0c,   // so.lt.hr_422 cy.is.un_430  de.is.un_530 sv.hu.fi_543
  0x080b1ea0, 0x2a0413a4, 0x1e006b08, 0x0f000307,   // ms.es.no_322 et.fi.mt_433  ceb.ms.un_430 nl.lv.un_420
  0x3f001f02, 0x2a080c07, 0x081707a0, 0x08311b55,   // cy.af.un_220 sv.no.mt_432  bg.sr.uk_322 tr.az.no_442
  // [8790]
  0x06003f0c, 0x0735550c, 0x25000923, 0x1a6b01af,   // af.de.un_530 rw.zu.it_543  pl.eu.un_880 en.ceb.tl_655
  0x6b3128ad, 0x3b005207, 0x2d1f0dad, 0x02001a05,   // sw.az.ceb_643 ha.so.un_420  cs.cy.sk_643 tl.da.un_330
  0x0e003f08, 0x55521aa9, 0x3b00210e, 0x1800680d,   // af.is.un_430 tl.ha.rw_544  jw.so.un_550 ig.ga.un_540
  0x521b2509, 0x1b001105, 0x0d180608, 0x10080a07,   // eu.tr.ha_444 ro.tr.un_330  de.ga.cs_443 mk.uk.be_432
  // [87a0]
  0x3b000e0e, 0x12001114, 0x0c002a0e, 0x11000512,   // is.so.un_550 ro.hu.un_660  mt.sv.un_550 fr.ro.un_640
  0x6b1a01a9, 0x2718200c, 0x0e1b0413, 0x3b5228af,   // en.tl.ceb_544 sq.ga.gd_543  fi.tr.is_665 sw.ha.so_655
  0x03051f0e, 0x201b09a9, 0x2b003505, 0x5500200b,   // cy.fr.nl_555 pl.tr.sq_544  zu.vi.un_330 sq.rw.un_520
  0x0e131baf, 0x0e00351a, 0x1f006b02, 0x013f050c,   // tr.et.is_655 zu.is.un_760  ceb.cy.un_220 fr.af.en_543
  // [87b0]
  0x070f1312, 0x530d190c, 0x08001302, 0x253b2a0c,   // et.lv.it_654 gl.cs.ht_543  et.no.un_220 mt.so.eu_543
  0x640e07ec, 0x3b6b130c, 0x0a1711a7, 0x17000f04,   // it.is.lg_644 et.ceb.so_543  ro.sr.mk_532 lv.sr.un_320
  0x05531904, 0x0d1029a4, 0x233f0507, 0x1f002b10,   // gl.ht.fr_332 sl.lt.cs_433  fr.af.ca_432 vi.cy.un_620
  0x06000409, 0x110504a4, 0x09311b07, 0x1c0d09a0,   // fi.de.un_440 fi.fr.ro_433  tr.az.pl_432 hi.ne.mr_322
  // [87c0]
  0x23001012, 0x11130f08, 0x0a162804, 0x194a280b,   // lt.ca.un_640 lv.et.ro_443  sw.hr.pt_332 sw.yo.gl_542
  0x0e080ca9, 0x52642808, 0x0f071007, 0x092d1607,   // sv.no.is_544 sw.lg.ha_443  lt.it.lv_432 hr.sk.pl_432
  0x0c001308, 0x132a0755, 0x0900290b, 0x3500550b,   // et.sv.un_430 it.mt.et_442  sl.pl.un_520 rw.zu.un_520
  0x64002822, 0x01003f07, 0x2d045304, 0x03005504,   // sw.lg.un_870 af.en.un_420  ht.fi.sk_332 rw.nl.un_320
  // [87d0]
  0x122118a0, 0x111e1ca0, 0x3f020ca0, 0x0c000508,   // ar.fa.ur_322 id.ms.ro_322  sv.da.af_322 fr.sv.un_430
  0x6b6428ad, 0x311a06a6, 0x08001719, 0x1a00040c,   // sw.lg.ceb_643 de.tl.az_521  sr.uk.un_750 fi.tl.un_530
  0x020c0811, 0x031c01a4, 0x28002508, 0x063101a0,   // no.sv.da_653 en.id.nl_433  eu.sw.un_430 en.az.de_322
  0x21270bee, 0x0b6b55a4, 0x11001319, 0x0f250302,   // es.gd.jw_422 rw.ceb.es_433  et.ro.un_750 nl.eu.lv_222
  // [87e0]
  0x5228200c, 0x1200051a, 0x2800070c, 0x310106ee,   // sq.sw.ha_543 fr.hu.un_760  it.sw.un_530 de.en.az_422
  0x53010507, 0x2006010c, 0x281a21a4, 0x2d0f0dec,   // fr.en.ht_432 en.de.sq_543  jw.tl.sw_433 cs.lv.sk_644
  0x1200091b, 0x1b004a04, 0x5500061a, 0x522013a9,   // pl.hu.un_770 yo.tr.un_320  de.rw.un_760 et.sq.ha_544
  0x0b00050c, 0x28000209, 0x190b35a4, 0x0700350c,   // fr.es.un_530 da.sw.un_440  zu.es.gl_433 zu.it.un_530
  // [87f0]
  0x05000d08, 0x5304130b, 0x09003f04, 0x1b190b0c,   // cs.fr.un_430 et.fi.ht_542  af.pl.un_320 es.gl.tr_543
  0x2d002b0b, 0x32236e0c, 0x35010aa6, 0x2d0d1609,   // vi.sk.un_520 hmn.ca.bs_543  pt.en.zu_521 hr.cs.sk_444
  0x1b00230b, 0x0a000c05, 0x0c0864a9, 0x2d0f17a9,   // ca.tr.un_520 sv.pt.un_330  lg.no.sv_544 sr.lv.sk_544
  0x1200090b, 0x03006804, 0x02016404, 0x3b001108,   // pl.hu.un_520 ig.nl.un_320  lg.en.da_332 ro.so.un_430

  // [8800]
  0x0a530907, 0x552d0907, 0x10002d0e, 0x04120811,   // pl.ht.pt_432 pl.sk.rw_432  sk.lt.un_550 no.hu.fi_653
  0x0f0a3bee, 0x1b0601a0, 0x2110350e, 0x0a00310c,   // so.pt.lv_422 en.de.tr_322  zu.lt.jw_555 az.pt.un_530
  0x19006b04, 0x093555a0, 0x31101b0e, 0x02000504,   // ceb.gl.un_320 rw.zu.pl_322  tr.lt.az_555 fr.da.un_320
  0x32000905, 0x1b196bec, 0x133b1855, 0x08023ba0,   // pl.bs.un_330 ceb.gl.tr_644  ga.so.et_442 so.da.no_322
  // [8810]
  0x061b2507, 0x18000e19, 0x29170909, 0x3b001813,   // eu.tr.de_432 is.ga.un_750  pl.sr.sl_444 ga.so.un_650
  0x1a0e0402, 0x3b0c1ca0, 0x04254aad, 0x10002013,   // fi.is.tl_222 id.sv.so_322  yo.eu.fi_643 sq.lt.un_650
  0x033f1e02, 0x170f2da7, 0x0802070c, 0x326b280c,   // ms.af.nl_222 sk.lv.sr_532  it.da.no_543 sw.ceb.bs_543
  0x2d0d295a, 0x17080707, 0x0c103b12, 0x28041a09,   // sl.cs.sk_553 bg.uk.sr_432  so.lt.sv_654 tl.fi.sw_444
  // [8820]
  0x29001b0c, 0x0e000413, 0x55136ba0, 0x0f1011ec,   // tr.sl.un_530 fi.is.un_650  ceb.et.rw_322 ro.lt.lv_644
  0x6b001307, 0x05230a04, 0x1a132804, 0x1a0e1ca4,   // et.ceb.un_420 pt.ca.fr_332  sw.et.tl_332 id.is.tl_433
  0x20251c07, 0x351f27ad, 0x17100a55, 0x3b351a08,   // id.eu.sq_432 gd.cy.zu_643  mk.be.sr_442 tl.zu.so_443
  0x6b001318, 0x063b1e04, 0x18000d04, 0x52002a21,   // et.ceb.un_740 ms.so.de_332  cs.ga.un_320 mt.ha.un_860
  // [8830]
  0x2d0302a4, 0x3200160b, 0x04000e12, 0x0b322807,   // da.nl.sk_433 hr.bs.un_520  is.fi.un_640 sw.bs.es_432
  0x28171608, 0x25010c0c, 0x2a01250c, 0x0f3b13ec,   // hr.sr.sw_443 sv.en.eu_543  eu.en.mt_543 et.so.lv_644
  0x25211c07, 0x2a1c2102, 0x023b1a0c, 0x182725a6,   // id.jw.eu_432 jw.id.mt_222  tl.so.da_543 eu.gd.ga_521
  0x21001123, 0x3b00680c, 0x0e3f0612, 0x21003b20,   // ro.jw.un_880 ig.so.un_530  de.af.is_654 so.jw.un_850
  // [8840]
  0x2b3f03ad, 0x251a10a4, 0x1000170d, 0x0925350c,   // nl.af.vi_643 lt.tl.eu_433  sr.be.un_540 zu.eu.pl_543
  0x645235ee, 0x126b13ee, 0x29000104, 0x1a210704,   // zu.ha.lg_422 et.ceb.hu_422  en.sl.un_320 it.jw.tl_332
  0x03003b07, 0x04002112, 0x2b001e13, 0x04133b0d,   // so.nl.un_420 jw.fi.un_640  ms.vi.un_650 so.et.fi_554
  0x6b1a180c, 0x25004a04, 0x05190eee, 0x0b0a13a0,   // ga.tl.ceb_543 yo.eu.un_320  is.gl.fr_422 et.pt.es_322
  // [8850]
  0x062a3b12, 0x16001004, 0x2a051faf, 0x08000a0c,   // so.mt.de_654 lt.hr.un_320  cy.fr.mt_655 mk.uk.un_530
  0x0a3b11a4, 0x31522312, 0x0100130d, 0x03070607,   // ro.so.pt_433 ca.ha.az_654  et.en.un_540 de.it.nl_432
  0x11100408, 0x131201a7, 0x1355010c, 0x1e005302,   // ru.be.ro_443 en.hu.et_532  en.rw.et_543 ht.ms.un_220
  0x552d01a7, 0x292025ac, 0x2d002107, 0x2d0e0c02,   // en.sk.rw_532 eu.sq.sl_632  jw.sk.un_420 sv.is.sk_222
  // [8860]
  0x2b001f05, 0x31002509, 0x2b1801ee, 0x2d081aa0,   // cy.vi.un_330 eu.az.un_440  en.ga.vi_422 tl.no.sk_322
  0x04080aaf, 0x1c290fa0, 0x0800022c, 0x102d29ee,   // mk.uk.ru_655 lv.sl.id_322  da.no.un_990 sl.sk.lt_422
  0x05013fa0, 0x0d252dad, 0x53002808, 0x04001f02,   // af.en.fr_322 sk.eu.cs_643  sw.ht.un_430 cy.fi.un_220
  0x051304a7, 0x08000c2c, 0x3f2901a4, 0x0e003207,   // fi.et.fr_532 sv.no.un_990  en.sl.af_433 bs.is.un_420
  // [8870]
  0x0c0821a0, 0x551f08a7, 0x012d0d04, 0x08005505,   // jw.no.sv_322 no.cy.rw_532  cs.sk.en_332 rw.no.un_330
  0x12020ca6, 0x2d005308, 0x0c001908, 0x13001f12,   // sv.da.hu_521 ht.sk.un_430  gl.sv.un_430 cy.et.un_640
  0x0b001005, 0x01312aac, 0x6b033f09, 0x4a001012,   // lt.es.un_330 mt.az.en_632  af.nl.ceb_444 lt.yo.un_640
  0x311b20a7, 0x053f10a0, 0x100223ec, 0x640328ad,   // sq.tr.az_532 lt.af.fr_322  ca.da.lt_644 sw.nl.lg_643
  // [8880]
  0x130c10a0, 0x010e3fa7, 0x2a11180c, 0x0c0855a9,   // lt.sv.et_322 af.is.en_532  ga.ro.mt_543 rw.no.sv_544
  0x10002312, 0x180c0808, 0x12032309, 0x133b640d,   // ca.lt.un_640 no.sv.ga_443  ca.nl.hu_444 lg.so.et_554
  0x122318ad, 0x10002012, 0x0a001019, 0x0b28100c,   // ga.ca.hu_643 sq.lt.un_640  lt.pt.un_750 lt.sw.es_543
  0x21002909, 0x1011120c, 0x04080702, 0x050823a6,   // sl.jw.un_440 hu.ro.lt_543  bg.uk.ru_222 ca.no.fr_521
  // [8890]
  0x21685507, 0x03002304, 0x27002805, 0x1a6b200d,   // rw.ig.jw_432 ca.nl.un_320  sw.gd.un_330 sq.ceb.tl_554
  0x111e1cec, 0x52003513, 0x1e3f1ca4, 0x090d1cee,   // id.ms.ro_644 zu.ha.un_650  id.af.ms_433 mr.ne.hi_422
  0x3b041304, 0x2a000c12, 0x072b6b0d, 0x12006822,   // et.fi.so_332 sv.mt.un_640  ceb.vi.it_554 ig.hu.un_870
  0x210e4aa0, 0x2d002814, 0x350b5508, 0x521c530c,   // yo.is.jw_322 sw.sk.un_660  rw.es.zu_443 ht.id.ha_543
  // [88a0]
  0x21006b05, 0x28182713, 0x6429110c, 0x322d0908,   // ceb.jw.un_330 gd.ga.sw_665  ro.sl.lg_543 pl.sk.bs_443
  0x3b1b2a11, 0x2000350e, 0x100a0507, 0x1105070d,   // mt.tr.so_653 zu.sq.un_550  fr.pt.lt_432 it.fr.ro_554
  0x18000921, 0x0f20350c, 0x10001c1a, 0x04006404,   // pl.ga.un_860 zu.sq.lv_543  id.lt.un_760 lg.fi.un_320
  0x17290fa9, 0x3b002a0b, 0x1100310d, 0x0e040f0c,   // lv.sl.sr_544 mt.so.un_520  az.ro.un_540 lv.fi.is_543
  // [88b0]
  0x523b280d, 0x202a0e0c, 0x53212a0c, 0x271f35ee,   // sw.so.ha_554 is.mt.sq_543  mt.jw.ht_543 zu.cy.gd_422
  0x272111a4, 0x32100f08, 0x1a210111, 0x07080a0c,   // ro.jw.gd_433 lv.lt.bs_443  en.jw.tl_653 mk.uk.bg_543
  0x070b23a9, 0x0f100c08, 0x0d001c2a, 0x3f1a1007,   // ca.es.it_544 sv.lt.lv_443  mr.ne.un_970 lt.tl.af_432
  0x0e3b01a4, 0x686b0108, 0x0b000a04, 0x4a2b0e04,   // en.so.is_433 en.ceb.ig_443  pt.es.un_320 is.vi.yo_332
  // [88c0]
  0x1c0e1ea4, 0x0e3b095a, 0x0d004a1b, 0x0b184a5a,   // ms.is.id_433 pl.so.is_553  yo.cs.un_770 yo.ga.es_553
  0x184a2ba7, 0x18004a35, 0x32091e0b, 0x100d0412,   // vi.yo.ga_532 yo.ga.un_A90  ms.pl.bs_542 fi.cs.lt_654
  0x110e0c0d, 0x1e1c0a05, 0x06020ca0, 0x19000a1a,   // sv.is.ro_554 pt.id.ms_333  sv.da.de_322 pt.gl.un_760
  0x2b184aec, 0x2b184aa7, 0x0d002919, 0x1c003204,   // yo.ga.vi_644 yo.ga.vi_532  sl.cs.un_750 bs.id.un_320
  // [88d0]
  0x091b5307, 0x091b530c, 0x64000705, 0x09251b07,   // ht.tr.pl_432 ht.tr.pl_543  it.lg.un_330 tr.eu.pl_432
  0x313b5204, 0x31190a60, 0x12642aad, 0x3f0410a0,   // ha.so.az_332 pt.gl.az_664  mt.lg.hu_643 lt.fi.af_322
  0x1e1c0909, 0x23184aad, 0x12106804, 0x041b0faf,   // pl.id.ms_444 yo.ga.ca_643  ig.lt.hu_332 lv.tr.fi_655
  0x1a6b28ee, 0x2a06010c, 0x07531955, 0x0700640c,   // sw.ceb.tl_422 en.de.mt_543  gl.ht.it_442 lg.it.un_530
  // [88e0]
  0x0c1e1c5a, 0x0d002b1a, 0x0c0610a0, 0x2a6b29a0,   // id.ms.sv_553 vi.cs.un_760  lt.de.sv_322 sl.ceb.mt_322
  0x07002707, 0x3b2331a0, 0x196b01ad, 0x64001b18,   // gd.it.un_420 az.ca.so_322  en.ceb.gl_643 tr.lg.un_740
  0x292d3b0e, 0x2a2032a0, 0x0b554a07, 0x281c1ea0,   // so.sk.sl_555 bs.sq.mt_322  yo.rw.es_432 ms.id.sw_322
  0x190b35ee, 0x1c212855, 0x531b35ee, 0x0e120c07,   // zu.es.gl_422 sw.jw.id_442  zu.tr.ht_422 sv.hu.is_432
  // [88f0]
  0x52001a07, 0x0b080c05, 0x1b1208a4, 0x2d0c0da4,   // tl.ha.un_420 sv.no.es_333  no.hu.tr_433 cs.sv.sk_433
  0x11121008, 0x1f00010d, 0x4a2921a0, 0x1b53310e,   // lt.hu.ro_443 en.cy.un_540  jw.sl.yo_322 az.ht.tr_555
  0x1100550d, 0x52211c55, 0x2d0d2109, 0x19110b04,   // rw.ro.un_540 id.jw.ha_442  jw.cs.sk_444 es.ro.gl_332
  0x52101e0c, 0x0b003b04, 0x520f100d, 0x08210ea0,   // ms.lt.ha_543 so.es.un_320  lt.lv.ha_554 is.jw.no_322
  // [8900]
  0x076411a0, 0x100f1ea9, 0x13091c08, 0x31123ba0,   // ro.lg.it_322 ms.lv.lt_544  mr.hi.bh_443 so.hu.az_322
  0x281052a4, 0x28001e02, 0x12132907, 0x11001b1a,   // ha.lt.sw_433 ms.sw.un_220  sl.et.hu_432 tr.ro.un_760
  0x19230d04, 0x0700060b, 0x0f120ca0, 0x1e1112ee,   // cs.ca.gl_332 de.it.un_520  sv.hu.lv_322 hu.ro.ms_422
  0x640417a0, 0x1e1c0aa4, 0x3f285204, 0x06136ba0,   // sr.fi.lg_322 pt.id.ms_433  ha.sw.af_332 ceb.et.de_322
  // [8910]
  0x521012a4, 0x28121ea4, 0x292d09ad, 0x25006e07,   // hu.lt.ha_433 ms.hu.sw_433  pl.sk.sl_643 hmn.eu.un_420
  0x1c1e52ad, 0x521008a4, 0x1000520d, 0x280335a0,   // ha.ms.id_643 no.lt.ha_433  ha.lt.un_540 zu.nl.sw_322
  0x03070aa0, 0x0a2810a4, 0x10000309, 0x0b2827ee,   // pt.it.nl_322 lt.sw.pt_433  nl.lt.un_440 gd.sw.es_422
  0x2b002007, 0x3b2728ad, 0x0564550e, 0x2d0f0913,   // sq.vi.un_420 sw.gd.so_643  rw.lg.fr_555 pl.lv.sk_665
  // [8920]
  0x272a1112, 0x06020c09, 0x0723190d, 0x0c0e08ee,   // ro.mt.gd_654 sv.da.de_444  gl.ca.it_554 no.is.sv_422
  0x1f0518a7, 0x1f0518ec, 0x283b52af, 0x08530eee,   // ga.fr.cy_532 ga.fr.cy_644  ha.so.sw_655 is.ht.no_422
  0x130d1ca9, 0x05041fa0, 0x030625ad, 0x2b2d3b04,   // mr.ne.bh_544 cy.fi.fr_322  eu.de.nl_643 so.sk.vi_332
  0x041c4a04, 0x0f0612a4, 0x1b3f6ba0, 0x0f095255,   // yo.id.fi_332 hu.de.lv_433  ceb.af.tr_322 ha.pl.lv_442
  // [8930]
  0x1a0910ee, 0x3b524aee, 0x521b530c, 0x01001f0b,   // lt.pl.tl_422 yo.ha.so_422  ht.tr.ha_543 cy.en.un_520
  0x10003f05, 0x53001f12, 0x35001913, 0x1800051a,   // af.lt.un_330 cy.ht.un_640  gl.zu.un_650 fr.ga.un_760
  0x032b16a0, 0x03003f36, 0x17311bad, 0x3f0313a7,   // hr.vi.nl_322 af.nl.un_AA0  tr.az.sr_643 et.nl.af_532
  0x253b31ee, 0x3b0653ec, 0x103f1aa0, 0x2d0d3b0d,   // az.so.eu_422 ht.de.so_644  tl.af.lt_322 so.cs.sk_554
  // [8940]
  0x20033f07, 0x2a1e2107, 0x1c2a2104, 0x24000133,   // af.nl.sq_432 jw.ms.mt_432  jw.mt.id_332 iw.yi.un_A70
  0x3b061012, 0x022a0bee, 0x3200210c, 0x052d0d11,   // lt.de.so_654 es.mt.da_422  jw.bs.un_530 cs.sk.fr_653
  0x17006e04, 0x211e1ca7, 0x53000702, 0x19211f08,   // hmn.sr.un_320 id.ms.jw_532  it.ht.un_220 cy.jw.gl_443
  0x0f1613a7, 0x6b1c11ee, 0x32001209, 0x3f210360,   // et.hr.lv_532 ro.id.ceb_422  hu.bs.un_440 nl.jw.af_664
  // [8950]
  0x1a001c07, 0x171668ee, 0x32122904, 0x0d0802a0,   // id.tl.un_420 ig.hr.sr_422  sl.hu.bs_332 da.no.cs_322
  0x09002914, 0x3f523205, 0x1300040b, 0x3f1101a4,   // sl.pl.un_660 bs.ha.af_333  fi.et.un_520 en.ro.af_433
  0x21100ca4, 0x0e0b19a7, 0x2400010e, 0x1a003f07,   // sv.lt.jw_433 gl.es.is_532  iw.yi.un_550 af.tl.un_420
  0x23003f02, 0x1b2008a0, 0x2d002918, 0x026408ac,   // af.ca.un_220 no.sq.tr_322  sl.sk.un_740 no.lg.da_632
  // [8960]
  0x0e1918a7, 0x192302a4, 0x0f1710a9, 0x23000713,   // ga.gl.is_532 da.ca.gl_433  lt.sr.lv_544 it.ca.un_650
  0x2804130d, 0x234a18ee, 0x6b043ba9, 0x3b280412,   // et.fi.sw_554 ga.yo.ca_422  so.fi.ceb_544 fi.sw.so_654
  0x23001107, 0x0f280412, 0x1c090da7, 0x02006407,   // ro.ca.un_420 fi.sw.lv_654  ne.hi.mr_532 lg.da.un_420
  0x4a002821, 0x192d0d13, 0x0b000304, 0x4a683b0c,   // sw.yo.un_860 cs.sk.gl_665  nl.es.un_320 so.ig.yo_543
  // [8970]
  0x17100cee, 0x1c00250d, 0x1800122a, 0x0a0128a7,   // sv.lt.sr_422 eu.id.un_540  ur.ar.un_970 sw.en.pt_532
  0x033f21a0, 0x530f28ac, 0x31000e05, 0x0c00022a,   // jw.af.nl_322 sw.lv.ht_632  is.az.un_330 da.sv.un_970
  0x28000421, 0x32162907, 0x4a3b6808, 0x0d17160e,   // fi.sw.un_860 sl.hr.bs_432  ig.so.yo_443 hr.sr.cs_555
  0x283b040d, 0x04003b22, 0x04004a22, 0x521e3ba4,   // fi.so.sw_554 so.fi.un_870  yo.fi.un_870 so.ms.ha_433
  // [8980]
  0x2a1f2b04, 0x20311ba7, 0x551a28a0, 0x1c311ead,   // vi.cy.mt_332 tr.az.sq_532  sw.tl.rw_322 ms.az.id_643
  0x03045304, 0x640e1b0c, 0x530406a0, 0x111e6b0c,   // ht.fi.nl_332 tr.is.lg_543  de.fi.ht_322 ceb.ms.ro_543
  0x1b3564ec, 0x28522a12, 0x170728ec, 0x161328a9,   // lg.zu.tr_644 mt.ha.sw_654  sw.it.sr_644 sw.et.hr_544
  0x040e2aa4, 0x321752ec, 0x0c000e2b, 0x0e1a52af,   // mt.is.fi_433 ha.sr.bs_644  is.sv.un_980 ha.tl.is_655
  // [8990]
  0x20210755, 0x6b0e25a4, 0x070b110c, 0x3f6435ee,   // it.jw.sq_442 eu.is.ceb_433  ro.es.it_543 zu.lg.af_422
  0x68005522, 0x6b005208, 0x25001a02, 0x0a000411,   // rw.ig.un_870 ha.ceb.un_430  tl.eu.un_220 ru.mk.un_630
  0x1b3111a9, 0x4a6855ec, 0x074a68ad, 0x641207a7,   // ro.az.tr_544 rw.ig.yo_644  ig.yo.it_643 it.hu.lg_532
  0x1f18270d, 0x0b1007a0, 0x2128680c, 0x205232a0,   // gd.ga.cy_554 it.lt.es_322  ig.sw.jw_543 bs.ha.sq_322
  // [89a0]
  0x282a27ee, 0x08020c12, 0x06202307, 0x4a556812,   // gd.mt.sw_422 sv.da.no_654  ca.sq.de_432 ig.rw.yo_654
  0x11002521, 0x07001908, 0x1e1c6b02, 0x12000918,   // eu.ro.un_860 gl.it.un_430  ceb.id.ms_222 pl.hu.un_740
  0x030e3f07, 0x03060808, 0x200e1f11, 0x0e521aa9,   // af.is.nl_432 no.de.nl_443  cy.is.sq_653 tl.ha.is_544
  0x3b000f07, 0x12192da0, 0x214a68ad, 0x0f003505,   // lv.so.un_420 sk.gl.hu_322  ig.yo.jw_643 zu.lv.un_330
  // [89b0]
  0x522801a4, 0x09000612, 0x6800551b, 0x190a25a9,   // en.sw.ha_433 de.pl.un_640  rw.ig.un_770 eu.pt.gl_544
  0x13523ba9, 0x2b533b05, 0x0f0623a7, 0x532528ee,   // so.ha.et_544 so.ht.vi_333  ca.de.lv_532 sw.eu.ht_422
  0x644a3b04, 0x1b202aa0, 0x0e000408, 0x0603100b,   // so.yo.lg_332 mt.sq.tr_322  fi.is.un_430 lt.nl.de_542
  0x17231fad, 0x181927ac, 0x6b3b13ec, 0x641201a4,   // cy.ca.sr_643 gd.gl.ga_632  et.so.ceb_644 en.hu.lg_433
  // [89c0]
  0x08000504, 0x070116a0, 0x29203107, 0x550b18a4,   // fr.no.un_320 hr.en.it_322  az.sq.sl_432 ga.es.rw_433
  0x23000509, 0x16003104, 0x180153ee, 0x250328a0,   // fr.ca.un_440 az.hr.un_320  ht.en.ga_422 sw.nl.eu_322
  0x16180704, 0x182d0d09, 0x230511a0, 0x18003204,   // it.ga.hr_332 cs.sk.ga_444  ro.fr.ca_322 bs.ga.un_320
  0x0a006408, 0x291f3ba7, 0x050d1207, 0x18092711,   // lg.pt.un_430 so.cy.sl_532  hu.cs.fr_432 gd.pl.ga_653
  // [89d0]
  0x063f08a4, 0x2b002308, 0x536b0107, 0x27000912,   // no.af.de_433 ca.vi.un_430  en.ceb.ht_432 pl.gd.un_640
  0x2b1f01ad, 0x02000511, 0x0a070f04, 0x19050b55,   // en.cy.vi_643 fr.da.un_630  lv.it.pt_332 es.fr.gl_442
  0x100523ee, 0x05002b05, 0x2b000b05, 0x100a0712,   // ca.fr.lt_422 vi.fr.un_330  es.vi.un_330 bg.mk.be_654
  0x182725a4, 0x2a203560, 0x01000208, 0x2d0a12a0,   // eu.gd.ga_433 zu.sq.mt_664  da.en.un_430 hu.pt.sk_322
  // [89e0]
  0x1a002709, 0x12082904, 0x35000507, 0x64002104,   // gd.tl.un_440 sl.no.hu_332  fr.zu.un_420 jw.lg.un_320
  0x07002712, 0x056b0aa0, 0x64000119, 0x3b1a6baf,   // gd.it.un_640 pt.ceb.fr_322  en.lg.un_750 ceb.tl.so_655
  0x231f3f02, 0x0b2319ec, 0x6b3b01a4, 0x31000508,   // af.cy.ca_222 gl.ca.es_644  en.so.ceb_433 fr.az.un_430
  0x1a003b35, 0x10002813, 0x1f171602, 0x3b000122,   // so.tl.un_A90 sw.lt.un_650  hr.sr.cy_222 en.so.un_870
  // [89f0]
  0x285201af, 0x3b531a0d, 0x081711ac, 0x2d001b13,   // en.ha.sw_655 tl.ht.so_554  ro.sr.uk_632 tr.sk.un_650
  0x2800641a, 0x642835ad, 0x25002721, 0x106429ec,   // lg.sw.un_760 zu.sw.lg_643  gd.eu.un_860 sl.lg.lt_644
  0x0e005512, 0x0b002319, 0x0e3555ec, 0x5500290e,   // rw.is.un_640 ca.es.un_750  rw.zu.is_644 sl.rw.un_550
  0x1000291a, 0x2d00230d, 0x016b1a14, 0x31121307,   // sl.lt.un_760 ca.sk.un_540  tl.ceb.en_666 et.hu.az_432
  // [8a00]
  0x6b1a3ba9, 0x07012807, 0x101729ec, 0x1a003b23,   // so.tl.ceb_544 sw.en.it_432  sl.sr.lt_644 so.tl.un_880
  0x1f000405, 0x12530e07, 0x0a642807, 0x16001304,   // fi.cy.un_330 is.ht.hu_432  sw.lg.pt_432 et.hr.un_320
  0x3b1204a4, 0x08002813, 0x0f191107, 0x52206404,   // fi.hu.so_433 sw.no.un_650  ro.gl.lv_432 lg.sq.ha_332
  0x25006413, 0x12250da0, 0x524a1aad, 0x270c0ea0,   // lg.eu.un_650 cs.eu.hu_322  tl.yo.ha_643 is.sv.gd_322
  // [8a10]
  0x1c5209a4, 0x01060da0, 0x23194aee, 0x0e000d1a,   // pl.ha.id_433 cs.de.en_322  yo.gl.ca_422 cs.is.un_760
  0x25190b09, 0x280f1fa4, 0x080a04a0, 0x181f2707,   // es.gl.eu_444 cy.lv.sw_433  ru.mk.uk_322 gd.cy.ga_432
  0x2a003b07, 0x311a3b55, 0x526428a4, 0x010825ad,   // so.mt.un_420 so.tl.az_442  sw.lg.ha_433 eu.no.en_643
  0x3b004a04, 0x2329120c, 0x0d12040c, 0x1b005202,   // yo.so.un_320 hu.sl.ca_543  fi.hu.cs_543 ha.tr.un_220
  // [8a20]
  0x2a3b310c, 0x3f030eee, 0x04122a07, 0x012a1213,   // az.so.mt_543 is.nl.af_422  mt.hu.fi_432 hu.mt.en_665
  0x04000a1a, 0x13005208, 0x28641ea0, 0x2a103b0d,   // mk.ru.un_760 ha.et.un_430  ms.lg.sw_322 so.lt.mt_554
  0x644a27ad, 0x534a3ba4, 0x6b1a3b0b, 0x52112a0c,   // gd.yo.lg_643 so.yo.ht_433  so.tl.ceb_542 mt.ro.ha_543
  0x19120707, 0x09001018, 0x642a0b08, 0x17000818,   // it.hu.gl_432 lt.pl.un_740  es.mt.lg_443 uk.sr.un_740
  // [8a30]
  0x10001719, 0x12684aad, 0x18016ba0, 0x0f00060d,   // sr.be.un_750 yo.ig.hu_643  ceb.en.ga_322 de.lv.un_540
  0x3b641108, 0x640c2a0c, 0x0a1110ad, 0x12233b07,   // ro.lg.so_443 mt.sv.lg_543  be.ro.mk_643 so.ca.hu_432
  0x6b010304, 0x0c004a07, 0x12160d07, 0x190a6402,   // nl.en.ceb_332 yo.sv.un_420  cs.hr.hu_432 lg.pt.gl_222
  0x3f03070c, 0x3b000908, 0x250853a9, 0x530d1004,   // it.nl.af_543 pl.so.un_430  ht.no.eu_544 lt.cs.ht_332
  // [8a40]
  0x12290da0, 0x096b1f04, 0x02001305, 0x0d00020b,   // cs.sl.hu_322 cy.ceb.pl_332  et.da.un_330 da.cs.un_520
  0x2b000113, 0x21001a04, 0x311b200c, 0x066b1aee,   // en.vi.un_650 tl.jw.un_320  sq.tr.az_543 tl.ceb.de_422
  0x1820080e, 0x1a106bad, 0x29002002, 0x3b312a0c,   // no.sq.ga_555 ceb.lt.tl_643  sq.sl.un_220 mt.az.so_543
  0x08020112, 0x0c000221, 0x522725af, 0x321603ec,   // en.da.no_654 da.sv.un_860  eu.gd.ha_655 nl.hr.bs_644
  // [8a50]
  0x2a003112, 0x2a312004, 0x1a6b6408, 0x0a311b13,   // az.mt.un_640 sq.az.mt_332  lg.ceb.tl_443 tr.az.pt_665
  0x0e002a0c, 0x04521a04, 0x1e1b5302, 0x255223a0,   // mt.is.un_530 tl.ha.fi_332  ht.tr.ms_222 ca.ha.eu_322
  0x25040c0b, 0x0752290c, 0x11521e0b, 0x111807a0,   // sv.fi.eu_542 sl.ha.it_543  ms.ha.ro_542 it.ga.ro_322
  0x29090dad, 0x08024aee, 0x2a00312a, 0x16006b08,   // cs.pl.sl_643 yo.da.no_422  az.mt.un_970 ceb.hr.un_430
  // [8a60]
  0x0d202da0, 0x09520d0b, 0x521807a4, 0x11231905,   // sk.sq.cs_322 cs.ha.pl_542  it.ga.ha_433 gl.ca.ro_333
  0x312319a4, 0x1b0f6eee, 0x315564ee, 0x13001e1a,   // gl.ca.az_433 hmn.lv.tr_422  lg.rw.az_422 ms.et.un_760
  0x68230704, 0x08230560, 0x55211e08, 0x1f00100d,   // it.ca.ig_332 fr.ca.no_664  ms.jw.rw_443 lt.cy.un_540
  0x1a646b12, 0x180306ec, 0x05006e34, 0x0d0952a0,   // ceb.lg.tl_654 de.nl.ga_644  hmn.fr.un_A80 ha.pl.cs_322
  // [8a70]
  0x05002d04, 0x21121a07, 0x1709070c, 0x040e13ec,   // sk.fr.un_320 tl.hu.jw_432  it.pl.sr_543 et.is.fi_644
  0x6e00231a, 0x4a005219, 0x0a0155ee, 0x553b52a0,   // ca.hmn.un_760 ha.yo.un_750  rw.en.pt_422 ha.so.rw_322
  0x09072a08, 0x033568a9, 0x6e000313, 0x6e00011a,   // mt.it.pl_443 ig.zu.nl_544  nl.hmn.un_650 en.hmn.un_760
  0x683b52ec, 0x3100530d, 0x1f3f030b, 0x01050602,   // ha.so.ig_644 ht.az.un_540  nl.af.cy_542 de.fr.en_222
  // [8a80]
  0x3f1b050c, 0x2504130c, 0x31206ea7, 0x31536407,   // fr.tr.af_543 et.fi.eu_543  hmn.sq.az_532 lg.ht.az_432
  0x031b5504, 0x2d0b29a4, 0x1e0613a0, 0x3f03190c,   // rw.tr.nl_332 sl.es.sk_433  et.de.ms_322 gl.nl.af_543
  0x53551c0b, 0x21003f1b, 0x05006e11, 0x033f52ee,   // id.rw.ht_542 af.jw.un_770  hmn.fr.un_630 ha.af.nl_422
  0x2a3555ad, 0x03003b08, 0x13002821, 0x4a5552ad,   // rw.zu.mt_643 so.nl.un_430  sw.et.un_860 ha.rw.yo_643
  // [8a90]
  0x3b033fec, 0x3f212aac, 0x52286404, 0x52065512,   // af.nl.so_644 mt.jw.af_632  lg.sw.ha_332 rw.de.ha_654
  0x12000c05, 0x0e130804, 0x0e080707, 0x08000f04,   // sv.hu.un_330 no.et.is_332  it.no.is_432 lv.no.un_320
  0x0655520e, 0x23001f1a, 0x09070da0, 0x23111f13,   // ha.rw.de_555 cy.ca.un_760  cs.it.pl_322 cy.ro.ca_665
  0x5564130c, 0x2d000205, 0x2d0d0214, 0x040a10ee,   // et.lg.rw_543 da.sk.un_330  da.cs.sk_666 be.mk.ru_422
  // [8aa0]
  0x05013f07, 0x64045512, 0x13350460, 0x03200804,   // af.en.fr_432 rw.fi.lg_654  fi.zu.et_664 no.sq.nl_332
  0x0f002804, 0x64292807, 0x64000a07, 0x550425a7,   // sw.lv.un_320 sw.sl.lg_432  pt.lg.un_420 eu.fi.rw_532
  0x1b64130c, 0x0300270d, 0x3f062307, 0x29080eee,   // et.lg.tr_543 gd.nl.un_540  ca.de.af_432 is.no.sl_422
  0x6b060cad, 0x010206ee, 0x070e0807, 0x07080260,   // sv.de.ceb_643 de.da.en_422  no.is.it_432 da.no.it_664
  // [8ab0]
  0x08121b0c, 0x645228ac, 0x3f001f05, 0x35003f07,   // tr.hu.no_543 sw.ha.lg_632  cy.af.un_330 af.zu.un_420
  0x092d3f08, 0x132006ad, 0x1b001313, 0x2d002005,   // af.sk.pl_443 de.sq.et_643  et.tr.un_650 sq.sk.un_330
  0x2d2913ee, 0x041310a4, 0x28322004, 0x130c2aa4,   // et.sl.sk_422 lt.et.fi_433  sq.bs.sw_332 mt.sv.et_433
  0x04311304, 0x201801af, 0x1b2311a0, 0x061f08a4,   // et.az.fi_332 en.ga.sq_655  ro.ca.tr_322 no.cy.de_433
  // [8ac0]
  0x2800351a, 0x55284aa7, 0x1c132a10, 0x1f3f2aa0,   // zu.sw.un_760 yo.sw.rw_532  mt.et.id_642 mt.af.cy_322
  0x091b3fa0, 0x0f003f05, 0x2a1b53a0, 0x23131b13,   // af.tr.pl_322 af.lv.un_330  ht.tr.mt_322 tr.et.ca_665
  0x521204ec, 0x64321604, 0x1b11530c, 0x2a1b08a4,   // fi.hu.ha_644 hr.bs.lg_332  ht.ro.tr_543 no.tr.mt_433
  0x3f072aee, 0x6b6835a0, 0x0e070807, 0x3500680c,   // mt.it.af_422 zu.ig.ceb_322  no.it.is_432 ig.zu.un_530
  // [8ad0]
  0x645528ee, 0x3b125355, 0x072a1fee, 0x532a11a4,   // sw.rw.lg_422 ht.hu.so_442  cy.mt.it_422 ro.mt.ht_433
  0x100b120e, 0x0600081a, 0x53052aa0, 0x033f2aee,   // hu.es.lt_555 no.de.un_760  mt.fr.ht_322 mt.af.nl_422
  0x200f1009, 0x6b6803a4, 0x28000d08, 0x111b31af,   // lt.lv.sq_444 nl.ig.ceb_433  cs.sw.un_430 az.tr.ro_655
  0x2b001805, 0x1700200c, 0x070412ad, 0x1c0d13af,   // ga.vi.un_330 sq.sr.un_530  hu.fi.it_643 bh.ne.mr_655
  // [8ae0]
  0x03283505, 0x1b11290c, 0x1828090c, 0x29092dad,   // zu.sw.nl_333 sl.ro.tr_543  pl.sw.ga_543 sk.pl.sl_643
  0x6b6853a4, 0x2d3b1108, 0x012a07ad, 0x3f020ea4,   // ht.ig.ceb_433 ro.so.sk_443  it.mt.en_643 is.da.af_433
  0x2a1118ee, 0x291b0ba4, 0x29000702, 0x0b000707,   // ga.ro.mt_422 es.tr.sl_433  it.sl.un_220 it.es.un_420
  0x31091b12, 0x31000707, 0x64012704, 0x113129a0,   // tr.pl.az_654 it.az.un_420  gd.en.lg_332 sl.az.ro_322
  // [8af0]
  0x113b0f07, 0x0c530802, 0x23072da4, 0x080e0c02,   // lv.so.ro_432 no.ht.sv_222  sk.it.ca_433 sv.is.no_222
  0x18052709, 0x182d01a0, 0x53005504, 0x25230fa7,   // gd.fr.ga_444 en.sk.ga_322  rw.ht.un_320 lv.ca.eu_532
  0x10020caf, 0x070811ad, 0x05062807, 0x03002808,   // sv.da.lt_655 ro.uk.bg_643  sw.de.fr_432 sw.nl.un_430
  0x32160ca0, 0x06052304, 0x12001309, 0x3b212504,   // sv.hr.bs_322 ca.fr.de_332  et.hu.un_440 eu.jw.so_332
  // [8b00]
  0x0a001912, 0x23010fa0, 0x101117af, 0x55296405,   // gl.pt.un_640 lv.en.ca_322  sr.ro.be_655 lg.sl.rw_333
  0x03173fa0, 0x0e0802ad, 0x28006419, 0x2d001007,   // af.sr.nl_322 da.no.is_643  lg.sw.un_750 lt.sk.un_420
  0x1f003b13, 0x64550705, 0x1103250c, 0x4a5564ad,   // so.cy.un_650 it.rw.lg_333  eu.nl.ro_543 lg.rw.yo_643
  0x16066855, 0x18012504, 0x31281b08, 0x171b2107,   // ig.de.hr_442 eu.en.ga_332  tr.sw.az_443 jw.tr.sr_432
  // [8b10]
  0x12553b08, 0x0f043202, 0x215564ad, 0x1c002908,   // so.rw.hu_443 bs.fi.lv_222  lg.rw.jw_643 sl.id.un_430
  0x180108a0, 0x1c003f04, 0x171625ee, 0x0e023fa0,   // no.en.ga_322 af.id.un_320  eu.hr.sr_422 af.da.is_322
  0x021e1c02, 0x09002b04, 0x1c1b29ee, 0x1a35550c,   // id.ms.da_222 vi.pl.un_320  sl.tr.id_422 rw.zu.tl_543
  0x171110ad, 0x32003b05, 0x201f55a4, 0x20253b05,   // be.ro.sr_643 so.bs.un_330  rw.cy.sq_433 so.eu.sq_333
  // [8b20]
  0x4a00640d, 0x06353f0c, 0x252868a7, 0x11535504,   // lg.yo.un_540 af.zu.de_543  ig.sw.eu_532 rw.ht.ro_332
  0x0e53040c, 0x531e1ca9, 0x12035204, 0x106b1a11,   // fi.ht.is_543 id.ms.ht_544  ha.nl.hu_332 tl.ceb.lt_653
  0x17040a13, 0x20003b04, 0x13640e09, 0x28291905,   // mk.ru.sr_665 so.sq.un_320  is.lg.et_444 gl.sl.sw_333
  0x2d093bec, 0x2d3b0da4, 0x3b4a3fad, 0x131701ee,   // so.pl.sk_644 cs.so.sk_433  af.yo.so_643 en.sr.et_422
  // [8b30]
  0x13023f0c, 0x040108ad, 0x0655645a, 0x06680312,   // af.da.et_543 no.en.fi_643  lg.rw.de_553 nl.ig.de_654
  0x32171611, 0x1a256bee, 0x285535a0, 0x08042aad,   // hr.sr.bs_653 ceb.eu.tl_422  zu.rw.sw_322 mt.fi.no_643
  0x03001608, 0x64005511, 0x10003f0d, 0x291a0107,   // hr.nl.un_430 rw.lg.un_630  af.lt.un_540 en.tl.sl_432
  0x062704af, 0x13172902, 0x131064ee, 0x042a0713,   // fi.gd.de_655 sl.sr.et_222  lg.lt.et_422 it.mt.fi_665
  // [8b40]
  0x13001707, 0x060364a0, 0x2d0c0d55, 0x19353104,   // sr.et.un_420 lg.nl.de_322  cs.sv.sk_442 az.zu.gl_332
  0x554a130c, 0x0e645511, 0x0c050707, 0x3b6455ad,   // et.yo.rw_543 rw.lg.is_653  it.fr.sv_432 rw.lg.so_643
  0x6400682a, 0x0531010c, 0x64685512, 0x1f0818ee,   // ig.lg.un_970 en.az.fr_543  rw.ig.lg_654 ga.no.cy_422
  0x3f13080c, 0x13001b18, 0x0c0102a0, 0x08040a14,   // no.et.af_543 tr.et.un_740  da.en.sv_322 mk.ru.uk_666
  // [8b50]
  0x07040c08, 0x2a041205, 0x23312504, 0x3100230e,   // sv.fi.it_443 hu.fi.mt_333  eu.az.ca_332 ca.az.un_550
  0x19072508, 0x553b6404, 0x532925a0, 0x0f28090b,   // eu.it.gl_443 lg.so.rw_332  eu.sl.ht_322 pl.sw.lv_542
  0x17190b05, 0x1100270e, 0x202d35a4, 0x091f12ad,   // es.gl.sr_333 gd.ro.un_550  zu.sk.sq_433 hu.cy.pl_643
  0x520425a0, 0x182711a7, 0x0452530c, 0x64003b08,   // eu.fi.ha_322 ro.gd.ga_532  ht.ha.fi_543 so.lg.un_430
  // [8b60]
  0x531109a4, 0x3f070fa4, 0x13001817, 0x35556ba0,   // pl.ro.ht_433 lv.it.af_433  ga.et.un_730 ceb.rw.zu_322
  0x1b312aa4, 0x3f001902, 0x03112705, 0x20116e08,   // mt.az.tr_433 gl.af.un_220  gd.ro.nl_333 hmn.ro.sq_443
  0x1700190e, 0x0e1801ee, 0x201b10a0, 0x282d4aad,   // gl.sr.un_550 en.ga.is_422  lt.tr.sq_322 yo.sk.sw_643
  0x18120805, 0x170709ee, 0x1b0804ee, 0x10000714,   // no.hu.ga_333 pl.it.sr_422  fi.no.tr_422 bg.be.un_660
  // [8b70]
  0x0f5304ee, 0x6b1b0805, 0x020413a0, 0x52190b02,   // fi.ht.lv_422 no.tr.ceb_333  et.fi.da_322 es.gl.ha_222
  0x1f000502, 0x10004a04, 0x0f130404, 0x011606a0,   // fr.cy.un_220 yo.lt.un_320  fi.et.lv_332 de.hr.en_322
  0x13060408, 0x1b1911a7, 0x03311b07, 0x3f001304,   // fi.de.et_443 ro.gl.tr_532  tr.az.nl_432 et.af.un_320
  0x0e2a0708, 0x53000807, 0x01072aa0, 0x190b01af,   // it.mt.is_443 no.ht.un_420  mt.it.en_322 en.es.gl_655
  // [8b80]
  0x0f00201a, 0x080c130e, 0x0c3f0309, 0x31190a12,   // sq.lv.un_760 et.sv.no_555  nl.af.sv_444 pt.gl.az_654
  0x0c011bee, 0x08025302, 0x2a1b13ee, 0x020c0e05,   // tr.en.sv_422 ht.da.no_222  et.tr.mt_422 is.sv.da_333
  0x200e0608, 0x3b2a6b07, 0x641055a4, 0x1a0e2112,   // de.is.sq_443 ceb.mt.so_432  rw.lt.lg_433 jw.is.tl_654
  0x1a1031ad, 0x356b1a12, 0x3553310c, 0x13080ca4,   // az.lt.tl_643 tl.ceb.zu_654  az.ht.zu_543 sv.no.et_433
  // [8b90]
  0x1b53520c, 0x3228550c, 0x0c081207, 0x35282a02,   // ha.ht.tr_543 rw.sw.bs_543  hu.no.sv_432 mt.sw.zu_222
  0x286425a0, 0x53523507, 0x13122a04, 0x08645512,   // eu.lg.sw_322 zu.ha.ht_432  mt.hu.et_332 rw.lg.no_654
  0x095310a0, 0x2a000c0b, 0x532328ee, 0x532555a9,   // lt.ht.pl_322 sv.mt.un_520  sw.ca.ht_422 rw.eu.ht_544
  0x2a1055a9, 0x060c0e12, 0x55282308, 0x531b55ee,   // rw.lt.mt_544 is.sv.de_654  ca.sw.rw_443 rw.tr.ht_422
  // [8ba0]
  0x6400282a, 0x52356408, 0x0200052b, 0x1a5564af,   // sw.lg.un_970 lg.zu.ha_443  fr.da.un_980 lg.rw.tl_655
  0x25280ea0, 0x52555308, 0x553508a4, 0x645235ad,   // is.sw.eu_322 ht.rw.ha_443  no.zu.rw_433 zu.ha.lg_643
  0x535535a0, 0x25001304, 0x53000708, 0x35003113,   // zu.rw.ht_322 et.eu.un_320  it.ht.un_430 az.zu.un_650
  0x1b0f0107, 0x130e0c04, 0x11004a0c, 0x522a6bad,   // en.lv.tr_432 sv.is.et_332  yo.ro.un_530 ceb.mt.ha_643
  // [8bb0]
  0x041305af, 0x273b3fee, 0x061a0107, 0x6400350e,   // fr.et.fi_655 af.so.gd_422  en.tl.de_432 zu.lg.un_550
  0x20532d02, 0x05003f1a, 0x1153290c, 0x08023f0e,   // sk.ht.sq_222 af.fr.un_760  sl.ht.ro_543 af.da.no_555
  0x0600250e, 0x0c030804, 0x050a3b12, 0x2a0507ec,   // eu.de.un_550 no.nl.sv_332  so.pt.fr_654 it.fr.mt_644
  0x3b555207, 0x080c0255, 0x6b0c0812, 0x1708105a,   // ha.rw.so_432 da.sv.no_442  no.sv.ceb_654 be.uk.sr_553
  // [8bc0]
  0x0a080205, 0x07211255, 0x3f0308ac, 0x04101110,   // da.no.pt_333 hu.jw.it_442  no.nl.af_632 ro.be.ru_642
  0x3b003105, 0x29040da0, 0x041305a4, 0x21552804,   // az.so.un_330 cs.fi.sl_322  fr.et.fi_433 sw.rw.jw_332
  0x28350ead, 0x6e016b04, 0x10005302, 0x07231108,   // is.zu.sw_643 ceb.en.hmn_332  ht.lt.un_220 ro.ca.it_443
  0x535528ad, 0x3f1f0212, 0x02030e07, 0x01000f0b,   // sw.rw.ht_643 da.cy.af_654  is.nl.da_432 lv.en.un_520
  // [8bd0]
  0x1e271ca0, 0x21521e04, 0x312d0d04, 0x04081fee,   // id.gd.ms_322 ms.ha.jw_332  cs.sk.az_332 cy.no.fi_422
  0x07040802, 0x1a0953a0, 0x1b1131a6, 0x1c005502,   // uk.ru.bg_222 ht.pl.tl_322  az.ro.tr_521 rw.id.un_220
  0x1b532108, 0x3f1c03a4, 0x01000f0c, 0x290d2dec,   // jw.ht.tr_443 nl.id.af_433  lv.en.un_530 sk.cs.sl_644
  0x1c181ea4, 0x09553ba9, 0x53101bad, 0x551a0904,   // ms.ga.id_433 so.rw.pl_544  tr.lt.ht_643 pl.tl.rw_332
  // [8be0]
  0x160c13ad, 0x1a3b55a0, 0x1a530d04, 0x03013f02,   // et.sv.hr_643 rw.so.tl_322  cs.ht.tl_332 af.en.nl_222
  0x04132d0c, 0x0c0e0813, 0x190a6b02, 0x1f1118af,   // sk.et.fi_543 no.is.sv_665  ceb.pt.gl_222 ga.ro.cy_655
  0x4a000512, 0x0100060b, 0x0a2319ee, 0x0b112da4,   // fr.yo.un_640 de.en.un_520  gl.ca.pt_422 sk.ro.es_433
  0x25521f13, 0x27002305, 0x0a133f04, 0x1e1c1902,   // cy.ha.eu_665 ca.gd.un_330  af.et.pt_332 gl.id.ms_222
  // [8bf0]
  0x4a002502, 0x02000c05, 0x4a1f5307, 0x0f0410af,   // eu.yo.un_220 sv.da.un_330  ht.cy.yo_432 lt.fi.lv_655
  0x00001b2d, 0x1c2a21a0, 0x53190a13, 0x201953a9,   // tr.un.un_A00 jw.mt.id_322  pt.gl.ht_665 ht.gl.sq_544
  0x190a10ac, 0x2d001907, 0x0f001119, 0x0a0125a0,   // lt.pt.gl_632 gl.sk.un_420  ro.lv.un_750 eu.en.pt_322
  0x1c1e1b0d, 0x324a09a6, 0x64000a04, 0x0a1304a4,   // tr.ms.id_554 pl.yo.bs_521  pt.lg.un_320 fi.et.pt_433

  // [8c00]
  0x0a553509, 0x0e00350d, 0x1c000711, 0x10352d0c,   // zu.rw.pt_444 zu.is.un_540  it.id.un_630 sk.zu.lt_543
  0x0f1004a7, 0x0e0608ec, 0x133f0a02, 0x3f0e1c04,   // fi.lt.lv_532 no.de.is_644  pt.af.et_222 id.is.af_332
  0x13003513, 0x28000107, 0x1b644a13, 0x203f0107,   // zu.et.un_650 en.sw.un_420  yo.lg.tr_665 en.af.sq_432
  0x1a3f03ee, 0x1b053b05, 0x2d132905, 0x210a06ee,   // nl.af.tl_422 so.fr.tr_333  sl.et.sk_333 de.pt.jw_422
  // [8c10]
  0x03173f02, 0x06003f21, 0x10211aa9, 0x0d003519,   // af.sr.nl_222 af.de.un_860  tl.jw.lt_544 zu.cs.un_750
  0x2d0a0da4, 0x12002312, 0x0c000a08, 0x0a2d190c,   // cs.pt.sk_433 ca.hu.un_640  pt.sv.un_430 gl.sk.pt_543
  0x2800640d, 0x1c020f55, 0x071b010c, 0x1b13040c,   // lg.sw.un_540 lv.da.id_442  en.tr.it_543 fi.et.tr_543
  0x01210cee, 0x1c1321a0, 0x4a251b07, 0x06020c05,   // sv.jw.en_422 jw.et.id_322  tr.eu.yo_432 sv.da.de_333
  // [8c20]
  0x2b553504, 0x27000c07, 0x0f132907, 0x072d0d55,   // zu.rw.vi_332 sv.gd.un_420  sl.et.lv_432 cs.sk.it_442
  0x010802a4, 0x130928a0, 0x0c000405, 0x016b2dad,   // da.no.en_433 sw.pl.et_322  fi.sv.un_330 sk.ceb.en_643
  0x231b0aa0, 0x12000209, 0x0e0827ad, 0x1f641307,   // pt.tr.ca_322 da.hu.un_440  gd.no.is_643 et.lg.cy_432
  0x2513640c, 0x323f030d, 0x080e1f13, 0x03003204,   // lg.et.eu_543 nl.af.bs_554  cy.is.no_665 bs.nl.un_320
  // [8c30]
  0x0400050c, 0x04163f04, 0x2a00070e, 0x180827ee,   // fr.fi.un_530 af.hr.fi_332  it.mt.un_550 gd.no.ga_422
  0x0725130c, 0x041f01a4, 0x64001a09, 0x526b1a04,   // et.eu.it_543 en.cy.fi_433  tl.lg.un_440 tl.ceb.ha_332
  0x0e130408, 0x28001e1a, 0x12091602, 0x21641c0c,   // fi.et.is_443 ms.sw.un_760  hr.pl.hu_222 id.lg.jw_543
  0x0c0f13a4, 0x0b190a55, 0x641e1ca9, 0x270b3bee,   // et.lv.sv_433 pt.gl.es_442  id.ms.lg_544 so.es.gd_422
  // [8c40]
  0x1a1c6ba9, 0x1a116b07, 0x2752280c, 0x64171aa4,   // ceb.id.tl_544 ceb.ro.tl_432  sw.ha.gd_543 tl.sr.lg_433
  0x030701a4, 0x52250607, 0x11001034, 0x25072a14,   // en.it.nl_433 de.eu.ha_432  be.ro.un_A80 mt.it.eu_666
  0x04282aee, 0x036b21ee, 0x1b0d0fee, 0x1a101c07,   // mt.sw.fi_422 jw.ceb.nl_422  lv.cs.tr_422 id.lt.tl_432
  0x0d020302, 0x2b002004, 0x060c0708, 0x1c210f0c,   // nl.da.cs_222 sq.vi.un_320  it.sv.de_443 lv.jw.id_543
  // [8c50]
  0x5200211a, 0x21121aa9, 0x6b1f07a4, 0x17130ea7,   // jw.ha.un_760 tl.hu.jw_544  it.cy.ceb_433 is.et.sr_532
  0x31001319, 0x35000909, 0x20002808, 0x52003f08,   // et.az.un_750 pl.zu.un_440  sw.sq.un_430 af.ha.un_430
  0x1f0c64a4, 0x131801a7, 0x1c13010c, 0x040a11ac,   // lg.sv.cy_433 en.ga.et_532  en.et.id_543 ro.mk.ru_632
  0x291325a4, 0x2a011fec, 0x09083bac, 0x2a050707,   // eu.et.sl_433 cy.en.mt_644  so.no.pl_632 it.fr.mt_432
  // [8c60]
  0x062a0307, 0x093b2d0c, 0x06001e1a, 0x020708a0,   // nl.mt.de_432 sk.so.pl_543  ms.de.un_760 no.it.da_322
  0x06006421, 0x553f35a7, 0x09003b19, 0x01093fee,   // lg.de.un_860 zu.af.rw_532  so.pl.un_750 af.pl.en_422
  0x280635ee, 0x2a3f35ee, 0x13002b11, 0x046453a0,   // zu.de.sw_422 zu.af.mt_422  vi.et.un_630 ht.lg.fi_322
  0x111205a0, 0x2d3b09a4, 0x55180508, 0x0b001107,   // fr.hu.ro_322 pl.so.sk_433  fr.ga.rw_443 ro.es.un_420
  // [8c70]
  0x1f001c0d, 0x2d0912ee, 0x06093512, 0x12000909,   // id.cy.un_540 hu.pl.sk_422  zu.pl.de_654 pl.hu.un_440
  0x27283207, 0x250612ad, 0x03353f05, 0x031f0607,   // bs.sw.gd_432 hu.de.eu_643  af.zu.nl_333 de.cy.nl_432
  0x6b000c04, 0x352852a4, 0x03002007, 0x02041302,   // sv.ceb.un_320 ha.sw.zu_433  sq.nl.un_420 et.fi.da_222
  0x20642807, 0x03060ca0, 0x09002a19, 0x0a1704a0,   // sw.lg.sq_432 sv.de.nl_322  mt.pl.un_750 ru.sr.mk_322
  // [8c80]
  0x06040112, 0x2a045208, 0x08110708, 0x19271811,   // en.fi.de_654 ha.fi.mt_443  bg.ro.uk_443 ga.gd.gl_653
  0x190a18ec, 0x2a0604a4, 0x06130c02, 0x041012ee,   // ga.pt.gl_644 fi.de.mt_433  sv.et.de_222 hu.lt.fi_422
  0x27002b05, 0x03000419, 0x1c640407, 0x042a0808,   // vi.gd.un_330 fi.nl.un_750  fi.lg.id_432 no.mt.fi_443
  0x53190b08, 0x05060707, 0x0d172d07, 0x090c0da7,   // es.gl.ht_443 it.de.fr_432  sk.sr.cs_432 cs.sv.pl_532
  // [8c90]
  0x0c081fa0, 0x35022805, 0x2a00030c, 0x2b001214,   // cy.no.sv_322 sw.da.zu_333  nl.mt.un_530 hu.vi.un_660
  0x17001905, 0x091c130b, 0x08042a12, 0x040910a4,   // gl.sr.un_330 bh.mr.hi_542  mt.fi.no_654 lt.pl.fi_433
  0x6408040c, 0x3f040807, 0x2855520c, 0x2d001705,   // fi.no.lg_543 no.fi.af_432  ha.rw.sw_543 sr.sk.un_330
  0x1c3b1e0c, 0x2312050c, 0x23072504, 0x0e006b04,   // ms.so.id_543 fr.hu.ca_543  eu.it.ca_332 ceb.is.un_320
  // [8ca0]
  0x552d10a0, 0x0e006b07, 0x1e121c0c, 0x322752ee,   // lt.sk.rw_322 ceb.is.un_420  id.hu.ms_543 ha.gd.bs_422
  0x0b251f0c, 0x0f101ea4, 0x27000112, 0x23002709,   // cy.eu.es_543 ms.lt.lv_433  en.gd.un_640 gd.ca.un_440
  0x0813020c, 0x0400132b, 0x3b005223, 0x6b2501ee,   // da.et.no_543 et.fi.un_980  ha.so.un_880 en.eu.ceb_422
  0x07100813, 0x281c01a0, 0x27001a08, 0x182701a7,   // uk.be.bg_665 en.id.sw_322  tl.gd.un_430 en.gd.ga_532
  // [8cb0]
  0x55182708, 0x521e1cad, 0x4a001219, 0x0b0107a0,   // gd.ga.rw_443 id.ms.ha_643  hu.yo.un_750 it.en.es_322
  0x20091f02, 0x1b1a640c, 0x29162da0, 0x35273b02,   // cy.pl.sq_222 lg.tl.tr_543  sk.hr.sl_322 so.gd.zu_222
  0x55121f12, 0x08000e1a, 0x6e321604, 0x091c1e11,   // cy.hu.rw_654 is.no.un_760  hr.bs.hmn_332 ms.id.pl_653
  0x252a20a0, 0x1e1f0fee, 0x09110a0c, 0x0c3f02a0,   // sq.mt.eu_322 lv.cy.ms_422  pt.ro.pl_543 da.af.sv_322
  // [8cc0]
  0x320625a7, 0x01251fee, 0x20001113, 0x190b12ec,   // eu.de.bs_532 cy.eu.en_422  ro.sq.un_650 hu.es.gl_644
  0x2111070c, 0x051201a4, 0x112b0704, 0x0e081304,   // it.ro.jw_543 en.hu.fr_433  it.vi.ro_332 et.no.is_332
  0x050401a4, 0x11000105, 0x07552807, 0x0e00050e,   // en.fi.fr_433 en.ro.un_330  sw.rw.it_432 fr.is.un_550
  0x1b12030c, 0x16002104, 0x06000404, 0x172a0808,   // nl.hu.tr_543 jw.hr.un_320  fi.de.un_320 no.mt.sr_443
  // [8cd0]
  0x25132107, 0x21171604, 0x010f0807, 0x1300210d,   // jw.et.eu_432 hr.sr.jw_332  no.lv.en_432 jw.et.un_540
  0x0f00130e, 0x212513af, 0x53001907, 0x0c231004,   // et.lv.un_550 et.eu.jw_655  gl.ht.un_420 lt.ca.sv_332
  0x0700051b, 0x05193f08, 0x0105190c, 0x09281b07,   // fr.it.un_770 af.gl.fr_443  gl.fr.en_543 tr.sw.pl_432
  0x09110613, 0x12053107, 0x09200f08, 0x101b28a0,   // de.ro.pl_665 az.fr.hu_432  lv.sq.pl_443 sw.tr.lt_322
  // [8ce0]
  0x091f68a7, 0x20132107, 0x045319ee, 0x050801a4,   // ig.cy.pl_532 jw.et.sq_432  gl.ht.fi_422 en.no.fr_433
  0x13212512, 0x64000912, 0x010d1904, 0x03210607,   // eu.jw.et_654 pl.lg.un_640  gl.cs.en_332 de.jw.nl_432
  0x08001f08, 0x16001108, 0x21061fad, 0x683564a9,   // cy.no.un_430 ro.hr.un_430  cy.de.jw_643 lg.zu.ig_544
  0x060c0308, 0x28036402, 0x3b5335ee, 0x0a112007,   // nl.sv.de_443 lg.nl.sw_222  zu.ht.so_422 sq.ro.pt_432
  // [8cf0]
  0x17080712, 0x23000802, 0x282a21ec, 0x285564ac,   // bg.uk.sr_654 no.ca.un_220  jw.mt.sw_644 lg.rw.sw_632
  0x10002102, 0x1a281c07, 0x06001e07, 0x281a6b04,   // jw.lt.un_220 id.sw.tl_432  ms.de.un_420 ceb.tl.sw_332
  0x1b5228af, 0x28001b04, 0x2a281ea0, 0x28352a13,   // sw.ha.tr_655 tr.sw.un_320  ms.sw.mt_322 mt.zu.sw_665
  0x09003514, 0x111255a6, 0x2a553505, 0x1c2135a7,   // zu.pl.un_660 rw.hu.ro_521  zu.rw.mt_333 zu.jw.id_532
  // [8d00]
  0x28006b07, 0x17001108, 0x4a5564a7, 0x13174aa4,   // ceb.sw.un_420 ro.sr.un_430  lg.rw.yo_532 yo.sr.et_433
  0x55281a04, 0x28001e22, 0x1f112713, 0x55281ca0,   // tl.sw.rw_332 ms.sw.un_870  gd.ro.cy_665 id.sw.rw_322
  0x1b4a2107, 0x13001221, 0x25281ca0, 0x06001b05,   // jw.yo.tr_432 hu.et.un_860  id.sw.eu_322 tr.de.un_330
  0x2a281e07, 0x3f0c02ee, 0x1b0553a7, 0x07250aad,   // ms.sw.mt_432 da.sv.af_422  ht.fr.tr_532 pt.eu.it_643
  // [8d10]
  0x52121b04, 0x32110da0, 0x520507a7, 0x35040107,   // tr.hu.ha_332 cs.ro.bs_322  it.fr.ha_532 en.fi.zu_432
  0x101b35a0, 0x081711a0, 0x29002d0b, 0x4a2d0d60,   // zu.tr.lt_322 ro.sr.uk_322  sk.sl.un_520 cs.sk.yo_664
  0x09181fad, 0x05002321, 0x1b0d350c, 0x05001222,   // cy.ga.pl_643 ca.fr.un_860  zu.cs.tr_543 hu.fr.un_870
  0x533105a9, 0x53000514, 0x6e211c04, 0x0b006e04,   // fr.az.ht_544 fr.ht.un_660  id.jw.hmn_332 hmn.es.un_320
  // [8d20]
  0x121b310c, 0x19000119, 0x52005308, 0x11040808,   // az.tr.hu_543 en.gl.un_750  ht.ha.un_430 uk.ru.ro_443
  0x01003513, 0x0b0512ad, 0x013f0504, 0x23120511,   // zu.en.un_650 hu.fr.es_643  fr.af.en_332 fr.hu.ca_653
  0x0a006e0b, 0x0b000a21, 0x5305010c, 0x230b0504,   // hmn.pt.un_520 pt.es.un_860  en.fr.ht_543 fr.es.ca_332
  0x283519ee, 0x0e686b12, 0x524a3bee, 0x190a3f05,   // gl.zu.sw_422 ceb.ig.is_654  so.yo.ha_422 af.pt.gl_333
  // [8d30]
  0x092d02ee, 0x642055a0, 0x05190a04, 0x13013ba0,   // da.sk.pl_422 rw.sq.lg_322  pt.gl.fr_332 so.en.et_322
  0x320829a0, 0x192d1ca0, 0x0500122c, 0x0a006e0c,   // sl.no.bs_322 id.sk.gl_322  hu.fr.un_990 hmn.pt.un_530
  0x0a006e08, 0x05001219, 0x532a0704, 0x640a19a4,   // hmn.pt.un_430 hu.fr.un_750  it.mt.ht_332 gl.pt.lg_433
  0x072a20a4, 0x2a3b13a9, 0x135301a0, 0x07000e13,   // sq.mt.it_433 et.so.mt_544  en.ht.et_322 is.it.un_650
  // [8d40]
  0x013b3f08, 0x01133ba0, 0x32001308, 0x0e130c04,   // af.so.en_443 so.et.en_322  et.bs.un_430 sv.et.is_332
  0x53000107, 0x1a006b20, 0x12000304, 0x19000804,   // en.ht.un_420 ceb.tl.un_850  nl.hu.un_320 no.gl.un_320
  0x311b2507, 0x160103ee, 0x55253107, 0x25003204,   // eu.tr.az_432 nl.en.hr_422  az.eu.rw_432 bs.eu.un_320
  0x3b643508, 0x2800060d, 0x6425550d, 0x3f0a06a0,   // zu.lg.so_443 de.sw.un_540  rw.eu.lg_554 de.pt.af_322
  // [8d50]
  0x52000108, 0x19010e0c, 0x122d29a0, 0x0e000814,   // en.ha.un_430 is.en.gl_543  sl.sk.hu_322 no.is.un_660
  0x4a000504, 0x06685555, 0x19003b13, 0x05004a1a,   // fr.yo.un_320 rw.ig.de_442  so.gl.un_650 yo.fr.un_760
  0x55002521, 0x552a5213, 0x531028a0, 0x28005309,   // eu.rw.un_860 ha.mt.rw_665  sw.lt.ht_322 ht.sw.un_440
  0x23121307, 0x250a23af, 0x1a211108, 0x03013fa0,   // et.hu.ca_432 ca.pt.eu_655  ro.jw.tl_443 af.en.nl_322
  // [8d60]
  0x3f092da4, 0x2d3f09a9, 0x12004a0c, 0x292011a0,   // sk.pl.af_433 pl.af.sk_544  yo.hu.un_530 ro.sq.sl_322
  0x06000e05, 0x68083fa4, 0x190b3f12, 0x3f001f12,   // is.de.un_330 af.no.ig_433  af.es.gl_654 cy.af.un_640
  0x06003f18, 0x0b093f08, 0x11100812, 0x0b090f04,   // af.de.un_740 af.pl.es_443  uk.be.ro_654 lv.pl.es_332
  0x17001a04, 0x12080caf, 0x0e00310c, 0x030f0408,   // tl.sr.un_320 sv.no.hu_655  az.is.un_530 fi.lv.nl_443
  // [8d70]
  0x03090613, 0x3f000f09, 0x010c3fa7, 0x1123070d,   // de.pl.nl_665 lv.af.un_440  af.sv.en_532 it.ca.ro_554
  0x093f0f08, 0x08170712, 0x2500050e, 0x100704ee,   // lv.af.pl_443 bg.sr.uk_654  fr.eu.un_550 ru.bg.be_422
  0x0407530c, 0x4a002704, 0x35211c55, 0x12005507,   // ht.it.fi_543 gd.yo.un_320  id.jw.zu_442 rw.hu.un_420
  0x290d0fee, 0x10006b18, 0x1e1f1207, 0x5500090d,   // lv.cs.sl_422 ceb.lt.un_740  hu.cy.ms_432 pl.rw.un_540
  // [8d80]
  0x3b0620ad, 0x2a033f08, 0x100c0814, 0x2a0e64ad,   // sq.de.so_643 af.nl.mt_443  no.sv.lt_666 lg.is.mt_643
  0x2700230d, 0x3b3f07a4, 0x05003505, 0x1923055a,   // ca.gd.un_540 it.af.so_433  zu.fr.un_330 fr.ca.gl_553
  0x55005204, 0x1c12210d, 0x35212005, 0x12190a09,   // ha.rw.un_320 jw.hu.id_554  sq.jw.zu_333 pt.gl.hu_444
  0x19042707, 0x1b2a6412, 0x0500191a, 0x12190a13,   // gd.fi.gl_432 lg.mt.tr_654  gl.fr.un_760 pt.gl.hu_665
  // [8d90]
  0x64005220, 0x6b1a5507, 0x2d0d0fee, 0x212305ee,   // ha.lg.un_850 rw.tl.ceb_432  lv.cs.sk_422 fr.ca.jw_422
  0x0e001007, 0x01002005, 0x080710af, 0x17041355,   // lt.is.un_420 sq.en.un_330  be.bg.uk_655 et.fi.sr_442
  0x190a1305, 0x0f08100c, 0x2a1c2107, 0x556452ec,   // et.pt.gl_333 lt.no.lv_543  jw.id.mt_432 ha.lg.rw_644
  0x1a6b3f11, 0x0d006e07, 0x1a04520c, 0x132a1055,   // af.ceb.tl_653 hmn.cs.un_420  ha.fi.tl_543 lt.mt.et_442
  // [8da0]
  0x29003b07, 0x1304050c, 0x2b050107, 0x64556ba9,   // so.sl.un_420 fr.fi.et_543  en.fr.vi_432 ceb.rw.lg_544
  0x0c0804ad, 0x1b310e0c, 0x310c3b04, 0x041319a4,   // fi.no.sv_643 is.az.tr_543  so.sv.az_332 gl.et.fi_433
  0x120e010c, 0x01040e04, 0x1000010d, 0x202d0d60,   // en.is.hu_543 is.fi.en_332  en.lt.un_540 cs.sk.sq_664
  0x0b19550c, 0x010e1008, 0x2521100c, 0x0a6827a4,   // rw.gl.es_543 lt.is.en_443  lt.jw.eu_543 gd.ig.pt_433
  // [8db0]
  0x6e182711, 0x20033f04, 0x1b280909, 0x190b0a12,   // gd.ga.hmn_653 af.nl.sq_332  pl.sw.tr_444 pt.es.gl_654
  0x2900080e, 0x2d0d12a6, 0x0e08200b, 0x0502080c,   // no.sl.un_550 hu.cs.sk_521  sq.no.is_542 no.da.fr_543
  0x25271102, 0x0e1304af, 0x0a07085a, 0x4a6e6b08,   // ro.gd.eu_222 fi.et.is_655  uk.bg.mk_553 ceb.hmn.yo_443
  0x19000a0d, 0x2b00271b, 0x0b002807, 0x01001302,   // pt.gl.un_540 gd.vi.un_770  sw.es.un_420 et.en.un_220
  // [8dc0]
  0x520e3b60, 0x0d003504, 0x11000c0c, 0x0a071013,   // so.is.ha_664 zu.cs.un_320  sv.ro.un_530 be.bg.mk_665
  0x2b2a1fa0, 0x05520aec, 0x160555ee, 0x07190b02,   // cy.mt.vi_322 pt.ha.fr_644  rw.fr.hr_422 es.gl.it_222
  0x250e0ca7, 0x022b010c, 0x3b553504, 0x3b123208,   // sv.is.eu_532 en.vi.da_543  zu.rw.so_332 bs.hu.so_443
  0x556b1aa7, 0x0a122d11, 0x12000509, 0x13000920,   // tl.ceb.rw_532 sk.hu.pt_653  fr.hu.un_440 hi.bh.un_850
  // [8dd0]
  0x05210eb2, 0x6b351aee, 0x31203b55, 0x3b132aa0,   // is.jw.fr_732 tl.zu.ceb_422  so.sq.az_442 mt.et.so_322
  0x230d0aee, 0x556b3b07, 0x091f0d07, 0x190a12ac,   // pt.cs.ca_422 so.ceb.rw_432  cs.cy.pl_432 hu.pt.gl_632
  0x11001a22, 0x6b284a07, 0x3b1a3504, 0x3f000205,   // tl.ro.un_870 yo.sw.ceb_432  zu.tl.so_332 da.af.un_330
  0x100b0f55, 0x1c3b520c, 0x0c1101ee, 0x29125504,   // lv.es.lt_442 ha.so.id_543  en.ro.sv_422 rw.hu.sl_332
  // [8de0]
  0x230219a6, 0x6b005202, 0x553b6baf, 0x210b0507,   // gl.da.ca_521 ha.ceb.un_220  ceb.so.rw_655 fr.es.jw_432
  0x1f352807, 0x196b0d08, 0x131617ad, 0x13002105,   // sw.zu.cy_432 cs.ceb.gl_443  sr.hr.et_643 jw.et.un_330
  0x526b2da4, 0x35644a0c, 0x1b2b1ca7, 0x091e21ee,   // sk.ceb.ha_433 yo.lg.zu_543  id.vi.tr_532 jw.ms.pl_422
  0x17000721, 0x19000512, 0x08132504, 0x0a2307a4,   // bg.sr.un_860 fr.gl.un_640  eu.et.no_332 it.ca.pt_433
  // [8df0]
  0x181e0413, 0x2a002708, 0x53182707, 0x052112ac,   // fi.ms.ga_665 gd.mt.un_430  gd.ga.ht_432 hu.jw.fr_632
  0x23640904, 0x121a6b5a, 0x1e1c2705, 0x523b6b12,   // pl.lg.ca_332 ceb.tl.hu_553  gd.id.ms_333 ceb.so.ha_654
  0x0d050aa9, 0x1b0a0507, 0x0d321705, 0x04094aa9,   // pt.fr.cs_544 fr.pt.tr_432  sr.bs.cs_333 yo.pl.fi_544
  0x0d1c130b, 0x640a350c, 0x1a056ba7, 0x52003511,   // bh.mr.ne_542 zu.pt.lg_543  ceb.fr.tl_532 zu.ha.un_630
  // [8e00]
  0x1e1c010c, 0x23044aaf, 0x122d0d1b, 0x1b215308,   // en.id.ms_543 yo.fi.ca_655  cs.sk.hu_777 ht.jw.tr_443
  0x3b002821, 0x53643513, 0x353b32a0, 0x0b0a12b2,   // sw.so.un_860 zu.lg.ht_665  bs.so.zu_322 hu.pt.es_732
  0x122d0d07, 0x2a001e02, 0x08171155, 0x190b110e,   // cs.sk.hu_432 ms.mt.un_220  ro.sr.uk_442 ro.es.gl_555
  0x29000f05, 0x0200230e, 0x21126ba4, 0x171664a0,   // lv.sl.un_330 ca.da.un_550  ceb.hu.jw_433 lg.hr.sr_322
  // [8e10]
  0x03000212, 0x116420a4, 0x060c13ee, 0x192025a0,   // da.nl.un_640 sq.lg.ro_433  et.sv.de_422 eu.sq.gl_322
  0x3b133f07, 0x1000290c, 0x100b4a55, 0x0a0b2908,   // af.et.so_432 sl.lt.un_530  yo.es.lt_442 sl.es.pt_443
  0x0802130c, 0x1c211ea7, 0x3f002a04, 0x19000b29,   // et.da.no_543 ms.jw.id_532  mt.af.un_320 es.gl.un_960
  0x104a2913, 0x0c0b200c, 0x03170804, 0x1f002804,   // sl.yo.lt_665 sq.es.sv_543  no.sr.nl_332 sw.cy.un_320
  // [8e20]
  0x0a1017ec, 0x25121fa7, 0x13091204, 0x29104a07,   // sr.be.mk_644 cy.hu.eu_532  hu.pl.et_332 yo.lt.sl_432
  0x07006b12, 0x10041aa4, 0x21282011, 0x09191004,   // ceb.it.un_640 tl.fi.lt_433  sq.sw.jw_653 lt.gl.pl_332
  0x64001804, 0x281327a0, 0x3f091ca0, 0x18042707,   // ga.lg.un_320 gd.et.sw_322  id.pl.af_322 gd.fi.ga_432
  0x01050da0, 0x31042505, 0x11232704, 0x32090511,   // cs.fr.en_322 eu.fi.az_333  gd.ca.ro_332 fr.pl.bs_653
  // [8e30]
  0x211029a4, 0x29000a13, 0x294a0b07, 0x05000a12,   // sl.lt.jw_433 pt.sl.un_650  es.yo.sl_432 pt.fr.un_640
  0x0a110807, 0x191009a7, 0x552035ac, 0x13006e0c,   // no.ro.pt_432 pl.lt.gl_532  zu.sq.rw_632 hmn.et.un_530
  0x1b003519, 0x08002722, 0x3f270407, 0x100717ad,   // zu.tr.un_750 gd.no.un_870  fi.gd.af_432 sr.bg.be_643
  0x040127a0, 0x02000507, 0x0f01070c, 0x07001b04,   // gd.en.fi_322 fr.da.un_420  it.en.lv_543 tr.it.un_320
  // [8e40]
  0x3b1b3104, 0x12311b0b, 0x17002702, 0x050a0ea0,   // az.tr.so_332 tr.az.hu_542  gd.sr.un_220 is.pt.fr_322
  0x27000812, 0x29201111, 0x16292aee, 0x10090408,   // no.gd.un_640 ro.sq.sl_653  mt.sl.hr_422 fi.pl.lt_443
  0x13001902, 0x3b000205, 0x10071704, 0x290f1012,   // gl.et.un_220 da.so.un_330  sr.bg.be_332 lt.lv.sl_654
  0x210e1211, 0x20292a60, 0x132029ad, 0x131f01ad,   // hu.is.jw_653 mt.sl.sq_664  sl.sq.et_643 en.cy.et_643
  // [8e50]
  0x090410a4, 0x091f0405, 0x0d001012, 0x2a070caf,   // lt.fi.pl_433 fi.cy.pl_333  lt.cs.un_640 sv.it.mt_655
  0x01000d19, 0x183f01a7, 0x04064aa0, 0x080a2705,   // cs.en.un_750 en.af.ga_532  yo.de.fi_322 gd.pt.no_333
  0x1a350807, 0x3b1b0e05, 0x254a3ba4, 0x29051f0b,   // no.zu.tl_432 is.tr.so_333  so.yo.eu_433 cy.fr.sl_542
  0x052112a4, 0x03004a1a, 0x1908100c, 0x083502a4,   // hu.jw.fr_433 yo.nl.un_760  lt.no.gl_543 da.zu.no_433
  // [8e60]
  0x0b0a35ee, 0x20523208, 0x0c00350b, 0x07006409,   // zu.pt.es_422 bs.ha.sq_443  zu.sv.un_520 lg.it.un_440
  0x3102080c, 0x0f3f5509, 0x18002734, 0x1b081004,   // no.da.az_543 rw.af.lv_444  gd.ga.un_A80 lt.no.tr_332
  0x2d290d14, 0x02001f14, 0x250a0107, 0x640d2d07,   // cs.sl.sk_666 cy.da.un_660  en.pt.eu_432 sk.cs.lg_432
  0x280811a0, 0x081007a0, 0x18052713, 0x1f100408,   // ro.no.sw_322 bg.be.uk_322  gd.fr.ga_665 fi.lt.cy_443
  // [8e70]
  0x25072a12, 0x185532a0, 0x5264040c, 0x132053ee,   // mt.it.eu_654 bs.rw.ga_322  fi.lg.ha_543 ht.sq.et_422
  0x2725180b, 0x1e1c20a6, 0x182725ad, 0x25206e07,   // ga.eu.gd_542 sq.id.ms_521  eu.gd.ga_643 hmn.sq.eu_432
  0x3f0b5504, 0x080705a0, 0x23001122, 0x282023ee,   // rw.es.af_332 fr.it.no_322  ro.ca.un_870 ca.sq.sw_422
  0x3f080213, 0x27005304, 0x0d0913ac, 0x20291304,   // da.no.af_665 ht.gd.un_320  bh.hi.ne_632 et.sl.sq_332
  // [8e80]
  0x550135a0, 0x1700270c, 0x281a2aa0, 0x6b280907,   // zu.en.rw_322 gd.sr.un_530  mt.tl.sw_322 pl.sw.ceb_432
  0x6b0b07ad, 0x1c101ea0, 0x0a040802, 0x06035307,   // it.es.ceb_643 ms.lt.id_322  uk.ru.mk_222 ht.nl.de_432
  0x2b050a5a, 0x521e11a0, 0x19003b04, 0x1b1310a0,   // pt.fr.vi_553 ro.ms.ha_322  so.gl.un_320 lt.et.tr_322
  0x0a00200c, 0x11040a0c, 0x0e040fa0, 0x0c070ea7,   // sq.pt.un_530 mk.ru.ro_543  lv.fi.is_322 is.it.sv_532
  // [8e90]
  0x25000802, 0x110a2308, 0x0c0e130b, 0x2d102913,   // no.eu.un_220 ca.pt.ro_443  et.is.sv_542 sl.lt.sk_665
  0x10000607, 0x53001f23, 0x07192312, 0x06050fee,   // de.lt.un_420 cy.ht.un_880  ca.gl.it_654 lv.fr.de_422
  0x1b2a31a4, 0x070a08ec, 0x04061008, 0x19005521,   // az.mt.tr_433 uk.mk.bg_644  lt.de.fi_443 rw.gl.un_860
  0x05001a0d, 0x10002811, 0x060e1a07, 0x211352ee,   // tl.fr.un_540 sw.lt.un_630  tl.is.de_432 ha.et.jw_422
  // [8ea0]
  0x3f023b02, 0x071911a0, 0x53253504, 0x0d003b04,   // so.da.af_222 ro.gl.it_322  zu.eu.ht_332 so.cs.un_320
  0x0d352d13, 0x1c0d13a6, 0x200603ec, 0x19111804,   // sk.zu.cs_665 bh.ne.mr_521  nl.de.sq_644 ga.ro.gl_332
  0x35000a02, 0x1100530d, 0x641955ad, 0x3f03130e,   // pt.zu.un_220 ht.ro.un_540  rw.gl.lg_643 et.nl.af_555
  0x283152a9, 0x3b1301a9, 0x0802060b, 0x53002821,   // ha.az.sw_544 en.et.so_544  de.da.no_542 sw.ht.un_860
  // [8eb0]
  0x1e180705, 0x1b273b07, 0x2806030c, 0x28180907,   // it.ga.ms_333 so.gd.tr_432  nl.de.sw_543 pl.ga.sw_432
  0x013f3b07, 0x05000d04, 0x280627ee, 0x64080707,   // so.af.en_432 cs.fr.un_320  gd.de.sw_422 it.no.lg_432
  0x2d096407, 0x23531f0c, 0x2a081ba0, 0x03070b09,   // lg.pl.sk_432 cy.ht.ca_543  tr.no.mt_322 es.it.nl_444
  0x644a5505, 0x283503ad, 0x3b68130e, 0x03291302,   // rw.yo.lg_333 nl.zu.sw_643  et.ig.so_555 et.sl.nl_222
  // [8ec0]
  0x111b2004, 0x522a0607, 0x070601a4, 0x355206ad,   // sq.tr.ro_332 de.mt.ha_432  en.de.it_433 de.ha.zu_643
  0x06010508, 0x05102807, 0x272501a4, 0x21531008,   // fr.en.de_443 sw.lt.fr_432  en.eu.gd_433 lt.ht.jw_443
  0x11072508, 0x11252dad, 0x01060808, 0x1c1e2560,   // eu.it.ro_443 sk.eu.ro_643  no.de.en_443 eu.ms.id_664
  0x080c25ee, 0x081b01a0, 0x251107a9, 0x23182da6,   // eu.sv.no_422 en.tr.no_322  it.ro.eu_544 sk.ga.ca_521
  // [8ed0]
  0x311b20a0, 0x0e2d4a07, 0x1e1c0ca0, 0x022108a4,   // sq.tr.az_322 yo.sk.is_432  sv.id.ms_322 no.jw.da_433
  0x31122805, 0x110712a0, 0x1e1c12af, 0x1a286b07,   // sw.hu.az_333 hu.it.ro_322  hu.id.ms_655 ceb.sw.tl_432
  0x68526407, 0x1a12285a, 0x07202507, 0x02003512,   // lg.ha.ig_432 sw.hu.tl_553  eu.sq.it_432 zu.da.un_640
  0x1a286b0c, 0x0b072d5a, 0x0f092d12, 0x116864ee,   // ceb.sw.tl_543 sk.it.es_553  sk.pl.lv_654 lg.ig.ro_422
  // [8ee0]
  0x11252dee, 0x130b1aa0, 0x072511a4, 0x352701a9,   // sk.eu.ro_422 tl.es.et_322  ro.eu.it_433 en.gd.zu_544
  0x08553508, 0x1c1e1811, 0x07642a14, 0x0e18190d,   // zu.rw.no_443 ga.ms.id_653  mt.lg.it_666 gl.ga.is_554
  0x121a28a0, 0x29201b02, 0x0c3b1ea4, 0x0d6428a6,   // sw.tl.hu_322 tr.sq.sl_222  ms.so.sv_433 sw.lg.cs_521
  0x524a2107, 0x17131ca0, 0x250b64a4, 0x190b6409,   // jw.yo.ha_432 id.et.sr_322  lg.es.eu_433 lg.es.gl_444
  // [8ef0]
  0x2700100d, 0x0e0c04a9, 0x1a280705, 0x55256407,   // lt.gd.un_540 fi.sv.is_544  it.sw.tl_333 lg.eu.rw_432
  0x311c0bee, 0x3b1025a9, 0x070b6455, 0x1a216b05,   // es.id.az_422 eu.lt.so_544  lg.es.it_442 ceb.jw.tl_333
  0x0b271812, 0x550764a4, 0x1f1a6bad, 0x0f002722,   // ga.gd.es_654 lg.it.rw_433  ceb.tl.cy_643 gd.lv.un_870
  0x2552530c, 0x6b0e275a, 0x554a070c, 0x4a645207,   // ht.ha.eu_543 gd.is.ceb_553  it.yo.rw_543 ha.lg.yo_432
  // [8f00]
  0x2d0d0a09, 0x643b0112, 0x020e3104, 0x3f1a6b11,   // pt.cs.sk_444 en.so.lg_654  az.is.da_332 ceb.tl.af_653
  0x3f102509, 0x04531e07, 0x32170da0, 0x55524a12,   // eu.lt.af_444 ms.ht.fi_432  cs.sr.bs_322 yo.ha.rw_654
  0x27131ca0, 0x01193b04, 0x27041307, 0x68000a1b,   // id.et.gd_322 so.gl.en_332  et.fi.gd_432 pt.ig.un_770
  0x0e3f0807, 0x21000118, 0x296455a4, 0x0c005307,   // no.af.is_432 en.jw.un_740  rw.lg.sl_433 ht.sv.un_420
  // [8f10]
  0x2d0d6ea4, 0x0b55645a, 0x18090d0c, 0x5208550c,   // hmn.cs.sk_433 lg.rw.es_553  cs.pl.ga_543 rw.no.ha_543
  0x28051e07, 0x64000b05, 0x17043f08, 0x101b2108,   // ms.fr.sw_432 es.lg.un_330  af.fi.sr_443 jw.tr.lt_443
  0x211309a0, 0x17001c08, 0x190a1814, 0x11182dee,   // pl.et.jw_322 id.sr.un_430  ga.pt.gl_666 sk.ga.ro_422
  0x083f0255, 0x0a0553ee, 0x32172955, 0x2d0d1f0c,   // da.af.no_442 ht.fr.pt_422  sl.sr.bs_442 cy.cs.sk_543
  // [8f20]
  0x062d0309, 0x2305211d, 0x03010207, 0x190a120c,   // nl.sk.de_444 jw.fr.ca_852  da.en.nl_432 hu.pt.gl_543
  0x12052108, 0x03060508, 0x06003f13, 0x3b022712,   // jw.fr.hu_443 fr.de.nl_443  af.de.un_650 gd.da.so_654
  0x290c08ee, 0x0c001002, 0x04080c02, 0x08053f08,   // no.sv.sl_422 lt.sv.un_220  sv.no.fi_222 af.fr.no_443
  0x53030507, 0x06190504, 0x3b131e07, 0x27182ba4,   // fr.nl.ht_432 fr.gl.de_332  ms.et.so_432 vi.ga.gd_433
  // [8f30]
  0x04002513, 0x27186ba7, 0x1c5535a9, 0x04181760,   // eu.fi.un_650 ceb.ga.gd_532  zu.rw.id_544 sr.ar.ru_664
  0x06001b21, 0x040853a4, 0x1b110a07, 0x520e3b07,   // tr.de.un_860 ht.no.fi_433  pt.ro.tr_432 so.is.ha_432
  0x0b113107, 0x08523b12, 0x0f2864ee, 0x271f1104,   // az.ro.es_432 so.ha.no_654  lg.sw.lv_422 ro.cy.gd_332
  0x10256404, 0x18000e0d, 0x230511a4, 0x20002b05,   // lg.eu.lt_332 is.ga.un_540  ro.fr.ca_433 vi.sq.un_330
  // [8f40]
  0x2d1720a6, 0x23100509, 0x130412ec, 0x0f2d0908,   // sq.sr.sk_521 fr.lt.ca_444  hu.fi.et_644 pl.sk.lv_443
  0x0b00641a, 0x28082007, 0x52551007, 0x102825ad,   // lg.es.un_760 sq.no.sw_432  lt.rw.ha_432 eu.sw.lt_643
  0x2300101a, 0x10230c08, 0x230e0aee, 0x17000304,   // lt.ca.un_760 sv.ca.lt_443  pt.is.ca_422 nl.sr.un_320
  0x1013230c, 0x085320ec, 0x05230355, 0x170a1fad,   // ca.et.lt_543 sq.ht.no_644  nl.ca.fr_442 cy.pt.sr_643
  // [8f50]
  0x05012308, 0x640701a0, 0x1b136407, 0x1e1b31a0,   // ca.en.fr_443 en.it.lg_322  lg.et.tr_432 az.tr.ms_322
  0x0f1b1a0c, 0x1f1302a0, 0x2300252b, 0x682864af,   // tl.tr.lv_543 da.et.cy_322  eu.ca.un_980 lg.sw.ig_655
  0x1f5305a4, 0x110523ad, 0x6b4a680c, 0x64120f0c,   // fr.ht.cy_433 ca.fr.ro_643  ig.yo.ceb_543 lv.hu.lg_543
  0x28000f22, 0x13283b60, 0x102852a7, 0x52282012,   // lv.sw.un_870 so.sw.et_664  ha.sw.lt_532 sq.sw.ha_654
  // [8f60]
  0x2b014a0b, 0x1123050c, 0x20285508, 0x121304ec,   // yo.en.vi_542 fr.ca.ro_543  rw.sw.sq_443 fi.et.hu_644
  0x3b060514, 0x0a0419a0, 0x01090cee, 0x3b00282a,   // fr.de.so_666 gl.fi.pt_322  sv.pl.en_422 sw.so.un_970
  0x011f3fa0, 0x03321605, 0x52202808, 0x31015505,   // af.cy.en_322 hr.bs.nl_333  sw.sq.ha_443 rw.en.az_333
  0x034a3ba4, 0x0828350c, 0x27002522, 0x3b550107,   // so.yo.nl_433 zu.sw.no_543  eu.gd.un_870 en.rw.so_432
  // [8f70]
  0x533b2a04, 0x1c00352a, 0x1a0e3b08, 0x1b040eaf,   // mt.so.ht_332 zu.id.un_970  so.is.tl_443 is.fi.tr_655
  0x11050355, 0x5220550c, 0x1002080c, 0x11183baf,   // nl.fr.ro_442 rw.sq.ha_543  no.da.lt_543 so.ga.ro_655
  0x550e3504, 0x6800520e, 0x35641ca0, 0x12184a04,   // zu.is.rw_332 ha.ig.un_550  id.lg.zu_322 yo.ga.hu_332
  0x1101130c, 0x550f6404, 0x03133b08, 0x1b3106a9,   // et.en.ro_543 lg.lv.rw_332  so.et.nl_443 de.az.tr_544
  // [8f80]
  0x28096bad, 0x1b310612, 0x13080e08, 0x311b4a11,   // ceb.pl.sw_643 de.az.tr_654  is.no.et_443 yo.tr.az_653
  0x310764ee, 0x051b3bad, 0x52205511, 0x056435a6,   // lg.it.az_422 so.tr.fr_643  rw.sq.ha_653 zu.lg.fr_521
  0x06311baf, 0x5200250e, 0x09003f19, 0x2a6b280c,   // tr.az.de_655 eu.ha.un_550  af.pl.un_750 sw.ceb.mt_543
  0x08020dee, 0x0f121ba7, 0x06256405, 0x214a5204,   // cs.da.no_422 tr.hu.lv_532  lg.eu.de_333 ha.yo.jw_332
  // [8f90]
  0x3f2016a0, 0x31061b0e, 0x25120412, 0x0864130c,   // hr.sq.af_322 tr.de.az_555  fi.hu.eu_654 et.lg.no_543
  0x23641107, 0x03131204, 0x210e1c0c, 0x31002118,   // ro.lg.ca_432 hu.et.nl_332  id.is.jw_543 jw.az.un_740
  0x0e08040c, 0x53321708, 0x25001702, 0x6b002a05,   // fi.no.is_543 sr.bs.ht_443  sr.eu.un_220 mt.ceb.un_330
  0x2a00060c, 0x4a2155a0, 0x202a2904, 0x0f000d12,   // de.mt.un_530 rw.jw.yo_322  sl.mt.sq_332 cs.lv.un_640
  // [8fa0]
  0x2b0501ee, 0x2d0d2b02, 0x0e042aa0, 0x040e4a12,   // en.fr.vi_422 vi.cs.sk_222  mt.fi.is_322 yo.is.fi_654
  0x0c0801a7, 0x07001f0c, 0x3b006b18, 0x0507030b,   // en.no.sv_532 cy.it.un_530  ceb.so.un_740 nl.it.fr_542
  0x0f000707, 0x18001119, 0x351a6b08, 0x28522a0c,   // it.lv.un_420 ro.ga.un_750  ceb.tl.zu_443 mt.ha.sw_543
  0x08526407, 0x2a131ea4, 0x192a1ea0, 0x0b003521,   // lg.ha.no_432 ms.et.mt_433  ms.mt.gl_322 zu.es.un_860
  // [8fb0]
  0x350b6ba9, 0x18252705, 0x211c6409, 0x081207a7,   // ceb.es.zu_544 gd.eu.ga_333  lg.id.jw_444 it.hu.no_532
  0x0e642504, 0x13100408, 0x4a003512, 0x3b2a10a9,   // eu.lg.is_332 fi.lt.et_443  zu.yo.un_640 lt.mt.so_544
  0x0328350c, 0x35000a07, 0x64531008, 0x130e4a04,   // zu.sw.nl_543 pt.zu.un_420  lt.ht.lg_443 yo.is.et_332
  0x0805115a, 0x212a01ac, 0x13110ca4, 0x116435a9,   // ro.fr.no_553 en.mt.jw_632  sv.ro.et_433 zu.lg.ro_544
  // [8fc0]
  0x21131007, 0x13211ea4, 0x3f2808a0, 0x01212da0,   // lt.et.jw_432 ms.jw.et_433  no.sw.af_322 sk.jw.en_322
  0x23001314, 0x13321602, 0x4a002a13, 0x292d25a7,   // et.ca.un_660 hr.bs.et_222  mt.yo.un_650 eu.sk.sl_532
  0x1a001305, 0x325535a4, 0x100f3f05, 0x3b001b19,   // et.tl.un_330 zu.rw.bs_433  af.lv.lt_333 tr.so.un_750
  0x3b2855a4, 0x6b0f13a0, 0x013f28a0, 0x13001021,   // rw.sw.so_433 et.lv.ceb_322  sw.af.en_322 lt.et.un_860
  // [8fd0]
  0x020b0a0d, 0x55003b0d, 0x3104010c, 0x6b5305ec,   // pt.es.da_554 so.rw.un_540  en.fi.az_543 fr.ht.ceb_644
  0x0809040c, 0x101302a7, 0x0e021307, 0x080c1307,   // fi.pl.no_543 da.et.lt_532  et.da.is_432 et.sv.no_432
  0x3b1b3112, 0x016b6804, 0x13100fad, 0x09001f02,   // az.tr.so_654 ig.ceb.en_332  lv.lt.et_643 cy.pl.un_220
  0x0f0313a6, 0x0f0413ee, 0x0c040eee, 0x32173fee,   // et.nl.lv_521 et.fi.lv_422  is.fi.sv_422 af.sr.bs_422
  // [8fe0]
  0x08111013, 0x1e00110c, 0x061204ad, 0x2a0129a6,   // be.ro.uk_665 ro.ms.un_530  fi.hu.de_643 sl.en.mt_521
  0x020804ad, 0x0d091c13, 0x68002d05, 0x11100107,   // fi.no.da_643 mr.hi.ne_665  sk.ig.un_330 en.lt.ro_432
  0x68004a1b, 0x2a00680e, 0x293202a0, 0x046b25a0,   // yo.ig.un_770 ig.mt.un_550  da.bs.sl_322 eu.ceb.fi_322
  0x275231a4, 0x12060407, 0x13040c0d, 0x08020e07,   // az.ha.gd_433 fi.de.hu_432  sv.fi.et_554 is.da.no_432
  // [8ff0]
  0x01531f07, 0x2d0d060e, 0x3b1a040e, 0x10083fa0,   // cy.ht.en_432 de.cs.sk_555  fi.tl.so_555 af.no.lt_322
  0x0e6b1a07, 0x0e100f0c, 0x131011a4, 0x0a1a010c,   // tl.ceb.is_432 lv.lt.is_543  ro.lt.et_433 en.tl.pt_543
  0x13522807, 0x3f230607, 0x3f230505, 0x644a3b07,   // sw.ha.et_432 de.ca.af_432  fr.ca.af_333 so.yo.lg_432
  0x1b21550c, 0x1a1b64a7, 0x211f1c05, 0x0c1329a4,   // rw.jw.tr_543 lg.tr.tl_532  id.cy.jw_333 sl.et.sv_433

  // [9000]
  0x13002702, 0x531b28af, 0x091155a7, 0x21646bad,   // gd.et.un_220 sw.tr.ht_655  rw.ro.pl_532 ceb.lg.jw_643
  0x5255640c, 0x02321704, 0x0e060c07, 0x081110a4,   // lg.rw.ha_543 sr.bs.da_332  sv.de.is_432 be.ro.uk_433
  0x122164a9, 0x55521ea4, 0x12012307, 0x6b230108,   // lg.jw.hu_544 ms.ha.rw_433  ca.en.hu_432 en.ca.ceb_443
  0x120123ee, 0x050123a7, 0x2d0e1904, 0x133f3bee,   // ca.en.hu_422 ca.en.fr_532  gl.is.sk_332 so.af.et_422
  // [9010]
  0x1600020c, 0x1e1c6ea4, 0x1f192302, 0x25132355,   // da.hr.un_530 hmn.id.ms_433  ca.gl.cy_222 ca.et.eu_442
  0x55182704, 0x250711a7, 0x08051e04, 0x232701ad,   // gd.ga.rw_332 ro.it.eu_532  ms.fr.no_332 en.gd.ca_643
  0x64006802, 0x6b012307, 0x092d3b12, 0x1c1e2a08,   // ig.lg.un_220 ca.en.ceb_432  so.sk.pl_654 mt.ms.id_443
  0x0b2d0207, 0x6b1a0212, 0x01036ba4, 0x030113a7,   // da.sk.es_432 da.tl.ceb_654  ceb.nl.en_433 et.en.nl_532
  // [9020]
  0x100c0ead, 0x0b1827ad, 0x191c0aee, 0x25073fa4,   // is.sv.lt_643 gd.ga.es_643  pt.id.gl_422 af.it.eu_433
  0x13000508, 0x1f0729ee, 0x351a6bad, 0x062718a0,   // fr.et.un_430 sl.it.cy_422  ceb.tl.zu_643 ga.gd.de_322
  0x3f060ea0, 0x06020fa0, 0x170f13ee, 0x2d0d1f07,   // is.de.af_322 lv.da.de_322  et.lv.sr_422 cy.cs.sk_432
  0x533564ee, 0x212d1107, 0x042153a4, 0x0c2168a0,   // lg.zu.ht_422 ro.sk.jw_432  ht.jw.fi_433 ig.jw.sv_322
  // [9030]
  0x13006b0e, 0x3f0208a7, 0x170a040b, 0x1b006821,   // ceb.et.un_550 no.da.af_532  ru.mk.sr_542 ig.tr.un_860
  0x04321702, 0x1011080c, 0x2800210c, 0x6b000802,   // sr.bs.fi_222 no.ro.lt_543  jw.sw.un_530 no.ceb.un_220
  0x0e0521a0, 0x2d1e1c08, 0x0e3506a9, 0x130e1855,   // jw.fr.is_322 id.ms.sk_443  de.zu.is_544 ga.is.et_442
  0x17005512, 0x20232ba0, 0x05040709, 0x05002902,   // rw.sr.un_640 vi.ca.sq_322  it.fi.fr_444 sl.fr.un_220
  // [9040]
  0x53130808, 0x06010407, 0x050704a9, 0x062a08ec,   // no.et.ht_443 fi.en.de_432  fi.it.fr_544 no.mt.de_644
  0x21081ca4, 0x1207045a, 0x0d641308, 0x20106804,   // id.no.jw_433 fi.it.hu_553  et.lg.cs_443 ig.lt.sq_332
  0x29004a0d, 0x11202aa4, 0x12070408, 0x135525af,   // yo.sl.un_540 mt.sq.ro_433  fi.it.hu_443 eu.rw.et_655
  0x060c0813, 0x12000721, 0x28206404, 0x64552555,   // no.sv.de_665 it.hu.un_860  lg.sq.sw_332 eu.rw.lg_442
  // [9050]
  0x06071b04, 0x10002512, 0x05641b07, 0x311a6bec,   // tr.it.de_332 eu.lt.un_640  tr.lg.fr_432 ceb.tl.az_644
  0x110805a0, 0x07101302, 0x041207a4, 0x2a063fa4,   // fr.no.ro_322 et.lt.it_222  it.hu.fi_433 af.de.mt_433
  0x6b081a0d, 0x071204ec, 0x12000814, 0x2a000c09,   // tl.no.ceb_554 fi.hu.it_644  no.hu.un_660 sv.mt.un_440
  0x072a08a0, 0x032d0d05, 0x081e25a4, 0x1b0b0fee,   // no.mt.it_322 cs.sk.nl_333  eu.ms.no_433 lv.es.tr_422
  // [9060]
  0x2a040709, 0x32290908, 0x061331a0, 0x1e68200c,   // it.fi.mt_444 pl.sl.bs_443  az.et.de_322 sq.ig.ms_543
  0x3f04130b, 0x3b4a290c, 0x2a070214, 0x0c0e0855,   // et.fi.af_542 sl.yo.so_543  da.it.mt_666 no.is.sv_442
  0x31005211, 0x19005207, 0x082a4a04, 0x1b000f08,   // ha.az.un_630 ha.gl.un_420  yo.mt.no_332 lv.tr.un_430
  0x2a0705ad, 0x0d321602, 0x03080ca4, 0x061b12a4,   // fr.it.mt_643 hr.bs.cs_222  sv.no.nl_433 hu.tr.de_433
  // [9070]
  0x6b066ea0, 0x04080507, 0x2a0412ec, 0x32291712,   // hmn.de.ceb_322 fr.no.fi_432  hu.fi.mt_644 sr.sl.bs_654
  0x2a001b0c, 0x0c0a08ee, 0x023f0807, 0x312508a9,   // tr.mt.un_530 no.pt.sv_422  no.af.da_432 no.eu.az_544
  0x2d00040c, 0x0807110e, 0x0c063fa0, 0x05124a05,   // fi.sk.un_530 ro.bg.uk_555  af.de.sv_322 yo.hu.fr_333
  0x19530a07, 0x280c1a04, 0x27060207, 0x18000102,   // pt.ht.gl_432 tl.sv.sw_332  da.de.gd_432 en.ga.un_220
  // [9080]
  0x0b09060c, 0x1a126ba7, 0x2d0a23ee, 0x0103250c,   // de.pl.es_543 ceb.hu.tl_532  ca.pt.sk_422 eu.nl.en_543
  0x28551aa0, 0x2100550c, 0x1a0f35ad, 0x35006b21,   // tl.rw.sw_322 rw.jw.un_530  zu.lv.tl_643 ceb.zu.un_860
  0x28000805, 0x29003508, 0x02002913, 0x3b2355a0,   // no.sw.un_330 zu.sl.un_430  sl.da.un_650 rw.ca.so_322
  0x10002821, 0x5564280b, 0x351a3bee, 0x6e001c13,   // sw.lt.un_860 sw.lg.rw_542  so.tl.zu_422 id.hmn.un_650
  // [9090]
  0x28122a04, 0x350955ee, 0x292555a9, 0x551c1e11,   // mt.hu.sw_332 rw.pl.zu_422  rw.eu.sl_544 ms.id.rw_653
  0x21003b22, 0x6b556412, 0x3b293204, 0x64002922,   // so.jw.un_870 lg.rw.ceb_654  bs.sl.so_332 sl.lg.un_870
  0x29200d0c, 0x090501a4, 0x17114aa0, 0x351e1c04,   // cs.sq.sl_543 en.fr.pl_433  yo.ro.sr_322 id.ms.zu_332
  0x1f006e0c, 0x2d092a08, 0x07006402, 0x0f1b1307,   // hmn.cy.un_530 mt.pl.sk_443  lg.it.un_220 et.tr.lv_432
  // [90a0]
  0x09200d04, 0x21002329, 0x35122b04, 0x2a002321,   // cs.sq.pl_332 ca.jw.un_960  vi.hu.zu_332 ca.mt.un_860
  0x13082a08, 0x010b18ee, 0x1e1c13af, 0x55282aad,   // mt.no.et_443 ga.es.en_422  et.id.ms_655 mt.sw.rw_643
  0x1328030b, 0x0b3b28af, 0x21001a13, 0x280364ee,   // nl.sw.et_542 sw.so.es_655  tl.jw.un_650 lg.nl.sw_422
  0x1a354a07, 0x03061b07, 0x1a3b4a0b, 0x13080c04,   // yo.zu.tl_432 tr.de.nl_432  yo.so.tl_542 sv.no.et_332
  // [90b0]
  0x23210504, 0x534a52a0, 0x521a1e07, 0x3f002a02,   // fr.jw.ca_332 ha.yo.ht_322  ms.tl.ha_432 mt.af.un_220
  0x312a3b0d, 0x13000118, 0x033f530c, 0x1a4a52a6,   // so.mt.az_554 en.et.un_740  ht.af.nl_543 ha.yo.tl_521
  0x1e1c2d02, 0x52003104, 0x04001329, 0x190b0fee,   // sk.id.ms_222 az.ha.un_320  et.fi.un_960 lv.es.gl_422
  0x09000c07, 0x1e1c5214, 0x27181f05, 0x0c0827a4,   // sv.pl.un_420 ha.id.ms_666  cy.ga.gd_333 gd.no.sv_433
  // [90c0]
  0x13190a13, 0x68523505, 0x4a685208, 0x080210ee,   // pt.gl.et_665 zu.ha.ig_333  ha.ig.yo_443 lt.da.no_422
  0x6e1f53ec, 0x1b1c1e07, 0x2a0a1802, 0x090b3507,   // ht.cy.hmn_644 ms.id.tr_432  ga.pt.mt_222 zu.es.pl_432
  0x1a4a6b02, 0x201b3104, 0x0b283512, 0x10190b07,   // ceb.yo.tl_222 az.tr.sq_332  zu.sw.es_654 es.gl.lt_432
  0x2800552a, 0x04000f04, 0x134a350c, 0x643f0305,   // rw.sw.un_970 lv.fi.un_320  zu.yo.et_543 nl.af.lg_333
  // [90d0]
  0x3f3b4aa0, 0x12643f04, 0x190b28ec, 0x55280ba4,   // yo.so.af_322 af.lg.hu_332  sw.es.gl_644 es.sw.rw_433
  0x28100b02, 0x23002102, 0x6400031b, 0x0a006b04,   // es.lt.sw_222 jw.ca.un_220  nl.lg.un_770 ceb.pt.un_320
  0x04006422, 0x5321070c, 0x3b060ea4, 0x11001607,   // lg.fi.un_870 it.jw.ht_543  is.de.so_433 hr.ro.un_420
  0x64046804, 0x12311b55, 0x31000308, 0x3b060e04,   // ig.fi.lg_332 tr.az.hu_442  nl.az.un_430 is.de.so_332
  // [90e0]
  0x051853a7, 0x53000517, 0x2500531a, 0x1c001a02,   // ht.ga.fr_532 fr.ht.un_730  ht.eu.un_760 tl.id.un_220
  0x21033fa4, 0x320a0304, 0x0a001605, 0x041a6ba0,   // af.nl.jw_433 nl.pt.bs_332  hr.pt.un_330 ceb.tl.fi_322
  0x1c1e0655, 0x68001108, 0x092012ee, 0x073f0308,   // de.ms.id_442 ro.ig.un_430  hu.sq.pl_422 nl.af.it_443
  0x2d180da4, 0x06031f02, 0x032a2013, 0x0e1f640d,   // cs.ga.sk_433 cy.nl.de_222  sq.mt.nl_665 lg.cy.is_554
  // [90f0]
  0x016b6ea0, 0x05041307, 0x01530c09, 0x130f2aad,   // hmn.ceb.en_322 et.fi.fr_432  sv.ht.en_444 mt.lv.et_643
  0x31020807, 0x09001602, 0x23002721, 0x1300070e,   // no.da.az_432 hr.pl.un_220  gd.ca.un_860 it.et.un_550
  0x29032da9, 0x2a002902, 0x063f230c, 0x0e3f06a4,   // sk.nl.sl_544 sl.mt.un_220  ca.af.de_543 de.af.is_433
  0x23080204, 0x01043b04, 0x3b2a2007, 0x0f1e3f0c,   // da.no.ca_332 so.fi.en_332  sq.mt.so_432 af.ms.lv_543
  // [9100]
  0x07100407, 0x180a230c, 0x2a031f07, 0x3b001008,   // fi.lt.it_432 ca.pt.ga_543  cy.nl.mt_432 lt.so.un_430
  0x08041fec, 0x553b100b, 0x05000a21, 0x055255a4,   // cy.fi.no_644 lt.so.rw_542  pt.fr.un_860 rw.ha.fr_433
  0x0f3b550b, 0x190527ec, 0x190a0414, 0x3b5255a7,   // rw.so.lv_542 gd.fr.gl_644  fi.pt.gl_666 rw.ha.so_532
  0x07000a34, 0x100b5507, 0x553b52af, 0x1c132a04,   // mk.bg.un_A80 rw.es.lt_432  ha.so.rw_655 mt.et.id_332
  // [9110]
  0x283f3504, 0x1c0935ad, 0x0c020608, 0x081110af,   // zu.af.sw_332 zu.pl.id_643  de.da.sv_443 be.ro.uk_655
  0x321610ec, 0x29684a08, 0x2b1e0107, 0x28640107,   // lt.hr.bs_644 yo.ig.sl_443  en.ms.vi_432 en.lg.sw_432
  0x1632170b, 0x2a006e09, 0x32100fa0, 0x2a006e19,   // sr.bs.hr_542 hmn.mt.un_440  lv.lt.bs_322 hmn.mt.un_750
  0x0c020da0, 0x2319050c, 0x284a5514, 0x123501ee,   // cs.da.sv_322 fr.gl.ca_543  rw.yo.sw_666 en.zu.hu_422
  // [9120]
  0x281e6ba0, 0x2a0f1007, 0x1a28640c, 0x05083ba0,   // ceb.ms.sw_322 lt.lv.mt_432  lg.sw.tl_543 so.no.fr_322
  0x530405ad, 0x2a001904, 0x07001604, 0x525528a9,   // fr.fi.ht_643 gl.mt.un_320  hr.it.un_320 sw.rw.ha_544
  0x12251b02, 0x352a075a, 0x18522813, 0x1b533255,   // tr.eu.hu_222 it.mt.zu_553  sw.ha.ga_665 bs.ht.tr_442
  0x131c1e07, 0x2a5220a7, 0x01090da0, 0x050307a6,   // ms.id.et_432 sq.ha.mt_532  cs.pl.en_322 it.nl.fr_521
  // [9130]
  0x161364a0, 0x080419a0, 0x2d0f10ec, 0x0c061204,   // lg.et.hr_322 gl.fi.no_322  lt.lv.sk_644 hu.de.sv_332
  0x0d2a2d07, 0x0f0313a0, 0x07046408, 0x291703af,   // sk.mt.cs_432 et.nl.lv_322  lg.fi.it_443 nl.sr.sl_655
  0x19000702, 0x0b0323ee, 0x526401a4, 0x08021fec,   // it.gl.un_220 ca.nl.es_422  en.lg.ha_433 cy.da.no_644
  0x230a6e07, 0x2520040b, 0x31131b02, 0x100504a7,   // hmn.pt.ca_432 fi.sq.eu_542  tr.et.az_222 fi.fr.lt_532
  // [9140]
  0x641e290c, 0x1c1e2712, 0x13001e05, 0x2b000704,   // sl.ms.lg_543 gd.ms.id_654  ms.et.un_330 it.vi.un_320
  0x1e1c0805, 0x20321605, 0x193223a6, 0x1f211ea0,   // no.id.ms_333 hr.bs.sq_333  ca.bs.gl_521 ms.jw.cy_322
  0x281752a0, 0x070a2809, 0x211a1ea7, 0x033f0ea9,   // ha.sr.sw_322 sw.pt.it_444  ms.tl.jw_532 is.af.nl_544
  0x23002d19, 0x1b0a0407, 0x321625ee, 0x06231108,   // sk.ca.un_750 fi.pt.tr_432  eu.hr.bs_422 ro.ca.de_443
  // [9150]
  0x122701a9, 0x103f06ac, 0x2b000e05, 0x646b53a4,   // en.gd.hu_544 de.af.lt_632  is.vi.un_330 ht.ceb.lg_433
  0x0e0c31af, 0x18255204, 0x19002705, 0x070f25ad,   // az.sv.is_655 ha.eu.ga_332  gd.gl.un_330 eu.lv.it_643
  0x13310eb2, 0x11003504, 0x10684a55, 0x55212505,   // is.az.et_732 zu.ro.un_320  yo.ig.lt_442 eu.jw.rw_333
  0x281168a6, 0x020531a0, 0x4a0b2507, 0x25001b08,   // ig.ro.sw_521 az.fr.da_322  eu.es.yo_432 tr.eu.un_430
  // [9160]
  0x08062004, 0x644a5507, 0x310e1b13, 0x0802060c,   // sq.de.no_332 rw.yo.lg_432  tr.is.az_665 de.da.no_543
  0x531b52a6, 0x6800070e, 0x1e250704, 0x032805a7,   // ha.tr.ht_521 it.ig.un_550  it.eu.ms_332 fr.sw.nl_532
  0x0b003b21, 0x091f05a4, 0x0c001b08, 0x12000a20,   // so.es.un_860 fr.cy.pl_433  tr.sv.un_430 pt.hu.un_850
  0x09040555, 0x0a1811a4, 0x3f033bac, 0x1b310cec,   // fr.fi.pl_442 ro.ga.pt_433  so.nl.af_632 sv.az.tr_644
  // [9170]
  0x061332ad, 0x28000e13, 0x23251904, 0x1f006407,   // bs.et.de_643 is.sw.un_650  gl.eu.ca_332 lg.cy.un_420
  0x160f2d02, 0x6828350d, 0x193b1212, 0x1f255204,   // sk.lv.hr_222 zu.sw.ig_554  hu.so.gl_654 ha.eu.cy_332
  0x2a005321, 0x022835ec, 0x64552a55, 0x02080c60,   // ht.mt.un_860 zu.sw.da_644  mt.rw.lg_442 sv.no.da_664
  0x323b0808, 0x19000618, 0x05000908, 0x290e1905,   // no.so.bs_443 de.gl.un_740  pl.fr.un_430 gl.is.sl_333
  // [9180]
  0x13000518, 0x09553512, 0x2a55530c, 0x12003102,   // fr.et.un_740 zu.rw.pl_654  ht.rw.mt_543 az.hu.un_220
  0x6b190a0d, 0x1e281c04, 0x09120607, 0x2a25350c,   // pt.gl.ceb_554 id.sw.ms_332  de.hu.pl_432 zu.eu.mt_543
  0x25001e13, 0x0c021ca0, 0x032511ee, 0x08001e0d,   // ms.eu.un_650 id.da.sv_322  ro.eu.nl_422 ms.no.un_540
  0x553b20ec, 0x0a100408, 0x135564a0, 0x6b132aa0,   // sq.so.rw_644 fi.lt.pt_443  lg.rw.et_322 mt.et.ceb_322
  // [9190]
  0x05070b08, 0x0b311b1d, 0x2003040c, 0x131a29a0,   // es.it.fr_443 tr.az.es_852  fi.nl.sq_543 sl.tl.et_322
  0x212035a4, 0x100a520d, 0x113f6404, 0x030618a9,   // zu.sq.jw_433 ha.pt.lt_554  lg.af.ro_332 ga.de.nl_544
  0x12001f14, 0x312125ad, 0x35062511, 0x042028a0,   // cy.hu.un_660 eu.jw.az_643  eu.de.zu_653 sw.sq.fi_322
  0x1b100e0c, 0x0e1206ec, 0x0b0501a4, 0x10320f04,   // is.lt.tr_543 de.hu.is_644  en.fr.es_433 lv.bs.lt_332
  // [91a0]
  0x18530104, 0x1e1c2014, 0x10201107, 0x2a112014,   // en.ht.ga_332 sq.id.ms_666  ro.sq.lt_432 sq.ro.mt_666
  0x04202511, 0x3f3509a4, 0x011e68a0, 0x0400181a,   // eu.sq.fi_653 pl.zu.af_433  ig.ms.en_322 ga.fi.un_760
  0x312a21a0, 0x271a1811, 0x6b2d0dad, 0x2a292704,   // jw.mt.az_322 ga.tl.gd_653  cs.sk.ceb_643 gd.sl.mt_332
  0x6b1206a0, 0x051e1c04, 0x1b1e3107, 0x1a0301ee,   // de.hu.ceb_322 id.ms.fr_332  az.ms.tr_432 en.nl.tl_422
  // [91b0]
  0x062832a0, 0x23002a08, 0x19000d19, 0x06106ba0,   // bs.sw.de_322 mt.ca.un_430  cs.gl.un_750 ceb.lt.de_322
  0x0d292dee, 0x01000511, 0x02031ca0, 0x03001f20,   // sk.sl.cs_422 fr.en.un_630  id.nl.da_322 cy.nl.un_850
  0x050f55a0, 0x08001029, 0x080b0a02, 0x25110a04,   // rw.lv.fr_322 be.uk.un_960  pt.es.no_222 pt.ro.eu_332
  0x3b285204, 0x0c1b05a0, 0x0b321704, 0x06111704,   // ha.sw.so_332 fr.tr.sv_322  sr.bs.es_332 sr.ro.de_332
  // [91c0]
  0x23001207, 0x355355a9, 0x3f5228ad, 0x55351cad,   // hu.ca.un_420 rw.ht.zu_544  sw.ha.af_643 id.zu.rw_643
  0x68001e04, 0x35532808, 0x061b3f12, 0x13031b0c,   // ms.ig.un_320 sw.ht.zu_443  af.tr.de_654 tr.nl.et_543
  0x64092a0d, 0x680603a4, 0x03556405, 0x3f1f030e,   // mt.pl.lg_554 nl.de.ig_433  lg.rw.nl_333 nl.cy.af_555
  0x1f063fa4, 0x3f6b0304, 0x21001902, 0x0c061302,   // af.de.cy_433 nl.ceb.af_332  gl.jw.un_220 et.de.sv_222
  // [91d0]
  0x190512ac, 0x092835a0, 0x28351c0c, 0x531a2813,   // hu.fr.gl_632 zu.sw.pl_322  id.zu.sw_543 sw.tl.ht_665
  0x1c351e12, 0x2a3f03a9, 0x64002114, 0x3f5501a4,   // ms.zu.id_654 nl.af.mt_544  jw.lg.un_660 en.rw.af_433
  0x033f6b02, 0x18000412, 0x3b00211b, 0x236b0e04,   // ceb.af.nl_222 fi.ga.un_640  jw.so.un_770 is.ceb.ca_332
  0x53356407, 0x0d091c55, 0x23200b13, 0x2a6b1a0c,   // lg.zu.ht_432 mr.hi.ne_442  es.sq.ca_665 tl.ceb.mt_543
  // [91e0]
  0x19641355, 0x011f2aee, 0x204a1a0b, 0x080c1fec,   // et.lg.gl_442 mt.cy.en_422  tl.yo.sq_542 cy.sv.no_644
  0x645255a4, 0x11040708, 0x52001118, 0x216b1a05,   // rw.ha.lg_433 bg.ru.ro_443  ro.ha.un_740 tl.ceb.jw_333
  0x095213a0, 0x0b032ba7, 0x3f321cee, 0x3b285513,   // et.ha.pl_322 vi.nl.es_532  id.bs.af_422 rw.sw.so_665
  0x1c1f1aa4, 0x6b13010c, 0x28351807, 0x050701a6,   // tl.cy.id_433 en.et.ceb_543  ga.zu.sw_432 en.it.fr_521
  // [91f0]
  0x64525555, 0x2a2007ee, 0x1a0401a0, 0x321618a0,   // rw.ha.lg_442 it.sq.mt_422  en.fi.tl_322 ga.hr.bs_322
  0x6b211a13, 0x2d3128a7, 0x6b002108, 0x11000e13,   // tl.jw.ceb_665 sw.az.sk_532  jw.ceb.un_430 is.ro.un_650
  0x6b005505, 0x111a6bad, 0x20285204, 0x1e1c25ee,   // rw.ceb.un_330 ceb.tl.ro_643  ha.sw.sq_332 eu.id.ms_422
  0x273f0304, 0x53001f09, 0x0410530b, 0x4a6421a0,   // nl.af.gd_332 cy.ht.un_440  ht.lt.fi_542 jw.lg.yo_322
  // [9200]
  0x01093507, 0x01070513, 0x093b285a, 0x27001321,   // zu.pl.en_432 fr.it.en_665  sw.so.pl_553 et.gd.un_860
  0x1f002814, 0x2718130d, 0x0000292d, 0x0300640d,   // sw.cy.un_660 et.ga.gd_554  sl.un.un_A00 lg.nl.un_540
  0x102531a0, 0x21063f12, 0x1300121a, 0x1b230aec,   // az.eu.lt_322 af.de.jw_654  hu.et.un_760 pt.ca.tr_644
  0x025308ee, 0x020a0cee, 0x29311ba7, 0x043b03ee,   // no.ht.da_422 sv.pt.da_422  tr.az.sl_532 nl.so.fi_422
  // [9210]
  0x2d120e55, 0x1f190704, 0x05013b02, 0x101117a0,   // is.hu.sk_442 it.gl.cy_332  so.en.fr_222 sr.ro.lt_322
  0x0c001b19, 0x201b1008, 0x2b001f09, 0x135520a0,   // tr.sv.un_750 lt.tr.sq_443  cy.vi.un_440 sq.rw.et_322
  0x1b10200b, 0x203510a9, 0x102d20ee, 0x311b0eac,   // sq.lt.tr_542 lt.zu.sq_544  sq.sk.lt_422 is.tr.az_632
  0x13052008, 0x2d1b20ee, 0x5255350d, 0x130c08a0,   // sq.fr.et_443 sq.tr.sk_422  zu.rw.ha_554 no.sv.et_322
  // [9220]
  0x19116407, 0x05230b02, 0x6b6428a4, 0x2b003521,   // lg.ro.gl_432 es.ca.fr_222  sw.lg.ceb_433 zu.vi.un_860
  0x09283507, 0x05252004, 0x116b35a9, 0x201013a9,   // zu.sw.pl_432 sq.eu.fr_332  zu.ceb.ro_544 et.lt.sq_544
  0x12642811, 0x202a07a7, 0x0e64350e, 0x68352804,   // sw.lg.hu_653 it.mt.sq_532  zu.lg.is_555 sw.zu.ig_332
  0x11100412, 0x551321ad, 0x520e09a7, 0x35062aa0,   // ru.be.ro_654 jw.et.rw_643  pl.is.ha_532 mt.de.zu_322
  // [9230]
  0x35006814, 0x32100ea7, 0x281e35ad, 0x55680aa4,   // ig.zu.un_660 is.lt.bs_532  zu.ms.sw_643 pt.ig.rw_433
  0x08021eee, 0x05002112, 0x0e1025a6, 0x4a0e130d,   // ms.da.no_422 jw.fr.un_640  eu.lt.is_521 et.is.yo_554
  0x32000e08, 0x230b25a4, 0x18001604, 0x191355a0,   // is.bs.un_430 eu.es.ca_433  hr.ga.un_320 rw.et.gl_322
  0x0d4a1902, 0x16002504, 0x2d1e1c02, 0x1c0f01ee,   // gl.yo.cs_222 eu.hr.un_320  id.ms.sk_222 en.lv.id_422
  // [9240]
  0x35281aa7, 0x3b275508, 0x1f1c21a0, 0x0906120d,   // tl.sw.zu_532 rw.gd.so_443  jw.id.cy_322 hu.de.pl_554
  0x1800170e, 0x03201211, 0x28000c07, 0x64001021,   // sr.ga.un_550 hu.sq.nl_653  sv.sw.un_420 lt.lg.un_860
  0x0600530c, 0x2a071ca9, 0x080c02ec, 0x100e64a4,   // ht.de.un_530 id.it.mt_544  da.sv.no_644 lg.is.lt_433
  0x2d292008, 0x05011e07, 0x2a1168a4, 0x1b120405,   // sq.sl.sk_443 ms.en.fr_432  ig.ro.mt_433 fi.hu.tr_333
  // [9250]
  0x13110707, 0x06040305, 0x2a103b04, 0x0d11230e,   // it.ro.et_432 nl.fi.de_333  so.lt.mt_332 ca.ro.cs_555
  0x2d0d23ee, 0x0e2a04ad, 0x2a1264ad, 0x101225ad,   // ca.cs.sk_422 fi.mt.is_643  lg.hu.mt_643 eu.hu.lt_643
  0x0e001022, 0x0b000a29, 0x52136e04, 0x08066b02,   // lt.is.un_870 pt.es.un_960  hmn.et.ha_332 ceb.de.no_222
  0x1f006e19, 0x196e1a12, 0x061252a4, 0x13072a5a,   // hmn.cy.un_750 tl.hmn.gl_654  ha.hu.de_433 mt.it.et_553
  // [9260]
  0x6e001f22, 0x1a0b6ea7, 0x1108040c, 0x230c1fad,   // cy.hmn.un_870 hmn.es.tl_532  ru.uk.ro_543 cy.sv.ca_643
  0x310e1a07, 0x3500201a, 0x27315211, 0x1a0e270c,   // tl.is.az_432 sq.zu.un_760  ha.az.gd_653 gd.is.tl_543
  0x640a3507, 0x2d0d29a6, 0x126b3f04, 0x1f04050c,   // zu.pt.lg_432 sl.cs.sk_521  af.ceb.hu_332 fr.fi.cy_543
  0x640510a0, 0x2a3b3155, 0x6e00050d, 0x0d000a12,   // lt.fr.lg_322 az.so.mt_442  fr.hmn.un_540 pt.cs.un_640
  // [9270]
  0x21356404, 0x313b1ea0, 0x550804a6, 0x1000130c,   // lg.zu.jw_332 ms.so.az_322  fi.no.rw_521 et.lt.un_530
  0x11004a02, 0x103127ad, 0x35080c0d, 0x2b2a25a0,   // yo.ro.un_220 gd.az.lt_643  sv.no.zu_554 eu.mt.vi_322
  0x2d0d0ba0, 0x2a072013, 0x6b311b05, 0x55642111,   // es.cs.sk_322 sq.it.mt_665  tr.az.ceb_333 jw.lg.rw_653
  0x1100170e, 0x4a5325ad, 0x53552811, 0x0d0f2807,   // sr.ro.un_550 eu.ht.yo_643  sw.rw.ht_653 sw.lv.cs_432
  // [9280]
  0x526428ad, 0x0e6b64a0, 0x55001f12, 0x32000808,   // sw.lg.ha_643 lg.ceb.is_322  cy.rw.un_640 no.bs.un_430
  0x1a352804, 0x52280ea6, 0x184a0da4, 0x213f06ee,   // sw.zu.tl_332 is.sw.ha_521  cs.yo.ga_433 de.af.jw_422
  0x1b1013a6, 0x07110a05, 0x215535a0, 0x641a52ad,   // et.lt.tr_521 mk.ro.bg_333  zu.rw.jw_322 ha.tl.lg_643
  0x350c0ea0, 0x1a001b20, 0x550c64ec, 0x35091a07,   // is.sv.zu_322 tr.tl.un_850  lg.sv.rw_644 tl.pl.zu_432
  // [9290]
  0x04002013, 0x3b520f08, 0x530f05a0, 0x64041055,   // sq.fi.un_650 lv.ha.so_443  fr.lv.ht_322 lt.fi.lg_442
  0x35531a08, 0x556428a9, 0x0418130d, 0x1e21280c,   // tl.ht.zu_443 sw.lg.rw_544  et.ga.fi_554 sw.jw.ms_543
  0x0812185a, 0x0528010c, 0x281a55a4, 0x181125ad,   // ga.hu.no_553 en.sw.fr_543  rw.tl.sw_433 eu.ro.ga_643
  0x120f3b0c, 0x11090709, 0x1e1c030c, 0x522a3bec,   // so.lv.hu_543 it.pl.ro_444  nl.id.ms_543 so.mt.ha_644
  // [92a0]
  0x09311e04, 0x201b29ec, 0x281e68a4, 0x2009520c,   // ms.az.pl_332 sl.tr.sq_644  ig.ms.sw_433 ha.pl.sq_543
  0x29001c13, 0x130a0807, 0x1b0c0208, 0x02123f0c,   // id.sl.un_650 no.pt.et_432  da.sv.tr_443 af.hu.da_543
  0x181f23a4, 0x0e0f2507, 0x0f2512ad, 0x1e1c0305,   // ca.cy.ga_433 eu.lv.is_432  hu.eu.lv_643 nl.id.ms_333
  0x100e3ba4, 0x0e00270d, 0x3f2527a0, 0x133f2904,   // so.is.lt_433 gd.is.un_540  gd.eu.af_322 sl.af.et_332
  // [92b0]
  0x131e0ea0, 0x07045208, 0x12055205, 0x0a2a070e,   // is.ms.et_322 ha.fi.it_443  ha.fr.hu_333 it.mt.pt_555
  0x100504a0, 0x10040f08, 0x111e21a9, 0x211c52ec,   // fi.fr.lt_322 lv.fi.lt_443  jw.ms.ro_544 ha.id.jw_644
  0x03136e05, 0x3b202aa7, 0x32055212, 0x11081708,   // hmn.et.nl_333 mt.sq.so_532  ha.fr.bs_654 sr.uk.ro_443
  0x3b6b3fa0, 0x253f100c, 0x0a0b010c, 0x12290e12,   // af.ceb.so_322 lt.af.eu_543  en.es.pt_543 is.sl.hu_654
  // [92c0]
  0x230f0aa4, 0x12132a08, 0x20115504, 0x251004a0,   // pt.lv.ca_433 mt.et.hu_443  rw.ro.sq_332 fi.lt.eu_322
  0x0a2b010c, 0x05232907, 0x1f00130d, 0x3b003f09,   // en.vi.pt_543 sl.ca.fr_432  et.cy.un_540 af.so.un_440
  0x1e1b12ee, 0x0f0428ee, 0x3b046ba9, 0x6e00010d,   // hu.tr.ms_422 sw.fi.lv_422  ceb.fi.so_544 en.hmn.un_540
  0x530c1ba4, 0x20001819, 0x16292d02, 0x0b0a03a4,   // tr.sv.ht_433 ga.sq.un_750  sk.sl.hr_222 nl.pt.es_433
  // [92d0]
  0x060b270c, 0x016b31a0, 0x0b3b5512, 0x6b1a550d,   // gd.es.de_543 az.ceb.en_322  rw.so.es_654 rw.tl.ceb_554
  0x05190b13, 0x321c2107, 0x2d0d23a0, 0x05002904,   // es.gl.fr_665 jw.id.bs_432  ca.cs.sk_322 sl.fr.un_320
  0x1f6818a0, 0x216b1a5a, 0x091f5304, 0x1e1c10ec,   // ga.ig.cy_322 tl.ceb.jw_553  ht.cy.pl_332 lt.id.ms_644
  0x2d35030c, 0x1e1c11ec, 0x551a530d, 0x080c3ba9,   // nl.zu.sk_543 ro.id.ms_644  ht.tl.rw_554 so.sv.no_544
  // [92e0]
  0x0711100c, 0x21521aa4, 0x0511180c, 0x04031ca0,   // lt.ro.it_543 tl.ha.jw_433  ga.ro.fr_543 id.nl.fi_322
  0x1709520c, 0x281053a4, 0x353b28a7, 0x0710230c,   // ha.pl.sr_543 ht.lt.sw_433  sw.so.zu_532 ca.lt.it_543
  0x0d280307, 0x1e130409, 0x031806a4, 0x0800290d,   // nl.sw.cs_432 fi.et.ms_444  de.ga.nl_433 sl.no.un_540
  0x2310110c, 0x5212070c, 0x6b1f0107, 0x0f0a100d,   // ro.lt.ca_543 it.hu.ha_543  en.cy.ceb_432 lt.pt.lv_554
  // [92f0]
  0x532a0a12, 0x0f1a130d, 0x3f351307, 0x2d000a09,   // pt.mt.ht_654 et.tl.lv_554  et.zu.af_432 pt.sk.un_440
  0x2b0410ee, 0x1b0413ee, 0x1e1c130c, 0x11001009,   // lt.fi.vi_422 et.fi.tr_422  et.id.ms_543 lt.ro.un_440
  0x03092507, 0x04101c07, 0x11050404, 0x070a2355,   // eu.pl.nl_432 id.lt.fi_432  fi.fr.ro_332 ca.pt.it_442
  0x3f00640b, 0x08115308, 0x536409ad, 0x1768130c,   // lg.af.un_520 ht.ro.no_443  pl.lg.ht_643 et.ig.sr_543
  // [9300]
  0x6b0913a4, 0x04133508, 0x1a64280b, 0x31321708,   // et.pl.ceb_433 zu.et.fi_443  sw.lg.tl_542 sr.bs.az_443
  0x0b6b3ba0, 0x3b001807, 0x55003b18, 0x050704a0,   // so.ceb.es_322 ga.so.un_420  so.rw.un_740 fi.it.fr_322
  0x1e002004, 0x1e002502, 0x32170fec, 0x0400010c,   // sq.ms.un_320 eu.ms.un_220  lv.sr.bs_644 en.fi.un_530
  0x6e016ba7, 0x0a524aee, 0x0d00041a, 0x0d2928a6,   // ceb.en.hmn_532 yo.ha.pt_422  fi.cs.un_760 sw.sl.cs_521
  // [9310]
  0x07551004, 0x012d09a0, 0x2a003502, 0x2b003508,   // lt.rw.it_332 pl.sk.en_322  zu.mt.un_220 zu.vi.un_430
  0x1304060c, 0x2b170ba0, 0x08022014, 0x182b20a4,   // de.fi.et_543 es.sr.vi_322  sq.da.no_666 sq.vi.ga_433
  0x2d00190e, 0x04100802, 0x081f0c0c, 0x2d0d28a0,   // gl.sk.un_550 uk.be.ru_222  sv.cy.no_543 sw.cs.sk_322
  0x04000908, 0x012d0d55, 0x20182707, 0x27002018,   // pl.fi.un_430 cs.sk.en_442  gd.ga.sq_432 sq.gd.un_740
  // [9320]
  0x32171ca0, 0x29320ca0, 0x19122d55, 0x2d000a13,   // id.sr.bs_322 sv.bs.sl_322  sk.hu.gl_442 pt.sk.un_650
  0x0e2a200c, 0x531c0e04, 0x1f11070b, 0x680d04ad,   // sq.mt.is_543 is.id.ht_332  it.ro.cy_542 fi.cs.ig_643
  0x53050e05, 0x13280e0c, 0x0a3f200b, 0x201b3b07,   // is.fr.ht_333 is.sw.et_543  sq.af.pt_542 so.tr.sq_432
  0x23002b2b, 0x072a1309, 0x2b1c1e12, 0x2a550e0c,   // vi.ca.un_980 et.mt.it_444  ms.id.vi_654 is.rw.mt_543
  // [9330]
  0x230a0b5a, 0x230a0108, 0x13121f12, 0x0d091ca6,   // es.pt.ca_553 en.pt.ca_443  cy.hu.et_654 mr.hi.ne_521
  0x3f1e01a7, 0x311e2dad, 0x310e2da4, 0x192d1205,   // en.ms.af_532 sk.ms.az_643  sk.is.az_433 hu.sk.gl_333
  0x2d1b53ad, 0x1c2120af, 0x180e12b4, 0x6b6807a0,   // ht.tr.sk_643 sq.jw.id_655  hu.is.ga_754 it.ig.ceb_322
  0x0e071c0c, 0x032b1cee, 0x11132813, 0x1f0e2512,   // id.it.is_543 id.vi.nl_422  sw.et.ro_665 eu.is.cy_654
  // [9340]
  0x29072da0, 0x13111aee, 0x0f213ba0, 0x11003102,   // sk.it.sl_322 tl.ro.et_422  so.jw.lv_322 az.ro.un_220
  0x53000719, 0x6e25040d, 0x06021f07, 0x042528a9,   // it.ht.un_750 fi.eu.hmn_554  cy.da.de_432 sw.eu.fi_544
  0x25002823, 0x25282308, 0x25126404, 0x4a28680c,   // sw.eu.un_880 ca.sw.eu_443  lg.hu.eu_332 ig.sw.yo_543
  0x282025af, 0x6e280407, 0x28251e0c, 0x17071002,   // eu.sq.sw_655 fi.sw.hmn_432  ms.eu.sw_543 be.bg.sr_222
  // [9350]
  0x1b125204, 0x202825ad, 0x2104250c, 0x521e4aa7,   // ha.hu.tr_332 eu.sw.sq_643  eu.fi.jw_543 yo.ms.ha_532
  0x080a02a0, 0x1f006e09, 0x133116ee, 0x28002a0b,   // da.pt.no_322 hmn.cy.un_440  hr.az.et_422 mt.sw.un_520
  0x09213f07, 0x011f23a7, 0x130802ee, 0x19180bee,   // af.jw.pl_432 ca.cy.en_532  da.no.et_422 es.ga.gl_422
  0x20523fa4, 0x20216b60, 0x683520ee, 0x5528200c,   // af.ha.sq_433 ceb.jw.sq_664  sq.zu.ig_422 sq.sw.rw_543
  // [9360]
  0x09103fa4, 0x0b0603af, 0x2809040c, 0x20000404,   // af.lt.pl_433 nl.de.es_655  fi.pl.sw_543 fi.sq.un_320
  0x100904ac, 0x1b1120a6, 0x28521e0c, 0x553f20ec,   // fi.pl.lt_632 sq.ro.tr_521  ms.ha.sw_543 sq.af.rw_644
  0x1e2025a9, 0x09022d0c, 0x1b523507, 0x201852a0,   // eu.sq.ms_544 sk.da.pl_543  zu.ha.tr_432 ha.ga.sq_322
  0x07092d0b, 0x2d070ba4, 0x0e3b52a0, 0x042a3555,   // sk.pl.it_542 es.it.sk_433  ha.so.is_322 zu.mt.fi_442
  // [9370]
  0x3f1129a0, 0x1a080202, 0x1c1a1ea9, 0x2b0128a0,   // sl.ro.af_322 da.no.tl_222  ms.tl.id_544 sw.en.vi_322
  0x213b1e08, 0x2a0e110c, 0x03060912, 0x173201a6,   // ms.so.jw_443 ro.is.mt_543  pl.de.nl_654 en.bs.sr_521
  0x521a6b5a, 0x083f27a0, 0x1c3568ee, 0x52280960,   // ceb.tl.ha_553 gd.af.no_322  ig.zu.id_422 pl.sw.ha_664
  0x2d0a050c, 0x0b072304, 0x103f0412, 0x09110f14,   // fr.pt.sk_543 ca.it.es_332  fi.af.lt_654 lv.ro.pl_666
  // [9380]
  0x1a2d0d04, 0x0400062b, 0x1c521e0b, 0x03000929,   // cs.sk.tl_332 de.fi.un_980  ms.ha.id_542 pl.nl.un_960
  0x18120e08, 0x2d042a0c, 0x531a2107, 0x010608a0,   // is.hu.ga_443 mt.fi.sk_543  jw.tl.ht_432 no.de.en_322
  0x25071807, 0x18311b0d, 0x2d0d1105, 0x100e120c,   // ga.it.eu_432 tr.az.ga_554  ro.cs.sk_333 hu.is.lt_543
  0x1e210107, 0x122a2008, 0x04072d07, 0x12080c0d,   // en.jw.ms_432 sq.mt.hu_443  sk.it.fi_432 sv.no.hu_554
  // [9390]
  0x2a6425a9, 0x2a0601ee, 0x180a0ca9, 0x116820a9,   // eu.lg.mt_544 en.de.mt_422  sv.pt.ga_544 sq.ig.ro_544
  0x3f0902a0, 0x06006408, 0x3f120c07, 0x1a080205,   // da.pl.af_322 lg.de.un_430  sv.hu.af_432 da.no.tl_333
  0x111e1c04, 0x53351204, 0x0c6408a0, 0x6b1a0ba4,   // id.ms.ro_332 hu.zu.ht_332  no.lg.sv_322 es.tl.ceb_433
  0x050a3f08, 0x1a311ead, 0x12001e13, 0x12071108,   // af.pt.fr_443 ms.az.tl_643  ms.hu.un_650 ro.it.hu_443
  // [93a0]
  0x281a180c, 0x120a2d0d, 0x1b0e0c0c, 0x252164a6,   // ga.tl.sw_543 sk.pt.hu_554  sv.is.tr_543 lg.jw.eu_521
  0x0b071107, 0x64522104, 0x551a64a4, 0x172d20ee,   // ro.it.es_432 jw.ha.lg_332  lg.tl.rw_433 sq.sk.sr_422
  0x100a040d, 0x13110a02, 0x64001008, 0x12232d0b,   // ru.mk.be_554 pt.ro.et_222  lt.lg.un_430 sk.ca.hu_542
  0x211b520c, 0x556404a4, 0x0d001604, 0x1600170c,   // ha.tr.jw_543 fi.lg.rw_433  hr.cs.un_320 sr.hr.un_530
  // [93b0]
  0x035528ec, 0x110625a4, 0x1335520b, 0x1c6b2b0b,   // sw.rw.nl_644 eu.de.ro_433  ha.zu.et_542 vi.ceb.id_542
  0x283513a0, 0x034a1f07, 0x1c281ea9, 0x531a2b02,   // et.zu.sw_322 cy.yo.nl_432  ms.sw.id_544 vi.tl.ht_222
  0x112d01a4, 0x1e1c3109, 0x1b00320c, 0x0a2319a0,   // en.sk.ro_433 az.id.ms_444  bs.tr.un_530 gl.ca.pt_322
  0x2d010209, 0x2d0d0e0c, 0x6b001c13, 0x3b001b04,   // da.en.sk_444 is.cs.sk_543  id.ceb.un_650 tr.so.un_320
  // [93c0]
  0x6b1a0107, 0x01250307, 0x6b0604a0, 0x10040e08,   // en.tl.ceb_432 nl.eu.en_432  fi.de.ceb_322 is.fi.lt_443
  0x29042d07, 0x030805a0, 0x041006a4, 0x1c3f030c,   // sk.fi.sl_432 fr.no.nl_322  de.lt.fi_433 nl.af.id_543
  0x08031ca0, 0x21002010, 0x52216b13, 0x101a040c,   // id.nl.no_322 sq.jw.un_620  ceb.jw.ha_665 fi.tl.lt_543
  0x05536b0c, 0x05002b07, 0x13211ca6, 0x1c553505,   // ceb.ht.fr_543 vi.fr.un_420  id.jw.et_521 zu.rw.id_333
  // [93d0]
  0x02004a04, 0x1b0e0307, 0x4a64040c, 0x2b211c08,   // yo.da.un_320 nl.is.tr_432  fi.lg.yo_543 id.jw.vi_443
  0x21041c11, 0x3f001705, 0x2d0d20af, 0x09133bee,   // id.fi.jw_653 sr.af.un_330  sq.cs.sk_655 so.et.pl_422
  0x1f042014, 0x1c5255a6, 0x1a0e3bee, 0x10112502,   // sq.fi.cy_666 rw.ha.id_521  so.is.tl_422 eu.ro.lt_222
  0x073b1c07, 0x316e3b12, 0x2b3b120c, 0x10002a21,   // id.so.it_432 so.hmn.az_654  hu.so.vi_543 mt.lt.un_860
  // [93e0]
  0x11074aa0, 0x07112304, 0x0100080d, 0x1a000808,   // yo.it.ro_322 ca.ro.it_332  no.en.un_540 no.tl.un_430
  0x6b1c1aa4, 0x28270ba4, 0x2b070e08, 0x0e3b0da0,   // tl.id.ceb_433 es.gd.sw_433  is.it.vi_443 cs.so.is_322
  0x13000e0b, 0x2864100c, 0x0600640b, 0x68005214,   // is.et.un_520 lt.lg.sw_543  lg.de.un_520 ha.ig.un_660
  0x1c211b04, 0x35281b0c, 0x2d0d100c, 0x0e6b1aa7,   // tr.jw.id_332 tr.sw.zu_543  lt.cs.sk_543 tl.ceb.is_532
  // [93f0]
  0x4a000913, 0x3f113507, 0x27282504, 0x2b040804,   // pl.yo.un_650 zu.ro.af_432  eu.sw.gd_332 no.fi.vi_332
  0x11133b07, 0x13003b0d, 0x215535ee, 0x09000102,   // so.et.ro_432 so.et.un_540  zu.rw.jw_422 en.pl.un_220
  0x0413110c, 0x01001102, 0x21090107, 0x01180504,   // ro.et.fi_543 ro.en.un_220  en.pl.jw_432 fr.ga.en_332
  0x53280104, 0x52001f04, 0x53132a04, 0x2a6b010c,   // en.sw.ht_332 cy.ha.un_320  mt.et.ht_332 en.ceb.mt_543

  // [9400]
  0x530d3fee, 0x07005313, 0x0f6b01ad, 0x090d010c,   // af.cs.ht_422 ht.it.un_650  en.ceb.lv_643 en.cs.pl_543
  0x10000202, 0x311b0807, 0x686b350c, 0x28000502,   // da.lt.un_220 no.tr.az_432  zu.ceb.ig_543 fr.sw.un_220
  0x0c2a01a4, 0x1e2721a0, 0x191729a9, 0x122d0a04,   // en.mt.sv_433 jw.gd.ms_322  sl.sr.gl_544 pt.sk.hu_332
  0x3b00352a, 0x1e3b0d12, 0x64033b0d, 0x25000f0d,   // zu.so.un_970 cs.so.ms_654  so.nl.lg_554 lv.eu.un_540
  // [9410]
  0x1103130c, 0x28685207, 0x190b0c09, 0x641e2505,   // et.nl.ro_543 ha.ig.sw_432  sv.es.gl_444 eu.ms.lg_333
  0x252835a6, 0x171b250b, 0x080e1f05, 0x2b002807,   // zu.sw.eu_521 eu.tr.sr_542  cy.is.no_333 sw.vi.un_420
  0x640a3b11, 0x6b2127a0, 0x27132dad, 0x0b0c0255,   // so.pt.lg_653 gd.jw.ceb_322  sk.et.gd_643 da.sv.es_442
  0x2b000c07, 0x0e6b2714, 0x29003519, 0x1c111e0c,   // sv.vi.un_420 gd.ceb.is_666  zu.sl.un_750 ms.ro.id_543
  // [9420]
  0x10090fac, 0x12002721, 0x3f120207, 0x20322a02,   // lv.pl.lt_632 gd.hu.un_860  da.hu.af_432 mt.bs.sq_222
  0x02066bee, 0x4a1a64a0, 0x283525a9, 0x1a6b3b12,   // ceb.de.da_422 lg.tl.yo_322  eu.zu.sw_544 so.ceb.tl_654
  0x27555209, 0x0c0a04ec, 0x11000c1b, 0x10070413,   // ha.rw.gd_444 fi.pt.sv_644  sv.ro.un_770 ru.bg.be_665
  0x041b3f08, 0x523b550c, 0x293b0e04, 0x0f310c02,   // af.tr.fi_443 rw.so.ha_543  is.so.sl_332 sv.az.lv_222
  // [9430]
  0x10130f04, 0x213b64a7, 0x04271813, 0x020611ee,   // lv.et.lt_332 lg.so.jw_532  ga.gd.fi_665 ro.de.da_422
  0x13030c05, 0x2a1e5205, 0x101827ad, 0x2705010c,   // sv.nl.et_333 ha.ms.mt_333  gd.ga.lt_643 en.fr.gd_543
  0x04001822, 0x1c2b640c, 0x1f091855, 0x08006b02,   // ga.fi.un_870 lg.vi.id_543  ga.pl.cy_442 ceb.no.un_220
  0x16291704, 0x1c0309a9, 0x1f5311a4, 0x27006e0d,   // sr.sl.hr_332 pl.nl.id_544  ro.ht.cy_433 hmn.gd.un_540
  // [9440]
  0x18000d0c, 0x271107a4, 0x0b00520d, 0x11002a04,   // cs.ga.un_530 it.ro.gd_433  ha.es.un_540 mt.ro.un_320
  0x0f00250d, 0x1c214aa0, 0x081e1c04, 0x55005212,   // eu.lv.un_540 yo.jw.id_322  id.ms.no_332 ha.rw.un_640
  0x1f6b35ee, 0x041801a4, 0x015255a0, 0x171a5255,   // zu.ceb.cy_422 en.ga.fi_433  rw.ha.en_322 ha.tl.sr_442
  0x281f200c, 0x0d080255, 0x29521207, 0x27001f09,   // sq.cy.sw_543 da.no.cs_442  hu.ha.sl_432 cy.gd.un_440
  // [9450]
  0x1a521e0b, 0x0a28350c, 0x02080c08, 0x17232102,   // ms.ha.tl_542 zu.sw.pt_543  sv.no.da_443 jw.ca.sr_222
  0x062b1802, 0x1a0c6ba4, 0x09004a08, 0x2a6455a0,   // ga.vi.de_222 ceb.sv.tl_433  yo.pl.un_430 rw.lg.mt_322
  0x2a011fee, 0x2b005504, 0x35006822, 0x28181fa9,   // cy.en.mt_422 rw.vi.un_320  ig.zu.un_870 cy.ga.sw_544
  0x051f18a4, 0x0d001e07, 0x065301a4, 0x0603530c,   // ga.cy.fr_433 ms.cs.un_420  en.ht.de_433 ht.nl.de_543
  // [9460]
  0x2025050d, 0x1f1b3fa4, 0x0600280e, 0x0306270c,   // fr.eu.sq_554 af.tr.cy_433  sw.de.un_550 gd.de.nl_543
  0x195306a4, 0x0f006819, 0x06003b19, 0x2506040b,   // de.ht.gl_433 ig.lv.un_750  so.de.un_750 fi.de.eu_542
  0x4a001a0d, 0x6805060c, 0x3f023ba4, 0x0603285a,   // tl.yo.un_540 de.fr.ig_543  so.da.af_433 sw.nl.de_553
  0x0c023bee, 0x202321ec, 0x6b000e04, 0x181327ee,   // so.da.sv_422 jw.ca.sq_644  is.ceb.un_320 gd.et.ga_422
  // [9470]
  0x02131a08, 0x19080507, 0x2000051f, 0x2b093f07,   // tl.et.da_443 fr.no.gl_432  fr.sq.un_840 af.pl.vi_432
  0x550964a0, 0x131923ad, 0x09041104, 0x25321704,   // lg.pl.rw_322 ca.gl.et_643  ro.fi.pl_332 sr.bs.eu_332
  0x080e2504, 0x536428a0, 0x08101711, 0x02002718,   // eu.is.no_332 sw.lg.ht_322  sr.be.uk_653 gd.da.un_740
  0x183b1304, 0x10200fee, 0x31002002, 0x0e2a1207,   // et.so.ga_332 lv.sq.lt_422  sq.az.un_220 hu.mt.is_432
  // [9480]
  0x18013fee, 0x010809a7, 0x211205ee, 0x110f04ee,   // af.en.ga_422 pl.no.en_532  fr.hu.jw_422 fi.lv.ro_422
  0x13041155, 0x092504a4, 0x11286404, 0x351b31ee,   // ro.fi.et_442 fi.eu.pl_433  lg.sw.ro_332 az.tr.zu_422
  0x0406110c, 0x060435a0, 0x640428a4, 0x64006b08,   // ro.de.fi_543 zu.fi.de_322  sw.fi.lg_433 ceb.lg.un_430
  0x3b5328ee, 0x1a1c6402, 0x05292aee, 0x04173502,   // sw.ht.so_422 lg.id.tl_222  mt.sl.fr_422 zu.sr.fi_222
  // [9490]
  0x25136bec, 0x04100eec, 0x1e002021, 0x291107ee,   // ceb.et.eu_644 is.lt.fi_644  sq.ms.un_860 it.ro.sl_422
  0x0f002a29, 0x2a0752ec, 0x045203a0, 0x21352508,   // mt.lv.un_960 ha.it.mt_644  nl.ha.fi_322 eu.zu.jw_443
  0x2d121902, 0x11521008, 0x35040804, 0x03086407,   // gl.hu.sk_222 lt.ha.ro_443  no.fi.zu_332 lg.no.nl_432
  0x03001b21, 0x0d004a04, 0x1c041aa0, 0x111735a7,   // tr.nl.un_860 yo.cs.un_320  tl.fi.id_322 zu.sr.ro_532
  // [94a0]
  0x283b1a07, 0x6b0425a0, 0x1a1604ee, 0x16045204,   // tl.so.sw_432 eu.fi.ceb_322  fi.hr.tl_422 ha.fi.hr_332
  0x0d35040e, 0x0e001004, 0x02041308, 0x03002d02,   // fi.zu.cs_555 lt.is.un_320  et.fi.da_443 sk.nl.un_220
  0x2b2d3fa0, 0x64000a02, 0x0c00110c, 0x040f2aec,   // af.sk.vi_322 pt.lg.un_220  ro.sv.un_530 mt.lv.fi_644
  0x1310115a, 0x0612040c, 0x080223ac, 0x020b6eee,   // ro.lt.et_553 fi.hu.de_543  ca.da.no_632 hmn.es.da_422
  // [94b0]
  0x190a13ee, 0x08013fa7, 0x1704100b, 0x082913a4,   // et.pt.gl_422 af.en.no_532  be.ru.sr_542 et.sl.no_433
  0x5313350c, 0x18052702, 0x352513a4, 0x29096804,   // zu.et.ht_543 gd.fr.ga_222  et.eu.zu_433 ig.pl.sl_332
  0x01100807, 0x3b136413, 0x29323b04, 0x06350c08,   // no.lt.en_432 lg.et.so_665  so.bs.sl_332 sv.zu.de_443
  0x230d1213, 0x13102a02, 0x13030109, 0x040a08ad,   // hu.cs.ca_665 mt.lt.et_222  en.nl.et_444 uk.mk.ru_643
  // [94c0]
  0x2064130c, 0x03553555, 0x040a19ee, 0x093125a9,   // et.lg.sq_543 zu.rw.nl_442  gl.pt.fi_422 eu.az.pl_544
  0x2a4a28ad, 0x2b211cee, 0x25001c08, 0x35202507,   // sw.yo.mt_643 id.jw.vi_422  id.eu.un_430 eu.sq.zu_432
  0x55125309, 0x644a3baf, 0x524a3504, 0x0a051107,   // ht.hu.rw_444 so.yo.lg_655  zu.yo.ha_332 ro.fr.pt_432
  0x021208a9, 0x130c35a7, 0x641f28ad, 0x03211e0b,   // no.hu.da_544 zu.sv.et_532  sw.cy.lg_643 ms.jw.nl_542
  // [94d0]
  0x1a00011a, 0x02100807, 0x011a2114, 0x211e04a4,   // en.tl.un_760 no.lt.da_432  jw.tl.en_666 fi.ms.jw_433
  0x3f030113, 0x1300641a, 0x3f1a010b, 0x04002d0e,   // en.nl.af_665 lg.et.un_760  en.tl.af_542 sk.fi.un_550
  0x52002811, 0x211a1c0c, 0x4a005518, 0x3b530555,   // sw.ha.un_630 id.tl.jw_543  rw.yo.un_740 fr.ht.so_442
  0x1a002821, 0x03080113, 0x290b530c, 0x031a0112,   // sw.tl.un_860 en.no.nl_665  ht.es.sl_543 en.tl.nl_654
  // [94e0]
  0x25216bad, 0x554a680d, 0x282055a4, 0x550a2307,   // ceb.jw.eu_643 ig.yo.rw_554  rw.sq.sw_433 ca.pt.rw_432
  0x1a01210c, 0x3b5528ec, 0x2a104aa9, 0x3b20520c,   // jw.en.tl_543 sw.rw.so_644  yo.lt.mt_544 ha.sq.so_543
  0x1e001119, 0x092d0faf, 0x040609b3, 0x55251a05,   // ro.ms.un_750 lv.sk.pl_655  pl.de.fi_743 tl.eu.rw_333
  0x172b20a0, 0x52552012, 0x1c6425a0, 0x6b013ba7,   // sq.vi.sr_322 sq.rw.ha_654  eu.lg.id_322 so.en.ceb_532
  // [94f0]
  0x03250a02, 0x3b015208, 0x074a3ba0, 0x352718a4,   // pt.eu.nl_222 ha.en.so_443  so.yo.it_322 ga.gd.zu_433
  0x10182755, 0x52553ba9, 0x52053ba0, 0x53050c11,   // gd.ga.lt_442 so.rw.ha_544  so.fr.ha_322 sv.fr.ht_653
  0x121c6405, 0x036406a0, 0x255213ec, 0x1113320d,   // lg.id.hu_333 de.lg.nl_322  et.ha.eu_644 bs.et.ro_554
  0x680f20a6, 0x0c060407, 0x07203b07, 0x20683f05,   // sq.lv.ig_521 fi.de.sv_432  so.sq.it_432 af.ig.sq_333
  // [9500]
  0x0e10010b, 0x35002704, 0x072108a0, 0x060c01ee,   // en.lt.is_542 gd.zu.un_320  no.jw.it_322 en.sv.de_422
  0x114a18a0, 0x19280aa0, 0x2d1b0107, 0x10050404,   // ga.yo.ro_322 pt.sw.gl_322  en.tr.sk_432 fi.fr.lt_332
  0x161732a7, 0x6b182708, 0x01062008, 0x530425a4,   // bs.sr.hr_532 gd.ga.ceb_443  sq.de.en_443 eu.fi.ht_433
  0x0f103f04, 0x3f0c0605, 0x282711a0, 0x213f6807,   // af.lt.lv_332 de.sv.af_333  ro.gd.sw_322 ig.af.jw_432
  // [9510]
  0x252a2907, 0x29002a1b, 0x013f0307, 0x07100855,   // sl.mt.eu_432 mt.sl.un_770  nl.af.en_432 uk.be.bg_442
  0x203f08ee, 0x2a2029af, 0x09080e07, 0x53010ca0,   // no.af.sq_422 sl.sq.mt_655  is.no.pl_432 sv.en.ht_322
  0x202a29a0, 0x0c0601ee, 0x0a18050c, 0x10052704,   // sl.mt.sq_322 en.de.sv_422  fr.ga.pt_543 gd.fr.lt_332
  0x233b29a9, 0x2518270e, 0x31182709, 0x29071805,   // sl.so.ca_544 gd.ga.eu_555  gd.ga.az_444 ga.it.sl_333
  // [9520]
  0x10182707, 0x121b25ee, 0x2a322912, 0x061e1ca4,   // gd.ga.lt_432 eu.tr.hu_422  sl.bs.mt_654 id.ms.de_433
  0x29122007, 0x1304290c, 0x032a0107, 0x20042a0c,   // sq.hu.sl_432 sl.fi.et_543  en.mt.nl_432 mt.fi.sq_543
  0x25132104, 0x13290413, 0x041312a4, 0x1e1c53ee,   // jw.et.eu_332 fi.sl.et_665  hu.et.fi_433 ht.id.ms_422
  0x2d0506a0, 0x1a643511, 0x13022007, 0x07201804,   // de.fr.sk_322 zu.lg.tl_653  sq.da.et_432 ga.sq.it_332
  // [9530]
  0x080a10ee, 0x2b0301ad, 0x1b005208, 0x0e09120c,   // be.mk.uk_422 en.nl.vi_643  ha.tr.un_430 hu.pl.is_543
  0x126e1b04, 0x03020107, 0x322d1702, 0x1b0129a0,   // tr.hmn.hu_332 en.da.nl_432  sr.sk.bs_222 sl.en.tr_322
  0x35002134, 0x160729a0, 0x0802210e, 0x1f00070b,   // jw.zu.un_A80 sl.it.hr_322  jw.da.no_555 it.cy.un_520
  0x19230b08, 0x351a21a9, 0x31002004, 0x6b091a07,   // es.ca.gl_443 jw.tl.zu_544  sq.az.un_320 tl.pl.ceb_432
  // [9540]
  0x321701ee, 0x1f520107, 0x1f2718a4, 0x551b1aec,   // en.sr.bs_422 en.ha.cy_432  ga.gd.cy_433 tl.tr.rw_644
  0x1b1a1ea9, 0x21183555, 0x110b0907, 0x1b351ea4,   // ms.tl.tr_544 zu.ga.jw_442  pl.es.ro_432 ms.zu.tr_433
  0x3528520c, 0x0a236b02, 0x1a521ea0, 0x13103bec,   // ha.sw.zu_543 ceb.ca.pt_222  ms.ha.tl_322 so.lt.et_644
  0x1b022907, 0x1f002902, 0x061c6ea6, 0x0f101104,   // sl.da.tr_432 sl.cy.un_220  hmn.id.de_521 ro.lt.lv_332
  // [9550]
  0x06056eee, 0x21642809, 0x20131eee, 0x2b6452a0,   // hmn.fr.de_422 sw.lg.jw_444  ms.et.sq_422 ha.lg.vi_322
  0x1c00280d, 0x32211c04, 0x011852a4, 0x1f006e12,   // sw.id.un_540 id.jw.bs_332  ha.ga.en_433 hmn.cy.un_640
  0x11120907, 0x1b35550c, 0x101104ad, 0x3b203112,   // pl.hu.ro_432 rw.zu.tr_543  ru.ro.be_643 az.sq.so_654
  0x121e25a0, 0x2a1e310c, 0x08000220, 0x3b6435a4,   // eu.ms.hu_322 az.ms.mt_543  da.no.un_850 zu.lg.so_433
  // [9560]
  0x55271ea4, 0x291608ee, 0x0a002004, 0x353b1e04,   // ms.gd.rw_433 no.hr.sl_422  sq.pt.un_320 ms.so.zu_332
  0x0f0c1304, 0x0c063f02, 0x085327a4, 0x0b0f0ca4,   // et.sv.lv_332 af.de.sv_222  gd.ht.no_433 sv.lv.es_433
  0x13211ca0, 0x020e0807, 0x050413ee, 0x12000a07,   // id.jw.et_322 no.is.da_432  et.fi.fr_422 pt.hu.un_420
  0x1e3b06a0, 0x6e35180e, 0x2b0e35ec, 0x03131902,   // de.so.ms_322 ga.zu.hmn_555  zu.is.vi_644 gl.et.nl_222
  // [9570]
  0x3f080e04, 0x13001f0e, 0x6b095507, 0x6e2718ad,   // is.no.af_332 cy.et.un_550  rw.pl.ceb_432 ga.gd.hmn_643
  0x082706ad, 0x3b000619, 0x4a2d18af, 0x12131b08,   // de.gd.no_643 de.so.un_750  ga.sk.yo_655 tr.et.hu_443
  0x03211b0c, 0x016b1307, 0x03681b07, 0x18270ea7,   // tr.jw.nl_543 et.ceb.en_432  tr.ig.nl_432 is.gd.ga_532
  0x191327a9, 0x1f00210e, 0x2b3f010b, 0x082d0c07,   // gd.et.gl_544 jw.cy.un_550  en.af.vi_542 sv.sk.no_432
  // [9580]
  0x08100f07, 0x13000e18, 0x033f1b08, 0x13002913,   // lv.lt.no_432 is.et.un_740  tr.af.nl_443 sl.et.un_650
  0x1a1113a0, 0x1c292aaf, 0x3f1311ec, 0x2b0221a0,   // et.ro.tl_322 mt.sl.id_655  ro.et.af_644 jw.da.vi_322
  0x171629af, 0x10070a02, 0x6b003513, 0x0e131b0b,   // sl.hr.sr_655 mk.bg.be_222  zu.ceb.un_650 tr.et.is_542
  0x0f3b5504, 0x070c0412, 0x170f0404, 0x32000c02,   // rw.so.lv_332 fi.sv.it_654  fi.lv.sr_332 sv.bs.un_220
  // [9590]
  0x29132a12, 0x646b1a14, 0x213b2804, 0x05073f08,   // mt.et.sl_654 tl.ceb.lg_666  sw.so.jw_332 af.it.fr_443
  0x130f28ee, 0x13041207, 0x0d2a5312, 0x180427a0,   // sw.lv.et_422 hu.fi.et_432  ht.mt.cs_654 gd.fi.ga_322
  0x18000408, 0x2a313507, 0x09000f20, 0x1a040fec,   // fi.ga.un_430 zu.az.mt_432  lv.pl.un_850 lv.fi.tl_644
  0x3b21520c, 0x6b160807, 0x3f0f0302, 0x2511285a,   // ha.jw.so_543 no.hr.ceb_432  nl.lv.af_222 sw.ro.eu_553
  // [95a0]
  0x2d002a09, 0x232d1ba0, 0x0e0906a0, 0x27062a55,   // mt.sk.un_440 tr.sk.ca_322  de.pl.is_322 mt.de.gd_442
  0x281b25ee, 0x29310e0c, 0x0b003111, 0x642810ad,   // eu.tr.sw_422 is.az.sl_543  az.es.un_630 lt.sw.lg_643
  0x23285502, 0x1c160407, 0x0f060704, 0x04250f05,   // rw.sw.ca_222 fi.hr.id_432  it.de.lv_332 lv.eu.fi_333
  0x0500270c, 0x16290d12, 0x2a1e3108, 0x6b131c07,   // gd.fr.un_530 cs.sl.hr_654  az.ms.mt_443 id.et.ceb_432
  // [95b0]
  0x1a2564a4, 0x11000f19, 0x28201108, 0x3f0810a0,   // lg.eu.tl_433 lv.ro.un_750  ro.sq.sw_443 lt.no.af_322
  0x123f13a0, 0x285311a9, 0x030f2a07, 0x135525a4,   // et.af.hu_322 ro.ht.sw_544  mt.lv.nl_432 eu.rw.et_433
  0x0b2d1008, 0x06130855, 0x20645555, 0x062b27a6,   // lt.sk.es_443 no.et.de_442  rw.lg.sq_442 gd.vi.de_521
  0x351b64ec, 0x52000208, 0x2000210d, 0x35282aec,   // lg.tr.zu_644 da.ha.un_430  jw.sq.un_540 mt.sw.zu_644
  // [95c0]
  0x06085308, 0x2a071ea4, 0x1604530c, 0x11041312,   // ht.no.de_443 ms.it.mt_433  ht.fi.hr_543 et.fi.ro_654
  0x280e200c, 0x52000221, 0x211a4a0c, 0x1304640c,   // sq.is.sw_543 da.ha.un_860  yo.tl.jw_543 lg.fi.et_543
  0x64351b04, 0x29641b0c, 0x190553a0, 0x12001e04,   // tr.zu.lg_332 tr.lg.sl_543  ht.fr.gl_322 ms.hu.un_320
  0x2d0d1ba4, 0x293217ee, 0x1300350c, 0x203b2804,   // tr.cs.sk_433 sr.bs.sl_422  zu.et.un_530 sw.so.sq_332
  // [95d0]
  0x0600021b, 0x27083f0c, 0x35041307, 0x2a230c5a,   // da.de.un_770 af.no.gd_543  et.fi.zu_432 sv.ca.mt_553
  0x050418ad, 0x553528ac, 0x10002a0c, 0x093216a4,   // ga.fi.fr_643 sw.zu.rw_632  mt.lt.un_530 hr.bs.pl_433
  0x0c1b1304, 0x04131b0c, 0x1b640604, 0x3f311ba4,   // et.tr.sv_332 tr.et.fi_543  de.lg.tr_332 tr.az.af_433
  0x230704ad, 0x3f1c21a0, 0x0d132807, 0x132a3f09,   // fi.it.ca_643 jw.id.af_322  sw.et.cs_432 af.mt.et_444
  // [95e0]
  0x2101130c, 0x283f55a7, 0x35081355, 0x1013350c,   // et.en.jw_543 rw.af.sw_532  et.no.zu_442 zu.et.lt_543
  0x52533fa6, 0x0d092d0d, 0x1a6b3f13, 0x0a250107,   // af.ht.ha_521 sk.pl.cs_554  af.ceb.tl_665 en.eu.pt_432
  0x64280405, 0x08004a02, 0x53231f55, 0x072501a4,   // fi.sw.lg_333 yo.no.un_220  cy.ca.ht_442 en.eu.it_433
  0x2a000121, 0x283568a7, 0x646b3507, 0x1c272107,   // en.mt.un_860 ig.zu.sw_532  zu.ceb.lg_432 jw.gd.id_432
  // [95f0]
  0x64286860, 0x53000322, 0x642868af, 0x07042a0c,   // ig.sw.lg_664 nl.ht.un_870  ig.sw.lg_655 mt.fi.it_543
  0x071868a0, 0x103f13a7, 0x25123fee, 0x232b11ad,   // ig.ga.it_322 et.af.lt_532  af.hu.eu_422 ro.vi.ca_643
  0x10082102, 0x11232ba7, 0x3f01130c, 0x112a01a4,   // jw.no.lt_222 vi.ca.ro_532  et.en.af_543 en.mt.ro_433
  0x533f2aa9, 0x16004a04, 0x29182704, 0x1f103b0c,   // mt.af.ht_544 yo.hr.un_320  gd.ga.sl_332 so.lt.cy_543
  // [9600]
  0x64011f05, 0x18022302, 0x2d022b07, 0x086b0c08,   // cy.en.lg_333 ca.da.ga_222  vi.da.sk_432 sv.ceb.no_443
  0x101705a4, 0x6e00202b, 0x0f1705ee, 0x1b3b0e07,   // fr.sr.lt_433 sq.hmn.un_980  fr.sr.lv_422 is.so.tr_432
  0x080e235a, 0x1f182b5a, 0x1b002802, 0x0f001609,   // ca.is.no_553 vi.ga.cy_553  sw.tr.un_220 hr.lv.un_440
  0x210c6b04, 0x182701a0, 0x10280405, 0x101f1105,   // ceb.sv.jw_332 en.gd.ga_322  fi.sw.lt_333 ro.cy.lt_333
  // [9610]
  0x1200551b, 0x08250411, 0x1f030ca0, 0x1f232512,   // rw.hu.un_770 fi.eu.no_653  sv.nl.cy_322 eu.ca.cy_654
  0x0d000e02, 0x2a200307, 0x19181104, 0x0a0723a9,   // is.cs.un_220 nl.sq.mt_432  ro.ga.gl_332 ca.it.pt_544
  0x21006408, 0x04106eee, 0x0d5553ee, 0x6e00531a,   // lg.jw.un_430 hmn.lt.fi_422  ht.rw.cs_422 ht.hmn.un_760
  0x050729a0, 0x6e001609, 0x184a6e04, 0x6b080108,   // sl.it.fr_322 hr.hmn.un_440  hmn.yo.ga_332 en.no.ceb_443
  // [9620]
  0x04641311, 0x12316ead, 0x036b3fa0, 0x12002819,   // et.lg.fi_653 hmn.az.hu_643  af.ceb.nl_322 sw.hu.un_750
  0x2a0452ad, 0x29000607, 0x12211aa0, 0x01001e02,   // ha.fi.mt_643 de.sl.un_420  tl.jw.hu_322 ms.en.un_220
  0x21120fa0, 0x235553a0, 0x53000e04, 0x07200ea0,   // lv.hu.jw_322 ht.rw.ca_322  is.ht.un_320 is.sq.it_322
  0x321b53a0, 0x4a003f0d, 0x09320da0, 0x01686b04,   // ht.tr.bs_322 af.yo.un_540  cs.bs.pl_322 ceb.ig.en_332
  // [9630]
  0x12001102, 0x1b00120d, 0x0f0113a0, 0x4a083fad,   // ro.hu.un_220 hu.tr.un_540  et.en.lv_322 af.no.yo_643
  0x0d190ba7, 0x271811a0, 0x1e554a04, 0x20020555,   // es.gl.cs_532 ro.ga.gd_322  yo.rw.ms_332 fr.da.sq_442
  0x0b001802, 0x23201ca0, 0x2a1b13a7, 0x11202304,   // ga.es.un_220 id.sq.ca_322  et.tr.mt_532 ca.sq.ro_332
  0x1e13180c, 0x0d005502, 0x201b5312, 0x3f002119,   // ga.et.ms_543 rw.cs.un_220  ht.tr.sq_654 jw.af.un_750
  // [9640]
  0x176e20ad, 0x31321602, 0x17002102, 0x06000f02,   // sq.hmn.sr_643 hr.bs.az_222  jw.sr.un_220 lv.de.un_220
  0x52640f0b, 0x210520ad, 0x52001702, 0x1a08020d,   // lv.lg.ha_542 sq.fr.jw_643  sr.ha.un_220 da.no.tl_554
  0x190b18a7, 0x2d0d21af, 0x6b0607ee, 0x20285208,   // ga.es.gl_532 jw.cs.sk_655  it.de.ceb_422 ha.sw.sq_443
  0x0a001014, 0x0b05210b, 0x0e001b2b, 0x28202108,   // be.mk.un_660 jw.fr.es_542  tr.is.un_980 jw.sq.sw_443
  // [9650]
  0x2300200e, 0x16001c04, 0x1a000713, 0x232d0d55,   // sq.ca.un_550 id.hr.un_320  it.tl.un_650 cs.sk.ca_442
  0x1b0d31a0, 0x3f000704, 0x100e1aee, 0x07282008,   // az.cs.tr_322 it.af.un_320  tl.is.lt_422 sq.sw.it_443
  0x281c2104, 0x0e311b11, 0x64205508, 0x162d29a9,   // jw.id.sw_332 tr.az.is_653  rw.sq.lg_443 sl.sk.hr_544
  0x0213290c, 0x21051007, 0x282a2905, 0x322a53a0,   // sl.et.da_543 lt.fr.jw_432  sl.mt.sw_333 ht.mt.bs_322
  // [9660]
  0x20120e0e, 0x4a001104, 0x6e00062a, 0x52211ea4,   // is.hu.sq_555 ro.yo.un_320  de.hmn.un_970 ms.jw.ha_433
  0x10060107, 0x076e27ad, 0x113f0312, 0x1b53120c,   // en.de.lt_432 gd.hmn.it_643  nl.af.ro_654 hu.ht.tr_543
  0x27001e0d, 0x192a0aad, 0x0c68120c, 0x03096ead,   // ms.gd.un_540 pt.mt.gl_643  hu.ig.sv_543 hmn.pl.nl_643
  0x19110b12, 0x0f6e11ad, 0x1c4a6b04, 0x212864ad,   // es.ro.gl_654 ro.hmn.lv_643  ceb.yo.id_332 lg.sw.jw_643
  // [9670]
  0x27000419, 0x28352dad, 0x13042da4, 0x3568640c,   // fi.gd.un_750 sk.zu.sw_643  sk.fi.et_433 lg.ig.zu_543
  0x122b2107, 0x132355ee, 0x122a6e02, 0x0408020d,   // jw.vi.hu_432 rw.ca.et_422  hmn.mt.hu_222 da.no.fi_554
  0x041011ec, 0x0e080ca7, 0x17552907, 0x0e120807,   // ro.be.ru_644 sv.no.is_532  sl.rw.sr_432 no.hu.is_432
  0x040f27a9, 0x0b000a0c, 0x022a0808, 0x0f000402,   // gd.lv.fi_544 pt.es.un_530  no.mt.da_443 fi.lv.un_220
  // [9680]
  0x21002702, 0x04212502, 0x2a0b0a02, 0x18002b1a,   // gd.jw.un_220 eu.jw.fi_222  pt.es.mt_222 vi.ga.un_760
  0x31130612, 0x100429a0, 0x13092504, 0x1f003202,   // de.et.az_654 sl.fi.lt_322  eu.pl.et_332 bs.cy.un_220
  0x0c1308ad, 0x16000e19, 0x171c0807, 0x320f0a08,   // no.et.sv_643 is.hr.un_750  no.id.sr_432 pt.lv.bs_443
  0x081a2111, 0x0f001213, 0x17092d09, 0x3b082a02,   // jw.tl.no_653 hu.lv.un_650  sk.pl.sr_444 mt.no.so_222
  // [9690]
  0x281035ad, 0x0a0f1102, 0x17122902, 0x6b060107,   // zu.lt.sw_643 ro.lv.pt_222  sl.hu.sr_222 en.de.ceb_432
  0x216b01ec, 0x3b201fa7, 0x021b35a0, 0x182d3507,   // en.ceb.jw_644 cy.sq.so_532  zu.tr.da_322 zu.sk.ga_432
  0x2d0d12ed, 0x202a06ad, 0x27212a07, 0x13003511,   // hu.cs.sk_622 de.mt.sq_643  mt.jw.gd_432 zu.et.un_630
  0x29002809, 0x17162aa0, 0x2d0d0e14, 0x0a0f1208,   // sw.sl.un_440 mt.hr.sr_322  is.cs.sk_666 hu.lv.pt_443
  // [96a0]
  0x1f23060c, 0x270f1ea0, 0x126e2da0, 0x110a05af,   // de.ca.cy_543 ms.lv.gd_322  sk.hmn.hu_322 fr.pt.ro_655
  0x271f0ea0, 0x11001214, 0x1b000c0b, 0x182711ee,   // is.cy.gd_322 hu.ro.un_660  sv.tr.un_520 ro.gd.ga_422
  0x08190aa0, 0x20020ca4, 0x041e1c05, 0x1b2910ee,   // pt.gl.no_322 sv.da.sq_433  id.ms.fi_333 lt.sl.tr_422
  0x1f00062a, 0x016b5307, 0x28002d0d, 0x35020107,   // de.cy.un_970 ht.ceb.en_432  sk.sw.un_540 en.da.zu_432
  // [96b0]
  0x28176407, 0x02350813, 0x0810045a, 0x55355307,   // lg.sr.sw_432 no.zu.da_665  ru.be.uk_553 ht.zu.rw_432
  0x23052104, 0x27180555, 0x05012bee, 0x041108a9,   // jw.fr.ca_332 fr.ga.gd_442  vi.en.fr_422 uk.ro.ru_544
  0x05002122, 0x532705a7, 0x0d000e0d, 0x3f1827ad,   // jw.fr.un_870 fr.gd.ht_532  is.cs.un_540 gd.ga.af_643
  0x3f1168a4, 0x28002b0b, 0x120b1911, 0x043f0302,   // ig.ro.af_433 vi.sw.un_520  gl.es.hu_653 nl.af.fi_222
  // [96c0]
  0x2700061a, 0x27000513, 0x3f00270e, 0x09293508,   // de.gd.un_760 fr.gd.un_650  gd.af.un_550 zu.sl.pl_443
  0x09041313, 0x32642808, 0x071108ad, 0x2a251e07,   // et.fi.pl_665 sw.lg.bs_443  uk.ro.bg_643 ms.eu.mt_432
  0x04000e1a, 0x13010404, 0x290201a0, 0x08171604,   // is.fi.un_760 fi.en.et_332  en.da.sl_322 hr.sr.no_332
  0x2d4a0d0c, 0x190b12a9, 0x28683bec, 0x2a6b1a04,   // cs.yo.sk_543 hu.es.gl_544  so.ig.sw_644 tl.ceb.mt_332
  // [96d0]
  0x1a203bee, 0x1a043b09, 0x281335a7, 0x0b2d0aa0,   // so.sq.tl_422 so.fi.tl_444  zu.et.sw_532 pt.sk.es_322
  0x05000b0e, 0x2a351a0c, 0x0305070c, 0x3105350c,   // es.fr.un_550 tl.zu.mt_543  it.fr.nl_543 zu.fr.az_543
  0x07002004, 0x53005204, 0x1c311ea0, 0x0413640c,   // sq.it.un_320 ha.ht.un_320  ms.az.id_322 lg.et.fi_543
  0x642a350d, 0x55000505, 0x12046408, 0x31000504,   // zu.mt.lg_554 fr.rw.un_330  lg.fi.hu_443 fr.az.un_320
  // [96e0]
  0x6b042a04, 0x13200f07, 0x0c0e6bee, 0x351a4aee,   // mt.fi.ceb_332 lv.sq.et_432  ceb.is.sv_422 yo.tl.zu_422
  0x015305ad, 0x0802055a, 0x25000912, 0x4a006412,   // fr.ht.en_643 fr.da.no_553  pl.eu.un_640 lg.yo.un_640
  0x321612a0, 0x2a29120c, 0x35041ba4, 0x0c021008,   // hu.hr.bs_322 hu.sl.mt_543  tr.fi.zu_433 lt.da.sv_443
  0x21292a02, 0x52000f0b, 0x20006b08, 0x55020807,   // mt.sl.jw_222 lv.ha.un_520  ceb.sq.un_430 no.da.rw_432
  // [96f0]
  0x20110a07, 0x07002d07, 0x1a001802, 0x322a070b,   // pt.ro.sq_432 sk.it.un_420  ga.tl.un_220 it.mt.bs_542
  0x31201e04, 0x2d0f17a0, 0x271118ee, 0x0d000508,   // ms.sq.az_332 sr.lv.sk_322  ga.ro.gd_422 fr.cs.un_430
  0x2d000513, 0x3f003b0d, 0x353104a4, 0x55356402,   // fr.sk.un_650 so.af.un_540  fi.az.zu_433 lg.zu.rw_222
  0x31002819, 0x0c0e0802, 0x681827a7, 0x2801130b,   // sw.az.un_750 no.is.sv_222  gd.ga.ig_532 et.en.sw_542
  // [9700]
  0x03190bad, 0x1e3168a0, 0x2a005219, 0x07002819,   // es.gl.nl_643 ig.az.ms_322  ha.mt.un_750 sw.it.un_750
  0x53680107, 0x162125a0, 0x1f090ba4, 0x683b280c,   // en.ig.ht_432 eu.jw.hr_322  es.pl.cy_433 sw.so.ig_543
  0x35061fee, 0x250e1a04, 0x0d531f0b, 0x0f001c08,   // cy.de.zu_422 tl.is.eu_332  cy.ht.cs_542 id.lv.un_430
  0x55001907, 0x521b1ca0, 0x531b680c, 0x530603a0,   // gl.rw.un_420 id.tr.ha_322  ig.tr.ht_543 nl.de.ht_322
  // [9710]
  0x53214aa7, 0x12076409, 0x3b3f0307, 0x0e002104,   // yo.jw.ht_532 lg.it.hu_444  nl.af.so_432 jw.is.un_320
  0x53003507, 0x08021105, 0x4a00270c, 0x0c0e64a7,   // zu.ht.un_420 ro.da.no_333  gd.yo.un_530 lg.is.sv_532
  0x0306050d, 0x115306a4, 0x0b19535a, 0x0c553507,   // fr.de.nl_554 de.ht.ro_433  ht.gl.es_553 zu.rw.sv_432
  0x21001e13, 0x03001119, 0x53202812, 0x550c08ad,   // ms.jw.un_650 ro.nl.un_750  sw.sq.ht_654 no.sv.rw_643
  // [9720]
  0x3f006404, 0x1c311e0b, 0x010225a0, 0x1c2b1eee,   // lg.af.un_320 ms.az.id_542  eu.da.en_322 ms.vi.id_422
  0x35001121, 0x04006b0c, 0x31001802, 0x2d0d0a0e,   // ro.zu.un_860 ceb.fi.un_530  ga.az.un_220 pt.cs.sk_555
  0x1704110e, 0x55000307, 0x0807100e, 0x08071702,   // ro.ru.sr_555 nl.rw.un_420  be.bg.uk_555 sr.bg.uk_222
  0x680128a6, 0x0a000407, 0x0a000f02, 0x1c002012,   // sw.en.ig_521 ru.mk.un_420  lv.pt.un_220 sq.id.un_640
  // [9730]
  0x081b0ea7, 0x1729280c, 0x283153a4, 0x1b110709,   // is.tr.no_532 sw.sl.sr_543  ht.az.sw_433 it.ro.tr_444
  0x21053ba4, 0x6e1235a0, 0x0b18190c, 0x172935a0,   // so.fr.jw_433 zu.hu.hmn_322  gl.ga.es_543 zu.sl.sr_322
  0x3564310d, 0x0e0801a0, 0x0a5227a4, 0x18000113,   // az.lg.zu_554 en.no.is_322  gd.ha.pt_433 en.ga.un_650
  0x09005311, 0x311b3509, 0x11100fee, 0x3520310c,   // ht.pl.un_630 zu.tr.az_444  lv.lt.ro_422 az.sq.zu_543
  // [9740]
  0x25002304, 0x0d2d0e11, 0x1e313b11, 0x29000804,   // ca.eu.un_320 is.sk.cs_653  so.az.ms_653 no.sl.un_320
  0x1e1c01ee, 0x09131012, 0x16006b02, 0x09286408,   // en.id.ms_422 lt.et.pl_654  ceb.hr.un_220 lg.sw.pl_443
  0x55004a1a, 0x0e2d12a4, 0x2b211ca0, 0x311c52ad,   // yo.rw.un_760 hu.sk.is_433  id.jw.vi_322 ha.id.az_643
  0x0f1c1ea4, 0x1a063b07, 0x526b1b55, 0x1b066baf,   // ms.id.lv_433 so.de.tl_432  tr.ceb.ha_442 ceb.de.tr_655
  // [9750]
  0x31552508, 0x0a005507, 0x351a11a4, 0x350613af,   // eu.rw.az_443 rw.pt.un_420  ro.tl.zu_433 et.de.zu_655
  0x1c005505, 0x1f5521ad, 0x0f006e13, 0x13062a12,   // rw.id.un_330 jw.rw.cy_643  hmn.lv.un_650 mt.de.et_654
  0x2a6425ad, 0x6e000113, 0x18005321, 0x100313a0,   // eu.lg.mt_643 en.hmn.un_650  ht.ga.un_860 et.nl.lt_322
  0x0d2d12a9, 0x200f1b07, 0x2a0320ee, 0x23000d0e,   // hu.sk.cs_544 tr.lv.sq_432  sq.nl.mt_422 cs.ca.un_550
  // [9760]
  0x0d2d2104, 0x2a0f6e12, 0x04252dec, 0x100925ad,   // jw.sk.cs_332 hmn.lv.mt_654  sk.eu.fi_644 eu.pl.lt_643
  0x060c1308, 0x4a2520ee, 0x101c1e0c, 0x31002304,   // et.sv.de_443 sq.eu.yo_422  ms.id.lt_543 ca.az.un_320
  0x311b3b08, 0x201b0f04, 0x282a2307, 0x11011f0c,   // so.tr.az_443 lv.tr.sq_332  ca.mt.sw_432 cy.en.ro_543
  0x311b2004, 0x2d250408, 0x25210405, 0x0b271a12,   // sq.tr.az_332 fi.eu.sk_443  fi.jw.eu_333 tl.gd.es_654
  // [9770]
  0x121f53a0, 0x0b55680c, 0x6b001e04, 0x1b120c0c,   // ht.cy.hu_322 ig.rw.es_543  ms.ceb.un_320 sv.hu.tr_543
  0x12130ea0, 0x0800250d, 0x0b1e25a0, 0x0e061207,   // is.et.hu_322 eu.no.un_540  eu.ms.es_322 hu.de.is_432
  0x18061102, 0x23001c02, 0x6b551a04, 0x062313ec,   // ro.de.ga_222 id.ca.un_220  tl.rw.ceb_332 et.ca.de_644
  0x060c12ec, 0x25112055, 0x29050107, 0x1b0e0cad,   // hu.sv.de_644 sq.ro.eu_442  en.fr.sl_432 sv.is.tr_643
  // [9780]
  0x2a2016a4, 0x17521a12, 0x20002819, 0x1a216ba9,   // hr.sq.mt_433 tl.ha.sr_654  sw.sq.un_750 ceb.jw.tl_544
  0x3b002018, 0x131a35a0, 0x523520ad, 0x05001022,   // sq.so.un_740 zu.tl.et_322  sq.zu.ha_643 lt.fr.un_870
  0x642853ad, 0x356423a4, 0x310c1b12, 0x1a6b120c,   // ht.sw.lg_643 ca.lg.zu_433  tr.sv.az_654 hu.ceb.tl_543
  0x35006802, 0x0b120505, 0x3564135a, 0x205535ee,   // ig.zu.un_220 fr.hu.es_333  et.lg.zu_553 zu.rw.sq_422
  // [9790]
  0x0264010c, 0x6431250d, 0x0600200d, 0x25071b0c,   // en.lg.da_543 eu.az.lg_554  sq.de.un_540 tr.it.eu_543
  0x1f033f04, 0x1f190a05, 0x250c0307, 0x32645512,   // af.nl.cy_332 pt.gl.cy_333  nl.sv.eu_432 rw.lg.bs_654
  0x2a030407, 0x03000214, 0x6b6468a7, 0x283b35a0,   // fi.nl.mt_432 da.nl.un_660  ig.lg.ceb_532 zu.so.sw_322
  0x01205255, 0x1110310c, 0x20351c05, 0x68002019,   // ha.sq.en_442 az.lt.ro_543  id.zu.sq_333 sq.ig.un_750
  // [97a0]
  0x1c101e07, 0x01183ba0, 0x5320110d, 0x036b20a7,   // ms.lt.id_432 so.ga.en_322  ro.sq.ht_554 sq.ceb.nl_532
  0x64280208, 0x100208a4, 0x25122aa0, 0x0b006412,   // da.sw.lg_443 no.da.lt_433  mt.hu.eu_322 lg.es.un_640
  0x35002a19, 0x12000b02, 0x2d3520a4, 0x080c0ead,   // mt.zu.un_750 es.hu.un_220  sq.zu.sk_433 is.sv.no_643
  0x2d1355a7, 0x10552d0c, 0x210703a0, 0x551301a0,   // rw.et.sk_532 sk.rw.lt_543  nl.it.jw_322 en.et.rw_322
  // [97b0]
  0x133b1a09, 0x2b005521, 0x05190b04, 0x0a0c0607,   // tl.so.et_444 rw.vi.un_860  es.gl.fr_332 de.sv.pt_432
  0x0e00210c, 0x130c0f04, 0x2d3b01ad, 0x132925a0,   // jw.is.un_530 lv.sv.et_332  en.so.sk_643 eu.sl.et_322
  0x643f68a4, 0x2d033504, 0x0f0c13a4, 0x682835a4,   // ig.af.lg_433 zu.nl.sk_332  et.sv.lv_433 zu.sw.ig_433
  0x2d00351a, 0x2d10130c, 0x55103ba0, 0x35551e0e,   // zu.sk.un_760 et.lt.sk_543  so.lt.rw_322 ms.rw.zu_555
  // [97c0]
  0x00001c37, 0x0e285504, 0x1a6b680c, 0x31521b08,   // mr.un.un_B00 rw.sw.is_332  ig.ceb.tl_543 tr.ha.az_443
  0x356452a4, 0x1a1b3b07, 0x060f1b07, 0x312a0a07,   // ha.lg.zu_433 so.tr.tl_432  tr.lv.de_432 pt.mt.az_432
  0x10286813, 0x52281fa6, 0x091e1c04, 0x28356807,   // ig.sw.lt_665 cy.sw.ha_521  id.ms.pl_332 ig.zu.sw_432
  0x13000e0e, 0x642868ad, 0x280652a0, 0x291735ee,   // is.et.un_550 ig.sw.lg_643  ha.de.sw_322 zu.sr.sl_422
  // [97d0]
  0x01646ba4, 0x3b645507, 0x4a1f5555, 0x012518a4,   // ceb.lg.en_433 rw.lg.so_432  rw.cy.yo_442 ga.eu.en_433
  0x210420a4, 0x130d2da4, 0x161f4aa6, 0x09072aee,   // sq.fi.jw_433 sk.cs.et_433  yo.cy.hr_521 mt.it.pl_422
  0x191a6b08, 0x092a1eee, 0x170708a6, 0x115268a7,   // ceb.tl.gl_443 ms.mt.pl_422  uk.bg.sr_521 ig.ha.ro_532
  0x08313504, 0x21003509, 0x0c001e04, 0x53683bad,   // zu.az.no_332 zu.jw.un_440  ms.sv.un_320 so.ig.ht_643
  // [97e0]
  0x3100010c, 0x216420a4, 0x1c020e12, 0x6b2a5504,   // en.az.un_530 sq.lg.jw_433  is.da.id_654 rw.mt.ceb_332
  0x100a110c, 0x18102755, 0x35531ba4, 0x551b31a9,   // ro.mk.be_543 gd.lt.ga_442  tr.ht.zu_433 az.tr.rw_544
  0x211c03a0, 0x09003b09, 0x081f270c, 0x09002102,   // nl.id.jw_322 so.pl.un_440  gd.cy.no_543 jw.pl.un_220
  0x64311bad, 0x121b100c, 0x12130112, 0x643b550c,   // tr.az.lg_643 lt.tr.hu_543  en.et.hu_654 rw.so.lg_543
  // [97f0]
  0x1716130c, 0x282a3504, 0x3b18010b, 0x100b070c,   // et.hr.sr_543 zu.mt.sw_332  en.ga.so_542 it.es.lt_543
  0x21002829, 0x2b092a04, 0x12180502, 0x28002a1a,   // sw.jw.un_960 mt.pl.vi_332  fr.ga.hu_222 mt.sw.un_760
  0x13002119, 0x1c4a5507, 0x292d35af, 0x1e6b1aaf,   // jw.et.un_750 rw.yo.id_432  zu.sk.sl_655 tl.ceb.ms_655
  0x2d001208, 0x3b3120a4, 0x10045308, 0x1304110c,   // hu.sk.un_430 sq.az.so_433  ht.fi.lt_443 ro.fi.et_543

  // [9800]
  0x1e551fa4, 0x114a1704, 0x02080ca7, 0x68170911,   // cy.rw.ms_433 sr.yo.ro_332  sv.no.da_532 pl.sr.ig_653
  0x35120708, 0x1100291a, 0x130d1ca4, 0x111e1c13,   // it.hu.zu_443 sl.ro.un_760  mr.ne.bh_433 id.ms.ro_665
  0x0c0804a4, 0x251135a0, 0x13110413, 0x2d1721ad,   // fi.no.sv_433 zu.ro.eu_322  fi.ro.et_665 jw.sr.sk_643
  0x1f0e0b04, 0x07111705, 0x235329a0, 0x32031ca0,   // es.is.cy_332 sr.ro.bg_333  sl.ht.ca_322 id.nl.bs_322
  // [9810]
  0x0e003202, 0x3b135304, 0x18201e07, 0x211a270c,   // bs.is.un_220 ht.et.so_332  ms.sq.ga_432 gd.tl.jw_543
  0x12000f1a, 0x10004a0d, 0x1b182712, 0x05120aa4,   // lv.hu.un_760 yo.lt.un_540  gd.ga.tr_654 pt.hu.fr_433
  0x112a070c, 0x3b1b310c, 0x180111a7, 0x3b1b31a4,   // it.mt.ro_543 az.tr.so_543  ro.en.ga_532 az.tr.so_433
  0x12350308, 0x3f126b04, 0x271f2a12, 0x0e001122,   // nl.zu.hu_443 ceb.hu.af_332  mt.cy.gd_654 ro.is.un_870
  // [9820]
  0x3f1f0107, 0x03005307, 0x1b033f07, 0x21311b12,   // en.cy.af_432 ht.nl.un_420  af.nl.tr_432 tr.az.jw_654
  0x3f1264a4, 0x2a3f1a08, 0x022a03ec, 0x1f006412,   // lg.hu.af_433 tl.af.mt_443  nl.mt.da_644 lg.cy.un_640
  0x033f35a9, 0x1f000d13, 0x5521350e, 0x1f3528ee,   // zu.af.nl_544 cs.cy.un_650  zu.jw.rw_555 sw.zu.cy_422
  0x3b1913a0, 0x0a0810a9, 0x0e001f05, 0x080e270c,   // et.gl.so_322 be.uk.mk_544  cy.is.un_330 gd.is.no_543
  // [9830]
  0x3f050607, 0x0e000d09, 0x120335af, 0x6435125a,   // de.fr.af_432 cs.is.un_440  zu.nl.hu_655 hu.zu.lg_553
  0x06002a07, 0x110155a4, 0x03642812, 0x033f55a9,   // mt.de.un_420 rw.en.ro_433  sw.lg.nl_654 rw.af.nl_544
  0x1c1a21ad, 0x6412350c, 0x122d0aee, 0x082812a4,   // jw.tl.id_643 zu.hu.lg_543  pt.sk.hu_422 hu.sw.no_433
  0x081a2155, 0x35211a04, 0x6811275a, 0x13211aa7,   // jw.tl.no_442 tl.jw.zu_332  gd.ro.ig_553 tl.jw.et_532
  // [9840]
  0x6828030e, 0x1f00181b, 0x1c0e21ad, 0x105504a0,   // nl.sw.ig_555 ga.cy.un_770  jw.is.id_643 fi.rw.lt_322
  0x1a6b2107, 0x060220a7, 0x0f190bec, 0x092d11a4,   // jw.ceb.tl_432 sq.da.de_532  es.gl.lv_644 ro.sk.pl_433
  0x641a2814, 0x102813ee, 0x12001c0d, 0x3b041e05,   // sw.tl.lg_666 et.sw.lt_422  id.hu.un_540 ms.fi.so_333
  0x1c6b2107, 0x2855110c, 0x1a1e2104, 0x13000113,   // jw.ceb.id_432 ro.rw.sw_543  jw.ms.tl_332 en.et.un_650
  // [9850]
  0x1c3f21a0, 0x08021a05, 0x23033f60, 0x103f1307,   // jw.af.id_322 tl.da.no_333  af.nl.ca_664 et.af.lt_432
  0x121e5504, 0x271c2102, 0x32291ca0, 0x12002b22,   // rw.ms.hu_332 jw.id.gd_222  id.sl.bs_322 vi.hu.un_870
  0x072001ee, 0x0c13060d, 0x07110455, 0x122b4a0c,   // en.sq.it_422 de.et.sv_554  ru.ro.bg_442 yo.vi.hu_543
  0x04083f12, 0x2d0d6ba0, 0x0e0d2b11, 0x0f2a2905,   // af.no.fi_654 ceb.cs.sk_322  vi.cs.is_653 sl.mt.lv_333
  // [9860]
  0x0a6455ad, 0x355206a4, 0x11123107, 0x6e0b5307,   // rw.lg.pt_643 de.ha.zu_433  az.hu.ro_432 ht.es.hmn_432
  0x2d0d1ca0, 0x3217290e, 0x53211b12, 0x0a230e07,   // id.cs.sk_322 sl.sr.bs_555  tr.jw.ht_654 is.ca.pt_432
  0x211b29a9, 0x030625ee, 0x290e1e08, 0x073511ee,   // sl.tr.jw_544 eu.de.nl_422  ms.is.sl_443 ro.zu.it_422
  0x52681b08, 0x04005323, 0x32055307, 0x3f00110d,   // tr.ig.ha_443 ht.fi.un_880  ht.fr.bs_432 ro.af.un_540
  // [9870]
  0x6b05530c, 0x17293f12, 0x295305a4, 0x07530507,   // ht.fr.ceb_543 af.sl.sr_654  fr.ht.sl_433 fr.ht.it_432
  0x0c520a04, 0x28002004, 0x2800030c, 0x64551b13,   // pt.ha.sv_332 sq.sw.un_320  nl.sw.un_530 tr.rw.lg_665
  0x083f03ad, 0x05530d12, 0x53020508, 0x04003502,   // nl.af.no_643 cs.ht.fr_654  fr.da.ht_443 zu.fi.un_220
  0x1e531104, 0x0d53050c, 0x17290207, 0x0435110c,   // ro.ht.ms_332 fr.ht.cs_543  da.sl.sr_432 ro.zu.fi_543
  // [9880]
  0x32311b05, 0x10006422, 0x06130c55, 0x273b2aee,   // tr.az.bs_333 lg.lt.un_870  sv.et.de_442 mt.so.gd_422
  0x02002108, 0x212a200c, 0x09112da0, 0x041b0f0c,   // jw.da.un_430 sq.mt.jw_543  sk.ro.pl_322 lv.tr.fi_543
  0x10130b08, 0x05074aa0, 0x530a110c, 0x2300271b,   // es.et.lt_443 yo.it.fr_322  ro.pt.ht_543 gd.ca.un_770
  0x040f1bad, 0x280107a0, 0x19230a07, 0x130e06ee,   // tr.lv.fi_643 it.en.sw_322  pt.ca.gl_432 de.is.et_422
  // [9890]
  0x0b001b08, 0x013f04ee, 0x3f082707, 0x3b5231a4,   // tr.es.un_430 fi.af.en_422  gd.no.af_432 az.ha.so_433
  0x1a080b04, 0x1e1c1bec, 0x05013507, 0x311b21af,   // es.no.tl_332 tr.id.ms_644  zu.en.fr_432 jw.tr.az_655
  0x03026e0c, 0x1b3b350b, 0x29322d14, 0x182b53a0,   // hmn.da.nl_543 zu.so.tr_542  sk.bs.sl_666 ht.vi.ga_322
  0x026b55ad, 0x2a0e06a4, 0x1a313ba9, 0x11091b04,   // rw.ceb.da_643 de.is.mt_433  so.az.tl_544 tr.pl.ro_332
  // [98a0]
  0x076435ec, 0x1a2807af, 0x170a1bee, 0x2d0d55af,   // zu.lg.it_644 it.sw.tl_655  tr.pt.sr_422 rw.cs.sk_655
  0x0e2b120c, 0x31130808, 0x0b1029a9, 0x1b3529a7,   // hu.vi.is_543 no.et.az_443  sl.lt.es_544 sl.zu.tr_532
  0x13205202, 0x03002b0d, 0x180501ee, 0x55352d0d,   // ha.sq.et_222 vi.nl.un_540  en.fr.ga_422 sk.zu.rw_554
  0x21230512, 0x0c0904ee, 0x0e0464a0, 0x061f0e04,   // fr.ca.jw_654 fi.pl.sv_422  lg.fi.is_322 is.cy.de_332
  // [98b0]
  0x1364040c, 0x3b0a19a9, 0x011b12a6, 0x03090ba0,   // fi.lg.et_543 gl.pt.so_544  hu.tr.en_521 es.pl.nl_322
  0x0b64350d, 0x230b13a9, 0x0c192aee, 0x286412ad,   // zu.lg.es_554 et.es.ca_544  mt.gl.sv_422 hu.lg.sw_643
  0x16002804, 0x17202d07, 0x2d2318ad, 0x05000d1a,   // sw.hr.un_320 sk.sq.sr_432  ga.ca.sk_643 cs.fr.un_760
  0x06122355, 0x1e52250c, 0x273f010c, 0x25114aa4,   // ca.hu.de_442 eu.ha.ms_543  en.af.gd_543 yo.ro.eu_433
  // [98c0]
  0x212728a7, 0x0b00090c, 0x0f062d08, 0x2a063fad,   // sw.gd.jw_532 pl.es.un_530  sk.de.lv_443 af.de.mt_643
  0x0e171355, 0x0e00280c, 0x4a000d08, 0x03066b02,   // et.sr.is_442 sw.is.un_530  cs.yo.un_430 ceb.de.nl_222
  0x17081012, 0x182b1c04, 0x3f003502, 0x552a01a0,   // be.uk.sr_654 id.vi.ga_332  zu.af.un_220 en.mt.rw_322
  0x100c6bad, 0x073512a9, 0x1e1c23a4, 0x171613a4,   // ceb.sv.lt_643 hu.zu.it_544  ca.id.ms_433 et.hr.sr_433
  // [98d0]
  0x09000a07, 0x0d001b02, 0x16285507, 0x1f0128a6,   // pt.pl.un_420 tr.cs.un_220  rw.sw.hr_432 sw.en.cy_521
  0x0f006412, 0x08000602, 0x551a28ee, 0x1a523f04,   // lg.lv.un_640 de.no.un_220  sw.tl.rw_422 af.ha.tl_332
  0x29005214, 0x1e53050c, 0x1f001b14, 0x2a000421,   // ha.sl.un_660 fr.ht.ms_543  tr.cy.un_660 fi.mt.un_860
  0x11162da7, 0x10120407, 0x312a1c09, 0x641620ee,   // sk.hr.ro_532 fi.hu.lt_432  id.mt.az_444 sq.hr.lg_422
  // [98e0]
  0x100112ee, 0x5300200e, 0x12030404, 0x21555204,   // hu.en.lt_422 sq.ht.un_550  fi.nl.hu_332 ha.rw.jw_332
  0x083f6412, 0x090d2013, 0x02036409, 0x111b3113,   // lg.af.no_654 sq.cs.pl_665  lg.nl.da_444 az.tr.ro_665
  0x6400100e, 0x12060c09, 0x3f001208, 0x11170a05,   // lt.lg.un_550 sv.de.hu_444  hu.af.un_430 mk.sr.ro_333
  0x1a00060c, 0x13003f04, 0x04036405, 0x201e270c,   // de.tl.un_530 af.et.un_320  lg.nl.fi_333 gd.ms.sq_543
  // [98f0]
  0x0b0a23a0, 0x1a21275a, 0x0721270c, 0x1e271f0d,   // ca.pt.es_322 gd.jw.tl_553  gd.jw.it_543 cy.gd.ms_554
  0x18082704, 0x182a06ee, 0x0600320c, 0x27230ba0,   // gd.no.ga_332 de.mt.ga_422  bs.de.un_530 es.ca.gd_322
  0x07000e11, 0x1b273114, 0x1e1c280e, 0x4a002118,   // is.it.un_630 az.gd.tr_666  sw.id.ms_555 jw.yo.un_740
  0x21001022, 0x202813a4, 0x6b11130c, 0x3f1311ee,   // lt.jw.un_870 et.sw.sq_433  et.ro.ceb_543 ro.et.af_422
  // [9900]
  0x352a6405, 0x32170f14, 0x100820ee, 0x2511135a,   // lg.mt.zu_333 lv.sr.bs_666  sq.no.lt_422 et.ro.eu_553
  0x23022da0, 0x0e253f04, 0x0e2811ee, 0x020e08a0,   // sk.da.ca_322 af.eu.is_332  ro.sw.is_422 no.is.da_322
  0x052a3b04, 0x2300350c, 0x28002a08, 0x112017ee,   // so.mt.fr_332 zu.ca.un_530  mt.sw.un_430 sr.sq.ro_422
  0x13042009, 0x18282aa0, 0x190b05ad, 0x283501a0,   // sq.fi.et_444 mt.sw.ga_322  fr.es.gl_643 en.zu.sw_322
  // [9910]
  0x0e041308, 0x25282904, 0x0f202855, 0x16072a07,   // et.fi.is_443 sl.sw.eu_332  sw.sq.lv_442 mt.it.hr_432
  0x070d4a05, 0x6428130c, 0x01112aee, 0x1b120608,   // yo.cs.it_333 et.sw.lg_543  mt.ro.en_422 de.hu.tr_443
  0x05003119, 0x1c292860, 0x081213ad, 0x061e1cec,   // az.fr.un_750 sw.sl.id_664  et.hu.no_643 id.ms.de_644
  0x4a001a05, 0x050701ec, 0x283f1f07, 0x216b13ee,   // tl.yo.un_330 en.it.fr_644  cy.af.sw_432 et.ceb.jw_422
  // [9920]
  0x041c2105, 0x6b293507, 0x210a4aa4, 0x19201107,   // jw.id.fi_333 zu.sl.ceb_432  yo.pt.jw_433 ro.sq.gl_432
  0x28133f0d, 0x05005317, 0x1c061e04, 0x200911a9,   // af.et.sw_554 ht.fr.un_730  ms.de.id_332 ro.pl.sq_544
  0x1e1c6ba4, 0x136b0e04, 0x1e1c06a9, 0x29230f04,   // ceb.id.ms_433 is.ceb.et_332  de.id.ms_544 lv.ca.sl_332
  0x120964ad, 0x2812350b, 0x0f08120c, 0x1e001f0c,   // lg.pl.hu_643 zu.hu.sw_542  hu.no.lv_543 cy.ms.un_530
  // [9930]
  0x643506ec, 0x2808120c, 0x132112ee, 0x1f3f020b,   // de.zu.lg_644 hu.no.sw_543  hu.jw.et_422 da.af.cy_542
  0x29090f05, 0x28001f0e, 0x060c0107, 0x1f0e0ca0,   // lv.pl.sl_333 cy.sw.un_550  en.sv.de_432 sv.is.cy_322
  0x0c0906a4, 0x16060c04, 0x063101ee, 0x0200551a,   // de.pl.sv_433 sv.de.hr_332  en.az.de_422 rw.da.un_760
  0x211c310c, 0x01060ca4, 0x0c6b0107, 0x230b05ac,   // az.id.jw_543 sv.de.en_433  en.ceb.sv_432 fr.es.ca_632
  // [9940]
  0x2d0d0702, 0x3b130311, 0x120b350c, 0x290a01a4,   // it.cs.sk_222 nl.et.so_653  zu.es.hu_543 en.pt.sl_433
  0x0a070811, 0x1c033bee, 0x1e1b1a08, 0x051f01af,   // uk.bg.mk_653 so.nl.id_422  tl.tr.ms_443 en.cy.fr_655
  0x681b1a55, 0x270401a9, 0x6b1b015a, 0x1a6b1b0d,   // tl.tr.ig_442 en.fi.gd_544  en.tr.ceb_553 tr.ceb.tl_554
  0x130e3fa0, 0x032a2da0, 0x211c1b07, 0x13102807,   // af.is.et_322 sk.mt.nl_322  tr.id.jw_432 sw.lt.et_432
  // [9950]
  0x206b1a55, 0x07183fa0, 0x06000f08, 0x01001313,   // tl.ceb.sq_442 af.ga.it_322  lv.de.un_430 et.en.un_650
  0x230b19ad, 0x554a35a0, 0x200f2a02, 0x16000b07,   // gl.es.ca_643 zu.yo.rw_322  mt.lv.sq_222 es.hr.un_420
  0x07052107, 0x1a1f0111, 0x2a002014, 0x53041e0c,   // jw.fr.it_432 en.cy.tl_653  sq.mt.un_660 ms.fi.ht_543
  0x0c0106a9, 0x1b1c0107, 0x185323a7, 0x0e00011a,   // de.en.sv_544 en.id.tr_432  ca.ht.ga_532 en.is.un_760
  // [9960]
  0x071f1804, 0x041918ad, 0x1a011f0d, 0x1a6b0407,   // ga.cy.it_332 ga.gl.fi_643  cy.en.tl_554 fi.ceb.tl_432
  0x211228a4, 0x311c01a0, 0x21201307, 0x05000202,   // sw.hu.jw_433 en.id.az_322  et.sq.jw_432 da.fr.un_220
  0x054a6b0c, 0x04002312, 0x1b003209, 0x55002004,   // ceb.yo.fr_543 ca.fi.un_640  bs.tr.un_440 sq.rw.un_320
  0x5207210c, 0x06553502, 0x283b1ea4, 0x190b1105,   // jw.it.ha_543 zu.rw.de_222  ms.so.sw_433 ro.es.gl_333
  // [9970]
  0x53680707, 0x29181eee, 0x29283512, 0x051c0e02,   // it.ig.ht_432 ms.ga.sl_422  zu.sw.sl_654 is.id.fr_222
  0x641a53ad, 0x190b120c, 0x0e0205a0, 0x3b1e280c,   // ht.tl.lg_643 hu.es.gl_543  fr.da.is_322 sw.ms.so_543
  0x12230507, 0x0b001812, 0x19120e55, 0x12083507,   // fr.ca.hu_432 ga.es.un_640  is.hu.gl_442 zu.no.hu_432
  0x0a124aa7, 0x2b00680e, 0x2d0d27af, 0x0d2011ee,   // yo.hu.pt_532 ig.vi.un_550  gd.cs.sk_655 ro.sq.cs_422
  // [9980]
  0x0b190aad, 0x0b0a0714, 0x043f08a0, 0x09190b0c,   // pt.gl.es_643 it.pt.es_666  no.af.fi_322 es.gl.pl_543
  0x25006813, 0x2d001a05, 0x116807ad, 0x35201aa4,   // ig.eu.un_650 tl.sk.un_330  it.ig.ro_643 tl.sq.zu_433
  0x4a002a0d, 0x09001334, 0x0b290d0c, 0x10293507,   // mt.yo.un_540 bh.hi.un_A80  cs.sl.es_543 zu.sl.lt_432
  0x0b0a0c11, 0x2d0d1014, 0x232d0deb, 0x3b526408,   // sv.pt.es_653 lt.cs.sk_666  cs.sk.ca_662 lg.ha.so_443
  // [9990]
  0x06001a07, 0x06001319, 0x16005512, 0x2900090e,   // tl.de.un_420 et.de.un_750  rw.hr.un_640 pl.sl.un_550
  0x0911200c, 0x0a0d2dec, 0x3f0602a7, 0x17292aa4,   // sq.ro.pl_543 sk.cs.pt_644  da.de.af_532 mt.sl.sr_433
  0x2d29200d, 0x02001213, 0x07283513, 0x23111905,   // sq.sl.sk_554 hu.da.un_650  zu.sw.it_665 gl.ro.ca_333
  0x3f351c04, 0x3f112514, 0x53521ea0, 0x2b3f10ec,   // id.zu.af_332 eu.ro.af_666  ms.ha.ht_322 lt.af.vi_644
  // [99a0]
  0x1b07120c, 0x160c0eee, 0x23271f0c, 0x060f1fa7,   // hu.it.tr_543 is.sv.hr_422  cy.gd.ca_543 cy.lv.de_532
  0x3b521a0c, 0x10081304, 0x28000d04, 0x3b281a0c,   // tl.ha.so_543 et.no.lt_332  cs.sw.un_320 tl.sw.so_543
  0x120a4aaf, 0x28131aa0, 0x3b2301a0, 0x21553ba9,   // yo.pt.hu_655 tl.et.sw_322  en.ca.so_322 so.rw.jw_544
  0x0a11170e, 0x553b1aad, 0x3b312008, 0x2055310c,   // sr.ro.mk_555 tl.so.rw_643  sq.az.so_443 az.rw.sq_543
  // [99b0]
  0x181f0807, 0x04000214, 0x10202807, 0x4a202955,   // no.cy.ga_432 da.fi.un_660  sw.sq.lt_432 sl.sq.yo_442
  0x27002312, 0x29200f04, 0x1a043b05, 0x3b521b0c,   // ca.gd.un_640 lv.sq.sl_332  so.fi.tl_333 tr.ha.so_543
  0x211a3b07, 0x0a120ea0, 0x0e180a04, 0x0e1321a7,   // so.tl.jw_432 is.hu.pt_322  pt.ga.is_332 jw.et.is_532
  0x6e2804a0, 0x041028a4, 0x0a250b07, 0x0f0413af,   // fi.sw.hmn_322 sw.lt.fi_433  es.eu.pt_432 et.fi.lv_655
  // [99c0]
  0x046b2804, 0x060a0308, 0x2a003507, 0x53272b07,   // sw.ceb.fi_332 nl.pt.de_443  zu.mt.un_420 vi.gd.ht_432
  0x23060704, 0x29001122, 0x0a000e0d, 0x1e050807,   // it.de.ca_332 ro.sl.un_870  is.pt.un_540 no.fr.ms_432
  0x55001e13, 0x03112d08, 0x122003ee, 0x283f0a12,   // ms.rw.un_650 sk.ro.nl_443  nl.sq.hu_422 pt.af.sw_654
  0x07011fa0, 0x042523af, 0x0d552d0c, 0x1f123fa7,   // cy.en.it_322 ca.eu.fi_655  sk.rw.cs_543 af.hu.cy_532
  // [99d0]
  0x32006807, 0x0f00680c, 0x6e683bee, 0x6e003b20,   // ig.bs.un_420 ig.lv.un_530  so.ig.hmn_422 so.hmn.un_850
  0x29000d22, 0x3b001302, 0x1a6b4a0c, 0x186e64a4,   // cs.sl.un_870 et.so.un_220  yo.ceb.tl_543 lg.hmn.ga_433
  0x0b4a05af, 0x1a013b07, 0x103568ad, 0x0c2d3ba0,   // fr.yo.es_655 so.en.tl_432  ig.zu.lt_643 so.sk.sv_322
  0x23214a05, 0x2b136ba0, 0x2d0d12b2, 0x21002821,   // yo.jw.ca_333 ceb.et.vi_322  hu.cs.sk_732 sw.jw.un_860
  // [99e0]
  0x12182daf, 0x682917a4, 0x1c2d07a6, 0x25351905,   // sk.ga.hu_655 sr.sl.ig_433  it.sk.id_521 gl.zu.eu_333
  0x2d0d23af, 0x133b3fa4, 0x0235680c, 0x293b6e07,   // ca.cs.sk_655 af.so.et_433  ig.zu.da_543 hmn.so.sl_432
  0x2d6e29af, 0x1e000108, 0x6b2318a4, 0x030b050c,   // sl.hmn.sk_655 en.ms.un_430  ga.ca.ceb_433 fr.es.nl_543
  0x0d001f0c, 0x20006e0b, 0x022d0907, 0x16006e08,   // cy.cs.un_530 hmn.sq.un_520  pl.sk.da_432 hmn.hr.un_430
  // [99f0]
  0x31181b14, 0x53210a05, 0x03061812, 0x32101655,   // tr.ga.az_666 pt.jw.ht_333  ga.de.nl_654 hr.lt.bs_442
  0x1b2531a4, 0x64551ea0, 0x082835ee, 0x64281902,   // az.eu.tr_433 ms.rw.lg_322  zu.sw.no_422 gl.sw.lg_222
  0x1b00230e, 0x020f0804, 0x321706a0, 0x2b6b1c11,   // ca.tr.un_550 no.lv.da_332  de.sr.bs_322 id.ceb.vi_653
  0x27002a02, 0x3b355555, 0x121b1002, 0x19121307,   // mt.gd.un_220 rw.zu.so_442  lt.tr.hu_222 et.hu.gl_432
  // [9a00]
  0x6b001c05, 0x2d120513, 0x350f1255, 0x191a5511,   // id.ceb.un_330 fr.hu.sk_665  hu.lv.zu_442 rw.tl.gl_653
  0x6b01060c, 0x52126b02, 0x08060c55, 0x200f5505,   // de.en.ceb_543 ceb.hu.ha_222  sv.de.no_442 rw.lv.sq_333
  0x10294aec, 0x1708020d, 0x201217a0, 0x551f4a0c,   // yo.sl.lt_644 da.no.sr_554  sr.hu.sq_322 yo.cy.rw_543
  0x2d551908, 0x16000d0c, 0x2a23060c, 0x050d12ec,   // gl.rw.sk_443 cs.hr.un_530  de.ca.mt_543 hu.cs.fr_644
  // [9a10]
  0x4a051905, 0x070105ee, 0x1f071104, 0x3b1055a4,   // gl.fr.yo_333 fr.en.it_422  ro.it.cy_332 rw.lt.so_433
  0x1b000521, 0x550a07a4, 0x19002004, 0x250602af,   // fr.tr.un_860 it.pt.rw_433  sq.gl.un_320 da.de.eu_655
  0x120e180c, 0x20521aa0, 0x0b004a02, 0x060313ee,   // ga.is.hu_543 tl.ha.sq_322  yo.es.un_220 et.nl.de_422
  0x130801a0, 0x3b001907, 0x181301a7, 0x2a0c060c,   // en.no.et_322 gl.so.un_420  en.et.ga_532 de.sv.mt_543
  // [9a20]
  0x07191aa4, 0x3500130d, 0x0c0628a0, 0x1a1011a4,   // tl.gl.it_433 et.zu.un_540  sw.de.sv_322 ro.lt.tl_433
  0x551364ec, 0x081c1e11, 0x64211ca4, 0x52131b13,   // lg.et.rw_644 ms.id.no_653  id.jw.lg_433 tr.et.ha_665
  0x131021a0, 0x16006b0c, 0x5200041a, 0x27066ea0,   // jw.lt.et_322 ceb.hr.un_530  fi.ha.un_760 hmn.de.gd_322
  0x6e005314, 0x64121fa0, 0x17066e07, 0x291a6eee,   // ht.hmn.un_660 cy.hu.lg_322  hmn.de.sr_432 hmn.tl.sl_422
  // [9a30]
  0x2a045505, 0x3f6408a4, 0x32121ca0, 0x12091812,   // rw.fi.mt_333 no.lg.af_433  id.hu.bs_322 ga.pl.hu_654
  0x3f0321a0, 0x6e120da0, 0x12182312, 0x09002008,   // jw.nl.af_322 cs.hu.hmn_322  ca.ga.hu_654 sq.pl.un_430
  0x04643507, 0x64520304, 0x53001c08, 0x111b13a4,   // zu.lg.fi_432 nl.ha.lg_332  id.ht.un_430 et.tr.ro_433
  0x0d043f04, 0x0f1123ad, 0x10251113, 0x13041a0c,   // af.fi.cs_332 ca.ro.lv_643  ro.eu.lt_665 tl.fi.et_543
  // [9a40]
  0x106b1a05, 0x132a0455, 0x043f52a4, 0x29000a08,   // tl.ceb.lt_333 fi.mt.et_442  ha.af.fi_433 pt.sl.un_430
  0x1f006e23, 0x3f0308af, 0x64033f12, 0x034a0207,   // hmn.cy.un_880 no.nl.af_655  af.nl.lg_654 da.yo.nl_432
  0x1b190aa4, 0x0d122d07, 0x0d190aa9, 0x4a006802,   // pt.gl.tr_433 sk.hu.cs_432  pt.gl.cs_544 ig.yo.un_220
  0x180a12a4, 0x25213513, 0x350321af, 0x32006b08,   // hu.pt.ga_433 zu.jw.eu_665  jw.nl.zu_655 ceb.bs.un_430
  // [9a50]
  0x130d2da0, 0x55212511, 0x06002907, 0x1e1c0605,   // sk.cs.et_322 eu.jw.rw_653  sl.de.un_420 de.id.ms_333
  0x1b21350b, 0x4a5231af, 0x28213b12, 0x276e2a07,   // zu.jw.tr_542 az.ha.yo_655  so.jw.sw_654 mt.hmn.gd_432
  0x181923a4, 0x18010505, 0x1e523107, 0x1c3b1e0d,   // ca.gl.ga_433 fr.en.ga_333  az.ha.ms_432 ms.so.id_554
  0x250c3f08, 0x0312250c, 0x1b132508, 0x5564350d,   // af.sv.eu_443 eu.hu.nl_543  eu.et.tr_443 zu.lg.rw_554
  // [9a60]
  0x1b251ea9, 0x120d060d, 0x060328a0, 0x090e0404,   // ms.eu.tr_544 de.cs.hu_554  sw.nl.de_322 fi.is.pl_332
  0x1e1a1c11, 0x0e082108, 0x04252108, 0x0c210812,   // id.tl.ms_653 jw.no.is_443  jw.eu.fi_443 no.jw.sv_654
  0x181b35ad, 0x271f01a9, 0x52003119, 0x0c530e13,   // zu.tr.ga_643 en.cy.gd_544  az.ha.un_750 is.ht.sv_665
  0x211c6804, 0x523b35af, 0x29001712, 0x272001a9,   // ig.id.jw_332 zu.so.ha_655  sr.sl.un_640 en.sq.gd_544
  // [9a70]
  0x271918ee, 0x06081355, 0x026b1a0d, 0x08003f1a,   // ga.gl.gd_422 et.no.de_442  tl.ceb.da_554 af.no.un_760
  0x1100181a, 0x20110fa4, 0x310f1baf, 0x6b1b28ac,   // ga.ro.un_760 lv.ro.sq_433  tr.lv.az_655 sw.tr.ceb_632
  0x132928a4, 0x08230611, 0x3b1f5202, 0x6b3b1307,   // sw.sl.et_433 de.ca.no_653  ha.cy.so_222 et.so.ceb_432
  0x642718ec, 0x4a132507, 0x1900311b, 0x313b5207,   // ga.gd.lg_644 eu.et.yo_432  az.gl.un_770 ha.so.az_432
  // [9a80]
  0x6b002508, 0x0d1c130d, 0x1f3b52a0, 0x09135555,   // eu.ceb.un_430 bh.mr.ne_554  ha.so.cy_322 rw.et.pl_442
  0x06000821, 0x52000f1a, 0x01072d05, 0x10002902,   // no.de.un_860 lv.ha.un_760  sk.it.en_333 sl.lt.un_220
  0x124a1308, 0x23000819, 0x230d2da9, 0x28003b02,   // et.yo.hu_443 no.ca.un_750  sk.cs.ca_544 so.sw.un_220
  0x251b3104, 0x12046baf, 0x02180607, 0x1f030e04,   // az.tr.eu_332 ceb.fi.hu_655  de.ga.da_432 is.nl.cy_332
  // [9a90]
  0x55353b09, 0x190b10ee, 0x1208025a, 0x4a213b07,   // so.zu.rw_444 lt.es.gl_422  da.no.hu_553 so.jw.yo_432
  0x25190aa4, 0x0c1a0fad, 0x09531107, 0x0e190b10,   // pt.gl.eu_433 lv.tl.sv_643  ro.ht.pl_432 es.gl.is_642
  0x5300030d, 0x080218ee, 0x031c08ad, 0x06130412,   // nl.ht.un_540 ga.da.no_422  no.id.nl_643 fi.et.de_654
  0x3f130302, 0x1b123107, 0x100a04ee, 0x060c010c,   // nl.et.af_222 az.hu.tr_432  fi.pt.lt_422 en.sv.de_543
  // [9aa0]
  0x19180da7, 0x2d0d0cee, 0x01133b07, 0x64531a02,   // cs.ga.gl_532 sv.cs.sk_422  so.et.en_432 tl.ht.lg_222
  0x12041004, 0x64001308, 0x1a233508, 0x0c0601a6,   // lt.fi.hu_332 et.lg.un_430  zu.ca.tl_443 en.de.sv_521
  0x013f06a0, 0x180106a0, 0x1c1309a7, 0x0d1c09a6,   // de.af.en_322 de.en.ga_322  hi.bh.mr_532 hi.mr.ne_521
  0x041110af, 0x0c00010d, 0x1f354a05, 0x03013ba0,   // be.ro.ru_655 en.sv.un_540  yo.zu.cy_333 so.en.nl_322
  // [9ab0]
  0x35686411, 0x0e0f1011, 0x2168200c, 0x0c202507,   // lg.ig.zu_653 lt.lv.is_653  sq.ig.jw_543 eu.sq.sv_432
  0x6800642a, 0x0e03100c, 0x35644aa4, 0x35010607,   // lg.ig.un_970 lt.nl.is_543  yo.lg.zu_433 de.en.zu_432
  0x0b191812, 0x643568af, 0x0e002d13, 0x3f036e08,   // ga.gl.es_654 ig.zu.lg_655  sk.is.un_650 hmn.nl.af_443
  0x180e27a0, 0x136b1a07, 0x0f2511a7, 0x085528ee,   // gd.is.ga_322 tl.ceb.et_432  ro.eu.lv_532 sw.rw.no_422
  // [9ac0]
  0x1e026407, 0x1f131aee, 0x061b310b, 0x3b0b0da0,   // lg.da.ms_432 tl.et.cy_422  az.tr.de_542 cs.es.so_322
  0x3b0d52a0, 0x550664a0, 0x120635a4, 0x06093f04,   // ha.cs.so_322 lg.de.rw_322  zu.de.hu_433 af.pl.de_332
  0x291135a9, 0x4a6b0704, 0x35282507, 0x25050d07,   // zu.ro.sl_544 it.ceb.yo_332  eu.sw.zu_432 cs.fr.eu_432
  0x21131105, 0x28352008, 0x04080305, 0x041a6b0c,   // ro.et.jw_333 sq.zu.sw_443  nl.no.fi_333 ceb.tl.fi_543
  // [9ad0]
  0x284a350c, 0x5300350d, 0x13211aad, 0x29552808,   // zu.yo.sw_543 zu.ht.un_540  tl.jw.et_643 sw.rw.sl_443
  0x110d55a0, 0x6b102904, 0x2a2d27ac, 0x0d253b11,   // rw.cs.ro_322 sl.lt.ceb_332  gd.sk.mt_632 so.eu.cs_653
  0x18091004, 0x350e110c, 0x4a003522, 0x3f0112a9,   // lt.pl.ga_332 ro.is.zu_543  zu.yo.un_870 hu.en.af_544
  0x350952a0, 0x0e2a080d, 0x2a070c07, 0x35115504,   // ha.pl.zu_322 no.mt.is_554  sv.it.mt_432 rw.ro.zu_332
  // [9ae0]
  0x1f283512, 0x01041007, 0x253f01a4, 0x19230aa9,   // zu.sw.cy_654 lt.fi.en_432  en.af.eu_433 pt.ca.gl_544
  0x3b003521, 0x010c1f05, 0x2821120c, 0x29001f14,   // zu.so.un_860 cy.sv.en_333  hu.jw.sw_543 cy.sl.un_660
  0x1c1b1ea0, 0x250c08a4, 0x251b1213, 0x52311b60,   // ms.tr.id_322 no.sv.eu_433  hu.tr.eu_665 tr.az.ha_664
  0x1100062b, 0x29001002, 0x2907090c, 0x0c0729a4,   // de.ro.un_980 lt.sl.un_220  pl.it.sl_543 sl.it.sv_433
  // [9af0]
  0x1b6b1a0e, 0x0e120aee, 0x090a18ec, 0x53003b07,   // tl.ceb.tr_555 pt.hu.is_422  ga.pt.pl_644 so.ht.un_420
  0x0a00121b, 0x29000a02, 0x0b230a07, 0x130e2007,   // hu.pt.un_770 pt.sl.un_220  pt.ca.es_432 sq.is.et_432
  0x3b312aac, 0x1a002b04, 0x02000122, 0x32002b08,   // mt.az.so_632 vi.tl.un_320  en.da.un_870 vi.bs.un_430
  0x11100805, 0x0a002310, 0x130611a0, 0x04000a33,   // uk.be.ro_333 ca.pt.un_620  ro.de.et_322 mk.ru.un_A70
  // [9b00]
  0x18111eee, 0x03040604, 0x2d170a04, 0x04000c02,   // ms.ro.ga_422 de.fi.nl_332  pt.sr.sk_332 sv.fi.un_220
  0x321b20a0, 0x011f0604, 0x1b082502, 0x046b1304,   // sq.tr.bs_322 de.cy.en_332  eu.no.tr_222 et.ceb.fi_332
  0x08003b02, 0x180a1902, 0x130e1ba0, 0x131b0e07,   // so.no.un_220 gl.pt.ga_222  tr.is.et_322 is.tr.et_432
  0x18001902, 0x1a640107, 0x521b3b08, 0x13040d0b,   // gl.ga.un_220 en.lg.tl_432  so.tr.ha_443 cs.fi.et_542
  // [9b10]
  0x524a68a9, 0x4a000713, 0x0f1b01a4, 0x16201104,   // ig.yo.ha_544 it.yo.un_650  en.tr.lv_433 ro.sq.hr_332
  0x0c001b14, 0x08311bad, 0x02005204, 0x18282b11,   // tr.sv.un_660 tr.az.no_643  ha.da.un_320 vi.sw.ga_653
  0x21190bad, 0x1200200c, 0x0413080c, 0x533b31ec,   // es.gl.jw_643 sq.hu.un_530  no.et.fi_543 az.so.ht_644
  0x25000f21, 0x2a6b13a9, 0x10531ca4, 0x1e1c3b04,   // lv.eu.un_860 et.ceb.mt_544  id.ht.lt_433 so.id.ms_332
  // [9b20]
  0x1a075307, 0x07004a11, 0x033f2102, 0x4a00070d,   // ht.it.tl_432 yo.it.un_630  jw.af.nl_222 it.yo.un_540
  0x52251a0d, 0x53255514, 0x1a00070d, 0x0325130c,   // tl.eu.ha_554 rw.eu.ht_666  it.tl.un_540 et.eu.nl_543
  0x52001907, 0x18315304, 0x0c082a0d, 0x03095308,   // gl.ha.un_420 ht.az.ga_332  mt.no.sv_554 ht.pl.nl_443
  0x1100031b, 0x192a0714, 0x0f212aa4, 0x1255250c,   // nl.ro.un_770 it.mt.gl_666  mt.jw.lv_433 eu.rw.hu_543
  // [9b30]
  0x101a530c, 0x04101308, 0x5228640b, 0x08020cad,   // ht.tl.lt_543 et.lt.fi_443  lg.sw.ha_542 sv.da.no_643
  0x2825135a, 0x1125130c, 0x1e251a08, 0x092d3b02,   // et.eu.sw_553 et.eu.ro_543  tl.eu.ms_443 so.sk.pl_222
  0x2535130c, 0x350f130c, 0x1b01130c, 0x04133205,   // et.zu.eu_543 et.lv.zu_543  et.en.tr_543 bs.et.fi_333
  0x0e5513ee, 0x07003507, 0x0b000f0e, 0x13350ead,   // et.rw.is_422 zu.it.un_420  lv.es.un_550 is.zu.et_643
  // [9b40]
  0x12182dad, 0x061803a0, 0x1b313b0c, 0x0b0105af,   // sk.ga.hu_643 nl.ga.de_322  so.az.tr_543 fr.en.es_655
  0x28351b0c, 0x192311ee, 0x286435ee, 0x04132105,   // tr.zu.sw_543 ro.ca.gl_422  zu.lg.sw_422 jw.et.fi_333
  0x10040aa7, 0x043513a4, 0x040d11ee, 0x28213b07,   // mk.ru.be_532 et.zu.fi_433  ro.cs.fi_422 so.jw.sw_432
  0x010a2b04, 0x32126e0c, 0x2b0b27a0, 0x0900180c,   // vi.pt.en_332 hmn.hu.bs_543  gd.es.vi_322 ga.pl.un_530
  // [9b50]
  0x290d2da0, 0x166e2912, 0x256409a4, 0x53006e22,   // sk.cs.sl_322 sl.hmn.hr_654  pl.lg.eu_433 hmn.ht.un_870
  0x0a1b530c, 0x28120aa0, 0x28641f0c, 0x0b000808,   // ht.tr.pt_543 pt.hu.sw_322  cy.lg.sw_543 no.es.un_430
  0x6e001e0d, 0x11000b0c, 0x4a53310c, 0x12206eec,   // ms.hmn.un_540 es.ro.un_530  az.ht.yo_543 hmn.sq.hu_644
  0x1b0604ad, 0x08005507, 0x0c18275a, 0x1c4a53a0,   // fi.de.tr_643 rw.no.un_420  gd.ga.sv_553 ht.yo.id_322
  // [9b60]
  0x070a1011, 0x29002023, 0x6e00532c, 0x02292da9,   // be.mk.bg_653 sq.sl.un_880  ht.hmn.un_990 sk.sl.da_544
  0x3f4a0707, 0x0e321713, 0x040e130c, 0x192021a0,   // it.yo.af_432 sr.bs.is_665  et.is.fi_543 jw.sq.gl_322
  0x020c3107, 0x1217290c, 0x13040660, 0x524a5555,   // az.sv.da_432 sl.sr.hu_543  de.fi.et_664 rw.yo.ha_442
  0x112805a7, 0x18252804, 0x283b1855, 0x051103a0,   // fr.sw.ro_532 sw.eu.ga_332  ga.so.sw_442 nl.ro.fr_322
  // [9b70]
  0x09006e2c, 0x06046411, 0x551108af, 0x04020811,   // hmn.pl.un_990 lg.fi.de_653  no.ro.rw_655 no.da.fi_653
  0x010c10a7, 0x17002a13, 0x2a640412, 0x131204ec,   // lt.sv.en_532 mt.sr.un_650  fi.lg.mt_654 fi.hu.et_644
  0x01211ba7, 0x2a070107, 0x2000131a, 0x2b27180e,   // tr.jw.en_532 en.it.mt_432  et.sq.un_760 ga.gd.vi_555
  0x6b060807, 0x080220a0, 0x3f0212a0, 0x07045205,   // no.de.ceb_432 sq.da.no_322  hu.da.af_322 ha.fi.it_333
  // [9b80]
  0x1c2b21a0, 0x071301ee, 0x13042aec, 0x1b133507,   // jw.vi.id_322 en.et.it_422  mt.fi.et_644 zu.et.tr_432
  0x1300520c, 0x0b0123a0, 0x640452ad, 0x2a001b08,   // ha.et.un_530 ca.en.es_322  ha.fi.lg_643 tr.mt.un_430
  0x1202080b, 0x31072a55, 0x200408a0, 0x64050702,   // no.da.hu_542 mt.it.az_442  no.fi.sq_322 it.fr.lg_222
  0x2d04290b, 0x04080aee, 0x02050702, 0x29205504,   // sl.fi.sk_542 mk.uk.ru_422  it.fr.da_222 rw.sq.sl_332
  // [9b90]
  0x4a6b1a08, 0x130f6b08, 0x25033fa9, 0x042012a7,   // tl.ceb.yo_443 ceb.lv.et_443  af.nl.eu_544 hu.sq.fi_532
  0x0b1a6bee, 0x0e4a12b6, 0x130c0255, 0x31201b0c,   // ceb.tl.es_422 hu.yo.is_766  da.sv.et_442 tr.sq.az_543
  0x130f010c, 0x2b6b01ad, 0x6e3b060c, 0x6b0c0455,   // en.lv.et_543 en.ceb.vi_643  de.so.hmn_543 fi.sv.ceb_442
  0x6e001c0d, 0x1f006e21, 0x100807a0, 0x320d2955,   // id.hmn.un_540 hmn.cy.un_860  bg.uk.be_322 sl.cs.bs_442
  // [9ba0]
  0x2513020c, 0x1f0e180e, 0x011f6ea7, 0x520f06af,   // da.et.eu_543 ga.is.cy_555  hmn.cy.en_532 de.lv.ha_655
  0x130e0caf, 0x07002907, 0x64552802, 0x20230509,   // sv.is.et_655 sl.it.un_420  sw.rw.lg_222 fr.ca.sq_444
  0x1e006e05, 0x203f10a0, 0x01006808, 0x53133112,   // hmn.ms.un_330 lt.af.sq_322  ig.en.un_430 az.et.ht_654
  0x161e6ea7, 0x23130960, 0x0c136ea7, 0x06640904,   // hmn.ms.hr_532 pl.et.ca_664  hmn.et.sv_532 pl.lg.de_332
  // [9bb0]
  0x23001021, 0x53050eaf, 0x1a5202a4, 0x4a08020d,   // lt.ca.un_860 is.fr.ht_655  da.ha.tl_433 da.no.yo_554
  0x03643fa4, 0x18290111, 0x3f2903a4, 0x1e1c35a4,   // af.lg.nl_433 en.sl.ga_653  nl.sl.af_433 zu.id.ms_433
  0x080e6b02, 0x0928550c, 0x122164a0, 0x320e17a9,   // ceb.is.no_222 rw.sw.pl_543  lg.jw.hu_322 sr.is.bs_544
  0x4a086ba9, 0x6e003b12, 0x060511ee, 0x35000f0e,   // ceb.no.yo_544 so.hmn.un_640  ro.fr.de_422 lv.zu.un_550
  // [9bc0]
  0x29002121, 0x024a6bee, 0x1a206e07, 0x09005502,   // jw.sl.un_860 ceb.yo.da_422  hmn.sq.tl_432 rw.pl.un_220
  0x12060a13, 0x3b1e2104, 0x1b293202, 0x17000404,   // pt.de.hu_665 jw.ms.so_332  bs.sl.tr_222 ru.sr.un_320
  0x070b0a05, 0x522d5508, 0x01033f0e, 0x030c11a4,   // pt.es.it_333 rw.sk.ha_443  af.nl.en_555 ro.sv.nl_433
  0x55641b55, 0x29550c04, 0x0c0306a0, 0x060e1ca0,   // tr.lg.rw_442 sv.rw.sl_332  de.nl.sv_322 id.is.de_322
  // [9bd0]
  0x286452a4, 0x3b5221a0, 0x29521ea0, 0x29002105,   // ha.lg.sw_433 jw.ha.so_322  ms.ha.sl_322 jw.sl.un_330
  0x06291eee, 0x21291711, 0x52552855, 0x0100180e,   // ms.sl.de_422 sr.sl.jw_653  sw.rw.ha_442 ga.en.un_550
  0x556452a7, 0x211e5255, 0x55062805, 0x060312ee,   // ha.lg.rw_532 ha.ms.jw_442  sw.de.rw_333 hu.nl.de_422
  0x3f271a05, 0x2d0d21ec, 0x21281fa4, 0x64520909,   // tl.gd.af_333 jw.cs.sk_644  cy.sw.jw_433 pl.ha.lg_444
  // [9be0]
  0x1c005221, 0x5500170e, 0x12190b5a, 0x2a1e28ac,   // ha.id.un_860 sr.rw.un_550  es.gl.hu_553 sw.ms.mt_632
  0x1a0e07a7, 0x2135520c, 0x0d2d2110, 0x09553509,   // it.is.tl_532 ha.zu.jw_543  jw.sk.cs_642 zu.rw.pl_444
  0x550719a6, 0x0d2d2111, 0x2d002119, 0x1200070e,   // gl.it.rw_521 jw.sk.cs_653  jw.sk.un_750 it.hu.un_550
  0x071a0caf, 0x211b0b12, 0x1e111b07, 0x531b2aee,   // sv.tl.it_655 es.tr.jw_654  tr.ro.ms_432 mt.tr.ht_422
  // [9bf0]
  0x25186808, 0x083b0e04, 0x311b2505, 0x033f1304,   // ig.ga.eu_443 is.so.no_332  eu.tr.az_333 et.af.nl_332
  0x091b53ad, 0x31001118, 0x53000a21, 0x1a284aa6,   // ht.tr.pl_643 ro.az.un_740  pt.ht.un_860 yo.sw.tl_521
  0x311b0aac, 0x110c03ec, 0x1a281012, 0x2d0d4aee,   // pt.tr.az_632 nl.sv.ro_644  lt.sw.tl_654 yo.cs.sk_422
  0x0a062512, 0x6e356407, 0x53003104, 0x28062a07,   // eu.de.pt_654 lg.zu.hmn_432  az.ht.un_320 mt.de.sw_432

  // [9c00]
  0x094a6404, 0x683f1307, 0x3b000223, 0x230d2da7,   // lg.yo.pl_332 et.af.ig_432  da.so.un_880 sk.cs.ca_532
  0x215352ee, 0x6b1a5505, 0x4a0f10a4, 0x2a3b2dac,   // ha.ht.jw_422 rw.tl.ceb_333  lt.lv.yo_433 sk.so.mt_632
  0x09003b12, 0x5300641a, 0x6b124a04, 0x01122a07,   // so.pl.un_640 lg.ht.un_760  yo.hu.ceb_332 mt.hu.en_432
  0x642a3512, 0x6435210d, 0x083b0caf, 0x081f310c,   // zu.mt.lg_654 jw.zu.lg_554  sv.so.no_655 az.cy.no_543
  // [9c10]
  0x28003521, 0x19200b5a, 0x35212808, 0x4a18270c,   // zu.sw.un_860 es.sq.gl_553  sw.jw.zu_443 gd.ga.yo_543
  0x0c1c530c, 0x3f1e64a9, 0x0802190c, 0x271f0807,   // ht.id.sv_543 lg.ms.af_544  gl.da.no_543 no.cy.gd_432
  0x27000502, 0x552a530c, 0x1e001308, 0x130904a0,   // fr.gd.un_220 ht.mt.rw_543  et.ms.un_430 fi.pl.et_322
  0x160b1104, 0x351e64a9, 0x1a000705, 0x521a250c,   // ro.es.hr_332 lg.ms.zu_544  it.tl.un_330 eu.tl.ha_543
  // [9c20]
  0x2d320aa0, 0x12001829, 0x311b13a4, 0x0b0a2daf,   // pt.bs.sk_322 ar.ur.un_960  et.tr.az_433 sk.pt.es_655
  0x0b2507a0, 0x12043b0b, 0x0b2d0a07, 0x55032a07,   // it.eu.es_322 so.fi.hu_542  pt.sk.es_432 mt.nl.rw_432
  0x316428a6, 0x07235205, 0x31272a08, 0x1a1225a0,   // sw.lg.az_521 ha.ca.it_333  mt.gd.az_443 eu.hu.tl_322
  0x3f0f0da4, 0x01072a11, 0x2810110d, 0x312029a0,   // cs.lv.af_433 mt.it.en_653  ro.lt.sw_554 sl.sq.az_322
  // [9c30]
  0x522a6808, 0x1704075a, 0x4a122d07, 0x273b06a4,   // ig.mt.ha_443 bg.ru.sr_553  sk.hu.yo_432 de.so.gd_433
  0x3f2d0da4, 0x6409355a, 0x4a523b5a, 0x23003b11,   // cs.sk.af_433 zu.pl.lg_553  so.ha.yo_553 so.ca.un_630
  0x250411af, 0x556453a4, 0x12131bee, 0x3b252a0c,   // ro.fi.eu_655 ht.lg.rw_433  tr.et.hu_422 mt.eu.so_543
  0x05000f36, 0x32162d0c, 0x53001b1b, 0x0d0a0b60,   // lv.fr.un_AA0 sk.hr.bs_543  tr.ht.un_770 es.pt.cs_664
  // [9c40]
  0x3b060112, 0x18002a0d, 0x0f2910a9, 0x536b1107,   // en.de.so_654 mt.ga.un_540  lt.sl.lv_544 ro.ceb.ht_432
  0x532a6404, 0x010511af, 0x1e1c0e0e, 0x28003b05,   // lg.mt.ht_332 ro.fr.en_655  is.id.ms_555 so.sw.un_330
  0x0e002d18, 0x2a020812, 0x20040607, 0x31190a0c,   // sk.is.un_740 no.da.mt_654  de.fi.sq_432 pt.gl.az_543
  0x080c23a7, 0x02040804, 0x2b002313, 0x53002a02,   // ca.sv.no_532 no.fi.da_332  ca.vi.un_650 mt.ht.un_220
  // [9c50]
  0x1b080214, 0x072d0a55, 0x2a0c020d, 0x0c0801a4,   // da.no.tr_666 pt.sk.it_442  da.sv.mt_554 en.no.sv_433
  0x250c2aec, 0x270511ad, 0x010a1f0c, 0x53290c04,   // mt.sv.eu_644 ro.fr.gd_643  cy.pt.en_543 sv.sl.ht_332
  0x0220080d, 0x230208ee, 0x02060804, 0x1a000307,   // no.sq.da_554 no.da.ca_422  no.de.da_332 nl.tl.un_420
  0x02311bad, 0x08071b07, 0x04212304, 0x032305a4,   // tr.az.da_643 tr.it.no_432  ca.jw.fi_332 fr.ca.nl_433
  // [9c60]
  0x0c001802, 0x0c291f04, 0x07001f1a, 0x01080260,   // ga.sv.un_220 cy.sl.sv_332  cy.it.un_760 da.no.en_664
  0x12022004, 0x52000607, 0x0d131c04, 0x100a11ee,   // sq.da.hu_332 de.ha.un_420  mr.bh.ne_332 ro.mk.be_422
  0x293f53ee, 0x1b211ea4, 0x6b1f0507, 0x311e1bee,   // ht.af.sl_422 ms.jw.tr_433  fr.cy.ceb_432 tr.ms.az_422
  0x3b1a55a0, 0x0b23180e, 0x64683504, 0x03000a04,   // rw.tl.so_322 ga.ca.es_555  zu.ig.lg_332 pt.nl.un_320
  // [9c70]
  0x35001b02, 0x6b2a18a4, 0x6b1935ee, 0x521e3b0c,   // tr.zu.un_220 ga.mt.ceb_433  zu.gl.ceb_422 so.ms.ha_543
  0x352864af, 0x32171ea4, 0x290c090c, 0x3b311ba7,   // lg.sw.zu_655 ms.sr.bs_433  pl.sv.sl_543 tr.az.so_532
  0x273b250c, 0x55003108, 0x11190ba4, 0x3f3b010b,   // eu.so.gd_543 az.rw.un_430  es.gl.ro_433 en.so.af_542
  0x290207ee, 0x07063b07, 0x2d003f04, 0x25060fa0,   // it.da.sl_422 so.de.it_432  af.sk.un_320 lv.de.eu_322
  // [9c80]
  0x31523ba4, 0x3f3b01a9, 0x0c0803ec, 0x3b271f12,   // so.ha.az_433 en.so.af_544  nl.no.sv_644 cy.gd.so_654
  0x31035512, 0x192d0d5a, 0x2a3b2112, 0x03061f07,   // rw.nl.az_654 cs.sk.gl_553  jw.so.mt_654 cy.de.nl_432
  0x28041313, 0x05032107, 0x066407a4, 0x64072aec,   // et.fi.sw_665 jw.nl.fr_432  it.lg.de_433 mt.it.lg_644
  0x23060407, 0x271f010b, 0x19252aa4, 0x03122755,   // fi.de.ca_432 en.cy.gd_542  mt.eu.gl_433 gd.hu.nl_442
  // [9c90]
  0x201068ee, 0x2135640c, 0x2012070c, 0x230a0707,   // ig.lt.sq_422 lg.zu.jw_543  it.hu.sq_543 it.pt.ca_432
  0x03001c04, 0x25001a07, 0x64073504, 0x1a685307,   // id.nl.un_320 tl.eu.un_420  zu.it.lg_332 ht.ig.tl_432
  0x23281fac, 0x08002807, 0x52071105, 0x13110507,   // cy.sw.ca_632 sw.no.un_420  ro.it.ha_333 fr.ro.et_432
  0x12072807, 0x175535a4, 0x19230707, 0x2119120c,   // sw.it.hu_432 zu.rw.sr_433  it.ca.gl_432 hu.gl.jw_543
  // [9ca0]
  0x0a005302, 0x121b0908, 0x64001b14, 0x0c023fa0,   // ht.pt.un_220 pl.tr.hu_443  tr.lg.un_660 af.da.sv_322
  0x3f03210c, 0x21171aa4, 0x6b121107, 0x210620a0,   // jw.nl.af_543 tl.sr.jw_433  ro.hu.ceb_432 sq.de.jw_322
  0x231b1108, 0x4a2852ee, 0x2953280c, 0x190b64a0,   // ro.tr.ca_443 ha.sw.yo_422  sw.ht.sl_543 lg.es.gl_322
  0x04005314, 0x1a5210ee, 0x35645304, 0x643b040d,   // ht.fi.un_660 lt.ha.tl_422  ht.lg.zu_332 fi.so.lg_554
  // [9cb0]
  0x291c210b, 0x121735a0, 0x520b3ba9, 0x08002121,   // jw.id.sl_542 zu.sr.hu_322  so.es.ha_544 jw.no.un_860
  0x1e2d6411, 0x53002a0c, 0x043b6404, 0x07022da0,   // lg.sk.ms_653 mt.ht.un_530  lg.so.fi_332 sk.da.it_322
  0x0e0c0404, 0x03006418, 0x0a173507, 0x1e1c5209,   // fi.sv.is_332 lg.nl.un_740  zu.sr.pt_432 ha.id.ms_444
  0x1e1c5205, 0x120c0e55, 0x211628ee, 0x29000b02,   // ha.id.ms_333 is.sv.hu_442  sw.hr.jw_422 es.sl.un_220
  // [9cc0]
  0x53280307, 0x0a6b2da4, 0x133b0407, 0x120410ad,   // nl.sw.ht_432 sk.ceb.pt_433  fi.so.et_432 lt.fi.hu_643
  0x1c251e60, 0x2d000f0e, 0x53002016, 0x136b0412,   // ms.eu.id_664 lv.sk.un_550  sq.ht.un_720 fi.ceb.et_654
  0x203f040d, 0x01033faf, 0x4a030c0b, 0x08131a0c,   // fi.af.sq_554 af.nl.en_655  sv.nl.yo_542 tl.et.no_543
  0x0a4a0707, 0x0f00092b, 0x190b2502, 0x6b0a0155,   // it.yo.pt_432 pl.lv.un_980  eu.es.gl_222 en.pt.ceb_442
  // [9cd0]
  0x0c1c1e0b, 0x6b311b55, 0x6b1b35a9, 0x115228a9,   // ms.id.sv_542 tr.az.ceb_442  zu.tr.ceb_544 sw.ha.ro_544
  0x1311040e, 0x55213509, 0x13321604, 0x11182708,   // fi.ro.et_555 zu.jw.rw_444  hr.bs.et_332 gd.ga.ro_443
  0x211c29a0, 0x2a6b01ee, 0x55042a0c, 0x230b0a14,   // sl.id.jw_322 en.ceb.mt_422  mt.fi.rw_543 pt.es.ca_666
  0x2a0413af, 0x235564a9, 0x354a52ad, 0x1a3b04a0,   // et.fi.mt_655 lg.rw.ca_544  ha.yo.zu_643 fi.so.tl_322
  // [9ce0]
  0x12000e2a, 0x273f030e, 0x2835645a, 0x1821270c,   // is.hu.un_970 nl.af.gd_555  lg.zu.sw_553 gd.jw.ga_543
  0x3b00181a, 0x0d003b07, 0x1017070c, 0x1c21520c,   // ga.so.un_760 so.cs.un_420  bg.sr.be_543 ha.jw.id_543
  0x25072a0c, 0x01271802, 0x31353ba4, 0x07321709,   // mt.it.eu_543 ga.gd.en_222  so.zu.az_433 sr.bs.it_444
  0x356b28a4, 0x28551209, 0x211629a9, 0x21001e22,   // sw.ceb.zu_433 hu.rw.sw_444  sl.hr.jw_544 ms.jw.un_870
  // [9cf0]
  0x08202a04, 0x13042805, 0x3f002722, 0x0a1c1eec,   // mt.sq.no_332 sw.fi.et_333  gd.af.un_870 ms.id.pt_644
  0x06133b0b, 0x1e3b10a4, 0x044a1ca4, 0x20312805,   // so.et.de_542 lt.so.ms_433  id.yo.fi_433 sw.az.sq_333
  0x1b190b13, 0x0d0f28ee, 0x171e1c5a, 0x07041f12,   // es.gl.tr_665 sw.lv.cs_422  id.ms.sr_553 cy.fi.it_654
  0x17293b04, 0x171b290c, 0x132104a0, 0x09033f0d,   // so.sl.sr_332 sl.tr.sr_543  fi.jw.et_322 af.nl.pl_554
  // [9d00]
  0x251e3b07, 0x28521aa9, 0x033f64a0, 0x290813ee,   // so.ms.eu_432 tl.ha.sw_544  lg.af.nl_322 et.no.sl_422
  0x0b130807, 0x3b0f25a9, 0x0f0b04ee, 0x1c000604,   // no.et.es_432 eu.lv.so_544  fi.es.lv_422 de.id.un_320
  0x1b321604, 0x193b25ec, 0x0c0813ee, 0x130408ad,   // hr.bs.tr_332 eu.so.gl_644  et.no.sv_422 no.fi.et_643
  0x0e08135a, 0x131b04ee, 0x1a0f2a0d, 0x256b1a04,   // et.no.is_553 fi.tr.et_422  mt.lv.tl_554 tl.ceb.eu_332
  // [9d10]
  0x2a313b11, 0x1b281ea4, 0x1b002713, 0x07000302,   // so.az.mt_653 ms.sw.tr_433  gd.tr.un_650 nl.it.un_220
  0x6b552d07, 0x31003f0d, 0x55003b13, 0x27033f08,   // sk.rw.ceb_432 af.az.un_540  so.rw.un_650 af.nl.gd_443
  0x01192102, 0x0b3568a9, 0x351a04a7, 0x68216414,   // jw.gl.en_222 ig.zu.es_544  fi.tl.zu_532 lg.jw.ig_666
  0x3b0a19af, 0x10250707, 0x053f015a, 0x23000511,   // gl.pt.so_655 it.eu.lt_432  en.af.fr_553 fr.ca.un_630
  // [9d20]
  0x3135200b, 0x0812020c, 0x040d3b0c, 0x0a015502,   // sq.zu.az_542 da.hu.no_543  so.cs.fi_543 rw.en.pt_222
  0x3b3528a0, 0x032a0412, 0x0a00530b, 0x033b6e07,   // sw.zu.so_322 fi.mt.nl_654  ht.pt.un_520 hmn.so.nl_432
  0x3f033ba4, 0x23120507, 0x6b0468a4, 0x281e3207,   // so.nl.af_433 fr.hu.ca_432  ig.fi.ceb_433 bs.ms.sw_432
  0x02090808, 0x120608a0, 0x0e005202, 0x28041302,   // no.pl.da_443 no.de.hu_322  ha.is.un_220 et.fi.sw_222
  // [9d30]
  0x043f1308, 0x28205204, 0x120413af, 0x04134aa0,   // et.af.fi_443 ha.sq.sw_332  et.fi.hu_655 yo.et.fi_322
  0x1a001e02, 0x03121107, 0x1c212708, 0x3b0108a7,   // ms.tl.un_220 ro.hu.nl_432  gd.jw.id_443 no.en.so_532
  0x252820af, 0x321b28a0, 0x68281b09, 0x0f64280d,   // sq.sw.eu_655 sw.tr.bs_322  tr.sw.ig_444 sw.lg.lv_554
  0x1e07280c, 0x531925a0, 0x04131114, 0x072531a9,   // sw.it.ms_543 eu.gl.ht_322  ro.et.fi_666 az.eu.it_544
  // [9d40]
  0x0b1905a9, 0x11313205, 0x29532104, 0x29170704,   // fr.gl.es_544 bs.az.ro_333  jw.ht.sl_332 it.sr.sl_332
  0x060a31a4, 0x280a5307, 0x20171ba4, 0x64190a09,   // az.pt.de_433 ht.pt.sw_432  tr.sr.sq_433 pt.gl.lg_444
  0x0a1b32a0, 0x53202aa9, 0x070a01a0, 0x35310f0c,   // bs.tr.pt_322 mt.sq.ht_544  en.pt.it_322 lv.az.zu_543
  0x10070f0c, 0x05136404, 0x11073155, 0x013206ee,   // lv.it.lt_543 lg.et.fr_332  az.it.ro_442 de.bs.en_422
  // [9d50]
  0x0c180607, 0x0d120607, 0x0d005302, 0x1b02080c,   // de.ga.sv_432 de.hu.cs_432  ht.cs.un_220 no.da.tr_543
  0x0a250705, 0x12190ea7, 0x130825a0, 0x1711080c,   // it.eu.pt_333 is.gl.hu_532  eu.no.et_322 uk.ro.sr_543
  0x06003209, 0x0d3f0307, 0x0a1004ad, 0x20062aac,   // bs.de.un_440 nl.af.cs_432  ru.be.mk_643 mt.de.sq_632
  0x27000612, 0x120153a0, 0x25002004, 0x01530504,   // de.gd.un_640 ht.en.hu_322  sq.eu.un_320 fr.ht.en_332
  // [9d60]
  0x016b0207, 0x2b6b31a0, 0x31001704, 0x2b003104,   // da.ceb.en_432 az.ceb.vi_322  sr.az.un_320 az.vi.un_320
  0x55050302, 0x0100530c, 0x20000502, 0x011f53a0,   // nl.fr.rw_222 ht.en.un_530  fr.sq.un_220 ht.cy.en_322
  0x160c0804, 0x3f002b04, 0x0c130602, 0x0e0c08a0,   // no.sv.hr_332 vi.af.un_320  de.et.sv_222 no.sv.is_322
  0x1f001702, 0x060f0c13, 0x311b06ee, 0x20000719,   // sr.cy.un_220 sv.lv.de_665  de.tr.az_422 it.sq.un_750
  // [9d70]
  0x11006b04, 0x040b19a0, 0x6b005512, 0x28002d04,   // ceb.ro.un_320 gl.es.fi_322  rw.ceb.un_640 sk.sw.un_320
  0x21534a08, 0x1b1c210d, 0x21101a5a, 0x311035a0,   // yo.ht.jw_443 jw.id.tr_554  tl.lt.jw_553 zu.lt.az_322
  0x0f000312, 0x21351ca7, 0x1a004a12, 0x3b25550c,   // nl.lv.un_640 id.zu.jw_532  yo.tl.un_640 rw.eu.so_543
  0x5500110e, 0x21071e0c, 0x283f1ea0, 0x3b520ea9,   // ro.rw.un_550 ms.it.jw_543  ms.af.sw_322 is.ha.so_544
  // [9d80]
  0x2d271855, 0x18001019, 0x55522da7, 0x1b55525a,   // ga.gd.sk_442 lt.ga.un_750  sk.ha.rw_532 ha.rw.tr_553
  0x1c0927a0, 0x21251a11, 0x2b1f6bac, 0x312a3bee,   // gd.pl.id_322 tl.eu.jw_653  ceb.cy.vi_632 so.mt.az_422
  0x28273502, 0x200727ad, 0x07270907, 0x0e183f07,   // zu.gd.sw_222 gd.it.sq_643  pl.gd.it_432 af.ga.is_432
  0x07112daf, 0x1a536b13, 0x061b3107, 0x01061fa9,   // sk.ro.it_655 ceb.ht.tl_665  az.tr.de_432 cy.de.en_544
  // [9d90]
  0x036e53ee, 0x27060302, 0x2a002514, 0x28006b18,   // ht.hmn.nl_422 nl.de.gd_222  eu.mt.un_660 ceb.sw.un_740
  0x10000e07, 0x134a040b, 0x3b0506ad, 0x060e3fa9,   // is.lt.un_420 fi.yo.et_542  de.fr.so_643 af.is.de_544
  0x64125204, 0x216e1ea7, 0x11202904, 0x3f030804,   // ha.hu.lg_332 ms.hmn.jw_532  sl.sq.ro_332 no.nl.af_332
  0x23120513, 0x070823a4, 0x0f082aa4, 0x083f2aa7,   // fr.hu.ca_665 ca.no.it_433  mt.no.lv_433 mt.af.no_532
  // [9da0]
  0x082b03a7, 0x3f0f0907, 0x2a0f08a4, 0x100a11a0,   // nl.vi.no_532 pl.lv.af_432  no.lv.mt_433 ro.mk.be_322
  0x06092a14, 0x0c081f0c, 0x20030f07, 0x030c2bee,   // mt.pl.de_666 cy.no.sv_543  lv.nl.sq_432 vi.sv.nl_422
  0x0f080214, 0x050119a7, 0x2b0727a0, 0x020c0fa7,   // da.no.lv_666 gl.en.fr_532  gd.it.vi_322 lv.sv.da_532
  0x0f2a2d04, 0x0e00110d, 0x1c311b07, 0x1c3b64a6,   // sk.mt.lv_332 ro.is.un_540  tr.az.id_432 lg.so.id_521
  // [9db0]
  0x16311bee, 0x28211aa0, 0x01003107, 0x062a07ac,   // tr.az.hr_422 tl.jw.sw_322  az.en.un_420 it.mt.de_632
  0x08170204, 0x3b6835a9, 0x18121904, 0x1e6e1cad,   // da.sr.no_332 zu.ig.so_544  gl.hu.ga_332 id.hmn.ms_643
  0x6e6b4a04, 0x6e1e2108, 0x0f252da4, 0x350b070b,   // yo.ceb.hmn_332 jw.ms.hmn_443  sk.eu.lv_433 it.es.zu_542
  0x023f08a9, 0x19230504, 0x1b1c1ead, 0x27005322,   // no.af.da_544 fr.ca.gl_332  ms.id.tr_643 ht.gd.un_870
  // [9dc0]
  0x3b002712, 0x29003f1a, 0x2a1827a0, 0x0e130855,   // gd.so.un_640 af.sl.un_760  gd.ga.mt_322 no.et.is_442
  0x21003f0d, 0x02060c0d, 0x285520ec, 0x181311a0,   // af.jw.un_540 sv.de.da_554  sq.rw.sw_644 ro.et.ga_322
  0x351664ec, 0x351820af, 0x642021a4, 0x53080204,   // lg.hr.zu_644 sq.ga.zu_655  jw.sq.lg_433 da.no.ht_332
  0x28165504, 0x4a0f07a4, 0x281b2905, 0x04201112,   // rw.hr.sw_332 it.lv.yo_433  sl.tr.sw_333 ro.sq.fi_654
  // [9dd0]
  0x190b0302, 0x531121a0, 0x2b031ea0, 0x112507a0,   // nl.es.gl_222 jw.ro.ht_322  ms.nl.vi_322 it.eu.ro_322
  0x0b0a2360, 0x1e006402, 0x0c130b07, 0x08131ea4,   // ca.pt.es_664 lg.ms.un_220  es.et.sv_432 ms.et.no_433
  0x2711180d, 0x2b21280b, 0x132d28a4, 0x533b11a7,   // ga.ro.gd_554 sw.jw.vi_542  sw.sk.et_433 ro.so.ht_532
  0x0b001114, 0x29130908, 0x07101fa7, 0x6b1a130e,   // ro.es.un_660 pl.et.sl_443  cy.lt.it_532 et.tl.ceb_555
  // [9de0]
  0x321609ec, 0x10001f05, 0x0d0855ec, 0x1c642107,   // pl.hr.bs_644 cy.lt.un_330  rw.no.cs_644 jw.lg.id_432
  0x10002b04, 0x12070fa7, 0x320c020c, 0x3f0c6ea4,   // vi.lt.un_320 lv.it.hu_532  da.sv.bs_543 hmn.sv.af_433
  0x02006e19, 0x6e002d1a, 0x13001007, 0x3b011aa0,   // hmn.da.un_750 sk.hmn.un_760  lt.et.un_420 tl.en.so_322
  0x1b1120ad, 0x132925a7, 0x6e00120d, 0x6b000208,   // sq.ro.tr_643 eu.sl.et_532  hu.hmn.un_540 da.ceb.un_430
  // [9df0]
  0x5500522c, 0x270208a4, 0x3f6b6eec, 0x080e02ee,   // ha.rw.un_990 no.da.gd_433  hmn.ceb.af_644 da.is.no_422
  0x1f27180d, 0x551264ec, 0x3f6e1fa9, 0x1f02030c,   // ga.gd.cy_554 lg.hu.rw_644  cy.hmn.af_544 nl.da.cy_543
  0x020c2912, 0x04003513, 0x35186b0c, 0x210468ad,   // sl.sv.da_654 zu.fi.un_650  ceb.ga.zu_543 ig.fi.jw_643
  0x036e270e, 0x04081eee, 0x096e2d11, 0x04130fad,   // gd.hmn.nl_555 ms.no.fi_422  sk.hmn.pl_653 lv.et.fi_643
  // [9e00]
  0x6b3513a4, 0x120d18ee, 0x6b100aa4, 0x021a6bad,   // et.zu.ceb_433 ga.cs.hu_422  pt.lt.ceb_433 ceb.tl.da_643
  0x126410a0, 0x53001904, 0x190b0fa9, 0x19051108,   // lt.lg.hu_322 gl.ht.un_320  lv.es.gl_544 ro.fr.gl_443
  0x060819a0, 0x10093507, 0x09000e07, 0x35001005,   // gl.no.de_322 zu.pl.lt_432  is.pl.un_420 lt.zu.un_330
  0x64033fec, 0x6b1a2aa9, 0x1c3b1ea4, 0x4a64280c,   // af.nl.lg_644 mt.tl.ceb_544  ms.so.id_433 sw.lg.yo_543
  // [9e10]
  0x10641305, 0x12211ea4, 0x0a35040d, 0x231228a0,   // et.lg.lt_333 ms.jw.hu_433  fi.zu.pt_554 sw.hu.ca_322
  0x531f35a4, 0x1c201e11, 0x551a6bee, 0x0802270d,   // zu.cy.ht_433 ms.sq.id_653  ceb.tl.rw_422 gd.da.no_554
  0x281e3b07, 0x0e071107, 0x2a6407af, 0x0f00350c,   // so.ms.sw_432 ro.it.is_432  it.lg.mt_655 zu.lv.un_530
  0x09131c08, 0x182821ad, 0x0f08130c, 0x2a271804,   // mr.bh.hi_443 jw.sw.ga_643  et.no.lv_543 ga.gd.mt_332
  // [9e20]
  0x0a0410ad, 0x25351207, 0x352b1fa0, 0x0120270c,   // be.ru.mk_643 hu.zu.eu_432  cy.vi.zu_322 gd.sq.en_543
  0x25550407, 0x13530e04, 0x11172907, 0x55002904,   // fi.rw.eu_432 is.ht.et_332  sl.sr.ro_432 sl.rw.un_320
  0x55002a0d, 0x11256b0c, 0x0a291cee, 0x28002d09,   // mt.rw.un_540 ceb.eu.ro_543  id.sl.pt_422 sk.sw.un_440
  0x351f0311, 0x1c1e6ea7, 0x05550208, 0x121355a4,   // nl.cy.zu_653 hmn.ms.id_532  da.rw.fr_443 rw.et.hu_433
  // [9e30]
  0x19236eee, 0x05321602, 0x1e1c5302, 0x10006e08,   // hmn.ca.gl_422 hr.bs.fr_222  ht.id.ms_222 hmn.lt.un_430
  0x19005308, 0x070601ad, 0x183b27a4, 0x0200200c,   // ht.gl.un_430 en.de.it_643  gd.so.ga_433 sq.da.un_530
  0x0c081213, 0x08061805, 0x322052a0, 0x0f136ead,   // hu.no.sv_665 ga.de.no_333  ha.sq.bs_322 hmn.et.lv_643
  0x12080c11, 0x061f0ea4, 0x52556bad, 0x522a285a,   // sv.no.hu_653 is.cy.de_433  ceb.rw.ha_643 sw.mt.ha_553
  // [9e40]
  0x124a530e, 0x080c1a09, 0x32173107, 0x55112aec,   // ht.yo.hu_555 tl.sv.no_444  az.sr.bs_432 mt.ro.rw_644
  0x27051807, 0x13000520, 0x526b1805, 0x3f033b04,   // ga.fr.gd_432 fr.et.un_850  ga.ceb.ha_333 so.nl.af_332
  0x11311baf, 0x080e0660, 0x52006b0e, 0x2d000604,   // tr.az.ro_655 de.is.no_664  ceb.ha.un_550 de.sk.un_320
  0x64063507, 0x28065202, 0x20211205, 0x646b3509,   // zu.de.lg_432 ha.de.sw_222  hu.jw.sq_333 zu.ceb.lg_444
  // [9e50]
  0x551718a4, 0x0c181a08, 0x2106550c, 0x080c200c,   // ga.sr.rw_433 tl.ga.sv_443  rw.de.jw_543 sq.sv.no_543
  0x132711ee, 0x02133f0c, 0x1e1c3bec, 0x06002821,   // ro.gd.et_422 af.et.da_543  so.id.ms_644 sw.de.un_860
  0x2d013b07, 0x13534aa4, 0x31102805, 0x3f005208,   // so.en.sk_432 yo.ht.et_433  sw.lt.az_333 ha.af.un_430
  0x642a68ad, 0x644a2808, 0x1f001602, 0x2500642b,   // ig.mt.lg_643 sw.yo.lg_443  hr.cy.un_220 lg.eu.un_980
  // [9e60]
  0x680e0604, 0x2a0c3bad, 0x0c003b0b, 0x04521b02,   // de.is.ig_332 so.sv.mt_643  so.sv.un_520 tr.ha.fi_222
  0x05102504, 0x1e033f07, 0x07042007, 0x25002814,   // eu.lt.fr_332 af.nl.ms_432  sq.fi.it_432 sw.eu.un_660
  0x551a3512, 0x19002d04, 0x2b206eee, 0x4a190b55,   // zu.tl.rw_654 sk.gl.un_320  hmn.sq.vi_422 es.gl.yo_442
  0x210906a7, 0x0900311a, 0x250407ad, 0x2b250407,   // de.pl.jw_532 az.pl.un_760  it.fi.eu_643 fi.eu.vi_432
  // [9e70]
  0x25002022, 0x0125200c, 0x11006b08, 0x641e1c04,   // sq.eu.un_870 sq.eu.en_543  ceb.ro.un_430 id.ms.lg_332
  0x1b002a11, 0x3f0e0214, 0x2d0d27a0, 0x19520bee,   // mt.tr.un_630 da.is.af_666  gd.cs.sk_322 es.ha.gl_422
  0x1f211c07, 0x53231807, 0x2b2718a4, 0x080219a0,   // id.jw.cy_432 ga.ca.ht_432  ga.gd.vi_433 gl.da.no_322
  0x050811a7, 0x1e061c04, 0x311b060c, 0x0d292d10,   // ro.no.fr_532 id.de.ms_332  de.tr.az_543 sk.sl.cs_642
  // [9e80]
  0x192b0aee, 0x2a123f07, 0x081213a0, 0x121c1ea4,   // pt.vi.gl_422 af.hu.mt_432  et.hu.no_322 ms.id.hu_433
  0x12001a2a, 0x080205ac, 0x0c00011a, 0x2d0e0a0b,   // tl.hu.un_970 fr.da.no_632  en.sv.un_760 pt.is.sk_542
  0x0e1a1205, 0x1c1a1e12, 0x291320ad, 0x20531212,   // hu.tl.is_333 ms.tl.id_654  sq.et.sl_643 hu.ht.sq_654
  0x2b2a3502, 0x1e000619, 0x1c0d09a6, 0x6b001313,   // zu.mt.vi_222 de.ms.un_750  hi.ne.mr_521 et.ceb.un_650
  // [9e90]
  0x6b001b12, 0x13120704, 0x29001904, 0x096b1a12,   // tr.ceb.un_640 it.hu.et_332  gl.sl.un_320 tl.ceb.pl_654
  0x16001808, 0x05070e04, 0x55293505, 0x1b190a08,   // ga.hr.un_430 is.it.fr_332  zu.sl.rw_333 pt.gl.tr_443
  0x033f1fac, 0x551f1012, 0x1f1811af, 0x080253a4,   // cy.af.nl_632 lt.cy.rw_654  ro.ga.cy_655 ht.da.no_433
  0x1f0f1112, 0x02060807, 0x3f211007, 0x55033f11,   // ro.lv.cy_654 no.de.da_432  lt.jw.af_432 af.nl.rw_653
  // [9ea0]
  0x0e00232b, 0x1f000c22, 0x04001904, 0x3f311aad,   // ca.is.un_980 sv.cy.un_870  gl.fi.un_320 tl.az.af_643
  0x2528640c, 0x6853010b, 0x090627ec, 0x11051b5a,   // lg.sw.eu_543 en.ht.ig_542  gd.de.pl_644 tr.fr.ro_553
  0x3100531b, 0x21053ba0, 0x1807110d, 0x20072313,   // ht.az.un_770 so.fr.jw_322  ro.it.ga_554 ca.it.sq_665
  0x1a252307, 0x1000282a, 0x190a29a9, 0x190b0a60,   // ca.eu.tl_432 sw.lt.un_970  sl.pt.gl_544 pt.es.gl_664
  // [9eb0]
  0x28186ba7, 0x060c27a4, 0x53041012, 0x041a3bee,   // ceb.ga.sw_532 gd.sv.de_433  lt.fi.ht_654 so.tl.fi_422
  0x1f090d0c, 0x033f04a6, 0x08252855, 0x18270608,   // cs.pl.cy_543 fi.af.nl_521  sw.eu.no_442 de.gd.ga_443
  0x1c4a210b, 0x13033f0b, 0x554a530b, 0x21091f07,   // jw.yo.id_542 af.nl.et_542  ht.yo.rw_542 cy.pl.jw_432
  0x53000a02, 0x2a1f0111, 0x091f2aa0, 0x4a1f53ee,   // pt.ht.un_220 en.cy.mt_653  mt.cy.pl_322 ht.cy.yo_422
  // [9ec0]
  0x11001b05, 0x1f00092a, 0x101629ee, 0x2a091f0c,   // tr.ro.un_330 pl.cy.un_970  sl.hr.lt_422 cy.pl.mt_543
  0x09280107, 0x53033f55, 0x06000e02, 0x070d1ba0,   // en.sw.pl_432 af.nl.ht_442  is.de.un_220 tr.cs.it_322
  0x0c130fa0, 0x10320dee, 0x052755a0, 0x1b353b07,   // lv.et.sv_322 cs.bs.lt_422  rw.gd.fr_322 so.zu.tr_432
  0x07033f0c, 0x351b3ba0, 0x55685209, 0x321f07ad,   // af.nl.it_543 so.tr.zu_322  ha.ig.rw_444 it.cy.bs_643
  // [9ed0]
  0x0b0a11ec, 0x10002a02, 0x641228a4, 0x551b3bee,   // ro.pt.es_644 mt.lt.un_220  sw.hu.lg_433 so.tr.rw_422
  0x64553ba7, 0x3b28550c, 0x1f6828ad, 0x28200407,   // so.rw.lg_532 rw.sw.so_543  sw.ig.cy_643 fi.sq.sw_432
  0x11070111, 0x0d192dee, 0x25643513, 0x64282514,   // en.it.ro_653 sk.gl.cs_422  zu.lg.eu_665 eu.sw.lg_666
  0x35284a07, 0x6b0d3ba9, 0x06040cec, 0x2a1806ee,   // yo.sw.zu_432 so.cs.ceb_544  sv.fi.de_644 de.ga.mt_422
  // [9ee0]
  0x3b1c04ad, 0x051f0713, 0x3b551a04, 0x11271808,   // fi.id.so_643 it.cy.fr_665  tl.rw.so_332 ga.gd.ro_443
  0x132811a4, 0x216b5507, 0x0a35640d, 0x6b31550c,   // ro.sw.et_433 rw.ceb.jw_432  lg.zu.pt_554 rw.az.ceb_543
  0x13000d02, 0x352a3b0c, 0x170c080e, 0x3b1a5555,   // ne.bh.un_220 so.mt.zu_543  no.sv.sr_555 rw.tl.so_442
  0x05041304, 0x211a28ee, 0x32006402, 0x0c001809,   // et.fi.fr_332 sw.tl.jw_422  lg.bs.un_220 ga.sv.un_440
  // [9ef0]
  0x251a3114, 0x041a6bee, 0x27251311, 0x19230aa7,   // az.tl.eu_666 ceb.tl.fi_422  et.eu.gd_653 pt.ca.gl_532
  0x110118a7, 0x05130808, 0x18080cad, 0x050a0ba0,   // ga.en.ro_532 no.et.fr_443  sv.no.ga_643 es.pt.fr_322
  0x131b0c0d, 0x0700200c, 0x030e0804, 0x0b006407,   // sv.tr.et_554 sq.it.un_530  no.is.nl_332 lg.es.un_420
  0x1e1c4aec, 0x311b12ec, 0x0c3564a4, 0x6e0b4aa4,   // yo.id.ms_644 hu.tr.az_644  lg.zu.sv_433 yo.es.hmn_433
  // [9f00]
  0x061b12ad, 0x080420ee, 0x18000502, 0x012a2007,   // hu.tr.de_643 sq.fi.no_422  fr.ga.un_220 sq.mt.en_432
  0x3b002d0d, 0x0f002102, 0x53311e0c, 0x0d00200c,   // sk.so.un_540 jw.lv.un_220  ms.az.ht_543 sq.cs.un_530
  0x351a2a04, 0x0b002904, 0x12321655, 0x643b6b13,   // mt.tl.zu_332 sl.es.un_320  hr.bs.hu_442 ceb.so.lg_665
  0x4a643b13, 0x290820ee, 0x1b042012, 0x08201608,   // so.lg.yo_665 sq.no.sl_422  sq.fi.tr_654 hr.sq.no_443
  // [9f10]
  0x201e0405, 0x3b2864af, 0x3f001302, 0x1a643b11,   // fi.ms.sq_333 lg.sw.so_655  et.af.un_220 so.lg.tl_653
  0x0c4a53a9, 0x092a6407, 0x52006e22, 0x21206405,   // ht.yo.sv_544 lg.mt.pl_432  hmn.ha.un_870 lg.sq.jw_333
  0x03133fa0, 0x235321a9, 0x32290d55, 0x06250c05,   // af.et.nl_322 jw.ht.ca_544  cs.sl.bs_442 sv.eu.de_333
  0x0e202a0d, 0x07000a36, 0x0e200c07, 0x0d042d0c,   // mt.sq.is_554 mk.bg.un_AA0  sv.sq.is_432 sk.fi.cs_543
  // [9f20]
  0x230701a9, 0x25311107, 0x18001708, 0x1100290d,   // en.it.ca_544 ro.az.eu_432  sr.ga.un_430 sl.ro.un_540
  0x160d29ad, 0x13002314, 0x1c2903a0, 0x52553b08,   // sl.cs.hr_643 ca.et.un_660  nl.sl.id_322 so.rw.ha_443
  0x04292da4, 0x273f53a0, 0x3b640f08, 0x3f001904,   // sk.sl.fi_433 ht.af.gd_322  lv.lg.so_443 gl.af.un_320
  0x2700290e, 0x062a6e12, 0x061e1bee, 0x643b5204,   // sl.gd.un_550 hmn.mt.de_654  tr.ms.de_422 ha.so.lg_332
  // [9f30]
  0x3b276bee, 0x2a12080b, 0x2d1819a0, 0x06001607,   // ceb.gd.so_422 no.hu.mt_542  gl.ga.sk_322 hr.de.un_420
  0x356425ee, 0x28121fec, 0x351b6405, 0x01032a02,   // eu.lg.zu_422 cy.hu.sw_644  lg.tr.zu_333 mt.nl.en_222
  0x21251fad, 0x04080a11, 0x0f000702, 0x0b05010c,   // cy.eu.jw_643 mk.uk.ru_653  it.lv.un_220 en.fr.es_543
  0x060e05ee, 0x3b523108, 0x101f25ad, 0x02040807,   // fr.is.de_422 az.ha.so_443  eu.cy.lt_643 no.fi.da_432
  // [9f40]
  0x3b21640b, 0x17090da7, 0x17200907, 0x115301a7,   // lg.jw.so_542 cs.pl.sr_532  pl.sq.sr_432 en.ht.ro_532
  0x0c252a04, 0x2a080ca9, 0x3f010310, 0x203117ee,   // mt.eu.sv_332 sv.no.mt_544  nl.en.af_642 sr.az.sq_422
  0x21031f04, 0x031f0dac, 0x076b0a04, 0x3217290c,   // cy.nl.jw_332 cs.cy.nl_632  pt.ceb.it_332 sl.sr.bs_543
  0x1a002a04, 0x1b0f1008, 0x04123fa9, 0x2100030c,   // mt.tl.un_320 lt.lv.tr_443  af.hu.fi_544 nl.jw.un_530
  // [9f50]
  0x083f0ca4, 0x122d18ee, 0x0c022d12, 0x0f1004a4,   // sv.af.no_433 ga.sk.hu_422  sk.da.sv_654 fi.lt.lv_433
  0x3f001212, 0x131004a4, 0x120208a0, 0x4a1f2855,   // hu.af.un_640 fi.lt.et_433  no.da.hu_322 sw.cy.yo_442
  0x20041007, 0x1835555a, 0x20000b04, 0x0a001e0c,   // lt.fi.sq_432 rw.zu.ga_553  es.sq.un_320 ms.pt.un_530
  0x1710040c, 0x1253050e, 0x20042d07, 0x2010040c,   // ru.be.sr_543 fr.ht.hu_555  sk.fi.sq_432 fi.lt.sq_543
  // [9f60]
  0x1935640c, 0x4a00090d, 0x0429200e, 0x31063b07,   // lg.zu.gl_543 pl.yo.un_540  sq.sl.fi_555 so.de.az_432
  0x53180ba0, 0x136e2512, 0x111e1912, 0x0307350c,   // es.ga.ht_322 eu.hmn.et_654  gl.ms.ro_654 zu.it.nl_543
  0x100f35ad, 0x06350314, 0x53170da0, 0x09105305,   // zu.lv.lt_643 nl.zu.de_666  cs.sr.ht_322 ht.lt.pl_333
  0x4a5504af, 0x4a250408, 0x291055a4, 0x1a4a3504,   // fi.rw.yo_655 fi.eu.yo_443  rw.lt.sl_433 zu.yo.tl_332
  // [9f70]
  0x2011530c, 0x07003522, 0x0a1c2dee, 0x311b04a4,   // ht.ro.sq_543 zu.it.un_870  sk.id.pt_422 fi.tr.az_433
  0x32006407, 0x2d290704, 0x0e002111, 0x316b3ba7,   // lg.bs.un_420 it.sl.sk_332  jw.is.un_630 so.ceb.az_532
  0x12291307, 0x20000e02, 0x52102907, 0x1c211360,   // et.sl.hu_432 is.sq.un_220  sl.lt.ha_432 et.jw.id_664
  0x022b250c, 0x1e003b0e, 0x1a356ba0, 0x29001012,   // eu.vi.da_543 so.ms.un_550  ceb.zu.tl_322 lt.sl.un_640
  // [9f80]
  0x160d2d04, 0x09203207, 0x18004a12, 0x042113af,   // sk.cs.hr_332 bs.sq.pl_432  yo.ga.un_640 et.jw.fi_655
  0x2b000804, 0x32006b02, 0x171610a0, 0x0e6452a0,   // no.vi.un_320 ceb.bs.un_220  lt.hr.sr_322 ha.lg.is_322
  0x13281a08, 0x101a1e0c, 0x122d6ba0, 0x55644aee,   // tl.sw.et_443 ms.tl.lt_543  ceb.sk.hu_322 yo.lg.rw_422
  0x042813ee, 0x11012307, 0x212a1ca4, 0x10041155,   // et.sw.fi_422 ca.en.ro_432  id.mt.jw_433 ro.ru.be_442
  // [9f90]
  0x13124aa7, 0x0413180c, 0x05010d07, 0x320413ad,   // yo.hu.et_532 ga.et.fi_543  cs.en.fr_432 et.fi.bs_643
  0x1e131ca4, 0x0f1e52a0, 0x12060cac, 0x1b003b09,   // id.et.ms_433 ha.ms.lv_322  sv.de.hu_632 so.tr.un_440
  0x3b1b52af, 0x11272b0b, 0x23051fa9, 0x5200531b,   // ha.tr.so_655 vi.gd.ro_542  cy.fr.ca_544 ht.ha.un_770
  0x0118270c, 0x6b041a04, 0x180301ee, 0x1e1c1a09,   // gd.ga.en_543 tl.fi.ceb_332  en.nl.ga_422 tl.id.ms_444
  // [9fa0]
  0x180111ee, 0x2d2b0907, 0x1c031ea9, 0x2a000802,   // ro.en.ga_422 pl.vi.sk_432  ms.nl.id_544 no.mt.un_220
  0x1e000c05, 0x3b112da4, 0x29006804, 0x060e10a9,   // sv.ms.un_330 sk.ro.so_433  ig.sl.un_320 lt.is.de_544
  0x352827ee, 0x18551f07, 0x31202511, 0x35211a07,   // gd.sw.zu_422 cy.rw.ga_432  eu.sq.az_653 tl.jw.zu_432
  0x1e00531a, 0x645501a0, 0x1f0627a4, 0x64002a07,   // ht.ms.un_760 en.rw.lg_322  gd.de.cy_433 mt.lg.un_420
  // [9fb0]
  0x04072a04, 0x18002822, 0x090a0ba0, 0x3b110fa4,   // mt.it.fi_332 sw.ga.un_870  es.pt.pl_322 lv.ro.so_433
  0x01002a0d, 0x310e01a0, 0x0a112a08, 0x3f0f1aa0,   // mt.en.un_540 en.is.az_322  mt.ro.pt_443 tl.lv.af_322
  0x1a536b07, 0x120a07a0, 0x281e35a4, 0x290701a0,   // ceb.ht.tl_432 it.pt.hu_322  zu.ms.sw_433 en.it.sl_322
  0x1f0701a4, 0x09006e0e, 0x3f011804, 0x532b180b,   // en.it.cy_433 hmn.pl.un_550  ga.en.af_332 ga.vi.ht_542
  // [9fc0]
  0x0e2d2a07, 0x063f2705, 0x0a070ba4, 0x033f0cee,   // mt.sk.is_432 gd.af.de_333  es.it.pt_433 sv.af.nl_422
  0x3f0325ad, 0x0100061a, 0x1e3f035a, 0x29001107,   // eu.nl.af_643 de.en.un_760  nl.af.ms_553 ro.sl.un_420
  0x35002919, 0x28002702, 0x210a3bad, 0x19070b60,   // sl.zu.un_750 gd.sw.un_220  so.pt.jw_643 es.it.gl_664
  0x030b55ee, 0x122d1304, 0x3f0106a0, 0x0403270b,   // rw.es.nl_422 et.sk.hu_332  de.en.af_322 gd.nl.fi_542
  // [9fd0]
  0x0200111b, 0x190b28a4, 0x11030707, 0x4a00120c,   // ro.da.un_770 sw.es.gl_433  it.nl.ro_432 hu.yo.un_530
  0x0c00090d, 0x09355502, 0x21132909, 0x0f1b31a4,   // pl.sv.un_540 rw.zu.pl_222  sl.et.jw_444 az.tr.lv_433
  0x321713ee, 0x31000b02, 0x133f0355, 0x12060812,   // et.sr.bs_422 es.az.un_220  nl.af.et_442 no.de.hu_654
  0x13093b04, 0x1b020812, 0x050601a9, 0x550820ee,   // so.pl.et_332 no.da.tr_654  en.de.fr_544 sq.no.rw_422
  // [9fe0]
  0x1c3231a4, 0x2a102505, 0x04001b13, 0x1e1c280c,   // az.bs.id_433 eu.lt.mt_333  tr.fi.un_650 sw.id.ms_543
  0x1b1c28a0, 0x0e203f07, 0x03643b0c, 0x3b281a04,   // sw.id.tr_322 af.sq.is_432  so.lg.nl_543 tl.sw.so_332
  0x23002b08, 0x321716ac, 0x06001a0b, 0x066b13a9,   // vi.ca.un_430 hr.sr.bs_632  tl.de.un_520 et.ceb.de_544
  0x21110fa0, 0x043264a0, 0x19250b55, 0x3f100c0b,   // lv.ro.jw_322 lg.bs.fi_322  es.eu.gl_442 sv.lt.af_542
  // [9ff0]
  0x35252807, 0x3f0320a4, 0x2a6b04a0, 0x1f1827a0,   // sw.eu.zu_432 sq.nl.af_433  fi.ceb.mt_322 gd.ga.cy_322
  0x6b1a28a0, 0x020e08a9, 0x233555af, 0x31001014,   // sw.tl.ceb_322 no.is.da_544  rw.zu.ca_655 lt.az.un_660
  0x6800280e, 0x191755ac, 0x11006413, 0x19000721,   // sw.ig.un_550 rw.sr.gl_632  lg.ro.un_650 it.gl.un_860
  0x321353a0, 0x040c2dee, 0x211c6ea7, 0x52132555,   // ht.et.bs_322 sk.sv.fi_422  hmn.id.jw_532 eu.et.ha_442

  // [a000]
  0x1928350c, 0x3113040c, 0x181e1c0c, 0x645511ee,   // zu.sw.gl_543 fi.et.az_543  id.ms.ga_543 ro.rw.lg_422
  0x182927a0, 0x3f03230c, 0x321b3104, 0x196e0aad,   // gd.sl.ga_322 ca.nl.af_543  az.tr.bs_332 pt.hmn.gl_643
  0x3b0925ad, 0x251155a4, 0x100f31a7, 0x020108ad,   // eu.pl.so_643 rw.ro.eu_433  az.lv.lt_532 no.en.da_643
  0x12000318, 0x03172a07, 0x115320a9, 0x55356807,   // nl.hu.un_740 mt.sr.nl_432  sq.ht.ro_544 ig.zu.rw_432
  // [a010]
  0x23001911, 0x2810640c, 0x1c0a6e08, 0x09532aa4,   // gl.ca.un_630 lg.lt.sw_543  hmn.pt.id_443 mt.ht.pl_433
  0x27180a13, 0x0a0401a4, 0x0c085507, 0x0a186ea0,   // pt.ga.gd_665 en.fi.pt_433  rw.no.sv_432 hmn.ga.pt_322
  0x530f1005, 0x16002a08, 0x033555ac, 0x0e085511,   // lt.lv.ht_333 mt.hr.un_430  rw.zu.nl_632 rw.no.is_653
  0x0c3525a0, 0x17311baf, 0x060c55a0, 0x026b1aa9,   // eu.zu.sv_322 tr.az.sr_655  rw.sv.de_322 tl.ceb.da_544
  // [a020]
  0x1e230ba9, 0x256455a9, 0x28000d19, 0x1b312a12,   // es.ca.ms_544 rw.lg.eu_544  cs.sw.un_750 mt.az.tr_654
  0x6b190b09, 0x106b280c, 0x3b001019, 0x131a280c,   // es.gl.ceb_444 sw.ceb.lt_543  lt.so.un_750 sw.tl.et_543
  0x0e191012, 0x0f000421, 0x1a2801a0, 0x132555a7,   // lt.gl.is_654 fi.lv.un_860  en.sw.tl_322 rw.eu.et_532
  0x181b31a7, 0x25072704, 0x17551304, 0x06020c55,   // az.tr.ga_532 gd.it.eu_332  et.rw.sr_332 sv.da.de_442
  // [a030]
  0x350413ee, 0x642925a0, 0x52281b08, 0x683b6407,   // et.fi.zu_422 eu.sl.lg_322  tr.sw.ha_443 lg.so.ig_432
  0x31001b02, 0x27115509, 0x212a07a0, 0x103b0107,   // tr.az.un_220 rw.ro.gd_444  it.mt.jw_322 en.so.lt_432
  0x52211aa9, 0x100f1aa0, 0x19090aaf, 0x050d1905,   // tl.jw.ha_544 tl.lv.lt_322  pt.pl.gl_655 gl.cs.fr_333
  0x31005504, 0x27000a07, 0x0e2b2808, 0x1e181ca4,   // rw.az.un_320 pt.gd.un_420  sw.vi.is_443 id.ga.ms_433
  // [a040]
  0x031a2107, 0x03020ca0, 0x10002119, 0x190b4aa0,   // jw.tl.nl_432 sv.da.nl_322  jw.lt.un_750 yo.es.gl_322
  0x310e0cee, 0x2d1918a7, 0x091b0ea0, 0x6412230c,   // sv.is.az_422 ga.gl.sk_532  is.tr.pl_322 ca.hu.lg_543
  0x3b290f0c, 0x68004a07, 0x23211ca0, 0x2b000802,   // lv.sl.so_543 yo.ig.un_420  id.jw.ca_322 no.vi.un_220
  0x3b211a08, 0x53001b08, 0x0e002b19, 0x0f080255,   // tl.jw.so_443 tr.ht.un_430  vi.is.un_750 da.no.lv_442
  // [a050]
  0x321b31a0, 0x21111707, 0x0f312907, 0x041353a4,   // az.tr.bs_322 sr.ro.jw_432  sl.az.lv_432 ht.et.fi_433
  0x010e08a4, 0x64000207, 0x53311b55, 0x12081fad,   // no.is.en_433 da.lg.un_420  tr.az.ht_442 cy.no.hu_643
  0x23000610, 0x03043f5a, 0x0a1007ee, 0x3f060f12,   // de.ca.un_620 af.fi.nl_553  bg.be.mk_422 lv.de.af_654
  0x08200c07, 0x641325a4, 0x52283fa9, 0x1a4a680c,   // sv.sq.no_432 eu.et.lg_433  af.sw.ha_544 ig.yo.tl_543
  // [a060]
  0x64312808, 0x1a180107, 0x271819a9, 0x326428a6,   // sw.az.lg_443 en.ga.tl_432  gl.ga.gd_544 sw.lg.bs_521
  0x130e0b04, 0x1e1c28ee, 0x0764550c, 0x6b0401ee,   // es.is.et_332 sw.id.ms_422  rw.lg.it_543 en.fi.ceb_422
  0x10002a09, 0x0f2d10af, 0x190b280c, 0x110f32a0,   // mt.lt.un_440 lt.sk.lv_655  sw.es.gl_543 bs.lv.ro_322
  0x28355555, 0x111b0b02, 0x35080208, 0x4a00281a,   // rw.zu.sw_442 es.tr.ro_222  da.no.zu_443 sw.yo.un_760
  // [a070]
  0x522864ee, 0x20001e02, 0x1e000404, 0x211a6b14,   // lg.sw.ha_422 ms.sq.un_220  fi.ms.un_320 ceb.tl.jw_666
  0x08130c0c, 0x09000f22, 0x25000502, 0x1b643b5a,   // sv.et.no_543 lv.pl.un_870  fr.eu.un_220 so.lg.tr_553
  0x090c2dee, 0x64003b02, 0x0e2d19af, 0x010c0207,   // sk.sv.pl_422 so.lg.un_220  gl.sk.is_655 da.sv.en_432
  0x09002304, 0x3b5264a4, 0x09001121, 0x3b3f64af,   // ca.pl.un_320 lg.ha.so_433  ro.pl.un_860 lg.af.so_655
  // [a080]
  0x2801180c, 0x31066b07, 0x641b5505, 0x0f190ba0,   // ga.en.sw_543 ceb.de.az_432  rw.tr.lg_333 es.gl.lv_322
  0x1e1c1ba0, 0x081b0c11, 0x250a280c, 0x04170802,   // tr.id.ms_322 sv.tr.no_653  sw.pt.eu_543 uk.sr.ru_222
  0x0a130707, 0x072305a4, 0x02000d08, 0x1c2108ee,   // it.et.pt_432 fr.ca.it_433  cs.da.un_430 no.jw.id_422
  0x04190a13, 0x28011807, 0x3b6b0107, 0x100f25a0,   // pt.gl.fi_665 ga.en.sw_432  en.ceb.so_432 eu.lv.lt_322
  // [a090]
  0x182704ad, 0x0a060507, 0x23072004, 0x2d0910ec,   // fi.gd.ga_643 fr.de.pt_432  sq.it.ca_332 lt.pl.sk_644
  0x120c28a4, 0x05000422, 0x0c521b0c, 0x04130ca6,   // sw.sv.hu_433 fi.fr.un_870  tr.ha.sv_543 sv.et.fi_521
  0x3b281aad, 0x2010530c, 0x322852a7, 0x232d0a04,   // tl.sw.so_643 ht.lt.sq_543  ha.sw.bs_532 pt.sk.ca_332
  0x16090dad, 0x68641a11, 0x52003b21, 0x1a556bad,   // cs.pl.hr_643 tl.lg.ig_653  so.ha.un_860 ceb.rw.tl_643
  // [a0a0]
  0x06005212, 0x212852ec, 0x35211e0c, 0x533528ad,   // ha.de.un_640 ha.sw.jw_644  ms.jw.zu_543 sw.zu.ht_643
  0x6b092107, 0x07271808, 0x1a282105, 0x031f27a0,   // jw.pl.ceb_432 ga.gd.it_443  jw.sw.tl_333 gd.cy.nl_322
  0x5200101a, 0x10111711, 0x0c120ea7, 0x10001321,   // lt.ha.un_760 sr.ro.be_653  is.hu.sv_532 et.lt.un_860
  0x18002307, 0x21321608, 0x190b5505, 0x203555ee,   // ca.ga.un_420 hr.bs.jw_443  rw.es.gl_333 rw.zu.sq_422
  // [a0b0]
  0x52003505, 0x2a1e32a0, 0x52285508, 0x051f0702,   // zu.ha.un_330 bs.ms.mt_322  rw.sw.ha_443 it.cy.fr_222
  0x17291604, 0x0d002007, 0x075564ad, 0x1f1b0e02,   // hr.sl.sr_332 sq.cs.un_420  lg.rw.it_643 is.tr.cy_222
  0x230e0c12, 0x0c1827a9, 0x1e00250e, 0x123f03ee,   // sv.is.ca_654 gd.ga.sv_544  eu.ms.un_550 nl.af.hu_422
  0x06020304, 0x050409ad, 0x20000c0c, 0x032b0804,   // nl.da.de_332 pl.fi.fr_643  sv.sq.un_530 no.vi.nl_332
  // [a0c0]
  0x3b122a02, 0x1a1e0804, 0x13680fa9, 0x132a12ad,   // mt.hu.so_222 no.ms.tl_332  lv.ig.et_544 hu.mt.et_643
  0x08112bee, 0x09033f04, 0x163168a4, 0x211f1c02,   // vi.ro.no_422 af.nl.pl_332  ig.az.hr_433 id.cy.jw_222
  0x11041005, 0x1f013ba0, 0x212d05a7, 0x1f312705,   // be.ru.ro_333 so.en.cy_322  fr.sk.jw_532 gd.az.cy_333
  0x130f04ec, 0x32552907, 0x2a0823ee, 0x012123ee,   // fi.lv.et_644 sl.rw.bs_432  ca.no.mt_422 ca.jw.en_422
  // [a0d0]
  0x23311bad, 0x10352da0, 0x64080ca7, 0x3b0117a0,   // tr.az.ca_643 sk.zu.lt_322  sv.no.lg_532 sr.en.so_322
  0x100f01a4, 0x082d1f07, 0x13351ea4, 0x64100f55,   // en.lv.lt_433 cy.sk.no_432  ms.zu.et_433 lv.lt.lg_442
  0x10190a09, 0x12351bee, 0x131a0107, 0x070553a4,   // pt.gl.lt_444 tr.zu.hu_422  en.tl.et_432 ht.fr.it_433
  0x12172004, 0x6b2a0a55, 0x4a0a050c, 0x18003f07,   // sq.sr.hu_332 pt.mt.ceb_442  fr.pt.yo_543 af.ga.un_420
  // [a0e0]
  0x2d172304, 0x553b2da0, 0x1664555a, 0x29000a04,   // ca.sr.sk_332 sk.so.rw_322  rw.lg.hr_553 pt.sl.un_320
  0x1a525508, 0x6400552c, 0x3264250c, 0x18273f04,   // rw.ha.tl_443 rw.lg.un_990  eu.lg.bs_543 af.gd.ga_332
  0x10080a12, 0x29556412, 0x18013b02, 0x033f10a4,   // mk.uk.be_654 lg.rw.sl_654  so.en.ga_222 lt.af.nl_433
  0x16645508, 0x3f030f02, 0x190b1102, 0x282155a7,   // rw.lg.hr_443 lv.nl.af_222  ro.es.gl_222 rw.jw.sw_532
  // [a0f0]
  0x5500642c, 0x112955a4, 0x100106ee, 0x0f004a0e,   // lg.rw.un_990 rw.sl.ro_433  de.en.lt_422 yo.lv.un_550
  0x16041312, 0x13045505, 0x213b1aa7, 0x32002a07,   // et.fi.hr_654 rw.fi.et_333  tl.so.jw_532 mt.bs.un_420
  0x20352107, 0x553513ee, 0x52201312, 0x531a1255,   // jw.zu.sq_432 et.zu.rw_422  et.sq.ha_654 hu.tl.ht_442
  0x55001311, 0x35125505, 0x32063f04, 0x103217a6,   // et.rw.un_630 rw.hu.zu_333  af.de.bs_332 sr.bs.lt_521
  // [a100]
  0x06045309, 0x35251a05, 0x0a04085a, 0x0a190b11,   // ht.fi.de_444 tl.eu.zu_333  uk.ru.mk_553 es.gl.pt_653
  0x293203ee, 0x1b033f05, 0x3b182704, 0x01040555,   // nl.bs.sl_422 af.nl.tr_333  gd.ga.so_332 fr.fi.en_442
  0x063504ee, 0x64006805, 0x17100a11, 0x031b06a0,   // fi.zu.de_422 ig.lg.un_330  mk.be.sr_653 de.tr.nl_322
  0x68641aa4, 0x1b001902, 0x2004550c, 0x1e271813,   // tl.lg.ig_433 gl.tr.un_220  rw.fi.sq_543 ga.gd.ms_665
  // [a110]
  0x35001314, 0x090711a7, 0x6b001302, 0x551225a9,   // et.zu.un_660 ro.it.pl_532  et.ceb.un_220 eu.hu.rw_544
  0x556812ec, 0x1b060305, 0x312b5204, 0x1e0903a4,   // hu.ig.rw_644 nl.de.tr_333  ha.vi.az_332 nl.pl.ms_433
  0x031b53ad, 0x68001b04, 0x55000c04, 0x181107a0,   // ht.tr.nl_643 tr.ig.un_320  sv.rw.un_320 it.ro.ga_322
  0x28642307, 0x2d250a05, 0x0e002902, 0x190b0e05,   // ca.lg.sw_432 pt.eu.sk_333  sl.is.un_220 is.es.gl_333
  // [a120]
  0x080e2aec, 0x1b000b05, 0x080c01a0, 0x3b3f03a0,   // mt.is.no_644 es.tr.un_330  en.sv.no_322 nl.af.so_322
  0x013f03ad, 0x2a080e07, 0x033f4aac, 0x3f4a3b07,   // nl.af.en_643 is.no.mt_432  yo.af.nl_632 so.yo.af_432
  0x0e030ca7, 0x13080260, 0x0a1e0113, 0x012b3bee,   // sv.nl.is_532 da.no.et_664  en.ms.pt_665 so.vi.en_422
  0x016b08a0, 0x290d17a9, 0x20311155, 0x6b0a01ac,   // no.ceb.en_322 sr.cs.sl_544  ro.az.sq_442 en.pt.ceb_632
  // [a130]
  0x0d091c04, 0x27080e04, 0x233101a4, 0x13123f07,   // mr.hi.ne_332 is.no.gd_332  en.az.ca_433 af.hu.et_432
  0x181f280c, 0x11002807, 0x2d0d28a9, 0x0f0706a9,   // sw.cy.ga_543 sw.ro.un_420  sw.cs.sk_544 de.it.lv_544
  0x13001907, 0x05275307, 0x0d292da4, 0x271903ee,   // gl.et.un_420 ht.gd.fr_432  sk.sl.cs_433 nl.gl.gd_422
  0x6811060c, 0x0f2913ee, 0x2d0d06ac, 0x1e000908,   // de.ro.ig_543 et.sl.lv_422  de.cs.sk_632 pl.ms.un_430
  // [a140]
  0x6800060d, 0x030928a0, 0x526b1a60, 0x0d2d1213,   // de.ig.un_540 sw.pl.nl_322  tl.ceb.ha_664 hu.sk.cs_665
  0x0d555209, 0x6b4a350d, 0x28644a02, 0x256b1ca0,   // ha.rw.cs_444 zu.yo.ceb_554  yo.lg.sw_222 id.ceb.eu_322
  0x524a5304, 0x3b1b64a0, 0x280552a0, 0x1f0135a4,   // ht.yo.ha_332 lg.tr.so_322  ha.fr.sw_322 zu.en.cy_433
  0x210f1c09, 0x21551f0c, 0x23070aa0, 0x0a0818ee,   // id.lv.jw_444 cy.rw.jw_543  pt.it.ca_322 ga.no.pt_422
  // [a150]
  0x3b072a11, 0x093f2807, 0x12322804, 0x0a0c3b0b,   // mt.it.so_653 sw.af.pl_432  sw.bs.hu_332 so.sv.pt_542
  0x0b0710a0, 0x13001b0e, 0x13081004, 0x201a280c,   // lt.it.es_322 tr.et.un_550  lt.no.et_332 sw.tl.sq_543
  0x64045211, 0x35250ba4, 0x2800270e, 0x31002308,   // ha.fi.lg_653 es.eu.zu_433  gd.sw.un_550 ca.az.un_430
  0x042d0da4, 0x230c55a0, 0x2a290f12, 0x073125a9,   // cs.sk.fi_433 rw.sv.ca_322  lv.sl.mt_654 eu.az.it_544
  // [a160]
  0x281b2007, 0x25120107, 0x021c2104, 0x1b072a5a,   // sq.tr.sw_432 en.hu.eu_432  jw.id.da_332 mt.it.tr_553
  0x03310208, 0x6e000f05, 0x06070413, 0x3516280c,   // da.az.nl_443 lv.hmn.un_330  fi.it.de_665 sw.hr.zu_543
  0x1c1353ee, 0x64000f19, 0x12001e02, 0x0c001102,   // ht.et.id_422 lv.lg.un_750  ms.hu.un_220 ro.sv.un_220
  0x64356b07, 0x6b003505, 0x64530907, 0x35536404,   // ceb.zu.lg_432 zu.ceb.un_330  pl.ht.lg_432 lg.ht.zu_332
  // [a170]
  0x322b12ad, 0x213527a7, 0x526b090c, 0x0e060cee,   // hu.vi.bs_643 gd.zu.jw_532  pl.ceb.ha_543 sv.de.is_422
  0x4a095307, 0x35002707, 0x52180107, 0x550a4aa0,   // ht.pl.yo_432 gd.zu.un_420  en.ga.ha_432 yo.pt.rw_322
  0x2a531c0c, 0x1c006b0d, 0x170c0855, 0x17050107,   // id.ht.mt_543 ceb.id.un_540  no.sv.sr_442 en.fr.sr_432
  0x2d100d05, 0x11002905, 0x13211a04, 0x133f1f04,   // cs.lt.sk_333 sl.ro.un_330  tl.jw.et_332 cy.af.et_332
  // [a180]
  0x290f1f12, 0x233f2aee, 0x0f0813a0, 0x10042807,   // cy.lv.sl_654 mt.af.ca_422  et.no.lv_322 sw.fi.lt_432
  0x0f1035ac, 0x1b3f060c, 0x19211c0c, 0x1c1a0107,   // zu.lt.lv_632 de.af.tr_543  id.jw.gl_543 en.tl.id_432
  0x17001f0c, 0x1b3113ad, 0x110509ee, 0x64211c55,   // cy.sr.un_530 et.az.tr_643  pl.fr.ro_422 id.jw.lg_442
  0x13001e20, 0x232a1355, 0x536b28a0, 0x5335090c,   // ms.et.un_850 et.mt.ca_442  sw.ceb.ht_322 pl.zu.ht_543
  // [a190]
  0x11100da0, 0x120429a0, 0x072d0d07, 0x28041307,   // cs.lt.ro_322 sl.fi.hu_322  cs.sk.it_432 et.fi.sw_432
  0x55641b04, 0x1f001e22, 0x042853af, 0x102518ad,   // tr.lg.rw_332 ms.cy.un_870  ht.sw.fi_655 ga.eu.lt_643
  0x096b3bee, 0x6b181aee, 0x521e25ad, 0x1f002522,   // so.ceb.pl_422 tl.ga.ceb_422  eu.ms.ha_643 eu.cy.un_870
  0x190f2512, 0x035305ee, 0x04002a0c, 0x3b000411,   // eu.lv.gl_654 fr.ht.nl_422  mt.fi.un_530 fi.so.un_630
  // [a1a0]
  0x20352813, 0x270f04a0, 0x681f0faf, 0x1f04180d,   // sw.zu.sq_665 fi.lv.gd_322  lv.cy.ig_655 ga.fi.cy_554
  0x0d2a0e02, 0x3b003202, 0x203b5555, 0x52002021,   // is.mt.cs_222 bs.so.un_220  rw.so.sq_442 sq.ha.un_860
  0x09002b14, 0x2000552a, 0x033f0e55, 0x2a000412,   // vi.pl.un_660 rw.sq.un_970  is.af.nl_442 fi.mt.un_640
  0x6b2128ee, 0x202852ec, 0x5500210c, 0x23002b1a,   // sw.jw.ceb_422 ha.sw.sq_644  jw.rw.un_530 vi.ca.un_760
  // [a1b0]
  0x21642807, 0x20132311, 0x550f050b, 0x130d0955,   // sw.lg.jw_432 ca.et.sq_653  fr.lv.rw_542 hi.ne.bh_442
  0x02003b04, 0x28071004, 0x2a000e12, 0x641a06a0,   // so.da.un_320 lt.it.sw_332  is.mt.un_640 de.tl.lg_322
  0x05032308, 0x201f27af, 0x28002133, 0x3f180404,   // ca.nl.fr_443 gd.cy.sq_655  jw.sw.un_A70 fi.ga.af_332
  0x32001a07, 0x0604180c, 0x230a1b04, 0x061b2007,   // tl.bs.un_420 ga.fi.de_543  tr.pt.ca_332 sq.tr.de_432
  // [a1c0]
  0x1c3b0155, 0x2a2031a7, 0x0d2a0e07, 0x642701a0,   // en.so.id_442 az.sq.mt_532  is.mt.cs_432 en.gd.lg_322
  0x1e523b0c, 0x030102a0, 0x033f64ee, 0x210a1ba0,   // so.ha.ms_543 da.en.nl_322  lg.af.nl_422 tr.pt.jw_322
  0x2a001222, 0x553f0604, 0x210828a0, 0x17291e05,   // hu.mt.un_870 de.af.rw_332  sw.no.jw_322 ms.sl.sr_333
  0x3100180e, 0x3b1201a0, 0x5200352c, 0x0e2708af,   // ga.az.un_550 en.hu.so_322  zu.ha.un_990 no.gd.is_655
  // [a1d0]
  0x06006b0e, 0x1000061b, 0x52283fee, 0x29001613,   // ceb.de.un_550 de.lt.un_770  af.sw.ha_422 hr.sl.un_650
  0x180c0eee, 0x641c2113, 0x1c091310, 0x212027ee,   // is.sv.ga_422 jw.id.lg_665  bh.hi.mr_642 gd.sq.jw_422
  0x2d050a55, 0x3f2301ad, 0x1a2b6b04, 0x31130405,   // pt.fr.sk_442 en.ca.af_643  ceb.vi.tl_332 fi.et.az_333
  0x082701ad, 0x271f1808, 0x0c522155, 0x253f3b11,   // en.gd.no_643 ga.cy.gd_443  jw.ha.sv_442 so.af.eu_653
  // [a1e0]
  0x136804ee, 0x04000322, 0x045210a7, 0x1a1364ee,   // fi.ig.et_422 nl.fi.un_870  lt.ha.fi_532 lg.et.tl_422
  0x25210604, 0x0e1806ad, 0x4a351308, 0x32291605,   // de.jw.eu_332 de.ga.is_643  et.zu.yo_443 hr.sl.bs_333
  0x0e6b1a5a, 0x1b521304, 0x1a64115a, 0x08354aad,   // tl.ceb.is_553 et.ha.tr_332  ro.lg.tl_553 yo.zu.no_643
  0x1e1a110c, 0x025208a0, 0x6b1a110c, 0x290d17a4,   // ro.tl.ms_543 no.ha.da_322  ro.tl.ceb_543 sr.cs.sl_433
  // [a1f0]
  0x6b1a350d, 0x1c2111a7, 0x211c35ee, 0x6b112108,   // zu.tl.ceb_554 ro.jw.id_532  zu.id.jw_422 jw.ro.ceb_443
  0x082d0c04, 0x13041c07, 0x11006419, 0x13044aa4,   // sv.sk.no_332 id.fi.et_432  lg.ro.un_750 yo.fi.et_433
  0x0e6421a9, 0x283f35ee, 0x643b280e, 0x046864af,   // jw.lg.is_544 zu.af.sw_422  sw.so.lg_555 lg.ig.fi_655
  0x3125110c, 0x0a081002, 0x311135a4, 0x1e1b0fa0,   // ro.eu.az_543 be.uk.mk_222  zu.ro.az_433 lv.tr.ms_322
  // [a200]
  0x641b31ad, 0x2d31290c, 0x1b3111ee, 0x1700530c,   // az.tr.lg_643 sl.az.sk_543  ro.az.tr_422 ht.sr.un_530
  0x522a130c, 0x311b1112, 0x20326b02, 0x111e520d,   // et.mt.ha_543 ro.tr.az_654  ceb.bs.sq_222 ha.ms.ro_554
  0x092311a0, 0x12200204, 0x211c2504, 0x52002012,   // ro.ca.pl_322 da.sq.hu_332  eu.id.jw_332 sq.ha.un_640
  0x233f01a0, 0x08012307, 0x0f002a07, 0x170a0855,   // en.af.ca_322 ca.en.no_432  mt.lv.un_420 uk.mk.sr_442
  // [a210]
  0x08320c07, 0x350601ee, 0x0000192d, 0x03230555,   // sv.bs.no_432 en.de.zu_422  gl.un.un_A00 fr.ca.nl_442
  0x09001112, 0x0b681805, 0x201205af, 0x130520ad,   // ro.pl.un_640 ga.ig.es_333  fr.hu.sq_655 sq.fr.et_643
  0x3f0123a7, 0x085507a0, 0x03160ea0, 0x230f010c,   // ca.en.af_532 it.rw.no_322  is.hr.nl_322 en.lv.ca_543
  0x16170dad, 0x0e270813, 0x01230f0d, 0x13043555,   // cs.sr.hr_643 no.gd.is_665  lv.ca.en_554 zu.fi.et_442
  // [a220]
  0x13004a02, 0x101325a0, 0x1e003502, 0x04133504,   // yo.et.un_220 eu.et.lt_322  zu.ms.un_220 zu.et.fi_332
  0x0e640407, 0x033f1ba0, 0x13002005, 0x642555a0,   // fi.lg.is_432 tr.af.nl_322  sq.et.un_330 rw.eu.lg_322
  0x4a003508, 0x0a110714, 0x6468350c, 0x08250e04,   // zu.yo.un_430 bg.ro.mk_666  zu.ig.lg_543 is.eu.no_332
  0x105525af, 0x0d17290b, 0x1a316b09, 0x68100f07,   // eu.rw.lt_655 sl.sr.cs_542  ceb.az.tl_444 lv.lt.ig_432
  // [a230]
  0x2507130c, 0x256b290c, 0x07286b08, 0x25106ba4,   // et.it.eu_543 sl.ceb.eu_543  ceb.sw.it_443 ceb.lt.eu_433
  0x06211e12, 0x0a113bee, 0x0e27080c, 0x0600210e,   // ms.jw.de_654 so.ro.pt_422  no.gd.is_543 jw.de.un_550
  0x2b210612, 0x09532da4, 0x32040f05, 0x2a04100c,   // de.jw.vi_654 sk.ht.pl_433  lv.fi.bs_333 lt.fi.mt_543
  0x532a6ba0, 0x530f0405, 0x13256bac, 0x0f251ca0,   // ceb.mt.ht_322 fi.lv.ht_333  ceb.eu.et_632 id.eu.lv_322
  // [a240]
  0x13042a0d, 0x0e00201b, 0x1e0425ad, 0x0f2853a4,   // mt.fi.et_554 sq.is.un_770  eu.fi.ms_643 ht.sw.lv_433
  0x52002123, 0x310c02ad, 0x1c121ea0, 0x080229ec,   // jw.ha.un_880 da.sv.az_643  ms.hu.id_322 sl.da.no_644
  0x061c21ad, 0x2100060e, 0x1c351e08, 0x1e211cad,   // jw.id.de_643 de.jw.un_550  ms.zu.id_443 id.jw.ms_643
  0x3b3513ee, 0x530304ad, 0x19002702, 0x04523bad,   // et.zu.so_422 fi.nl.ht_643  gd.gl.un_220 so.ha.fi_643
  // [a250]
  0x10032aaf, 0x1a001c1a, 0x1b1a04a4, 0x250f4aa4,   // mt.nl.lt_655 id.tl.un_760  fi.tl.tr_433 yo.lv.eu_433
  0x521a1c07, 0x083155a4, 0x1f00090d, 0x27011804,   // id.tl.ha_432 rw.az.no_433  pl.cy.un_540 ga.en.gd_332
  0x17160da0, 0x0d001614, 0x2b182d07, 0x11001907,   // cs.hr.sr_322 hr.cs.un_660  sk.ga.vi_432 gl.ro.un_420
  0x21093ba0, 0x6b6831ad, 0x1104530c, 0x191711ee,   // so.pl.jw_322 az.ig.ceb_643  ht.fi.ro_543 ro.sr.gl_422
  // [a260]
  0x0e06035a, 0x0d1b2504, 0x130501ad, 0x190b11af,   // nl.de.is_553 eu.tr.cs_332  en.fr.et_643 ro.es.gl_655
  0x2d0d0b0e, 0x2a3b31ee, 0x526b25ee, 0x026b08a9,   // es.cs.sk_555 az.so.mt_422  eu.ceb.ha_422 no.ceb.da_544
  0x0223110c, 0x076b01ac, 0x1800110c, 0x101729a0,   // ro.ca.da_543 en.ceb.it_632  ro.ga.un_530 sl.sr.lt_322
  0x55530708, 0x1b0f04ad, 0x23132513, 0x180413ee,   // it.ht.rw_443 fi.lv.tr_643  eu.et.ca_665 et.fi.ga_422
  // [a270]
  0x03126e07, 0x1218050c, 0x0911010c, 0x026b0808,   // hmn.hu.nl_432 fr.ga.hu_543  en.ro.pl_543 no.ceb.da_443
  0x18190da7, 0x0d0b18a4, 0x1119520c, 0x08003507,   // cs.gl.ga_532 ga.es.cs_433  ha.gl.ro_543 zu.no.un_420
  0x130e0804, 0x03080ca9, 0x521e28a4, 0x4a12180c,   // no.is.et_332 sv.no.nl_544  sw.ms.ha_433 ga.hu.yo_543
  0x3b0b28a9, 0x0a680704, 0x12041302, 0x0a3553ad,   // sw.es.so_544 it.ig.pt_332  et.fi.hu_222 ht.zu.pt_643
  // [a280]
  0x313555ad, 0x205553a0, 0x21281c04, 0x071710a9,   // rw.zu.az_643 ht.rw.sq_322  id.sw.jw_332 be.sr.bg_544
  0x07001c04, 0x190b1009, 0x0a001308, 0x23001819,   // id.it.un_320 lt.es.gl_444  et.pt.un_430 ga.ca.un_750
  0x292d0f0c, 0x1118010c, 0x28352702, 0x211120a7,   // lv.sk.sl_543 en.ga.ro_543  gd.zu.sw_222 sq.ro.jw_532
  0x20102aee, 0x08040ca4, 0x6b136407, 0x0c0e13ac,   // mt.lt.sq_422 sv.fi.no_433  lg.et.ceb_432 et.is.sv_632
  // [a290]
  0x356407a4, 0x030c2ba0, 0x07350408, 0x190a0702,   // it.lg.zu_433 vi.sv.nl_322  fi.zu.it_443 it.pt.gl_222
  0x132d0d02, 0x28311ba7, 0x131220a4, 0x1b211ca0,   // cs.sk.et_222 tr.az.sw_532  sq.hu.et_433 id.jw.tr_322
  0x32160d14, 0x35312aa0, 0x55311aa4, 0x130c1012,   // cs.hr.bs_666 mt.az.zu_322  tl.az.rw_433 lt.sv.et_654
  0x042813ec, 0x06020508, 0x13091c11, 0x12132aa0,   // et.sw.fi_644 fr.da.de_443  mr.hi.bh_653 mt.et.hu_322
  // [a2a0]
  0x2a3555af, 0x2a554a07, 0x216468a4, 0x212025ee,   // rw.zu.mt_655 yo.rw.mt_432  ig.lg.jw_433 eu.sq.jw_422
  0x110d0a08, 0x64211c05, 0x10000e21, 0x06032aa0,   // pt.cs.ro_443 id.jw.lg_333  is.lt.un_860 mt.nl.de_322
  0x101c1ea6, 0x0802310c, 0x0c5204a9, 0x050b070d,   // ms.id.lt_521 az.da.no_543  fi.ha.sv_544 it.es.fr_554
  0x07530413, 0x1f1108a4, 0x07192507, 0x08356404,   // fi.ht.it_665 no.ro.cy_433  eu.gl.it_432 lg.zu.no_332
  // [a2b0]
  0x1a002d1a, 0x3f6801a0, 0x530802a9, 0x0e063560,   // sk.tl.un_760 en.ig.af_322  da.no.ht_544 zu.de.is_664
  0x0c6e3507, 0x35281e04, 0x641b5208, 0x17001133,   // zu.hmn.sv_432 ms.sw.zu_332  ha.tr.lg_443 ro.sr.un_A70
  0x273b180c, 0x0e1227a9, 0x3b041112, 0x53520413,   // ga.so.gd_543 gd.hu.is_544  ro.fi.so_654 fi.ha.ht_665
  0x04071755, 0x1a530da0, 0x0f060e07, 0x04181f08,   // sr.bg.ru_442 cs.ht.tl_322  is.de.lv_432 cy.ga.fi_443
  // [a2c0]
  0x53042108, 0x282135ec, 0x290e2d0c, 0x08022905,   // jw.fi.ht_443 zu.jw.sw_644  sk.is.sl_543 sl.da.no_333
  0x02003b07, 0x64552aaf, 0x0c133fa0, 0x3b046802,   // so.da.un_420 mt.rw.lg_655  af.et.sv_322 ig.fi.so_222
  0x2d29020e, 0x06250f13, 0x07186804, 0x190b0509,   // da.sl.sk_555 lv.eu.de_665  ig.ga.it_332 fr.es.gl_444
  0x5528130b, 0x08040302, 0x21000c02, 0x202852ee,   // et.sw.rw_542 nl.fi.no_222  sv.jw.un_220 ha.sw.sq_422
  // [a2d0]
  0x552513a4, 0x1a311baf, 0x293f2d05, 0x030623a0,   // et.eu.rw_433 tr.az.tl_655  sk.af.sl_333 ca.de.nl_322
  0x0e000311, 0x271835af, 0x0e292d13, 0x120e0aa4,   // nl.is.un_630 zu.ga.gd_655  sk.sl.is_665 pt.is.hu_433
  0x051e1c55, 0x17041111, 0x1200092b, 0x210b02a0,   // id.ms.fr_442 ro.ru.sr_653  pl.hu.un_980 da.es.jw_322
  0x062b0302, 0x3f0c1fee, 0x131b1207, 0x25521a0c,   // nl.vi.de_222 cy.sv.af_422  hu.tr.et_432 tl.ha.eu_543
  // [a2e0]
  0x043f4aad, 0x3f2503af, 0x061b0807, 0x03021f04,   // yo.af.fi_643 nl.eu.af_655  no.tr.de_432 cy.da.nl_332
  0x120310a0, 0x03001b0b, 0x521b3105, 0x081113ad,   // lt.nl.hu_322 tr.nl.un_520  az.tr.ha_333 et.ro.no_643
  0x350e130c, 0x3f010304, 0x5202310b, 0x01271804,   // et.is.zu_543 nl.en.af_332  az.da.ha_542 ga.gd.en_332
  0x062009a4, 0x08131c07, 0x0e041ea0, 0x2100270b,   // pl.sq.de_433 id.et.no_432  ms.fi.is_322 gd.jw.un_520
  // [a2f0]
  0x053f0314, 0x102a1e0b, 0x021a1355, 0x101716ac,   // nl.af.fr_666 ms.mt.lt_542  et.tl.da_442 hr.sr.lt_632
  0x11000919, 0x316b0807, 0x061a09a7, 0x0c3f035a,   // pl.ro.un_750 no.ceb.az_432  pl.tl.de_532 nl.af.sv_553
  0x131104ec, 0x0813680c, 0x0e520813, 0x110f0404,   // fi.ro.et_644 ig.et.no_543  no.ha.is_665 fi.lv.ro_332
  0x171606a0, 0x321753ee, 0x25315307, 0x28353ba4,   // de.hr.sr_322 ht.sr.bs_422  ht.az.eu_432 so.zu.sw_433
  // [a300]
  0x0d00110d, 0x6b353b09, 0x04211012, 0x3f005507,   // ro.cs.un_540 so.zu.ceb_444  lt.jw.fi_654 rw.af.un_420
  0x2b016bee, 0x211c55a0, 0x1e52280c, 0x01072302,   // ceb.en.vi_422 rw.id.jw_322  sw.ha.ms_543 ca.it.en_222
  0x19001818, 0x35000404, 0x0d2d0e0c, 0x2d0802a0,   // ga.gl.un_740 fi.zu.un_320  is.sk.cs_543 da.no.sk_322
  0x0c061207, 0x2d0d4a0c, 0x12313f07, 0x07030fee,   // hu.de.sv_432 yo.cs.sk_543  af.az.hu_432 lv.nl.it_422
  // [a310]
  0x1a2a01a0, 0x04102104, 0x0e1a55ec, 0x110f0307,   // en.mt.tl_322 jw.lt.fi_332  rw.tl.is_644 nl.lv.ro_432
  0x27000204, 0x122903a0, 0x080252a0, 0x55203504,   // da.gd.un_320 nl.sl.hu_322  ha.da.no_322 zu.sq.rw_332
  0x1c5523a4, 0x08020da9, 0x042d0faf, 0x251a01af,   // ca.rw.id_433 cs.da.no_544  lv.sk.fi_655 en.tl.eu_655
  0x28271804, 0x272118a0, 0x0b11235a, 0x200455a0,   // ga.gd.sw_332 ga.jw.gd_322  ca.ro.es_553 rw.fi.sq_322
  // [a320]
  0x060c20a4, 0x2025115a, 0x3b001919, 0x13071007,   // sq.sv.de_433 ro.eu.sq_553  gl.so.un_750 lt.it.et_432
  0x550921ec, 0x0425230c, 0x27185207, 0x23040aa0,   // jw.pl.rw_644 ca.eu.fi_543  ha.ga.gd_432 pt.fi.ca_322
  0x1b531c04, 0x1f0c08a7, 0x28042da0, 0x3f051312,   // id.ht.tr_332 no.sv.cy_532  sk.fi.sw_322 et.fr.af_654
  0x210c35a0, 0x28040aa4, 0x041329ee, 0x2d001f08,   // zu.sv.jw_322 pt.fi.sw_433  sl.et.fi_422 cy.sk.un_430
  // [a330]
  0x3f092a12, 0x172a0704, 0x040717a7, 0x17110a0e,   // mt.pl.af_654 it.mt.sr_332  sr.bg.ru_532 mk.ro.sr_555
  0x640107ee, 0x350b1109, 0x092a3f12, 0x3f31100c,   // it.en.lg_422 ro.es.zu_444  af.mt.pl_654 lt.az.af_543
  0x351f0e02, 0x082a0eaf, 0x102a07a0, 0x53211ca4,   // is.cy.zu_222 is.mt.no_655  it.mt.lt_322 id.jw.ht_433
  0x3f0206a0, 0x122d0e0c, 0x2b004a19, 0x18010ca7,   // de.da.af_322 is.sk.hu_543  yo.vi.un_750 sv.en.ga_532
  // [a340]
  0x100e0c04, 0x0a640702, 0x201f23a7, 0x0f102a0e,   // sv.is.lt_332 it.lg.pt_222  ca.cy.sq_532 mt.lt.lv_555
  0x0b121807, 0x292d1607, 0x32000a02, 0x1f001912,   // ga.hu.es_432 hr.sk.sl_432  pt.bs.un_220 gl.cy.un_640
  0x040501a0, 0x01082a07, 0x1c090da6, 0x050609a9,   // en.fr.fi_322 mt.no.en_432  ne.hi.mr_521 pl.de.fr_544
  0x170911a4, 0x0b000c07, 0x202a1c07, 0x08200405,   // ro.pl.sr_433 sv.es.un_420  id.mt.sq_432 fi.sq.no_333
  // [a350]
  0x120b0e0c, 0x03023f5a, 0x3b1a3513, 0x1a00350c,   // is.es.hu_543 af.da.nl_553  zu.tl.so_665 zu.tl.un_530
  0x283b3560, 0x050235ee, 0x3b000d11, 0x55353b05,   // zu.so.sw_664 zu.da.fr_422  cs.so.un_630 so.zu.rw_333
  0x6e3b6b04, 0x35643b13, 0x356410a7, 0x18010502,   // ceb.so.hmn_332 so.lg.zu_665  lt.lg.zu_532 fr.en.ga_222
  0x182007af, 0x1708070c, 0x35000a19, 0x18353bad,   // it.sq.ga_655 bg.uk.sr_543  pt.zu.un_750 so.zu.ga_643
  // [a360]
  0x0b001819, 0x11003b1e, 0x080c06a0, 0x6b0135ee,   // ga.es.un_750 so.ro.un_830  de.sv.no_322 zu.en.ceb_422
  0x35182704, 0x3b005520, 0x08003f0e, 0x0f6425ad,   // gd.ga.zu_332 rw.so.un_850  af.no.un_550 eu.lg.lv_643
  0x06013505, 0x0c060eac, 0x3f003b07, 0x35554aa0,   // zu.en.de_333 is.de.sv_632  so.af.un_420 yo.rw.zu_322
  0x3f3110ec, 0x160725ee, 0x2a190709, 0x1a6b3b07,   // lt.az.af_644 eu.it.hr_422  it.gl.mt_444 so.ceb.tl_432
  // [a370]
  0x0f003209, 0x646823a4, 0x680608a0, 0x05190b0c,   // bs.lv.un_440 ca.ig.lg_433  no.de.ig_322 es.gl.fr_543
  0x13020fee, 0x0f04050c, 0x190b0a0d, 0x2809070b,   // lv.da.et_422 fr.fi.lv_543  pt.es.gl_554 it.pl.sw_542
  0x2a070907, 0x2500050c, 0x060c0eec, 0x190b055a,   // pl.it.mt_432 fr.eu.un_530  is.sv.de_644 fr.es.gl_553
  0x100f1ca0, 0x10000e02, 0x070c0807, 0x3f000f19,   // id.lv.lt_322 is.lt.un_220  no.sv.it_432 lv.af.un_750
  // [a380]
  0x17160fee, 0x041a2107, 0x311003a7, 0x011853a0,   // lv.hr.sr_422 jw.tl.fi_432  nl.lt.az_532 ht.ga.en_322
  0x09006818, 0x55000a08, 0x17100f04, 0x2b1f0755,   // ig.pl.un_740 pt.rw.un_430  lv.lt.sr_332 it.cy.vi_442
  0x090f04a9, 0x06040f14, 0x07100f12, 0x0b1b4aa4,   // fi.lv.pl_544 lv.fi.de_666  lv.lt.it_654 yo.tr.es_433
  0x130e0f0c, 0x190b25a4, 0x3f2a0bad, 0x032d17a4,   // lv.is.et_543 eu.es.gl_433  es.mt.af_643 sr.sk.nl_433
  // [a390]
  0x0f2d1007, 0x2b002108, 0x03060202, 0x310418a4,   // lt.sk.lv_432 jw.vi.un_430  da.de.nl_222 ga.fi.az_433
  0x0e04090c, 0x030c1307, 0x0c0f03a4, 0x35000d08,   // pl.fi.is_543 et.sv.nl_432  nl.lv.sv_433 cs.zu.un_430
  0x35053f07, 0x193555ec, 0x64000f0e, 0x080301a0,   // af.fr.zu_432 rw.zu.gl_644  lv.lg.un_550 en.nl.no_322
  0x2928550c, 0x040605ac, 0x3f130802, 0x16002107,   // rw.sw.sl_543 fr.de.fi_632  no.et.af_222 jw.hr.un_420
  // [a3a0]
  0x20321602, 0x162d32a0, 0x0b192da4, 0x4a176407,   // hr.bs.sq_222 bs.sk.hr_322  sk.gl.es_433 lg.sr.yo_432
  0x644a35a0, 0x64190b08, 0x135311ee, 0x190b2805,   // zu.yo.lg_322 es.gl.lg_443  ro.ht.et_422 sw.es.gl_333
  0x162953a4, 0x170811ec, 0x2a2501ee, 0x1c1125a7,   // ht.sl.hr_433 ro.uk.sr_644  en.eu.mt_422 eu.ro.id_532
  0x6400071a, 0x112855af, 0x07006419, 0x08060505,   // it.lg.un_760 rw.sw.ro_655  lg.it.un_750 fr.de.no_333
  // [a3b0]
  0x070511ac, 0x042b200c, 0x08030404, 0x053f5505,   // ro.fr.it_632 sq.vi.fi_543  fi.nl.no_332 rw.af.fr_333
  0x644a5312, 0x32281bee, 0x0a07080e, 0x050e08a0,   // ht.yo.lg_654 tr.sw.bs_422  uk.bg.mk_555 no.is.fr_322
  0x0700102b, 0x18060107, 0x6b0501a0, 0x1f0b1a07,   // be.bg.un_980 en.de.ga_432  en.fr.ceb_322 tl.es.cy_432
  0x100a07a6, 0x21231ca0, 0x19100ba0, 0x27230107,   // it.pt.lt_521 id.ca.jw_322  es.lt.gl_322 en.ca.gd_432
  // [a3c0]
  0x0d0e0ba0, 0x271223ee, 0x52005314, 0x01110fa0,   // es.is.cs_322 ca.hu.gd_422  ht.ha.un_660 lv.ro.en_322
  0x180201a0, 0x20190b08, 0x20001807, 0x35642104,   // en.da.ga_322 es.gl.sq_443  ga.sq.un_420 jw.lg.zu_332
  0x0a001f04, 0x2d0d2a02, 0x19120b12, 0x200c1a08,   // cy.pt.un_320 mt.cs.sk_222  es.hu.gl_654 tl.sv.sq_443
  0x080e1212, 0x35000608, 0x0a086405, 0x25200b07,   // hu.is.no_654 de.zu.un_430  lg.no.pt_333 es.sq.eu_432
  // [a3d0]
  0x105207ac, 0x0717100b, 0x100f0302, 0x350b64a0,   // it.ha.lt_632 be.sr.bg_542  nl.lv.lt_222 lg.es.zu_322
  0x2000130d, 0x3b202811, 0x55002102, 0x28553ba0,   // et.sq.un_540 sw.sq.so_653  jw.rw.un_220 so.rw.sw_322
  0x06002d05, 0x0b030e55, 0x310f2504, 0x1b042a12,   // sk.de.un_330 is.nl.es_442  eu.lv.az_332 mt.fi.tr_654
  0x07000a20, 0x12001e08, 0x01031fa7, 0x25000b14,   // mk.bg.un_850 ms.hu.un_430  cy.nl.en_532 es.eu.un_660
  // [a3e0]
  0x0725555a, 0x32001014, 0x55642513, 0x3b6b1a04,   // rw.eu.it_553 lt.bs.un_660  eu.lg.rw_665 tl.ceb.so_332
  0x1c11310c, 0x0f004a07, 0x271001ee, 0x31211004,   // az.ro.id_543 yo.lv.un_420  en.lt.gd_422 lt.jw.az_332
  0x55250da4, 0x283b68ac, 0x1b1029ec, 0x23192512,   // cs.eu.rw_433 ig.so.sw_632  sl.lt.tr_644 eu.gl.ca_654
  0x280a6808, 0x554a64af, 0x0c64550d, 0x2a090ba0,   // ig.pt.sw_443 lg.yo.rw_655  rw.lg.sv_554 es.pl.mt_322
  // [a3f0]
  0x01051307, 0x0f1c2107, 0x0a180e04, 0x2d0d0fa9,   // et.fr.en_432 jw.id.lv_432  is.ga.pt_332 lv.cs.sk_544
  0x13090d08, 0x2d3b0d0c, 0x29211e02, 0x160d32a7,   // ne.hi.bh_443 cs.so.sk_543  ms.jw.sl_222 bs.cs.hr_532
  0x55041308, 0x02355212, 0x09681fa0, 0x1f350e55,   // et.fi.rw_443 ha.zu.da_654  cy.ig.pl_322 is.zu.cy_442
  0x1b3525a0, 0x0f1729ee, 0x0c352308, 0x2a0712ec,   // eu.zu.tr_322 sl.sr.lv_422  ca.zu.sv_443 hu.it.mt_644

  // [a400]
  0x0800350d, 0x1b00280b, 0x23043504, 0x21001b0c,   // zu.no.un_540 sw.tr.un_520  zu.fi.ca_332 tr.jw.un_530
  0x29100e04, 0x3f321602, 0x6b551b08, 0x0c1325a4,   // is.lt.sl_332 hr.bs.af_222  tr.rw.ceb_443 eu.et.sv_433
  0x1a2b010b, 0x323529a4, 0x320d295e, 0x29081ba7,   // en.vi.tl_542 sl.zu.bs_433  sl.cs.bs_652 tr.no.sl_532
  0x0c1e0308, 0x04100a5a, 0x101b20ec, 0x05132a07,   // nl.ms.sv_443 mk.be.ru_553  sq.tr.lt_644 mt.et.fr_432
  // [a410]
  0x0b183102, 0x060c5307, 0x20001b21, 0x090e100c,   // az.ga.es_222 ht.sv.de_432  tr.sq.un_860 lt.is.pl_543
  0x0e0c27a0, 0x52280e08, 0x1204080c, 0x11281360,   // gd.sv.is_322 is.sw.ha_443  no.fi.hu_543 et.sw.ro_664
  0x2d170d09, 0x01132855, 0x531028ac, 0x1900060b,   // cs.sr.sk_444 sw.et.en_442  sw.lt.ht_632 de.gl.un_520
  0x061b2a07, 0x3b286ba7, 0x25232aaf, 0x1a122104,   // mt.tr.de_432 ceb.sw.so_532  mt.ca.eu_655 jw.hu.tl_332
  // [a420]
  0x120e1f55, 0x18012aad, 0x6b250aad, 0x1f180f5a,   // cy.is.hu_442 mt.en.ga_643  pt.eu.ceb_643 lv.ga.cy_553
  0x0e18270d, 0x02003202, 0x1c282107, 0x07006b21,   // gd.ga.is_554 bs.da.un_220  jw.sw.id_432 ceb.it.un_860
  0x111b310d, 0x286b52a0, 0x10060e55, 0x123217a7,   // az.tr.ro_554 ha.ceb.sw_322  is.de.lt_442 sr.bs.hu_532
  0x323b21ad, 0x28001f11, 0x1b002904, 0x280308a0,   // jw.so.bs_643 cy.sw.un_630  sl.tr.un_320 no.nl.sw_322
  // [a430]
  0x2a5220ac, 0x011927a0, 0x132501a0, 0x351f0107,   // sq.ha.mt_632 gd.gl.en_322  en.eu.et_322 en.cy.zu_432
  0x18003b0c, 0x1e5528ee, 0x1a6b1b60, 0x041306ad,   // so.ga.un_530 sw.rw.ms_422  tr.ceb.tl_664 de.et.fi_643
  0x131a2012, 0x13040aa4, 0x11001308, 0x116b64ee,   // sq.tl.et_654 pt.fi.et_433  et.ro.un_430 lg.ceb.ro_422
  0x08000723, 0x3f000e02, 0x27000c04, 0x1225270d,   // bg.uk.un_880 is.af.un_220  sv.gd.un_320 gd.eu.hu_554
  // [a440]
  0x0308350c, 0x0a170755, 0x32082aa0, 0x1e1c020e,   // zu.no.nl_543 bg.sr.mk_442  mt.no.bs_322 da.id.ms_555
  0x291617a9, 0x13060cee, 0x233511ad, 0x11002102,   // sr.hr.sl_544 sv.de.et_422  ro.zu.ca_643 jw.ro.un_220
  0x03000412, 0x271e1cac, 0x29171614, 0x356b1f0b,   // fi.nl.un_640 id.ms.gd_632  hr.sr.sl_666 cy.ceb.zu_542
  0x17002d02, 0x013f1aa0, 0x2b086404, 0x31090dee,   // sk.sr.un_220 tl.af.en_322  lg.no.vi_332 cs.pl.az_422
  // [a450]
  0x351e1c14, 0x1f3568a0, 0x31001212, 0x071c05a0,   // id.ms.zu_666 ig.zu.cy_322  hu.az.un_640 fr.id.it_322
  0x32162d02, 0x6b033511, 0x552864ee, 0x0e081309,   // sk.hr.bs_222 zu.nl.ceb_653  lg.sw.rw_422 et.no.is_444
  0x01030504, 0x35642811, 0x1b005508, 0x180135a7,   // fr.nl.en_332 sw.lg.zu_653  rw.tr.un_430 zu.en.ga_532
  0x17006404, 0x05110309, 0x64134a5a, 0x23055307,   // lg.sr.un_320 nl.ro.fr_444  yo.et.lg_553 ht.fr.ca_432
  // [a460]
  0x0b005505, 0x28072a0c, 0x04212804, 0x1c003202,   // rw.es.un_330 mt.it.sw_543  sw.jw.fi_332 bs.id.un_220
  0x28002504, 0x113128a4, 0x0e6455ec, 0x06001104,   // eu.sw.un_320 sw.az.ro_433  rw.lg.is_644 ro.de.un_320
  0x21003102, 0x13215204, 0x06012007, 0x352a2012,   // az.jw.un_220 ha.jw.et_332  sq.en.de_432 sq.mt.zu_654
  0x2a0728ac, 0x2a131aa4, 0x55001f02, 0x28686412,   // sw.it.mt_632 tl.et.mt_433  cy.rw.un_220 lg.ig.sw_654
  // [a470]
  0x645328ec, 0x2a130107, 0x21016ba0, 0x080c12a4,   // sw.ht.lg_644 en.et.mt_432  ceb.en.jw_322 hu.sv.no_433
  0x20121304, 0x072028ee, 0x5500110c, 0x3f3528ad,   // et.hu.sq_332 sw.sq.it_422  ro.rw.un_530 sw.zu.af_643
  0x3f6b5507, 0x070a64ad, 0x1f3b35a4, 0x32001e02,   // rw.ceb.af_432 lg.pt.it_643  zu.so.cy_433 ms.bs.un_220
  0x1a3b55ee, 0x273f0107, 0x350968a9, 0x110c53ee,   // rw.so.tl_422 en.af.gd_432  ig.pl.zu_544 ht.sv.ro_422
  // [a480]
  0x2a07180c, 0x271301ee, 0x1827130c, 0x31000304,   // ga.it.mt_543 en.et.gd_422  et.gd.ga_543 nl.az.un_320
  0x0c0e3fee, 0x16001002, 0x6b2701ad, 0x102313a9,   // af.is.sv_422 lt.hr.un_220  en.gd.ceb_643 et.ca.lt_544
  0x120420af, 0x10052855, 0x03073f09, 0x13536b04,   // sq.fi.hu_655 sw.fr.lt_442  af.it.nl_444 ceb.ht.et_332
  0x3f1053ec, 0x1a276b07, 0x2a0b1007, 0x53041004,   // ht.lt.af_644 ceb.gd.tl_432  lt.es.mt_432 lt.fi.ht_332
  // [a490]
  0x03073fa9, 0x1a5568a0, 0x53102509, 0x082a25ad,   // af.it.nl_544 ig.rw.tl_322  eu.lt.ht_444 eu.mt.no_643
  0x080413ee, 0x0e001f22, 0x190a2502, 0x32102d07,   // et.fi.no_422 cy.is.un_870  eu.pt.gl_222 sk.lt.bs_432
  0x3f27100b, 0x11000614, 0x642a10af, 0x120c08ee,   // lt.gd.af_542 de.ro.un_660  lt.mt.lg_655 no.sv.hu_422
  0x07110a0b, 0x10286413, 0x286410ec, 0x21641007,   // mk.ro.bg_542 lg.sw.lt_665  lt.lg.sw_644 lt.lg.jw_432
  // [a4a0]
  0x52064a08, 0x2023110c, 0x1b2d0d02, 0x2a1f05ec,   // yo.de.ha_443 ro.ca.sq_543  cs.sk.tr_222 fr.cy.mt_644
  0x1b07350c, 0x111335ec, 0x13351108, 0x0a3504a6,   // zu.it.tr_543 zu.et.ro_644  ro.zu.et_443 fi.zu.pt_521
  0x171608a0, 0x32133508, 0x2818010c, 0x133f6408,   // no.hr.sr_322 zu.et.bs_443  en.ga.sw_543 lg.af.et_443
  0x283564a4, 0x35070508, 0x13000314, 0x1f010611,   // lg.zu.sw_433 fr.it.zu_443  nl.et.un_660 de.en.cy_653
  // [a4b0]
  0x2b1c13a4, 0x041c2502, 0x3b00030c, 0x03052307,   // et.id.vi_433 eu.id.fi_222  nl.so.un_530 ca.fr.nl_432
  0x531135a4, 0x13003507, 0x3f643ba9, 0x273b1ca0,   // zu.ro.ht_433 zu.et.un_420  so.lg.af_544 id.so.gd_322
  0x130711ec, 0x092a4aee, 0x114a3508, 0x13031a14,   // ro.it.et_644 yo.mt.pl_422  zu.yo.ro_443 tl.nl.et_666
  0x1a133b60, 0x6b133b04, 0x211c2a05, 0x02065204,   // so.et.tl_664 so.et.ceb_332  mt.id.jw_333 ha.de.da_332
  // [a4c0]
  0x280952a0, 0x19206408, 0x550f03ee, 0x0f0610a0,   // ha.pl.sw_322 lg.sq.gl_443  nl.lv.rw_422 lt.de.lv_322
  0x20321ba0, 0x044a550c, 0x10092aee, 0x181c28a0,   // tr.bs.sq_322 rw.yo.fi_543  mt.pl.lt_422 sw.id.ga_322
  0x68005322, 0x100a1108, 0x090507a0, 0x092a07af,   // ht.ig.un_870 ro.mk.be_443  it.fr.pl_322 it.mt.pl_655
  0x086b31a0, 0x351355a7, 0x280b2b0b, 0x18272b5a,   // az.ceb.no_322 rw.et.zu_532  vi.es.sw_542 vi.gd.ga_553
  // [a4d0]
  0x3b2720ec, 0x11521b08, 0x0c3568ee, 0x03352b07,   // sq.gd.so_644 tr.ha.ro_443  ig.zu.sv_422 vi.zu.nl_432
  0x03002502, 0x13086eec, 0x111c01ee, 0x55002802,   // eu.nl.un_220 hmn.no.et_644  en.id.ro_422 sw.rw.un_220
  0x05001704, 0x03290955, 0x27185204, 0x3f201ca0,   // sr.fr.un_320 pl.sl.nl_442  ha.ga.gd_332 id.sq.af_322
  0x050a1fa0, 0x27182b04, 0x6b1f01ee, 0x0a005305,   // cy.pt.fr_322 vi.ga.gd_332  en.cy.ceb_422 ht.pt.un_330
  // [a4e0]
  0x04311b0c, 0x6b000120, 0x271c1fa4, 0x27180107,   // tr.az.fi_543 en.ceb.un_850  cy.id.gd_433 en.ga.gd_432
  0x1f00182c, 0x6b3508a0, 0x64251307, 0x3b110407,   // ga.cy.un_990 no.zu.ceb_322  et.eu.lg_432 fi.ro.so_432
  0x0e522105, 0x270d1812, 0x12002134, 0x0c120207,   // jw.ha.is_333 ga.cs.gd_654  fa.ur.un_A80 da.hu.sv_432
  0x0f120eee, 0x251b520c, 0x18000111, 0x1e231fa0,   // is.hu.lv_422 ha.tr.eu_543  en.ga.un_630 cy.ca.ms_322
  // [a4f0]
  0x0e0501a4, 0x05351308, 0x3528555a, 0x251b13ec,   // en.fr.is_433 et.zu.fr_443  rw.sw.zu_553 et.tr.eu_644
  0x211204a0, 0x13080c0c, 0x1b25130c, 0x1b4a1307,   // fi.hu.jw_322 sv.no.et_543  et.eu.tr_543 et.yo.tr_432
  0x13040a0c, 0x13114aa0, 0x311b520e, 0x556410af,   // pt.fi.et_543 yo.ro.et_322  ha.tr.az_555 lt.lg.rw_655
  0x18310812, 0x280155a4, 0x2b030508, 0x31200f05,   // no.az.ga_654 rw.en.sw_433  fr.nl.vi_443 lv.sq.az_333
  // [a500]
  0x2a00551a, 0x53052b04, 0x06531b07, 0x2a005513,   // rw.mt.un_760 vi.fr.ht_332  tr.ht.de_432 rw.mt.un_650
  0x05532b02, 0x13060c07, 0x0835010c, 0x2a4a5508,   // vi.ht.fr_222 sv.de.et_432  en.zu.no_543 rw.yo.mt_443
  0x01131ba4, 0x640f5512, 0x04210107, 0x6b520c07,   // tr.et.en_433 rw.lv.lg_654  en.jw.fi_432 sv.ha.ceb_432
  0x21054a0c, 0x290507a7, 0x352a0407, 0x060413ad,   // yo.fr.jw_543 it.fr.sl_532  fi.mt.zu_432 et.fi.de_643
  // [a510]
  0x28322aa7, 0x55002a1a, 0x3b211aec, 0x17311ba4,   // mt.bs.sw_532 mt.rw.un_760  tl.jw.so_644 tr.az.sr_433
  0x4a002a04, 0x3b205208, 0x1c0921ee, 0x2100251b,   // mt.yo.un_320 ha.sq.so_443  jw.pl.id_422 eu.jw.un_770
  0x53201eee, 0x291c1a0c, 0x1c082807, 0x320701a7,   // ms.sq.ht_422 tl.id.sl_543  sw.no.id_432 en.it.bs_532
  0x3b2501a0, 0x3b531808, 0x1a0b3b09, 0x25121b04,   // en.eu.so_322 ga.ht.so_443  so.es.tl_444 tr.hu.eu_332
  // [a520]
  0x2a1001a0, 0x010b0a09, 0x01313bee, 0x16202912,   // en.lt.mt_322 pt.es.en_444  so.az.en_422 sl.sq.hr_654
  0x02120c04, 0x062b1804, 0x17005221, 0x106b1a0d,   // sv.hu.da_332 ga.vi.de_332  ha.sr.un_860 tl.ceb.lt_554
  0x0c040812, 0x3b002834, 0x1c6b1e0c, 0x55006b07,   // no.fi.sv_654 sw.so.un_A80  ms.ceb.id_543 ceb.rw.un_420
  0x552864a0, 0x021008a4, 0x0e1729ac, 0x3b64280c,   // lg.sw.rw_322 no.lt.da_433  sl.sr.is_632 sw.lg.so_543
  // [a530]
  0x0607250d, 0x10020f13, 0x271107ad, 0x16351aad,   // eu.it.de_554 lv.da.lt_665  it.ro.gd_643 tl.zu.hr_643
  0x111827ac, 0x1e1c1309, 0x5500520d, 0x3500200e,   // gd.ga.ro_632 et.id.ms_444  ha.rw.un_540 sq.zu.un_550
  0x0e290f0c, 0x29001e21, 0x23290bee, 0x182027ad,   // lv.sl.is_543 ms.sl.un_860  es.sl.ca_422 gd.sq.ga_643
  0x1e1c04ee, 0x120364ee, 0x13190bee, 0x32003105,   // fi.id.ms_422 lg.nl.hu_422  es.gl.et_422 az.bs.un_330
  // [a540]
  0x0a00640c, 0x3f090804, 0x0c1b28ee, 0x0e0d2dec,   // lg.pt.un_530 no.pl.af_332  sw.tr.sv_422 sk.cs.is_644
  0x08021b02, 0x2a0918ee, 0x31002808, 0x18051108,   // tr.da.no_222 ga.pl.mt_422  sw.az.un_430 ro.fr.ga_443
  0x21312da0, 0x06001008, 0x352855ec, 0x16110f55,   // sk.az.jw_322 lt.de.un_430  rw.sw.zu_644 lv.ro.hr_442
  0x021b0604, 0x322129a0, 0x6b532802, 0x206b08a0,   // de.tr.da_332 sl.jw.bs_322  sw.ht.ceb_222 no.ceb.sq_322
  // [a550]
  0x121a27a7, 0x27003504, 0x2b00180c, 0x3b524aa0,   // gd.tl.hu_532 zu.gd.un_320  ga.vi.un_530 yo.ha.so_322
  0x0d001a04, 0x1227180c, 0x3b1f1e05, 0x07211c0c,   // tl.cs.un_320 ga.gd.hu_543  ms.cy.so_333 id.jw.it_543
  0x28251e12, 0x23530c04, 0x181127af, 0x5235550b,   // ms.eu.sw_654 sv.ht.ca_332  gd.ro.ga_655 rw.zu.ha_542
  0x053b2704, 0x0a190b07, 0x122952a6, 0x0b1f5208,   // gd.so.fr_332 es.gl.pt_432  ha.sl.hu_521 ha.cy.es_443
  // [a560]
  0x285255a0, 0x55020812, 0x0d003520, 0x101b06af,   // rw.ha.sw_322 no.da.rw_654  zu.cs.un_850 de.tr.lt_655
  0x64352007, 0x13525513, 0x283b01a0, 0x041c550c,   // sq.zu.lg_432 rw.ha.et_665  en.so.sw_322 rw.id.fi_543
  0x6b005212, 0x3f006402, 0x02045208, 0x1f52280c,   // ha.ceb.un_640 lg.af.un_220  ha.fi.da_443 sw.ha.cy_543
  0x29080207, 0x642855a0, 0x2b6b1a0b, 0x273f02ad,   // da.no.sl_432 rw.sw.lg_322  tl.ceb.vi_542 da.af.gd_643
  // [a570]
  0x080255ee, 0x035501a4, 0x03070507, 0x0f283504,   // rw.da.no_422 en.rw.nl_433  fr.it.nl_432 zu.sw.lv_332
  0x190b35ad, 0x3f1308a0, 0x353f0311, 0x13210c05,   // zu.es.gl_643 no.et.af_322  nl.af.zu_653 sv.jw.et_333
  0x3b001213, 0x0821350c, 0x1113350c, 0x35281a07,   // hu.so.un_650 zu.jw.no_543  zu.et.ro_543 tl.sw.zu_432
  0x683564af, 0x1e351104, 0x25350308, 0x2d521aee,   // lg.zu.ig_655 ro.zu.ms_332  nl.zu.eu_443 tl.ha.sk_422
  // [a580]
  0x0c08290c, 0x64001902, 0x11351fee, 0x28016405,   // sl.no.sv_543 gl.lg.un_220  cy.zu.ro_422 lg.en.sw_333
  0x5513280c, 0x3f160f07, 0x01350ba4, 0x6435525a,   // sw.et.rw_543 lv.hr.af_432  es.zu.en_433 ha.zu.lg_553
  0x5208040c, 0x09352513, 0x100813a0, 0x280a0da0,   // fi.no.ha_543 eu.zu.pl_665  et.no.lt_322 cs.pt.sw_322
  0x1e1c2155, 0x190b55ec, 0x0a6e050c, 0x554a2aec,   // jw.id.ms_442 rw.es.gl_644  fr.hmn.pt_543 mt.yo.rw_644
  // [a590]
  0x0a3b190c, 0x0e1f0c0d, 0x082a07a7, 0x0811170c,   // gl.so.pt_543 sv.cy.is_554  it.mt.no_532 sr.ro.uk_543
  0x1c351ea4, 0x28321613, 0x21006e0d, 0x1b64350d,   // ms.zu.id_433 hr.bs.sw_665  hmn.jw.un_540 zu.lg.tr_554
  0x31000a19, 0x17003512, 0x642a550c, 0x0a0b190b,   // pt.az.un_750 zu.sr.un_640  rw.mt.lg_543 gl.es.pt_542
  0x531c3fa0, 0x211a350b, 0x53522807, 0x3f005309,   // af.id.ht_322 zu.tl.jw_542  sw.ha.ht_432 ht.af.un_440
  // [a5a0]
  0x0e3f1f04, 0x070523a0, 0x28190b07, 0x01000912,   // cy.af.is_332 ca.fr.it_322  es.gl.sw_432 pl.en.un_640
  0x130c010b, 0x3b012aee, 0x28310b05, 0x010309a6,   // en.sv.et_542 mt.en.so_422  es.az.sw_333 pl.nl.en_521
  0x180b19a0, 0x0500271b, 0x2a0201a4, 0x3f182707,   // gl.es.ga_322 gd.fr.un_770  en.da.mt_433 gd.ga.af_432
  0x1f312308, 0x05200107, 0x52270c12, 0x353f0104,   // ca.az.cy_443 en.sq.fr_432  sv.gd.ha_654 en.af.zu_332
  // [a5b0]
  0x1053680d, 0x233b01a4, 0x55116807, 0x200c080c,   // ig.ht.lt_554 en.so.ca_433  ig.ro.rw_432 no.sv.sq_543
  0x6b1827ad, 0x0d0a0ea9, 0x0511290c, 0x060c20a0,   // gd.ga.ceb_643 is.pt.cs_544  sl.ro.fr_543 sq.sv.de_322
  0x295301a0, 0x2109550d, 0x19110a05, 0x160b1fa7,   // en.ht.sl_322 rw.pl.jw_554  pt.ro.gl_333 cy.es.hr_532
  0x2b000d0b, 0x132a20ee, 0x081220ad, 0x3b081ca7,   // cs.vi.un_520 sq.mt.et_422  sq.hu.no_643 id.no.so_532
  // [a5c0]
  0x6400530e, 0x1e53100c, 0x1b5535a7, 0x16553508,   // ht.lg.un_550 lt.ht.ms_543  zu.rw.tr_532 zu.rw.hr_443
  0x64162807, 0x35001b0d, 0x202832a0, 0x103528ee,   // sw.hr.lg_432 tr.zu.un_540  bs.sw.sq_322 sw.zu.lt_422
  0x2b1e1c02, 0x0b292d12, 0x160c0807, 0x1c211f04,   // id.ms.vi_222 sk.sl.es_654  no.sv.hr_432 cy.jw.id_332
  0x21003108, 0x10280da4, 0x0b090709, 0x28013504,   // az.jw.un_430 cs.sw.lt_433  it.pl.es_444 zu.en.sw_332
  // [a5d0]
  0x13080707, 0x18072707, 0x6e6b01ee, 0x1725280c,   // it.no.et_432 gd.it.ga_432  en.ceb.hmn_422 sw.eu.sr_543
  0x04282560, 0x0f202a0c, 0x28555312, 0x28001905,   // eu.sw.fi_664 mt.sq.lv_543  ht.rw.sw_654 gl.sw.un_330
  0x0c0f1005, 0x091f1804, 0x25640c55, 0x25211ca9,   // lt.lv.sv_333 ga.cy.pl_332  sv.lg.eu_442 id.jw.eu_544
  0x641a4aaf, 0x00000737, 0x356413a0, 0x0a080107,   // yo.tl.lg_655 it.un.un_B00  et.lg.zu_322 en.no.pt_432
  // [a5e0]
  0x11071308, 0x2b00181b, 0x03162907, 0x31041ba9,   // et.it.ro_443 ga.vi.un_770  sl.hr.nl_432 tr.fi.az_544
  0x202a13a4, 0x355513af, 0x060c1205, 0x64352108,   // et.mt.sq_433 et.rw.zu_655  hu.sv.de_333 jw.zu.lg_443
  0x352955a4, 0x1e0d1802, 0x0a07310c, 0x0964550c,   // rw.sl.zu_433 ga.cs.ms_222  az.it.pt_543 rw.lg.pl_543
  0x1b23310c, 0x6b112004, 0x106428a4, 0x2564350c,   // az.ca.tr_543 sq.ro.ceb_332  sw.lg.lt_433 zu.lg.eu_543
  // [a5f0]
  0x0c356b55, 0x030608a0, 0x23000f12, 0x050d2da0,   // ceb.zu.sv_442 no.de.nl_322  lv.ca.un_640 sk.cs.fr_322
  0x200f10af, 0x19640aa0, 0x64283504, 0x1a1255ee,   // lt.lv.sq_655 pt.lg.gl_322  zu.sw.lg_332 rw.hu.tl_422
  0x53124a02, 0x0e121804, 0x251c1e07, 0x01130304,   // yo.hu.ht_222 ga.hu.is_332  ms.id.eu_432 nl.et.en_332
  0x35002307, 0x0a11175a, 0x09000e09, 0x0e1208ee,   // ca.zu.un_420 sr.ro.mk_553  is.pl.un_440 no.hu.is_422
  // [a600]
  0x050c11a4, 0x136b2aa0, 0x1f062da6, 0x23060ca7,   // ro.sv.fr_433 mt.ceb.et_322  sk.de.cy_521 sv.de.ca_532
  0x2a5204ad, 0x2100170c, 0x1f050ca0, 0x0b004a1a,   // fi.ha.mt_643 sr.jw.un_530  sv.fr.cy_322 yo.es.un_760
  0x643b1b07, 0x2a3220a7, 0x21232aee, 0x520e2805,   // tr.so.lg_432 sq.bs.mt_532  mt.ca.jw_422 sw.is.ha_333
  0x21551ea9, 0x28684a0d, 0x08031208, 0x25552808,   // ms.rw.jw_544 yo.ig.sw_554  hu.nl.no_443 sw.rw.eu_443
  // [a610]
  0x4a55520c, 0x23070207, 0x1b312012, 0x12080eaf,   // ha.rw.yo_543 da.it.ca_432  sq.az.tr_654 is.no.hu_655
  0x07292da0, 0x21006812, 0x522555a4, 0x522168ec,   // sk.sl.it_322 ig.jw.un_640  rw.eu.ha_433 ig.jw.ha_644
  0x10645207, 0x2a313ba0, 0x1b3504a4, 0x0c3513a4,   // ha.lg.lt_432 so.az.mt_322  fi.zu.tr_433 et.zu.sv_433
  0x0617130e, 0x1b2904ee, 0x551c1ba4, 0x032153ee,   // et.sr.de_555 fi.sl.tr_422  tr.id.rw_433 ht.jw.nl_422
  // [a620]
  0x640b0407, 0x250413af, 0x553552a0, 0x31002a07,   // fi.es.lg_432 et.fi.eu_655  ha.zu.rw_322 mt.az.un_420
  0x18122105, 0x29040d08, 0x02355511, 0x0f005202,   // fa.ur.ar_333 cs.fi.sl_443  rw.zu.da_653 ha.lv.un_220
  0x06005218, 0x25125555, 0x213155ee, 0x1327180b,   // ha.de.un_740 rw.hu.eu_442  rw.az.jw_422 ga.gd.et_542
  0x35555212, 0x250f13ee, 0x250c13a4, 0x05002714,   // ha.rw.zu_654 et.lv.eu_422  et.sv.eu_433 gd.fr.un_660
  // [a630]
  0x17290404, 0x07050c05, 0x033f1c04, 0x051a02ee,   // fi.sl.sr_332 sv.fr.it_333  id.af.nl_332 da.tl.fr_422
  0x1f6b090c, 0x0f00061a, 0x68281e12, 0x06020fad,   // pl.ceb.cy_543 de.lv.un_760  ms.sw.ig_654 lv.da.de_643
  0x292705ad, 0x16000507, 0x27013b04, 0x2a2864ad,   // fr.gd.sl_643 fr.hr.un_420  so.en.gd_332 lg.sw.mt_643
  0x2a000c07, 0x25296808, 0x64212907, 0x11002323,   // sv.mt.un_420 ig.sl.eu_443  sl.jw.lg_432 ca.ro.un_880
  // [a640]
  0x12110107, 0x2000090e, 0x102925a0, 0x1e1c0cee,   // en.ro.hu_432 pl.sq.un_550  eu.sl.lt_322 sv.id.ms_422
  0x68002a0c, 0x02252a07, 0x080e10a4, 0x10171602,   // mt.ig.un_530 mt.eu.da_432  lt.is.no_433 hr.sr.lt_222
  0x13000621, 0x2d180ba9, 0x032a20af, 0x17531e0b,   // de.et.un_860 es.ga.sk_544  sq.mt.nl_655 ms.ht.sr_542
  0x02060107, 0x271101a9, 0x55352da4, 0x20352804,   // en.de.da_432 en.ro.gd_544  sk.zu.rw_433 sw.zu.sq_332
  // [a650]
  0x250803a0, 0x280104ee, 0x2b0121ee, 0x08001a04,   // nl.no.eu_322 fi.en.sw_422  jw.en.vi_422 tl.no.un_320
  0x0f06120d, 0x35002018, 0x08020405, 0x2a08120e,   // hu.de.lv_554 sq.zu.un_740  fi.da.no_333 hu.no.mt_555
  0x1b3b31ec, 0x050d01ec, 0x013f03af, 0x6b1f1a5a,   // az.so.tr_644 en.cs.fr_644  nl.af.en_655 tl.cy.ceb_553
  0x4a643bee, 0x01033f08, 0x3f100a07, 0x1a1c12a4,   // so.lg.yo_422 af.nl.en_443  pt.lt.af_432 hu.id.tl_433
  // [a660]
  0x216b1aee, 0x031c1e0c, 0x1200080d, 0x0a0911a7,   // tl.ceb.jw_422 ms.id.nl_543  no.hu.un_540 ro.pl.pt_532
  0x133b6405, 0x27201f0c, 0x2a0e0407, 0x0c045212,   // lg.so.et_333 cy.sq.gd_543  fi.is.mt_432 ha.fi.sv_654
  0x6e032107, 0x0d2d1260, 0x310453ec, 0x0e000d0e,   // jw.nl.hmn_432 hu.sk.cs_664  ht.fi.az_644 cs.is.un_550
  0x182720ad, 0x1a00532a, 0x01030faf, 0x3f200807,   // sq.gd.ga_643 ht.tl.un_970  lv.nl.en_655 no.sq.af_432
  // [a670]
  0x0e000a19, 0x31281e07, 0x0305010b, 0x68536b0c,   // pt.is.un_750 ms.sw.az_432  en.fr.nl_542 ceb.ht.ig_543
  0x03270613, 0x06233fad, 0x23013f0c, 0x043b2707,   // de.gd.nl_665 af.ca.de_643  af.en.ca_543 gd.so.fi_432
  0x18000a18, 0x2d643508, 0x1a060cee, 0x3f2d0904,   // pt.ga.un_740 zu.lg.sk_443  sv.de.tl_422 pl.sk.af_332
  0x0e181912, 0x08021b05, 0x3f1b5307, 0x010a4a04,   // gl.ga.is_654 tr.da.no_333  ht.tr.af_432 yo.pt.en_332
  // [a680]
  0x13251ea4, 0x25681309, 0x04251308, 0x2d535505,   // ms.eu.et_433 et.ig.eu_444  et.eu.fi_443 rw.ht.sk_333
  0x1312530b, 0x21250c08, 0x11000b08, 0x1b006b19,   // ht.hu.et_542 sv.eu.jw_443  es.ro.un_430 ceb.tr.un_750
  0x03000714, 0x2d0f0d0c, 0x642d0d07, 0x092025a9,   // it.nl.un_660 cs.lv.sk_543  cs.sk.lg_432 eu.sq.pl_544
  0x211b020c, 0x3b1364a7, 0x286420af, 0x0a16230c,   // da.tr.jw_543 lg.et.so_532  sq.lg.sw_655 ca.hr.pt_543
  // [a690]
  0x64682109, 0x182b28a0, 0x0b051104, 0x2021130c,   // jw.ig.lg_444 sw.vi.ga_322  ro.fr.es_332 et.jw.sq_543
  0x080f0c04, 0x3f080f04, 0x18003f04, 0x0a006b0b,   // sv.lv.no_332 lv.no.af_332  af.ga.un_320 ceb.pt.un_520
  0x29001c02, 0x1c130d12, 0x180c1304, 0x080221ee,   // id.sl.un_220 ne.bh.mr_654  et.sv.ga_332 jw.da.no_422
  0x27006b34, 0x123501a9, 0x131f3b08, 0x283518a9,   // ceb.gd.un_A80 en.zu.hu_544  so.cy.et_443 ga.zu.sw_544
  // [a6a0]
  0x2b35050c, 0x6b030ca0, 0x0c0f3fa0, 0x0e081bad,   // fr.zu.vi_543 sv.nl.ceb_322  af.lv.sv_322 tr.no.is_643
  0x6864350c, 0x0d180aaf, 0x072a1212, 0x082a06a0,   // zu.lg.ig_543 pt.ga.cs_655  hu.mt.it_654 de.mt.no_322
  0x171b2304, 0x20210204, 0x0d3119ee, 0x080212ee,   // ca.tr.sr_332 da.jw.sq_332  gl.az.cs_422 hu.da.no_422
  0x292a0dee, 0x1f0827ac, 0x323b0f10, 0x290c0e11,   // cs.mt.sl_422 gd.no.cy_632  lv.so.bs_642 is.sv.sl_653
  // [a6b0]
  0x04641804, 0x53016e02, 0x0d00550d, 0x350364ec,   // ga.lg.fi_332 hmn.en.ht_222  rw.cs.un_540 lg.nl.zu_644
  0x27006812, 0x09001a04, 0x21645555, 0x55641a13,   // ig.gd.un_640 tl.pl.un_320  rw.lg.jw_442 tl.lg.rw_665
  0x20006413, 0x350d64ad, 0x0a1007a0, 0x3b04200c,   // lg.sq.un_650 lg.cs.zu_643  bg.be.mk_322 sq.fi.so_543
  0x180452a0, 0x130464af, 0x060902a0, 0x1e1064ad,   // ha.fi.ga_322 lg.fi.et_655  da.pl.de_322 lg.lt.ms_643
  // [a6c0]
  0x03110208, 0x2d060dad, 0x52000813, 0x011809a4,   // da.ro.nl_443 cs.de.sk_643  no.ha.un_650 pl.ga.en_433
  0x20126b04, 0x296416ee, 0x5300190d, 0x1200060c,   // ceb.hu.sq_332 hr.lg.sl_422  gl.ht.un_540 de.hu.un_530
  0x1e1a53a4, 0x0e133f04, 0x183527a7, 0x07170802,   // ht.tl.ms_433 af.et.is_332  gd.zu.ga_532 uk.sr.bg_222
  0x3f640455, 0x0f286412, 0x04643512, 0x190a2da4,   // fi.lg.af_442 lg.sw.lv_654  zu.lg.fi_654 sk.pt.gl_433
  // [a6d0]
  0x0a111304, 0x05232b08, 0x2153230c, 0x05101fec,   // et.ro.pt_332 vi.ca.fr_443  ca.ht.jw_543 cy.lt.fr_644
  0x281a5512, 0x041a2807, 0x28041311, 0x68350d07,   // rw.tl.sw_654 sw.tl.fi_432  et.fi.sw_653 cs.zu.ig_432
  0x21521b09, 0x13551a07, 0x1f09350c, 0x09351ea0,   // tr.ha.jw_444 tl.rw.et_432  zu.pl.cy_543 ms.zu.pl_322
  0x13092d0c, 0x0c0f13a0, 0x0e3553a9, 0x033f0811,   // sk.pl.et_543 et.lv.sv_322  ht.zu.is_544 no.af.nl_653
  // [a6e0]
  0x556b1a08, 0x3b040f04, 0x293216ee, 0x28131a04,   // tl.ceb.rw_443 lv.fi.so_332  hr.bs.sl_422 tl.et.sw_332
  0x0e000202, 0x06552805, 0x216b1a07, 0x1b060c12,   // da.is.un_220 sw.rw.de_333  tl.ceb.jw_432 sv.de.tr_654
  0x0b1f23af, 0x25041308, 0x3500642a, 0x64212305,   // ca.cy.es_655 et.fi.eu_443  lg.zu.un_970 ca.jw.lg_333
  0x201f0107, 0x250b01ee, 0x20131e0c, 0x530913a9,   // en.cy.sq_432 en.es.eu_422  ms.et.sq_543 et.pl.ht_544
  // [a6f0]
  0x25643507, 0x552d0314, 0x552112ad, 0x53290305,   // zu.lg.eu_432 nl.sk.rw_666  hu.jw.rw_643 nl.sl.ht_333
  0x1e1c2902, 0x02030e0c, 0x03552808, 0x201164a0,   // sl.id.ms_222 is.nl.da_543  sw.rw.nl_443 lg.ro.sq_322
  0x552d1ba4, 0x1f5301a0, 0x20001102, 0x21014a07,   // tr.sk.rw_433 en.ht.cy_322  ro.sq.un_220 yo.en.jw_432
  0x68355512, 0x55000b09, 0x20521ea4, 0x08023b0b,   // rw.zu.ig_654 es.rw.un_440  ms.ha.sq_433 so.da.no_542
  // [a700]
  0x0a001c08, 0x280b55a4, 0x0c0809af, 0x1c3f2807,   // id.pt.un_430 rw.es.sw_433  pl.no.sv_655 sw.af.id_432
  0x321752a0, 0x072d2907, 0x07042055, 0x07001321,   // ha.sr.bs_322 sl.sk.it_432  sq.fi.it_442 et.it.un_860
  0x32092907, 0x1c3b2102, 0x1b532104, 0x071f2904,   // sl.pl.bs_432 jw.so.id_222  jw.ht.tr_332 sl.cy.it_332
  0x6e003f04, 0x060c1f10, 0x050e1fee, 0x0d6b1fee,   // af.hmn.un_320 cy.sv.de_642  cy.is.fr_422 cy.ceb.cs_422
  // [a710]
  0x3b040c0c, 0x131f31a9, 0x522125a0, 0x1c3b27a4,   // sv.fi.so_543 az.cy.et_544  eu.jw.ha_322 gd.so.id_433
  0x04251ca7, 0x31005321, 0x3f0e3ba4, 0x1a215312,   // id.eu.fi_532 ht.az.un_860  so.is.af_433 ht.jw.tl_654
  0x1f6b0eec, 0x12001b11, 0x032a130c, 0x271e1c08,   // is.ceb.cy_644 tr.hu.un_630  et.mt.nl_543 id.ms.gd_443
  0x521b3ba4, 0x1a3b0ba0, 0x02180107, 0x27050411,   // so.tr.ha_433 es.so.tl_322  en.ga.da_432 fi.fr.gd_653
  // [a720]
  0x29111304, 0x12200607, 0x0c6406ee, 0x1f1a1bee,   // et.ro.sl_332 de.sq.hu_432  de.lg.sv_422 tr.tl.cy_422
  0x01034aa0, 0x0c060ea0, 0x27000407, 0x16000607,   // yo.nl.en_322 is.de.sv_322  fi.gd.un_420 de.hr.un_420
  0x182b01ad, 0x2b000504, 0x272504ec, 0x12130908,   // en.vi.ga_643 fr.vi.un_320  fi.eu.gd_644 pl.et.hu_443
  0x2012130c, 0x6b251304, 0x080253ec, 0x21201c04,   // et.hu.sq_543 et.eu.ceb_332  ht.da.no_644 id.sq.jw_332
  // [a730]
  0x201325a4, 0x104a2008, 0x13645508, 0x0d071304,   // eu.et.sq_433 sq.yo.lt_443  rw.lg.et_443 et.it.cs_332
  0x0f030ea7, 0x19000d04, 0x6b6864a9, 0x280e13ad,   // is.nl.lv_532 cs.gl.un_320  lg.ig.ceb_544 et.is.sw_643
  0x28355507, 0x3b00682a, 0x060e3fa4, 0x1c012d07,   // rw.zu.sw_432 ig.so.un_970  af.is.de_433 sk.en.id_432
  0x041013a4, 0x201312a0, 0x1a0c0807, 0x11002a02,   // et.lt.fi_433 hu.et.sq_322  no.sv.tl_432 mt.ro.un_220
  // [a740]
  0x21040204, 0x29090f0e, 0x1f520407, 0x522d04ac,   // da.fi.jw_332 lv.pl.sl_555  fi.ha.cy_432 fi.sk.ha_632
  0x181e1cee, 0x35000e09, 0x3f080f07, 0x55354aad,   // id.ms.ga_422 is.zu.un_440  lv.no.af_432 yo.zu.rw_643
  0x21531bad, 0x11000d0d, 0x6b211ea0, 0x284a64a7,   // tr.ht.jw_643 cs.ro.un_540  ms.jw.ceb_322 lg.yo.sw_532
  0x311b1904, 0x1e0e1ca0, 0x080e64a0, 0x17110aa7,   // gl.tr.az_332 id.is.ms_322  lg.is.no_322 mk.ro.sr_532
  // [a750]
  0x2d0d4aec, 0x6b1f1b04, 0x531264a6, 0x0e182dad,   // yo.cs.sk_644 tr.cy.ceb_332  lg.hu.ht_521 sk.ga.is_643
  0x1b045204, 0x0e003521, 0x190b4a09, 0x17001e04,   // ha.fi.tr_332 zu.is.un_860  yo.es.gl_444 ms.sr.un_320
  0x35060ea4, 0x314a1eee, 0x1b3b0504, 0x2700550c,   // is.de.zu_433 ms.yo.az_422  fr.so.tr_332 rw.gd.un_530
  0x074a19a0, 0x31682105, 0x19005319, 0x3f1f040d,   // gl.yo.it_322 jw.ig.az_333  ht.gl.un_750 fi.cy.af_554
  // [a760]
  0x1f003f1a, 0x2b212512, 0x25006b1a, 0x6b2125a0,   // af.cy.un_760 eu.jw.vi_654  ceb.eu.un_760 eu.jw.ceb_322
  0x190b2da0, 0x25002122, 0x53072305, 0x28000713,   // sk.es.gl_322 jw.eu.un_870  ca.it.ht_333 it.sw.un_650
  0x25643511, 0x2b6b2512, 0x1c002518, 0x0c106b0c,   // zu.lg.eu_653 eu.ceb.vi_654  eu.id.un_740 ceb.lt.sv_543
  0x03190b08, 0x2b00250e, 0x2d0d18ee, 0x030511ee,   // es.gl.nl_443 eu.vi.un_550  ga.cs.sk_422 ro.fr.nl_422
  // [a770]
  0x0b110560, 0x1c041b07, 0x0f003b19, 0x255535a4,   // fr.ro.es_664 tr.fi.id_432  so.lv.un_750 zu.rw.eu_433
  0x55351211, 0x1f000607, 0x55001105, 0x11095507,   // hu.zu.rw_653 de.cy.un_420  ro.rw.un_330 rw.pl.ro_432
  0x31193507, 0x0a080202, 0x13521aa0, 0x5511350c,   // zu.gl.az_432 da.no.pt_222  tl.ha.et_322 zu.ro.rw_543
  0x686b01a6, 0x0f100112, 0x27006807, 0x0a201b12,   // en.ceb.ig_521 en.lt.lv_654  ig.gd.un_420 tr.sq.pt_654
  // [a780]
  0x200f35a0, 0x050f100c, 0x063120ee, 0x311b1a14,   // zu.lv.sq_322 lt.lv.fr_543  sq.az.de_422 tl.tr.az_666
  0x050111af, 0x1c130d09, 0x0f101aa7, 0x010f3f07,   // ro.en.fr_655 ne.bh.mr_444  tl.lt.lv_532 af.lv.en_432
  0x010f13ec, 0x0f000322, 0x010a110c, 0x233f01a9,   // et.lv.en_644 nl.lv.un_870  ro.pt.en_543 en.af.ca_544
  0x010e050c, 0x68162507, 0x0a005502, 0x060f0107,   // fr.is.en_543 eu.hr.ig_432  rw.pt.un_220 en.lv.de_432
  // [a790]
  0x213b3f07, 0x31001007, 0x180123a9, 0x10171604,   // af.so.jw_432 lt.az.un_420  ca.en.ga_544 hr.sr.lt_332
  0x04521313, 0x13005307, 0x05001e02, 0x525501a4,   // et.ha.fi_665 ht.et.un_420  ms.fr.un_220 en.rw.ha_433
  0x3b01280c, 0x23001f21, 0x252d29ad, 0x35643112,   // sw.en.so_543 cy.ca.un_860  sl.sk.eu_643 az.lg.zu_654
  0x1a041ea4, 0x181027ec, 0x10281aad, 0x31525504,   // ms.fi.tl_433 gd.lt.ga_644  tl.sw.lt_643 rw.ha.az_332
  // [a7a0]
  0x6e00012b, 0x35110aa4, 0x1b1a3108, 0x6e00100e,   // en.hmn.un_980 pt.ro.zu_433  az.tl.tr_443 lt.hmn.un_550
  0x2d0d03a9, 0x1a001e1a, 0x1b1a31a7, 0x082a010d,   // nl.cs.sk_544 ms.tl.un_760  az.tl.tr_532 en.mt.no_554
  0x172a070b, 0x3f190aa7, 0x1c0304ee, 0x091308ad,   // it.mt.sr_542 pt.gl.af_532  fi.nl.id_422 no.et.pl_643
  0x133235ee, 0x131a1ca4, 0x213b1ea0, 0x06040fa0,   // zu.bs.et_422 id.tl.et_433  ms.so.jw_322 lv.fi.de_322
  // [a7b0]
  0x356b6409, 0x283520a0, 0x01203b07, 0x3f0809ad,   // lg.ceb.zu_444 sq.zu.sw_322  so.sq.en_432 pl.no.af_643
  0x1b106b60, 0x0f556460, 0x6b013b07, 0x20006404,   // ceb.lt.tr_664 lg.rw.lv_664  so.en.ceb_432 lg.sq.un_320
  0x0c0110ee, 0x1b253113, 0x28090407, 0x08002713,   // lt.en.sv_422 az.eu.tr_665  fi.pl.sw_432 gd.no.un_650
  0x206b01a6, 0x0800520b, 0x0d004a12, 0x281a1055,   // en.ceb.sq_521 ha.no.un_520  yo.cs.un_640 lt.tl.sw_442
  // [a7c0]
  0x311b530c, 0x171c1eee, 0x1f2327a7, 0x641a1e12,   // ht.tr.az_543 ms.id.sr_422  gd.ca.cy_532 ms.tl.lg_654
  0x181223a9, 0x1e3b3504, 0x08071b04, 0x6855200c,   // ca.hu.ga_544 zu.so.ms_332  tr.it.no_332 sq.rw.ig_543
  0x1e31100c, 0x2d5228ee, 0x55000714, 0x64551207,   // lt.az.ms_543 sw.ha.sk_422  it.rw.un_660 hu.rw.lg_432
  0x182d1211, 0x3f002b0d, 0x0f005219, 0x0a000e19,   // hu.sk.ga_653 vi.af.un_540  ha.lv.un_750 is.pt.un_750
  // [a7d0]
  0x08000b02, 0x110129a4, 0x010752ee, 0x0d071313,   // es.no.un_220 sl.en.ro_433  ha.it.en_422 et.it.cs_665
  0x08022da9, 0x20001b19, 0x29172da6, 0x53045211,   // sk.da.no_544 tr.sq.un_750  sk.sr.sl_521 ha.fi.ht_653
  0x131a5502, 0x551201ee, 0x3b0e040d, 0x016b35a0,   // rw.tl.et_222 en.hu.rw_422  fi.is.so_554 zu.ceb.en_322
  0x2b641c0c, 0x13080f07, 0x1c1316a0, 0x1a00130e,   // id.lg.vi_543 lv.no.et_432  hr.et.id_322 et.tl.un_550
  // [a7e0]
  0x040701a0, 0x18002507, 0x200d3ba9, 0x0e005207,   // en.it.fi_322 eu.ga.un_420  so.cs.sq_544 ha.is.un_420
  0x0e00522a, 0x18000e21, 0x6e003204, 0x6b003507,   // ha.is.un_970 is.ga.un_860  bs.hmn.un_320 zu.ceb.un_420
  0x3f1e1c0c, 0x025208a4, 0x291b0fa4, 0x2a0d3b07,   // id.ms.af_543 no.ha.da_433  lv.tr.sl_433 so.cs.mt_432
  0x213f060c, 0x1b6e1604, 0x68253ba4, 0x3f3b29ee,   // de.af.jw_543 hr.hmn.tr_332  so.eu.ig_433 sl.so.af_422
  // [a7f0]
  0x526b1b0c, 0x29206e07, 0x1b3521a0, 0x68643b55,   // tr.ceb.ha_543 hmn.sq.sl_432  jw.zu.tr_322 so.lg.ig_442
  0x0a003b09, 0x13004a0b, 0x1b6b1a04, 0x68353b0c,   // so.pt.un_440 yo.et.un_520  tl.ceb.tr_332 so.zu.ig_543
  0x10170410, 0x521f3b07, 0x0f000209, 0x20102812,   // ru.sr.be_642 so.cy.ha_432  da.lv.un_440 sw.lt.sq_654
  0x3f641307, 0x01231a08, 0x27001008, 0x6b000d08,   // et.lg.af_432 tl.ca.en_443  lt.gd.un_430 cs.ceb.un_430

  // [a800]
  0x643f3ba4, 0x4a313bad, 0x200802ad, 0x252053a4,   // so.af.lg_433 so.az.yo_643  da.no.sq_643 ht.sq.eu_433
  0x522b010c, 0x2a002102, 0x0a0e52a7, 0x321752a9,   // en.vi.ha_543 jw.mt.un_220  ha.is.pt_532 ha.sr.bs_544
  0x13281fee, 0x3b001e1a, 0x13116408, 0x255511a6,   // cy.sw.et_422 ms.so.un_760  lg.ro.et_443 ro.rw.eu_521
  0x135527ac, 0x061c21ee, 0x25556408, 0x523b11a4,   // gd.rw.et_632 jw.id.de_422  lg.rw.eu_443 ro.so.ha_433
  // [a810]
  0x110119a0, 0x25186405, 0x092921a4, 0x18052711,   // gl.en.ro_322 lg.ga.eu_333  jw.sl.pl_433 gd.fr.ga_653
  0x641155a4, 0x52001107, 0x2d296460, 0x323129a0,   // rw.ro.lg_433 ro.ha.un_420  lg.sl.sk_664 sl.az.bs_322
  0x64281a05, 0x1c201602, 0x016b180b, 0x645529a7,   // tl.sw.lg_333 hr.sq.id_222  ga.ceb.en_542 sl.rw.lg_532
  0x64315512, 0x5300270c, 0x091f2d04, 0x046455a0,   // rw.az.lg_654 gd.ht.un_530  sk.cy.pl_332 rw.lg.fi_322
  // [a820]
  0x011f55a0, 0x32092d04, 0x4a1b0107, 0x6b1c1aec,   // rw.cy.en_322 sk.pl.bs_332  en.tr.yo_432 tl.id.ceb_644
  0x35001123, 0x28113512, 0x28536ba0, 0x3f11350c,   // ro.zu.un_880 zu.ro.sw_654  ceb.ht.sw_322 zu.ro.af_543
  0x033513a9, 0x3f03350c, 0x32161109, 0x29020c60,   // et.zu.nl_544 zu.nl.af_543  ro.hr.bs_444 sv.da.sl_664
  0x1b11130c, 0x31001607, 0x09006e34, 0x03113508,   // et.ro.tr_543 hr.az.un_420  hmn.pl.un_A80 zu.ro.nl_443
  // [a830]
  0x11640408, 0x1b113512, 0x031c1102, 0x03006e0e,   // fi.lg.ro_443 zu.ro.tr_654  ro.id.nl_222 hmn.nl.un_550
  0x1c1b1eee, 0x2d0d6e11, 0x1100351b, 0x5311350c,   // ms.tr.id_422 hmn.cs.sk_653  zu.ro.un_770 zu.ro.ht_543
  0x3b002904, 0x042752ad, 0x0d131113, 0x0c0620a4,   // sl.so.un_320 ha.gd.fi_643  ro.et.cs_665 sq.de.sv_433
  0x07191f07, 0x1b01530c, 0x10003122, 0x3f13110c,   // cy.gl.it_432 ht.en.tr_543  az.lt.un_870 ro.et.af_543
  // [a840]
  0x113513af, 0x170f08a0, 0x180d1205, 0x1f0e06a7,   // et.zu.ro_655 no.lv.sr_322  hu.cs.ga_333 de.is.cy_532
  0x052321ad, 0x64356804, 0x31252a0c, 0x0c00180c,   // jw.ca.fr_643 ig.zu.lg_332  mt.eu.az_543 ga.sv.un_530
  0x0c033fad, 0x6b016e07, 0x1a00041b, 0x05001813,   // af.nl.sv_643 hmn.en.ceb_432  fi.tl.un_770 ga.fr.un_650
  0x1b110504, 0x4a001a09, 0x1a3b040c, 0x09291807,   // fr.ro.tr_332 tl.yo.un_440  fi.so.tl_543 ga.sl.pl_432
  // [a850]
  0x02521fec, 0x6e3101ee, 0x6e000a1b, 0x030c3f60,   // cy.ha.da_644 en.az.hmn_422  pt.hmn.un_770 af.sv.nl_664
  0x1c043bee, 0x1e086e0c, 0x1200021a, 0x043b4aa0,   // so.fi.id_422 hmn.no.ms_543  da.hu.un_760 yo.so.fi_322
  0x13043b04, 0x250c0ea4, 0x6b1a2107, 0x04133b02,   // so.fi.et_332 is.sv.eu_433  jw.tl.ceb_432 so.et.fi_222
  0x056e1f0c, 0x02273f07, 0x530a52a9, 0x05530308,   // cy.hmn.fr_543 af.gd.da_432  ha.pt.ht_544 nl.ht.fr_443
  // [a860]
  0x1b006b0c, 0x25312aad, 0x0f2916ee, 0x3b1a040c,   // ceb.tr.un_530 mt.az.eu_643  hr.sl.lv_422 fi.tl.so_543
  0x2b0a6eec, 0x1a3b1b0c, 0x0c0204ad, 0x2a6e0107,   // hmn.pt.vi_644 tr.so.tl_543  fi.da.sv_643 en.hmn.mt_432
  0x6e000e1a, 0x250f100c, 0x1b0c31a4, 0x311a1ba4,   // is.hmn.un_760 lt.lv.eu_543  az.sv.tr_433 tr.tl.az_433
  0x050b0a02, 0x6b1b3112, 0x0d040107, 0x64055304,   // pt.es.fr_222 az.tr.ceb_654  en.fi.cs_432 ht.fr.lg_332
  // [a870]
  0x6800640d, 0x311b4aa4, 0x35042802, 0x64213507,   // lg.ig.un_540 yo.tr.az_433  sw.fi.zu_222 zu.jw.lg_432
  0x53190111, 0x1a001b04, 0x0f106e60, 0x531c01a6,   // en.gl.ht_653 tr.tl.un_320  hmn.lt.lv_664 en.id.ht_521
  0x131b680c, 0x02003f29, 0x081b0255, 0x682801ee,   // ig.tr.et_543 af.da.un_960  da.tr.no_442 en.sw.ig_422
  0x04003104, 0x041b31ad, 0x02321605, 0x4a1b02ee,   // az.fi.un_320 az.tr.fi_643  hr.bs.da_333 da.tr.yo_422
  // [a880]
  0x4a311b08, 0x02071ba0, 0x134a02a4, 0x5200090c,   // tr.az.yo_443 tr.it.da_322  da.yo.et_433 pl.ha.un_530
  0x3f1768a4, 0x1b190b08, 0x0d2d3507, 0x1a005521,   // ig.sr.af_433 es.gl.tr_443  zu.sk.cs_432 rw.tl.un_860
  0x121b09ec, 0x1f5564a9, 0x64000609, 0x6413550c,   // pl.tr.hu_644 lg.rw.cy_544  de.lg.un_440 rw.et.lg_543
  0x680208af, 0x3f10230c, 0x02532908, 0x021b11a6,   // no.da.ig_655 ca.lt.af_543  sl.ht.da_443 ro.tr.da_521
  // [a890]
  0x1f020807, 0x09201b0c, 0x68356ea4, 0x6b130f07,   // no.da.cy_432 tr.sq.pl_543  hmn.zu.ig_433 lv.et.ceb_432
  0x01550504, 0x1f0364a9, 0x03043f04, 0x2a180a09,   // fr.rw.en_332 lg.nl.cy_544  af.fi.nl_332 pt.ga.mt_444
  0x0f103fa7, 0x080e2004, 0x2a0c08a0, 0x02081107,   // af.lt.lv_532 sq.is.no_332  no.sv.mt_322 ro.no.da_432
  0x0c041fa0, 0x0c0e0fee, 0x080c0f55, 0x521710ee,   // cy.fi.sv_322 lv.is.sv_422  lv.sv.no_442 lt.sr.ha_422
  // [a8a0]
  0x18000507, 0x0200012a, 0x1e531ca4, 0x2900160e,   // fr.ga.un_420 en.da.un_970  id.ht.ms_433 hr.sl.un_550
  0x17002004, 0x170708ad, 0x0553020c, 0x2a0f095a,   // sq.sr.un_320 uk.bg.sr_643  da.ht.fr_543 pl.lv.mt_553
  0x25000908, 0x05006807, 0x0d000307, 0x3f060313,   // pl.eu.un_430 ig.fr.un_420  nl.cs.un_420 nl.de.af_665
  0x683f27a9, 0x3f552104, 0x681c1ea7, 0x23110707,   // gd.af.ig_544 jw.rw.af_332  ms.id.ig_532 it.ro.ca_432
  // [a8b0]
  0x251c1e0c, 0x28071108, 0x08020114, 0x68100107,   // ms.id.eu_543 ro.it.sw_443  en.da.no_666 en.lt.ig_432
  0x25041ea7, 0x27191107, 0x1e28110c, 0x3f682011,   // ms.fi.eu_532 ro.gl.gd_432  ro.sw.ms_543 sq.ig.af_653
  0x190a05ec, 0x6b1001a7, 0x68000321, 0x060801a0,   // fr.pt.gl_644 en.lt.ceb_532  nl.ig.un_860 en.no.de_322
  0x231b3107, 0x1c002504, 0x23071907, 0x6b091aa9,   // az.tr.ca_432 eu.id.un_320  gl.it.ca_432 tl.pl.ceb_544
  // [a8c0]
  0x6b6818ee, 0x080602ee, 0x680906ad, 0x28111aa9,   // ga.ig.ceb_422 da.de.no_422  de.pl.ig_643 tl.ro.sw_544
  0x1e1c6ba9, 0x2d04050c, 0x0d090107, 0x08020607,   // ceb.id.ms_544 fr.fi.sk_543  en.pl.cs_432 de.da.no_432
  0x23001b12, 0x131112a4, 0x311b32a0, 0x1c131a60,   // tr.ca.un_640 hu.ro.et_433  bs.tr.az_322 tl.et.id_664
  0x100f20af, 0x280c0807, 0x19211c07, 0x350d2908,   // sq.lv.lt_655 no.sv.sw_432  id.jw.gl_432 sl.cs.zu_443
  // [a8d0]
  0x052a2708, 0x68131e07, 0x20313b12, 0x0c2808ee,   // gd.mt.fr_443 ms.et.ig_432  so.az.sq_654 no.sw.sv_422
  0x0d120960, 0x0e641f04, 0x1f3b0808, 0x10006b02,   // pl.hu.cs_664 cy.lg.is_332  no.so.cy_443 ceb.lt.un_220
  0x135520a4, 0x1f0127ee, 0x051b530d, 0x28356ea4,   // sq.rw.et_433 gd.en.cy_422  ht.tr.fr_554 hmn.zu.sw_433
  0x200d55a4, 0x01181302, 0x0900310d, 0x1c0811a0,   // rw.cs.sq_433 et.ga.en_222  az.pl.un_540 ro.no.id_322
  // [a8e0]
  0x17080e0c, 0x18040107, 0x08020fa4, 0x03001e04,   // is.no.sr_543 en.fi.ga_432  lv.da.no_433 ms.nl.un_320
  0x3f3b0107, 0x0c055307, 0x13043b08, 0x35095508,   // en.so.af_432 ht.fr.sv_432  so.fi.et_443 rw.pl.zu_443
  0x3b534aad, 0x0b0a27a0, 0x1b102a04, 0x644a3ba0,   // yo.ht.so_643 gd.pt.es_322  mt.lt.tr_332 so.yo.lg_322
  0x051f270b, 0x211e29ee, 0x1a3b6e0c, 0x1a4a5504,   // gd.cy.fr_542 sl.ms.jw_422  hmn.so.tl_543 rw.yo.tl_332
  // [a8f0]
  0x32293bee, 0x18061f0c, 0x1a083bad, 0x07002d1a,   // so.sl.bs_422 cy.de.ga_543  so.no.tl_643 sk.it.un_760
  0x1a556b0e, 0x52000704, 0x31001805, 0x231801ee,   // ceb.rw.tl_555 it.ha.un_320  ga.az.un_330 en.ga.ca_422
  0x20011fad, 0x3b1f10ec, 0x066b0104, 0x3f006e0d,   // cy.en.sq_643 lt.cy.so_644  en.ceb.de_332 hmn.af.un_540
  0x3f6e13a9, 0x190a05a7, 0x190a050c, 0x0f5528ee,   // et.hmn.af_544 fr.pt.gl_532  fr.pt.gl_543 sw.rw.lv_422
  // [a900]
  0x1e1c31a0, 0x11070a05, 0x23000e0e, 0x061b1307,   // az.id.ms_322 mk.bg.ro_333  is.ca.un_550 et.tr.de_432
  0x1a001812, 0x1f041aad, 0x3b002114, 0x2a1107a0,   // ga.tl.un_640 tl.fi.cy_643  jw.so.un_660 it.ro.mt_322
  0x03253fa9, 0x0a230eaf, 0x3b52010c, 0x1820010c,   // af.eu.nl_544 is.ca.pt_655  en.ha.so_543 en.sq.ga_543
  0x2720010b, 0x315206af, 0x2000522b, 0x2d0d6b02,   // en.sq.gd_542 de.ha.az_655  ha.sq.un_980 ceb.cs.sk_222
  // [a910]
  0x641f5508, 0x64000614, 0x060955ad, 0x06550111,   // rw.cy.lg_443 de.lg.un_660  rw.pl.de_643 en.rw.de_653
  0x311b12b4, 0x1b060507, 0x2d001608, 0x250b23a7,   // hu.tr.az_754 fr.de.tr_432  hr.sk.un_430 ca.es.eu_532
  0x0664550d, 0x0f002502, 0x1e1c0b0c, 0x28061fa0,   // rw.lg.de_554 eu.lv.un_220  es.id.ms_543 cy.de.sw_322
  0x13282104, 0x05001f19, 0x1f3f64a0, 0x06552112,   // jw.sw.et_332 cy.fr.un_750  lg.af.cy_322 jw.rw.de_654
  // [a920]
  0x1f002822, 0x681b3112, 0x063f09ad, 0x2800290e,   // sw.cy.un_870 az.tr.ig_654  pl.af.de_643 sl.sw.un_550
  0x1f3553a7, 0x211c1aa0, 0x1c28290c, 0x230b28a7,   // ht.zu.cy_532 tl.id.jw_322  sl.sw.id_543 sw.es.ca_532
  0x1f0c25a7, 0x1f005208, 0x0a2913a4, 0x1f001c02,   // eu.sv.cy_532 ha.cy.un_430  et.sl.pt_433 id.cy.un_220
  0x1c2521ad, 0x1a041fa7, 0x115313a0, 0x3f002813,   // jw.eu.id_643 cy.fi.tl_532  et.ht.ro_322 sw.af.un_650
  // [a930]
  0x132d0da4, 0x1a1c1fa0, 0x06132807, 0x20113f07,   // cs.sk.et_433 cy.id.tl_322  sw.et.de_432 af.ro.sq_432
  0x0b0c250c, 0x2a0827a0, 0x13120613, 0x190b05af,   // eu.sv.es_543 gd.no.mt_322  de.hu.et_665 fr.es.gl_655
  0x1b5355af, 0x04091fa7, 0x283f5507, 0x3f2a0809,   // rw.ht.tr_655 cy.pl.fi_532  rw.af.sw_432 no.mt.af_444
  0x32001f04, 0x29080907, 0x0e091f0c, 0x17060804,   // cy.bs.un_320 pl.no.sl_432  cy.pl.is_543 no.de.sr_332
  // [a940]
  0x040c1fa4, 0x052b01a6, 0x32003107, 0x3f020fa0,   // cy.sv.fi_433 en.vi.fr_521  az.bs.un_420 lv.da.af_322
  0x1c006407, 0x1a255555, 0x28523b07, 0x012805ee,   // lg.id.un_420 rw.eu.tl_442  so.ha.sw_432 fr.sw.en_422
  0x2b6b040c, 0x212b1c09, 0x18271e07, 0x532b28ee,   // fi.ceb.vi_543 id.vi.jw_444  ms.gd.ga_432 sw.vi.ht_422
  0x29203202, 0x520a1107, 0x1828680c, 0x6b1a27ad,   // bs.sq.sl_222 ro.pt.ha_432  ig.sw.ga_543 gd.tl.ceb_643
  // [a950]
  0x35000702, 0x1f5327a9, 0x165210a7, 0x324a17a0,   // it.zu.un_220 gd.ht.cy_544  lt.ha.hr_532 sr.yo.bs_322
  0x1a006807, 0x5200042c, 0x102b680d, 0x2b000712,   // ig.tl.un_420 fi.ha.un_990  ig.vi.lt_554 it.vi.un_640
  0x0e0425ad, 0x523b01af, 0x1a0e3b05, 0x0e0452ad,   // eu.fi.is_643 en.so.ha_655  so.is.tl_333 ha.fi.is_643
  0x130d09ac, 0x2a3b52a0, 0x211c0d07, 0x0418270c,   // hi.ne.bh_632 ha.so.mt_322  cs.id.jw_432 gd.ga.fi_543
  // [a960]
  0x1e27180c, 0x11040da4, 0x552528a4, 0x202723a4,   // ga.gd.ms_543 cs.fi.ro_433  sw.eu.rw_433 ca.gd.sq_433
  0x1c0a21a0, 0x3b07110e, 0x00000142, 0x6b1a10a7,   // jw.pt.id_322 ro.it.so_555  en.un.un_C00 lt.tl.ceb_532
  0x172916a0, 0x0d180e04, 0x35313b08, 0x250935a0,   // hr.sl.sr_322 is.ga.cs_332  so.az.zu_443 zu.pl.eu_322
  0x55353b0c, 0x23052107, 0x07171002, 0x015204a0,   // so.zu.rw_543 jw.fr.ca_432  be.sr.bg_222 fi.ha.en_322
  // [a970]
  0x0e04520c, 0x171307ee, 0x19040b0c, 0x07001812,   // ha.fi.is_543 it.et.sr_422  es.fi.gl_543 ga.it.un_640
  0x041f09a6, 0x040e0c04, 0x060b1fa0, 0x0c0601a0,   // pl.cy.fi_521 sv.is.fi_332  cy.es.de_322 en.de.sv_322
  0x070a080e, 0x190701a0, 0x0a051960, 0x03124aa4,   // uk.mk.bg_555 en.it.gl_322  gl.fr.pt_664 yo.hu.nl_433
  0x191f0a04, 0x2d0d6b14, 0x190b3b05, 0x18010607,   // pt.cy.gl_332 ceb.cs.sk_666  so.es.gl_333 de.en.ga_432
  // [a980]
  0x12040c07, 0x10643b55, 0x531b0ba4, 0x01353fa0,   // sv.fi.hu_432 so.lg.lt_442  es.tr.ht_433 af.zu.en_322
  0x3b1f6baf, 0x3b001a20, 0x161a2d07, 0x030113ee,   // ceb.cy.so_655 tl.so.un_850  sk.tl.hr_432 et.en.nl_422
  0x193b0b55, 0x6400091b, 0x0f532d04, 0x64195304,   // es.so.gl_442 pl.lg.un_770  sk.ht.lv_332 ht.gl.lg_332
  0x08071160, 0x55071c04, 0x55003112, 0x16001a07,   // ro.bg.uk_664 id.it.rw_332  az.rw.un_640 tl.hr.un_420
  // [a990]
  0x2d29010c, 0x04132304, 0x2d0d35a4, 0x06000713,   // en.sl.sk_543 ca.et.fi_332  zu.cs.sk_433 it.de.un_650
  0x556b1aa9, 0x25001002, 0x126468ad, 0x29000c14,   // tl.ceb.rw_544 lt.eu.un_220  ig.lg.hu_643 sv.sl.un_660
  0x08002a02, 0x0a2119a4, 0x292d1ea0, 0x01002804,   // mt.no.un_220 gl.jw.pt_433  ms.sk.sl_322 sw.en.un_320
  0x203564a9, 0x08120eee, 0x285220ad, 0x09292008,   // lg.zu.sq_544 is.hu.no_422  sq.ha.sw_643 sq.sl.pl_443
  // [a9a0]
  0x641a6ba7, 0x29352d07, 0x3b6855a7, 0x4a1e1c0d,   // ceb.tl.lg_532 sk.zu.sl_432  rw.ig.so_532 id.ms.yo_554
  0x1b202908, 0x1c521eec, 0x29202dee, 0x1e1c3b14,   // sl.sq.tr_443 ms.ha.id_644  sk.sq.sl_422 so.id.ms_666
  0x1b2920ad, 0x201029a4, 0x1b072014, 0x25040308,   // sq.sl.tr_643 sl.lt.sq_433  sq.it.tr_666 nl.fi.eu_443
  0x1e1c080e, 0x551b200c, 0x1a00130c, 0x1b31200c,   // no.id.ms_555 sq.tr.rw_543  et.tl.un_530 sq.az.tr_543
  // [a9b0]
  0x231107a7, 0x3f0908a0, 0x1000072b, 0x121f1104,   // it.ro.ca_532 no.pl.af_322  bg.be.un_980 ro.cy.hu_332
  0x0a190513, 0x0b0705ee, 0x050b2307, 0x190b35a0,   // fr.gl.pt_665 fr.it.es_422  ca.es.fr_432 zu.es.gl_322
  0x532d0d55, 0x28250da0, 0x256b280b, 0x0b0a05a4,   // cs.sk.ht_442 cs.eu.sw_322  sw.ceb.eu_542 fr.pt.es_433
  0x23042504, 0x1c211a07, 0x520e01af, 0x05000f04,   // eu.fi.ca_332 tl.jw.id_432  en.is.ha_655 lv.fr.un_320
  // [a9c0]
  0x01023fa0, 0x2552280b, 0x0b1823a0, 0x4a003502,   // af.da.en_322 sw.ha.eu_542  ca.ga.es_322 zu.yo.un_220
  0x0106280d, 0x350127a0, 0x051f07ee, 0x111b1605,   // sw.de.en_554 gd.en.zu_322  it.cy.fr_422 hr.tr.ro_333
  0x1a3f2104, 0x13040ca0, 0x0f1b3255, 0x130c2aec,   // jw.af.tl_332 sv.fi.et_322  bs.tr.lv_442 mt.sv.et_644
  0x02130107, 0x53312009, 0x202d0d08, 0x160a11a0,   // en.et.da_432 sq.az.ht_444  cs.sk.sq_443 ro.pt.hr_322
  // [a9d0]
  0x09642504, 0x20122907, 0x20310107, 0x271c010c,   // eu.lg.pl_332 sl.hu.sq_432  en.az.sq_432 en.id.gd_543
  0x3b1b1fec, 0x68003b1b, 0x05285207, 0x6b3b0455,   // cy.tr.so_644 so.ig.un_770  ha.sw.fr_432 fi.so.ceb_442
  0x4a04050c, 0x684a0408, 0x310355a7, 0x061a3bad,   // fr.fi.yo_543 fi.yo.ig_443  rw.nl.az_532 so.tl.de_643
  0x6b2510a0, 0x0320060c, 0x6b683b05, 0x35551a09,   // lt.eu.ceb_322 de.sq.nl_543  so.ig.ceb_333 tl.rw.zu_444
  // [a9e0]
  0x182d0d5a, 0x0802350c, 0x06293504, 0x286e3bad,   // cs.sk.ga_553 zu.da.no_543  zu.sl.de_332 so.hmn.sw_643
  0x3b196ea9, 0x55062508, 0x120a0dad, 0x68255508,   // hmn.gl.so_544 eu.de.rw_443  cs.pt.hu_643 rw.eu.ig_443
  0x32002808, 0x320f6804, 0x1a2a55a7, 0x35006829,   // sw.bs.un_430 ig.lv.bs_332  rw.mt.tl_532 ig.zu.un_960
  0x1268550d, 0x120e0c02, 0x68002818, 0x1c4a68ad,   // rw.ig.hu_554 sv.is.hu_222  sw.ig.un_740 ig.yo.id_643
  // [a9f0]
  0x3500522a, 0x52182ba7, 0x534a680b, 0x04322aee,   // ha.zu.un_970 vi.ga.ha_532  ig.yo.ht_542 mt.bs.fi_422
  0x3f2a52ee, 0x1700320c, 0x64133b07, 0x55282108,   // ha.mt.af_422 bs.sr.un_530  so.et.lg_432 jw.sw.rw_443
  0x200c0208, 0x3f3b6b08, 0x2b271e0c, 0x1a136b07,   // da.sv.sq_443 ceb.so.af_443  ms.gd.vi_543 ceb.et.tl_432
  0x272b0107, 0x033f1b0c, 0x0f5510ec, 0x0f1101a0,   // en.vi.gd_432 tr.af.nl_543  lt.rw.lv_644 en.ro.lv_322
  // [aa00]
  0x11551e08, 0x08000d04, 0x53190a04, 0x051104a4,   // ms.rw.ro_443 cs.no.un_320  pt.gl.ht_332 fi.ro.fr_433
  0x552001a0, 0x102001ad, 0x20005509, 0x12000309,   // en.sq.rw_322 en.sq.lt_643  rw.sq.un_440 nl.hu.un_440
  0x2a1b3204, 0x356b13ac, 0x03002021, 0x1f1118ac,   // bs.tr.mt_332 et.ceb.zu_632  sq.nl.un_860 ga.ro.cy_632
  0x21523b0c, 0x5528130e, 0x293b130c, 0x1e5225af,   // so.ha.jw_543 et.sw.rw_555  et.so.sl_543 eu.ha.ms_655
  // [aa10]
  0x07111308, 0x311c55a0, 0x553b06ee, 0x3b2519a9,   // et.ro.it_443 rw.id.az_322  de.so.rw_422 gl.eu.so_544
  0x2028550b, 0x31003502, 0x1b101ea0, 0x03553fa0,   // rw.sw.sq_542 zu.az.un_220  ms.lt.tr_322 af.rw.nl_322
  0x1a6b1b07, 0x1e552807, 0x0c4a6e02, 0x1a004a1b,   // tr.ceb.tl_432 sw.rw.ms_432  hmn.yo.sv_222 yo.tl.un_770
  0x17532902, 0x3b4a1205, 0x1a211fa7, 0x17080a11,   // sl.ht.sr_222 hu.yo.so_333  cy.jw.tl_532 mk.uk.sr_653
  // [aa20]
  0x03060207, 0x322864ad, 0x3f122da0, 0x6e1a6baf,   // da.de.nl_432 lg.sw.bs_643  sk.hu.af_322 ceb.tl.hmn_655
  0x16286408, 0x64100f07, 0x1800191a, 0x4a356404,   // lg.sw.hr_443 lv.lt.lg_432  gl.ga.un_760 lg.zu.yo_332
  0x07110a12, 0x3f00070d, 0x0f64550d, 0x351b13a4,   // mk.ro.bg_654 it.af.un_540  rw.lg.lv_554 et.tr.zu_433
  0x1107130c, 0x28641e07, 0x284a645a, 0x25122304,   // et.it.ro_543 ms.lg.sw_432  lg.yo.sw_553 ca.hu.eu_332
  // [aa30]
  0x0c0807ad, 0x35280713, 0x05110713, 0x18052104,   // it.no.sv_643 it.sw.zu_665  it.ro.fr_665 jw.fr.ga_332
  0x12082907, 0x120721ad, 0x291625ee, 0x3b355304,   // sl.no.hu_432 jw.it.hu_643  eu.hr.sl_422 ht.zu.so_332
  0x6b0431ee, 0x0500101b, 0x0c00270d, 0x202a2104,   // az.fi.ceb_422 lt.fr.un_770  gd.sv.un_540 jw.mt.sq_332
  0x553b2807, 0x022008ad, 0x0a182708, 0x0c20080c,   // sw.so.rw_432 no.sq.da_643  gd.ga.pt_443 no.sq.sv_543
  // [aa40]
  0x190a13a0, 0x180e2709, 0x05060fad, 0x1a0964a0,   // et.pt.gl_322 gd.is.ga_444  lv.de.fr_643 lg.pl.tl_322
  0x0e0827a4, 0x351809ad, 0x040e2304, 0x31645504,   // gd.no.is_433 pl.ga.zu_643  ca.is.fi_332 rw.lg.az_332
  0x18271ea0, 0x0c092055, 0x1f006402, 0x07100455,   // ms.gd.ga_322 sq.pl.sv_442  lg.cy.un_220 ru.be.bg_442
  0x0e250504, 0x13052707, 0x080e1907, 0x1e2021af,   // fr.eu.is_332 gd.fr.et_432  gl.is.no_432 jw.sq.ms_655
  // [aa50]
  0x080220af, 0x03002b04, 0x3f55070c, 0x2d172913,   // sq.da.no_655 vi.nl.un_320  it.rw.af_543 sl.sr.sk_665
  0x1b002119, 0x1f3b07ad, 0x3b0a0fa4, 0x12192004,   // jw.tr.un_750 it.so.cy_643  lv.pt.so_433 sq.gl.hu_332
  0x103b29a0, 0x3f1b0107, 0x190113a4, 0x291c21ee,   // sl.so.lt_322 en.tr.af_432  et.en.gl_433 jw.id.sl_422
  0x133f0c08, 0x3b10290c, 0x3b000729, 0x350603a4,   // sv.af.et_443 sl.lt.so_543  it.so.un_960 nl.de.zu_433
  // [aa60]
  0x3f0c350c, 0x28211e02, 0x19000a36, 0x080210af,   // zu.sv.af_543 ms.jw.sw_222  pt.gl.un_AA0 lt.da.no_655
  0x1b310c12, 0x2118280c, 0x063f0c0c, 0x101f3b13,   // sv.az.tr_654 sw.ga.jw_543  sv.af.de_543 so.cy.lt_665
  0x03010904, 0x08132508, 0x076419a0, 0x31190a55,   // pl.en.nl_332 eu.et.no_443  gl.lg.it_322 pt.gl.az_442
  0x556453a0, 0x201355a0, 0x081710a9, 0x063f030e,   // ht.lg.rw_322 rw.et.sq_322  be.sr.uk_544 nl.af.de_555
  // [aa70]
  0x190a0c0c, 0x20103205, 0x550c2da0, 0x130c2d07,   // sv.pt.gl_543 bs.lt.sq_333  sk.sv.rw_322 sk.sv.et_432
  0x101f090c, 0x4a352555, 0x55282907, 0x25001c02,   // pl.cy.lt_543 eu.zu.yo_442  sl.sw.rw_432 id.eu.un_220
  0x09002014, 0x32060fa0, 0x130d1c13, 0x4a00212a,   // sq.pl.un_660 lv.de.bs_322  mr.ne.bh_665 jw.yo.un_970
  0x554a6812, 0x110c080c, 0x520b5504, 0x1c0e2aa0,   // ig.yo.rw_654 no.sv.ro_543  rw.es.ha_332 mt.is.id_322
  // [aa80]
  0x02005513, 0x1b646808, 0x101b4aee, 0x28254a07,   // rw.da.un_650 ig.lg.tr_443  yo.tr.lt_422 yo.eu.sw_432
  0x551e4aa4, 0x11000307, 0x2d023104, 0x32002018,   // yo.ms.rw_433 nl.ro.un_420  az.da.sk_332 sq.bs.un_740
  0x0b4a6808, 0x35684aec, 0x190b0207, 0x06110a08,   // ig.yo.es_443 yo.ig.zu_644  da.es.gl_432 pt.ro.de_443
  0x122911a0, 0x28092913, 0x0e180d12, 0x120432a0,   // ro.sl.hu_322 sl.pl.sw_665  cs.ga.is_654 bs.fi.hu_322
  // [aa90]
  0x015327a0, 0x0c001a07, 0x685552ad, 0x3b00011b,   // gd.ht.en_322 tl.sv.un_420  ha.rw.ig_643 en.so.un_770
  0x0c002b02, 0x3f2b1a04, 0x3b180913, 0x1a6b2805,   // vi.sv.un_220 tl.vi.af_332  pl.ga.so_665 sw.ceb.tl_333
  0x27093b08, 0x52646b04, 0x52001a1b, 0x18093b04,   // so.pl.gd_443 ceb.lg.ha_332  tl.ha.un_770 so.pl.ga_332
  0x3500022b, 0x6b5564ee, 0x01062ba0, 0x1e3b1a12,   // da.zu.un_980 lg.rw.ceb_422  vi.de.en_322 tl.so.ms_654
  // [aaa0]
  0x353f23a0, 0x093b6e0c, 0x52190bec, 0x3b5309ee,   // ca.af.zu_322 hmn.so.pl_543  es.gl.ha_644 pl.ht.so_422
  0x093b0107, 0x05193bee, 0x066b1aad, 0x28002107,   // en.so.pl_432 so.gl.fr_422  tl.ceb.de_643 jw.sw.un_420
  0x251710af, 0x080e29a7, 0x040513a0, 0x3500020d,   // lt.sr.eu_655 sl.is.no_532  et.fr.fi_322 da.zu.un_540
  0x050b010c, 0x1c1a2b11, 0x1a2153ee, 0x086b270d,   // en.es.fr_543 vi.tl.id_653  ht.jw.tl_422 gd.ceb.no_554
  // [aab0]
  0x101b0f60, 0x6e033f0d, 0x1b06210c, 0x1f060807,   // lv.tr.lt_664 af.nl.hmn_554  jw.de.tr_543 no.de.cy_432
  0x27081855, 0x29004a04, 0x683506af, 0x3f0864ad,   // ga.no.gd_442 yo.sl.un_320  de.zu.ig_655 lg.no.af_643
  0x0b1f100d, 0x27080202, 0x0c002804, 0x07210107,   // lt.cy.es_554 da.no.gd_222  sw.sv.un_320 en.jw.it_432
  0x08023502, 0x07001f23, 0x06202aa9, 0x03350612,   // zu.da.no_222 cy.it.un_880  mt.sq.de_544 de.zu.nl_654
  // [aac0]
  0x060e0307, 0x10002823, 0x201308ec, 0x0a001f20,   // nl.is.de_432 sw.lt.un_880  no.et.sq_644 cy.pt.un_850
  0x1a211c02, 0x062a010c, 0x68642508, 0x17002a02,   // id.jw.tl_222 en.mt.de_543  eu.lg.ig_443 mt.sr.un_220
  0x0700252c, 0x6b2519a7, 0x68185512, 0x0e2a1609,   // eu.it.un_990 gl.eu.ceb_532  rw.ga.ig_654 hr.mt.is_444
  0x101f1ca0, 0x1e12520b, 0x080f13a0, 0x11012807,   // id.cy.lt_322 ha.hu.ms_542  et.lv.no_322 sw.en.ro_432
  // [aad0]
  0x0b002502, 0x311f0e0c, 0x163f03a0, 0x3231205a,   // eu.es.un_220 is.cy.az_543  nl.af.hr_322 sq.az.bs_553
  0x1255680d, 0x31011802, 0x28042007, 0x1b250e08,   // ig.rw.hu_554 ga.en.az_222  sq.fi.sw_432 is.eu.tr_443
  0x2325280c, 0x1a0e2009, 0x0f10530b, 0x3b2717ee,   // sw.eu.ca_543 sq.is.tl_444  ht.lt.lv_542 sr.gd.so_422
  0x190b13ee, 0x521e1fa4, 0x08551fa0, 0x0b00040c,   // et.es.gl_422 cy.ms.ha_433  cy.rw.no_322 fi.es.un_530
  // [aae0]
  0x211e28ee, 0x180327af, 0x041323a0, 0x2100071a,   // sw.ms.jw_422 gd.nl.ga_655  ca.et.fi_322 it.jw.un_760
  0x05000c13, 0x52051ea0, 0x0c041f04, 0x211f5207,   // sv.fr.un_650 ms.fr.ha_322  cy.fi.sv_332 ha.cy.jw_432
  0x06521f04, 0x1f00040d, 0x2a20020c, 0x05230aa0,   // cy.ha.de_332 fi.cy.un_540  da.sq.mt_543 pt.ca.fr_322
  0x55521f07, 0x280955a4, 0x120d350c, 0x280d03a4,   // cy.ha.rw_432 rw.pl.sw_433  zu.cs.hu_543 nl.cs.sw_433
  // [aaf0]
  0x0f002513, 0x28351212, 0x12003522, 0x18080c0d,   // eu.lv.un_650 hu.zu.sw_654  zu.hu.un_870 sv.no.ga_554
  0x040601a0, 0x271f6b02, 0x1c0820a0, 0x130852a9,   // en.de.fi_322 ceb.cy.gd_222  sq.no.id_322 ha.no.et_544
  0x04171819, 0x522a28a4, 0x52005512, 0x0635290c,   // ar.sr.ru_765 sw.mt.ha_433  rw.ha.un_640 sl.zu.de_543
  0x200c0404, 0x1f3b0408, 0x190b010c, 0x2007010b,   // fi.sv.sq_332 fi.so.cy_443  en.es.gl_543 en.it.sq_542
  // [ab00]
  0x1318270b, 0x2d004a13, 0x061b1204, 0x036428ec,   // gd.ga.et_542 yo.sk.un_650  hu.tr.de_332 sw.lg.nl_644
  0x202552a0, 0x11122507, 0x182725a0, 0x19313b0d,   // ha.eu.sq_322 eu.hu.ro_432  eu.gd.ga_322 so.az.gl_554
  0x1e3f0355, 0x092564a4, 0x0d0655ad, 0x1112250b,   // nl.af.ms_442 lg.eu.pl_433  rw.de.cs_643 eu.hu.ro_542
  0x552512af, 0x1e003f07, 0x05521ea4, 0x072001a0,   // hu.eu.rw_655 af.ms.un_420  ms.ha.fr_433 en.sq.it_322
  // [ab10]
  0x1029130c, 0x28002113, 0x522313a9, 0x231f1aa4,   // et.sl.lt_543 jw.sw.un_650  et.ca.ha_544 tl.cy.ca_433
  0x02270812, 0x1255110b, 0x32272d0c, 0x271a08a0,   // no.gd.da_654 ro.rw.hu_542  sk.gd.bs_543 no.tl.gd_322
  0x1c211f12, 0x321601ee, 0x070111a9, 0x1a3b0614,   // cy.jw.id_654 en.hr.bs_422  ro.en.it_544 de.so.tl_666
  0x0c126b08, 0x0c3f02a7, 0x20556860, 0x2a110709,   // ceb.hu.sv_443 da.af.sv_532  ig.rw.sq_664 it.ro.mt_444
  // [ab20]
  0x0d1219a7, 0x0c2129ee, 0x123f1fa9, 0x0600181a,   // gl.hu.cs_532 sl.jw.sv_422  cy.af.hu_544 ga.de.un_760
  0x252d1112, 0x02061208, 0x2b216404, 0x68131b05,   // ro.sk.eu_654 hu.de.da_443  lg.jw.vi_332 tr.et.ig_333
  0x0713010c, 0x20190bec, 0x2511010b, 0x250711a4,   // en.et.it_543 es.gl.sq_644  en.ro.eu_542 ro.it.eu_433
  0x29006807, 0x553521a0, 0x6e000c0e, 0x11095505,   // ig.sl.un_420 jw.zu.rw_322  sv.hmn.un_550 rw.pl.ro_333
  // [ab30]
  0x6828550c, 0x6e000c12, 0x1a003f1a, 0x033f100b,   // rw.sw.ig_543 sv.hmn.un_640  af.tl.un_760 lt.af.nl_542
  0x28682a0d, 0x1a6e3f5a, 0x200712a4, 0x520c08a0,   // mt.ig.sw_554 af.hmn.tl_553  hu.it.sq_433 no.sv.ha_322
  0x08126b0c, 0x28682907, 0x280152a0, 0x291668ac,   // ceb.hu.no_543 sl.ig.sw_432  ha.en.sw_322 ig.hr.sl_632
  0x190a0ea0, 0x685521a9, 0x680555a4, 0x19252007,   // is.pt.gl_322 jw.rw.ig_544  rw.fr.ig_433 sq.eu.gl_432
  // [ab40]
  0x030f68ee, 0x283553ee, 0x186e2aa9, 0x0f006813,   // ig.lv.nl_422 ht.zu.sw_422  mt.hmn.ga_544 ig.lv.un_650
  0x20055307, 0x291603ee, 0x23000e04, 0x1a6b18ee,   // ht.fr.sq_432 nl.hr.sl_422  is.ca.un_320 ga.ceb.tl_422
  0x230a1b07, 0x08001c02, 0x4a00210c, 0x16000304,   // tr.pt.ca_432 id.no.un_220  jw.yo.un_530 nl.hr.un_320
  0x531628ee, 0x1b3552af, 0x1e251702, 0x6b311b13,   // sw.hr.ht_422 ha.zu.tr_655  sr.eu.ms_222 tr.az.ceb_665
  // [ab50]
  0x311b08a0, 0x172568ad, 0x1a195207, 0x182301ee,   // no.tr.az_322 ig.eu.sr_643  ha.gl.tl_432 en.ca.ga_422
  0x1f003b08, 0x28001a0e, 0x325318a0, 0x06081107,   // so.cy.un_430 tl.sw.un_550  ga.ht.bs_322 ro.no.de_432
  0x2506550c, 0x533504a0, 0x32311b0b, 0x311b1fa4,   // rw.de.eu_543 fi.zu.ht_322  tr.az.bs_542 cy.tr.az_433
  0x1b643504, 0x352a180c, 0x04351aa4, 0x11104a02,   // zu.lg.tr_332 ga.mt.zu_543  tl.zu.fi_433 yo.lt.ro_222
  // [ab60]
  0x17003104, 0x042564a4, 0x011a3504, 0x55640da4,   // az.sr.un_320 lg.eu.fi_433  zu.tl.en_332 cs.lg.rw_433
  0x311b08a9, 0x2302110c, 0x31006b19, 0x184a0daf,   // no.tr.az_544 ro.da.ca_543  ceb.az.un_750 cs.yo.ga_655
  0x0811060d, 0x5500120d, 0x681b5508, 0x640b11ee,   // de.ro.no_554 hu.rw.un_540  rw.tr.ig_443 ro.es.lg_422
  0x032319a0, 0x2d0d0faf, 0x190a05af, 0x2d0d0ea9,   // gl.ca.nl_322 lv.cs.sk_655  fr.pt.gl_655 is.cs.sk_544
  // [ab70]
  0x100f110c, 0x11232508, 0x16352855, 0x05132004,   // ro.lv.lt_543 eu.ca.ro_443  sw.zu.hr_442 sq.et.fr_332
  0x210701a0, 0x2d0201a0, 0x08291204, 0x09002519,   // en.it.jw_322 en.da.sk_322  hu.sl.no_332 eu.pl.un_750
  0x286420a0, 0x080b06ee, 0x3b2d0d02, 0x182820a4,   // sq.lg.sw_322 de.es.no_422  cs.sk.so_222 sq.sw.ga_433
  0x2b000e02, 0x211205a6, 0x17000c13, 0x13001802,   // is.vi.un_220 fr.hu.jw_521  sv.sr.un_650 ga.et.un_220
  // [ab80]
  0x4a00520e, 0x0e0f13ad, 0x121b06ee, 0x2704060d,   // ha.yo.un_550 et.lv.is_643  de.tr.hu_422 de.fi.gd_554
  0x3f00041a, 0x090c0812, 0x6b033fee, 0x271203ee,   // fi.af.un_760 no.sv.pl_654  af.nl.ceb_422 nl.hu.gd_422
  0x0e080602, 0x6b1a68ac, 0x09113ba4, 0x28000b0e,   // de.no.is_222 ig.tl.ceb_632  so.ro.pl_433 es.sw.un_550
  0x0c065302, 0x4a0e1805, 0x210601a4, 0x322820a6,   // ht.de.sv_222 ga.is.yo_333  en.de.jw_433 sq.sw.bs_521
  // [ab90]
  0x1f2b35ac, 0x52046e12, 0x1a0405a0, 0x28353b0e,   // zu.vi.cy_632 hmn.fi.ha_654  fr.fi.tl_322 so.zu.sw_555
  0x211c0e0e, 0x27201f5a, 0x180c0207, 0x11101713,   // is.id.jw_555 cy.sq.gd_553  da.sv.ga_432 sr.be.ro_665
  0x21082011, 0x08041355, 0x0c1b12ad, 0x20190a08,   // sq.no.jw_653 et.fi.no_442  hu.tr.sv_643 pt.gl.sq_443
  0x120c0e07, 0x041b03a4, 0x06041b07, 0x31041ba4,   // is.sv.hu_432 nl.tr.fi_433  tr.fi.de_432 tr.fi.az_433
  // [aba0]
  0x03041ba7, 0x050e0c07, 0x1b02030c, 0x16002702,   // tr.fi.nl_532 sv.is.fr_432  nl.da.tr_543 gd.hr.un_220
  0x056b0709, 0x0e0820ad, 0x070e0ca4, 0x1b311aa7,   // it.ceb.fr_444 sq.no.is_643  sv.is.it_433 tl.az.tr_532
  0x190b12af, 0x0c0508a0, 0x1a5505ad, 0x31031b07,   // hu.es.gl_655 no.fr.sv_322  fr.rw.tl_643 tr.nl.az_432
  0x130425ec, 0x09013f12, 0x091f1a12, 0x3b250b0e,   // eu.fi.et_644 af.en.pl_654  tl.cy.pl_654 es.eu.so_555
  // [abb0]
  0x53091fa7, 0x68031355, 0x03123bee, 0x103f0d11,   // cy.pl.ht_532 et.nl.ig_442  so.hu.nl_422 cs.af.lt_653
  0x4a283505, 0x2d1b25ec, 0x212b1aa0, 0x64063ba4,   // zu.sw.yo_333 eu.tr.sk_644  tl.vi.jw_322 so.de.lg_433
  0x521f4aad, 0x1a073b0c, 0x2d0d09a6, 0x27211f04,   // yo.cy.ha_643 so.it.tl_543  pl.cs.sk_521 cy.jw.gd_332
  0x096b4a04, 0x35526402, 0x320f3504, 0x0a23195a,   // yo.ceb.pl_332 lg.ha.zu_222  zu.lv.bs_332 gl.ca.pt_553
  // [abc0]
  0x35000722, 0x6b1c1307, 0x050e2107, 0x061809ad,   // it.zu.un_870 et.id.ceb_432  jw.is.fr_432 pl.ga.de_643
  0x100c23a0, 0x3f130112, 0x1200040e, 0x230c0407,   // ca.sv.lt_322 en.et.af_654  fi.hu.un_550 fi.sv.ca_432
  0x25190b13, 0x08020c0d, 0x031a3faf, 0x1a124aa7,   // es.gl.eu_665 sv.da.no_554  af.tl.nl_655 yo.hu.tl_532
  0x04252704, 0x2500272b, 0x2700252b, 0x04110a05,   // gd.eu.fi_332 gd.eu.un_980  eu.gd.un_980 mk.ro.ru_333
  // [abd0]
  0x212504af, 0x27002819, 0x311b4aa9, 0x212518a4,   // fi.eu.jw_655 sw.gd.un_750  yo.tr.az_544 ga.eu.jw_433
  0x2a552105, 0x116b27a0, 0x070e06a4, 0x2d2928a4,   // jw.rw.mt_333 gd.ceb.ro_322  de.is.it_433 sw.sl.sk_433
  0x0429090c, 0x281f6407, 0x1e280a07, 0x07051f11,   // pl.sl.fi_543 lg.cy.sw_432  pt.sw.ms_432 cy.fr.it_653
  0x04642508, 0x531a6b04, 0x350153a7, 0x2d092908,   // eu.lg.fi_443 ceb.tl.ht_332  ht.en.zu_532 sl.pl.sk_443
  // [abe0]
  0x681a2507, 0x2d3b6405, 0x05190aa7, 0x684a07a4,   // eu.tl.ig_432 lg.so.sk_333  pt.gl.fr_532 it.yo.ig_433
  0x0d356eac, 0x0c081b09, 0x06201109, 0x130853ec,   // hmn.zu.cs_632 tr.no.sv_444  ro.sq.de_444 ht.no.et_644
  0x0c310808, 0x04191f11, 0x68130414, 0x080e06af,   // no.az.sv_443 cy.gl.fi_653  fi.et.ig_666 de.is.no_655
  0x08004a0d, 0x2a4a6808, 0x4a6468a0, 0x04162da9,   // yo.no.un_540 ig.yo.mt_443  ig.lg.yo_322 sk.hr.fi_544
  // [abf0]
  0x080b310c, 0x1b2331ad, 0x68110a0c, 0x16002708,   // az.es.no_543 az.ca.tr_643  pt.ro.ig_543 gd.hr.un_430
  0x2d0d3b08, 0x3b1b045a, 0x232a01a0, 0x100920a0,   // so.cs.sk_443 fi.tr.so_553  en.mt.ca_322 sq.pl.lt_322
  0x130c04a6, 0x250810ee, 0x31000c0d, 0x12532812,   // fi.sv.et_521 lt.no.eu_422  sv.az.un_540 sw.ht.hu_654
  0x081b0c04, 0x21283bad, 0x0a0f0d11, 0x0d090c07,   // sv.tr.no_332 so.sw.jw_643  cs.lv.pt_653 sv.pl.cs_432

  // [ac00]
  0x23311b0d, 0x353b6807, 0x31081b12, 0x530568ec,   // tr.az.ca_554 ig.so.zu_432  tr.no.az_654 ig.fr.ht_644
  0x68002108, 0x683521a4, 0x6800281a, 0x3b006821,   // jw.ig.un_430 jw.zu.ig_433  sw.ig.un_760 ig.so.un_860
  0x1f000507, 0x5300640c, 0x040925ee, 0x131a0407,   // fr.cy.un_420 lg.ht.un_530  eu.pl.fi_422 fi.tl.et_432
  0x32092904, 0x203b1c07, 0x0c0b4aa0, 0x1f180911,   // sl.pl.bs_332 id.so.sq_432  yo.es.sv_322 pl.ga.cy_653
  // [ac10]
  0x090a2da4, 0x130f1ba4, 0x080c1eec, 0x3b004a13,   // sk.pt.pl_433 tr.lv.et_433  ms.sv.no_644 yo.so.un_650
  0x11190a02, 0x08200ead, 0x0b0d1907, 0x09130d5a,   // pt.gl.ro_222 is.sq.no_643  gl.cs.es_432 ne.bh.hi_553
  0x2d000b02, 0x27001604, 0x0e005219, 0x06102304,   // es.sk.un_220 hr.gd.un_320  ha.is.un_750 ca.lt.de_332
  0x1a0f1ba4, 0x2a003109, 0x1b001a1b, 0x03001002,   // tr.lv.tl_433 az.mt.un_440  tl.tr.un_770 lt.nl.un_220
  // [ac20]
  0x1a3b1f0b, 0x3f002b11, 0x1c130da4, 0x10170aee,   // cy.so.tl_542 vi.af.un_630  ne.bh.mr_433 mk.sr.be_422
  0x09002b08, 0x641b6b04, 0x111b35a7, 0x3b21270b,   // vi.pl.un_430 ceb.tr.lg_332  zu.tr.ro_532 gd.jw.so_542
  0x1100100e, 0x3b101aec, 0x323b1aa4, 0x10531e07,   // be.ro.un_550 tl.lt.so_644  tl.so.bs_433 ms.ht.lt_432
  0x012321a4, 0x3f1f0308, 0x3b551a0c, 0x256b550c,   // jw.ca.en_433 nl.cy.af_443  tl.rw.so_543 rw.ceb.eu_543
  // [ac30]
  0x532a07a0, 0x6b255311, 0x55080cad, 0x0200040c,   // it.mt.ht_322 ht.eu.ceb_653  sv.no.rw_643 fi.da.un_530
  0x05000a1a, 0x3b1a5512, 0x3b1b1604, 0x0c002707,   // pt.fr.un_760 rw.tl.so_654  hr.tr.so_332 gd.sv.un_420
  0x055325a4, 0x6e003f2b, 0x3f6e0811, 0x0d03110c,   // eu.ht.fr_433 af.hmn.un_980  no.hmn.af_653 ro.nl.cs_543
  0x19182760, 0x20001e11, 0x27086ead, 0x53002512,   // gd.ga.gl_664 ms.sq.un_630  hmn.no.gd_643 eu.ht.un_640
  // [ac40]
  0x052718ec, 0x031c3fad, 0x6e052314, 0x6b3528a6,   // ga.gd.fr_644 af.id.nl_643  ca.fr.hmn_666 sw.zu.ceb_521
  0x213b20ad, 0x091a55a0, 0x2b290a11, 0x2d090c09,   // sq.so.jw_643 rw.tl.pl_322  pt.sl.vi_653 sv.pl.sk_444
  0x0a230da0, 0x10556405, 0x233f2ba9, 0x313f1b0d,   // cs.ca.pt_322 lg.rw.lt_333  vi.af.ca_544 tr.af.az_554
  0x1e1c2855, 0x016e6b04, 0x08051807, 0x04641b0d,   // sw.id.ms_442 ceb.hmn.en_332  ga.fr.no_432 tr.lg.fi_554
  // [ac50]
  0x0600031b, 0x2b086813, 0x101f0411, 0x11000622,   // nl.de.un_770 ig.no.vi_665  fi.cy.lt_653 de.ro.un_870
  0x21063fa4, 0x3f002012, 0x030701a0, 0x1b063107,   // af.de.jw_433 sq.af.un_640  en.it.nl_322 az.de.tr_432
  0x211e050c, 0x32162da0, 0x2d00200b, 0x03011ea0,   // fr.ms.jw_543 sk.hr.bs_322  sq.sk.un_520 ms.en.nl_322
  0x1c000504, 0x190a0daf, 0x520c1f07, 0x121b1307,   // fr.id.un_320 cs.pt.gl_655  cy.sv.ha_432 et.tr.hu_432
  // [ac60]
  0x35080e02, 0x030507a4, 0x0d27180c, 0x1f1c25a7,   // is.no.zu_222 it.fr.nl_433  ga.gd.cs_543 eu.id.cy_532
  0x080c1c02, 0x520e1f07, 0x2b1c3fa7, 0x53003f08,   // id.sv.no_222 cy.is.ha_432  af.id.vi_532 af.ht.un_430
  0x211c08a4, 0x523b20a4, 0x13002d09, 0x0d2d35ad,   // no.id.jw_433 sq.so.ha_433  sk.et.un_440 zu.sk.cs_643
  0x03085311, 0x6e092da0, 0x2a3528ad, 0x1e3b28a0,   // ht.no.nl_653 sk.pl.hmn_322  sw.zu.mt_643 sw.so.ms_322
  // [ac70]
  0x0b111908, 0x130c0413, 0x20000b09, 0x181b0e04,   // gl.ro.es_443 fi.sv.et_665  es.sq.un_440 is.tr.ga_332
  0x321f1baf, 0x18005208, 0x03000802, 0x2d003207,   // tr.cy.bs_655 ha.ga.un_430  no.nl.un_220 bs.sk.un_420
  0x010e6b04, 0x121b0e07, 0x4a001004, 0x06003205,   // ceb.is.en_332 is.tr.hu_432  lt.yo.un_320 bs.de.un_330
  0x280518a4, 0x682a4aad, 0x0304210c, 0x092d3f04,   // ga.fr.sw_433 yo.mt.ig_643  jw.fi.nl_543 af.sk.pl_332
  // [ac80]
  0x066b010c, 0x081e0305, 0x0c13060b, 0x0f001f0e,   // en.ceb.de_543 nl.ms.no_333  de.et.sv_542 cy.lv.un_550
  0x0f4a68ec, 0x23003f09, 0x55683512, 0x05010705,   // ig.yo.lv_644 af.ca.un_440  zu.ig.rw_654 it.en.fr_333
  0x3f232904, 0x1300682b, 0x04551304, 0x25556b55,   // sl.ca.af_332 ig.et.un_980  et.rw.fi_332 ceb.rw.eu_442
  0x64355508, 0x28641012, 0x28002a12, 0x0c0811a6,   // rw.zu.lg_443 lt.lg.sw_654  mt.sw.un_640 ro.no.sv_521
  // [ac90]
  0x0d112da0, 0x012708a0, 0x2a1a4aad, 0x08520207,   // sk.ro.cs_322 no.gd.en_322  yo.tl.mt_643 da.ha.no_432
  0x193513ee, 0x35292105, 0x6e0a13ee, 0x2d1f05a0,   // et.zu.gl_422 jw.sl.zu_333  et.pt.hmn_422 fr.cy.sk_322
  0x20112107, 0x09281ca4, 0x32003f04, 0x1e003108,   // jw.ro.sq_432 id.sw.pl_433  af.bs.un_320 az.ms.un_430
  0x5200201b, 0x175229a0, 0x17095208, 0x13556ba4,   // sq.ha.un_770 sl.ha.sr_322  ha.pl.sr_443 ceb.rw.et_433
  // [aca0]
  0x215511ee, 0x100a1104, 0x0f2a070c, 0x120a23ee,   // ro.rw.jw_422 ro.pt.lt_332  it.mt.lv_543 ca.pt.hu_422
  0x21045308, 0x033f28a6, 0x09521207, 0x4a2a070c,   // ht.fi.jw_443 sw.af.nl_521  hu.ha.pl_432 it.mt.yo_543
  0x18033f04, 0x0b00111a, 0x12131f08, 0x13251260,   // af.nl.ga_332 ro.es.un_760  cy.et.hu_443 hu.eu.et_664
  0x11120aa0, 0x356812a4, 0x32002802, 0x3f4a68a0,   // pt.hu.ro_322 hu.ig.zu_433  sw.bs.un_220 ig.yo.af_322
  // [acb0]
  0x122a1fa9, 0x3f021fec, 0x0a100702, 0x2a0628af,   // cy.mt.hu_544 cy.da.af_644  bg.be.mk_222 sw.de.mt_655
  0x3b2d0fac, 0x521312a7, 0x3f004a1a, 0x4a211c07,   // lv.sk.so_632 hu.et.ha_532  yo.af.un_760 id.jw.yo_432
  0x353f6ba0, 0x0900102a, 0x130e23ee, 0x10006402,   // ceb.af.zu_322 lt.pl.un_970  ca.is.et_422 lg.lt.un_220
  0x2b250ba0, 0x1c06020d, 0x230e4a07, 0x2b000404,   // es.eu.vi_322 da.de.id_554  yo.is.ca_432 fi.vi.un_320
  // [acc0]
  0x201b6411, 0x0e051ba4, 0x280720ad, 0x0c352a04,   // lg.tr.sq_653 tr.fr.is_433  sq.it.sw_643 mt.zu.sv_332
  0x0e003b07, 0x206e0112, 0x16002307, 0x08040b02,   // so.is.un_420 en.hmn.sq_654  ca.hr.un_420 es.fi.no_222
  0x1a00090c, 0x0e2909a4, 0x112013a7, 0x211b1a04,   // pl.tl.un_530 pl.sl.is_433  et.sq.ro_532 tl.tr.jw_332
  0x351b4a07, 0x35002522, 0x120720af, 0x2d184a0c,   // yo.tr.zu_432 eu.zu.un_870  sq.it.hu_655 yo.ga.sk_543
  // [acd0]
  0x1b200605, 0x162953a0, 0x20280ead, 0x6b6423ad,   // de.sq.tr_333 ht.sl.hr_322  is.sw.sq_643 ca.lg.ceb_643
  0x25000418, 0x080c35ad, 0x08020c08, 0x35250608,   // fi.eu.un_740 zu.sv.no_643  sv.da.no_443 de.eu.zu_443
  0x68553505, 0x6b002713, 0x531b1e02, 0x0b5511a4,   // zu.rw.ig_333 gd.ceb.un_650  ms.tr.ht_222 ro.rw.es_433
  0x2d0d55a0, 0x03002009, 0x25015505, 0x033b3204,   // rw.cs.sk_322 sq.nl.un_440  rw.en.eu_333 bs.so.nl_332
  // [ace0]
  0x0a080e12, 0x2d080d07, 0x350a550c, 0x6b080c02,   // is.no.pt_654 cs.no.sk_432  rw.pt.zu_543 sv.no.ceb_222
  0x0a251b08, 0x1f0419ee, 0x0c083555, 0x0f136b04,   // tr.eu.pt_443 gl.fi.cy_422  zu.no.sv_442 ceb.et.lv_332
  0x0e1f06a9, 0x12250a07, 0x0825040c, 0x271f060c,   // de.cy.is_544 pt.eu.hu_432  fi.eu.no_543 de.cy.gd_543
  0x0a230ea9, 0x081f0508, 0x2d000905, 0x1e1b28ad,   // is.ca.pt_544 fr.cy.no_443  pl.sk.un_330 sw.tr.ms_643
  // [acf0]
  0x23000904, 0x09002308, 0x041b13ad, 0x0c025509,   // pl.ca.un_320 ca.pl.un_430  et.tr.fi_643 rw.da.sv_444
  0x2a000f08, 0x270b05a0, 0x0329640c, 0x531f1207,   // lv.mt.un_430 fr.es.gd_322  lg.sl.nl_543 hu.cy.ht_432
  0x0b1f070c, 0x1f000204, 0x05002702, 0x01091f04,   // it.cy.es_543 da.cy.un_320  gd.fr.un_220 cy.pl.en_332
  0x2d001e0e, 0x35550255, 0x03001b02, 0x09016ba4,   // ms.sk.un_550 da.rw.zu_442  tr.nl.un_220 ceb.en.pl_433
  // [ad00]
  0x0b1c10a0, 0x282a0a07, 0x17161009, 0x3216100c,   // lt.id.es_322 pt.mt.sw_432  lt.hr.sr_444 lt.hr.bs_543
  0x35550aa4, 0x08110308, 0x354a5514, 0x3b00290e,   // pt.rw.zu_433 nl.ro.no_443  rw.yo.zu_666 sl.so.un_550
  0x28003f07, 0x4a006414, 0x1008110c, 0x0a041011,   // af.sw.un_420 lg.yo.un_660  ro.uk.be_543 be.ru.mk_653
  0x0d131c0c, 0x10002918, 0x0d092908, 0x64000d12,   // mr.bh.ne_543 sl.lt.un_740  sl.pl.cs_443 cs.lg.un_640
  // [ad10]
  0x10080c07, 0x1b002520, 0x272d5507, 0x030b01a9,   // sv.no.lt_432 eu.tr.un_850  rw.sk.gd_432 en.es.nl_544
  0x101e08a4, 0x53003f35, 0x1c041360, 0x0d235304,   // no.ms.lt_433 af.ht.un_A90  et.fi.id_664 ht.ca.cs_332
  0x320901ac, 0x233f53ec, 0x28006822, 0x356b2da0,   // en.pl.bs_632 ht.af.ca_644  ig.sw.un_870 sk.ceb.zu_322
  0x53001c2b, 0x0f092907, 0x270553a0, 0x53233fad,   // id.ht.un_980 sl.pl.lv_432  ht.fr.gd_322 af.ca.ht_643
  // [ad20]
  0x18230507, 0x19530a04, 0x05532308, 0x2d180d12,   // fr.ca.ga_432 pt.ht.gl_332  ca.ht.fr_443 cs.ga.sk_654
  0x53003f1a, 0x1004520c, 0x182d0d0c, 0x27070b08,   // af.ht.un_760 ha.fi.lt_543  cs.sk.ga_543 es.it.gd_443
  0x550e53a9, 0x174a100b, 0x16044aa0, 0x13003207,   // ht.is.rw_544 lt.yo.sr_542  yo.fi.hr_322 bs.et.un_420
  0x070f0107, 0x551f28a0, 0x53113f55, 0x6b006418,   // en.lv.it_432 sw.cy.rw_322  af.ro.ht_442 lg.ceb.un_740
  // [ad30]
  0x3f005334, 0x0d001709, 0x1b00522b, 0x3f190aad,   // ht.af.un_A80 sr.cs.un_440  ha.tr.un_980 pt.gl.af_643
  0x03533f12, 0x3b0f52ad, 0x0d4a2da9, 0x18000d21,   // af.ht.nl_654 ha.lv.so_643  sk.yo.cs_544 cs.ga.un_860
  0x20000534, 0x171f4aa4, 0x6b0929a4, 0x21082504,   // fr.sq.un_A80 yo.cy.sr_433  sl.pl.ceb_433 eu.no.jw_332
  0x0b2308a4, 0x3b0f520c, 0x230f0608, 0x4a182d11,   // no.ca.es_433 ha.lv.so_543  de.lv.ca_443 sk.ga.yo_653
  // [ad40]
  0x09523bad, 0x101304ad, 0x18000d13, 0x182d0dad,   // so.ha.pl_643 fi.et.lt_643  cs.ga.un_650 cs.sk.ga_643
  0x0c00100d, 0x080925a0, 0x10011f12, 0x09001220,   // lt.sv.un_540 eu.pl.no_322  cy.en.lt_654 hu.pl.un_850
  0x251c21a9, 0x19000609, 0x1c0301a0, 0x03023fa9,   // jw.id.eu_544 de.gl.un_440  en.nl.id_322 af.da.nl_544
  0x6b005309, 0x1e1a28a7, 0x053f2312, 0x231925a4,   // ht.ceb.un_440 sw.tl.ms_532  ca.af.fr_654 eu.gl.ca_433
  // [ad50]
  0x031125ad, 0x1f190b55, 0x0c250808, 0x2d190d05,   // eu.ro.nl_643 es.gl.cy_442  no.eu.sv_443 cs.gl.sk_333
  0x0a1b110c, 0x011f35a0, 0x6b132007, 0x136b1a09,   // ro.tr.pt_543 zu.cy.en_322  sq.et.ceb_432 tl.ceb.et_444
  0x0f11250d, 0x55001b20, 0x52006e05, 0x061f0308,   // eu.ro.lv_554 tr.rw.un_850  hmn.ha.un_330 nl.cy.de_443
  0x130329ee, 0x521125af, 0x6b1135a7, 0x2a2031ad,   // sl.nl.et_422 eu.ro.ha_655  zu.ro.ceb_532 az.sq.mt_643
  // [ad60]
  0x3f2903a0, 0x1b2d3109, 0x2a001112, 0x012d35a0,   // nl.sl.af_322 az.sk.tr_444  ro.mt.un_640 zu.sk.en_322
  0x2a201212, 0x075305a0, 0x3f002904, 0x02080e0c,   // hu.sq.mt_654 fr.ht.it_322  sl.af.un_320 is.no.da_543
  0x080f17ee, 0x52255304, 0x1e180107, 0x1f5325ad,   // sr.lv.no_422 ht.eu.ha_332  en.ga.ms_432 eu.ht.cy_643
  0x6b00100d, 0x1e271ca9, 0x274a2107, 0x6b1f270c,   // lt.ceb.un_540 id.gd.ms_544  jw.yo.gd_432 gd.cy.ceb_543
  // [ad70]
  0x532b52a4, 0x060710a0, 0x2b080208, 0x1a18270c,   // ha.vi.ht_433 lt.it.de_322  da.no.vi_443 gd.ga.tl_543
  0x0f6e20a9, 0x02253bad, 0x0c251a0c, 0x27180a11,   // sq.hmn.lv_544 so.eu.da_643  tl.eu.sv_543 pt.ga.gd_653
  0x27181ca4, 0x0400050e, 0x533b25ec, 0x10290dad,   // id.ga.gd_433 fr.fi.un_550  eu.so.ht_644 cs.sl.lt_643
  0x18271f04, 0x20293202, 0x643b1f0d, 0x1017110c,   // cy.gd.ga_332 bs.sl.sq_222  cy.so.lg_554 ro.sr.be_543
  // [ad80]
  0x1e2855a0, 0x3b1752a4, 0x18270507, 0x320810a0,   // rw.sw.ms_322 ha.sr.so_433  fr.gd.ga_432 lt.no.bs_322
  0x1f00530e, 0x68100504, 0x2b1f27a4, 0x1900520b,   // ht.cy.un_550 fr.lt.ig_332  gd.cy.vi_433 ha.gl.un_520
  0x1e536e0c, 0x1c521a0c, 0x033f2b0c, 0x1f001a1b,   // hmn.ht.ms_543 tl.ha.id_543  vi.af.nl_543 tl.cy.un_770
  0x180401af, 0x251f2708, 0x21271c08, 0x536e1f0c,   // en.fi.ga_655 gd.cy.eu_443  id.gd.jw_443 cy.hmn.ht_543
  // [ad90]
  0x051c1a0c, 0x07056407, 0x6e000d0d, 0x21006818,   // tl.id.fr_543 lg.fr.it_432  cs.hmn.un_540 ig.jw.un_740
  0x1c05210c, 0x173f0304, 0x3f0305a0, 0x3f000a0d,   // jw.fr.id_543 nl.af.sr_332  fr.nl.af_322 pt.af.un_540
  0x320f0da0, 0x13120b04, 0x23000614, 0x1a1b310c,   // cs.lv.bs_322 es.hu.et_332  de.ca.un_660 az.tr.tl_543
  0x3f211ea4, 0x1f1e270c, 0x64004a19, 0x35211aad,   // ms.jw.af_433 gd.ms.cy_543  yo.lg.un_750 tl.jw.zu_643
  // [ada0]
  0x061b31ee, 0x1b0e310c, 0x0d061b04, 0x1b3113a0,   // az.tr.de_422 az.is.tr_543  tr.de.cs_332 et.az.tr_322
  0x03000d0c, 0x1b311f04, 0x0e0c1fa4, 0x08171b07,   // cs.nl.un_530 cy.az.tr_332  cy.sv.is_433 tr.sr.no_432
  0x3b311b04, 0x190a01ee, 0x04023107, 0x100d09ad,   // tr.az.so_332 en.pt.gl_422  az.da.fi_432 pl.cs.lt_643
  0x0e311baf, 0x20131004, 0x4a1b3108, 0x283b0fad,   // tr.az.is_655 lt.et.sq_332  az.tr.yo_443 lv.so.sw_643
  // [adb0]
  0x06020702, 0x1c1b210c, 0x0a0c070c, 0x11090da4,   // it.da.de_222 jw.tr.id_543  it.sv.pt_543 cs.pl.ro_433
  0x553f2aa0, 0x122a130d, 0x20043b0c, 0x1c0312a7,   // mt.af.rw_322 et.mt.hu_554  so.fi.sq_543 hu.nl.id_532
  0x0c041309, 0x13070fa0, 0x06005202, 0x08002a08,   // et.fi.sv_444 lv.it.et_322  ha.de.un_220 mt.no.un_430
  0x081f0107, 0x1a294aa0, 0x122006ee, 0x1e6b01ee,   // en.cy.no_432 yo.sl.tl_322  de.sq.hu_422 en.ceb.ms_422
  // [adc0]
  0x3204130c, 0x55003502, 0x0b002314, 0x16000e05,   // et.fi.bs_543 zu.rw.un_220  ca.es.un_660 is.hr.un_330
  0x0a111714, 0x076b04ad, 0x0500130d, 0x024a1cad,   // sr.ro.mk_666 fi.ceb.it_643  et.fr.un_540 id.yo.da_643
  0x27002a0c, 0x28035507, 0x55000302, 0x0e001f0d,   // mt.gd.un_530 rw.nl.sw_432  nl.rw.un_220 cy.is.un_540
  0x285503ee, 0x31002a02, 0x350f52a7, 0x3b211e0d,   // nl.rw.sw_422 mt.az.un_220  ha.lv.zu_532 ms.jw.so_554
  // [add0]
  0x043b0305, 0x216b1c09, 0x1c000419, 0x1c041e11,   // nl.so.fi_333 id.ceb.jw_444  fi.id.un_750 ms.fi.id_653
  0x04683b0c, 0x21041e0c, 0x212b1c04, 0x17322955,   // so.ig.fi_543 ms.fi.jw_543  id.vi.jw_332 sl.bs.sr_442
  0x133f1812, 0x1b31680d, 0x4a683bad, 0x2a2103ac,   // ga.af.et_654 ig.az.tr_554  so.ig.yo_643 nl.jw.mt_632
  0x1c1128ac, 0x32681a08, 0x1f002114, 0x1c1e3b12,   // sw.ro.id_632 tl.ig.bs_443  jw.cy.un_660 so.ms.id_654
  // [ade0]
  0x190b1faf, 0x68354a12, 0x190b03a4, 0x033b680c,   // cy.es.gl_655 yo.zu.ig_654  nl.es.gl_433 ig.so.nl_543
  0x06100c04, 0x031a1309, 0x3f3b04a9, 0x4a3b285a,   // sv.lt.de_332 et.tl.nl_444  fi.so.af_544 sw.so.yo_553
  0x103f0fa7, 0x19002119, 0x062053a0, 0x160908a0,   // lv.af.lt_532 jw.gl.un_750  ht.sq.de_322 no.pl.hr_322
  0x04001a14, 0x3f030907, 0x06005504, 0x310b23ee,   // tl.fi.un_660 pl.nl.af_432  rw.de.un_320 ca.es.az_422
  // [adf0]
  0x1a2b18a0, 0x042029ad, 0x2a000a1b, 0x6b0910ec,   // ga.vi.tl_322 sl.sq.fi_643  pt.mt.un_770 lt.pl.ceb_644
  0x06120305, 0x1008115a, 0x3500252a, 0x0400281a,   // nl.hu.de_333 ro.uk.be_553  eu.zu.un_970 sw.fi.un_760
  0x18272104, 0x033f1e0d, 0x3f0806a4, 0x093f13a4,   // jw.gd.ga_332 ms.af.nl_554  de.no.af_433 et.af.pl_433
  0x182a270c, 0x32253504, 0x0b2955ee, 0x070811af,   // gd.mt.ga_543 zu.eu.bs_332  rw.sl.es_422 ro.uk.bg_655
  // [ae00]
  0x641235ec, 0x17200655, 0x214a1aee, 0x0c091055,   // zu.hu.lg_644 de.sq.sr_442  tl.yo.jw_422 lt.pl.sv_442
  0x06001221, 0x0621030c, 0x050c0804, 0x550d3555,   // hu.de.un_860 nl.jw.de_543  no.sv.fr_332 zu.cs.rw_442
  0x2b001f13, 0x2a20520c, 0x08020daf, 0x3f120804,   // cy.vi.un_650 ha.sq.mt_543  cs.da.no_655 no.hu.af_332
  0x35093f0c, 0x1700280d, 0x07280b08, 0x103216ee,   // af.pl.zu_543 sw.sr.un_540  es.sw.it_443 hr.bs.lt_422
  // [ae10]
  0x190b07a9, 0x2d0d0c05, 0x53120911, 0x072b19a0,   // it.es.gl_544 sv.cs.sk_333  pl.hu.ht_653 gl.vi.it_322
  0x1c1127a0, 0x2700210e, 0x3b001602, 0x04251a55,   // gd.ro.id_322 jw.gd.un_550  hr.so.un_220 tl.eu.fi_442
  0x13001205, 0x29006821, 0x2a315207, 0x081017af,   // hu.et.un_330 ig.sl.un_860  ha.az.mt_432 sr.be.uk_655
  0x11071a13, 0x190b18a9, 0x27181f55, 0x17100702,   // tl.it.ro_665 ga.es.gl_544  cy.ga.gd_442 bg.be.sr_222
  // [ae20]
  0x09000402, 0x120c17ee, 0x0c0e1fad, 0x2d0d0ea7,   // fi.pl.un_220 sr.sv.hu_422  cy.is.sv_643 is.cs.sk_532
  0x12003b07, 0x19180ba4, 0x28136407, 0x281809ad,   // so.hu.un_420 es.ga.gl_433  lg.et.sw_432 pl.ga.sw_643
  0x35523bec, 0x293b6ba4, 0x16000504, 0x11100808,   // so.ha.zu_644 ceb.so.sl_433  fr.hr.un_320 uk.be.ro_443
  0x190b18a6, 0x0b190a60, 0x0e0c0507, 0x4a000d13,   // ga.es.gl_521 pt.gl.es_664  fr.sv.is_432 cs.yo.un_650
  // [ae30]
  0x23122004, 0x10640407, 0x190a0602, 0x2d0d1fa4,   // sq.hu.ca_332 fi.lg.lt_432  de.pt.gl_222 cy.cs.sk_433
  0x4a001f04, 0x0d093bad, 0x093b1fee, 0x2902080c,   // cy.yo.un_320 so.pl.cs_643  cy.so.pl_422 no.da.sl_543
  0x3b051907, 0x031b0e04, 0x3b091f0b, 0x1f000e0c,   // gl.fr.so_432 is.tr.nl_332  cy.pl.so_542 is.cy.un_530
  0x282a18a0, 0x080c1ca0, 0x2904550c, 0x110623ec,   // ga.mt.sw_322 id.sv.no_322  rw.fi.sl_543 ca.de.ro_644
  // [ae40]
  0x0b2305a0, 0x2a0e0807, 0x31000c04, 0x64350b09,   // fr.ca.es_322 no.is.mt_432  sv.az.un_320 es.zu.lg_444
  0x20556411, 0x0e130802, 0x6e2101a0, 0x29644a0c,   // lg.rw.sq_653 no.et.is_222  en.jw.hmn_322 yo.lg.sl_543
  0x06250304, 0x4a005513, 0x0e520ca4, 0x3f001c12,   // nl.eu.de_332 rw.yo.un_650  sv.ha.is_433 id.af.un_640
  0x2152120c, 0x23201308, 0x6b121f55, 0x042d0dad,   // hu.ha.jw_543 et.sq.ca_443  cy.hu.ceb_442 cs.sk.fi_643
  // [ae50]
  0x1b105307, 0x3f211f60, 0x0c0306ee, 0x12005223,   // ht.lt.tr_432 cy.jw.af_664  de.nl.sv_422 ha.hu.un_880
  0x05170dee, 0x1a162102, 0x29211f04, 0x035306a4,   // cs.sr.fr_422 jw.hr.tl_222  cy.jw.sl_332 de.ht.nl_433
  0x036b0aee, 0x06120807, 0x16091207, 0x3b056ba9,   // pt.ceb.nl_422 no.hu.de_432  hu.pl.hr_432 ceb.fr.so_544
  0x3f080e0c, 0x0c230707, 0x0c1f12a4, 0x180d0ba0,   // is.no.af_543 it.ca.sv_432  hu.cy.sv_433 es.cs.ga_322
  // [ae60]
  0x64551b04, 0x1f296ea4, 0x0c2d1b08, 0x060b110c,   // tr.rw.lg_332 hmn.sl.cy_433  tr.sk.sv_443 ro.es.de_543
  0x523555ac, 0x0c020307, 0x32030607, 0x190a35a4,   // rw.zu.ha_632 nl.da.sv_432  de.nl.bs_432 zu.pt.gl_433
  0x0f060111, 0x060c0e07, 0x116455ad, 0x110a0107,   // en.de.lv_653 is.sv.de_432  rw.lg.ro_643 en.pt.ro_432
  0x64553560, 0x0708105a, 0x09001204, 0x0a1110a4,   // zu.rw.lg_664 be.uk.bg_553  hu.pl.un_320 lt.ro.pt_433
  // [ae70]
  0x1b0802a0, 0x232d0d13, 0x27040607, 0x0c030e04,   // da.no.tr_322 cs.sk.ca_665  de.fi.gd_432 is.nl.sv_332
  0x172555a4, 0x32271fa9, 0x12000d04, 0x12530aa0,   // rw.eu.sr_433 cy.gd.bs_544  cs.hu.un_320 pt.ht.hu_322
  0x526e2512, 0x32011107, 0x2b211c11, 0x2b6e25a9,   // eu.hmn.ha_654 ro.en.bs_432  id.jw.vi_653 eu.hmn.vi_544
  0x232552a4, 0x2500532b, 0x170553a0, 0x232b1f13,   // ha.eu.ca_433 ht.eu.un_980  ht.fr.sr_322 cy.vi.ca_665
  // [ae80]
  0x313f1f55, 0x25001f14, 0x23005202, 0x52116e07,   // cy.af.az_442 cy.eu.un_660  ha.ca.un_220 hmn.ro.ha_432
  0x6e005222, 0x310c13a4, 0x112b6e04, 0x170a04a9,   // ha.hmn.un_870 et.sv.az_433  hmn.vi.ro_332 ru.mk.sr_544
  0x311a2d07, 0x6e2b1114, 0x1a043bac, 0x050a230b,   // sk.tl.az_432 ro.vi.hmn_666  so.fi.tl_632 ca.pt.fr_542
  0x35206407, 0x0c1f07ee, 0x3b1a060c, 0x04236e04,   // lg.sq.zu_432 it.cy.sv_422  de.tl.so_543 hmn.ca.fi_332
  // [ae90]
  0x1e002118, 0x32160bee, 0x0b002822, 0x1c255307,   // jw.ms.un_740 es.hr.bs_422  sw.es.un_870 ht.eu.id_432
  0x52001f18, 0x5553290c, 0x08020609, 0x1806030c,   // cy.ha.un_740 sl.ht.rw_543  de.da.no_444 nl.de.ga_543
  0x643531a7, 0x1b5209a4, 0x09001a09, 0x2a100f09,   // az.zu.lg_532 pl.ha.tr_433  tl.pl.un_440 lv.lt.mt_444
  0x1a011b04, 0x13002002, 0x1a190b04, 0x196b1aad,   // tr.en.tl_332 sq.et.un_220  es.gl.tl_332 tl.ceb.gl_643
  // [aea0]
  0x0b001a20, 0x3200031a, 0x351b3155, 0x646855ec,   // tl.es.un_850 nl.bs.un_760  az.tr.zu_442 rw.ig.lg_644
  0x03000c02, 0x55684aa4, 0x2b3513a0, 0x17682da0,   // sv.nl.un_220 yo.ig.rw_433  et.zu.vi_322 sk.ig.sr_322
  0x04522aad, 0x554a35a9, 0x0d002012, 0x16032a08,   // mt.ha.fi_643 zu.yo.rw_544  sq.cs.un_640 mt.nl.hr_443
  0x3f1b1f07, 0x25202a0c, 0x0c08230d, 0x6420550b,   // cy.tr.af_432 mt.sq.eu_543  ca.no.sv_554 rw.sq.lg_542
  // [aeb0]
  0x25205508, 0x1f00070e, 0x6b686eee, 0x0e0d21a0,   // rw.sq.eu_443 it.cy.un_550  hmn.ig.ceb_422 jw.cs.is_322
  0x1a5255ac, 0x040b5502, 0x352718a0, 0x042b35a0,   // rw.ha.tl_632 rw.es.fi_222  ga.gd.zu_322 zu.vi.fi_322
  0x190b1baf, 0x21000a02, 0x0c3f030c, 0x182827ee,   // tr.es.gl_655 pt.jw.un_220  nl.af.sv_543 gd.sw.ga_422
  0x080c13ec, 0x1a2855a4, 0x063555ad, 0x351325af,   // et.sv.no_644 rw.sw.tl_433  rw.zu.de_643 eu.et.zu_655
  // [aec0]
  0x350c5504, 0x35551305, 0x05191bee, 0x11551ba4,   // rw.sv.zu_332 et.rw.zu_333  tr.gl.fr_422 tr.rw.ro_433
  0x065513a7, 0x080525a4, 0x015535a0, 0x105223a7,   // et.rw.de_532 eu.fr.no_433  zu.rw.en_322 ca.ha.lt_532
  0x03001218, 0x0800550b, 0x6e005512, 0x13285511,   // hu.nl.un_740 rw.no.un_520  rw.hmn.un_640 rw.sw.et_653
  0x2b5511a0, 0x0801070d, 0x0c085512, 0x18001e18,   // ro.rw.vi_322 it.en.no_554  rw.no.sv_654 ms.ga.un_740
  // [aed0]
  0x25001b13, 0x0c5508a4, 0x13003502, 0x1a556408,   // tr.eu.un_650 no.rw.sv_433  zu.et.un_220 lg.rw.tl_443
  0x551e1c14, 0x28000d0d, 0x1a09100c, 0x080a070b,   // id.ms.rw_666 cs.sw.un_540  lt.pl.tl_543 bg.mk.uk_542
  0x1100020c, 0x1b2752a4, 0x08022502, 0x53092a55,   // da.ro.un_530 ha.gd.tr_433  eu.da.no_222 mt.pl.ht_442
  0x2d0929a4, 0x356b2a04, 0x534a21ee, 0x20212a04,   // sl.pl.sk_433 mt.ceb.zu_332  jw.yo.ht_422 mt.jw.sq_332
  // [aee0]
  0x531f2aad, 0x351a53ec, 0x530a04ee, 0x016b52ee,   // mt.cy.ht_643 ht.tl.zu_644  fi.pt.ht_422 ha.ceb.en_422
  0x070a3ba4, 0x09645512, 0x09001a0d, 0x2d0d17a9,   // so.pt.it_433 rw.lg.pl_654  tl.pl.un_540 sr.cs.sk_544
  0x2d070907, 0x532a09ec, 0x06190b05, 0x1f2a5304,   // pl.it.sk_432 pl.mt.ht_644  es.gl.de_333 ht.mt.cy_332
  0x092a0107, 0x100f285a, 0x0f042aa4, 0x110b0408,   // en.mt.pl_432 sw.lv.lt_553  mt.fi.lv_433 fi.es.ro_443
  // [aef0]
  0x351a31ad, 0x523b2a05, 0x012b1c0b, 0x52002a13,   // az.tl.zu_643 mt.so.ha_333  id.vi.en_542 mt.ha.un_650
  0x29090fad, 0x212b1cee, 0x2d6b09ad, 0x3b0e08a7,   // lv.pl.sl_643 id.vi.jw_422  pl.ceb.sk_643 no.is.so_532
  0x250c19ad, 0x1a190b08, 0x05042804, 0x04000a2a,   // gl.sv.eu_643 es.gl.tl_443  sw.fi.fr_332 pt.fi.un_970
  0x012309ee, 0x04000511, 0x07060360, 0x2b002a0d,   // pl.ca.en_422 fr.fi.un_630  nl.de.it_664 mt.vi.un_540
  // [af00]
  0x27230509, 0x2a0823af, 0x040f13a0, 0x033f2712,   // fr.ca.gd_444 ca.no.mt_655  et.lv.fi_322 gd.af.nl_654
  0x050b01a4, 0x2b0123ee, 0x05004a0e, 0x1f2a2360,   // en.es.fr_433 ca.en.vi_422  yo.fr.un_550 ca.mt.cy_664
  0x1e1c2108, 0x16002a12, 0x1e003202, 0x32000607,   // jw.id.ms_443 mt.hr.un_640  bs.ms.un_220 de.bs.un_420
  0x055568a0, 0x10252908, 0x2d0d3f5a, 0x3b6407a0,   // ig.rw.fr_322 sl.eu.lt_443  af.cs.sk_553 it.lg.so_322
  // [af10]
  0x0b006b18, 0x640955a4, 0x0a003b02, 0x1a3b090c,   // ceb.es.un_740 rw.pl.lg_433  so.pt.un_220 pl.so.tl_543
  0x072164a4, 0x0b25190d, 0x2d0d29a7, 0x2a002d04,   // lg.jw.it_433 gl.eu.es_554  sl.cs.sk_532 sk.mt.un_320
  0x6b006405, 0x0b001f09, 0x0a315555, 0x18000613,   // lg.ceb.un_330 cy.es.un_440  rw.az.pt_442 de.ga.un_650
  0x28003f04, 0x10030f02, 0x0d090aa0, 0x32002304,   // af.sw.un_320 lv.nl.lt_222  pt.pl.cs_322 ca.bs.un_320
  // [af20]
  0x101b06a0, 0x2d004a1a, 0x08002902, 0x0c000421,   // de.tr.lt_322 yo.sk.un_760  sl.no.un_220 fi.sv.un_860
  0x0d016ba0, 0x29061fa0, 0x0e031004, 0x1e1c2805,   // ceb.en.cs_322 cy.de.sl_322  lt.nl.is_332 sw.id.ms_333
  0x0f1729a0, 0x11055208, 0x09130da6, 0x1e1c68a9,   // sl.sr.lv_322 ha.fr.ro_443  cs.et.pl_521 ig.id.ms_544
  0x181e1c5a, 0x28646811, 0x080c3fee, 0x640968ec,   // id.ms.ga_553 ig.lg.sw_653  af.sv.no_422 ig.pl.lg_644
  // [af30]
  0x2827180e, 0x0800680c, 0x1e1c52a9, 0x20326812,   // ga.gd.sw_555 ig.no.un_530  ha.id.ms_544 ig.bs.sq_654
  0x03080ea4, 0x170f03ac, 0x3f032da4, 0x070523a4,   // is.no.nl_433 nl.lv.sr_632  sk.nl.af_433 ca.fr.it_433
  0x352a55af, 0x1e292d07, 0x2a55640c, 0x64552014,   // rw.mt.zu_655 sk.sl.ms_432  lg.rw.mt_543 sq.rw.lg_666
  0x10110855, 0x070a2302, 0x640e13ec, 0x0b1125a4,   // no.ro.lt_442 ca.pt.it_222  et.is.lg_644 eu.ro.es_433
  // [af40]
  0x060103ad, 0x551f0708, 0x02120508, 0x093f2da0,   // nl.en.de_643 it.cy.rw_443  fr.hu.da_443 sk.af.pl_322
  0x08001b18, 0x2d291605, 0x10000e14, 0x03002a14,   // tr.no.un_740 hr.sl.sk_333  is.lt.un_660 mt.nl.un_660
  0x112123af, 0x321b0a04, 0x133f1b0c, 0x321603a4,   // ca.jw.ro_655 pt.tr.bs_332  tr.af.et_543 nl.hr.bs_433
  0x29173fa4, 0x2a2d09a6, 0x11055308, 0x64000512,   // af.sr.sl_433 pl.sk.mt_521  ht.fr.ro_443 fr.lg.un_640
  // [af50]
  0x12000c18, 0x3f0c12a6, 0x040506a7, 0x1800100c,   // sv.hu.un_740 hu.sv.af_521  de.fr.fi_532 lt.ga.un_530
  0x230b25a9, 0x0c082104, 0x0508020e, 0x3f1b1ca0,   // eu.es.ca_544 jw.no.sv_332  da.no.fr_555 id.tr.af_322
  0x041b1002, 0x133f1b07, 0x2d002012, 0x13001804,   // lt.tr.fi_222 tr.af.et_432  sq.sk.un_640 ga.et.un_320
  0x04123fa0, 0x03120807, 0x08020705, 0x180e130c,   // af.hu.fi_322 no.hu.nl_432  it.da.no_333 et.is.ga_543
  // [af60]
  0x210568a7, 0x21005502, 0x25110b04, 0x6b060302,   // ig.fr.jw_532 rw.jw.un_220  es.ro.eu_332 nl.de.ceb_222
  0x08001311, 0x271b01a0, 0x1c2155a4, 0x52002109,   // et.no.un_630 en.tr.gd_322  rw.jw.id_433 jw.ha.un_440
  0x095510ad, 0x1a553ba4, 0x321609af, 0x531f3ba0,   // lt.rw.pl_643 so.rw.tl_433  pl.hr.bs_655 so.cy.ht_322
  0x190b1f0c, 0x0d002521, 0x55000905, 0x286e210c,   // cy.es.gl_543 eu.cs.un_860  pl.rw.un_330 jw.hmn.sw_543
  // [af70]
  0x0a0206a7, 0x09272104, 0x166b0909, 0x211c2812,   // de.da.pt_532 jw.gd.pl_332  pl.ceb.hr_444 sw.id.jw_654
  0x093f10a4, 0x1900310c, 0x1b310e12, 0x291805ec,   // lt.af.pl_433 az.gl.un_530  is.az.tr_654 fr.ga.sl_644
  0x050c010c, 0x4a556408, 0x1e1c2ba0, 0x52684a13,   // en.sv.fr_543 lg.rw.yo_443  vi.id.ms_322 yo.ig.ha_665
  0x310e1f12, 0x253568a0, 0x3b310b04, 0x1e1c2909,   // cy.is.az_654 ig.zu.eu_322  es.az.so_332 sl.id.ms_444
  // [af80]
  0x215309a0, 0x1e1c2509, 0x1f1b315a, 0x05231fa7,   // pl.ht.jw_322 eu.id.ms_444  az.tr.cy_553 cy.ca.fr_532
  0x06286ba4, 0x1f311b13, 0x160929ee, 0x0528190d,   // ceb.sw.de_433 tr.az.cy_665  sl.pl.hr_422 gl.sw.fr_554
  0x010a6ba4, 0x1c1e31a7, 0x0c0831ec, 0x020106ee,   // ceb.pt.en_433 az.ms.id_532  az.no.sv_644 de.en.da_422
  0x0d003f04, 0x3b2a13a6, 0x122d210e, 0x2d162904,   // af.cs.un_320 et.mt.so_521  jw.sk.hu_555 sl.hr.sk_332
  // [af90]
  0x0a1e1c04, 0x536e070b, 0x20001004, 0x18311b09,   // id.ms.pt_332 it.hmn.ht_542  lt.sq.un_320 tr.az.ga_444
  0x08311309, 0x043f2007, 0x3f350307, 0x040811ac,   // et.az.no_444 sq.af.fi_432  nl.zu.af_432 ro.uk.ru_632
  0x23001302, 0x23041302, 0x0a102d55, 0x12180e07,   // et.ca.un_220 et.fi.ca_222  sk.lt.pt_442 is.ga.hu_432
  0x19182b0c, 0x23041304, 0x191e1c04, 0x53002523,   // vi.ga.gl_543 et.fi.ca_332  id.ms.gl_332 eu.ht.un_880
  // [afa0]
  0x0200180d, 0x100f1708, 0x033f200c, 0x522807a4,   // ga.da.un_540 sr.lv.lt_443  sq.af.nl_543 it.sw.ha_433
  0x19094a04, 0x172129a7, 0x03001b12, 0x2900202a,   // yo.pl.gl_332 sl.jw.sr_532  tr.nl.un_640 sq.sl.un_970
  0x53256bad, 0x3f1f0913, 0x3b2319a7, 0x12041b04,   // ceb.eu.ht_643 pl.cy.af_665  gl.ca.so_532 tr.fi.hu_332
  0x04132a0c, 0x0a102da0, 0x643f29a4, 0x25230307,   // mt.et.fi_543 sk.lt.pt_322  sl.af.lg_433 nl.ca.eu_432
  // [afb0]
  0x2503090b, 0x1e1003a7, 0x1c1f21af, 0x25001812,   // pl.nl.eu_542 nl.lt.ms_532  jw.cy.id_655 ga.eu.un_640
  0x2d1f0d07, 0x284a31a9, 0x0c3f0fee, 0x160c06ee,   // cs.cy.sk_432 az.yo.sw_544  lv.af.sv_422 de.sv.hr_422
  0x311b0e09, 0x0d000807, 0x08520e08, 0x1e291ca4,   // is.tr.az_444 no.cs.un_420  is.ha.no_443 id.sl.ms_433
  0x55212012, 0x52254a07, 0x1e2d0d11, 0x0e0c1f0c,   // sq.jw.rw_654 yo.eu.ha_432  cs.sk.ms_653 cy.sv.is_543
  // [afc0]
  0x1e001902, 0x18001913, 0x551b68af, 0x19310b55,   // gl.ms.un_220 gl.ga.un_650  ig.tr.rw_655 es.az.gl_442
  0x1c4a1ea4, 0x64001f12, 0x68534a60, 0x270631a7,   // ms.yo.id_433 cy.lg.un_640  yo.ht.ig_664 az.de.gd_532
  0x320d2da0, 0x1b081fa0, 0x31080f04, 0x020308a4,   // sk.cs.bs_322 cy.no.tr_322  lv.no.az_332 no.nl.da_433
  0x1b0b08a0, 0x281620a0, 0x0c523b08, 0x19000604,   // no.es.tr_322 sq.hr.sw_322  so.ha.sv_443 de.gl.un_320
  // [afd0]
  0x296b1a04, 0x2916040e, 0x273b13a0, 0x68000219,   // tl.ceb.sl_332 fi.hr.sl_555  et.so.gd_322 da.ig.un_750
  0x552932a0, 0x02311b0b, 0x3b190a0d, 0x18131f55,   // bs.sl.rw_322 tr.az.da_542  pt.gl.so_554 cy.et.ga_442
  0x3b1b1012, 0x232013a7, 0x0e122107, 0x0f0121a0,   // lt.tr.so_654 et.sq.ca_532  jw.hu.is_432 jw.en.lv_322
  0x1e171c04, 0x166b0eee, 0x0e121302, 0x161a2807,   // id.sr.ms_332 is.ceb.hr_422  et.hu.is_222 sw.tl.hr_432
  // [afe0]
  0x130212a9, 0x21311b55, 0x0e3b27ad, 0x180128a6,   // hu.da.et_544 tr.az.jw_442  gd.so.is_643 sw.en.ga_521
  0x070b01a4, 0x130d095a, 0x201a1f04, 0x0b0a0eec,   // en.es.it_433 hi.ne.bh_553  cy.tl.sq_332 is.pt.es_644
  0x211e0eee, 0x3b281a02, 0x081f02ee, 0x19250aa4,   // is.ms.jw_422 tl.sw.so_222  da.cy.no_422 pt.eu.gl_433
  0x202835a0, 0x311e1c02, 0x3b081a12, 0x18190f04,   // zu.sw.sq_322 id.ms.az_222  tl.no.so_654 lv.gl.ga_332
  // [aff0]
  0x2b190fa0, 0x1a27180e, 0x18191f08, 0x6e532ba4,   // lv.gl.vi_322 ga.gd.tl_555  cy.gl.ga_443 vi.ht.hmn_433
  0x1e292007, 0x21033f02, 0x27180807, 0x6e532b08,   // sq.sl.ms_432 af.nl.jw_222  no.ga.gd_432 vi.ht.hmn_443
  0x53206e05, 0x180a0807, 0x0a1b6e12, 0x10005313,   // hmn.sq.ht_333 no.pt.ga_432  hmn.tr.pt_654 ht.lt.un_650
  0x01033fad, 0x231a10a0, 0x311b6e04, 0x19181f0c,   // af.nl.en_643 lt.tl.ca_322  hmn.tr.az_332 cy.ga.gl_543

  // [b000]
  0x0f160404, 0x290e0d0b, 0x6b1a1baf, 0x0c0a2913,   // fi.hr.lv_332 cs.is.sl_542  tr.tl.ceb_655 sl.pt.sv_665
  0x020c04a0, 0x6453060b, 0x29000a2c, 0x12102da6,   // fi.sv.da_322 de.ht.lg_542  pt.sl.un_990 sk.lt.hu_521
  0x08001e08, 0x3b1135ee, 0x03130602, 0x1b0901a4,   // ms.no.un_430 zu.ro.so_422  de.et.nl_222 en.pl.tr_433
  0x27130a07, 0x643501a0, 0x0c2128a0, 0x3b000c19,   // pt.et.gd_432 en.zu.lg_322  sw.jw.sv_322 sv.so.un_750
  // [b010]
  0x250631a4, 0x0f0d29ee, 0x211b3112, 0x04280f04,   // az.de.eu_433 sl.cs.lv_422  az.tr.jw_654 lv.sw.fi_332
  0x120f11a7, 0x216b1a13, 0x18033f02, 0x031b31a0,   // ro.lv.hu_532 tl.ceb.jw_665  af.nl.ga_222 az.tr.nl_322
  0x0807105a, 0x04080c14, 0x10352ba7, 0x0e256ba9,   // be.bg.uk_553 sv.no.fi_666  vi.zu.lt_532 ceb.eu.is_544
  0x64004a09, 0x350452a4, 0x13002712, 0x0f350ca7,   // yo.lg.un_440 ha.fi.zu_433  gd.et.un_640 sv.zu.lv_532
  // [b020]
  0x100d1b07, 0x52000422, 0x551264ee, 0x06082a55,   // tr.cs.lt_432 fi.ha.un_870  lg.hu.rw_422 mt.no.de_442
  0x05011008, 0x0c0806af, 0x0a280c55, 0x55006b0e,   // lt.en.fr_443 de.no.sv_655  sv.sw.pt_442 ceb.rw.un_550
  0x0c130a08, 0x04201f0d, 0x2a0a07a0, 0x3f1a1208,   // pt.et.sv_443 cy.sq.fi_554  it.pt.mt_322 hu.tl.af_443
  0x0e041fee, 0x1a211e0c, 0x276b1a12, 0x5300212a,   // cy.fi.is_422 ms.jw.tl_543  tl.ceb.gd_654 jw.ht.un_970
  // [b030]
  0x0a170460, 0x210c52a7, 0x160435ad, 0x29132008,   // ru.sr.mk_664 ha.sv.jw_532  zu.fi.hr_643 sq.et.sl_443
  0x0305020c, 0x531f0bee, 0x0c0e0407, 0x0f311b55,   // da.fr.nl_543 es.cy.ht_422  fi.is.sv_432 tr.az.lv_442
  0x29531105, 0x4a6b1a04, 0x683b13a4, 0x172905ee,   // ro.ht.sl_333 tl.ceb.yo_332  et.so.ig_433 fr.sl.sr_422
  0x1e005221, 0x111901a0, 0x310827a0, 0x066404ee,   // ha.ms.un_860 en.gl.ro_322  gd.no.az_322 fi.lg.de_422
  // [b040]
  0x121a6b60, 0x3f2003ee, 0x1f1c1e0b, 0x0a351b07,   // ceb.tl.hu_664 nl.sq.af_422  ms.id.cy_542 tr.zu.pt_432
  0x230b64a4, 0x12030209, 0x526435ee, 0x060c6bec,   // lg.es.ca_433 da.nl.hu_444  zu.lg.ha_422 ceb.sv.de_644
  0x1f1b0e0c, 0x6b1e1cee, 0x2718110e, 0x52350e5a,   // is.tr.cy_543 id.ms.ceb_422  ro.ga.gd_555 is.zu.ha_553
  0x3f1a0213, 0x210b1805, 0x29083f04, 0x0b0127a7,   // da.tl.af_665 ga.es.jw_333  af.no.sl_332 gd.en.es_532
  // [b050]
  0x111201a7, 0x053f0309, 0x3f082905, 0x2a00681b,   // en.hu.ro_532 nl.af.fr_444  sl.no.af_333 ig.mt.un_770
  0x04286807, 0x08180cac, 0x0300682b, 0x021827a7,   // ig.sw.fi_432 sv.ga.no_632  ig.nl.un_980 gd.ga.da_532
  0x040c0855, 0x07181907, 0x283b680b, 0x1e1c64af,   // no.sv.fi_442 gl.ga.it_432  ig.so.sw_542 lg.id.ms_655
  0x1a000607, 0x0c04060e, 0x68003f21, 0x0c0504ac,   // de.tl.un_420 de.fi.sv_555  af.ig.un_860 fi.fr.sv_632
  // [b060]
  0x112701ad, 0x190a0e09, 0x6e006404, 0x1c2101a4,   // en.gd.ro_643 is.pt.gl_444  lg.hmn.un_320 en.jw.id_433
  0x4a272855, 0x522d0daf, 0x230e2da0, 0x09201304,   // sw.gd.yo_442 cs.sk.ha_655  sk.is.ca_322 et.sq.pl_332
  0x1e006408, 0x18270a07, 0x273f01a0, 0x0b1827a0,   // lg.ms.un_430 pt.gd.ga_432  en.af.gd_322 gd.ga.es_322
  0x01002714, 0x4a556804, 0x53232508, 0x0a070507,   // gd.en.un_660 ig.rw.yo_332  eu.ca.ht_443 fr.it.pt_432
  // [b070]
  0x0f1725a0, 0x553b64ee, 0x040c0660, 0x0b004a07,   // eu.sr.lv_322 lg.so.rw_422  de.sv.fi_664 yo.es.un_420
  0x211a0113, 0x193b25a4, 0x1f1201a0, 0x3b002919,   // en.tl.jw_665 eu.so.gl_433  en.hu.cy_322 sl.so.un_750
  0x3f041204, 0x68004a35, 0x073b6408, 0x045206a0,   // hu.fi.af_332 yo.ig.un_A90  lg.so.it_443 de.ha.fi_322
  0x043b29ee, 0x21276807, 0x133b5504, 0x1b0c04a4,   // sl.so.fi_422 ig.gd.jw_432  rw.so.et_332 fi.sv.tr_433
  // [b080]
  0x4a005207, 0x0b2d0ead, 0x0b2364ee, 0x03253f02,   // ha.yo.un_420 is.sk.es_643  lg.ca.es_422 af.eu.nl_222
  0x1b0c2905, 0x3b271812, 0x21136807, 0x2b005502,   // sl.sv.tr_333 ga.gd.so_654  ig.et.jw_432 rw.vi.un_220
  0x07112312, 0x02031fec, 0x09000b04, 0x11040711,   // ca.ro.it_654 cy.nl.da_644  es.pl.un_320 bg.ru.ro_653
  0x0a0318a4, 0x020c1805, 0x02093ba7, 0x111220a4,   // ga.nl.pt_433 ga.sv.da_333  so.pl.da_532 sq.hu.ro_433
  // [b090]
  0x16070aad, 0x02005502, 0x27211c04, 0x2d000a19,   // pt.it.hr_643 rw.da.un_220  id.jw.gd_332 pt.sk.un_750
  0x04032a55, 0x29041809, 0x0a212960, 0x17115504,   // mt.nl.fi_442 ga.fi.sl_444  sl.jw.pt_664 rw.ro.sr_332
  0x190b04ee, 0x072b1ca0, 0x646b13ee, 0x03061bee,   // fi.es.gl_422 id.vi.it_322  et.ceb.lg_422 tr.de.nl_422
  0x1b0231a4, 0x1b23020c, 0x0e101208, 0x6e070912,   // az.da.tr_433 da.ca.tr_543  hu.lt.is_443 pl.it.hmn_654
  // [b0a0]
  0x016b040c, 0x100304a4, 0x31000e1a, 0x043f10a7,   // fi.ceb.en_543 fi.nl.lt_433  is.az.un_760 lt.af.fi_532
  0x0e002102, 0x10170a0d, 0x0d103f07, 0x053b31a0,   // jw.is.un_220 mk.sr.be_554  af.lt.cs_432 az.so.fr_322
  0x2d0712a4, 0x07000913, 0x53053faf, 0x25000212,   // hu.it.sk_433 pl.it.un_650  af.fr.ht_655 da.eu.un_640
  0x3b001f13, 0x2d180d0d, 0x192d0d17, 0x0f001219,   // cy.so.un_650 cs.ga.sk_554  cs.sk.gl_753 hu.lv.un_750
  // [b0b0]
  0x290f0da0, 0x2d1b09ac, 0x032d1007, 0x3f071060,   // cs.lv.sl_322 pl.tr.sk_632  lt.sk.nl_432 lt.it.af_664
  0x093f0fee, 0x256b0504, 0x17110805, 0x110b010c,   // lv.af.pl_422 fr.ceb.eu_332  uk.ro.sr_333 en.es.ro_543
  0x04272107, 0x2d1219a9, 0x6b1a2a12, 0x352a53a4,   // jw.gd.fi_432 gl.hu.sk_544  mt.tl.ceb_654 ht.mt.zu_433
  0x1a000d08, 0x2a6b1a13, 0x122d190c, 0x3b6e6b08,   // cs.tl.un_430 tl.ceb.mt_665  gl.sk.hu_543 ceb.hmn.so_443
  // [b0c0]
  0x3f530405, 0x35001a19, 0x55014aee, 0x1f2a3b07,   // fi.ht.af_333 tl.zu.un_750  yo.en.rw_422 so.mt.cy_432
  0x17352908, 0x1b1a010c, 0x0d12050c, 0x133b1aad,   // sl.zu.sr_443 en.tl.tr_543  fr.hu.cs_543 tl.so.et_643
  0x130f1008, 0x096b1a60, 0x123b1a05, 0x192d0aa4,   // lt.lv.et_443 tl.ceb.pl_664  tl.so.hu_333 pt.sk.gl_433
  0x083f03ee, 0x030e3f0c, 0x1b643512, 0x102a3f05,   // nl.af.no_422 af.is.nl_543  zu.lg.tr_654 af.mt.lt_333
  // [b0d0]
  0x641e28a0, 0x55002519, 0x6b1a2a09, 0x13000504,   // sw.ms.lg_322 eu.rw.un_750  mt.tl.ceb_444 fr.et.un_320
  0x17003f1a, 0x120b04a4, 0x6e6b1a04, 0x0e23180d,   // af.sr.un_760 fi.es.hu_433  tl.ceb.hmn_332 ga.ca.is_554
  0x1a6b2a12, 0x322d0802, 0x120a2508, 0x23553b0c,   // mt.ceb.tl_654 no.sk.bs_222  eu.pt.hu_443 so.rw.ca_543
  0x06531307, 0x68001105, 0x17110107, 0x030c08ad,   // et.ht.de_432 ro.ig.un_330  en.ro.sr_432 no.sv.nl_643
  // [b0e0]
  0x08520c07, 0x2a005323, 0x2a001912, 0x1b230504,   // sv.ha.no_432 ht.mt.un_880  gl.mt.un_640 fr.ca.tr_332
  0x01051fac, 0x12050e55, 0x19000519, 0x23100ea4,   // cy.fr.en_632 is.fr.hu_442  fr.gl.un_750 is.lt.ca_433
  0x3f0c0813, 0x0c180e05, 0x1a2b01ee, 0x122d0aac,   // no.sv.af_665 is.ga.sv_333  en.vi.tl_422 pt.sk.hu_632
  0x0e000513, 0x050e0fa4, 0x2d120aa0, 0x0e2d0a04,   // fr.is.un_650 lv.is.fr_433  pt.hu.sk_322 pt.sk.is_332
  // [b0f0]
  0x092d3fee, 0x4a182712, 0x06000e12, 0x033b0d07,   // af.sk.pl_422 gd.ga.yo_654  is.de.un_640 cs.so.nl_432
  0x21351808, 0x07111805, 0x041828a6, 0x111f64a0,   // ga.zu.jw_443 ga.ro.it_333  sw.ga.fi_521 lg.cy.ro_322
  0x0a002802, 0x06311b02, 0x2104130c, 0x0b3b07a0,   // sw.pt.un_220 tr.az.de_222  et.fi.jw_543 it.so.es_322
  0x190e0aad, 0x013f070c, 0x55001309, 0x060e1307,   // pt.is.gl_643 it.af.en_543  et.rw.un_440 et.is.de_432
  // [b100]
  0x52203b0c, 0x23110aa9, 0x0a5311af, 0x01350204,   // so.sq.ha_543 pt.ro.ca_544  ro.ht.pt_655 da.zu.en_332
  0x06001f2a, 0x105535a7, 0x2b1e3f02, 0x23032008,   // cy.de.un_970 zu.rw.lt_532  af.ms.vi_222 sq.nl.ca_443
  0x230a0e07, 0x350711a4, 0x6455110c, 0x175321a0,   // is.pt.ca_432 ro.it.zu_433  ro.rw.lg_543 jw.ht.sr_322
  0x04002121, 0x10352a13, 0x09052a0c, 0x3f0c02a0,   // jw.fi.un_860 mt.zu.lt_665  mt.fr.pl_543 da.sv.af_322
  // [b110]
  0x680735af, 0x03001707, 0x10080212, 0x3f03350e,   // zu.it.ig_655 sr.nl.un_420  da.no.lt_654 zu.nl.af_555
  0x2353250c, 0x0a1b1904, 0x1e251aa4, 0x3b00111b,   // eu.ht.ca_543 gl.tr.pt_332  tl.eu.ms_433 ro.so.un_770
  0x0a002123, 0x23001923, 0x5264530c, 0x3f031ea0,   // jw.pt.un_880 gl.ca.un_880  ht.lg.ha_543 ms.nl.af_322
  0x1b2d35af, 0x3b520f12, 0x311b3511, 0x4a000b02,   // zu.sk.tr_655 lv.ha.so_654  zu.tr.az_653 es.yo.un_220
  // [b120]
  0x20522a0b, 0x52211c12, 0x05230ead, 0x1f6b110c,   // mt.ha.sq_542 id.jw.ha_654  is.ca.fr_643 ro.ceb.cy_543
  0x530f215a, 0x10311bec, 0x1f682a04, 0x2d0e12a9,   // jw.lv.ht_553 tr.az.lt_644  mt.ig.cy_332 hu.is.sk_544
  0x0e550ba0, 0x10170fa4, 0x0f100cad, 0x0b121902,   // es.rw.is_322 lv.sr.lt_433  sv.lt.lv_643 gl.hu.es_222
  0x6b002813, 0x10290f07, 0x052519a6, 0x253b1108,   // sw.ceb.un_650 lv.sl.lt_432  gl.eu.fr_521 ro.so.eu_443
  // [b130]
  0x0b122d04, 0x094a6860, 0x0e002d05, 0x4a355304,   // sk.hu.es_332 ig.yo.pl_664  sk.is.un_330 ht.zu.yo_332
  0x351f680c, 0x2d020d0c, 0x190b050c, 0x181225a7,   // ig.cy.zu_543 cs.da.sk_543  fr.es.gl_543 eu.hu.ga_532
  0x081f0cec, 0x532031a7, 0x0605190c, 0x183f3b02,   // sv.cy.no_644 az.sq.ht_532  gl.fr.de_543 so.af.ga_222
  0x6b3b19ad, 0x2d000508, 0x124a0509, 0x3b060b05,   // gl.so.ceb_643 fr.sk.un_430  fr.yo.hu_444 es.de.so_333
  // [b140]
  0x04354a0b, 0x0f290804, 0x0e001302, 0x0a2d05a9,   // yo.zu.fi_542 no.sl.lv_332  et.is.un_220 fr.sk.pt_544
  0x0e132707, 0x21000404, 0x551304ee, 0x3b13640e,   // gd.et.is_432 fi.jw.un_320  fi.et.rw_422 lg.et.so_555
  0x101304af, 0x0a1a28a4, 0x110b23ad, 0x1f1828a0,   // fi.et.lt_655 sw.tl.pt_433  ca.es.ro_643 sw.ga.cy_322
  0x07001a2b, 0x1a0e64af, 0x354a55ee, 0x182a27ee,   // tl.it.un_980 lg.is.tl_655  rw.yo.zu_422 gd.mt.ga_422
  // [b150]
  0x120e2aa0, 0x0d1c1fa0, 0x182728a6, 0x07000e0c,   // mt.is.hu_322 cy.id.cs_322  sw.gd.ga_521 is.it.un_530
  0x03292504, 0x0f1e2707, 0x0f4a64a7, 0x01063ba7,   // eu.sl.nl_332 gd.ms.lv_432  lg.yo.lv_532 so.de.en_532
  0x0b4a280c, 0x0c20210c, 0x64551c11, 0x2855215a,   // sw.yo.es_543 jw.sq.sv_543  id.rw.lg_653 jw.rw.sw_553
  0x313b1b0c, 0x2d350da4, 0x080a07a7, 0x6455255a,   // tr.so.az_543 cs.zu.sk_433  bg.mk.uk_532 eu.rw.lg_553
  // [b160]
  0x27002013, 0x131223a7, 0x036b68a0, 0x552d2855,   // sq.gd.un_650 ca.hu.et_532  ig.ceb.nl_322 sw.sk.rw_442
  0x04132912, 0x0300350e, 0x681a64a4, 0x2d004a11,   // sl.et.fi_654 zu.nl.un_550  lg.tl.ig_433 yo.sk.un_630
  0x100b0fa7, 0x101a1305, 0x0a2728a0, 0x321a0307,   // lv.es.lt_532 et.tl.lt_333  sw.gd.pt_322 nl.tl.bs_432
  0x2d1f0ca4, 0x12101313, 0x0c1c1ea0, 0x1b553bec,   // sv.cy.sk_433 et.lt.hu_665  ms.id.sv_322 so.rw.tr_644
  // [b170]
  0x4a6b350c, 0x253507ee, 0x28181ba4, 0x120a2105,   // zu.ceb.yo_543 it.zu.eu_422  tr.ga.sw_433 jw.pt.hu_333
  0x18005212, 0x0208135a, 0x120e04ee, 0x35311fa7,   // ha.ga.un_640 et.no.da_553  fi.is.hu_422 cy.az.zu_532
  0x0d120c05, 0x200709ad, 0x12251fad, 0x213b1807,   // sv.hu.cs_333 pl.it.sq_643  cy.eu.hu_643 ga.so.jw_432
  0x25002d0e, 0x190e2d5a, 0x062d1104, 0x3f0106ac,   // sk.eu.un_550 sk.is.gl_553  ro.sk.de_332 de.en.af_632
  // [b180]
  0x53250f08, 0x0e002708, 0x3f0203a0, 0x0f046408,   // lv.eu.ht_443 gd.is.un_430  nl.da.af_322 lg.fi.lv_443
  0x270c190b, 0x21080255, 0x4a2d0eee, 0x13183b0c,   // gl.sv.gd_542 da.no.jw_442  is.sk.yo_422 so.ga.et_543
  0x0c072aad, 0x3f0e0aa0, 0x3b1f6b0b, 0x16000808,   // mt.it.sv_643 pt.is.af_322  ceb.cy.so_542 no.hr.un_430
  0x64000702, 0x182120a9, 0x0c032aee, 0x183b27ec,   // it.lg.un_220 sq.jw.ga_544  mt.nl.sv_422 gd.so.ga_644
  // [b190]
  0x0f043b07, 0x0653030c, 0x10030902, 0x031a6bee,   // so.fi.lv_432 nl.ht.de_543  pl.nl.lt_222 ceb.tl.nl_422
  0x1f0d31ee, 0x2d0d1f14, 0x311b0c0c, 0x0e2a08ee,   // az.cs.cy_422 cy.cs.sk_666  sv.tr.az_543 no.mt.is_422
  0x3b270e02, 0x16552508, 0x0d3b27ee, 0x0a0c0ea7,   // is.gd.so_222 eu.rw.hr_443  gd.so.cs_422 is.sv.pt_532
  0x13314a04, 0x68000908, 0x205521a9, 0x0e082004,   // yo.az.et_332 pl.ig.un_430  jw.rw.sq_544 sq.no.is_332
  // [b1a0]
  0x68195508, 0x032001a0, 0x2d1128ad, 0x04082a0c,   // rw.gl.ig_443 en.sq.nl_322  sw.ro.sk_643 mt.no.fi_543
  0x3f080ca6, 0x23532505, 0x681c3507, 0x20091107,   // sv.no.af_521 eu.ht.ca_333  zu.id.ig_432 ro.pl.sq_432
  0x120410ee, 0x03250f60, 0x1b4a68af, 0x071f27ec,   // lt.fi.hu_422 lv.eu.nl_664  ig.yo.tr_655 gd.cy.it_644
  0x281a1204, 0x211a64ad, 0x0e000f11, 0x105528a9,   // hu.tl.sw_332 lg.tl.jw_643  lv.is.un_630 sw.rw.lt_544
  // [b1b0]
  0x0f4a53a4, 0x325525a7, 0x09006b0d, 0x2700080c,   // ht.yo.lv_433 eu.rw.bs_532  ceb.pl.un_540 no.gd.un_530
  0x250f0baf, 0x0b002102, 0x180127a0, 0x3f100b0c,   // es.lv.eu_655 jw.es.un_220  gd.en.ga_322 es.lt.af_543
  0x52200a13, 0x132718ec, 0x18120307, 0x030602a0,   // pt.sq.ha_665 ga.gd.et_644  nl.hu.ga_432 da.de.nl_322
  0x071a10a4, 0x1f3b090d, 0x080f2d07, 0x0f3117a0,   // lt.tl.it_433 pl.so.cy_554  sk.lv.no_432 sr.az.lv_322
  // [b1c0]
  0x03123f02, 0x6b1a1f0c, 0x211a090b, 0x072a64a4,   // af.hu.nl_222 cy.tl.ceb_543  pl.tl.jw_542 lg.mt.it_433
  0x3f1a2807, 0x1a09210c, 0x0f000419, 0x28001a19,   // sw.tl.af_432 jw.pl.tl_543  fi.lv.un_750 tl.sw.un_750
  0x04000509, 0x120407a4, 0x01212d07, 0x093b2108,   // fr.fi.un_440 it.fi.hu_433  sk.jw.en_432 jw.so.pl_443
  0x046e1304, 0x0d003205, 0x4a6b1aad, 0x2100092a,   // et.hmn.fi_332 bs.cs.un_330  tl.ceb.yo_643 pl.jw.un_970
  // [b1d0]
  0x213b1a04, 0x090f10a0, 0x0a286855, 0x6e683b04,   // tl.so.jw_332 lt.lv.pl_322  ig.sw.pt_442 so.ig.hmn_332
  0x10552108, 0x6e1e1ca4, 0x4a3b6ea4, 0x4a0b0a05,   // jw.rw.lt_443 id.ms.hmn_433  hmn.so.yo_433 pt.es.yo_333
  0x212a1c04, 0x20000a07, 0x0a2921a4, 0x1055130c,   // id.mt.jw_332 pt.sq.un_420  jw.sl.pt_433 et.rw.lt_543
  0x03200807, 0x2a001807, 0x1b006e08, 0x030e0208,   // no.sq.nl_432 ga.mt.un_420  hmn.tr.un_430 da.is.nl_443
  // [b1e0]
  0x4a3f1b04, 0x0b0a01a4, 0x0503190c, 0x6e000613,   // tr.af.yo_332 en.pt.es_433  gl.nl.fr_543 de.hmn.un_650
  0x2a1c28a7, 0x27001f23, 0x1f006b23, 0x03285504,   // sw.id.mt_532 cy.gd.un_880  ceb.cy.un_880 rw.sw.nl_332
  0x2b13010c, 0x1e6404a0, 0x0b0c1307, 0x1e312aa4,   // en.et.vi_543 fi.lg.ms_322  et.sv.es_432 mt.az.ms_433
  0x0a2d2504, 0x35182813, 0x1f000921, 0x53281b07,   // eu.sk.pt_332 sw.ga.zu_665  pl.cy.un_860 tr.sw.ht_432
  // [b1f0]
  0x0a1f2d11, 0x1b042aa0, 0x0d2d10ac, 0x04252309,   // sk.cy.pt_653 mt.fi.tr_322  lt.sk.cs_632 ca.eu.fi_444
  0x051106a9, 0x05131b04, 0x04001f04, 0x03271805,   // de.ro.fr_544 tr.et.fr_332  cy.fi.un_320 ga.gd.nl_333
  0x180327a4, 0x0e00021b, 0x09276b08, 0x071908a0,   // gd.nl.ga_433 da.is.un_770  ceb.gd.pl_443 no.gl.it_322
  0x1a1801ee, 0x64271804, 0x1b00100e, 0x03001311,   // en.ga.tl_422 ga.gd.lg_332  lt.tr.un_550 et.nl.un_630
  // [b200]
  0x07000519, 0x681f01ee, 0x6b531a14, 0x0a2327a4,   // fr.it.un_750 en.cy.ig_422  tl.ht.ceb_666 gd.ca.pt_433
  0x53001f1b, 0x4a001909, 0x061e0804, 0x1f6409a7,   // cy.ht.un_770 gl.yo.un_440  no.ms.de_332 pl.lg.cy_532
  0x2d2a07a4, 0x092d1108, 0x3f2a0714, 0x01532702,   // it.mt.sk_433 ro.sk.pl_443  it.mt.af_666 gd.ht.en_222
  0x10321608, 0x2500101a, 0x18190b13, 0x06080302,   // hr.bs.lt_443 lt.eu.un_760  es.gl.ga_665 nl.no.de_222
  // [b210]
  0x1b31205a, 0x2d280b04, 0x5321290c, 0x532311a7,   // sq.az.tr_553 es.sw.sk_332  sl.jw.ht_543 ro.ca.ht_532
  0x20002904, 0x321602ee, 0x1f001b09, 0x181f01a7,   // sl.sq.un_320 da.hr.bs_422  tr.cy.un_440 en.cy.ga_532
  0x133b0308, 0x1f53230c, 0x5300081a, 0x2a0523a9,   // nl.so.et_443 ca.ht.cy_543  no.ht.un_760 ca.fr.mt_544
  0x3f280a12, 0x53006813, 0x6b3f130c, 0x282153ec,   // pt.sw.af_654 ig.ht.un_650  et.af.ceb_543 ht.jw.sw_644
  // [b220]
  0x532103a4, 0x2b0364a0, 0x0b0a23ee, 0x08091307,   // nl.jw.ht_433 lg.nl.vi_322  ca.pt.es_422 et.pl.no_432
  0x1b354a55, 0x29000d17, 0x100e13a7, 0x10130e5a,   // yo.zu.tr_442 cs.sl.un_730  et.is.lt_532 is.et.lt_553
  0x52190b05, 0x1e081007, 0x201209ec, 0x1b3132a0,   // es.gl.ha_333 lt.no.ms_432  pl.hu.sq_644 bs.az.tr_322
  0x282153a0, 0x2b3f6ba0, 0x0f68640e, 0x642b35af,   // ht.jw.sw_322 ceb.af.vi_322  lg.ig.lv_555 zu.vi.lg_655
  // [b230]
  0x641052a4, 0x641b3102, 0x281335a9, 0x28553b55,   // ha.lt.lg_433 az.tr.lg_222  zu.et.sw_544 so.rw.sw_442
  0x05286807, 0x03645307, 0x1e0a05a9, 0x1c2164ad,   // ig.sw.fr_432 ht.lg.nl_432  fr.pt.ms_544 lg.jw.id_643
  0x3f030912, 0x0b135204, 0x6427180c, 0x53251c07,   // pl.nl.af_654 ha.et.es_332  ga.gd.lg_543 id.eu.ht_432
  0x10203b07, 0x1b312109, 0x270f5507, 0x251c53ec,   // so.sq.lt_432 jw.az.tr_444  rw.lv.gd_432 ht.id.eu_644
  // [b240]
  0x1e1c0faf, 0x52001e0d, 0x0a231908, 0x130f2d07,   // lv.id.ms_655 ms.ha.un_540  gl.ca.pt_443 sk.lv.et_432
  0x033b3f12, 0x32132a5a, 0x35130408, 0x116435a4,   // af.so.nl_654 mt.et.bs_553  fi.et.zu_443 zu.lg.ro_433
  0x3b133fa0, 0x2a055507, 0x13063f55, 0x68003508,   // af.et.so_322 rw.fr.mt_432  af.de.et_442 zu.ig.un_430
  0x3b1b1004, 0x0400120c, 0x130410ec, 0x3b0e1004,   // lt.tr.so_332 hu.fi.un_530  lt.fi.et_644 lt.is.so_332
  // [b250]
  0x192003a0, 0x09020807, 0x680c3508, 0x1b640f11,   // nl.sq.gl_322 no.da.pl_432  zu.sv.ig_443 lv.lg.tr_653
  0x0f1b28a4, 0x0d000304, 0x101b0fa4, 0x1a212308,   // sw.tr.lv_433 nl.cs.un_320  lv.tr.lt_433 ca.jw.tl_443
  0x640f280c, 0x64280f13, 0x214a25a4, 0x092d0f04,   // sw.lv.lg_543 lv.sw.lg_665  eu.yo.jw_433 lv.sk.pl_332
  0x1b0e10a7, 0x310f55af, 0x0313120c, 0x0f2a2011,   // lt.is.tr_532 rw.lv.az_655  hu.et.nl_543 sq.mt.lv_653
  // [b260]
  0x13350612, 0x6408130c, 0x08050e07, 0x55640faf,   // de.zu.et_654 et.no.lg_543  is.fr.no_432 lv.lg.rw_655
  0x194a64a0, 0x282d0f08, 0x2a001114, 0x05230a0d,   // lg.yo.gl_322 lv.sk.sw_443  ro.mt.un_660 pt.ca.fr_554
  0x291b17a9, 0x03061312, 0x35136407, 0x321c1ea0,   // sr.tr.sl_544 et.de.nl_654  lg.et.zu_432 ms.id.bs_322
  0x64280fa0, 0x0b1323a7, 0x31001e13, 0x0111050c,   // lv.sw.lg_322 ca.et.es_532  ms.az.un_650 fr.ro.en_543
  // [b270]
  0x3500282b, 0x0d006e0c, 0x555325af, 0x3f205304,   // sw.zu.un_980 hmn.cs.un_530  eu.ht.rw_655 ht.sq.af_332
  0x012553a0, 0x1f000a1a, 0x270a4a13, 0x211b55a6,   // ht.eu.en_322 pt.cy.un_760  yo.pt.gd_665 rw.tr.jw_521
  0x171364a4, 0x07645507, 0x5531250c, 0x3b2d5512,   // lg.et.sr_433 rw.lg.it_432  eu.az.rw_543 rw.sk.so_654
  0x0f1113ad, 0x35136404, 0x160513a0, 0x2d0953a0,   // et.ro.lv_643 lg.et.zu_332  et.fr.hr_322 ht.pl.sk_322
  // [b280]
  0x1c0d13ee, 0x553135a4, 0x31203502, 0x171b1304,   // bh.ne.mr_422 zu.az.rw_433  zu.sq.az_222 et.tr.sr_332
  0x682752a4, 0x52534a07, 0x0523070c, 0x200a230c,   // ha.gd.ig_433 yo.ht.ha_432  it.ca.fr_543 ca.pt.sq_543
  0x21000723, 0x1029680d, 0x35003b2b, 0x190721a0,   // it.jw.un_880 ig.sl.lt_554  so.zu.un_980 jw.it.gl_322
  0x29522105, 0x35002014, 0x06231204, 0x29065202,   // jw.ha.sl_333 sq.zu.un_660  hu.ca.de_332 ha.de.sl_222
  // [b290]
  0x0a122d0d, 0x044a21ee, 0x31251311, 0x09132507,   // sk.hu.pt_554 jw.yo.fi_422  et.eu.az_653 eu.et.pl_432
  0x08002b04, 0x525304a7, 0x13120408, 0x122304a0,   // vi.no.un_320 fi.ht.ha_532  fi.hu.et_443 fi.ca.hu_322
  0x2d002304, 0x291b0f55, 0x0b0929ee, 0x11002b0c,   // ca.sk.un_320 lv.tr.sl_442  sl.pl.es_422 vi.ro.un_530
  0x014a1307, 0x063552a0, 0x52133507, 0x01281307,   // et.yo.en_432 ha.zu.de_322  zu.et.ha_432 et.sw.en_432
  // [b2a0]
  0x13080107, 0x043f1a08, 0x0b0a11ac, 0x0c1c53ad,   // en.no.et_432 tl.af.fi_443  ro.pt.es_632 ht.id.sv_643
  0x1a206ea0, 0x0c0210a4, 0x68130204, 0x13000207,   // hmn.sq.tl_322 lt.da.sv_433  da.et.ig_332 da.et.un_420
  0x0804130c, 0x0c270607, 0x27061ead, 0x10002307,   // et.fi.no_543 de.gd.sv_432  ms.de.gd_643 ca.lt.un_420
  0x28354a04, 0x0c100f0c, 0x0c1b0407, 0x2a00550b,   // yo.zu.sw_332 lv.lt.sv_543  fi.tr.sv_432 rw.mt.un_520
  // [b2b0]
  0x080c5208, 0x0c051304, 0x03020c0d, 0x133504a7,   // ha.sv.no_443 et.fr.sv_332  sv.da.nl_554 fi.zu.et_532
  0x641e1c12, 0x2d0d100b, 0x230b3ba4, 0x0c6b08a0,   // id.ms.lg_654 lt.cs.sk_542  so.es.ca_433 no.ceb.sv_322
  0x0c3f2907, 0x0c520608, 0x6b0c0604, 0x18002d18,   // sl.af.sv_432 de.ha.sv_443  de.sv.ceb_332 sk.ga.un_740
  0x313b1208, 0x251b0ba0, 0x531a520c, 0x071305a4,   // hu.so.az_443 es.tr.eu_322  ha.tl.ht_543 fr.et.it_433
  // [b2c0]
  0x35004a21, 0x3b1e1cee, 0x216b1aa7, 0x5300211a,   // yo.zu.un_860 id.ms.so_422  tl.ceb.jw_532 jw.ht.un_760
  0x0b354aad, 0x6b1a1213, 0x12005219, 0x09161707,   // yo.zu.es_643 hu.tl.ceb_665  ha.hu.un_750 sr.hr.pl_432
  0x2505190c, 0x550b0a02, 0x09102504, 0x161304a4,   // gl.fr.eu_543 pt.es.rw_222  eu.lt.pl_332 fi.et.hr_433
  0x0f0310ec, 0x256b3b09, 0x051101af, 0x3f0c25a4,   // lt.nl.lv_644 so.ceb.eu_444  en.ro.fr_655 eu.sv.af_433
  // [b2d0]
  0x313b21a4, 0x3f005513, 0x6b3153af, 0x3f531e08,   // jw.so.az_433 rw.af.un_650  ht.az.ceb_655 ms.ht.af_443
  0x271f3f0c, 0x3b1e1308, 0x0a033f14, 0x190b04a9,   // af.cy.gd_543 et.ms.so_443  af.nl.pt_666 fi.es.gl_544
  0x05070307, 0x1a321c07, 0x6b201a0b, 0x17322055,   // nl.it.fr_432 id.bs.tl_432  tl.sq.ceb_542 sq.bs.sr_442
  0x5517040c, 0x641b55ee, 0x05072004, 0x280c1060,   // fi.sr.rw_543 rw.tr.lg_422  sq.it.fr_332 lt.sv.sw_664
  // [b2e0]
  0x130464a0, 0x0600230d, 0x3500090c, 0x10006414,   // lg.fi.et_322 ca.de.un_540  pl.zu.un_530 lg.lt.un_660
  0x17531baf, 0x040107a4, 0x3f050402, 0x051a20ee,   // tr.ht.sr_655 it.en.fi_433  fi.fr.af_222 sq.tl.fr_422
  0x0c0855a0, 0x2a100504, 0x641b1307, 0x031c1ea0,   // rw.no.sv_322 fr.lt.mt_332  et.tr.lg_432 ms.id.nl_322
  0x27123b0c, 0x181327a0, 0x18282713, 0x252d29a0,   // so.hu.gd_543 gd.et.ga_322  gd.sw.ga_665 sl.sk.eu_322
  // [b2f0]
  0x060f08a0, 0x08003b04, 0x06100f0d, 0x204a29a7,   // no.lv.de_322 so.no.un_320  lv.lt.de_554 sl.yo.sq_532
  0x311b2012, 0x2b182707, 0x2100100e, 0x100f01a0,   // sq.tr.az_654 gd.ga.vi_432  lt.jw.un_550 en.lv.lt_322
  0x351055ee, 0x0c130fa4, 0x35130412, 0x11133507,   // rw.lt.zu_422 lv.et.sv_433  fi.et.zu_654 zu.et.ro_432
  0x31006812, 0x11040aa4, 0x3b4a5204, 0x20001902,   // ig.az.un_640 mk.ru.ro_433  ha.yo.so_332 gl.sq.un_220
  // [b300]
  0x53523b0c, 0x55523bec, 0x311a52ec, 0x353b1a0c,   // so.ha.ht_543 so.ha.rw_644  ha.tl.az_644 tl.so.zu_543
  0x3b004a02, 0x213b520c, 0x35645212, 0x07001e04,   // yo.so.un_220 ha.so.jw_543  ha.lg.zu_654 ms.it.un_320
  0x1b1a3ba9, 0x3531520c, 0x272118af, 0x356431a7,   // so.tl.tr_544 ha.az.zu_543  ga.jw.gd_655 az.lg.zu_532
  0x0f10270e, 0x351a28af, 0x311b5209, 0x0b0f1008,   // gd.lt.lv_555 sw.tl.zu_655  ha.tr.az_444 lt.lv.es_443
  // [b310]
  0x643b5208, 0x060c020e, 0x112b28a4, 0x21313ba4,   // ha.so.lg_443 da.sv.de_555  sw.vi.ro_433 so.az.jw_433
  0x1a6e1f12, 0x523b31a9, 0x182927ee, 0x31645509,   // cy.hmn.tl_654 az.so.ha_544  gd.sl.ga_422 rw.lg.az_444
  0x311b21ad, 0x21313b0b, 0x2d0d1aa4, 0x52283ba0,   // jw.tr.az_643 so.az.jw_542  tl.cs.sk_433 so.sw.ha_322
  0x1b1a210c, 0x6b5552ec, 0x1a3531ec, 0x64682812,   // jw.tl.tr_543 ha.rw.ceb_644  az.zu.tl_644 sw.ig.lg_654
  // [b320]
  0x0d020c12, 0x0b1f6b11, 0x101b0302, 0x08060207,   // sv.da.cs_654 ceb.cy.es_653  nl.tr.lt_222 da.de.no_432
  0x1f060e02, 0x551f520b, 0x1b000602, 0x0c0b0a07,   // is.de.cy_222 ha.cy.rw_542  de.tr.un_220 pt.es.sv_432
  0x1b2d12ad, 0x0d1710a4, 0x131f6ba4, 0x1a1b080c,   // hu.sk.tr_643 lt.sr.cs_433  ceb.cy.et_433 no.tr.tl_543
  0x120b23a0, 0x0c003118, 0x2b1201a0, 0x0a3204a4,   // ca.es.hu_322 az.sv.un_740  en.hu.vi_322 fi.bs.pt_433
  // [b330]
  0x25006b0d, 0x1a280107, 0x1c002d04, 0x203501a0,   // ceb.eu.un_540 en.sw.tl_432  sk.id.un_320 en.zu.sq_322
  0x1e2125a0, 0x1e532a02, 0x12553504, 0x0a2301a0,   // eu.jw.ms_322 mt.ht.ms_222  zu.rw.hu_332 en.ca.pt_322
  0x1f55520c, 0x11001b02, 0x173f010c, 0x11172911,   // ha.rw.cy_543 tr.ro.un_220  en.af.sr_543 sl.sr.ro_653
  0x103b5507, 0x0100120d, 0x0f3b3511, 0x130f6b0c,   // rw.so.lt_432 hu.en.un_540  zu.so.lv_653 ceb.lv.et_543
  // [b340]
  0x080612a4, 0x101113a0, 0x1101070c, 0x283b3504,   // hu.de.no_433 et.ro.lt_322  it.en.ro_543 zu.so.sw_332
  0x53523b07, 0x3553050c, 0x120c1304, 0x2d005502,   // so.ha.ht_432 fr.ht.zu_543  et.sv.hu_332 rw.sk.un_220
  0x55216402, 0x10072512, 0x0c082aad, 0x52355513,   // lg.jw.rw_222 eu.it.lt_654  mt.no.sv_643 rw.zu.ha_665
  0x0c2a06a4, 0x040e0ca0, 0x520a3b07, 0x29355212,   // de.mt.sv_433 sv.is.fi_322  so.pt.ha_432 ha.zu.sl_654
  // [b350]
  0x1c036b02, 0x0c086b07, 0x3f6b1a12, 0x4a295207,   // ceb.nl.id_222 ceb.no.sv_432  tl.ceb.af_654 ha.sl.yo_432
  0x10251111, 0x0a0810af, 0x1028070b, 0x080e3b07,   // ro.eu.lt_653 be.uk.mk_655  it.sw.lt_542 so.is.no_432
  0x25130108, 0x07020c08, 0x21110807, 0x11006818,   // en.et.eu_443 sv.da.it_443  no.ro.jw_432 ig.ro.un_740
  0x0e041bad, 0x08040212, 0x55000704, 0x6b2d550c,   // tr.fi.is_643 da.fi.no_654  it.rw.un_320 rw.sk.ceb_543
  // [b360]
  0x536b2807, 0x111923ee, 0x016e02ee, 0x290a0f04,   // sw.ceb.ht_432 ca.gl.ro_422  da.hmn.en_422 lv.pt.sl_332
  0x010413a7, 0x05001b04, 0x271013a0, 0x1208350c,   // et.fi.en_532 tr.fr.un_320  et.lt.gd_322 zu.no.hu_543
  0x0a081f07, 0x552d0d0d, 0x2a686b07, 0x102528a4,   // cy.no.pt_432 cs.sk.rw_554  ceb.ig.mt_432 sw.eu.lt_433
  0x53100fa0, 0x042d5504, 0x1c131a55, 0x32006e07,   // lv.lt.ht_322 rw.sk.fi_332  tl.et.id_442 hmn.bs.un_420
  // [b370]
  0x1a6b55a9, 0x3b353112, 0x20071aa0, 0x5500680e,   // rw.ceb.tl_544 az.zu.so_654  tl.it.sq_322 ig.rw.un_550
  0x25531f05, 0x052868ee, 0x0f181ea9, 0x356820a4,   // cy.ht.eu_333 ig.sw.fr_422  ms.ga.lv_544 sq.ig.zu_433
  0x130553ad, 0x1a0155a0, 0x10282507, 0x0b0a25a4,   // ht.fr.et_643 rw.en.tl_322  eu.sw.lt_432 eu.pt.es_433
  0x1a070404, 0x0b041007, 0x28102508, 0x01646b02,   // fi.it.tl_332 lt.fi.es_432  eu.lt.sw_443 ceb.lg.en_222
  // [b380]
  0x350c6ea7, 0x0c13230c, 0x16120dee, 0x3527180b,   // hmn.sv.zu_532 ca.et.sv_543  cs.hu.hr_422 ga.gd.zu_542
  0x1e0c1c0c, 0x052a0408, 0x322a160c, 0x3f0704a4,   // id.sv.ms_543 fi.mt.fr_443  hr.mt.bs_543 fi.it.af_433
  0x0d32160d, 0x04070505, 0x4a000d0c, 0x04003112,   // hr.bs.cs_554 fr.it.fi_333  cs.yo.un_530 az.fi.un_640
  0x080b060c, 0x232a2807, 0x535564a0, 0x072a0a0c,   // de.es.no_543 sw.mt.ca_432  lg.rw.ht_322 pt.mt.it_543
  // [b390]
  0x3f250b0d, 0x061364a0, 0x02285507, 0x1008250c,   // es.eu.af_554 lg.et.de_322  rw.sw.da_432 eu.no.lt_543
  0x295535ec, 0x0a1c2107, 0x2b000d02, 0x525535af,   // zu.rw.sl_644 jw.id.pt_432  cs.vi.un_220 zu.rw.ha_655
  0x03062a08, 0x1017290c, 0x050704a4, 0x0305040c,   // mt.de.nl_443 sl.sr.lt_543  fi.it.fr_433 fi.fr.nl_543
  0x230504ee, 0x52006e2a, 0x081220a6, 0x043b1e08,   // fi.fr.ca_422 hmn.ha.un_970  sq.hu.no_521 ms.so.fi_443
  // [b3a0]
  0x13033f02, 0x1c1e3b04, 0x0f000502, 0x011f09a7,   // af.nl.et_222 so.ms.id_332  fr.lv.un_220 pl.cy.en_532
  0x05006405, 0x6b000709, 0x280e35a4, 0x1a3f0907,   // lg.fr.un_330 it.ceb.un_440  zu.is.sw_433 pl.af.tl_432
  0x0f101704, 0x043f0fa0, 0x3b0403a0, 0x08036402,   // sr.lt.lv_332 lv.af.fi_322  nl.fi.so_322 lg.nl.no_222
  0x01130a05, 0x25102805, 0x29003f04, 0x35001a12,   // pt.et.en_333 sw.lt.eu_333  af.sl.un_320 tl.zu.un_640
  // [b3b0]
  0x2a200f09, 0x03000813, 0x0d001102, 0x13013b08,   // lv.sq.mt_444 no.nl.un_650  ro.cs.un_220 so.en.et_443
  0x033f3512, 0x1e1c0dee, 0x1a0f10a4, 0x190a0faf,   // zu.af.nl_654 cs.id.ms_422  lt.lv.tl_433 lv.pt.gl_655
  0x130f0ba4, 0x6b68350c, 0x0f210bee, 0x112520a4,   // es.lv.et_433 zu.ig.ceb_543  es.jw.lv_422 sq.eu.ro_433
  0x2d0d0407, 0x01000513, 0x523b21ec, 0x2d3b0d07,   // fi.cs.sk_432 fr.en.un_650  jw.so.ha_644 cs.so.sk_432
  // [b3c0]
  0x1000280c, 0x1e1c3b02, 0x2d0d080c, 0x2d4a120c,   // sw.lt.un_530 so.id.ms_222  no.cs.sk_543 hu.yo.sk_543
  0x10113ba4, 0x550f6e07, 0x1f103b08, 0x195305a0,   // so.ro.lt_433 hmn.lv.rw_432  so.lt.cy_443 fr.ht.gl_322
  0x0e006b12, 0x356864a4, 0x07193b05, 0x0f103ba0,   // ceb.is.un_640 lg.ig.zu_433  so.gl.it_333 so.lt.lv_322
  0x0b076b07, 0x4a3b52ec, 0x1e000808, 0x10135208,   // ceb.it.es_432 ha.so.yo_644  no.ms.un_430 ha.et.lt_443
  // [b3d0]
  0x071a4aa0, 0x1f645212, 0x1f00521a, 0x35010407,   // yo.tl.it_322 ha.lg.cy_654  ha.cy.un_760 fi.en.zu_432
  0x53000b04, 0x080d02ee, 0x27113f02, 0x06040ea0,   // es.ht.un_320 da.cs.no_422  af.ro.gd_222 is.fi.de_322
  0x1b0f1304, 0x1f000d18, 0x31081b07, 0x02201ba0,   // et.lv.tr_332 cs.cy.un_740  tr.no.az_432 tr.sq.da_322
  0x04000504, 0x081710ec, 0x3f031055, 0x2d0d1302,   // fr.fi.un_320 be.sr.uk_644  lt.nl.af_442 et.cs.sk_222
  // [b3e0]
  0x0d2d100b, 0x10000312, 0x09000405, 0x55211009,   // lt.sk.cs_542 nl.lt.un_640  fi.pl.un_330 lt.jw.rw_444
  0x122a3505, 0x28551a0b, 0x2d0d0f0c, 0x55046bad,   // zu.mt.hu_333 tl.rw.sw_542  lv.cs.sk_543 ceb.fi.rw_643
  0x52200fa4, 0x12210408, 0x12211008, 0x10030ead,   // lv.sq.ha_433 fi.jw.hu_443  lt.jw.hu_443 is.nl.lt_643
  0x0e2910ee, 0x29040ea4, 0x252112ee, 0x1c130d07,   // lt.sl.is_422 is.fi.sl_433  hu.jw.eu_422 ne.bh.mr_432
  // [b3f0]
  0x521c21a0, 0x033f1812, 0x133f0807, 0x25122807,   // jw.id.ha_322 ga.af.nl_654  no.af.et_432 sw.hu.eu_432
  0x6b122804, 0x03020d0c, 0x3f0802ad, 0x1106070c,   // sw.hu.ceb_332 cs.da.nl_543  da.no.af_643 it.de.ro_543
  0x0412280c, 0x3f110304, 0x162528a6, 0x122821a4,   // sw.hu.fi_543 nl.ro.af_332  sw.eu.hr_521 jw.sw.hu_433
  0x4a0e6805, 0x4a20280c, 0x1c201e12, 0x27040512,   // ig.is.yo_333 sw.sq.yo_543  ms.sq.id_654 fr.fi.gd_654

  // [b400]
  0x11010707, 0x08090d07, 0x05010408, 0x121f1ba0,   // it.en.ro_432 cs.pl.no_432  fi.en.fr_443 tr.cy.hu_322
  0x18090555, 0x18270aaf, 0x3f321708, 0x271119a0,   // fr.pl.ga_442 pt.gd.ga_655  sr.bs.af_443 gl.ro.gd_322
  0x286b1aa4, 0x0b0a19a6, 0x552868af, 0x180b05a0,   // tl.ceb.sw_433 gl.pt.es_521  ig.sw.rw_655 fr.es.ga_322
  0x10090ead, 0x041801a0, 0x0500041a, 0x28171605,   // is.pl.lt_643 en.ga.fi_322  fi.fr.un_760 hr.sr.sw_333
  // [b410]
  0x25285512, 0x28190a08, 0x16072aa7, 0x02251309,   // rw.sw.eu_654 pt.gl.sw_443  mt.it.hr_532 et.eu.da_444
  0x2a000a02, 0x08230f08, 0x1610020c, 0x190a52ee,   // pt.mt.un_220 lv.ca.no_443  da.lt.hr_543 ha.pt.gl_422
  0x20273fa0, 0x11552804, 0x286b5304, 0x2d0d2505,   // af.gd.sq_322 sw.rw.ro_332  ht.ceb.sw_332 eu.cs.sk_333
  0x1a0b6b13, 0x29001723, 0x1c13090b, 0x1712200c,   // ceb.es.tl_665 sr.sl.un_880  hi.bh.mr_542 sq.hu.sr_543
  // [b420]
  0x535204ad, 0x31033f0c, 0x3b021ba0, 0x12000307,   // fi.ha.ht_643 af.nl.az_543  tr.da.so_322 nl.hu.un_420
  0x1900180b, 0x2d1e2304, 0x18000a02, 0x2b322dad,   // ga.gl.un_520 ca.ms.sk_332  pt.ga.un_220 sk.bs.vi_643
  0x05351102, 0x131b0655, 0x2a1208a0, 0x080c2104,   // ro.zu.fr_222 de.tr.et_442  no.hu.mt_322 jw.sv.no_332
  0x4a1a5505, 0x03081207, 0x322135ee, 0x682855ad,   // rw.tl.yo_333 hu.no.nl_432  zu.jw.bs_422 rw.sw.ig_643
  // [b430]
  0x0b2318a4, 0x68645508, 0x1e1b1aaf, 0x2d1c0804,   // ga.ca.es_433 rw.lg.ig_443  tl.tr.ms_655 no.id.sk_332
  0x0b002007, 0x3220170c, 0x25060aa4, 0x2a004a0d,   // sq.es.un_420 sr.sq.bs_543  pt.de.eu_433 yo.mt.un_540
  0x32172905, 0x0728350d, 0x21230aa0, 0x070b23a4,   // sl.sr.bs_333 zu.sw.it_554  pt.ca.jw_322 ca.es.it_433
  0x0f090304, 0x2000120c, 0x09681107, 0x100d2812,   // nl.pl.lv_332 hu.sq.un_530  ro.ig.pl_432 sw.cs.lt_654
  // [b440]
  0x276b06ee, 0x281101ee, 0x27001314, 0x12111304,   // de.ceb.gd_422 en.ro.sw_422  et.gd.un_660 et.ro.hu_332
  0x12040a0c, 0x01523f04, 0x0c1308a7, 0x121306a7,   // pt.fi.hu_543 af.ha.en_332  no.et.sv_532 de.et.hu_532
  0x03232507, 0x6b100f07, 0x3b1013a0, 0x3f180107,   // eu.ca.nl_432 lv.lt.ceb_432  et.lt.so_322 en.ga.af_432
  0x28214aa0, 0x210e1ca4, 0x0f103fac, 0x122d0dee,   // yo.jw.sw_322 id.is.jw_433  af.lt.lv_632 cs.sk.hu_422
  // [b450]
  0x08270cad, 0x172d53a4, 0x1c006e04, 0x3b000a14,   // sv.gd.no_643 ht.sk.sr_433  hmn.id.un_320 pt.so.un_660
  0x13003b02, 0x0f0e0611, 0x21101c12, 0x313b1807,   // so.et.un_220 de.is.lv_653  id.lt.jw_654 ga.so.az_432
  0x0b200fa7, 0x0f000604, 0x20283b0b, 0x0a1a6eee,   // lv.sq.es_532 de.lv.un_320  so.sw.sq_542 hmn.tl.pt_422
  0x132a07ee, 0x28205208, 0x03273f12, 0x1f0c08a0,   // it.mt.et_422 ha.sq.sw_443  af.gd.nl_654 no.sv.cy_322
  // [b460]
  0x06123f04, 0x6b182711, 0x030c06ee, 0x0c000602,   // af.hu.de_332 gd.ga.ceb_653  de.sv.nl_422 de.sv.un_220
  0x19110f07, 0x190b2509, 0x013b2755, 0x35321704,   // lv.ro.gl_432 eu.es.gl_444  gd.so.en_442 sr.bs.zu_332
  0x0c1b0307, 0x31061ba7, 0x093516ee, 0x050108a4,   // nl.tr.sv_432 tr.de.az_532  hr.zu.pl_422 no.en.fr_433
  0x1b172d08, 0x0c4a0e04, 0x040a1f05, 0x2932520c,   // sk.sr.tr_443 is.yo.sv_332  cy.pt.fi_333 ha.bs.sl_543
  // [b470]
  0x321f2a07, 0x10030107, 0x3f031f09, 0x0f2d3f13,   // mt.cy.bs_432 en.nl.lt_432  cy.nl.af_444 af.sk.lv_665
  0x04003f13, 0x03002321, 0x1300011a, 0x0a0b1960,   // af.fi.un_650 ca.nl.un_860  en.et.un_760 gl.es.pt_664
  0x0200120c, 0x11530855, 0x1100201b, 0x52351a0c,   // hu.da.un_530 no.ht.ro_442  sq.ro.un_770 tl.zu.ha_543
  0x103f0807, 0x1a2152a0, 0x1c002a0d, 0x3f13060b,   // no.af.lt_432 ha.jw.tl_322  mt.id.un_540 de.et.af_542
  // [b480]
  0x063f1fee, 0x1f040f55, 0x52531aa4, 0x04641a09,   // cy.af.de_422 lv.fi.cy_442  tl.ht.ha_433 tl.lg.fi_444
  0x35092802, 0x28641a08, 0x5318010c, 0x4a0f28ee,   // sw.pl.zu_222 tl.lg.sw_443  en.ga.ht_543 sw.lv.yo_422
  0x271332a0, 0x32203509, 0x1e1c5505, 0x136404a4,   // bs.et.gd_322 zu.sq.bs_444  rw.id.ms_333 fi.lg.et_433
  0x290d12af, 0x1c000c05, 0x0f0c130c, 0x03130508,   // hu.cs.sl_655 sv.id.un_330  et.sv.lv_543 fr.et.nl_443
  // [b490]
  0x1c000c18, 0x6b2864ac, 0x0b1912a9, 0x1632295a,   // sv.id.un_740 lg.sw.ceb_632  hu.gl.es_544 sl.bs.hr_553
  0x180b2707, 0x55641105, 0x1c0f6eee, 0x64133ba6,   // gd.es.ga_432 ro.lg.rw_333  hmn.lv.id_422 so.et.lg_521
  0x07282a13, 0x1f6b10ac, 0x3f030e02, 0x120d2012,   // mt.sw.it_665 lt.ceb.cy_632  is.nl.af_222 sq.cs.hu_654
  0x3f230512, 0x126425af, 0x172d0dee, 0x290353af,   // fr.ca.af_654 eu.lg.hu_655  cs.sk.sr_422 ht.nl.sl_655
  // [b4a0]
  0x282a5202, 0x3b000c05, 0x32126407, 0x52000502,   // ha.mt.sw_222 sv.so.un_330  lg.hu.bs_432 fr.ha.un_220
  0x171c21a6, 0x28354aa0, 0x2d120daf, 0x536428ad,   // jw.id.sr_521 yo.zu.sw_322  cs.hu.sk_655 sw.lg.ht_643
  0x016435ad, 0x68133b12, 0x1f6435a9, 0x032d0513,   // zu.lg.en_643 so.et.ig_654  zu.lg.cy_544 fr.sk.nl_665
  0x122128a4, 0x28536412, 0x35092a05, 0x2111120c,   // sw.jw.hu_433 lg.ht.sw_654  mt.pl.zu_333 hu.ro.jw_543
  // [b4b0]
  0x10033f04, 0x120413a4, 0x0a0723a7, 0x68003f1a,   // af.nl.lt_332 et.fi.hu_433  ca.it.pt_532 af.ig.un_760
  0x533f6b02, 0x1c64550c, 0x31230aa0, 0x23000a2b,   // ceb.af.ht_222 rw.lg.id_543  pt.ca.az_322 pt.ca.un_980
  0x030a0107, 0x172d0d02, 0x2a683513, 0x170d1607,   // en.pt.nl_432 cs.sk.sr_222  zu.ig.mt_665 hr.cs.sr_432
  0x130e0f12, 0x1b0a230c, 0x19110a0c, 0x270a1907,   // lv.is.et_654 ca.pt.tr_543  pt.ro.gl_543 gl.pt.gd_432
  // [b4c0]
  0x290f2d07, 0x4a001814, 0x0b27180c, 0x254a2a08,   // sk.lv.sl_432 ga.yo.un_660  ga.gd.es_543 mt.yo.eu_443
  0x6e1827ad, 0x32002104, 0x190a0b07, 0x200a0702,   // gd.ga.hmn_643 jw.bs.un_320  es.pt.gl_432 it.pt.sq_222
  0x643507a0, 0x2d0a2107, 0x521b1e09, 0x2a120707,   // it.zu.lg_322 jw.pt.sk_432  ms.tr.ha_444 it.hu.mt_432
  0x551a6b05, 0x643b685a, 0x270a13a4, 0x10292d08,   // ceb.tl.rw_333 ig.so.lg_553  et.pt.gd_433 sk.sl.lt_443
  // [b4d0]
  0x071a28a7, 0x27001308, 0x6b531a09, 0x1300251b,   // sw.tl.it_532 et.gd.un_430  tl.ht.ceb_444 eu.et.un_770
  0x6b641a05, 0x05001b12, 0x25066b02, 0x3b6b6414,   // tl.lg.ceb_333 tr.fr.un_640  ceb.de.eu_222 lg.ceb.so_666
  0x3b005522, 0x083f0508, 0x3f1f0807, 0x55351ea0,   // rw.so.un_870 fr.af.no_443  no.cy.af_432 ms.zu.rw_322
  0x030f08a0, 0x6b1a55af, 0x17112004, 0x4a1210ad,   // no.lv.nl_322 rw.tl.ceb_655  sq.ro.sr_332 lt.hu.yo_643
  // [b4e0]
  0x35006e0e, 0x1e1c3502, 0x31001111, 0x55211802,   // hmn.zu.un_550 zu.id.ms_222  ro.az.un_630 ga.jw.rw_222
  0x19120aa6, 0x130b0a55, 0x2d4a2107, 0x25036ba0,   // pt.hu.gl_521 pt.es.et_442  jw.yo.sk_432 ceb.nl.eu_322
  0x192305a9, 0x06002007, 0x20042aad, 0x2821250c,   // fr.ca.gl_544 sq.de.un_420  mt.fi.sq_643 eu.jw.sw_543
  0x190a6eec, 0x0e2d0d1b, 0x040e200c, 0x2a00200e,   // hmn.pt.gl_644 cs.sk.is_777  sq.is.fi_543 sq.mt.un_550
  // [b4f0]
  0x52113107, 0x0b0a10a6, 0x3b282004, 0x1b002709,   // az.ro.ha_432 lt.pt.es_521  sq.sw.so_332 gd.tr.un_440
  0x0f1720a0, 0x20132804, 0x211b11ad, 0x09062507,   // sq.sr.lv_322 sw.et.sq_332  ro.tr.jw_643 eu.de.pl_432
  0x01282bad, 0x25042008, 0x0e202b05, 0x0e085202,   // vi.sw.en_643 sq.fi.eu_443  vi.sq.is_333 ha.no.is_222
  0x08060e55, 0x11051fa0, 0x2d0d0b02, 0x02100fa0,   // is.de.no_442 cy.fr.ro_322  es.cs.sk_222 lv.lt.da_322
  // [b500]
  0x190b0ea4, 0x250d120c, 0x113525ee, 0x3f1f11a7,   // is.es.gl_433 hu.cs.eu_543  eu.zu.ro_422 ro.cy.af_532
  0x18001909, 0x640d35a0, 0x1b043b02, 0x17210907,   // gl.ga.un_440 zu.cs.lg_322  so.fi.tr_222 pl.jw.sr_432
  0x68001c22, 0x31043b07, 0x5368520c, 0x3f2855a0,   // id.ig.un_870 so.fi.az_432  ha.ig.ht_543 rw.sw.af_322
  0x520e1a5a, 0x09321704, 0x3b2052ee, 0x532852ad,   // tl.is.ha_553 sr.bs.pl_332  ha.sq.so_422 ha.sw.ht_643
  // [b510]
  0x11120707, 0x0c1f100d, 0x0b0a01ec, 0x103528a9,   // it.hu.ro_432 lt.cy.sv_554  en.pt.es_644 sw.zu.lt_544
  0x2d210da4, 0x016452ad, 0x6e180405, 0x09520ea9,   // cs.jw.sk_433 ha.lg.en_643  fi.ga.hmn_333 is.ha.pl_544
  0x10003f07, 0x1005280d, 0x17351155, 0x13042508,   // af.lt.un_420 sw.fr.lt_554  ro.zu.sr_442 eu.fi.et_443
  0x180413a9, 0x0c6b64a0, 0x092155af, 0x28100508,   // et.fi.ga_544 lg.ceb.sv_322  rw.jw.pl_655 fr.lt.sw_443
  // [b520]
  0x080c2aec, 0x0c000820, 0x0b070112, 0x0e2d0d11,   // mt.sv.no_644 no.sv.un_850  en.it.es_654 cs.sk.is_653
  0x08520e05, 0x0d05120c, 0x52100fa4, 0x64683bec,   // is.ha.no_333 hu.fr.cs_543  lv.lt.ha_433 so.ig.lg_644
  0x31002302, 0x17072055, 0x180727a0, 0x0a005309,   // ca.az.un_220 sq.it.sr_442  gd.it.ga_322 ht.pt.un_440
  0x1e001a0c, 0x2a0807a9, 0x04050fa9, 0x683b6412,   // tl.ms.un_530 it.no.mt_544  lv.fr.fi_544 lg.so.ig_654
  // [b530]
  0x35215212, 0x2d0d23ec, 0x190510ad, 0x271018a9,   // ha.jw.zu_654 ca.cs.sk_644  lt.fr.gl_643 ga.lt.gd_544
  0x0b000208, 0x0f080e08, 0x6404050c, 0x0c065213,   // da.es.un_430 is.no.lv_443  fr.fi.lg_543 ha.de.sv_665
  0x21003b09, 0x55640b07, 0x281a6b60, 0x11200d07,   // so.jw.un_440 es.lg.rw_432  ceb.tl.sw_664 cs.sq.ro_432
  0x02183b55, 0x03001604, 0x0e183bee, 0x3b090407,   // so.ga.da_442 hr.nl.un_320  so.ga.is_422 fi.pl.so_432
  // [b540]
  0x13000a09, 0x27311b07, 0x521a1b0c, 0x321608af,   // pt.et.un_440 tr.az.gd_432  tr.tl.ha_543 no.hr.bs_655
  0x186e27a7, 0x1f120ca0, 0x083b1b0d, 0x032512a4,   // gd.hmn.ga_532 sv.hu.cy_322  tr.so.no_554 hu.eu.nl_433
  0x4a643507, 0x0811550b, 0x23080711, 0x523b6bec,   // zu.lg.yo_432 rw.ro.no_542  it.no.ca_653 ceb.so.ha_644
  0x0e000d12, 0x1c0b0807, 0x216468a0, 0x3f3b0ea0,   // cs.is.un_640 no.es.id_432  ig.lg.jw_322 is.so.af_322
  // [b550]
  0x25000605, 0x21050ba0, 0x062a070c, 0x06102507,   // de.eu.un_330 es.fr.jw_322  it.mt.de_543 eu.lt.de_432
  0x1101230c, 0x183106ee, 0x35642002, 0x183b5213,   // ca.en.ro_543 de.az.ga_422  sq.lg.zu_222 ha.so.ga_665
  0x2a000812, 0x3b27250c, 0x21111aa4, 0x0711010c,   // no.mt.un_640 eu.gd.so_543  tl.ro.jw_433 en.ro.it_543
  0x2a1b6ba4, 0x281a1b0c, 0x1b352808, 0x18000313,   // ceb.tr.mt_433 tr.tl.sw_543  sw.zu.tr_443 nl.ga.un_650
  // [b560]
  0x1331110c, 0x08231c0b, 0x04110502, 0x082501a4,   // ro.az.et_543 id.ca.no_542  fr.ro.fi_222 en.eu.no_433
  0x64551304, 0x030501a9, 0x641135a4, 0x25080205,   // et.rw.lg_332 en.fr.nl_544  zu.ro.lg_433 da.no.eu_333
  0x11311ba4, 0x04111a02, 0x4a00290e, 0x10005502,   // tr.az.ro_433 tl.ro.fi_222  sl.yo.un_550 rw.lt.un_220
  0x100a0704, 0x191c2107, 0x18211cee, 0x270a110c,   // bg.mk.be_332 jw.id.gl_432  id.jw.ga_422 ro.pt.gd_543
  // [b570]
  0x190f0bad, 0x532718ad, 0x1b3f13ee, 0x080c1aa0,   // es.lv.gl_643 ga.gd.ht_643  et.af.tr_422 tl.sv.no_322
  0x110a0808, 0x04032704, 0x276b1b04, 0x041c25a9,   // no.pt.ro_443 gd.nl.fi_332  tr.ceb.gd_332 eu.id.fi_544
  0x29182008, 0x272d04a0, 0x0c5306a0, 0x23271804,   // sq.ga.sl_443 fi.sk.gd_322  de.ht.sv_322 ga.gd.ca_332
  0x0a002104, 0x133b3f11, 0x07181005, 0x23072007,   // jw.pt.un_320 af.so.et_653  lt.ga.it_333 sq.it.ca_432
  // [b580]
  0x07081711, 0x3f5528a0, 0x05001307, 0x3f041aa4,   // sr.uk.bg_653 sw.rw.af_322  et.fr.un_420 tl.fi.af_433
  0x0a2311af, 0x3f1003a0, 0x1e003b12, 0x2d1c0c04,   // ro.ca.pt_655 nl.lt.af_322  so.ms.un_640 sv.id.sk_332
  0x31000709, 0x6e230504, 0x6b2d0d09, 0x233b195a,   // it.az.un_440 fr.ca.hmn_332  cs.sk.ceb_444 gl.so.ca_553
  0x64001602, 0x3f032704, 0x0a1c28a4, 0x031304ad,   // hr.lg.un_220 gd.nl.af_332  sw.id.pt_433 fi.et.nl_643
  // [b590]
  0x4a3b28a4, 0x0c060207, 0x1b1027a0, 0x072320a4,   // sw.so.yo_433 da.de.sv_432  gd.lt.tr_322 sq.ca.it_433
  0x23110a0d, 0x2d18270d, 0x10116ea6, 0x20272104,   // pt.ro.ca_554 gd.ga.sk_554  hmn.ro.lt_521 jw.gd.sq_332
  0x270b18af, 0x0f1310ec, 0x232105a4, 0x080413ad,   // ga.es.gd_655 lt.et.lv_644  fr.jw.ca_433 et.fi.no_643
  0x1a006e0d, 0x103513a4, 0x120a050c, 0x5200050d,   // hmn.tl.un_540 et.zu.lt_433  fr.pt.hu_543 fr.ha.un_540
  // [b5a0]
  0x100f0c09, 0x6b311b09, 0x230e4a55, 0x17523b08,   // sv.lv.lt_444 tr.az.ceb_444  yo.is.ca_442 so.ha.sr_443
  0x6b280609, 0x3b215505, 0x32043fa0, 0x2b006b02,   // de.sw.ceb_444 rw.jw.so_333  af.fi.bs_322 ceb.vi.un_220
  0x0e101307, 0x1a101304, 0x043f1f55, 0x6b1c0408,   // et.lt.is_432 et.lt.tl_332  cy.af.fi_442 fi.id.ceb_443
  0x2a0e2007, 0x0d3b200b, 0x081b1ca0, 0x321c21ad,   // sq.is.mt_432 sq.so.cs_542  id.tr.no_322 jw.id.bs_643
  // [b5b0]
  0x1c552105, 0x0405310c, 0x312a6b04, 0x1312100c,   // jw.rw.id_333 az.fr.fi_543  ceb.mt.az_332 lt.hu.et_543
  0x31201f07, 0x4a190b04, 0x043b2004, 0x315220a7,   // cy.sq.az_432 es.gl.yo_332  sq.so.fi_332 sq.ha.az_532
  0x09100f11, 0x1c6b1207, 0x2021040c, 0x1a216b60,   // lv.lt.pl_653 hu.ceb.id_432  fi.jw.sq_543 ceb.jw.tl_664
  0x640a4aa0, 0x091f2108, 0x29101604, 0x04251e0c,   // yo.pt.lg_322 jw.cy.pl_443  hr.lt.sl_332 ms.eu.fi_543
  // [b5c0]
  0x25201aa4, 0x18273b0c, 0x1a002722, 0x254a0107,   // tl.sq.eu_433 so.gd.ga_543  gd.tl.un_870 en.yo.eu_432
  0x1c2b2707, 0x1e251c07, 0x182b2709, 0x0f0c21a4,   // gd.vi.id_432 id.eu.ms_432  gd.vi.ga_444 jw.sv.lv_433
  0x1b4a64ee, 0x52005304, 0x3b0a1805, 0x644a115a,   // lg.yo.tr_422 ht.ha.un_320  ga.pt.so_333 ro.yo.lg_553
  0x642104a9, 0x6b1e1aa4, 0x1e251ca4, 0x1a00250d,   // fi.jw.lg_544 tl.ms.ceb_433  id.eu.ms_433 eu.tl.un_540
  // [b5d0]
  0x0f02270c, 0x12285511, 0x1a3b4a14, 0x311a6b12,   // gd.da.lv_543 rw.sw.hu_653  yo.so.tl_666 ceb.tl.az_654
  0x68033fa4, 0x25000505, 0x05531907, 0x19000502,   // af.nl.ig_433 fr.eu.un_330  gl.ht.fr_432 fr.gl.un_220
  0x0c0153a4, 0x283b21a0, 0x0d530aee, 0x29111604,   // ht.en.sv_433 jw.so.sw_322  pt.ht.cs_422 hr.ro.sl_332
  0x0c0f1011, 0x1e1c520e, 0x040f1011, 0x681a11a4,   // lt.lv.sv_653 ha.id.ms_555  lt.lv.fi_653 ro.tl.ig_433
  // [b5e0]
  0x25003512, 0x100f13ee, 0x0f006e05, 0x08020c04,   // zu.eu.un_640 et.lv.lt_422  hmn.lv.un_330 sv.da.no_332
  0x10000c1a, 0x321752a4, 0x68205505, 0x0d212da7,   // sv.lt.un_760 ha.sr.bs_433  rw.sq.ig_333 sk.jw.cs_532
  0x11002921, 0x2d022955, 0x211b5212, 0x070a2309,   // sl.ro.un_860 sl.da.sk_442  ha.tr.jw_654 ca.pt.it_444
  0x16214aa0, 0x132555a4, 0x120532a4, 0x2b4a5511,   // yo.jw.hr_322 rw.eu.et_433  bs.fr.hu_433 rw.yo.vi_653
  // [b5f0]
  0x4a002509, 0x1716550c, 0x6e0f1014, 0x04255205,   // eu.yo.un_440 rw.hr.sr_543  lt.lv.hmn_666 ha.eu.fi_333
  0x282135a0, 0x523b21a0, 0x271f4a60, 0x28552104,   // zu.jw.sw_322 jw.so.ha_322  yo.cy.gd_664 jw.rw.sw_332
  0x281e1207, 0x013f290c, 0x29164a0c, 0x16231f08,   // hu.ms.sw_432 sl.af.en_543  yo.hr.sl_543 cy.ca.hr_443
  0x0b00250e, 0x55321708, 0x05321fee, 0x06006402,   // eu.es.un_550 sr.bs.rw_443  cy.bs.fr_422 lg.de.un_220
  // [b600]
  0x0a000802, 0x11001007, 0x52532705, 0x2327040c,   // uk.mk.un_220 lt.ro.un_420  gd.ht.ha_333 fi.gd.ca_543
  0x03002a0e, 0x09060304, 0x535228ee, 0x110b0504,   // mt.nl.un_550 nl.de.pl_332  sw.ha.ht_422 fr.es.ro_332
  0x1b1335ad, 0x060923a0, 0x0f311bec, 0x6b0a28a0,   // zu.et.tr_643 ca.pl.de_322  tr.az.lv_644 sw.pt.ceb_322
  0x531a2807, 0x1a4a2811, 0x32162a14, 0x2d043fad,   // sw.tl.ht_432 sw.yo.tl_653  mt.hr.bs_666 af.fi.sk_643
  // [b610]
  0x193f0b11, 0x182735ec, 0x18011aa0, 0x53130555,   // es.af.gl_653 zu.gd.ga_644  tl.en.ga_322 fr.et.ht_442
  0x013508a0, 0x0e286b0b, 0x6b682707, 0x1e003112,   // no.zu.en_322 ceb.sw.is_542  gd.ig.ceb_432 az.ms.un_640
  0x05232aad, 0x086e060c, 0x25000a0c, 0x1b2a5212,   // mt.ca.fr_643 de.hmn.no_543  pt.eu.un_530 ha.mt.tr_654
  0x131b3108, 0x1a006812, 0x1c0c1a0c, 0x311a5304,   // az.tr.et_443 ig.tl.un_640  tl.sv.id_543 ht.tl.az_332
  // [b620]
  0x351b1e04, 0x0a356ea0, 0x0300681a, 0x0f0419a0,   // ms.tr.zu_332 hmn.zu.pt_322  ig.nl.un_760 gl.fi.lv_322
  0x020c2555, 0x070311a7, 0x200835ad, 0x2d006808,   // eu.sv.da_442 ro.nl.it_532  zu.no.sq_643 ig.sk.un_430
  0x011a1e02, 0x1307100c, 0x1328685a, 0x1a526ba0,   // ms.tl.en_222 lt.it.et_543  ig.sw.et_553 ceb.ha.tl_322
  0x323b1ea0, 0x06312a0b, 0x2b005314, 0x041352a9,   // ms.so.bs_322 mt.az.de_542  ht.vi.un_660 ha.et.fi_544
  // [b630]
  0x1f6b2102, 0x190b1a14, 0x27041ba4, 0x05231ea0,   // jw.ceb.cy_222 tl.es.gl_666  tr.fi.gd_433 ms.ca.fr_322
  0x290407ad, 0x0f2a1207, 0x0a0905a0, 0x354a5504,   // it.fi.sl_643 hu.mt.lv_432  fr.pl.pt_322 rw.yo.zu_332
  0x19100b02, 0x532b07a0, 0x2d0d0ba4, 0x27003204,   // es.lt.gl_222 it.vi.ht_322  es.cs.sk_433 bs.gd.un_320
  0x645520a4, 0x120b0aa9, 0x64524a0c, 0x112007ad,   // sq.rw.lg_433 pt.es.hu_544  yo.ha.lg_543 it.sq.ro_643
  // [b640]
  0x2511050e, 0x274a680c, 0x1b4a550b, 0x11081705,   // fr.ro.eu_555 ig.yo.gd_543  rw.yo.tr_542 sr.uk.ro_333
  0x3b0428ad, 0x07250604, 0x4a11070c, 0x4a006e04,   // sw.fi.so_643 de.eu.it_332  it.ro.yo_543 hmn.yo.un_320
  0x112a1904, 0x1f3f0b02, 0x20311b12, 0x2d1a1fee,   // gl.mt.ro_332 es.af.cy_222  tr.az.sq_654 cy.tl.sk_422
  0x684a25ec, 0x4a2568a9, 0x200a0704, 0x1a355507,   // eu.yo.ig_644 ig.eu.yo_544  it.pt.sq_332 rw.zu.tl_432
  // [b650]
  0x20024a02, 0x17002d35, 0x1b0f130d, 0x68293f5a,   // yo.da.sq_222 sk.sr.un_A90  et.lv.tr_554 af.sl.ig_553
  0x16003505, 0x16000904, 0x2a000d08, 0x0a282508,   // zu.hr.un_330 pl.hr.un_320  cs.mt.un_430 eu.sw.pt_443
  0x642a520c, 0x321c64a0, 0x64000b02, 0x64132a07,   // ha.mt.lg_543 lg.id.bs_322  es.lg.un_220 mt.et.lg_432
  0x0a04115a, 0x0b1805a7, 0x682a640c, 0x4a1c1e0c,   // ro.ru.mk_553 fr.ga.es_532  lg.mt.ig_543 ms.id.yo_543
  // [b660]
  0x1e002a02, 0x211f270c, 0x0f27100d, 0x64286807,   // mt.ms.un_220 gd.cy.jw_543  lt.gd.lv_554 ig.sw.lg_432
  0x071028ad, 0x64002a09, 0x1a52530c, 0x29170aa0,   // sw.lt.it_643 mt.lg.un_440  ht.ha.tl_543 pt.sr.sl_322
  0x2728180c, 0x1f270f09, 0x64522aa9, 0x060704a9,   // ga.sw.gd_543 lv.gd.cy_444  mt.ha.lg_544 fi.it.de_544
  0x0f272512, 0x281f27a6, 0x072b110c, 0x0c313b07,   // eu.gd.lv_654 gd.cy.sw_521  ro.vi.it_543 so.az.sv_432
  // [b670]
  0x060412ee, 0x0e0c3b07, 0x040812a4, 0x035319a0,   // hu.fi.de_422 so.sv.is_432  hu.no.fi_433 gl.ht.nl_322
  0x043b2705, 0x2d0d28ee, 0x533b1a0c, 0x052a010c,   // gd.so.fi_333 sw.cs.sk_422  tl.so.ht_543 en.mt.fr_543
  0x21041a0c, 0x183b2760, 0x041f270c, 0x070a010c,   // tl.fi.jw_543 gd.so.ga_664  gd.cy.fi_543 en.pt.it_543
  0x13005219, 0x35091104, 0x0f18270c, 0x27002823,   // ha.et.un_750 ro.pl.zu_332  gd.ga.lv_543 sw.gd.un_880
  // [b680]
  0x1e1c23a0, 0x040652a0, 0x0a120612, 0x1b04120d,   // ca.id.ms_322 ha.de.fi_322  de.hu.pt_654 hu.fi.tr_554
  0x2a643f04, 0x070a12a4, 0x080c0e02, 0x2a6b0607,   // af.lg.mt_332 hu.pt.it_433  is.sv.no_222 de.ceb.mt_432
  0x0e003f0d, 0x270e3bee, 0x29122d0c, 0x2d2917ee,   // af.is.un_540 so.is.gd_422  sk.hu.sl_543 sr.sl.sk_422
  0x170c13a7, 0x21090155, 0x6e2d1255, 0x52190b13,   // et.sv.sr_532 en.pl.jw_442  hu.sk.hmn_442 es.gl.ha_665
  // [b690]
  0x250a0702, 0x161229ee, 0x04110aa9, 0x290e0c08,   // it.pt.eu_222 sl.hu.hr_422  pt.ro.fi_544 sv.is.sl_443
  0x3b012aa0, 0x104a2aa7, 0x16522a07, 0x25002321,   // mt.en.so_322 mt.yo.lt_532  mt.ha.hr_432 ca.eu.un_860
  0x0c530604, 0x130e0807, 0x11130605, 0x0f00110c,   // de.ht.sv_332 no.is.et_432  de.et.ro_333 ro.lv.un_530
  0x28133504, 0x08002d08, 0x122855ee, 0x6b060c55,   // zu.et.sw_332 sk.no.un_430  rw.sw.hu_422 sv.de.ceb_442
  // [b6a0]
  0x130c0614, 0x062055a4, 0x08060c0c, 0x1a2913a7,   // de.sv.et_666 rw.sq.de_433  sv.de.no_543 et.sl.tl_532
  0x29130460, 0x3b095304, 0x3f001f22, 0x1e101c04,   // fi.et.sl_664 ht.pl.so_332  cy.af.un_870 id.lt.ms_332
  0x35003f0e, 0x1e002802, 0x17001609, 0x213b5512,   // af.zu.un_550 sw.ms.un_220  hr.sr.un_440 rw.so.jw_654
  0x35644a08, 0x071035a4, 0x063f3508, 0x521a5504,   // yo.lg.zu_443 zu.lt.it_433  zu.af.de_443 rw.tl.ha_332
  // [b6b0]
  0x0f006423, 0x100f1a12, 0x550506a0, 0x286b3b08,   // lg.lv.un_880 tl.lv.lt_654  de.fr.rw_322 so.ceb.sw_443
  0x216b28ad, 0x06190b55, 0x2735110c, 0x4a0f52a4,   // sw.ceb.jw_643 es.gl.de_442  ro.zu.gd_543 ha.lv.yo_433
  0x133b6b14, 0x350d3f07, 0x64551004, 0x64683ba7,   // ceb.so.et_666 af.cs.zu_432  lt.rw.lg_332 so.ig.lg_532
  0x10043b07, 0x354a530c, 0x1b00521a, 0x19050ba7,   // so.fi.lt_432 ht.yo.zu_543  ha.tr.un_760 es.fr.gl_532
  // [b6c0]
  0x6b063f07, 0x64350f11, 0x055331ec, 0x19002a07,   // af.de.ceb_432 lv.zu.lg_653  az.ht.fr_644 mt.gl.un_420
  0x0f1320a9, 0x4a181fa0, 0x086410a7, 0x292d3f05,   // sq.et.lv_544 cy.ga.yo_322  lt.lg.no_532 af.sk.sl_333
  0x354a0408, 0x01002905, 0x046410ee, 0x061a6ba0,   // fi.yo.zu_443 sl.en.un_330  lt.lg.fi_422 ceb.tl.de_322
  0x28133b07, 0x2710090c, 0x0b3507a4, 0x3b281308,   // so.et.sw_432 pl.lt.gd_543  it.zu.es_433 et.sw.so_443
  // [b6d0]
  0x32191704, 0x2b041307, 0x643b13a0, 0x68050107,   // sr.gl.bs_332 et.fi.vi_432  et.so.lg_322 en.fr.ig_432
  0x311b520c, 0x01002b07, 0x282b1fee, 0x20041355,   // ha.tr.az_543 vi.en.un_420  cy.vi.sw_422 et.fi.sq_442
  0x08120cee, 0x28231e04, 0x23001f12, 0x0f000802,   // sv.hu.no_422 ms.ca.sw_332  cy.ca.un_640 no.lv.un_220
  0x680112a0, 0x3f0e0ca4, 0x02000502, 0x6b281307,   // hu.en.ig_322 sv.is.af_433  fr.da.un_220 et.sw.ceb_432
  // [b6e0]
  0x23001235, 0x2d0d2105, 0x6b0501ad, 0x13080607,   // hu.ca.un_A90 jw.cs.sk_333  en.fr.ceb_643 de.no.et_432
  0x1e000a02, 0x0c081905, 0x3f0608a4, 0x20006822,   // pt.ms.un_220 gl.no.sv_333  no.de.af_433 ig.sq.un_870
  0x53163fa9, 0x6b005523, 0x100a350b, 0x52136860,   // af.hr.ht_544 rw.ceb.un_880  zu.pt.lt_542 ig.et.ha_664
  0x1e1c08ee, 0x3f68640c, 0x28201302, 0x3f2a2512,   // no.id.ms_422 lg.ig.af_543  et.sq.sw_222 eu.mt.af_654
  // [b6f0]
  0x2a2025a4, 0x25180aaf, 0x256b4aad, 0x0201080c,   // eu.sq.mt_433 pt.ga.eu_655  yo.ceb.eu_643 no.en.da_543
  0x2820355a, 0x132a3504, 0x0104520b, 0x0f092507,   // zu.sq.sw_553 zu.mt.et_332  ha.fi.en_542 eu.pl.lv_432
  0x29011a02, 0x320f20a4, 0x0e1125a4, 0x202b08ee,   // tl.en.sl_222 sq.lv.bs_433  eu.ro.is_433 no.vi.sq_422
  0x64521fa9, 0x2d3b07ee, 0x0d2d05af, 0x082853a0,   // cy.ha.lg_544 it.so.sk_422  fr.sk.cs_655 ht.sw.no_322
  // [b700]
  0x21131e07, 0x031a3f08, 0x0f0a25a0, 0x213509a0,   // ms.et.jw_432 af.tl.nl_443  eu.pt.lv_322 pl.zu.jw_322
  0x1a0601ad, 0x280c0802, 0x6b080213, 0x17211cee,   // en.de.tl_643 no.sv.sw_222  da.no.ceb_665 id.jw.sr_422
  0x1121520c, 0x061b3b07, 0x1104080e, 0x2d520d08,   // ha.jw.ro_543 so.tr.de_432  uk.ru.ro_555 cs.ha.sk_443
  0x281a3b11, 0x6b313ba9, 0x3f2864ac, 0x19230a11,   // so.tl.sw_653 so.az.ceb_544  lg.sw.af_632 pt.ca.gl_653
  // [b710]
  0x10250fee, 0x3b311b02, 0x4a0453a0, 0x530504a4,   // lv.eu.lt_422 tr.az.so_222  ht.fi.yo_322 fi.fr.ht_433
  0x53060307, 0x32162911, 0x0d125304, 0x5305640c,   // nl.de.ht_432 sl.hr.bs_653  ht.hu.cs_332 lg.fr.ht_543
  0x0a1205af, 0x0603530e, 0x04056407, 0x3b002902,   // fr.hu.pt_655 ht.nl.de_555  lg.fr.fi_432 sl.so.un_220
  0x1809050c, 0x316b1ca0, 0x640705ee, 0x23005222,   // fr.pl.ga_543 id.ceb.az_322  fr.it.lg_422 ha.ca.un_870
  // [b720]
  0x23011e0c, 0x1c0553a0, 0x18110a08, 0x2113040c,   // ms.en.ca_543 ht.fr.id_322  pt.ro.ga_443 fi.et.jw_543
  0x201c21ad, 0x18352711, 0x132a0ca9, 0x3b0b0411,   // jw.id.sq_643 gd.zu.ga_653  sv.mt.et_544 fi.es.so_653
  0x01050407, 0x551b640c, 0x0f0e13af, 0x0d271860,   // fi.fr.en_432 lg.tr.rw_543  et.is.lv_655 ga.gd.cs_664
  0x16102911, 0x5521640d, 0x4a255355, 0x641b310c,   // sl.lt.hr_653 lg.jw.rw_554  ht.eu.yo_442 az.tr.lg_543
  // [b730]
  0x2b03010c, 0x3b3f1313, 0x12254a13, 0x31001c08,   // en.nl.vi_543 et.af.so_665  yo.eu.hu_665 id.az.un_430
  0x0c1e1c0c, 0x25133bee, 0x29165207, 0x0b040e0d,   // id.ms.sv_543 so.et.eu_422  ha.hr.sl_432 is.fi.es_554
  0x27092513, 0x11050a05, 0x11070d07, 0x032553a0,   // eu.pl.gd_665 pt.fr.ro_333  cs.it.ro_432 ht.eu.nl_322
  0x07004a13, 0x2104100b, 0x52311b55, 0x11000821,   // yo.it.un_650 lt.fi.jw_542  tr.az.ha_442 uk.ro.un_860
  // [b740]
  0x162911a4, 0x082105ee, 0x642a2807, 0x282a68ad,   // ro.sl.hr_433 fr.jw.no_422  sw.mt.lg_432 ig.mt.sw_643
  0x112718a4, 0x082505ad, 0x210b07a4, 0x23131007,   // ga.gd.ro_433 fr.eu.no_643  it.es.jw_433 lt.et.ca_432
  0x27643b13, 0x531e4aa4, 0x521b2308, 0x0c003b14,   // so.lg.gd_665 yo.ms.ht_433  ca.tr.ha_443 so.sv.un_660
  0x080e180c, 0x25185208, 0x3f2a0605, 0x11000e21,   // ga.is.no_543 ha.ga.eu_443  de.mt.af_333 is.ro.un_860
  // [b750]
  0x2a040f0c, 0x29110da7, 0x06250704, 0x035325ee,   // lv.fi.mt_543 cs.ro.sl_532  it.eu.de_332 eu.ht.nl_422
  0x4a250655, 0x180608a4, 0x25271c07, 0x08100e0d,   // de.eu.yo_442 no.de.ga_433  id.gd.eu_432 is.lt.no_554
  0x21251c12, 0x2900010d, 0x18000919, 0x2a0406a9,   // id.eu.jw_654 en.sl.un_540  pl.ga.un_750 de.fi.mt_544
  0x080b0ea0, 0x11003f07, 0x1f0618a4, 0x35002921,   // is.es.no_322 af.ro.un_420  ga.de.cy_433 sl.zu.un_860
  // [b760]
  0x291007a0, 0x3b06270e, 0x04100b05, 0x04533f08,   // it.lt.sl_322 gd.de.so_555  es.lt.fi_333 af.ht.fi_443
  0x291f06af, 0x3b1e2aee, 0x521b25ec, 0x1f1e1c04,   // de.cy.sl_655 mt.ms.so_422  eu.tr.ha_644 id.ms.cy_332
  0x2d3509ad, 0x64100f04, 0x0a060807, 0x0f2d09ec,   // pl.zu.sk_643 lv.lt.lg_332  no.de.pt_432 pl.sk.lv_644
  0x21073fad, 0x10251213, 0x16002502, 0x101306a4,   // af.it.jw_643 hu.eu.lt_665  eu.hr.un_220 de.et.lt_433
  // [b770]
  0x0f2d04a4, 0x2a183b0b, 0x210e200c, 0x112d0d02,   // fi.sk.lv_433 so.ga.mt_542  sq.is.jw_543 cs.sk.ro_222
  0x0a122dad, 0x3b2a5208, 0x052a5202, 0x19004a0d,   // sk.hu.pt_643 ha.mt.so_443  ha.mt.fr_222 yo.gl.un_540
  0x092a13ad, 0x3f001812, 0x08111714, 0x53214a55,   // et.mt.pl_643 ga.af.un_640  sr.ro.uk_666 yo.jw.ht_442
  0x213f1a02, 0x68042107, 0x0e3f53ad, 0x4a001018,   // tl.af.jw_222 jw.fi.ig_432  ht.af.is_643 lt.yo.un_740
  // [b780]
  0x642335ee, 0x110725af, 0x01050ea0, 0x0b350507,   // zu.ca.lg_422 eu.it.ro_655  is.fr.en_322 fr.zu.es_432
  0x23120d09, 0x68122114, 0x0f2d0d0d, 0x1b002a09,   // cs.hu.ca_444 jw.hu.ig_666  cs.sk.lv_554 mt.tr.un_440
  0x040b070c, 0x1e0a1107, 0x04104a05, 0x231f0a02,   // it.es.fi_543 ro.pt.ms_432  yo.lt.fi_333 pt.cy.ca_222
  0x0a072da9, 0x1900110d, 0x25000a02, 0x1a6b2d0c,   // sk.it.pt_544 ro.gl.un_540  pt.eu.un_220 sk.ceb.tl_543
  // [b790]
  0x2d1925a4, 0x1c070fa0, 0x21322dee, 0x29103b04,   // eu.gl.sk_433 lv.it.id_322  sk.bs.jw_422 so.lt.sl_332
  0x643b07ad, 0x0532200d, 0x03051f04, 0x060c3f04,   // it.so.lg_643 sq.bs.fr_554  cy.fr.nl_332 af.sv.de_332
  0x10093b05, 0x23160a07, 0x0a003114, 0x012a18a0,   // so.pl.lt_333 pt.hr.ca_432  az.pt.un_660 ga.mt.en_322
  0x21110702, 0x041307a4, 0x060428a7, 0x2d2928a7,   // it.ro.jw_222 it.et.fi_433  sw.fi.de_532 sw.sl.sk_532
  // [b7a0]
  0x0200200e, 0x23071fa0, 0x081025a0, 0x0c291e55,   // sq.da.un_550 cy.it.ca_322  eu.lt.no_322 ms.sl.sv_442
  0x0e0c080d, 0x0c110807, 0x64053ba0, 0x10271f12,   // no.sv.is_554 no.ro.sv_432  so.fr.lg_322 cy.gd.lt_654
  0x212055ec, 0x211e3504, 0x681b55a4, 0x2700040d,   // rw.sq.jw_644 zu.ms.jw_332  rw.tr.ig_433 fi.gd.un_540
  0x21122307, 0x10000b19, 0x0d00100d, 0x13281104,   // ca.hu.jw_432 es.lt.un_750  lt.cs.un_540 ro.sw.et_332
  // [b7b0]
  0x1a00020c, 0x2a351207, 0x556e2804, 0x2a521bad,   // da.tl.un_530 hu.zu.mt_432  sw.hmn.rw_332 tr.ha.mt_643
  0x19041309, 0x130f1ca4, 0x121307a4, 0x07000b02,   // et.fi.gl_444 id.lv.et_433  it.et.hu_433 es.it.un_220
  0x3b281fa4, 0x033f28a0, 0x64352811, 0x552853a0,   // cy.sw.so_433 sw.af.nl_322  sw.zu.lg_653 ht.sw.rw_322
  0x20352504, 0x21001b1a, 0x2800091a, 0x041307ad,   // eu.zu.sq_332 tr.jw.un_760  pl.sw.un_760 it.et.fi_643
  // [b7c0]
  0x310401a4, 0x17201bee, 0x3f032012, 0x0e551e0c,   // en.fi.az_433 tr.sq.sr_422  sq.nl.af_654 ms.rw.is_543
  0x101721a7, 0x1e1c2da0, 0x0a1e1c13, 0x291a21a4,   // jw.sr.lt_532 sk.id.ms_322  id.ms.pt_665 jw.tl.sl_433
  0x270823a0, 0x16321712, 0x31231ba4, 0x05120b05,   // ca.no.gd_322 sr.bs.hr_654  tr.ca.az_433 es.hu.fr_333
  0x010603ee, 0x080b1907, 0x18055502, 0x2018350c,   // nl.de.en_422 gl.es.no_432  rw.fr.ga_222 zu.ga.sq_543
  // [b7d0]
  0x131155a7, 0x1712640c, 0x1c051e07, 0x35230ba4,   // rw.ro.et_532 lg.hu.sr_543  ms.fr.id_432 es.ca.zu_433
  0x0613080c, 0x011b13ee, 0x3f27130c, 0x08211ca0,   // no.et.de_543 et.tr.en_422  et.gd.af_543 id.jw.no_322
  0x20270511, 0x35205504, 0x2008110c, 0x2a2029a7,   // fr.gd.sq_653 rw.sq.zu_332  ro.no.sq_543 sl.sq.mt_532
  0x04100e08, 0x1300102c, 0x64201109, 0x35551b07,   // is.lt.fi_443 lt.et.un_990  ro.sq.lg_444 tr.rw.zu_432
  // [b7e0]
  0x01072005, 0x05271805, 0x270519a0, 0x183f0608,   // sq.it.en_333 ga.gd.fr_333  gl.fr.gd_322 de.af.ga_443
  0x6b190aee, 0x27060305, 0x18273bec, 0x271913ee,   // pt.gl.ceb_422 nl.de.gd_333  so.gd.ga_644 et.gl.gd_422
  0x08190a04, 0x18112004, 0x12041305, 0x642035a6,   // pt.gl.no_332 sq.ro.ga_332  et.fi.hu_333 zu.sq.lg_521
  0x01002119, 0x28042107, 0x200513ee, 0x0e006b0c,   // jw.en.un_750 jw.fi.sw_432  et.fr.sq_422 ceb.is.un_530
  // [b7f0]
  0x010520a4, 0x1c2a070c, 0x1320350b, 0x35001322,   // sq.fr.en_433 it.mt.id_543  zu.sq.et_542 et.zu.un_870
  0x3500200c, 0x6b002522, 0x06212a04, 0x231211ee,   // sq.zu.un_530 eu.ceb.un_870  mt.jw.de_332 ro.hu.ca_422
  0x07041305, 0x2d290da0, 0x0e101ba0, 0x321729a9,   // et.fi.it_333 cs.sl.sk_322  tr.lt.is_322 sl.sr.bs_544
  0x281853a7, 0x536b05ee, 0x010d1f04, 0x1e006804,   // ht.ga.sw_532 fr.ceb.ht_422  cy.cs.en_332 ig.ms.un_320

  // [b800]
  0x081a0e07, 0x08211c0c, 0x0e000f0c, 0x2d0d17a4,   // is.tl.no_432 id.jw.no_543  lv.is.un_530 sr.cs.sk_433
  0x060a21a0, 0x11202508, 0x35131ea0, 0x070b280c,   // jw.pt.de_322 eu.sq.ro_443  ms.et.zu_322 sw.es.it_543
  0x0f062a02, 0x13356808, 0x27112304, 0x1a001014,   // mt.de.lv_222 ig.zu.et_443  ca.ro.gd_332 lt.tl.un_660
  0x3f0f1307, 0x272d2a07, 0x3b553507, 0x064a35a4,   // et.lv.af_432 mt.sk.gd_432  zu.rw.so_432 zu.yo.de_433
  // [b810]
  0x25092aee, 0x280a1004, 0x3b00120d, 0x07280b13,   // mt.pl.eu_422 lt.pt.sw_332  hu.so.un_540 es.sw.it_665
  0x286425ad, 0x6809280c, 0x25002a09, 0x68001a19,   // eu.lg.sw_643 sw.pl.ig_543  mt.eu.un_440 tl.ig.un_750
  0x25211fa4, 0x21646808, 0x1c003513, 0x25162a07,   // cy.jw.eu_433 ig.lg.jw_443  zu.id.un_650 mt.hr.eu_432
  0x1f3b2107, 0x64092507, 0x122b3b0d, 0x1f0b2304,   // jw.so.cy_432 eu.pl.lg_432  so.vi.hu_554 ca.es.cy_332
  // [b820]
  0x07321707, 0x211a3fa4, 0x6b6817a6, 0x062d0f07,   // sr.bs.it_432 af.tl.jw_433  sr.ig.ceb_521 lv.sk.de_432
  0x35216eee, 0x0768280c, 0x291e1804, 0x073f27a0,   // hmn.jw.zu_422 sw.ig.it_543  ga.ms.sl_332 gd.af.it_322
  0x106825ad, 0x0b251a08, 0x0700210c, 0x13120ca0,   // eu.ig.lt_643 tl.eu.es_443  jw.it.un_530 sv.hu.et_322
  0x18001108, 0x1c250107, 0x01271112, 0x27191812,   // ro.ga.un_430 en.eu.id_432  ro.gd.en_654 ga.gl.gd_654
  // [b830]
  0x3b1b1e07, 0x68016b0d, 0x182719a0, 0x1a00520d,   // ms.tr.so_432 ceb.en.ig_554  gl.gd.ga_322 ha.tl.un_540
  0x3b681b0c, 0x3b1a28a9, 0x4a003b14, 0x6b1a52ec,   // tr.ig.so_543 sw.tl.so_544  so.yo.un_660 ha.tl.ceb_644
  0x320216a4, 0x0127180c, 0x3f271811, 0x1b685204,   // hr.da.bs_433 ga.gd.en_543  ga.gd.af_653 ha.ig.tr_332
  0x21281c08, 0x52642108, 0x1b213ba7, 0x050b1907,   // id.sw.jw_443 jw.lg.ha_443  so.jw.tr_532 gl.es.fr_432
  // [b840]
  0x0b523b0c, 0x1b3168af, 0x1a52310c, 0x04641309,   // so.ha.es_543 ig.az.tr_655  az.ha.tl_543 et.lg.fi_444
  0x52211e0c, 0x04134a13, 0x640e5508, 0x1b681a0c,   // ms.jw.ha_543 yo.et.fi_665  rw.is.lg_443 tl.ig.tr_543
  0x2d0d4aa0, 0x2d0d08a4, 0x10121fa0, 0x2d05120b,   // yo.cs.sk_322 no.cs.sk_433  cy.hu.lt_322 hu.fr.sk_542
  0x04684aa4, 0x126403a9, 0x29071f0d, 0x0e000602,   // yo.ig.fi_433 nl.lg.hu_544  cy.it.sl_554 de.is.un_220
  // [b850]
  0x3f060e0c, 0x103b070b, 0x061335a7, 0x0a073b05,   // is.de.af_543 it.so.lt_542  zu.et.de_532 so.it.pt_333
  0x68000912, 0x4a6825ad, 0x11001f12, 0x53130eee,   // pl.ig.un_640 eu.ig.yo_643  cy.ro.un_640 is.et.ht_422
  0x0d0e1908, 0x35110a0e, 0x08190204, 0x0208060d,   // gl.is.cs_443 pt.ro.zu_555  da.gl.no_332 de.no.da_554
  0x3b6b06ec, 0x08006b20, 0x23122da0, 0x0f000720,   // de.ceb.so_644 ceb.no.un_850  sk.hu.ca_322 it.lv.un_850
  // [b860]
  0x0a000e13, 0x1905230c, 0x211c3bec, 0x23002502,   // is.pt.un_650 ca.fr.gl_543  so.id.jw_644 eu.ca.un_220
  0x07001a1a, 0x0a1219a9, 0x0b001708, 0x060c080b,   // tl.it.un_760 gl.hu.pt_544  sr.es.un_430 no.sv.de_542
  0x0f0c08a0, 0x132d0855, 0x06180812, 0x216e0e04,   // no.sv.lv_322 no.sk.et_442  no.ga.de_654 is.hmn.jw_332
  0x234a1812, 0x0e0b1a08, 0x3f6e6b55, 0x13080702,   // ga.yo.ca_654 tl.es.is_443  ceb.hmn.af_442 it.no.et_222
  // [b870]
  0x0311250b, 0x076b11a0, 0x310525a0, 0x05030607,   // eu.ro.nl_542 ro.ceb.it_322  eu.fr.az_322 de.nl.fr_432
  0x313b0e12, 0x1b003b02, 0x23180d0c, 0x27010cee,   // is.so.az_654 so.tr.un_220  cs.ga.ca_543 sv.en.gd_422
  0x313b1f0c, 0x3f0e3bad, 0x5200210c, 0x523f0907,   // cy.so.az_543 so.is.af_643  jw.ha.un_530 pl.af.ha_432
  0x280f2504, 0x1e3b3508, 0x104a0f11, 0x2d0f4a55,   // eu.lv.sw_332 zu.so.ms_443  lv.yo.lt_653 yo.lv.sk_442
  // [b880]
  0x1e531c04, 0x093f1f02, 0x3b352a12, 0x3b285214,   // id.ht.ms_332 cy.af.pl_222  mt.zu.so_654 ha.sw.so_666
  0x0725040c, 0x13100f13, 0x1009190c, 0x06183507,   // fi.eu.it_543 lv.lt.et_665  gl.pl.lt_543 zu.ga.de_432
  0x280f0d04, 0x1a271855, 0x12520407, 0x32171aec,   // cs.lv.sw_332 ga.gd.tl_442  fi.ha.hu_432 tl.sr.bs_644
  0x55000513, 0x29080e0c, 0x2a000618, 0x1f195214,   // fr.rw.un_650 is.no.sl_543  de.mt.un_740 ha.gl.cy_666
  // [b890]
  0x64001209, 0x16131e08, 0x0b1720ee, 0x0c271809,   // hu.lg.un_440 ms.et.hr_443  sq.sr.es_422 ga.gd.sv_444
  0x19002109, 0x13050455, 0x0400051b, 0x552811af,   // jw.gl.un_440 fi.fr.et_442  fr.fi.un_770 ro.sw.rw_655
  0x07000c13, 0x071328a7, 0x1e1c1bac, 0x6b030107,   // sv.it.un_650 sw.et.it_532  tr.id.ms_632 en.nl.ceb_432
  0x111017a4, 0x532105ee, 0x230c0aa4, 0x1200680c,   // sr.be.ro_433 fr.jw.ht_422  pt.sv.ca_433 ig.hu.un_530
  // [b8a0]
  0x0f000302, 0x100f090c, 0x2a110702, 0x09001a07,   // nl.lv.un_220 pl.lv.lt_543  it.ro.mt_222 tl.pl.un_420
  0x21124aee, 0x646b6809, 0x106b3b02, 0x0400350e,   // yo.hu.jw_422 ig.ceb.lg_444  so.ceb.lt_222 zu.fi.un_550
  0x211c35a0, 0x05001912, 0x0e120da7, 0x043525ad,   // zu.id.jw_322 gl.fr.un_640  cs.hu.is_532 eu.zu.fi_643
  0x535229af, 0x3b2127a0, 0x081b02ad, 0x321b21a0,   // sl.ha.ht_655 gd.jw.so_322  da.tr.no_643 jw.tr.bs_322
  // [b8b0]
  0x081b1305, 0x3b2d35a9, 0x1e1c18a4, 0x111208a0,   // et.tr.no_333 zu.sk.so_544  ga.id.ms_433 no.hu.ro_322
  0x211f3507, 0x68002d07, 0x3f000e0b, 0x2d0a23af,   // zu.cy.jw_432 sk.ig.un_420  is.af.un_520 ca.pt.sk_655
  0x0f3b6407, 0x1a001008, 0x21033f04, 0x103b1a07,   // lg.so.lv_432 lt.tl.un_430  af.nl.jw_332 tl.so.lt_432
  0x1c031eee, 0x190b0ea0, 0x03131ba7, 0x1f122b07,   // ms.nl.id_422 is.es.gl_322  tr.et.nl_532 vi.hu.cy_432
  // [b8c0]
  0x6b55045a, 0x0e101355, 0x32201702, 0x2035530c,   // fi.rw.ceb_553 et.lt.is_442  sr.sq.bs_222 ht.zu.sq_543
  0x190a2d07, 0x09071813, 0x2b002a02, 0x1e1c03a0,   // sk.pt.gl_432 ga.it.pl_665  mt.vi.un_220 nl.id.ms_322
  0x23534a08, 0x351e1ca7, 0x181013a4, 0x25640905,   // yo.ht.ca_443 id.ms.zu_532  et.lt.ga_433 pl.lg.eu_333
  0x190b0da4, 0x0a2d23ec, 0x10121f55, 0x180e2d07,   // cs.es.gl_433 ca.sk.pt_644  cy.hu.lt_442 sk.is.ga_432
  // [b8d0]
  0x2a0f0804, 0x170e16a4, 0x28552a5a, 0x0a000e07,   // no.lv.mt_332 hr.is.sr_433  mt.rw.sw_553 is.pt.un_420
  0x55002a04, 0x190a55af, 0x04131008, 0x0b2312ec,   // mt.rw.un_320 rw.pt.gl_655  lt.et.fi_443 hu.ca.es_644
  0x1f0e5355, 0x191655a0, 0x6e005522, 0x292d200c,   // ht.is.cy_442 rw.hr.gl_322  rw.hmn.un_870 sq.sk.sl_543
  0x6e006409, 0x2300090c, 0x645355a0, 0x100c0ea9,   // lg.hmn.un_440 pl.ca.un_530  rw.ht.lg_322 is.sv.lt_544
  // [b8e0]
  0x05120a02, 0x03054a02, 0x19120a0d, 0x0c290da4,   // pt.hu.fr_222 yo.fr.nl_222  pt.hu.gl_554 cs.sl.sv_433
  0x0d102d12, 0x2d0d23a4, 0x191205ee, 0x351b0305,   // sk.lt.cs_654 ca.cs.sk_433  fr.hu.gl_422 nl.tr.zu_333
  0x2d0d1fec, 0x0e004a1a, 0x0a08100d, 0x185535a0,   // cy.cs.sk_644 yo.is.un_760  be.uk.mk_554 zu.rw.ga_322
  0x2d0d64a0, 0x0500100d, 0x05122104, 0x6b000307,   // lg.cs.sk_322 lt.fr.un_540  jw.hu.fr_332 nl.ceb.un_420
  // [b8f0]
  0x5305110c, 0x25040604, 0x093f0ea4, 0x092a0f13,   // ro.fr.ht_543 de.fi.eu_332  is.af.pl_433 lv.mt.pl_665
  0x06006804, 0x0900020e, 0x05093f08, 0x25006402,   // ig.de.un_320 da.pl.un_550  af.pl.fr_443 lg.eu.un_220
  0x23111809, 0x07002b07, 0x05186ba4, 0x235305ee,   // ga.ro.ca_444 vi.it.un_420  ceb.ga.fr_433 fr.ht.ca_422
  0x033f0da9, 0x090f05a9, 0x64002a11, 0x09000f12,   // cs.af.nl_544 fr.lv.pl_544  mt.lg.un_630 lv.pl.un_640
  // [b900]
  0x645505a0, 0x073555a4, 0x010603a0, 0x1c001f12,   // fr.rw.lg_322 rw.zu.it_433  nl.de.en_322 cy.id.un_640
  0x0f1813a4, 0x53640307, 0x1f002a22, 0x3f270c07,   // et.ga.lv_433 nl.lg.ht_432  mt.cy.un_870 sv.gd.af_432
  0x0b2d18a0, 0x5302080c, 0x090a05a0, 0x0c211ca0,   // ga.sk.es_322 no.da.ht_543  fr.pt.pl_322 id.jw.sv_322
  0x276b1a04, 0x060f64ee, 0x3f1210af, 0x55121104,   // tl.ceb.gd_332 lg.lv.de_422  lt.hu.af_655 ro.hu.rw_332
  // [b910]
  0x55002a14, 0x535264ee, 0x1819110c, 0x07041955,   // mt.rw.un_660 lg.ha.ht_422  ro.gl.ga_543 gl.fi.it_442
  0x07101155, 0x2d0d11af, 0x071105ee, 0x0d122d60,   // ro.be.bg_442 ro.cs.sk_655  fr.ro.it_422 sk.hu.cs_664
  0x311011a0, 0x1b4a1107, 0x55006812, 0x192d120d,   // ro.lt.az_322 ro.yo.tr_432  ig.rw.un_640 hu.sk.gl_554
  0x356e2b05, 0x130e1f08, 0x0e6b1aa0, 0x6b001e22,   // vi.hmn.zu_333 cy.is.et_443  tl.ceb.is_322 ms.ceb.un_870
  // [b920]
  0x0d0e1704, 0x286852a7, 0x0b0764a4, 0x1c282008,   // sr.is.cs_332 ha.ig.sw_532  lg.it.es_433 sq.sw.id_443
  0x2a1f25af, 0x55073507, 0x4a35280c, 0x2b006407,   // eu.cy.mt_655 zu.it.rw_432  sw.zu.yo_543 lg.vi.un_420
  0x1e104aee, 0x2b005202, 0x31281ca4, 0x32002a0d,   // yo.lt.ms_422 ha.vi.un_220  id.sw.az_433 mt.bs.un_540
  0x012711a0, 0x0a091107, 0x050753ec, 0x521c6808,   // ro.gd.en_322 ro.pl.pt_432  ht.it.fr_644 ig.id.ha_443
  // [b930]
  0x2b530f05, 0x120c35a0, 0x55001319, 0x350e0c0e,   // lv.ht.vi_333 zu.sv.hu_322  et.rw.un_750 sv.is.zu_555
  0x3f00520c, 0x0e556407, 0x216455a0, 0x6423250c,   // ha.af.un_530 lg.rw.is_432  rw.lg.jw_322 eu.ca.lg_543
  0x072053a7, 0x1964550c, 0x070e53ad, 0x042a10ec,   // ht.sq.it_532 rw.lg.gl_543  ht.is.it_643 lt.mt.fi_644
  0x355364ec, 0x53122107, 0x09030404, 0x2d100f08,   // lg.ht.zu_644 jw.hu.ht_432  fi.nl.pl_332 lv.lt.sk_443
  // [b940]
  0x09102d12, 0x09644aa7, 0x091f6809, 0x25033fa0,   // sk.lt.pl_654 yo.lg.pl_532  ig.cy.pl_444 af.nl.eu_322
  0x3f4a6808, 0x1f00642a, 0x21003f22, 0x5500091b,   // ig.yo.af_443 lg.cy.un_970  af.jw.un_870 pl.rw.un_770
  0x09525512, 0x100f2d07, 0x065355ad, 0x1028160c,   // rw.ha.pl_654 sk.lv.lt_432  rw.ht.de_643 hr.sw.lt_543
  0x32101707, 0x0628680c, 0x2a132807, 0x280a5207,   // sr.lt.bs_432 ig.sw.de_543  sw.et.mt_432 ha.pt.sw_432
  // [b950]
  0x6b000418, 0x04002511, 0x1000130e, 0x276b04ee,   // fi.ceb.un_740 eu.fi.un_630  et.lt.un_550 fi.ceb.gd_422
  0x550f4a55, 0x32172805, 0x193b235a, 0x100f0707,   // yo.lv.rw_442 sw.sr.bs_333  ca.so.gl_553 it.lv.lt_432
  0x4a2125a7, 0x101701a0, 0x23193b07, 0x1c070107,   // eu.jw.yo_532 en.sr.lt_322  so.gl.ca_432 en.it.id_432
  0x6b1e1a05, 0x03042802, 0x03353fa4, 0x1655685a,   // tl.ms.ceb_333 sw.fi.nl_222  af.zu.nl_433 ig.rw.hr_553
  // [b960]
  0x09160804, 0x2d120c04, 0x1b0a25ac, 0x4a1b310c,   // no.hr.pl_332 sv.hu.sk_332  eu.pt.tr_632 az.tr.yo_543
  0x3b2a19ec, 0x06032a0c, 0x0b0a2da0, 0x252d0d08,   // gl.mt.so_644 mt.nl.de_543  sk.pt.es_322 cs.sk.eu_443
  0x29112704, 0x1c002902, 0x550a5355, 0x05001e04,   // gd.ro.sl_332 sl.id.un_220  ht.pt.rw_442 ms.fr.un_320
  0x2505110c, 0x05182507, 0x0d321702, 0x52201ba7,   // ro.fr.eu_543 eu.ga.fr_432  sr.bs.cs_222 tr.sq.ha_532
  // [b970]
  0x352d0ca4, 0x1b000e22, 0x321b0e13, 0x28126eee,   // sv.sk.zu_433 is.tr.un_870  is.tr.bs_665 hmn.hu.sw_422
  0x645368a4, 0x07010504, 0x232d18a0, 0x28236407,   // ig.ht.lg_433 fr.en.it_332  ga.sk.ca_322 lg.ca.sw_432
  0x13001f0c, 0x03120f0b, 0x1312060c, 0x283f03a0,   // cy.et.un_530 lv.hu.nl_542  de.hu.et_543 nl.af.sw_322
  0x3f280308, 0x25286bee, 0x06100f07, 0x10643555,   // nl.sw.af_443 ceb.sw.eu_422  lv.lt.de_432 zu.lg.lt_442
  // [b980]
  0x211353a0, 0x0603050b, 0x040e0804, 0x25280304,   // ht.et.jw_322 fr.nl.de_542  no.is.fi_332 nl.sw.eu_332
  0x13520455, 0x200429ee, 0x04522107, 0x1f2710a4,   // fi.ha.et_442 sl.fi.sq_422  jw.ha.fi_432 lt.gd.cy_433
  0x1309040e, 0x0f190a08, 0x2a0e08ad, 0x3b321ba0,   // fi.pl.et_555 pt.gl.lv_443  no.is.mt_643 tr.bs.so_322
  0x10060c04, 0x29210aee, 0x0c02090c, 0x0c00550c,   // sv.de.lt_332 pt.jw.sl_422  pl.da.sv_543 rw.sv.un_530
  // [b990]
  0x3b1a2aa0, 0x0f1005a4, 0x0f1810a9, 0x031a2805,   // mt.tl.so_322 fr.lt.lv_433  lt.ga.lv_544 sw.tl.nl_333
  0x28353fee, 0x2a1e1c09, 0x131004a7, 0x033f290c,   // af.zu.sw_422 id.ms.mt_444  fi.lt.et_532 sl.af.nl_543
  0x191023ad, 0x1b1a18a0, 0x1a686404, 0x6435680c,   // ca.lt.gl_643 ga.tl.tr_322  lg.ig.tl_332 ig.zu.lg_543
  0x681c1eac, 0x0c205260, 0x55093555, 0x270468a4,   // ms.id.ig_632 ha.sq.sv_664  zu.pl.rw_442 ig.fi.gd_433
  // [b9a0]
  0x1b25550c, 0x18201b12, 0x0e0c08a7, 0x2a0c200c,   // rw.eu.tr_543 tr.sq.ga_654  no.sv.is_532 sq.sv.mt_543
  0x35002114, 0x0c1808ac, 0x2d002512, 0x1e1a0302,   // jw.zu.un_660 no.ga.sv_632  eu.sk.un_640 nl.tl.ms_222
  0x684a250c, 0x556e6404, 0x1e28520c, 0x18235207,   // eu.yo.ig_543 lg.hmn.rw_332  ha.sw.ms_543 ha.ca.ga_432
  0x53084a05, 0x1e1c2aa4, 0x0c3b3111, 0x354a2107,   // yo.no.ht_333 mt.id.ms_433  az.so.sv_653 jw.yo.zu_432
  // [b9b0]
  0x1e1a1f07, 0x0e0c0813, 0x3f002802, 0x0b000804,   // cy.tl.ms_432 no.sv.is_665  sw.af.un_220 no.es.un_320
  0x080e100d, 0x10203504, 0x2321200c, 0x2164200b,   // lt.is.no_554 zu.sq.lt_332  sq.jw.ca_543 sq.lg.jw_542
  0x08000721, 0x550c085a, 0x200c02a0, 0x311a1b5a,   // bg.uk.un_860 no.sv.rw_553  da.sv.sq_322 tr.tl.az_553
  0x190a1fa0, 0x311b3bec, 0x35281e07, 0x641a1e0c,   // cy.pt.gl_322 so.tr.az_644  ms.sw.zu_432 ms.tl.lg_543
  // [b9c0]
  0x131c21ad, 0x0e001a14, 0x35311b14, 0x1b353ba9,   // jw.id.et_643 tl.is.un_660  tr.az.zu_666 so.zu.tr_544
  0x214a5507, 0x6b2035a0, 0x112b07ee, 0x353155ec,   // rw.yo.jw_432 zu.sq.ceb_322  it.vi.ro_422 rw.az.zu_644
  0x4a553ba4, 0x03070609, 0x121e3513, 0x20111bad,   // so.rw.yo_433 de.it.nl_444  zu.ms.hu_665 tr.ro.sq_643
  0x3b1b1ea7, 0x281a640c, 0x311b5304, 0x281c1e0c,   // ms.tr.so_532 lg.tl.sw_543  ht.tr.az_332 ms.id.sw_543
  // [b9d0]
  0x091f6404, 0x3b1b5504, 0x553b1b09, 0x4a3f68a4,   // lg.cy.pl_332 rw.tr.so_332  tr.so.rw_444 ig.af.yo_433
  0x3b1b5507, 0x0b1221ee, 0x532868ad, 0x1f130807,   // rw.tr.so_432 jw.hu.es_422  ig.sw.ht_643 no.et.cy_432
  0x521b6e07, 0x2a001c0d, 0x31202a07, 0x013b2ba7,   // hmn.tr.ha_432 id.mt.un_540  mt.sq.az_432 vi.so.en_532
  0x0a006e1b, 0x1b041307, 0x64000708, 0x0c11680c,   // hmn.pt.un_770 et.fi.tr_432  it.lg.un_430 ig.ro.sv_543
  // [b9e0]
  0x352520ad, 0x3b0f1a04, 0x1f23115a, 0x08001e02,   // sq.eu.zu_643 tl.lv.so_332  ro.ca.cy_553 ms.no.un_220
  0x6b2518ee, 0x11082307, 0x25081f11, 0x0f0912af,   // ga.eu.ceb_422 ca.no.ro_432  cy.no.eu_653 hu.pl.lv_655
  0x05122da0, 0x2b316e07, 0x0b0a0805, 0x12050a0e,   // sk.hu.fr_322 hmn.az.vi_432  no.pt.es_333 pt.fr.hu_555
  0x5535285a, 0x1e6e1faf, 0x1335530c, 0x13041608,   // sw.zu.rw_553 cy.hmn.ms_655  ht.zu.et_543 hr.fi.et_443
  // [b9f0]
  0x020a07a0, 0x2d212b12, 0x231911ee, 0x52321705,   // it.pt.da_322 vi.jw.sk_654  ro.gl.ca_422 sr.bs.ha_333
  0x083b3f04, 0x08003b12, 0x3f2821ad, 0x322925ad,   // af.so.no_332 so.no.un_640  jw.sw.af_643 eu.sl.bs_643
  0x3f6455a4, 0x5508640c, 0x284a10a6, 0x080e12a9,   // rw.lg.af_433 lg.no.rw_543  lt.yo.sw_521 hu.is.no_544
  0x32002507, 0x1a3f6ba0, 0x645328a7, 0x64255504,   // eu.bs.un_420 ceb.af.tl_322  sw.ht.lg_532 rw.eu.lg_332
  // [ba00]
  0x292508ee, 0x0d006b0c, 0x3f00121b, 0x093f04ee,   // no.eu.sl_422 ceb.cs.un_530  hu.af.un_770 fi.af.pl_422
  0x02001a02, 0x351a1c04, 0x55523b04, 0x1a535207,   // tl.da.un_220 id.tl.zu_332  so.ha.rw_332 ha.ht.tl_432
  0x1c213f12, 0x31355207, 0x17092905, 0x12292104,   // af.jw.id_654 ha.zu.az_432  sl.pl.sr_333 jw.sl.hu_332
  0x21130f07, 0x283564ec, 0x25001f12, 0x320d1f04,   // lv.et.jw_432 lg.zu.sw_644  cy.eu.un_640 cy.cs.bs_332
  // [ba10]
  0x4a5253a0, 0x18311ba9, 0x3b2a1207, 0x180a3107,   // ht.ha.yo_322 tr.az.ga_544  hu.mt.so_432 az.pt.ga_432
  0x1e005212, 0x1f530504, 0x35003b20, 0x1a1f6b04,   // ha.ms.un_640 fr.ht.cy_332  so.zu.un_850 ceb.cy.tl_332
  0x0d5304ad, 0x090d2da7, 0x102509ee, 0x3f090409,   // fi.ht.cs_643 sk.cs.pl_532  pl.eu.lt_422 fi.pl.af_444
  0x1f3b0702, 0x55122105, 0x353b2104, 0x3500532a,   // it.so.cy_222 jw.hu.rw_333  jw.so.zu_332 ht.zu.un_970
  // [ba20]
  0x1006090b, 0x1e1c2bee, 0x1c201eaf, 0x1c111e04,   // pl.de.lt_542 vi.id.ms_422  ms.sq.id_655 ms.ro.id_332
  0x3f1105a7, 0x08072a02, 0x53280504, 0x1f002519,   // fr.ro.af_532 mt.it.no_222  fr.sw.ht_332 eu.cy.un_750
  0x280a20a6, 0x271b18af, 0x04093f0c, 0x29002a0d,   // sq.pt.sw_521 ga.tr.gd_655  af.pl.fi_543 mt.sl.un_540
  0x0100071b, 0x063b0107, 0x181f53a0, 0x191b0a07,   // it.en.un_770 en.so.de_432  ht.cy.ga_322 pt.tr.gl_432
  // [ba30]
  0x0500681b, 0x1b190a04, 0x06003520, 0x0a2320ad,   // ig.fr.un_770 pt.gl.tr_332  zu.de.un_850 sq.ca.pt_643
  0x53020807, 0x07011ea0, 0x030727a0, 0x52005509,   // no.da.ht_432 ms.en.it_322  gd.it.nl_322 rw.ha.un_440
  0x1c0405a0, 0x2a0c0e07, 0x1f000d0d, 0x1c526807,   // fr.fi.id_322 is.sv.mt_432  cs.cy.un_540 ig.ha.id_432
  0x0500020b, 0x1a040104, 0x292d1f08, 0x210e12a4,   // da.fr.un_520 en.fi.tl_332  cy.sk.sl_443 hu.is.jw_433
  // [ba40]
  0x35074a07, 0x291c2104, 0x034a6407, 0x11074a12,   // yo.it.zu_432 jw.id.sl_332  lg.yo.nl_432 yo.it.ro_654
  0x2d091605, 0x1a1053a0, 0x1c0413a6, 0x19080c11,   // hr.pl.sk_333 ht.lt.tl_322  et.fi.id_521 sv.no.gl_653
  0x53110707, 0x17041055, 0x181f3b02, 0x01313ba0,   // it.ro.ht_432 be.ru.sr_442  so.cy.ga_222 so.az.en_322
  0x2a003b2a, 0x2a3f03ec, 0x072b01ee, 0x1900100c,   // so.mt.un_970 nl.af.mt_644  en.vi.it_422 lt.gl.un_530
  // [ba50]
  0x2800160e, 0x0c0e0b0c, 0x02005319, 0x0e0a23a0,   // hr.sw.un_550 es.is.sv_543  ht.da.un_750 ca.pt.is_322
  0x28216407, 0x18015304, 0x1a2a53a7, 0x3f090407,   // lg.jw.sw_432 ht.en.ga_332  ht.mt.tl_532 fi.pl.af_432
  0x3f280f0c, 0x16006405, 0x0a072da4, 0x29071fee,   // lv.sw.af_543 lg.hr.un_330  sk.it.pt_433 cy.it.sl_422
  0x531e1c55, 0x092804a4, 0x6e2a53af, 0x0413350c,   // id.ms.ht_442 fi.sw.pl_433  ht.mt.hmn_655 zu.et.fi_543
  // [ba60]
  0x2a290daf, 0x530f0cad, 0x2a072704, 0x35002a0c,   // cs.sl.mt_655 sv.lv.ht_643  gd.it.mt_332 mt.zu.un_530
  0x3f6803a4, 0x050c0909, 0x0b0a3ba0, 0x02002308,   // nl.ig.af_433 pl.sv.fr_444  so.pt.es_322 ca.da.un_430
  0x253b6407, 0x0900061b, 0x121604ad, 0x032a09ec,   // lg.so.eu_432 de.pl.un_770  fi.hr.hu_643 pl.mt.nl_644
  0x292a0713, 0x35002111, 0x646b1a11, 0x2a1007a4,   // it.mt.sl_665 jw.zu.un_630  tl.ceb.lg_653 it.lt.mt_433
  // [ba70]
  0x2d00081a, 0x09550fa4, 0x090f06af, 0x1c1921ee,   // no.sk.un_760 lv.rw.pl_433  de.lv.pl_655 jw.gl.id_422
  0x07100fa0, 0x181f1ca9, 0x27001a0d, 0x6b1a2112,   // lv.lt.it_322 id.cy.ga_544  tl.gd.un_540 jw.tl.ceb_654
  0x35134a07, 0x21275505, 0x131b35ee, 0x0c2d0dad,   // yo.et.zu_432 rw.gd.jw_333  zu.tr.et_422 cs.sk.sv_643
  0x230f1807, 0x2a050eaf, 0x281255ee, 0x1b522113,   // ga.lv.ca_432 is.fr.mt_655  rw.hu.sw_422 jw.ha.tr_665
  // [ba80]
  0x5300040c, 0x061308a0, 0x041801a9, 0x04100f08,   // fi.ht.un_530 no.et.de_322  en.ga.fi_544 lv.lt.fi_443
  0x120820ee, 0x080c3b55, 0x27000b13, 0x4a212007,   // sq.no.hu_422 so.sv.no_442  es.gd.un_650 sq.jw.yo_432
  0x52641a0c, 0x311e3b04, 0x4a131b12, 0x28202d04,   // tl.lg.ha_543 so.ms.az_332  tr.et.yo_654 sk.sq.sw_332
  0x0e002913, 0x182d0107, 0x68033f0b, 0x2b001a22,   // sl.is.un_650 en.sk.ga_432  af.nl.ig_542 tl.vi.un_870
  // [ba90]
  0x322010a7, 0x202801a0, 0x052b010c, 0x6b6e2b07,   // lt.sq.bs_532 en.sw.sq_322  en.vi.fr_543 vi.hmn.ceb_432
  0x1a002b12, 0x1f531e0c, 0x2b0d13a7, 0x320701a4,   // vi.tl.un_640 ms.ht.cy_543  et.cs.vi_532 en.it.bs_433
  0x13070305, 0x132b210b, 0x214a13a6, 0x073f19a7,   // nl.it.et_333 jw.vi.et_542  et.yo.jw_521 gl.af.it_532
  0x071e1aee, 0x1635680c, 0x070d5305, 0x3f6421a4,   // tl.ms.it_422 ig.zu.hr_543  ht.cs.it_333 jw.lg.af_433
  // [baa0]
  0x35194a0b, 0x4a1b20ee, 0x11321604, 0x0f002a12,   // yo.gl.zu_542 sq.tr.yo_422  hr.bs.ro_332 mt.lv.un_640
  0x13071904, 0x0f072aa4, 0x553b6ba4, 0x64553f07,   // gl.it.et_332 mt.it.lv_433  ceb.so.rw_433 af.rw.lg_432
  0x641311a4, 0x190a2005, 0x19680d07, 0x2a003f12,   // ro.et.lg_433 sq.pt.gl_333  cs.ig.gl_432 af.mt.un_640
  0x131135a4, 0x0d000e0b, 0x3f4a0313, 0x21204aa6,   // zu.ro.et_433 is.cs.un_520  nl.yo.af_665 yo.sq.jw_521
  // [bab0]
  0x11006409, 0x183b6804, 0x133b2813, 0x6800282a,   // lg.ro.un_440 ig.so.ga_332  sw.so.et_665 sw.ig.un_970
  0x042d0fa4, 0x2a003f21, 0x68552804, 0x12680107,   // lv.sk.fi_433 af.mt.un_860  sw.rw.ig_332 en.ig.hu_432
  0x0b3f10a4, 0x68002305, 0x061225ee, 0x4a002d02,   // lt.af.es_433 ca.ig.un_330  eu.hu.de_422 sk.yo.un_220
  0x283b27a0, 0x23051aa4, 0x122a1fee, 0x0f100455,   // gd.so.sw_322 tl.fr.ca_433  cy.mt.hu_422 fi.lt.lv_442
  // [bac0]
  0x551052a4, 0x111a01a0, 0x021f080c, 0x091011a7,   // ha.lt.rw_433 en.tl.ro_322  no.cy.da_543 ro.lt.pl_532
  0x3b0413a0, 0x211e1aa7, 0x12111905, 0x1a3b110c,   // et.fi.so_322 tl.ms.jw_532  gl.ro.hu_333 ro.so.tl_543
  0x29520c04, 0x16323b0c, 0x0b0519ee, 0x3b042807,   // sv.ha.sl_332 so.bs.hr_543  gl.fr.es_422 sw.fi.so_432
  0x0a005504, 0x0a000f0c, 0x27211aee, 0x0c060813,   // rw.pt.un_320 lv.pt.un_530  tl.jw.gd_422 no.de.sv_665
  // [bad0]
  0x11000b1b, 0x080e520b, 0x111908ee, 0x1b230cee,   // es.ro.un_770 ha.is.no_542  no.gl.ro_422 sv.ca.tr_422
  0x4a3b64ad, 0x19002002, 0x130e1704, 0x044a35a0,   // lg.so.yo_643 sq.gl.un_220  sr.is.et_332 zu.yo.fi_322
  0x13001609, 0x53162913, 0x126b52a0, 0x00001615,   // hr.et.un_440 sl.hr.ht_665  ha.ceb.hu_322 hr.un.un_700
  0x1e1c21a7, 0x0b0a13ee, 0x32001b05, 0x310f1207,   // jw.id.ms_532 et.pt.es_422  tr.bs.un_330 hu.lv.az_432
  // [bae0]
  0x132512ee, 0x030a0104, 0x190711a0, 0x021206ad,   // hu.eu.et_422 en.pt.nl_332  ro.it.gl_322 de.hu.da_643
  0x2b2d0d55, 0x0b003f04, 0x6b355507, 0x3216230c,   // cs.sk.vi_442 af.es.un_320  rw.zu.ceb_432 ca.hr.bs_543
  0x283b1ead, 0x27051b0c, 0x040e2d07, 0x2a2007ec,   // ms.so.sw_643 tr.fr.gd_543  sk.is.fi_432 it.sq.mt_644
  0x64011aa4, 0x2a121f0c, 0x53271808, 0x28101112,   // tl.en.lg_433 cy.hu.mt_543  ga.gd.ht_443 ro.lt.sw_654
  // [baf0]
  0x55006e08, 0x206b1a0c, 0x1b041f08, 0x06121fa7,   // hmn.rw.un_430 tl.ceb.sq_543  cy.fi.tr_443 cy.hu.de_532
  0x3f06040c, 0x20006b12, 0x040908af, 0x6468355a,   // fi.de.af_543 ceb.sq.un_640  no.pl.fi_655 zu.ig.lg_553
  0x12003519, 0x1e1c68a0, 0x0c532008, 0x19250bec,   // zu.hu.un_750 ig.id.ms_322  sq.ht.sv_443 es.eu.gl_644
  0x4a0253a4, 0x52283b0c, 0x2500231a, 0x2b64050b,   // ht.da.yo_433 so.sw.ha_543  ca.eu.un_760 fr.lg.vi_542
  // [bb00]
  0x0c000702, 0x0b006b08, 0x3f641f07, 0x681828af,   // it.sv.un_220 ceb.es.un_430  cy.lg.af_432 sw.ga.ig_655
  0x641a1fa0, 0x04060805, 0x0e3f02ad, 0x2d041f0c,   // cy.tl.lg_322 no.de.fi_333  da.af.is_643 cy.fi.sk_543
  0x0d6b1aec, 0x03061207, 0x281235ad, 0x091310ee,   // tl.ceb.cs_644 hu.de.nl_432  zu.hu.sw_643 lt.et.pl_422
  0x1a212004, 0x131a6b08, 0x551b280c, 0x211a28ad,   // sq.jw.tl_332 ceb.tl.et_443  sw.tr.rw_543 sw.tl.jw_643
  // [bb10]
  0x1b006407, 0x186b27ec, 0x0720215a, 0x10181f05,   // lg.tr.un_420 gd.ceb.ga_644  jw.sq.it_553 cy.ga.lt_333
  0x535201a4, 0x551b350c, 0x6b683b0c, 0x05032aee,   // en.ha.ht_433 zu.tr.rw_543  so.ig.ceb_543 mt.nl.fr_422
  0x211f1a04, 0x53000418, 0x172d1007, 0x090b190c,   // tl.cy.jw_332 fi.ht.un_740  lt.sk.sr_432 gl.es.pl_543
  0x0b004a0d, 0x6b641ca4, 0x6b521a14, 0x0b20050d,   // yo.es.un_540 id.lg.ceb_433  tl.ha.ceb_666 fr.sq.es_554
  // [bb20]
  0x20000527, 0x042528ec, 0x1000640c, 0x10006805,   // fr.sq.un_940 sw.eu.fi_644  lg.lt.un_530 ig.lt.un_330
  0x2a213fad, 0x033f1805, 0x53106ba0, 0x2d2955a0,   // af.jw.mt_643 ga.af.nl_333  ceb.lt.ht_322 rw.sl.sk_322
  0x35041004, 0x04000520, 0x16101704, 0x3f6b1aa0,   // lt.fi.zu_332 fr.fi.un_850  sr.lt.hr_332 tl.ceb.af_322
  0x081f3f08, 0x0410250c, 0x25286807, 0x02080c12,   // af.cy.no_443 eu.lt.fi_543  ig.sw.eu_432 sv.no.da_654
  // [bb30]
  0x0f3510a4, 0x211c6411, 0x10530f07, 0x18520107,   // lt.zu.lv_433 lg.id.jw_653  lv.ht.lt_432 en.ha.ga_432
  0x080e020b, 0x3b4a53ac, 0x3b682008, 0x21290d07,   // da.is.no_542 ht.yo.so_632  sq.ig.so_443 cs.sl.jw_432
  0x01001204, 0x3f121a55, 0x27311ea4, 0x3b2852ec,   // hu.en.un_320 tl.hu.af_442  ms.az.gd_433 ha.sw.so_644
  0x28350605, 0x643208ee, 0x282523a4, 0x0b030ca4,   // de.zu.sw_333 no.bs.lg_422  ca.eu.sw_433 sv.nl.es_433
  // [bb40]
  0x21646b08, 0x283b4a08, 0x64003f13, 0x3b6801ee,   // ceb.lg.jw_443 yo.so.sw_443  af.lg.un_650 en.ig.so_422
  0x4a6b1ba4, 0x090802ee, 0x032535ee, 0x352d290c,   // tr.ceb.yo_433 da.no.pl_422  zu.eu.nl_422 sl.sk.zu_543
  0x17160905, 0x281a07a9, 0x1c6b1a04, 0x103f030c,   // pl.hr.sr_333 it.tl.sw_544  tl.ceb.id_332 nl.af.lt_543
  0x0b0723ec, 0x1e00130c, 0x3f08030d, 0x53081907,   // ca.it.es_644 et.ms.un_530  nl.no.af_554 gl.no.ht_432
  // [bb50]
  0x0f00251b, 0x040b1313, 0x172910a6, 0x12080aa7,   // eu.lv.un_770 et.es.fi_665  lt.sl.sr_521 pt.no.hu_532
  0x1c000807, 0x07352da4, 0x11122908, 0x04021ba0,   // no.id.un_420 sk.zu.it_433  sl.hu.ro_443 tr.da.fi_322
  0x04002a1b, 0x1a092811, 0x32281a0c, 0x3100350e,   // mt.fi.un_770 sw.pl.tl_653  tl.sw.bs_543 zu.az.un_550
  0x0d1a5305, 0x2a004a08, 0x0b120508, 0x0f102d02,   // ht.tl.cs_333 yo.mt.un_430  fr.hu.es_443 sk.lt.lv_222
  // [bb60]
  0x0d2a076c, 0x00001242, 0x4a643bad, 0x1e002a0b,   // it.mt.cs_873 ur.un.un_C00  so.lg.yo_643 mt.ms.un_520
  0x3f643ba6, 0x684a3baf, 0x20536ba9, 0x18000f19,   // so.lg.af_521 so.yo.ig_655  ceb.ht.sq_544 lv.ga.un_750
  0x111f2512, 0x066b1ca4, 0x0b001a08, 0x0c6b01a0,   // eu.cy.ro_654 id.ceb.de_433  tl.es.un_430 en.ceb.sv_322
  0x06001a0d, 0x1e003b0b, 0x4a53520c, 0x123b0107,   // tl.de.un_540 so.ms.un_520  ha.ht.yo_543 en.so.hu_432
  // [bb70]
  0x04121aa0, 0x52530107, 0x1a536baf, 0x1204060c,   // tl.hu.fi_322 en.ht.ha_432  ceb.ht.tl_655 de.fi.hu_543
  0x55000112, 0x03023fa7, 0x0e53010c, 0x1b233109,   // en.rw.un_640 af.da.nl_532  en.ht.is_543 az.ca.tr_444
  0x136828ad, 0x28080c12, 0x0a230705, 0x21641709,   // sw.ig.et_643 sv.no.sw_654  it.ca.pt_333 sr.lg.jw_444
  0x52356809, 0x01003202, 0x250f0107, 0x170d2da0,   // ig.zu.ha_444 bs.en.un_220  en.lv.eu_432 sk.cs.sr_322
  // [bb80]
  0x6b002822, 0x251001a0, 0x2a285504, 0x2d280713,   // sw.ceb.un_870 en.lt.eu_322  rw.sw.mt_332 it.sw.sk_665
  0x2a1628ee, 0x280306a7, 0x2a071312, 0x07006809,   // sw.hr.mt_422 de.nl.sw_532  et.it.mt_654 ig.it.un_440
  0x190b0109, 0x320f2907, 0x1c000a02, 0x032a2d02,   // en.es.gl_444 sl.lv.bs_432  pt.id.un_220 sk.mt.nl_222
  0x130419a7, 0x04072a12, 0x030f08a4, 0x03100f08,   // gl.fi.et_532 mt.it.fi_654  no.lv.nl_433 lv.lt.nl_443
  // [bb90]
  0x211219a0, 0x29000d02, 0x04102da0, 0x0d2908a7,   // gl.hu.jw_322 cs.sl.un_220  sk.lt.fi_322 no.sl.cs_532
  0x3229160e, 0x0d190ba4, 0x20001312, 0x0d352da9,   // hr.sl.bs_555 es.gl.cs_433  et.sq.un_640 sk.zu.cs_544
  0x4a1c1eec, 0x52215305, 0x0b181907, 0x551b040c,   // ms.id.yo_644 ht.jw.ha_333  gl.ga.es_432 fi.tr.rw_543
  0x21081ca0, 0x041c4aa4, 0x2908020d, 0x13002113,   // id.no.jw_322 yo.id.fi_433  da.no.sl_554 jw.et.un_650
  // [bba0]
  0x0e643fa0, 0x13046ba4, 0x4a550408, 0x082555a4,   // af.lg.is_322 ceb.fi.et_433  fi.rw.yo_443 rw.eu.no_433
  0x55532105, 0x17080c0e, 0x16080ca4, 0x09001702,   // jw.ht.rw_333 sv.no.sr_555  sv.no.hr_433 sr.pl.un_220
  0x013552a0, 0x170a1055, 0x200325ec, 0x0e002b09,   // ha.zu.en_322 be.mk.sr_442  eu.nl.sq_644 vi.is.un_440
  0x280121a7, 0x050f0714, 0x03202108, 0x2a0c08a9,   // jw.en.sw_532 it.lv.fr_666  jw.sq.nl_443 no.sv.mt_544
  // [bbb0]
  0x133f21a4, 0x1c2921af, 0x10040aa0, 0x321a6ba0,   // jw.af.et_433 jw.sl.id_655  mk.ru.be_322 ceb.tl.bs_322
  0x231c210c, 0x080c0307, 0x01522807, 0x1a2b1c07,   // jw.id.ca_543 nl.sv.no_432  sw.ha.en_432 id.vi.tl_432
  0x5229010c, 0x2b211aec, 0x12022704, 0x1e000308,   // en.sl.ha_543 tl.jw.vi_644  gd.da.hu_332 nl.ms.un_430
  0x2b1a01a0, 0x0700121a, 0x6b6e2bad, 0x2835550e,   // en.tl.vi_322 hu.it.un_760  vi.hmn.ceb_643 rw.zu.sw_555
  // [bbc0]
  0x52000309, 0x10290fee, 0x110a0760, 0x1c212b0d,   // nl.ha.un_440 lv.sl.lt_422  bg.mk.ro_664 vi.jw.id_554
  0x27000713, 0x6e3f2b08, 0x1a522ba7, 0x043228a0,   // it.gd.un_650 vi.af.hmn_443  vi.ha.tl_532 sw.bs.fi_322
  0x280f64a4, 0x101764ee, 0x05003f0b, 0x52284aee,   // lg.lv.sw_433 lg.sr.lt_422  af.fr.un_520 yo.sw.ha_422
  0x2d032007, 0x550e2804, 0x28106408, 0x52283b07,   // sq.nl.sk_432 sw.is.rw_332  lg.lt.sw_443 so.sw.ha_432
  // [bbd0]
  0x120a180b, 0x642831af, 0x522701a0, 0x0a042704,   // ga.pt.hu_542 az.sw.lg_655  en.gd.ha_322 gd.fi.pt_332
  0x023f08a0, 0x09001b08, 0x25182702, 0x21002320,   // no.af.da_322 tr.pl.un_430  gd.ga.eu_222 ca.jw.un_850
  0x112901a4, 0x102304a7, 0x52091f04, 0x31121bad,   // en.sl.ro_433 fi.ca.lt_532  cy.pl.ha_332 tr.hu.az_643
  0x23100408, 0x28522055, 0x281309ee, 0x1b013fad,   // fi.lt.ca_443 sq.ha.sw_442  pl.et.sw_422 af.en.tr_643
  // [bbe0]
  0x12321604, 0x06180807, 0x32160405, 0x20080408,   // hr.bs.hu_332 no.ga.de_432  fi.hr.bs_333 fi.no.sq_443
  0x1b1007ee, 0x0e2820ac, 0x200812ad, 0x081a6b07,   // it.lt.tr_422 sq.sw.is_632  hu.no.sq_643 ceb.tl.no_432
  0x641e2104, 0x251e64a0, 0x313b280d, 0x32161214,   // jw.ms.lg_332 lg.ms.eu_322  sw.so.az_554 hu.hr.bs_666
  0x0500190b, 0x321620a4, 0x120408a0, 0x3216130c,   // gl.fr.un_520 sq.hr.bs_433  no.fi.hu_322 et.hr.bs_543
  // [bbf0]
  0x043f0809, 0x321731a0, 0x0c350202, 0x112005af,   // no.af.fi_444 az.sr.bs_322  da.zu.sv_222 fr.sq.ro_655
  0x02001e04, 0x1c1a21a4, 0x03353f0d, 0x52320dee,   // ms.da.un_320 jw.tl.id_433  af.zu.nl_554 cs.bs.ha_422
  0x6800530e, 0x0b0d01a4, 0x25190a11, 0x52000d21,   // ht.ig.un_550 en.cs.es_433  pt.gl.eu_653 cs.ha.un_860
  0x1c3b2112, 0x19520dee, 0x320b1907, 0x55290dad,   // jw.so.id_654 cs.ha.gl_422  gl.es.bs_432 cs.sl.rw_643

  // [bc00]
  0x092a3507, 0x525535a0, 0x0b0a1f05, 0x350705af,   // zu.mt.pl_432 zu.rw.ha_322  cy.pt.es_333 fr.it.zu_655
  0x28354a12, 0x0b001f04, 0x06083f08, 0x083f2302,   // yo.zu.sw_654 cy.es.un_320  af.no.de_443 ca.af.no_222
  0x07320dee, 0x324a35ee, 0x4a001f12, 0x09520da7,   // cs.bs.it_422 zu.yo.bs_422  cy.yo.un_640 cs.ha.pl_532
  0x0d4a3202, 0x21000f0c, 0x522105ee, 0x210f6807,   // bs.yo.cs_222 lv.jw.un_530  fr.jw.ha_422 ig.lv.jw_432
  // [bc10]
  0x32352855, 0x3b52350c, 0x100817ec, 0x230729a0,   // sw.zu.bs_442 zu.ha.so_543  sr.uk.be_644 sl.it.ca_322
  0x20000c18, 0x53352811, 0x120b0ea0, 0x160d3ba6,   // sv.sq.un_740 sw.zu.ht_653  is.es.hu_322 so.cs.hr_521
  0x0b190aee, 0x253f06ec, 0x13121104, 0x12001321,   // pt.gl.es_422 de.af.eu_644  ro.hu.et_332 et.hu.un_860
  0x04171002, 0x120208a9, 0x320d0fac, 0x17000905,   // be.sr.ru_222 no.da.hu_544  lv.cs.bs_632 pl.sr.un_330
  // [bc20]
  0x09122da0, 0x250831a4, 0x021f3504, 0x21281c5a,   // sk.hu.pl_322 az.no.eu_433  zu.cy.da_332 id.sw.jw_553
  0x162a1ea4, 0x0f3202a9, 0x0300550d, 0x04060c08,   // ms.mt.hr_433 da.bs.lv_544  rw.nl.un_540 sv.de.fi_443
  0x686428af, 0x55044a09, 0x136455a0, 0x02123f08,   // sw.lg.ig_655 yo.fi.rw_444  rw.lg.et_322 af.hu.da_443
  0x121906ad, 0x09291713, 0x2529100c, 0x353153ad,   // de.gl.hu_643 sr.sl.pl_665  lt.sl.eu_543 ht.az.zu_643
  // [bc30]
  0x16020807, 0x0804020c, 0x4a6b64a0, 0x2a13255a,   // no.da.hr_432 da.fi.no_543  lg.ceb.yo_322 eu.et.mt_553
  0x23002814, 0x31292d11, 0x122523a4, 0x31292d09,   // sw.ca.un_660 sk.sl.az_653  ca.eu.hu_433 sk.sl.az_444
  0x1e003102, 0x312d2913, 0x10044a04, 0x0a232555,   // az.ms.un_220 sl.sk.az_665  yo.fi.lt_332 eu.ca.pt_442
  0x100f020b, 0x0a002d10, 0x0e2a23ec, 0x0e1208a0,   // da.lv.lt_542 sk.pt.un_620  ca.mt.is_644 no.hu.is_322
  // [bc40]
  0x29312d13, 0x316e2da6, 0x1306250c, 0x31292dac,   // sk.az.sl_665 sk.hmn.az_521  eu.de.et_543 sk.sl.az_632
  0x1c2135ec, 0x190a07ee, 0x210103ee, 0x31292d13,   // zu.jw.id_644 it.pt.gl_422  nl.en.jw_422 sk.sl.az_665
  0x1b0118a0, 0x11292d0c, 0x012a1fa0, 0x080a11a0,   // ga.en.tr_322 sk.sl.ro_543  cy.mt.en_322 ro.mk.uk_322
  0x13001705, 0x1f000804, 0x02003b0b, 0x2d0d53ee,   // sr.et.un_330 no.cy.un_320  so.da.un_520 ht.cs.sk_422
  // [bc50]
  0x292a11a7, 0x0f100da0, 0x0a192bb2, 0x20003f13,   // ro.mt.sl_532 cs.lt.lv_322  vi.gl.pt_732 af.sq.un_650
  0x20100fad, 0x3100292b, 0x060e3f04, 0x0a072308,   // lv.lt.sq_643 sl.az.un_980  af.is.de_332 ca.it.pt_443
  0x060e0ca0, 0x0e201008, 0x06100305, 0x350655ad,   // sv.is.de_322 lt.sq.is_443  nl.lt.de_333 rw.de.zu_643
  0x55131ea0, 0x3f030f05, 0x234a1907, 0x31005313,   // ms.et.rw_322 lv.nl.af_333  gl.yo.ca_432 ht.az.un_650
  // [bc60]
  0x210806ad, 0x2a001302, 0x2917100c, 0x13091ca0,   // de.no.jw_643 et.mt.un_220  lt.sr.sl_543 mr.hi.bh_322
  0x1a20520d, 0x23060e11, 0x1b523113, 0x2520520c,   // ha.sq.tl_554 is.de.ca_653  az.ha.tr_665 ha.sq.eu_543
  0x194a2d04, 0x1c043b02, 0x211f35a0, 0x52000d04,   // sk.yo.gl_332 so.fi.id_222  zu.cy.jw_322 cs.ha.un_320
  0x1f4a52ec, 0x4a3b520c, 0x531f35ad, 0x0925210c,   // ha.yo.cy_644 ha.so.yo_543  zu.cy.ht_643 jw.eu.pl_543
  // [bc70]
  0x182d0a07, 0x0d1c21a0, 0x350920a4, 0x4a3152ec,   // pt.sk.ga_432 jw.id.cs_322  sq.pl.zu_433 ha.az.yo_644
  0x19111308, 0x31233b0c, 0x1c3b4aad, 0x0d31045a,   // et.ro.gl_443 so.ca.az_543  yo.so.id_643 fi.az.cs_553
  0x03095305, 0x0613010c, 0x286421ad, 0x100901a4,   // ht.pl.nl_333 en.et.de_543  jw.lg.sw_643 en.pl.lt_433
  0x04003121, 0x21045508, 0x12000c1a, 0x2913350c,   // az.fi.un_860 rw.fi.jw_443  sv.hu.un_760 zu.et.sl_543
  // [bc80]
  0x29251bec, 0x2535010c, 0x350e645a, 0x6b000714,   // tr.eu.sl_644 en.zu.eu_543  lg.is.zu_553 it.ceb.un_660
  0x0c5511a7, 0x131f200c, 0x0d35295a, 0x286b1a14,   // ro.rw.sv_532 sq.cy.et_543  sl.zu.cs_553 tl.ceb.sw_666
  0x10042507, 0x23050b04, 0x13002a04, 0x11131907,   // eu.fi.lt_432 es.fr.ca_332  mt.et.un_320 gl.et.ro_432
  0x5301190c, 0x21130807, 0x170229a4, 0x4a2d53a4,   // gl.en.ht_543 no.et.jw_432  sl.da.sr_433 ht.sk.yo_433
  // [bc90]
  0x3b201e04, 0x250413a6, 0x03121304, 0x04130804,   // ms.sq.so_332 et.fi.eu_521  et.hu.nl_332 no.et.fi_332
  0x6b1f3f04, 0x2b2128a9, 0x53000609, 0x101f1c07,   // af.cy.ceb_332 sw.jw.vi_544  de.ht.un_440 id.cy.lt_432
  0x131b2aa0, 0x6b4a1a0e, 0x033f2a07, 0x0c115355,   // mt.tr.et_322 tl.yo.ceb_555  mt.af.nl_432 ht.ro.sv_442
  0x25130e04, 0x040306ee, 0x072301a9, 0x3f1c0eee,   // is.et.eu_332 de.nl.fi_422  en.ca.it_544 is.id.af_422
  // [bca0]
  0x100e2504, 0x05000807, 0x0e522504, 0x2d0d0709,   // eu.is.lt_332 no.fr.un_420  eu.ha.is_332 it.cs.sk_444
  0x071320ee, 0x0d3528a0, 0x103217a0, 0x12131007,   // sq.et.it_422 sw.zu.cs_322  sr.bs.lt_322 lt.et.hu_432
  0x1c0e0907, 0x0e003107, 0x080213a9, 0x190a0907,   // pl.is.id_432 az.is.un_420  et.da.no_544 pl.pt.gl_432
  0x07110b0c, 0x531b5555, 0x321708a0, 0x1f1b310c,   // es.ro.it_543 rw.tr.ht_442  no.sr.bs_322 az.tr.cy_543
  // [bcb0]
  0x20551104, 0x051b31ee, 0x25130da4, 0x20290402,   // ro.rw.sq_332 az.tr.fr_422  cs.et.eu_433 fi.sl.sq_222
  0x091725a6, 0x4a1153a0, 0x051c2a04, 0x35534a04,   // eu.sr.pl_521 ht.ro.yo_322  mt.id.fr_332 yo.ht.zu_332
  0x2b184a02, 0x11004a04, 0x3b355502, 0x526425a4,   // yo.ga.vi_222 yo.ro.un_320  rw.zu.so_222 eu.lg.ha_433
  0x1c110a02, 0x53094aa0, 0x3b535512, 0x35533ba0,   // pt.ro.id_222 yo.pl.ht_322  rw.ht.so_654 so.ht.zu_322
  // [bcc0]
  0x550d4aa4, 0x061f23a4, 0x1a6807a7, 0x64286802,   // yo.cs.rw_433 ca.cy.de_433  it.ig.tl_532 ig.sw.lg_222
  0x55282514, 0x232120a4, 0x3f256412, 0x6b0801ee,   // eu.sw.rw_666 sq.jw.ca_433  lg.eu.af_654 en.no.ceb_422
  0x282055a0, 0x1a35130b, 0x03132105, 0x134a6409,   // rw.sq.sw_322 et.zu.tl_542  jw.et.nl_333 lg.yo.et_444
  0x10130407, 0x230a1907, 0x18232dac, 0x253f030c,   // fi.et.lt_432 gl.pt.ca_432  sk.ca.ga_632 nl.af.eu_543
  // [bcd0]
  0x3f200804, 0x2321050b, 0x3b351aad, 0x211c3f12,   // no.sq.af_332 fr.jw.ca_542  tl.zu.so_643 af.id.jw_654
  0x02030ca0, 0x2b035307, 0x3f25030d, 0x05000c04,   // sv.nl.da_322 ht.nl.vi_432  nl.eu.af_554 sv.fr.un_320
  0x25003f1a, 0x1c080e0c, 0x0f120802, 0x350208ac,   // af.eu.un_760 is.no.id_543  no.hu.lv_222 no.da.zu_632
  0x060828a0, 0x2a0c3f07, 0x08033fad, 0x08000519,   // sw.no.de_322 af.sv.mt_432  af.nl.no_643 fr.no.un_750
  // [bce0]
  0x040e52a4, 0x080252a9, 0x1b020307, 0x0e181fad,   // ha.is.fi_433 ha.da.no_544  nl.da.tr_432 cy.ga.is_643
  0x4a080202, 0x040655ec, 0x182752a9, 0x1e271807,   // da.no.yo_222 rw.de.fi_644  ha.gd.ga_544 ga.gd.ms_432
  0x20352855, 0x06130cad, 0x200f0608, 0x290d0fad,   // sw.zu.sq_442 sv.et.de_643  de.lv.sq_443 lv.cs.sl_643
  0x06030ea0, 0x1c554a04, 0x1002040c, 0x0f132d07,   // is.nl.de_322 yo.rw.id_332  fi.da.lt_543 sk.et.lv_432
  // [bcf0]
  0x07640107, 0x210c08af, 0x1800520e, 0x132a070c,   // en.lg.it_432 no.sv.jw_655  ha.ga.un_550 it.mt.et_543
  0x05000809, 0x28686e0b, 0x23080c04, 0x28001f13,   // no.fr.un_440 hmn.ig.sw_542  sv.no.ca_332 cy.sw.un_650
  0x55061e0c, 0x3f0910ee, 0x532d0d09, 0x050b11ac,   // ms.de.rw_543 lt.pl.af_422  cs.sk.ht_444 ro.es.fr_632
  0x0c10290c, 0x17001219, 0x03062d07, 0x0a1a0208,   // sl.lt.sv_543 hu.sr.un_750  sk.de.nl_432 da.tl.pt_443
  // [bd00]
  0x2d030611, 0x682852a0, 0x120b07a4, 0x1a000423,   // de.nl.sk_653 ha.sw.ig_322  it.es.hu_433 fi.tl.un_880
  0x09083f04, 0x076b1aa9, 0x063f0205, 0x1f1b0205,   // af.no.pl_332 tl.ceb.it_544  da.af.de_333 da.tr.cy_333
  0x013f1a07, 0x1b2a07ac, 0x08070209, 0x1a0601a0,   // tl.af.en_432 it.mt.tr_632  da.it.no_444 en.de.tl_322
  0x3f2a0960, 0x0f520407, 0x0f2a3fa4, 0x13081bad,   // pl.mt.af_664 fi.ha.lv_432  af.mt.lv_433 tr.no.et_643
  // [bd10]
  0x13042a04, 0x32041cee, 0x04005212, 0x0c0810ee,   // mt.fi.et_332 id.fi.bs_422  ha.fi.un_640 lt.no.sv_422
  0x6b1a0712, 0x06120207, 0x3b040507, 0x2a251b0c,   // it.tl.ceb_654 da.hu.de_432  fr.fi.so_432 tr.eu.mt_543
  0x31321bac, 0x211b1eaf, 0x1a556b0c, 0x1f52130c,   // tr.bs.az_632 ms.tr.jw_655  ceb.rw.tl_543 et.ha.cy_543
  0x1a536404, 0x012864a4, 0x0f041307, 0x1e001b13,   // lg.ht.tl_332 lg.sw.en_433  et.fi.lv_432 tr.ms.un_650
  // [bd20]
  0x040c13a0, 0x1f0e0408, 0x070a2305, 0x32161ba0,   // et.sv.fi_322 fi.is.cy_443  ca.pt.it_333 tr.hr.bs_322
  0x2d0e120b, 0x171b3f07, 0x10020d0d, 0x27011207,   // hu.is.sk_542 af.tr.sr_432  cs.da.lt_554 hu.en.gd_432
  0x04002304, 0x2b1f3507, 0x0d13290c, 0x20000e09,   // ca.fi.un_320 zu.cy.vi_432  sl.et.cs_543 is.sq.un_440
  0x6e53290c, 0x190a3b05, 0x120c0e05, 0x050f1305,   // sl.ht.hmn_543 so.pt.gl_333  is.sv.hu_333 et.lv.fr_333
  // [bd30]
  0x2d090d13, 0x2a0b0ea0, 0x090d17ad, 0x23000412,   // cs.pl.sk_665 is.es.mt_322  sr.cs.pl_643 fi.ca.un_640
  0x11001221, 0x0d131c13, 0x2a002502, 0x0c001807,   // hu.ro.un_860 mr.bh.ne_665  eu.mt.un_220 ga.sv.un_420
  0x6b010755, 0x52006b04, 0x6b352aa9, 0x1f090ea4,   // it.en.ceb_442 ceb.ha.un_320  mt.zu.ceb_544 is.pl.cy_433
  0x042513af, 0x1a4a6bee, 0x21052d0c, 0x213b640e,   // et.eu.fi_655 ceb.yo.tl_422  sk.fr.jw_543 lg.so.jw_555
  // [bd40]
  0x3f3b6807, 0x13522a04, 0x012b1b04, 0x4a641b5a,   // ig.so.af_432 mt.ha.et_332  tr.vi.en_332 tr.lg.yo_553
  0x3b3f13ad, 0x13043f12, 0x0e2105a6, 0x0f021a08,   // et.af.so_643 af.fi.et_654  fr.jw.is_521 tl.da.lv_443
  0x53040d14, 0x1a3110a9, 0x351a100d, 0x09002505,   // cs.fi.ht_666 lt.az.tl_544  lt.tl.zu_554 eu.pl.un_330
  0x0c0e0204, 0x1a5510a9, 0x10002121, 0x3252100c,   // da.is.sv_332 lt.rw.tl_544  jw.lt.un_860 lt.ha.bs_543
  // [bd50]
  0x1a006e09, 0x1b11100c, 0x17162907, 0x310710a4,   // hmn.tl.un_440 lt.ro.tr_543  sl.hr.sr_432 lt.it.az_433
  0x0f10350c, 0x2d530d12, 0x181f23ad, 0x311b100c,   // zu.lt.lv_543 cs.ht.sk_654  ca.cy.ga_643 lt.tr.az_543
  0x2d0d53a9, 0x1f2109ad, 0x1b3110ec, 0x101b310d,   // ht.cs.sk_544 pl.jw.cy_643  lt.az.tr_644 az.tr.lt_554
  0x531b10a4, 0x091b12a7, 0x01080e11, 0x090d12ec,   // lt.tr.ht_433 hu.tr.pl_532  is.no.en_653 hu.cs.pl_644
  // [bd60]
  0x3b001f22, 0x130f1112, 0x0e1711a4, 0x0800050b,   // cy.so.un_870 ro.lv.et_654  ro.sr.is_433 fr.no.un_520
  0x2a641f55, 0x1c004a19, 0x10006b07, 0x041364af,   // cy.lg.mt_442 yo.id.un_750  ceb.lt.un_420 lg.et.fi_655
  0x3111120c, 0x1e101ca4, 0x04280fa4, 0x211b52ee,   // hu.ro.az_543 id.lt.ms_433  lv.sw.fi_433 ha.tr.jw_422
  0x1a2b55a7, 0x21001f09, 0x1f18080c, 0x0b07250c,   // rw.vi.tl_532 cy.jw.un_440  no.ga.cy_543 eu.it.es_543
  // [bd70]
  0x162917a4, 0x2b641207, 0x0e2821a6, 0x2a005508,   // sr.sl.hr_433 hu.lg.vi_432  jw.sw.is_521 rw.mt.un_430
  0x0a0d010c, 0x212820ec, 0x25063508, 0x0d001805,   // en.cs.pt_543 sq.sw.jw_644  zu.de.eu_443 ga.cs.un_330
  0x1e281ca0, 0x122528a4, 0x2d0d1ca4, 0x53074a08,   // id.sw.ms_322 sw.eu.hu_433  id.cs.sk_433 yo.it.ht_443
  0x27080205, 0x322725a7, 0x12136ba6, 0x682864a4,   // da.no.gd_333 eu.gd.bs_532  ceb.et.hu_521 lg.sw.ig_433
  // [bd80]
  0x1b0d100c, 0x3f2d0fa7, 0x3217350c, 0x3f2d0308,   // lt.cs.tr_543 lv.sk.af_532  zu.sr.bs_543 nl.sk.af_443
  0x033109ee, 0x1b032dad, 0x3b07230c, 0x31006808,   // pl.az.nl_422 sk.nl.tr_643  ca.it.so_543 ig.az.un_430
  0x29002721, 0x21000a0d, 0x13002d12, 0x3f041909,   // gd.sl.un_860 pt.jw.un_540  sk.et.un_640 gl.fi.af_444
  0x251055ec, 0x17003b0d, 0x1b641108, 0x060c20b4,   // rw.lt.eu_644 so.sr.un_540  ro.lg.tr_443 sq.sv.de_754
  // [bd90]
  0x6b00111b, 0x2d093fa7, 0x120e3504, 0x3f1325a4,   // ro.ceb.un_770 af.pl.sk_532  zu.is.hu_332 eu.et.af_433
  0x640c1314, 0x0c005512, 0x2d120d55, 0x21060e05,   // et.sv.lg_666 rw.sv.un_640  cs.hu.sk_442 is.de.jw_333
  0x21100f09, 0x2d002708, 0x0d00132a, 0x080702a6,   // lv.lt.jw_444 gd.sk.un_430  bh.ne.un_970 da.it.no_521
  0x1c216e08, 0x0d2d0e12, 0x3f1f12af, 0x06001208,   // hmn.jw.id_443 is.sk.cs_654  hu.cy.af_655 hu.de.un_430
  // [bda0]
  0x06120e05, 0x0b1219a0, 0x074a1608, 0x23191113,   // is.hu.de_333 gl.hu.es_322  hr.yo.it_443 ro.gl.ca_665
  0x2500180e, 0x643b0412, 0x52201ba4, 0x4a68350c,   // ga.eu.un_550 fi.so.lg_654  tr.sq.ha_433 zu.ig.yo_543
  0x52070f0c, 0x13001821, 0x1b120cec, 0x3b1e110c,   // lv.it.ha_543 ga.et.un_860  sv.hu.tr_644 ro.ms.so_543
  0x11200707, 0x172d0d60, 0x28005223, 0x11022a0d,   // it.sq.ro_432 cs.sk.sr_664  ha.sw.un_880 mt.da.ro_554
  // [bdb0]
  0x0700351b, 0x53026eaf, 0x020c3207, 0x0f001f21,   // zu.it.un_770 hmn.da.ht_655  bs.sv.da_432 cy.lv.un_860
  0x110128ad, 0x281364ad, 0x2d1309af, 0x3b641360,   // sw.en.ro_643 lg.et.sw_643  pl.et.sk_655 et.lg.so_664
  0x2d190b13, 0x07321608, 0x3b4a200c, 0x31006e07,   // es.gl.sk_665 hr.bs.it_443  sq.yo.so_543 hmn.az.un_420
  0x6b1a6e0d, 0x0500251a, 0x4a002d21, 0x060504ad,   // hmn.tl.ceb_554 eu.fr.un_760  sk.yo.un_860 fi.fr.de_643
  // [bdc0]
  0x3f25050c, 0x2d055312, 0x0d3b2da7, 0x6e000605,   // fr.eu.af_543 ht.fr.sk_654  sk.so.cs_532 de.hmn.un_330
  0x0a272305, 0x111007ad, 0x1e1c3514, 0x124a2d0d,   // ca.gd.pt_333 bg.be.ro_643  zu.id.ms_666 sk.yo.hu_554
  0x1a182711, 0x12182d0c, 0x2b4a1cad, 0x111728a4,   // gd.ga.tl_653 sk.ga.hu_543  id.yo.vi_643 sw.sr.ro_433
  0x55041313, 0x043b2010, 0x530b190c, 0x2a00050c,   // et.fi.rw_665 sq.so.fi_642  gl.es.ht_543 fr.mt.un_530
  // [bdd0]
  0x18001313, 0x1a0c1b0c, 0x21004a0c, 0x0e1b1f55,   // et.ga.un_650 tr.sv.tl_543  yo.jw.un_530 cy.tr.is_442
  0x0c003b12, 0x0c0908a4, 0x0a0b18a6, 0x17001020,   // so.sv.un_640 no.pl.sv_433  ga.es.pt_521 be.sr.un_850
  0x0d1c1313, 0x190b18af, 0x070c2a13, 0x060e3fa7,   // bh.mr.ne_665 ga.es.gl_655  mt.sv.it_665 af.is.de_532
  0x192d0d0c, 0x211c04ad, 0x091f3faf, 0x0c021c04,   // cs.sk.gl_543 fi.id.jw_643  af.cy.pl_655 id.da.sv_332
  // [bde0]
  0x020c1c05, 0x190b35ec, 0x1c063104, 0x32002b0c,   // id.sv.da_333 zu.es.gl_644  az.de.id_332 vi.bs.un_530
  0x1e1c4aa9, 0x105535a4, 0x2d050d0c, 0x210b0407,   // yo.id.ms_544 zu.rw.lt_433  cs.fr.sk_543 fi.es.jw_432
  0x2910120c, 0x033f1ca4, 0x55000e23, 0x20211b07,   // hu.lt.sl_543 id.af.nl_433  is.rw.un_880 tr.jw.sq_432
  0x031c3b12, 0x0b3f2d02, 0x644a3508, 0x64005309,   // so.id.nl_654 sk.af.es_222  zu.yo.lg_443 ht.lg.un_440
  // [bdf0]
  0x1e3f1c0c, 0x521e08ac, 0x21202ba0, 0x1e1c3fa4,   // id.af.ms_543 no.ms.ha_632  vi.sq.jw_322 af.id.ms_433
  0x030e23ee, 0x2a0e28a6, 0x19002102, 0x1c0e1eee,   // ca.is.nl_422 sw.is.mt_521  jw.gl.un_220 ms.is.id_422
  0x27033f0d, 0x32160da4, 0x2b003102, 0x3f2a230c,   // af.nl.gd_554 cs.hr.bs_433  az.vi.un_220 ca.mt.af_543
  0x20022a5a, 0x0d232d0d, 0x172935ac, 0x070a1aec,   // mt.da.sq_553 sk.ca.cs_554  zu.sl.sr_632 tl.pt.it_644
  // [be00]
  0x0b00270b, 0x210e3504, 0x646b1e0c, 0x55351f0e,   // gd.es.un_520 zu.is.jw_332  ms.ceb.lg_543 cy.zu.rw_555
  0x1f0a4aad, 0x556b2805, 0x311b28a0, 0x07551308,   // yo.pt.cy_643 sw.ceb.rw_333  sw.tr.az_322 et.rw.it_443
  0x103b31a4, 0x121f31af, 0x23000d19, 0x321b2dee,   // az.so.lt_433 az.cy.hu_655  cs.ca.un_750 sk.tr.bs_422
  0x09190b13, 0x1b1235a4, 0x28001608, 0x64552d07,   // es.gl.pl_665 zu.hu.tr_433  hr.sw.un_430 sk.rw.lg_432
  // [be10]
  0x1f031ea4, 0x25063f08, 0x4a016ba4, 0x1f321ba4,   // ms.nl.cy_433 af.de.eu_443  ceb.en.yo_433 tr.bs.cy_433
  0x2052550c, 0x0a070813, 0x6b1a250c, 0x11532512,   // rw.ha.sq_543 uk.bg.mk_665  eu.tl.ceb_543 eu.ht.ro_654
  0x52310ea7, 0x18003b07, 0x315368a9, 0x08022dee,   // is.az.ha_532 so.ga.un_420  ig.ht.az_544 sk.da.no_422
  0x06002113, 0x09211607, 0x05000b09, 0x10062aec,   // jw.de.un_650 hr.jw.pl_432  es.fr.un_440 mt.de.lt_644
  // [be20]
  0x0c120ead, 0x0a1027a7, 0x01122a0c, 0x6e00640d,   // is.hu.sv_643 gd.lt.pt_532  mt.hu.en_543 lg.hmn.un_540
  0x202917ad, 0x64004a13, 0x2b000502, 0x17001907,   // sr.sl.sq_643 yo.lg.un_650  fr.vi.un_220 gl.sr.un_420
  0x2a02080c, 0x0d3f2a11, 0x525531ee, 0x3b03130c,   // no.da.mt_543 mt.af.cs_653  az.rw.ha_422 et.nl.so_543
  0x2a050fa4, 0x03001b19, 0x201b050c, 0x171b0704,   // lv.fr.mt_433 tr.nl.un_750  fr.tr.sq_543 it.tr.sr_332
  // [be30]
  0x11001723, 0x230b1804, 0x19160bac, 0x35002507,   // sr.ro.un_880 ga.es.ca_332  es.hr.gl_632 eu.zu.un_420
  0x291f07ad, 0x2d0d160e, 0x522701a4, 0x64553555,   // it.cy.sl_643 hr.cs.sk_555  en.gd.ha_433 zu.rw.lg_442
  0x1b353b12, 0x2d001e02, 0x0e350fa0, 0x2953050c,   // so.zu.tr_654 ms.sk.un_220  lv.zu.is_322 fr.ht.sl_543
  0x3b281bad, 0x6800290c, 0x16001a04, 0x201b53a4,   // tr.sw.so_643 sl.ig.un_530  tl.hr.un_320 ht.tr.sq_433
  // [be40]
  0x05080c0d, 0x523b3505, 0x530501ad, 0x551a2807,   // sv.no.fr_554 zu.so.ha_333  en.fr.ht_643 sw.tl.rw_432
  0x3b3155a4, 0x31553ba9, 0x070a2360, 0x08095305,   // rw.az.so_433 so.rw.az_544  ca.pt.it_664 ht.pl.no_333
  0x4a681f0c, 0x28040e08, 0x1a2801a7, 0x1a100408,   // cy.ig.yo_543 is.fi.sw_443  en.sw.tl_532 fi.lt.tl_443
  0x2a1207ad, 0x035320ad, 0x0e6b04a0, 0x04100f0d,   // it.hu.mt_643 sq.ht.nl_643  fi.ceb.is_322 lv.lt.fi_554
  // [be50]
  0x55355211, 0x321709af, 0x553b350c, 0x52350555,   // ha.zu.rw_653 pl.sr.bs_655  zu.so.rw_543 fr.zu.ha_442
  0x036806ee, 0x31532011, 0x02080e07, 0x2500522b,   // de.ig.nl_422 sq.ht.az_653  is.no.da_432 ha.eu.un_980
  0x231101a9, 0x112a23a4, 0x00000637, 0x64351a04,   // en.ro.ca_544 ca.mt.ro_433  de.un.un_B00 tl.zu.lg_332
  0x23002802, 0x0f005221, 0x250d2da4, 0x211b1c0c,   // sw.ca.un_220 ha.lv.un_860  sk.cs.eu_433 id.tr.jw_543
  // [be60]
  0x20005507, 0x53201f0c, 0x08021005, 0x07042aa0,   // rw.sq.un_420 cy.sq.ht_543  lt.da.no_333 mt.fi.it_322
  0x20350fad, 0x35210cad, 0x08022b0c, 0x20000c08,   // lv.zu.sq_643 sv.jw.zu_643  vi.da.no_543 sv.sq.un_430
  0x280813ee, 0x06271fa0, 0x311f18a4, 0x190a3ba0,   // et.no.sw_422 cy.gd.de_322  ga.cy.az_433 so.pt.gl_322
  0x535511a0, 0x32523b55, 0x0c003512, 0x530b0aa6,   // ro.rw.ht_322 so.ha.bs_442  zu.sv.un_640 pt.es.ht_521
  // [be70]
  0x2a070411, 0x190b1fee, 0x19051855, 0x172d1109,   // fi.it.mt_653 cy.es.gl_422  ga.fr.gl_442 ro.sk.sr_444
  0x4a6435ec, 0x55000707, 0x273b1812, 0x0b001112,   // zu.lg.yo_644 it.rw.un_420  ga.so.gd_654 ro.es.un_640
  0x6b55520c, 0x11282304, 0x52005521, 0x071b0a02,   // ha.rw.ceb_543 ca.sw.ro_332  rw.ha.un_860 pt.tr.it_222
  0x022808ad, 0x23273b05, 0x102d13a7, 0x111c55ee,   // no.sw.da_643 so.gd.ca_333  et.sk.lt_532 rw.id.ro_422
  // [be80]
  0x550d05a7, 0x1300050c, 0x5211550c, 0x2d2b0d13,   // fr.cs.rw_532 fr.et.un_530  rw.ro.ha_543 cs.vi.sk_665
  0x131b520d, 0x1a6b2808, 0x01532a09, 0x0f006419,   // ha.tr.et_554 sw.ceb.tl_443  mt.ht.en_444 lg.lv.un_750
  0x292d0dad, 0x040b5307, 0x081a02ee, 0x6b00350d,   // cs.sk.sl_643 ht.es.fi_432  da.tl.no_422 zu.ceb.un_540
  0x0b23070c, 0x27180a08, 0x0f1053a4, 0x3b1e1cec,   // it.ca.es_543 pt.ga.gd_443  ht.lt.lv_433 id.ms.so_644
  // [be90]
  0x12533ba4, 0x19180b12, 0x532a060d, 0x4a641b08,   // so.ht.hu_433 es.ga.gl_654  de.mt.ht_554 tr.lg.yo_443
  0x1b00070e, 0x0f050208, 0x2a130a08, 0x1c004a02,   // it.tr.un_550 da.fr.lv_443  pt.et.mt_443 yo.id.un_220
  0x2a00290c, 0x1e002112, 0x3b1f0712, 0x123b20a4,   // sl.mt.un_530 jw.ms.un_640  it.cy.so_654 sq.so.hu_433
  0x080e3104, 0x353b100c, 0x3b321705, 0x0a53010c,   // az.is.no_332 lt.so.zu_543  sr.bs.so_333 en.ht.pt_543
  // [bea0]
  0x201105a9, 0x16290f0c, 0x19311b0c, 0x532a3fad,   // fr.ro.sq_544 lv.sl.hr_543  tr.az.gl_543 af.mt.ht_643
  0x270608af, 0x551701a4, 0x20001b0e, 0x53206404,   // no.de.gd_655 en.sr.rw_433  tr.sq.un_550 lg.sq.ht_332
  0x18002519, 0x20102514, 0x080c0f02, 0x20252a0c,   // eu.ga.un_750 eu.lt.sq_666  lv.sv.no_222 mt.eu.sq_543
  0x1b3f17a0, 0x09021f12, 0x1e003f0c, 0x08100fec,   // sr.af.tr_322 cy.da.pl_654  af.ms.un_530 lv.lt.no_644
  // [beb0]
  0x201f3fec, 0x10252a07, 0x0729120c, 0x171168a4,   // af.cy.sq_644 mt.eu.lt_432  hu.sl.it_543 ig.ro.sr_433
  0x133512ad, 0x2832160d, 0x2a1b20a4, 0x13204a04,   // hu.zu.et_643 hr.bs.sw_554  sq.tr.mt_433 yo.sq.et_332
  0x320d1107, 0x12312813, 0x1e1c18a9, 0x11291708,   // ro.cs.bs_432 sw.az.hu_665  ga.id.ms_544 sr.sl.ro_443
  0x3211200c, 0x16101e07, 0x172a2bee, 0x0c000521,   // sq.ro.bs_543 ms.lt.hr_432  vi.mt.sr_422 fr.sv.un_860
  // [bec0]
  0x1e136405, 0x53101ca4, 0x170810ec, 0x1f275307,   // lg.et.ms_333 id.lt.ht_433  be.uk.sr_644 ht.gd.cy_432
  0x1c2a1e04, 0x4a00020c, 0x291611ad, 0x16003f0c,   // ms.mt.id_332 da.yo.un_530  ro.hr.sl_643 af.hr.un_530
  0x11000c29, 0x1f002712, 0x100f2a60, 0x06003b04,   // sv.ro.un_960 gd.cy.un_640  mt.lv.lt_664 so.de.un_320
  0x0c251305, 0x3f1f08ee, 0x1b123b0b, 0x0c230aa9,   // et.eu.sv_333 no.cy.af_422  so.hu.tr_542 pt.ca.sv_544
  // [bed0]
  0x04280807, 0x25202814, 0x0a2319ad, 0x01041311,   // no.sw.fi_432 sw.sq.eu_666  gl.ca.pt_643 et.fi.en_653
  0x3f0713ee, 0x68006b0d, 0x270b2807, 0x21000207,   // et.it.af_422 ceb.ig.un_540  sw.es.gd_432 da.jw.un_420
  0x11050aa4, 0x323564ac, 0x684a3505, 0x6b3f04a4,   // pt.fr.ro_433 lg.zu.bs_632  zu.yo.ig_333 fi.af.ceb_433
  0x09041a55, 0x6800350e, 0x04211308, 0x19130aec,   // tl.fi.pl_442 zu.ig.un_550  et.jw.fi_443 pt.et.gl_644
  // [bee0]
  0x13041bac, 0x3b350ba4, 0x3f081c0c, 0x556b6409,   // tr.fi.et_632 es.zu.so_433  id.no.af_543 lg.ceb.rw_444
  0x070b2312, 0x03001012, 0x08021a0e, 0x07230a07,   // ca.es.it_654 lt.nl.un_640  tl.da.no_555 pt.ca.it_432
  0x253f0313, 0x1c040805, 0x02002909, 0x25200612,   // nl.af.eu_665 no.fi.id_333  sl.da.un_440 de.sq.eu_654
  0x070c2d07, 0x080418ad, 0x1200071b, 0x1600530b,   // sk.sv.it_432 ga.fi.no_643  it.hu.un_770 ht.hr.un_520
  // [bef0]
  0x0c03060e, 0x17161ba0, 0x52190b09, 0x046b5507,   // de.nl.sv_555 tr.hr.sr_322  es.gl.ha_444 rw.ceb.fi_432
  0x4a002804, 0x1a1935ee, 0x0f203209, 0x29032512,   // sw.yo.un_320 zu.gl.tl_422  bs.sq.lv_444 eu.nl.sl_654
  0x1b5253a9, 0x190c230c, 0x31006b29, 0x211a0eee,   // ht.ha.tr_544 ca.sv.gl_543  ceb.az.un_960 is.tl.jw_422
  0x1f530308, 0x25230611, 0x0c0823ec, 0x3b1b4aa7,   // nl.ht.cy_443 de.ca.eu_653  ca.no.sv_644 yo.tr.so_532
  // [bf00]
  0x122503a9, 0x081e0c11, 0x0e6b1aa9, 0x12352508,   // nl.eu.hu_544 sv.ms.no_653  tl.ceb.is_544 eu.zu.hu_443
  0x070435ee, 0x2b1e01a7, 0x1b6b1a0c, 0x110529ee,   // zu.fi.it_422 en.ms.vi_532  tl.ceb.tr_543 sl.fr.ro_422
  0x551353a4, 0x204a2308, 0x17110711, 0x0e001e0d,   // ht.et.rw_433 ca.yo.sq_443  bg.ro.sr_653 ms.is.un_540
  0x3500270c, 0x251c10a7, 0x08000429, 0x25001f18,   // gd.zu.un_530 lt.id.eu_532  ru.uk.un_960 cy.eu.un_740
  // [bf10]
  0x1a003502, 0x08002313, 0x08024aa0, 0x644a55ec,   // zu.tl.un_220 ca.no.un_650  yo.da.no_322 rw.yo.lg_644
  0x08050cee, 0x13313bec, 0x13000218, 0x641f1baf,   // sv.fr.no_422 so.az.et_644  da.et.un_740 tr.cy.lg_655
  0x0c1f520c, 0x1e351c0c, 0x0c0603a4, 0x190b13a4,   // ha.cy.sv_543 id.zu.ms_543  nl.de.sv_433 et.es.gl_433
  0x08001313, 0x29110307, 0x0d1b3f0c, 0x2a070612,   // et.no.un_650 nl.ro.sl_432  af.tr.cs_543 de.it.mt_654
  // [bf20]
  0x0b2d1955, 0x1c0210a0, 0x012a0302, 0x0b191811,   // gl.sk.es_442 lt.da.id_322  nl.mt.en_222 ga.gl.es_653
  0x051253ad, 0x1a001b12, 0x0f3f02ec, 0x1b531e5a,   // ht.hu.fr_643 tr.tl.un_640  da.af.lv_644 ms.ht.tr_553
  0x25001707, 0x3f030daf, 0x313f5507, 0x21070fec,   // sr.eu.un_420 cs.nl.af_655  rw.af.az_432 lv.it.jw_644
  0x1b31550c, 0x1620100c, 0x523b0bee, 0x55005202,   // rw.az.tr_543 lt.sq.hr_543  es.so.ha_422 ha.rw.un_220
  // [bf30]
  0x04062804, 0x0f531014, 0x1e2031a7, 0x102b3f08,   // sw.de.fi_332 lt.ht.lv_666  az.sq.ms_532 af.vi.lt_443
  0x11042808, 0x1a104aad, 0x641b1905, 0x072d1fa0,   // sw.fi.ro_443 yo.lt.tl_643  gl.tr.lg_333 cy.sk.it_322
  0x3b1f1aa7, 0x25230407, 0x0507230c, 0x02001107,   // tl.cy.so_532 fi.ca.eu_432  ca.it.fr_543 ro.da.un_420
  0x0f1001a9, 0x1a0a6b09, 0x0e1812af, 0x2a060c0c,   // en.lt.lv_544 ceb.pt.tl_444  hu.ga.is_655 sv.de.mt_543
  // [bf40]
  0x1e1c0ba0, 0x1a533512, 0x09030fa0, 0x3b281aaf,   // es.id.ms_322 zu.ht.tl_654  lv.nl.pl_322 tl.sw.so_655
  0x25200407, 0x10521a0d, 0x1f52100d, 0x101901a4,   // fi.sq.eu_432 tl.ha.lt_554  lt.ha.cy_554 en.gl.lt_433
  0x35551aa7, 0x03000f04, 0x12111007, 0x321e1b11,   // tl.rw.zu_532 lv.nl.un_320  lt.ro.hu_432 tr.ms.bs_653
  0x6b211c0c, 0x216455a4, 0x190a1eee, 0x04131ca4,   // id.jw.ceb_543 rw.lg.jw_433  ms.pt.gl_422 id.et.fi_433
  // [bf50]
  0x13100f0c, 0x3b3f6405, 0x100f1955, 0x29170f0c,   // lv.lt.et_543 lg.af.so_333  gl.lv.lt_442 lv.sr.sl_543
  0x1364030c, 0x274a6808, 0x110a29a0, 0x1f000e0e,   // nl.lg.et_543 ig.yo.gd_443  sl.pt.ro_322 is.cy.un_550
  0x1225280b, 0x00000e37, 0x0a23210d, 0x04100a12,   // sw.eu.hu_542 is.un.un_B00  jw.ca.pt_554 mk.be.ru_654
  0x020e08a7, 0x1b061213, 0x28001b0c, 0x0d002107,   // no.is.da_532 hu.de.tr_665  tr.sw.un_530 jw.cs.un_420
  // [bf60]
  0x1204250c, 0x04000113, 0x072501ad, 0x041f1311,   // eu.fi.hu_543 en.fi.un_650  en.eu.it_643 et.cy.fi_653
  0x6806250c, 0x290d6e0c, 0x293113a4, 0x3b00250d,   // eu.de.ig_543 hmn.cs.sl_543  et.az.sl_433 eu.so.un_540
  0x21255213, 0x1e1c0f14, 0x126413ee, 0x023531a4,   // ha.eu.jw_665 lv.id.ms_666  et.lg.hu_422 az.zu.da_433
  0x083b0204, 0x353b2d07, 0x1b00190d, 0x072a1e11,   // da.so.no_332 sk.so.zu_432  gl.tr.un_540 ms.mt.it_653
  // [bf70]
  0x523118a4, 0x20551008, 0x256b2da4, 0x1b0a10a4,   // ga.az.ha_433 lt.rw.sq_443  sk.ceb.eu_433 lt.pt.tr_433
  0x354a3ba0, 0x1c171ea0, 0x641b28a0, 0x102a550d,   // so.yo.zu_322 ms.sr.id_322  sw.tr.lg_322 rw.mt.lt_554
  0x3f000613, 0x3211070c, 0x04526405, 0x12080411,   // de.af.un_650 it.ro.bs_543  lg.ha.fi_333 fi.no.hu_653
  0x2932350c, 0x0a2b1c0c, 0x2a0964af, 0x0b010707,   // zu.bs.sl_543 id.vi.pt_543  lg.pl.mt_655 it.en.es_432
  // [bf80]
  0x16072aa9, 0x32171102, 0x1e1c2aec, 0x1b000a02,   // mt.it.hr_544 ro.sr.bs_222  mt.id.ms_644 pt.tr.un_220
  0x25121bee, 0x023f20ac, 0x133f6e04, 0x06250ea7,   // tr.hu.eu_422 sq.af.da_632  hmn.af.et_332 is.eu.de_532
  0x6421350c, 0x204a64a4, 0x3f6835ad, 0x1b002d19,   // zu.jw.lg_543 lg.yo.sq_433  zu.ig.af_643 sk.tr.un_750
  0x291b2d0c, 0x35552a60, 0x0c1f08a4, 0x271928af,   // sk.tr.sl_543 mt.rw.zu_664  no.cy.sv_433 sw.gl.gd_655
  // [bf90]
  0x2d200d12, 0x1100102b, 0x2d291fa4, 0x53201b0c,   // cs.sq.sk_654 be.ro.un_980  cy.sl.sk_433 tr.sq.ht_543
  0x2900171a, 0x4a2a2807, 0x1a005512, 0x3f080502,   // sr.sl.un_760 sw.mt.yo_432  rw.tl.un_640 fr.no.af_222
  0x3100210c, 0x162953a7, 0x1a3b6413, 0x283552a7,   // jw.az.un_530 ht.sl.hr_532  lg.so.tl_665 ha.zu.sw_532
  0x1b052d0c, 0x17212808, 0x180a32a0, 0x1a000207,   // sk.fr.tr_543 sw.jw.sr_443  bs.pt.ga_322 da.tl.un_420
  // [bfa0]
  0x08022d0c, 0x0c290d08, 0x28001019, 0x03006818,   // sk.da.no_543 cs.sl.sv_443  lt.sw.un_750 ig.nl.un_740
  0x13684a04, 0x1e1a1c07, 0x100364ad, 0x23005504,   // yo.ig.et_332 id.tl.ms_432  lg.nl.lt_643 rw.ca.un_320
  0x4a28350c, 0x2823530d, 0x2800311b, 0x20033f11,   // zu.sw.yo_543 ht.ca.sw_554  az.sw.un_770 af.nl.sq_653
  0x6b003b0d, 0x3f005202, 0x3f02010c, 0x21000d0c,   // so.ceb.un_540 ha.af.un_220  en.da.af_543 cs.jw.un_530
  // [bfb0]
  0x234a2bad, 0x2d002a02, 0x09110fad, 0x074a2712,   // vi.yo.ca_643 mt.sk.un_220  lv.ro.pl_643 gd.yo.it_654
  0x29000f18, 0x02086ea7, 0x2b274aec, 0x10080faf,   // lv.sl.un_740 hmn.no.da_532  yo.gd.vi_644 lv.no.lt_655
  0x6b002807, 0x2a002d12, 0x130e0f04, 0x532a010c,   // sw.ceb.un_420 sk.mt.un_640  lv.is.et_332 en.mt.ht_543
  0x10005202, 0x6b251a13, 0x64000e14, 0x351355ac,   // ha.lt.un_220 tl.eu.ceb_665  is.lg.un_660 rw.et.zu_632
  // [bfc0]
  0x1b000302, 0x20080caf, 0x1b0c08af, 0x102a0f13,   // nl.tr.un_220 sv.no.sq_655  no.sv.tr_655 lv.mt.lt_665
  0x64066ba7, 0x64283ba0, 0x1008020d, 0x352a1a07,   // ceb.de.lg_532 so.sw.lg_322  da.no.lt_554 tl.mt.zu_432
  0x1f12640c, 0x2852350c, 0x53033f05, 0x535564af,   // lg.hu.cy_543 zu.ha.sw_543  af.nl.ht_333 lg.rw.ht_655
  0x1e1c28a9, 0x12184aec, 0x642a5508, 0x231128a4,   // sw.id.ms_544 yo.ga.hu_644  rw.mt.lg_443 sw.ro.ca_433
  // [bfd0]
  0x531a0111, 0x0a191155, 0x3f2a070d, 0x13253fa4,   // en.tl.ht_653 ro.gl.pt_442  it.mt.af_554 af.eu.et_433
  0x106828ad, 0x32252da4, 0x1c1e2807, 0x1828010c,   // sw.ig.lt_643 sk.eu.bs_433  sw.ms.id_432 en.sw.ga_543
  0x5310010c, 0x28552a05, 0x035528ee, 0x1b282d07,   // en.lt.ht_543 mt.rw.sw_333  sw.rw.nl_422 sk.sw.tr_432
  0x182d4a07, 0x0b191807, 0x4a00532c, 0x4a072ba4,   // yo.sk.ga_432 ga.gl.es_432  ht.yo.un_990 vi.it.yo_433
  // [bfe0]
  0x17001612, 0x0f271005, 0x1a001011, 0x55525305,   // hr.sr.un_640 lt.gd.lv_333  lt.tl.un_630 ht.ha.rw_333
  0x4a6b1a11, 0x53004a2a, 0x21323ba4, 0x21001b12,   // tl.ceb.yo_653 yo.ht.un_970  so.bs.jw_433 tr.jw.un_640
  0x160d29a4, 0x4a001c0e, 0x0e001013, 0x32202d04,   // sl.cs.hr_433 id.yo.un_550  lt.is.un_650 sk.sq.bs_332
  0x35005312, 0x0e0c130c, 0x0f05100c, 0x105313af,   // ht.zu.un_640 et.sv.is_543  lt.fr.lv_543 et.ht.lt_655
  // [bff0]
  0x06530e0c, 0x2b000d08, 0x556401ad, 0x2d290d09,   // is.ht.de_543 cs.vi.un_430  en.lg.rw_643 cs.sl.sk_444
  0x52213508, 0x17002104, 0x28136b09, 0x02002802,   // zu.jw.ha_443 jw.sr.un_320  ceb.et.sw_444 sw.da.un_220
  0x07121108, 0x050b01af, 0x2a642812, 0x202a32a4,   // ro.hu.it_443 en.es.fr_655  sw.lg.mt_654 bs.mt.sq_433
  0x072155a9, 0x32110708, 0x062503a4, 0x121b0c55,   // rw.jw.it_544 it.ro.bs_443  nl.eu.de_433 sv.tr.hu_442

  // [c000]
  0x2b68280d, 0x6b1004ad, 0x121b0ca4, 0x29230202,   // sw.ig.vi_554 fi.lt.ceb_643  sv.tr.hu_433 da.ca.sl_222
  0x0f4a1013, 0x286b1a12, 0x10001e09, 0x0a2718ec,   // lt.yo.lv_665 tl.ceb.sw_654  ms.lt.un_440 ga.gd.pt_644
  0x1b1c07ad, 0x0f4a2707, 0x27003104, 0x18090eec,   // it.id.tr_643 gd.yo.lv_432  az.gd.un_320 is.pl.ga_644
  0x35010fa4, 0x53000f19, 0x31001302, 0x29161104,   // lv.en.zu_433 lv.ht.un_750  et.az.un_220 ro.hr.sl_332
  // [c010]
  0x101827a9, 0x100b1ca4, 0x0a07680c, 0x285268ad,   // gd.ga.lt_544 id.es.lt_433  ig.it.pt_543 ig.ha.sw_643
  0x200f18ee, 0x12000a22, 0x0f101aad, 0x29100f04,   // ga.lv.sq_422 pt.hu.un_870  tl.lt.lv_643 lv.lt.sl_332
  0x20255307, 0x19131a04, 0x170b1c07, 0x3112350c,   // ht.eu.sq_432 tl.et.gl_332  id.es.sr_432 zu.hu.az_543
  0x55281212, 0x6e6b21a0, 0x3f131e0c, 0x1e001a12,   // hu.sw.rw_654 jw.ceb.hmn_322  ms.et.af_543 tl.ms.un_640
  // [c020]
  0x12001a19, 0x041307af, 0x12190508, 0x20001a04,   // tl.hu.un_750 it.et.fi_655  fr.gl.hu_443 tl.sq.un_320
  0x04523514, 0x1c1e525a, 0x1f032a04, 0x1e1c11a9,   // zu.ha.fi_666 ha.ms.id_553  mt.nl.cy_332 ro.id.ms_544
  0x271f25a9, 0x1f002d08, 0x18270304, 0x3f00040c,   // eu.cy.gd_544 sk.cy.un_430  nl.gd.ga_332 fi.af.un_530
  0x2b3b190c, 0x6b6827a0, 0x2a002702, 0x1c1b27ee,   // gl.so.vi_543 gd.ig.ceb_322  gd.mt.un_220 gd.tr.id_422
  // [c030]
  0x0b272307, 0x3101130c, 0x25313b08, 0x1704530d,   // ca.gd.es_432 et.en.az_543  so.az.eu_443 ht.fi.sr_554
  0x04003f22, 0x1c251e12, 0x4a130e11, 0x290c1807,   // af.fi.un_870 ms.eu.id_654  is.et.yo_653 ga.sv.sl_432
  0x2d0d04ec, 0x29111e0b, 0x6b130e08, 0x12135304,   // fi.cs.sk_644 ms.ro.sl_542  is.et.ceb_443 ht.et.hu_332
  0x10271812, 0x2a5313ee, 0x27183f14, 0x0719010c,   // ga.gd.lt_654 et.ht.mt_422  af.ga.gd_666 en.gl.it_543
  // [c040]
  0x0e033f13, 0x2a2305a4, 0x1f023f04, 0x292311ac,   // af.nl.is_665 fr.ca.mt_433  af.da.cy_332 ro.ca.sl_632
  0x1b0d3104, 0x130407a4, 0x05533fee, 0x016b1305,   // az.cs.tr_332 it.fi.et_433  af.ht.fr_422 et.ceb.en_333
  0x285231af, 0x29002a2b, 0x04321605, 0x0a2027a0,   // az.ha.sw_655 mt.sl.un_980  hr.bs.fi_333 gd.sq.pt_322
  0x19231108, 0x6b113bec, 0x0f161713, 0x130c1b0c,   // ro.ca.gl_443 so.ro.ceb_644  sr.hr.lv_665 tr.sv.et_543
  // [c050]
  0x4a55355a, 0x29006404, 0x13001e02, 0x681e3555,   // zu.rw.yo_553 lg.sl.un_320  ms.et.un_220 zu.ms.ig_442
  0x1c2d1ea0, 0x1a002904, 0x1a1e10a4, 0x0e1c06a9,   // ms.sk.id_322 sl.tl.un_320  lt.ms.tl_433 de.id.is_544
  0x1e1c1fa4, 0x13551205, 0x03001e08, 0x0f003114,   // cy.id.ms_433 hu.rw.et_333  ms.nl.un_430 az.lv.un_660
  0x21641a0c, 0x061353a6, 0x13002319, 0x1c2112ad,   // tl.lg.jw_543 ht.et.de_521  ca.et.un_750 hu.jw.id_643
  // [c060]
  0x1c3564a9, 0x11232a05, 0x21000e07, 0x21291855,   // lg.zu.id_544 mt.ca.ro_333  is.jw.un_420 ga.sl.jw_442
  0x13215308, 0x6b0110a0, 0x032806ad, 0x192a0b07,   // ht.jw.et_443 lt.en.ceb_322  de.sw.nl_643 es.mt.gl_432
  0x0c030e0c, 0x321816ee, 0x28680e05, 0x212804ee,   // is.nl.sv_543 hr.ga.bs_422  is.ig.sw_333 fi.sw.jw_422
  0x6e1e1c08, 0x523f3b07, 0x1118250c, 0x356428ec,   // id.ms.hmn_443 so.af.ha_432  eu.ga.ro_543 sw.lg.zu_644
  // [c070]
  0x35000920, 0x1c0921ad, 0x086e1a07, 0x02126804,   // pl.zu.un_850 jw.pl.id_643  tl.hmn.no_432 ig.hu.da_332
  0x01211cad, 0x07001b21, 0x09004a0e, 0x183b095a,   // id.jw.en_643 tr.it.un_860  yo.pl.un_550 pl.so.ga_553
  0x0f001b07, 0x1a6e28ec, 0x311b0405, 0x322916ee,   // tr.lv.un_420 sw.hmn.tl_644  fi.tr.az_333 hr.sl.bs_422
  0x13120609, 0x35556bec, 0x3b0c0ea6, 0x640135a7,   // de.hu.et_444 ceb.rw.zu_644  is.sv.so_521 zu.en.lg_532
  // [c080]
  0x20006818, 0x35071208, 0x0a64350c, 0x2112230c,   // ig.sq.un_740 hu.it.zu_443  zu.lg.pt_543 ca.hu.jw_543
  0x23521aa4, 0x1352250c, 0x0720080c, 0x18121baf,   // tl.ha.ca_433 eu.ha.et_543  no.sq.it_543 tr.hu.ga_655
  0x1700350b, 0x192311a7, 0x04003519, 0x521a3511,   // zu.sr.un_520 ro.ca.gl_532  zu.fi.un_750 zu.tl.ha_653
  0x230f0b13, 0x11313507, 0x0a002102, 0x110723ad,   // es.lv.ca_665 zu.az.ro_432  jw.pt.un_220 ca.it.ro_643
  // [c090]
  0x19000412, 0x060305ee, 0x0c5208af, 0x0411250c,   // fi.gl.un_640 fr.nl.de_422  no.ha.sv_655 eu.ro.fi_543
  0x09000202, 0x120e520e, 0x280a25a4, 0x191c11ee,   // da.pl.un_220 ha.is.hu_555  eu.pt.sw_433 ro.id.gl_422
  0x0527040c, 0x3f000602, 0x32170f05, 0x05202509,   // fi.gd.fr_543 de.af.un_220  lv.sr.bs_333 eu.sq.fr_444
  0x0e002522, 0x13014aee, 0x10000d04, 0x25040ea4,   // eu.is.un_870 yo.en.et_422  cs.lt.un_320 is.fi.eu_433
  // [c0a0]
  0x2b0810a4, 0x17131ba4, 0x13005314, 0x0c0213ec,   // lt.no.vi_433 tr.et.sr_433  ht.et.un_660 et.da.sv_644
  0x2852640c, 0x531129a0, 0x1e1c0a02, 0x12000314,   // lg.ha.sw_543 sl.ro.ht_322  pt.id.ms_222 nl.hu.un_660
  0x0223250c, 0x6e002d08, 0x35536e07, 0x3200130c,   // eu.ca.da_543 sk.hmn.un_430  hmn.ht.zu_432 et.bs.un_530
  0x52282511, 0x2a1b3113, 0x16111a07, 0x291f2da0,   // eu.sw.ha_653 az.tr.mt_665  tl.ro.hr_432 sk.cy.sl_322
  // [c0b0]
  0x2a52010c, 0x311a6b0c, 0x3b2855af, 0x4a12195a,   // en.ha.mt_543 ceb.tl.az_543  rw.sw.so_655 gl.hu.yo_553
  0x0b0a1ca0, 0x05000d0d, 0x1f001902, 0x0e270607,   // id.pt.es_322 cs.fr.un_540  gl.cy.un_220 de.gd.is_432
  0x6b0a1911, 0x01000a02, 0x091f3fa7, 0x1e1c2111,   // gl.pt.ceb_653 pt.en.un_220  af.cy.pl_532 jw.id.ms_653
  0x04293b08, 0x0c082107, 0x07030611, 0x02002d04,   // so.sl.fi_443 jw.no.sv_432  de.nl.it_653 sk.da.un_320
  // [c0c0]
  0x08023fec, 0x0b002b04, 0x2b102008, 0x290d01a9,   // af.da.no_644 vi.es.un_320  sq.lt.vi_443 en.cs.sl_544
  0x18272a04, 0x100f01a9, 0x1805080b, 0x085323ad,   // mt.gd.ga_332 en.lv.lt_544  no.fr.ga_542 ca.ht.no_643
  0x1f003f02, 0x310e0111, 0x252d0909, 0x0f0c3fa9,   // af.cy.un_220 en.is.az_653  pl.sk.eu_444 af.sv.lv_544
  0x09522da4, 0x080227a4, 0x030625af, 0x32080ca4,   // sk.ha.pl_433 gd.da.no_433  eu.de.nl_655 sv.no.bs_433
  // [c0d0]
  0x093552a9, 0x275302ad, 0x20080ca9, 0x1a6b13ec,   // ha.zu.pl_544 da.ht.gd_643  sv.no.sq_544 et.ceb.tl_644
  0x042053a7, 0x2a201b07, 0x6b013f05, 0x3b2531ad,   // ht.sq.fi_532 tr.sq.mt_432  af.en.ceb_333 az.eu.so_643
  0x10003102, 0x0c136b0c, 0x520c23ec, 0x0b236b05,   // az.lt.un_220 ceb.et.sv_543  ca.sv.ha_644 ceb.ca.es_333
  0x130f0c02, 0x55162da4, 0x136b1aad, 0x0f100a11,   // sv.lv.et_222 sk.hr.rw_433  tl.ceb.et_643 pt.lt.lv_653
  // [c0e0]
  0x52551307, 0x3b1b10a9, 0x1a5513a4, 0x07002702,   // et.rw.ha_432 lt.tr.so_544  et.rw.tl_433 gd.it.un_220
  0x190b0fa0, 0x35040fa4, 0x1c1b1e0d, 0x17293b0c,   // lv.es.gl_322 lv.fi.zu_433  ms.tr.id_554 so.sl.sr_543
  0x1a002a0d, 0x033b1ba9, 0x0f000602, 0x0e1a6bec,   // mt.tl.un_540 tr.so.nl_544  de.lv.un_220 ceb.tl.is_644
  0x040c1312, 0x1b0c0a0c, 0x1f683ba7, 0x6b1f55ee,   // et.sv.fi_654 pt.sv.tr_543  so.ig.cy_532 rw.cy.ceb_422
  // [c0f0]
  0x1700520c, 0x64551a5a, 0x3b000502, 0x25106805,   // ha.sr.un_530 tl.rw.lg_553  fr.so.un_220 ig.lt.eu_333
  0x012b08a4, 0x12171609, 0x090a2daf, 0x06291105,   // no.vi.en_433 hr.sr.hu_444  sk.pt.pl_655 ro.sl.de_333
  0x53112911, 0x2d1806a4, 0x1a6b20ee, 0x2d0735a0,   // sl.ro.ht_653 de.ga.sk_433  sq.ceb.tl_422 zu.it.sk_322
  0x0d162dac, 0x04521e08, 0x016813a0, 0x130e280d,   // sk.hr.cs_632 ms.ha.fi_443  et.ig.en_322 sw.is.et_554
  // [c100]
  0x5500311a, 0x0c27180c, 0x3b3f27a4, 0x123b1aac,   // az.rw.un_760 ga.gd.sv_543  gd.af.so_433 tl.so.hu_632
  0x052853a9, 0x131a1f02, 0x27003b2b, 0x1c0b180c,   // ht.sw.fr_544 cy.tl.et_222  so.gd.un_980 ga.es.id_543
  0x12050aaf, 0x522328a4, 0x645312ec, 0x0a1b2808,   // pt.fr.hu_655 sw.ca.ha_433  hu.ht.lg_644 sw.tr.pt_443
  0x552135ad, 0x0c001312, 0x31521bec, 0x27053ba0,   // zu.jw.rw_643 et.sv.un_640  tr.ha.az_644 so.fr.gd_322
  // [c110]
  0x10001b1b, 0x00001837, 0x121a10a4, 0x0f003b02,   // tr.lt.un_770 ar.un.un_B00  lt.tl.hu_433 so.lv.un_220
  0x10313f5a, 0x4a27090c, 0x3f0635a9, 0x021708a9,   // af.az.lt_553 pl.gd.yo_543  zu.de.af_544 no.sr.da_544
  0x12190512, 0x02005302, 0x27071111, 0x02001102,   // fr.gl.hu_654 ht.da.un_220  ro.it.gd_653 ro.da.un_220
  0x31002802, 0x0f0906a6, 0x21003104, 0x1e000605,   // sw.az.un_220 de.pl.lv_521  az.jw.un_320 de.ms.un_330
  // [c120]
  0x1a200607, 0x0b00550c, 0x0c20290c, 0x111008ec,   // de.sq.tl_432 rw.es.un_530  sl.sq.sv_543 uk.be.ro_644
  0x55001e02, 0x1c062007, 0x190d20a0, 0x07053ba0,   // ms.rw.un_220 sq.de.id_432  sq.cs.gl_322 so.fr.it_322
  0x090f2955, 0x0d0a2da4, 0x0713045a, 0x06281a05,   // sl.lv.pl_442 sk.pt.cs_433  fi.et.it_553 tl.sw.de_333
  0x0d2d2107, 0x230c07a4, 0x2320010c, 0x18192705,   // jw.sk.cs_432 it.sv.ca_433  en.sq.ca_543 gd.gl.ga_333
  // [c130]
  0x52001804, 0x3f020304, 0x0f1612a4, 0x31091b04,   // ga.ha.un_320 nl.da.af_332  hu.hr.lv_433 tr.pl.az_332
  0x2b000307, 0x070a115a, 0x07012a14, 0x1c001704,   // nl.vi.un_420 ro.mk.bg_553  mt.en.it_666 sr.id.un_320
  0x102d3204, 0x525321a4, 0x0a072aa4, 0x2b001019,   // bs.sk.lt_332 jw.ht.ha_433  mt.it.pt_433 lt.vi.un_750
  0x28216813, 0x35096ba4, 0x3b5352a4, 0x27000708,   // ig.jw.sw_665 ceb.pl.zu_433  ha.ht.so_433 it.gd.un_430
  // [c140]
  0x6b00550d, 0x350e1007, 0x1320100c, 0x1e1c0308,   // rw.ceb.un_540 lt.is.zu_432  lt.sq.et_543 nl.id.ms_443
  0x032d010b, 0x0a2312b2, 0x04000519, 0x35316402,   // en.sk.nl_542 hu.ca.pt_732  fr.fi.un_750 lg.az.zu_222
  0x0a0512bb, 0x180a12ac, 0x06040504, 0x11072d0c,   // hu.fr.pt_854 hu.pt.ga_632  fr.fi.de_332 sk.it.ro_543
  0x3f2a0204, 0x0a0e0204, 0x042010af, 0x1a0405ad,   // da.mt.af_332 da.is.pt_332  lt.sq.fi_655 fr.fi.tl_643
  // [c150]
  0x3100030d, 0x554a2802, 0x640b4a0c, 0x27002802,   // nl.az.un_540 sw.yo.rw_222  yo.es.lg_543 sw.gd.un_220
  0x321768ac, 0x2d211f5a, 0x190b5302, 0x18030612,   // ig.sr.bs_632 cy.jw.sk_553  ht.es.gl_222 de.nl.ga_654
  0x1e211ca7, 0x554a28ec, 0x11190108, 0x0d003f07,   // id.jw.ms_532 sw.yo.rw_644  en.gl.ro_443 af.cs.un_420
  0x1f1220ec, 0x0110070c, 0x1e1c2da4, 0x07251108,   // sq.hu.cy_644 it.lt.en_543  sk.id.ms_433 ro.eu.it_443
  // [c160]
  0x35315502, 0x0e211b0c, 0x13000e02, 0x1c211f07,   // rw.az.zu_222 tr.jw.is_543  is.et.un_220 cy.jw.id_432
  0x1e23055a, 0x13005202, 0x0e08100c, 0x13523bee,   // fr.ca.ms_553 ha.et.un_220  lt.no.is_543 so.ha.et_422
  0x28131a08, 0x4a2864ec, 0x0d000b04, 0x1b121aa7,   // tl.et.sw_443 lg.sw.yo_644  es.cs.un_320 tl.hu.tr_532
  0x311b1cec, 0x07001e02, 0x21203b0d, 0x1200110e,   // id.tr.az_644 ms.it.un_220  so.sq.jw_554 ro.hu.un_550
  // [c170]
  0x18000619, 0x356801a4, 0x1f28520c, 0x2a00520b,   // de.ga.un_750 en.ig.zu_433  ha.sw.cy_543 ha.mt.un_520
  0x35182112, 0x0306355a, 0x64212811, 0x25115309,   // jw.ga.zu_654 zu.de.nl_553  sw.jw.lg_653 ht.ro.eu_444
  0x06000414, 0x2d0d25af, 0x18000b02, 0x27101804,   // fi.de.un_660 eu.cs.sk_655  es.ga.un_220 ga.lt.gd_332
  0x20522a04, 0x1e1f1c0c, 0x6b52090c, 0x10060955,   // mt.ha.sq_332 id.cy.ms_543  pl.ha.ceb_543 pl.de.lt_442
  // [c180]
  0x16296b07, 0x090312ec, 0x13252d08, 0x1b001602,   // ceb.sl.hr_432 hu.nl.pl_644  sk.eu.et_443 hr.tr.un_220
  0x683555a4, 0x2d121ba0, 0x20060c5a, 0x211335a6,   // rw.zu.ig_433 tr.hu.sk_322  sv.de.sq_553 zu.et.jw_521
  0x09066413, 0x1f060ea9, 0x1300060e, 0x03002318,   // lg.de.pl_665 is.de.cy_544  de.et.un_550 ca.nl.un_740
  0x0e000c21, 0x160f1bad, 0x253564ec, 0x685264ad,   // sv.is.un_860 tr.lv.hr_643  lg.zu.eu_644 lg.ha.ig_643
  // [c190]
  0x190a0bee, 0x68003108, 0x191206a6, 0x3f2835ad,   // es.pt.gl_422 az.ig.un_430  de.hu.gl_521 zu.sw.af_643
  0x27121a07, 0x1a001221, 0x2a001f0b, 0x1b525512,   // tl.hu.gd_432 hu.tl.un_860  cy.mt.un_520 rw.ha.tr_654
  0x1b6b6802, 0x3564250e, 0x0c002b04, 0x1b06120e,   // ig.ceb.tr_222 eu.lg.zu_555  vi.sv.un_320 hu.de.tr_555
  0x2a0410ad, 0x20123512, 0x121e1c14, 0x070919a4,   // lt.fi.mt_643 zu.hu.sq_654  id.ms.hu_666 gl.pl.it_433
  // [c1a0]
  0x282055a9, 0x12003529, 0x046b4a0e, 0x551711a9,   // rw.sq.sw_544 zu.hu.un_960  yo.ceb.fi_555 ro.sr.rw_544
  0x04100aec, 0x11100f13, 0x04132a07, 0x55001b08,   // mk.be.ru_644 lv.lt.ro_665  mt.et.fi_432 tr.rw.un_430
  0x03093f04, 0x32255514, 0x10250460, 0x1b552a08,   // af.pl.nl_332 rw.eu.bs_666  fi.eu.lt_664 mt.rw.tr_443
  0x32172911, 0x35001e1a, 0x6b001105, 0x32172d0c,   // sl.sr.bs_653 ms.zu.un_760  ro.ceb.un_330 sk.sr.bs_543
  // [c1b0]
  0x28526b04, 0x52000d08, 0x3f001f0d, 0x110301ad,   // ceb.ha.sw_332 cs.ha.un_430  cy.af.un_540 en.nl.ro_643
  0x0d005214, 0x090d050d, 0x050d20a0, 0x02001812,   // ha.cs.un_660 fr.cs.pl_554  sq.cs.fr_322 ga.da.un_640
  0x4a00280e, 0x4a3555ad, 0x2d0d2855, 0x1b1e4a55,   // sw.yo.un_550 rw.zu.yo_643  sw.cs.sk_442 yo.ms.tr_442
  0x3217030c, 0x17002002, 0x0b002802, 0x01002902,   // nl.sr.bs_543 sq.sr.un_220  sw.es.un_220 sl.en.un_220
  // [c1c0]
  0x13040111, 0x0c6808ee, 0x0810130c, 0x646b35a0,   // en.fi.et_653 no.ig.sv_422  et.lt.no_543 zu.ceb.lg_322
  0x063f1ba9, 0x120425af, 0x556407ee, 0x2a003509,   // tr.af.de_544 eu.fi.hu_655  it.lg.rw_422 zu.mt.un_440
  0x04521ba4, 0x35554aec, 0x1a00530c, 0x01121ba7,   // tr.ha.fi_433 yo.rw.zu_644  ht.tl.un_530 tr.hu.en_532
  0x0f002b0e, 0x100b050c, 0x091f3fa9, 0x01056b07,   // vi.lv.un_550 fr.es.lt_543  af.cy.pl_544 ceb.fr.en_432
  // [c1d0]
  0x022d0305, 0x1a311bad, 0x041c1313, 0x0302185a,   // nl.sk.da_333 tr.az.tl_643  et.id.fi_665 ga.da.nl_553
  0x1b001302, 0x21056ea7, 0x1c251eec, 0x0e250fac,   // et.tr.un_220 hmn.fr.jw_532  ms.eu.id_644 lv.eu.is_632
  0x02172a04, 0x0f002b07, 0x21091c05, 0x1b00210e,   // mt.sr.da_332 vi.lv.un_420  id.pl.jw_333 jw.tr.un_550
  0x552805a0, 0x100f0455, 0x1a130f07, 0x25001302,   // fr.sw.rw_322 fi.lv.lt_442  lv.et.tl_432 et.eu.un_220
  // [c1e0]
  0x16173212, 0x130c080e, 0x0a001b02, 0x130308a4,   // bs.sr.hr_654 no.sv.et_555  tr.pt.un_220 no.nl.et_433
  0x08003104, 0x31000f04, 0x3b642108, 0x270752ac,   // az.no.un_320 lv.az.un_320  jw.lg.so_443 ha.it.gd_632
  0x03053f04, 0x2917080c, 0x1a003202, 0x120e18af,   // af.fr.nl_332 no.sr.sl_543  bs.tl.un_220 ga.is.hu_655
  0x080e02ac, 0x53192811, 0x0b1328a4, 0x07211008,   // da.is.no_632 sw.gl.ht_653  sw.et.es_433 lt.jw.it_443
  // [c1f0]
  0x6b00101a, 0x6e2d29ad, 0x31521ba4, 0x64001319,   // lt.ceb.un_760 sl.sk.hmn_643  tr.ha.az_433 et.lg.un_750
  0x6b103513, 0x0a0b10a7, 0x02005312, 0x13550208,   // zu.lt.ceb_665 lt.es.pt_532  ht.da.un_640 da.rw.et_443
  0x551b180c, 0x13001123, 0x08000319, 0x4a23530e,   // ga.tr.rw_543 ro.et.un_880  nl.no.un_750 ht.ca.yo_555
  0x10110807, 0x4a1a0b04, 0x1a002d08, 0x162053a4,   // uk.ro.be_432 es.tl.yo_332  sk.tl.un_430 ht.sq.hr_433
  // [c200]
  0x060113a9, 0x0b6e19ee, 0x030b0a0d, 0x0c001813,   // et.en.de_544 gl.hmn.es_422  pt.es.nl_554 ga.sv.un_650
  0x2d0e0dad, 0x35556b55, 0x3b00200b, 0x1b160fa4,   // cs.is.sk_643 ceb.rw.zu_442  sq.so.un_520 lv.hr.tr_433
  0x20132aad, 0x1f5231ee, 0x35002b29, 0x06180eee,   // mt.et.sq_643 az.ha.cy_422  vi.zu.un_960 is.ga.de_422
  0x11200fee, 0x28182a05, 0x35205511, 0x12003113,   // lv.sq.ro_422 mt.ga.sw_333  rw.sq.zu_653 az.hu.un_650
  // [c210]
  0x232b0c07, 0x52352805, 0x100502ee, 0x1b042aa4,   // sv.vi.ca_432 sw.zu.ha_333  da.fr.lt_422 mt.fi.tr_433
  0x2a000d05, 0x0f2012ad, 0x525525ad, 0x1325280c,   // cs.mt.un_330 hu.sq.lv_643  eu.rw.ha_643 sw.eu.et_543
  0x10040f0c, 0x68001704, 0x20000d07, 0x2a003f08,   // lv.fi.lt_543 sr.ig.un_320  cs.sq.un_420 af.mt.un_430
  0x0c002914, 0x1f002b07, 0x111628a9, 0x03060955,   // sl.sv.un_660 vi.cy.un_420  sw.hr.ro_544 pl.de.nl_442
  // [c220]
  0x29060c60, 0x0400121a, 0x1a001605, 0x176428ad,   // sv.de.sl_664 hu.fi.un_760  hr.tl.un_330 sw.lg.sr_643
  0x060304a9, 0x170c0612, 0x030619ee, 0x320e2802,   // fi.nl.de_544 de.sv.sr_654  gl.de.nl_422 sw.is.bs_222
  0x07113505, 0x1e1c0f07, 0x0200042b, 0x29132a09,   // zu.ro.it_333 lv.id.ms_432  fi.da.un_980 mt.et.sl_444
  0x0c0d2d0c, 0x2d131212, 0x0d0311a4, 0x211b2012,   // sk.cs.sv_543 hu.et.sk_654  ro.nl.cs_433 sq.tr.jw_654
  // [c230]
  0x0b000519, 0x0e0864a4, 0x0e0f4aa4, 0x64040e08,   // fr.es.un_750 lg.no.is_433  yo.lv.is_433 is.fi.lg_443
  0x21132aa4, 0x202928ec, 0x11016b08, 0x044a0eac,   // mt.et.jw_433 sw.sl.sq_644  ceb.en.ro_443 is.yo.fi_632
  0x084a0e07, 0x090220a0, 0x4a64350c, 0x52640e07,   // is.yo.no_432 sq.da.pl_322  zu.lg.yo_543 is.lg.ha_432
  0x31101b07, 0x52086407, 0x31000e09, 0x160b10ad,   // tr.lt.az_432 lg.no.ha_432  is.az.un_440 lt.es.hr_643
  // [c240]
  0x1e002009, 0x13042909, 0x31190b08, 0x070b06a4,   // sq.ms.un_440 sl.fi.et_444  es.gl.az_443 de.es.it_433
  0x080c6412, 0x07060309, 0x310e3b55, 0x010910ad,   // lg.sv.no_654 nl.de.it_444  so.is.az_442 lt.pl.en_643
  0x1f000a02, 0x1b1a0a07, 0x03060714, 0x182d0e0c,   // pt.cy.un_220 pt.tl.tr_432  it.de.nl_666 is.sk.ga_543
  0x03080604, 0x25122108, 0x1b2006ac, 0x063203a4,   // de.no.nl_332 jw.hu.eu_443  de.sq.tr_632 nl.bs.de_433
  // [c250]
  0x03213fa4, 0x07002a2b, 0x35000707, 0x53002322,   // af.jw.nl_433 mt.it.un_980  it.zu.un_420 ca.ht.un_870
  0x35121e08, 0x0c000318, 0x1f00230e, 0x12231b08,   // ms.hu.zu_443 nl.sv.un_740  ca.cy.un_550 tr.ca.hu_443
  0x64352805, 0x0b110604, 0x270518af, 0x28182a08,   // sw.zu.lg_333 de.ro.es_332  ga.fr.gd_655 mt.ga.sw_443
  0x02113104, 0x3b12080c, 0x08022309, 0x011803ee,   // az.ro.da_332 no.hu.so_543  ca.da.no_444 nl.ga.en_422
  // [c260]
  0x090c29a4, 0x0d2d270d, 0x2a3b2811, 0x0c000714,   // sl.sv.pl_433 gd.sk.cs_554  sw.so.mt_653 it.sv.un_660
  0x27182860, 0x2721280c, 0x110d55a4, 0x2508040c,   // sw.ga.gd_664 sw.jw.gd_543  rw.cs.ro_433 fi.no.eu_543
  0x1c1b28a0, 0x0e006e08, 0x190b55a0, 0x130706a4,   // sw.tr.id_322 hmn.is.un_430  rw.es.gl_322 de.it.et_433
  0x1107230d, 0x1e2135ac, 0x2718070e, 0x07001307,   // ca.it.ro_554 zu.jw.ms_632  it.ga.gd_555 et.it.un_420
  // [c270]
  0x13071bee, 0x2a111814, 0x3b354a13, 0x16290aa9,   // tr.it.et_422 ga.ro.mt_666  yo.zu.so_665 pt.sl.hr_544
  0x1c213b0c, 0x0b0a0da6, 0x020c05ee, 0x1907235a,   // so.jw.id_543 cs.pt.es_521  fr.sv.da_422 ca.it.gl_553
  0x0b040f04, 0x0900551b, 0x35001902, 0x185509ad,   // lv.fi.es_332 rw.pl.un_770  gl.zu.un_220 pl.rw.ga_643
  0x64550960, 0x190955a4, 0x55002902, 0x130f0411,   // pl.rw.lg_664 rw.pl.gl_433  sl.rw.un_220 fi.lv.et_653
  // [c280]
  0x09320f0c, 0x290b28ad, 0x130f10a4, 0x09100fa9,   // lv.bs.pl_543 sw.es.sl_643  lt.lv.et_433 lv.lt.pl_544
  0x2a002019, 0x120805a4, 0x0e100f0e, 0x130f0dee,   // sq.mt.un_750 fr.no.hu_433  lv.lt.is_555 cs.lv.et_422
  0x18005309, 0x320f165a, 0x20230baf, 0x0f041305,   // ht.ga.un_440 hr.lv.bs_553  es.ca.sq_655 et.fi.lv_333
  0x29286855, 0x52001f08, 0x532a6855, 0x216b06ee,   // ig.sw.sl_442 cy.ha.un_430  ig.mt.ht_442 de.ceb.jw_422
  // [c290]
  0x0f0510ee, 0x2a000419, 0x3f0f2da4, 0x040201a0,   // lt.fr.lv_422 fi.mt.un_750  sk.lv.af_433 en.da.fi_322
  0x063f2a07, 0x0700130c, 0x3217280c, 0x042d2b02,   // mt.af.de_432 et.it.un_530  sw.sr.bs_543 vi.sk.fi_222
  0x063f0b0c, 0x11290f07, 0x12292307, 0x101b0304,   // es.af.de_543 lv.sl.ro_432  ca.sl.hu_432 nl.tr.lt_332
  0x290d17a6, 0x64171ca4, 0x0508210c, 0x0c001208,   // sr.cs.sl_521 id.sr.lg_433  jw.no.fr_543 hu.sv.un_430
  // [c2a0]
  0x0f281005, 0x553b0305, 0x0d022d60, 0x1108175a,   // lt.sw.lv_333 nl.so.rw_333  sk.da.cs_664 sr.uk.ro_553
  0x122016a4, 0x202912ee, 0x0f121008, 0x323555ad,   // hr.sq.hu_433 hu.sl.sq_422  lt.hu.lv_443 rw.zu.bs_643
  0x1b0e08a4, 0x0d6b2d0c, 0x09000809, 0x0e2d1212,   // no.is.tr_433 sk.ceb.cs_543  no.pl.un_440 hu.sk.is_654
  0x32166ea0, 0x19002012, 0x0600110c, 0x05001821,   // hmn.hr.bs_322 sq.gl.un_640  ro.de.un_530 ga.fr.un_860
  // [c2b0]
  0x0d2911af, 0x06200c13, 0x01001113, 0x35280604,   // ro.sl.cs_655 sv.sq.de_665  ro.en.un_650 de.sw.zu_332
  0x351827ec, 0x3f25130c, 0x0d11290c, 0x1109290c,   // gd.ga.zu_644 et.eu.af_543  sl.ro.cs_543 sl.pl.ro_543
  0x05291111, 0x0c1b53ec, 0x290d110c, 0x53000c09,   // ro.sl.fr_653 ht.tr.sv_644  ro.cs.sl_543 sv.ht.un_440
  0x27002108, 0x280c200c, 0x1c080c12, 0x64351207,   // jw.gd.un_430 sq.sv.sw_543  sv.no.id_654 hu.zu.lg_432
  // [c2c0]
  0x0e192d09, 0x0f122808, 0x1100091b, 0x015318a0,   // sk.gl.is_444 sw.hu.lv_443  pl.ro.un_770 ga.ht.en_322
  0x685264ee, 0x0f28040d, 0x1f0406a4, 0x040806a4,   // lg.ha.ig_422 fi.sw.lv_554  de.fi.cy_433 de.no.fi_433
  0x04100614, 0x13063f0c, 0x2a050712, 0x031f01ec,   // de.lt.fi_666 af.de.et_543  it.fr.mt_654 en.cy.nl_644
  0x0a001f22, 0x251f0611, 0x2d0b19af, 0x10211b08,   // cy.pt.un_870 de.cy.eu_653  gl.es.sk_655 tr.jw.lt_443
  // [c2d0]
  0x190a0e14, 0x063b35ec, 0x06113fad, 0x190a0609,   // is.pt.gl_666 zu.so.de_644  af.ro.de_643 de.pt.gl_444
  0x041f06ad, 0x033f11a7, 0x0f0425a4, 0x06351faf,   // de.cy.fi_643 ro.af.nl_532  eu.fi.lv_433 cy.zu.de_655
  0x01530602, 0x1a3f3508, 0x110768a7, 0x131c0d08,   // de.ht.en_222 zu.af.tl_443  ig.it.ro_532 ne.mr.bh_443
  0x04000f13, 0x124a2d09, 0x1c281e55, 0x061f35a4,   // lv.fi.un_650 sk.yo.hu_444  ms.sw.id_442 zu.cy.de_433
  // [c2e0]
  0x0e131ba7, 0x0b0e1204, 0x0b203208, 0x29172004,   // tr.et.is_532 hu.is.es_332  bs.sq.es_443 sq.sr.sl_332
  0x231f550c, 0x060910ad, 0x1204530b, 0x20110b0c,   // rw.cy.ca_543 lt.pl.de_643  ht.fi.hu_542 es.ro.sq_543
  0x212925a4, 0x174a28ac, 0x17022a0c, 0x212052a4,   // eu.sl.jw_433 sw.yo.sr_632  mt.da.sr_543 ha.sq.jw_433
  0x09004a1b, 0x53094aad, 0x25551007, 0x09101e07,   // yo.pl.un_770 yo.pl.ht_643  lt.rw.eu_432 ms.lt.pl_432
  // [c2f0]
  0x1b005302, 0x0e00230c, 0x1711120c, 0x25100507,   // ht.tr.un_220 ca.is.un_530  hu.ro.sr_543 fr.lt.eu_432
  0x2d000620, 0x17002804, 0x0f233f08, 0x062a0f0c,   // de.sk.un_850 sw.sr.un_320  af.ca.lv_443 lv.mt.de_543
  0x032d050c, 0x272a1fad, 0x0a070f08, 0x0e040cec,   // fr.sk.nl_543 cy.mt.gd_643  lv.it.pt_443 sv.fi.is_644
  0x3b313f0c, 0x10002b09, 0x13200f05, 0x311e1a12,   // af.az.so_543 vi.lt.un_440  lv.sq.et_333 tl.ms.az_654
  // [c300]
  0x351c1a0c, 0x32160fa4, 0x53232807, 0x53192807,   // tl.id.zu_543 lv.hr.bs_433  sw.ca.ht_432 sw.gl.ht_432
  0x3f101fa7, 0x35000402, 0x55641ea4, 0x530c1f0b,   // cy.lt.af_532 fi.zu.un_220  ms.lg.rw_433 cy.sv.ht_542
  0x21555208, 0x171c21a9, 0x64551aa4, 0x536e05a0,   // ha.rw.jw_443 jw.id.sr_544  tl.rw.lg_433 fr.hmn.ht_322
  0x0500250d, 0x1c3f6ba4, 0x2a05210c, 0x091c21af,   // eu.fr.un_540 ceb.af.id_433  jw.fr.mt_543 jw.id.pl_655
  // [c310]
  0x2a1e5307, 0x10130fa4, 0x01002812, 0x1f20090c,   // ht.ms.mt_432 lv.et.lt_433  sw.en.un_640 pl.sq.cy_543
  0x253b2008, 0x1b552aa7, 0x0e0c1314, 0x091f04a4,   // sq.so.eu_443 mt.rw.tr_532  et.sv.is_666 fi.cy.pl_433
  0x133b080b, 0x13000c21, 0x056b0807, 0x060c1312,   // no.so.et_542 sv.et.un_860  no.ceb.fr_432 et.sv.de_654
  0x190d10ad, 0x31253bec, 0x0c1b1009, 0x2a06070c,   // lt.cs.gl_643 so.eu.az_644  lt.tr.sv_444 it.de.mt_543
  // [c320]
  0x07001e07, 0x55281ca7, 0x080313af, 0x10202da4,   // ms.it.un_420 id.sw.rw_532  et.nl.no_655 sk.sq.lt_433
  0x0e081312, 0x160e03a4, 0x052d11a0, 0x18273504,   // et.no.is_654 nl.is.hr_433  ro.sk.fr_322 zu.gd.ga_332
  0x29232a04, 0x21002a23, 0x1a4a25a7, 0x20000f07,   // mt.ca.sl_332 mt.jw.un_880  eu.yo.tl_532 lv.sq.un_420
  0x68522107, 0x2500280d, 0x32200ea7, 0x281318a4,   // jw.ha.ig_432 sw.eu.un_540  is.sq.bs_532 ga.et.sw_433
  // [c330]
  0x183b2012, 0x1b64310e, 0x35311b0c, 0x11312012,   // sq.so.ga_654 az.lg.tr_555  tr.az.zu_543 sq.az.ro_654
  0x11133b0c, 0x3b251a07, 0x550b0504, 0x35552b5a,   // so.et.ro_543 tl.eu.so_432  fr.es.rw_332 vi.rw.zu_553
  0x0d120508, 0x17091308, 0x211f55a0, 0x25231e0c,   // fr.hu.cs_443 et.pl.sr_443  rw.cy.jw_322 ms.ca.eu_543
  0x0b2b55a9, 0x12000b08, 0x1b2b0b09, 0x3f0f2a07,   // rw.vi.es_544 es.hu.un_430  es.vi.tr_444 mt.lv.af_432
  // [c340]
  0x083f2a04, 0x081b0507, 0x0f043f14, 0x09001709,   // mt.af.no_332 fr.tr.no_432  af.fi.lv_666 sr.pl.un_440
  0x1e001c29, 0x1e211c0b, 0x1e282105, 0x3f2a2108,   // id.ms.un_960 id.jw.ms_542  jw.sw.ms_333 jw.mt.af_443
  0x281e1ba9, 0x3f2513a4, 0x230a11a4, 0x07102008,   // tr.ms.sw_544 et.eu.af_433  ro.pt.ca_433 sq.lt.it_443
  0x2b535507, 0x2a083fa4, 0x19110b09, 0x12041313,   // rw.ht.vi_432 af.no.mt_433  es.ro.gl_444 et.fi.hu_665
  // [c350]
  0x11002d12, 0x2a0f120c, 0x07532a07, 0x2a110304,   // sk.ro.un_640 hu.lv.mt_543  mt.ht.it_432 nl.ro.mt_332
  0x52111ba4, 0x10002502, 0x040b110c, 0x031004ee,   // tr.ro.ha_433 eu.lt.un_220  ro.es.fi_543 fi.lt.nl_422
  0x113f1308, 0x28205504, 0x023f1213, 0x13072da7,   // et.af.ro_443 rw.sq.sw_332  hu.af.da_665 sk.it.et_532
  0x6b552512, 0x080c2aa9, 0x551e250c, 0x12002520,   // eu.rw.ceb_654 mt.sv.no_544  eu.ms.rw_543 eu.hu.un_850
  // [c360]
  0x100409a4, 0x130c05ec, 0x0604080c, 0x03040da4,   // pl.fi.lt_433 fr.sv.et_644  no.fi.de_543 cs.fi.nl_433
  0x12113f08, 0x1b55280d, 0x321e5309, 0x35282505,   // af.ro.hu_443 sw.rw.tr_554  ht.ms.bs_444 eu.sw.zu_333
  0x02002d0c, 0x3b1a55a4, 0x1a1c3ba7, 0x353b640d,   // sk.da.un_530 rw.tl.so_433  so.id.tl_532 lg.so.zu_554
  0x6411350c, 0x0a130704, 0x0b003b02, 0x09001c34,   // zu.ro.lg_543 it.et.pt_332  so.es.un_220 mr.hi.un_A80
  // [c370]
  0x350f3ba4, 0x35525512, 0x0b1f2bad, 0x3b2a520c,   // so.lv.zu_433 rw.ha.zu_654  vi.cy.es_643 ha.mt.so_543
  0x35285208, 0x3f211c11, 0x283b53a4, 0x4a002908,   // ha.sw.zu_443 id.jw.af_653  ht.so.sw_433 sl.yo.un_430
  0x1c005508, 0x1e1c1b0c, 0x020c08ad, 0x3b0b68ee,   // rw.id.un_430 tr.id.ms_543  no.sv.da_643 ig.es.so_422
  0x0f003b0c, 0x53001f0e, 0x10320fa7, 0x121f2da0,   // so.lv.un_530 cy.ht.un_550  lv.bs.lt_532 sk.cy.hu_322
  // [c380]
  0x27000304, 0x01350708, 0x05000a23, 0x19001f07,   // nl.gd.un_320 it.zu.en_443  pt.fr.un_880 cy.gl.un_420
  0x20291a09, 0x322012ad, 0x64010304, 0x1216640c,   // tl.sl.sq_444 hu.sq.bs_643  nl.en.lg_332 lg.hr.hu_543
  0x1c1e1a0c, 0x1e551c0c, 0x29556408, 0x193b3109,   // tl.ms.id_543 id.rw.ms_543  lg.rw.sl_443 az.so.gl_444
  0x100f5211, 0x553b1a13, 0x551e31a9, 0x642916a9,   // ha.lv.lt_653 tl.so.rw_665  az.ms.rw_544 hr.sl.lg_544
  // [c390]
  0x3b002012, 0x0b0e19a4, 0x1e3b0604, 0x0a001e08,   // sq.so.un_640 gl.is.es_433  de.so.ms_332 ms.pt.un_430
  0x27281813, 0x2d0d02a0, 0x211c6405, 0x25321608,   // ga.sw.gd_665 da.cs.sk_322  lg.id.jw_333 hr.bs.eu_443
  0x29256407, 0x1c0c08a4, 0x3f020c12, 0x18282bee,   // lg.eu.sl_432 no.sv.id_433  sv.da.af_654 vi.sw.ga_422
  0x53681a11, 0x683b01ee, 0x0d022dec, 0x190a0b11,   // tl.ig.ht_653 en.so.ig_422  sk.da.cs_644 es.pt.gl_653
  // [c3a0]
  0x20002b02, 0x643b070e, 0x0f322909, 0x123f0705,   // vi.sq.un_220 it.so.lg_555  sl.bs.lv_444 it.af.hu_333
  0x04000b02, 0x0402280d, 0x1e6b5305, 0x0a6b0ca4,   // es.fi.un_220 sw.da.fi_554  ht.ceb.ms_333 sv.ceb.pt_433
  0x060c0513, 0x080e2a12, 0x1f1a0aa6, 0x2b060aad,   // fr.sv.de_665 mt.is.no_654  pt.tl.cy_521 pt.de.vi_643
  0x64002304, 0x0a2b1a04, 0x2a092d60, 0x2b0a2a07,   // ca.lg.un_320 tl.vi.pt_332  sk.pl.mt_664 mt.pt.vi_432
  // [c3b0]
  0x3b6852a9, 0x28012b07, 0x2a28680d, 0x6e092d12,   // ha.ig.so_544 vi.en.sw_432  ig.sw.mt_554 sk.pl.hmn_654
  0x6b0105ee, 0x68214a0c, 0x2b000a0c, 0x68184aa9,   // fr.en.ceb_422 yo.jw.ig_543  pt.vi.un_530 yo.ga.ig_544
  0x11520e0e, 0x0725685a, 0x091f1012, 0x0500532b,   // is.ha.ro_555 ig.eu.it_553  lt.cy.pl_654 ht.fr.un_980
  0x2b520aa7, 0x09101f08, 0x3b4a520c, 0x11002802,   // pt.ha.vi_532 cy.lt.pl_443  ha.yo.so_543 sw.ro.un_220
  // [c3c0]
  0x11136b04, 0x28001107, 0x13091cee, 0x0a001c0d,   // ceb.et.ro_332 ro.sw.un_420  mr.hi.bh_422 id.pt.un_540
  0x2a2035a9, 0x13110cad, 0x0b3f04a4, 0x10020c08,   // zu.sq.mt_544 sv.ro.et_643  fi.af.es_433 sv.da.lt_443
  0x2a000f05, 0x16003107, 0x02000f19, 0x02030611,   // lv.mt.un_330 az.hr.un_420  lv.da.un_750 de.nl.da_653
  0x32000f0c, 0x4a2010ec, 0x06002109, 0x2a640e07,   // lv.bs.un_530 lt.sq.yo_644  jw.de.un_440 is.lg.mt_432
  // [c3d0]
  0x0d100908, 0x111b1e08, 0x20001018, 0x0802290c,   // pl.lt.cs_443 ms.tr.ro_443  lt.sq.un_740 sl.da.no_543
  0x20001002, 0x29080c11, 0x23000b0c, 0x16296807,   // lt.sq.un_220 sv.no.sl_653  es.ca.un_530 ig.sl.hr_432
  0x6b051aa4, 0x02050812, 0x2d0f06a9, 0x07050aa9,   // tl.fr.ceb_433 no.fr.da_654  de.lv.sk_544 pt.fr.it_544
  0x0e111ba9, 0x1b00070c, 0x050253a0, 0x55201011,   // tr.ro.is_544 it.tr.un_530  ht.da.fr_322 lt.sq.rw_653
  // [c3e0]
  0x55201008, 0x17202aa4, 0x18110713, 0x112d1b07,   // lt.sq.rw_443 mt.sq.sr_433  it.ro.ga_665 tr.sk.ro_432
  0x3f09100c, 0x0e07050d, 0x0d002807, 0x130725a9,   // lt.pl.af_543 fr.it.is_554  sw.cs.un_420 eu.it.et_544
  0x112d2104, 0x23000c04, 0x12311bec, 0x2d0e0da9,   // jw.sk.ro_332 sv.ca.un_320  tr.az.hu_644 cs.is.sk_544
  0x31061ba4, 0x6b3555ad, 0x35000e21, 0x08000502,   // tr.de.az_433 rw.zu.ceb_643  is.zu.un_860 fr.no.un_220
  // [c3f0]
  0x6b04130c, 0x0e000913, 0x12042513, 0x0f10200c,   // et.fi.ceb_543 pl.is.un_650  eu.fi.hu_665 sq.lt.lv_543
  0x211b3502, 0x120d04a4, 0x1c32160d, 0x64521204,   // zu.tr.jw_222 fi.cs.hu_433  hr.bs.id_554 hu.ha.lg_332
  0x1008070e, 0x072a0408, 0x1c006419, 0x350d2dec,   // bg.uk.be_555 fi.mt.it_443  lg.id.un_750 sk.cs.zu_644
  0x06102aa4, 0x190a0502, 0x2d0d25ec, 0x20191004,   // mt.lt.de_433 fr.pt.gl_222  eu.cs.sk_644 lt.gl.sq_332

  // [c400]
  0x20041205, 0x0e070da9, 0x29682d11, 0x09160d05,   // hu.fi.sq_333 cs.it.is_544  sk.ig.sl_653 cs.hr.pl_333
  0x68646b60, 0x06271811, 0x2703180b, 0x2b0e55a0,   // ceb.lg.ig_664 ga.gd.de_653  ga.nl.gd_542 rw.is.vi_322
  0x0c2a10af, 0x2d000e04, 0x2d0d0b0c, 0x1f000202,   // lt.mt.sv_655 is.sk.un_320  es.cs.sk_543 da.cy.un_220
  0x0717080e, 0x06311ba9, 0x13000502, 0x1c1929a0,   // uk.sr.bg_555 tr.az.de_544  fr.et.un_220 sl.gl.id_322
  // [c410]
  0x2b00352a, 0x0b000e0d, 0x1f182760, 0x04551205,   // zu.vi.un_970 is.es.un_540  gd.ga.cy_664 hu.rw.fi_333
  0x2753180c, 0x52531807, 0x1b530108, 0x250405ec,   // ga.ht.gd_543 ga.ht.ha_432  en.ht.tr_443 fr.fi.eu_644
  0x041306a6, 0x100e21af, 0x03000519, 0x6b2b0111,   // de.et.fi_521 jw.is.lt_655  fr.nl.un_750 en.vi.ceb_653
  0x2723070c, 0x6b0901ec, 0x12001b02, 0x12011ba4,   // it.ca.gd_543 en.pl.ceb_644  tr.hu.un_220 tr.en.hu_433
  // [c420]
  0x643f23a4, 0x1f000f02, 0x2a003521, 0x52181008,   // ca.af.lg_433 lv.cy.un_220  zu.mt.un_860 lt.ga.ha_443
  0x1004180c, 0x52131008, 0x6b000805, 0x5200181b,   // ga.fi.lt_543 lt.et.ha_443  no.ceb.un_330 ga.ha.un_770
  0x6b0a0604, 0x07003520, 0x03002514, 0x251a1f13,   // de.pt.ceb_332 zu.it.un_850  eu.nl.un_660 cy.tl.eu_665
  0x0728110c, 0x04001c13, 0x06001004, 0x06002520,   // ro.sw.it_543 id.fi.un_650  lt.de.un_320 eu.de.un_850
  // [c430]
  0x3f1a09a4, 0x013f1314, 0x28521f12, 0x08133f08,   // pl.tl.af_433 et.af.en_666  cy.ha.sw_654 af.et.no_443
  0x352319a9, 0x2531180c, 0x31681808, 0x0f000907,   // gl.ca.zu_544 ga.az.eu_543  ga.ig.az_443 pl.lv.un_420
  0x131b040c, 0x531b0707, 0x2a091104, 0x08002002,   // fi.tr.et_543 it.tr.ht_432  ro.pl.mt_332 sq.no.un_220
  0x1e1c32a0, 0x2b0c0308, 0x03101302, 0x1e1a0405,   // bs.id.ms_322 nl.sv.vi_443  et.lt.nl_222 fi.tl.ms_333
  // [c440]
  0x230b0aa9, 0x11525507, 0x03203f08, 0x3b5520a4,   // pt.es.ca_544 rw.ha.ro_432  af.sq.nl_443 sq.rw.so_433
  0x18122dec, 0x1303060d, 0x55312805, 0x0e120811,   // sk.hu.ga_644 de.nl.et_554  sw.az.rw_333 no.hu.is_653
  0x2b001007, 0x0c645508, 0x20230b07, 0x3b522860,   // lt.vi.un_420 rw.lg.sv_443  es.ca.sq_432 sw.ha.so_664
  0x534a64a4, 0x0c001602, 0x52644aad, 0x35640708,   // lg.yo.ht_433 hr.sv.un_220  yo.lg.ha_643 it.lg.zu_443
  // [c450]
  0x35030705, 0x04211008, 0x03000914, 0x550635ad,   // it.nl.zu_333 lt.jw.fi_443  pl.nl.un_660 zu.de.rw_643
  0x0f2004ad, 0x3b00060c, 0x3f013b07, 0x0d1208ad,   // fi.sq.lv_643 de.so.un_530  so.en.af_432 no.hu.cs_643
  0x0107200c, 0x532055af, 0x0b11205a, 0x0d322004,   // sq.it.en_543 rw.sq.ht_655  sq.ro.es_553 sq.bs.cs_332
  0x012005ad, 0x2a6435ec, 0x55072a09, 0x0b003508,   // fr.sq.en_643 zu.lg.mt_644  mt.it.rw_444 zu.es.un_430
  // [c460]
  0x21002b13, 0x0d202812, 0x252007ad, 0x043b130d,   // vi.jw.un_650 sw.sq.cs_654  it.sq.eu_643 et.so.fi_554
  0x07002021, 0x1e006412, 0x0755200c, 0x210464a6,   // sq.it.un_860 lg.ms.un_640  sq.rw.it_543 lg.fi.jw_521
  0x210b2055, 0x0a551107, 0x3f041312, 0x215535ad,   // sq.es.jw_442 ro.rw.pt_432  et.fi.af_654 zu.rw.jw_643
  0x062725ec, 0x0f312512, 0x11080aad, 0x0c006e08,   // eu.gd.de_644 eu.az.lv_654  mk.uk.ro_643 hmn.sv.un_430
  // [c470]
  0x022a080b, 0x08023f07, 0x11123f0d, 0x1a1e10a9,   // no.mt.da_542 af.da.no_432  af.hu.ro_554 lt.ms.tl_544
  0x180c0609, 0x23053f0c, 0x3f0f03a4, 0x05122aec,   // de.sv.ga_444 af.fr.ca_543  nl.lv.af_433 mt.hu.fr_644
  0x20132a0c, 0x081323ee, 0x2a0425af, 0x4a642813,   // mt.et.sq_543 ca.et.no_422  eu.fi.mt_655 sw.lg.yo_665
  0x2d0d2a05, 0x160329a4, 0x0a1307ee, 0x106b0f0c,   // mt.cs.sk_333 sl.nl.hr_433  it.et.pt_422 lv.ceb.lt_543
  // [c480]
  0x20002a1a, 0x0d0f2d07, 0x64071305, 0x09204aee,   // mt.sq.un_760 sk.lv.cs_432  et.it.lg_333 yo.sq.pl_422
  0x55040112, 0x64051309, 0x32175505, 0x2800121b,   // en.fi.rw_654 et.fr.lg_444  rw.sr.bs_333 hu.sw.un_770
  0x550f11a0, 0x162955a4, 0x35282008, 0x6b051208,   // ro.lv.rw_322 rw.sl.hr_433  sq.sw.zu_443 hu.fr.ceb_443
  0x28000e1a, 0x32161eaf, 0x29001b09, 0x08350d0c,   // is.sw.un_760 ms.hr.bs_655  tr.sl.un_440 cs.zu.no_543
  // [c490]
  0x10001e02, 0x2d0d2a0c, 0x08002107, 0x081a0e04,   // ms.lt.un_220 mt.cs.sk_543  jw.no.un_420 is.tl.no_332
  0x1f00081a, 0x06081aa4, 0x53321608, 0x1e1c2905,   // no.cy.un_760 tl.no.de_433  hr.bs.ht_443 sl.id.ms_333
  0x12003118, 0x320d1bee, 0x18006e0b, 0x18010d04,   // az.hu.un_740 tr.cs.bs_422  hmn.ga.un_520 cs.en.ga_332
  0x091b1208, 0x1c031b0c, 0x3f230ea7, 0x080c3f0d,   // hu.tr.pl_443 tr.nl.id_543  is.ca.af_532 af.sv.no_554
  // [c4a0]
  0x052927a0, 0x1709290c, 0x2b003b05, 0x120905a4,   // gd.sl.fr_322 sl.pl.sr_543  so.vi.un_330 fr.pl.hu_433
  0x29002319, 0x0c290fa0, 0x25000c0b, 0x1e2835ac,   // ca.sl.un_750 lv.sl.sv_322  sv.eu.un_520 zu.sw.ms_632
  0x182025a4, 0x131b04ec, 0x05004a14, 0x112506a0,   // eu.sq.ga_433 fi.tr.et_644  yo.fr.un_660 de.eu.ro_322
  0x12184a0c, 0x1b000508, 0x2a2868a9, 0x116b1804,   // yo.ga.hu_543 fr.tr.un_430  ig.sw.mt_544 ga.ceb.ro_332
  // [c4b0]
  0x1b00040d, 0x3f00680b, 0x28000a02, 0x13121155,   // fi.tr.un_540 ig.af.un_520  pt.sw.un_220 ro.hu.et_442
  0x0f090dec, 0x0b1912ad, 0x4a215305, 0x013b2aee,   // cs.pl.lv_644 hu.gl.es_643  ht.jw.yo_333 mt.so.en_422
  0x28645308, 0x11190a0c, 0x21125507, 0x191812ad,   // ht.lg.sw_443 pt.gl.ro_543  rw.hu.jw_432 hu.ga.gl_643
  0x3b1125a4, 0x350b23ee, 0x2700110e, 0x07001309,   // eu.ro.so_433 ca.es.zu_422  ro.gd.un_550 et.it.un_440
  // [c4c0]
  0x0b0168a4, 0x1a6b4a11, 0x0b021f04, 0x530b10ad,   // ig.en.es_433 yo.ceb.tl_653  cy.da.es_332 lt.es.ht_643
  0x21535207, 0x190b25ac, 0x130c0408, 0x521c110c,   // ha.ht.jw_432 eu.es.gl_632  fi.sv.et_443 ro.id.ha_543
  0x55003f08, 0x6b005305, 0x13001904, 0x10001e12,   // af.rw.un_430 ht.ceb.un_330  gl.et.un_320 ms.lt.un_640
  0x316b0ead, 0x20353205, 0x1c051ea4, 0x013b0b07,   // is.ceb.az_643 bs.zu.sq_333  ms.fr.id_433 es.so.en_432
  // [c4d0]
  0x12002719, 0x120e18ad, 0x10132509, 0x0a006b09,   // gd.hu.un_750 ga.is.hu_643  eu.et.lt_444 ceb.pt.un_440
  0x014a29a7, 0x02250511, 0x25032812, 0x2800080e,   // sl.yo.en_532 fr.eu.da_653  sw.nl.eu_654 no.sw.un_550
  0x0b002107, 0x03193fa4, 0x1e0609a4, 0x20002118,   // jw.es.un_420 af.gl.nl_433  pl.de.ms_433 jw.sq.un_740
  0x27182112, 0x251c1eec, 0x640a1ba4, 0x020c03a4,   // jw.ga.gd_654 ms.id.eu_644  tr.pt.lg_433 nl.sv.da_433
  // [c4e0]
  0x1b001f0c, 0x201213a4, 0x3b001a2c, 0x32090d0c,   // cy.tr.un_530 et.hu.sq_433  tl.so.un_990 cs.pl.bs_543
  0x32283bad, 0x3b1a6ba9, 0x3f35640e, 0x190a08a9,   // so.sw.bs_643 ceb.tl.so_544  lg.zu.af_555 no.pt.gl_544
  0x6b103b04, 0x0d1020ee, 0x191223a4, 0x032508a9,   // so.lt.ceb_332 sq.lt.cs_422  ca.hu.gl_433 no.eu.nl_544
  0x2a1a3b08, 0x190a01a4, 0x283b1eaf, 0x1805070c,   // so.tl.mt_443 en.pt.gl_433  ms.so.sw_655 it.fr.ga_543
  // [c4f0]
  0x1a6b5507, 0x32000a0c, 0x5511250c, 0x55003b2a,   // rw.ceb.tl_432 pt.bs.un_530  eu.ro.rw_543 so.rw.un_970
  0x1b1c2112, 0x0325090c, 0x1b2053a9, 0x53000d19,   // jw.id.tr_654 pl.eu.nl_543  ht.sq.tr_544 cs.ht.un_750
  0x3b1c1eac, 0x55003b23, 0x550153ee, 0x081155a7,   // ms.id.so_632 so.rw.un_880  ht.en.rw_422 rw.ro.no_532
  0x1f006807, 0x53556409, 0x0e17080c, 0x133b1c0c,   // ig.cy.un_420 lg.rw.ht_444  no.sr.is_543 id.so.et_543
  // [c500]
  0x3b6b5512, 0x13283bad, 0x1b1112a4, 0x53210511,   // rw.ceb.so_654 so.sw.et_643  hu.ro.tr_433 fr.jw.ht_653
  0x2d0d2955, 0x08003502, 0x06041ea4, 0x32000302,   // sl.cs.sk_442 zu.no.un_220  ms.fi.de_433 nl.bs.un_220
  0x0c06350e, 0x030e0808, 0x02130604, 0x061f0ea0,   // zu.de.sv_555 no.is.nl_443  de.et.da_332 is.cy.de_322
  0x182a060b, 0x28201008, 0x102804ad, 0x05061005,   // de.mt.ga_542 lt.sq.sw_443  fi.sw.lt_643 lt.de.fr_333
  // [c510]
  0x066801a9, 0x021f0ca4, 0x02060ea4, 0x2d0d21ee,   // en.ig.de_544 sv.cy.da_433  is.de.da_433 jw.cs.sk_422
  0x68081fa4, 0x07281a0c, 0x2900520c, 0x11005513,   // cy.no.ig_433 tl.sw.it_543  ha.sl.un_530 rw.ro.un_650
  0x10212004, 0x52553baf, 0x0b1153af, 0x0718645a,   // sq.jw.lt_332 so.rw.ha_655  ht.ro.es_655 lg.ga.it_553
  0x0f002012, 0x201f18ad, 0x110755af, 0x1800061b,   // sq.lv.un_640 ga.cy.sq_643  rw.it.ro_655 de.ga.un_770
  // [c520]
  0x03230cee, 0x012155a4, 0x071328a9, 0x1b645511,   // sv.ca.nl_422 rw.jw.en_433  sw.et.it_544 rw.lg.tr_653
  0x19006405, 0x2b011905, 0x1a254a08, 0x1f001819,   // lg.gl.un_330 gl.en.vi_333  yo.eu.tl_443 ga.cy.un_750
  0x2d0920a9, 0x2500530e, 0x641b5512, 0x55071160,   // sq.pl.sk_544 ht.eu.un_550  rw.tr.lg_654 ro.it.rw_664
  0x11003b14, 0x21002902, 0x646b1b0c, 0x0e286455,   // so.ro.un_660 sl.jw.un_220  tr.ceb.lg_543 lg.sw.is_442
  // [c530]
  0x1e1c07a4, 0x11645307, 0x2807215a, 0x055311a7,   // it.id.ms_433 ht.lg.ro_432  jw.it.sw_553 ro.ht.fr_532
  0x01645505, 0x0a070f12, 0x530b6ba0, 0x55070509,   // rw.lg.en_333 lv.it.pt_654  ceb.es.ht_322 fr.it.rw_444
  0x0f182713, 0x052755a9, 0x6b005307, 0x6b354aec,   // gd.ga.lv_665 rw.gd.fr_544  ht.ceb.un_420 yo.zu.ceb_644
  0x35005319, 0x3504130c, 0x21251308, 0x11071c07,   // ht.zu.un_750 et.fi.zu_543  et.eu.jw_443 id.it.ro_432
  // [c540]
  0x100701a4, 0x55211c09, 0x042a1baf, 0x0a0e18ad,   // en.it.lt_433 id.jw.rw_444  tr.mt.fi_655 ga.is.pt_643
  0x684a520b, 0x1b006402, 0x0f6b02ec, 0x18174a02,   // ha.yo.ig_542 lg.tr.un_220  da.ceb.lv_644 yo.sr.ga_222
  0x28641cee, 0x03520707, 0x6e00230d, 0x090f1308,   // id.lg.sw_422 it.ha.nl_432  ca.hmn.un_540 et.lv.pl_443
  0x173132ee, 0x171e1107, 0x23070b05, 0x1e521c11,   // bs.az.sr_422 ro.ms.sr_432  es.it.ca_333 id.ha.ms_653
  // [c550]
  0x05015308, 0x29132dec, 0x04280dee, 0x0603080c,   // ht.en.fr_443 sk.et.sl_644  cs.sw.fi_422 no.nl.de_543
  0x35104aa7, 0x3b200f12, 0x1e00100c, 0x204a1c07,   // yo.lt.zu_532 lv.sq.so_654  lt.ms.un_530 id.yo.sq_432
  0x1b1f31ee, 0x05682813, 0x1f4a0e08, 0x28530104,   // az.cy.tr_422 sw.ig.fr_665  is.yo.cy_443 en.ht.sw_332
  0x05020811, 0x0700050c, 0x5200071b, 0x0a231105,   // no.da.fr_653 fr.it.un_530  it.ha.un_770 ro.ca.pt_333
  // [c560]
  0x03000819, 0x120855a7, 0x2b281c55, 0x022d080b,   // no.nl.un_750 rw.no.hu_532  id.sw.vi_442 no.sk.da_542
  0x0e4a52a9, 0x32030eee, 0x10160707, 0x1b524a0d,   // ha.yo.is_544 is.nl.bs_422  it.hr.lt_432 yo.ha.tr_554
  0x0c006b02, 0x06270111, 0x68356408, 0x061103ec,   // ceb.sv.un_220 en.gd.de_653  lg.zu.ig_443 nl.ro.de_644
  0x13253b5a, 0x1c351eee, 0x4a3f68ec, 0x01001002,   // so.eu.et_553 ms.zu.id_422  ig.af.yo_644 lt.en.un_220
  // [c570]
  0x1803010b, 0x1c002d08, 0x213b0213, 0x2b350111,   // en.nl.ga_542 sk.id.un_430  da.so.jw_665 en.zu.vi_653
  0x272b18a0, 0x11190a08, 0x06271855, 0x3f1f35ee,   // ga.vi.gd_322 pt.gl.ro_443  ga.gd.de_442 zu.cy.af_422
  0x353b31ad, 0x281c210e, 0x193b0a08, 0x2a003f02,   // az.so.zu_643 jw.id.sw_555  pt.so.gl_443 af.mt.un_220
  0x08023107, 0x3f0f050c, 0x1b00550c, 0x55001805,   // az.da.no_432 fr.lv.af_543  rw.tr.un_530 ga.rw.un_330
  // [c580]
  0x090c530c, 0x11071760, 0x35551e05, 0x082128a4,   // ht.sv.pl_543 sr.bg.ro_664  ms.rw.zu_333 sw.jw.no_433
  0x552a1b08, 0x0e0f0707, 0x070f0a04, 0x1c681e55,   // tr.mt.rw_443 it.lv.is_432  pt.lv.it_332 ms.ig.id_442
  0x53001304, 0x122a08a4, 0x20001911, 0x270c060c,   // et.ht.un_320 no.mt.hu_433  gl.sq.un_630 de.sv.gd_543
  0x021f0c04, 0x64203504, 0x35642507, 0x0e0f10ad,   // sv.cy.da_332 zu.sq.lg_332  eu.lg.zu_432 lt.lv.is_643
  // [c590]
  0x322d29a9, 0x0f080e05, 0x3f020308, 0x092910a6,   // sl.sk.bs_544 is.no.lv_333  nl.da.af_443 lt.sl.pl_521
  0x051b310c, 0x1e08550c, 0x10066b0c, 0x12052aa7,   // az.tr.fr_543 rw.no.ms_543  ceb.de.lt_543 mt.fr.hu_532
  0x112923ee, 0x06080ead, 0x03213f04, 0x19090b12,   // ca.sl.ro_422 is.no.de_643  af.jw.nl_332 es.pl.gl_654
  0x553220ad, 0x2b000521, 0x21252b07, 0x061007a4,   // sq.bs.rw_643 fr.vi.un_860  vi.eu.jw_432 it.lt.de_433
  // [c5a0]
  0x0b00052b, 0x091025a4, 0x280f10ad, 0x190b2da7,   // fr.es.un_980 eu.lt.pl_433  lt.lv.sw_643 sk.es.gl_532
  0x531a1c0c, 0x1a6b1ca0, 0x052b6ea4, 0x1c0f1ea4,   // id.tl.ht_543 id.ceb.tl_322  hmn.vi.fr_433 ms.lv.id_433
  0x17291aa9, 0x25000321, 0x2a1b31a9, 0x6b251aa9,   // tl.sl.sr_544 nl.eu.un_860  az.tr.mt_544 tl.eu.ceb_544
  0x07042508, 0x042313ac, 0x0b050fec, 0x2b100faf,   // eu.fi.it_443 et.ca.fi_632  lv.fr.es_644 lv.lt.vi_655
  // [c5b0]
  0x020806ad, 0x090810a9, 0x100e0f0c, 0x6b0a1a0c,   // de.no.da_643 lt.no.pl_544  lv.is.lt_543 tl.pt.ceb_543
  0x55641a05, 0x1a1204a9, 0x04100e0c, 0x1e1c53a4,   // tl.lg.rw_333 fi.hu.tl_544  is.lt.fi_543 ht.id.ms_433
  0x0452550c, 0x160b0ea4, 0x19170ca4, 0x250e1011,   // rw.ha.fi_543 is.es.hr_433  sv.sr.gl_433 lt.is.eu_653
  0x0c004a05, 0x280e520d, 0x1b0b04ee, 0x17072755,   // yo.sv.un_330 ha.is.sw_554  fi.es.tr_422 gd.it.sr_442
  // [c5c0]
  0x2855190b, 0x55252804, 0x3100190d, 0x092152ad,   // gl.rw.sw_542 sw.eu.rw_332  gl.az.un_540 ha.jw.pl_643
  0x08123b09, 0x072805af, 0x32171aa6, 0x17080ca4,   // so.hu.no_444 fr.sw.it_655  tl.sr.bs_521 sv.no.sr_433
  0x02002a02, 0x13172004, 0x0c521aad, 0x230b530c,   // mt.da.un_220 sq.sr.et_332  tl.ha.sv_643 ht.es.ca_543
  0x1f0420ad, 0x01530ca0, 0x0c09020e, 0x16290ea0,   // sq.fi.cy_643 sv.ht.en_322  da.pl.sv_555 is.sl.hr_322
  // [c5d0]
  0x52110aa0, 0x2a0853a4, 0x212513ee, 0x1b00250e,   // pt.ro.ha_322 ht.no.mt_433  et.eu.jw_422 eu.tr.un_550
  0x211020a4, 0x12002d21, 0x18122db6, 0x0b006b04,   // sq.lt.jw_433 sk.hu.un_860  sk.hu.ga_766 ceb.es.un_320
  0x1b060e55, 0x28350608, 0x06072aa9, 0x281a350d,   // is.de.tr_442 de.zu.sw_443  mt.it.de_544 zu.tl.sw_554
  0x190b07ec, 0x04522505, 0x321707ee, 0x110f25ad,   // it.es.gl_644 eu.ha.fi_333  it.sr.bs_422 eu.lv.ro_643
  // [c5e0]
  0x2835210e, 0x110853ec, 0x3b2128af, 0x64551ea4,   // jw.zu.sw_555 ht.no.ro_644  sw.jw.so_655 ms.rw.lg_433
  0x183b2855, 0x2d1e1c0d, 0x2d0d28a6, 0x55072a12,   // sw.so.ga_442 id.ms.sk_554  sw.cs.sk_521 mt.it.rw_654
  0x3b002121, 0x21183baf, 0x552a0708, 0x25552d0c,   // jw.so.un_860 so.ga.jw_655  it.mt.rw_443 sk.rw.eu_543
  0x28183b5a, 0x07002514, 0x6e006813, 0x0e0c010c,   // so.ga.sw_553 eu.it.un_660  ig.hmn.un_650 en.sv.is_543
  // [c5f0]
  0x270a0508, 0x64004a1b, 0x13126b08, 0x64550c0d,   // fr.pt.gd_443 yo.lg.un_770  ceb.hu.et_443 sv.rw.lg_554
  0x08250c08, 0x350b5305, 0x17080aac, 0x190a250d,   // sv.eu.no_443 ht.es.zu_333  mk.uk.sr_632 eu.pt.gl_554
  0x28182008, 0x53002014, 0x3b282113, 0x0d130ca4,   // sq.ga.sw_443 sq.ht.un_660  jw.sw.so_665 sv.et.cs_433
  0x181a27ad, 0x181312a0, 0x520a0504, 0x351f2812,   // gd.tl.ga_643 hu.et.ga_322  fr.pt.ha_332 sw.cy.zu_654
  // [c600]
  0x1e000b04, 0x2a0812ad, 0x21121c0c, 0x09122a0e,   // es.ms.un_320 hu.no.mt_643  id.hu.jw_543 mt.hu.pl_555
  0x1b00061b, 0x32000802, 0x6b090d0c, 0x196401a7,   // de.tr.un_770 no.bs.un_220  cs.pl.ceb_543 en.lg.gl_532
  0x2d090205, 0x25091208, 0x250d1ba4, 0x2a00640e,   // da.pl.sk_333 hu.pl.eu_443  tr.cs.eu_433 lg.mt.un_550
  0x030d200c, 0x0100190b, 0x1713200c, 0x20080ea4,   // sq.cs.nl_543 gl.en.un_520  sq.et.sr_543 is.no.sq_433
  // [c610] --- double_langprob_start=c614 ---
  0x0e251fad, 0x0a112d04, 0x1f04080c, 0x286b11a0,   // cy.eu.is_643 sk.ro.pt_332  no.fi.cy_543 ro.ceb.sw_322
                                                    //
  };

//  COMPILE_ASSERT(50708 <= 65536, k_indirectbits_too_small);

extern const CLD2TableSummary kQuad_obj = {
  kQuadChrome0122_2,
  kQuadChrome0122_2Ind,
  kQuadChrome0122_2SizeOne,
  kQuadChrome0122_2Size,
  kQuadChrome0122_2KeyMask,
  kQuadChrome0122_2BuildDate,
  kQuadChrome0122_2RecognizedLangScripts,
};

static const uint32 kQuadChrome0122_2_2Size = 0;    // Bucket count
static const uint32 kQuadChrome0122_2_2KeyMask = 0xffffffff;    // Mask hash key

// NOTE: Some compilers will not allow an array of structs to have a constant
//       size of zero. Thus, we tell the code that the size is zero, but
//       actually allocate a single element array that will never be read.
//       More info: https://code.google.com/p/cld2/issues/detail?id=9
static const IndirectProbBucket4 kQuadChrome0122_2_2[1] = {
  // hash_indirect[4], tokens[4] in UTF-8
  {0x00000000,0x00000000,0x00000000,0x00000000} // UNUSED, see above!
  };
  // table_hash = ffff-ffff, unused_entries = 0 (0.00%)

static const uint32 kQuadChrome0122_2_2SizeOne = 2;  // One-langprob count
static const uint32 kQuadChrome0122_2_2IndSize = 2;  // Largest subscript
extern const uint32 kQuadChrome2IndSize = kQuadChrome0122_2_2IndSize; // Source-agnostic named constant
static const uint32 kQuadChrome0122_2_2Ind[kQuadChrome0122_2_2IndSize] = {
  // [0000] --- double_langprob_start=0002 ---
  0x00000000, 0x00000000,                           // -- --
                                                    //
  };

extern const CLD2TableSummary kQuad_obj2 = {
  kQuadChrome0122_2_2,
  kQuadChrome0122_2_2Ind,
  kQuadChrome0122_2_2SizeOne,
  kQuadChrome0122_2_2Size,
  kQuadChrome0122_2_2KeyMask,
  kQuadChrome0122_2BuildDate,
  kQuadChrome0122_2RecognizedLangScripts,
};

}       // End namespace CLD2

// End of generated tables
